;; -*- fundamental -*- ; coding: euc-jp -*-
;; Small size dictionary for SKK system
;; Copyright (C) 1988-1995, 1997, 1999-2003
;;
;; Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
;; Hironobu Takahashi <takahasi@tiny.or.jp>,
;; Masahiro Doteguchi, Miki Inooka,
;; Yukiyoshi Kameyama <kameyama@kuis.kyoto-u.ac.jp>,
;; Akihiko Sasaki, Dai Ando, Junichi Okukawa,
;; Katsushi Sato and Nobuhiro Yamagishi
;;
;; Maintainer: SKK Development Team <skk@ring.gr.jp>
;; Version: $Id: SKK-JISYO.S,v 1.55 2006/01/04 10:25:04 skk-cvs Exp $
;; Keywords: japanese
;; Last Modified: $Date: 2006/01/04 10:25:04 $
;;
;; This dictionary is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either versions 2, or (at your option)
;; any later version.
;;
;; This dictionary is distributed in the hope that it will be useful
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with Daredevil SKK, see the file COPYING.  If not, write to the Free
;; Software Foundation Inc., 51 Franklin St, Fifth Floor, Boston,
;; MA 02110-1301, USA.
;;
;; okuri-ari entries.
わるs /悪/
わるk /悪/
わるi /悪/
わらu /笑/
わらi /笑/
わたt /渡/
わたs /渡/
わたr /渡/亘/亙/渉/
わずらw /煩/
わずらu /患/煩/
わすr /忘/
わざわi /災/
わかs /若/
わかr /別/
わかk /若/
わかi /若/
わr /割/
わk /沸/分/
わb /詫/
よわs /弱/
よわr /弱/
よわm /弱/
よわk /弱/
よわi /弱/
よろこb /喜/
よろs /宜/
よっt /四/
よそおu /装/
よごs /汚/
よごr /汚/
よw /酔/
よu /酔/
よt /酔/四/
よs /寄/良/
よr /寄/因/
よm /読/詠/
よk /良/
よi /良/酔/善/
よb /呼/
ゆるy /緩/
ゆるs /許/
ゆるm /緩/
ゆるi /緩/
ゆたk /豊/
ゆずt /譲/
ゆずr /譲/
ゆがn /歪/
ゆがm /歪/
ゆうs /有/
ゆw /結/
ゆu /結/
ゆs /揺/
ゆr /揺/
ゆk /行/逝/
やわr /柔/軟/和/
やぶr /破/敗/
やどs /宿/
やどr /宿/
やとu /雇/
やっt /八/
やすうr /安売/
やすs /安/
やすm /休/
やすk /安/
やすi /安/
やしなu /養/
やさs /易/優/
やt /八/
やm /辞/病/
やk /焼/
もらw /貰/
もらu /貰/
もらt /貰/
もらi /貰/
もらe /貰/
もよおs /催/
もよr /最寄/
もどt /戻/
もどs /戻/
もどr /戻/
もとm /求/
もっぱr /専/
もっとm /最/
もちi /用/
もぐr /潜/
もうs /申/
もうk /設/儲/
もy /燃/
もt /持/
もs /若/燃/
もr /盛/漏/守/
もe /燃/
めだt /目立/
めずらs /珍/
めざs /目指/
めぐr /巡/
めぐm /恵/
めs /召/
むっt /六/
むずかs /難/
むすb /結/
むくi /報/
むかe /迎/
むt /六/
むs /蒸/
むr /群/蒸/
むk /向/
みのr /実/
みにくi /醜/
みとm /認/
みつk /見付/
みつg /貢/
みっt /三/
みちびk /導/
みだs /乱/
みだr /乱/
みずかr /自/
みじかm /短/
みじかk /短/
みじかi /短/
みじm /惨/
みがk /磨/
みかk /見掛/
みおt /見落/
みt /満/
みs /見/
みr /見/診/
みn /観/
みe /見/
まわs /周/回/
まわr /周/回/
まるm /丸/
まるi /丸/円/
まよu /迷/
まよi /迷/
まもt /守/
まもr /守/
まねk /招/
まぬかr /免/
まなb /学/
まどu /惑/
まつr /祭/
まったk /全/
まちがu /間違/
まちがt /間違/
まちがi /間違/
まちがe /間違/
またたk /瞬/
まずs /貧/
まじw /交/
まじe /交/
まさr /勝/
まぎr /紛/
まかなu /賄/
まかs /任/
まいr /参/
まz /交/混/
まu /舞/
まt /待/
まs /増/
まk /負/巻/
まg /曲/
ほろb /滅/
ほどこs /施/
ほとんd /殆/
ほっs /欲/
ほそs /細/
ほそr /細/
ほそm /細/
ほそi /細/
ほこr /誇/
ほがr /朗/
ほうむr /葬/
ほs /欲/干/
ほr /彫/掘/
ほm /褒/
ほe /吠/
へだt /隔/
へr /減/経/
ふるu /震/奮/
ふるs /古/
ふるm /古/
ふるk /古/
ふるi /古/
ふるe /震/
ふとr /太/
ふとi /太/
ふたたb /再/
ふたt /二/
ふせg /防/
ふくr /膨/
ふくn /含/
ふくm /含/
ふかm /深/
ふかk /深/
ふかi /深/
ふy /増/殖/
ふt /振/
ふs /伏/
ふr /振/触/降/
ふn /踏/
ふm /踏/
ふk /吹/更/噴/老/
ふi /吹/
ふe /増/殖/
ひろu /拾/
ひろm /広/
ひろi /広/
ひろg /広/
ひるがえs /翻/
ひるがえr /翻/
ひらk /開/
ひらi /開/
ひびk /響/
ひとt /一/
ひとs /等/
ひとr /独/
ひたs /浸/
ひたr /浸/
ひそm /潜/
ひさs /久/
ひくm /低/
ひくk /低/
ひくi /低/
ひきi /率/
ひがえr /日帰/
ひかr /光/
ひかe /控/
ひいd /秀/
ひy /冷/
ひr /干/
ひm /秘/
ひk /引/弾/
ひe /冷/
ばk /化/
はんs /反/
はらw /払/
はらu /払/
はらt /払/
はらo /払/
はらi /払/
はらe /払/
はやs /速/早/
はやm /早/速/
はやk /早/速/
はやi /速/早/
はぶk /省/
はばm /阻/
はなはd /甚/
はなt /放/
はなs /離/放/話/
はなr /離/放/
はたらk /働/
はずかしm /辱/
はずs /外/
はずr /外/
はずm /弾/
はじm /始/初/
はしr /走/
はさm /挟/
はこb /運/
はげs /激/
はげm /励/
はかr /図/計/測/量/諮/謀/
はいr /入/
はz /恥/
はy /生/
はu /這/
はt /果/貼/
はr /張/貼/晴/
はn /跳/
はk /掃/吐/履/
はe /生/栄/映/
のぼs /上/
のぼr /登/上/昇/
のぞm /望/臨/
のぞk /除/覗/
のこs /残/
のこr /残/
のがs /逃/
のがr /逃/
のt /載/
のs /載/乗/
のr /乗/載/
のm /飲/
のb /述/延/伸/
ねんごr /懇/
ねらu /狙/
ねらt /狙/
ねらi /狙/
ねむt /眠/
ねむr /眠/
ねむi /眠/
ねばr /粘/
ねがu /願/
ねがi /願/
ねr /寝/練/
ぬすm /盗/
ぬu /縫/
ぬt /塗/
ぬr /塗/濡/
ぬk /抜/
ぬi /抜/
ぬg /脱/
にぶr /鈍/
にぶi /鈍/
になu /担/
にごs /濁/
にごr /濁/
にくs /憎/
にくr /憎/
にくm /憎/
にくi /憎/
にぎw /賑/
にがr /苦/
にがi /苦/
におw /匂/
におu /匂/
におi /匂/
におe /匂/
にあw /似合/
にあu /似合/
にあt /似合/
にあi /似合/
にy /煮/
にr /似/煮/
にg /逃/
にe /煮/
ならu /倣/習/
ならb /並/
なやn /悩/
なやm /悩/
なめr /滑/
なまk /怠/
ななt /七/
ななm /斜/
なつk /懐/
なさk /情/
なごy /和/
なごm /和/
なげk /嘆/
なぐさm /慰/
なぐr /殴/
ながs /流/長/
ながr /流/乍/
ながm /眺/
ながk /長/
ながi /長/永/
なかb /半/
なおs /治/直/
なおr /治/直/
なs /無/成/
なr /慣/鳴/馴/成/
なk /無/鳴/泣/
なi /無/亡/
なg /凪/投/
ともなw /伴/
ともなu /伴/
ともなt /伴/
ともなi /伴/
とむらu /弔/
とぼs /乏/
となr /隣/
となe /唱/
とどこおr /滞/
とどk /届/
ととのu /整/調/
ととのe /整/調/
とつg /嫁/
とおs /遠/通/
とおr /通/
とおk /遠/
とおi /遠/
とうとi /尊/貴/
とうとb /尊/貴/
とz /閉/
とu /問/
とt /撮/
とr /取/撮/捕/執/採/
とm /止/富/留/泊/
とk /解/溶/説/
とi /問/
とg /研/遂/
とb /飛/跳/
できt /出来/
できs /出来/
できr /出来/
できn /出来/
できm /出来/
でr /出/
てつづk /手続/
てつだt /手伝/
てつだi /手伝/
てつだe /手伝/
てきs /適/
ていs /呈/
てr /照/
つらぬk /貫/
つらn /連/
つよm /強/
つよk /強/
つよi /強/
つめt /冷/
つむg /紡/
つぶs /潰/
つのr /募/
つどu /集/
つどi /集/
つとm /勤/努/務/
つづr /綴/
つづk /続/
つつしm /謹/慎/
つつm /包/
つちかu /培/
つたw /伝/
つたu /伝/
つたe /伝/
つぐなu /償/
つくろu /繕/
つくr /作/造/
つかw /遣/
つかu /使/遣/
つかr /疲/
つかm /捕/掴/
つかi /使/
つかe /仕/
ついy /費/
ついe /費/
つt /突/
つr /釣/連/
つm /詰/摘/積/
つk /付/着/突/漬/就/尽/
つi /突/
つg /継/次/接/告/
ちぢr /縮/
ちぢm /縮/
ちぎr /契/
ちがw /違/
ちがu /違/
ちがt /違/
ちがi /違/
ちがe /違/
ちかu /誓/
ちかi /近/
ちいs /小/
ちr /散/
だまt /黙/
だまr /黙/
だいすk /大好/
だs /出/
だk /抱/
たわむr /戯/
たよt /頼/
たよr /頼/便/
たもt /保/
ためs /試/
たまわr /賜/
たまr /溜/
たのs /楽/
たのn /頼/
たのm /頼/
たどr /辿/
たとe /例/
たてまつr /奉/
たっとi /貴/尊/
たっとb /尊/貴/
ただよu /漂/
ただt /直/
ただs /正/但/
たたかu /戦/闘/
たたm /畳/
たたk /叩/
たずさw /携/
たずさe /携/
たずn /尋/訪/
たすk /助/
たしk /確/
たくわe /蓄/
たがやs /耕/
たがi /互/
たかs /高/
たかm /高/
たかk /高/
たかi /高/
たおs /倒/
たおr /倒/
たいs /対/
たいr /平/
たy /絶/
たt /立/建/断/裁/絶/
たs /足/
たr /垂/足/
たm /溜/矯/
たk /炊/
たe /耐/絶/
たb /食/
ぞんz /存/
ぞくs /属/
そろt /揃/
そろi /揃/
そろe /揃/
そむk /背/
そなw /備/
そなe /供/備/
そだt /育/
そそのかs /唆/
そそg /注/
そこn /損/
そu /沿/添/
そt /沿/添/
そr /反/
そm /初/染/
そi /沿/
そe /添/
せまr /迫/
せまi /狭/
せばm /狭/
せr /競/
せm /攻/責/
すわr /座/
するどi /鋭/
すみy /速/
すべt /滑/
すべr /滑/
すばr /素晴/
すなわt /即/
すでn /既/
すたr /廃/
すずs /涼/
すずm /涼/
すすm /進/勧/薦/
すごs /凄/
すごm /凄/
すごk /凄/
すごi /凄/
すこぶr /頗/
すこy /健/
すこs /少/
すぐr /優/
すくu /救/
すくn /少/
すくi /救/
すw /据/
すu /吸/
すt /捨/
すr /擦/摺/刷/
すm /済/住/澄/
すk /好/透/
すi /酸/
すg /過/
すe /据/
すb /統/
しんz /信/
しろk /白/
しろi /白/
しるs /記/
しりぞk /退/
しらb /調/
しゃべt /喋/
しゃべr /喋/
しめs /示/湿/
しめr /湿/
しぼr /搾/絞/
しぶi /渋/
しばr /縛/
しはらw /支払/
しはらu /支払/
しはらt /支払/
しはらi /支払/
しのb /偲/忍/
したたr /滴/
したがu /従/
したがi /従/
したがe /従/
したu /慕/
したs /親/
しずm /沈/静/鎮/
しずk /静/
しげr /茂/
しくm /仕組/
しかt /叱/
しかr /叱/
しいたg /虐/
しあわs /幸/
しr /知/
しn /死/
しm /締/占/絞/染/閉/
しk /敷/
しi /強/
さわt /触/
さわr /触/障/
さわg /騒/
さむs /寒/
さむk /寒/
さむi /寒/
さまたg /妨/
さびs /寂/
さびr /寂/
さばk /裁/捌/
さとs /諭/
さとr /悟/
さだm /定/
さだk /定/
さそu /誘/
さずk /授/
さしだs /差出/
ささe /支/
さけb /叫/
さぐr /探/
さがs /捜/探/
さかr /逆/盛/
さかn /盛/
さかe /栄/
さえぎr /遮/
さいわi /幸/
さs /挿/差/刺/指/
さr /去/
さm /覚/冷/
さk /避/割/咲/裂/
さg /提/下/
さe /冴/
ごぞんz /御存/
こわs /壊/
こわr /壊/
こわk /恐/怖/
こわi /恐/怖/
こわg /怖/恐/
ころs /殺/
ころg /転/
ころb /転/
こまr /困/
こまk /細/
こばm /拒/
このm /好/
ことわr /断/
ことn /異/
こたe /答/応/
こごe /凍/
こころよi /快/
こころざs /志/
こころm /試/
ここのt /九/
こがr /焦/
こおr /凍/
こうむr /被/
こうz /高/講/
こいs /恋/
こy /肥/
こu /乞/請/恋/
こs /越/漉/超/
こr /凝/懲/
こn /込/
こm /込/
こk /濃/
こi /濃/乞/
こg /焦/
こe /越/超/肥/
げんz /減/
けわs /険/
けむr /煙/
けむi /煙/
けっs /決/
けずr /削/
けがs /汚/
けがr /汚/
けs /消/
くわだt /企/
くわw /加/
くわs /詳/
くわe /加/
くろi /黒/
くるu /狂/
くるs /苦/
くるo /狂/
くるi /狂/
くらi /暗/
くらb /比/
くやs /悔/
くもr /曇/
くばr /配/
くつがえs /覆/
くつがえr /覆/
くだs /下/
くだr /下/
くだk /砕/
くずs /崩/
くずr /崩/
くさr /腐/
くさi /臭/
くy /悔/
くw /喰/
くu /食/喰/
くt /喰/朽/
くr /来/繰/暮/食/
くm /酌/組/
くi /食/喰/悔/
くe /喰/
きわm /極/究/窮/
きらw /嫌/
きらu /嫌/
きらt /嫌/
きらi /嫌/
きよm /清/
きよi /清/
きもt /気持/
きびs /厳/
きづk /気付/
きづi /気付/
きたなi /汚/
きたe /鍛/
きそu /競/
きずk /築/
きざs /兆/
きざm /刻/
きs /着/
きr /切/着/
きm /決/
きk /聞/聴/効/利/
きi /聴/
きe /消/
がんばt /頑張/
がんばr /頑張/
かんばs /芳/
かんちがi /勘違/
かんがe /考/
かんz /感/
かんs /関/
かわいr /可愛/
かわいk /可愛/
かわいi /可愛/
かわいg /可愛/
かわr /変/
かわk /渇/乾/
かろy /軽/
かるs /軽/
かるk /軽/
かるi /軽/
からn /絡/
からm /絡/
からi /辛/
かよu /通/
かよi /通/
かもs /醸/
かまu /構/
かまi /構/
かまe /構/
かならz /必/
かなu /叶/
かなs /悲/
かなd /奏/
かつg /担/
かたわr /傍/
かたよr /偏/
かたむk /傾/
かたr /語/
かたm /固/
かたi /硬/堅/固/難/
かぞe /数/
かせg /稼/
かしこi /賢/
かざr /飾/
かさn /重/
かこu /囲/
かこm /囲/
かくs /隠/
かくr /隠/
かぎr /限/
かがやk /輝/
かかw /関/
かかr /係/
かかg /掲/
かかe /抱/
かおr /香/馨/薫/
かえりm /顧/省/
かえs /返/帰/
かえr /帰/返/
かw /変/代/替/換/交/
かu /買/交/飼/
かt /勝/且/
かs /貸/
かr /借/苅/刈/駆/狩/枯/
かn /噛/兼/
かm /噛/
かk /書/掛/欠/架/駆/懸/
かi /買/
かe /変/替/代/換/
おわr /終/
おろs /卸/
おろk /愚/
およg /泳/
およb /及/
おもむk /赴/
おもしろs /面白/
おもしろk /面白/
おもしろi /面白/
おもu /思/
おもs /重/
おもm /重/
おもi /思/重/
おぼe /覚/
おびやk /脅/
おなz /同/
おどろk /驚/
おどろi /驚/
おどs /脅/
おどr /躍/踊/
おどk /脅/
おとろe /衰/
おとずr /訪/
おとしいr /陥/
おとr /劣/
おちいr /陥/
おだy /穏/
おそw /教/
おそu /襲/
おそs /遅/
おそr /恐/
おそk /遅/
おそi /遅/
おしe /教/
おさなi /幼/
おさm /収/修/治/納/
おさe /抑/
おごそk /厳/
おこなu /行/
おこたr /怠/
おこs /興/
おこr /興/怒/
おくr /送/遅/後/
おぎなu /補/
おがm /拝/
おかs /犯/冒/
おおu /覆/
おおs /多/
おおm /多/
おおk /大/多/
おおi /多/大/
おうz /応/
おw /終/
おu /負/追/生/
おt /落/
おs /押/惜/推/
おr /降/折/織/下/
おk /起/置/
おi /追/負/老/
おe /終/
おb /帯/
えらi /偉/
えらb /選/
えがk /描/
えがi /描/
えr /得/
えm /笑/
うれs /嬉/
うれi /憂/愁/
うれe /憂/愁/
うるわs /麗/
うるおu /潤/
うるおs /潤/
うるm /潤/
うらなu /占/
うらなi /占/
うらm /恨/
うやまu /敬/
うやうやs /恭/
うばu /奪/
うばt /奪/
うながs /促/
うとm /疎/
うとi /疎/
うつくs /美/
うつs /移/映/写/
うつr /移/写/映/
うったe /訴/
うたがu /疑/
うたu /歌/謡/
うすr /薄/
うすm /薄/
うすk /薄/
うすi /薄/
うしなu /失/
うしr /後/
うごk /動/
うけたまわr /承/
うかがu /窺/伺/
うかがi /窺/伺/
うt /打/撃/討/
うr /売/熟/得/
うm /埋/産/生/
うk /受/浮/請/
うi /浮/憂/
うe /飢/植/
いわu /祝/
いろどr /彩/
いやs /卑/
いましm /戒/
いのr /祈/
いどm /挑/
いとなm /営/
いつわr /偽/
いつくs /慈/
いつt /五/
いちじるs /著/
いだk /抱/
いだi /抱/
いただk /頂/戴/
いただi /戴/
いたs /致/
いたr /至/
いたm /痛/傷/悼/
いたi /痛/
いそがs /忙/
いそg /急/
いさぎよi /潔/
いさm /勇/
いこu /憩/
いこi /憩/
いくt /幾/
いくr /幾/
いきどおr /憤/
いきおi /勢/
いかt /怒/
いかr /怒/
いu /言/云/
いr /入/居/射/要/鋳/
いm /忌/
いk /行/生/
いi /言/
あわt /慌/
あわs /併/
あわr /哀/
あわi /淡/
あるk /歩/
ありがとu /有難/
ありがたi /有難/
あらわs /現/著/表/
あらわr /現/表/
あらたm /改/
あらそu /争/
あらu /洗/
あらt /新/
あらi /洗/粗/荒/
あゆm /歩/
あやまt /過/
あやまr /誤/謝/
あやつr /操/
あやu /危/
あやs /怪/
あやb /危/
あまy /甘/
あまs /余/
あまr /余/
あまi /甘/
あまe /甘/
あぶn /危/
あばr /暴/
あばk /暴/
あなどr /侮/
あつかw /扱/
あつかu /扱/
あつかt /扱/
あつかo /扱/
あつかi /扱/
あつかe /扱/
あつm /集/
あつk /厚/熱/暑/
あつi /熱/暑/厚/
あたらs /新/
あたたm /暖/温/
あたたk /暖/温/
あたr /辺/
あたe /与/
あそb /遊/
あせr /焦/
あずk /預/
あじw /味/
あざむk /欺/
あざy /鮮/
あさk /浅/
あさi /浅/
あきらm /諦/
あきなu /商/
あきr /明/
あかr /赤/明/
あかn /赤/
あかi /赤/
あおk /青/
あおi /青/
あいかわr /相変/
あw /合/
あu /合/逢/会/遭/
あt /当/充/
あr /有/在/荒/
あm /編/
あk /飽/開/空/明/
あi /合/会/
あg /挙/揚/上/
あb /浴/
;; okuri-nasi entries.
Cyrillic /А/Б/В/Г/Д/Е/Ё/Ж/З/И/Й/К/Л/М/Н/О/П/Р/С/Т/У/Ф/Х/Ц/Ч/Ш/Щ/Ъ/Ы/Ь/Э/Ю/Я/
Greek /Α/Β/Γ/Δ/Ε/Ζ/Η/Θ/Ι/Κ/Λ/Μ/Ν/Ξ/Ο/Π/Ρ/Σ/Τ/Υ/Φ/Χ/Ψ/Ω/
cyrillic /а/б/в/г/д/е/ё/ж/з/и/й/к/л/м/н/о/п/р/с/т/у/ф/х/ц/ч/ш/щ/ъ/ы/ь/э/ю/я/
greek /α/β/γ/δ/ε/ζ/η/θ/ι/κ/λ/μ/ν/ξ/ο/π/ρ/σ/τ/υ/φ/χ/ψ/ω/
あ /阿/唖/亜/娃/
あい /愛/哀/相/挨/
あいさつ /挨拶/
あいだ /間/
あいて /相手/
あいよう /愛用/
あいら /姶良/
あお /青/
あおい /葵/
あか /赤/垢/
あかつき /暁/
あかね /茜/
あき /秋/穐/
あく /悪/握/渥/
あくい /悪意/
あけぼの /曙/
あさ /朝/麻/
あさひ /朝日/旭/
あざ /字/
あし /足/芦/葦/脚/
あした /明日/
あじ /味/鯵/
あす /明日/
あずさ /梓/
あずま /東/
あせ /汗/
あぜ /畦/
あたい /値/価/
あたかも /宛/
あたま /頭/
あたり /辺/
あっしゅく /圧縮/
あっとうてき /圧倒的/
あつ /篤/斡/圧/
あつみ /渥美/
あて /宛/
あてさき /宛先/
あと /後/跡/
あな /穴/
あなた /貴方/
あに /兄/
あね /姉/姐/
あぶ /虻/
あぶら /油/脂/
あま /天/雨/甘/尼/
あまみ /奄美/
あみ /網/
あめ /雨/飴/天/
あや /文/綾/絢/
あゆ /鮎/
あらかじめ /予/
あらがね /鉱/
あらし /嵐/
ある /或/
あるじ /主/
あわ /泡/粟/
あわせ /袷/
あん /安/案/暗/行/杏/鞍/庵/闇/按/
あんか /安価/
あんしん /安心/
あんぜん /安全/
あんない /案内/
い /位/為/意/井/唯/如/偉/異/亥/医/遺/違/謂/衣/萎/胃/緯/維/移/畏/易/慰/惟/尉/威/委/夷/囲/依/伊/以/椅/
いえ /家/
いか /以下/
いかが /如何/
いかだ /筏/
いかり /錨/
いかん /如何/
いがい /以外/意外/
いき /息/域/
いく /郁/育/幾/
いくさ /戦/
いけ /池/
いけん /意見/
いこう /以降/移行/意向/
いご /以後/
いし /石/医師/
いしき /意識/
いしずえ /礎/
いしゃ /医者/
いしょく /移植/
いじ /維持/
いじょう /以上/異常/
いす /椅子/
いずみ /泉/
いせん /緯線/
いぜん /以前/
いそ /磯/
いぞん /依存/
いた /板/
いただき /頂/
いち /一/位置/壱/市/
いちおう /一応/
いちぎょう /一行/
いちげん /一言/
いちじ /一時/一次/
いちど /一度/
いちばん /一番/
いちぶ /一部/
いちらん /一覧/
いっかい /一回/
いっき /一気/
いっけん /一見/
いっこう /一行/
いっしゅ /一種/
いっしょ /一緒/
いったい /一体/
いっち /一致/
いってい /一定/
いっとき /一時/
いっぱつ /一発/
いっぱん /一般/
いっぱんてき /一般的/
いっぽう /一方/
いっぽん /一本/
いつ /一/五/逸/溢/
いと /糸/意図/
いどう /移動/
いな /否/
いなか /田舎/
いぬ /犬/
いね /稲/
いのしし /猪/
いのち /命/
いはん /違反/
いばら /茨/
いま /今/
いみ /意味/
いも /芋/
いもうと /妹/
いや /嫌/
いらい /以来/依頼/
いりぐち /入口/
いろ /色/
いわ /岩/
いわし /鰯/
いん /音/引/印/隠/陰/因/韻/院/蔭/胤/淫/飲/姻/員/咽/允/
いんさつ /印刷/
いんしょう /印象/
いんじ /印字/
いんたい /引退/
いんち /吋/
いんよう /引用/
う /雨/右/有/鵜/卯/迂/羽/宇/烏/
うい /初/
うえ /上/
うお /魚/
うぐいす /鴬/
うけとりにん /受取人/
うさぎ /兎/
うし /牛/丑/
うしろ /後/
うじ /氏/
うす /臼/碓/
うず /渦/
うそ /嘘/
うた /歌/唄/
うたい /謡/
うち /内/
うちがわ /内側/
うつ /蔚/欝/
うつわ /器/
うで /腕/
うなぎ /鰻/
うね /畝/
うば /姥/
うぶ /産/
うま /馬/
うまや /厩/
うみ /海/
うめ /梅/
うら /裏/浦/
うり /瓜/
うるう /閏/
うるうどし /閏年/
うるし /漆/
うわ /上/
うわさ /噂/
うん /云/運/雲/
うんえい /運営/
うんてん /運転/
うんよう /運用/
え /回/会/絵/重/恵/餌/荏/江/柄/
えい /英/映/影/鋭/詠/衛/頴/穎/盈/瑛/洩/泳/永/栄/曳/嬰/営/叡/
えいえん /永遠/
えいが /映画/
えいきょう /影響/
えいぎょう /営業/
えいご /英語/
えいり /営利/
えき /駅/役/益/疫/液/易/
えきめい /駅名/
えだ /枝/
えつ /閲/越/謁/悦/
えのき /榎/
えり /襟/
えん /円/延/煙/淵/演/塩/鉛/遠/薗/苑/艶/縁/猿/焔/炎/沿/援/掩/怨/宴/園/厭/燕/奄/鴛/堰/
えんぎ /演技/
えんそう /演奏/
お /汚/於/緒/小/尾/雄/和/
おい /甥/笈/
おう /横/桜/応/黄/鴎/翁/王/殴/欧/旺/押/往/奥/央/凹/皇/鴬/襖/
おうぎ /扇/
おうしょう /王将/
おうとう /応答/
おうぼ /応募/
おうむ /鸚鵡/
おうよう /応用/
おお /大/
おおかみ /狼/
おおごえ /大声/
おおごと /大事/
おおさか /大阪/
おおはば /大幅/
おおむかし /大昔/
おおむね /概/
おおやけ /公/
おか /丘/岡/
おがわ /小川/
おき /沖/
おぎ /荻/
おく /屋/奥/臆/憶/億/
おけ /桶/
おす /牡/雄/
おそれ /虞/
おっと /夫/
おつ /乙/
おと /音/
おとうと /弟/
おとこ /男/
おとな /大人/
おに /鬼/
おの /斧/
おのおの /各/
おのれ /己/
おび /帯/
おも /主/面/
おもい /思/
おもしろ /面白/
おもて /表/面/
おもむき /趣/
おや /親/
おれ /俺/
おろし /卸/
おん /音/温/御/恩/穏/遠/
おんがく /音楽/
おんな /女/
か /下/日/歌/化/家/仮/花/夏/火/暇/香/靴/果/蚊/霞/過/迦/貨/課/蝦/菓/華/荷/茄/苛/箇/稼/禾/禍/珂/河/架/科/寡/嫁/嘉/可/加/佳/価/伽/何/
かい /会/回/解/開/改/界/海/階/快/介/壊/械/貝/戒/皆/絵/悔/怪/懐/街/塊/灰/甲斐/恢/廻/魁/芥/蟹/晦/拐/
かいいん /会員/
かいかん /快感/
かいがい /海外/
かいぎょう /改行/
かいけつ /解決/
かいこ /蚕/
かいごう /会合/
かいさい /開催/
かいさつ /改札/
かいし /開始/
かいしゃ /会社/
かいしゃく /解釈/
かいしゅう /回収/
かいしょう /解消/
かいじょ /解除/
かいじょう /会場/
かいすう /回数/
かいせき /解析/
かいせつ /解説/
かいせん /回線/
かいぜん /改善/
かいそう /階層/
かいぞう /改造/
かいてき /快適/
かいてん /回転/
かいとう /回答/
かいとうしゃ /回答者/
かいはつ /開発/
かいへん /改変/
かいほう /開放/
かいらん /回覧/
かいり /浬/
かいりょう /改良/
かいわ /会話/
かえで /楓/
かえる /蛙/
かお /顔/
かおる /馨/
かかく /価格/
かかり /係/
かがく /科学/
かがみ /鏡/
かき /下記/蛎/柿/垣/
かぎ /鍵/鈎/
かぎり /限/
かく /確/各/客/覚/革/隔/閣/郭/較/赫/角/穫/獲/殻/核/格/撹/拡/廓/嚇/劃/画/
かくご /覚悟/
かくしゃ /各社/
かくしゅ /各種/
かくじつ /確実/
かくだい /拡大/
かくちょう /拡張/
かくとく /獲得/
かくにん /確認/
かくのう /格納/
かくほ /確保/
かくりつ /確率/確立/
かぐら /神楽/
かけ /掛/
かげ /陰/影/
かげん /加減/
かこ /過去/
かご /篭/
かさ /笠/傘/
かさん /加算/
かざ /風/
かし /菓子/歌詞/橿/樫/
かしゅ /歌手/
かしわ /栢/
かじ /梶/
かじか /鰍/
かすみ /霞/
かず /数/
かせつ /仮説/
かぜ /風/風邪/
かぞく /家族/
かた /方/形/型/肩/潟/片/
かたかな /片仮名/
かたき /敵/
かたち /形/
かたな /刀/
かたまり /塊/
かち /価値/
かっ /合/
かっこ /括弧/
かって /勝手/
かっぱつ /活発/
かつ /割/滑/且/轄/褐/葛/渇/活/括/恰/喝/
かつお /鰹/
かつどう /活動/
かつやく /活躍/
かつよう /活用/
かて /糧/
かてい /仮定/過程/
かど /角/門/
かどう /稼働/
かどく /可読/
かな /金/
かなかんじへんかん /仮名漢字変換/
かにゅう /加入/
かね /金/鐘/
かねつ /加熱/
かの /彼/
かのう /可能/
かのうせい /可能性/
かのじょ /彼女/
かば /樺/椛/
かばん /鞄/
かふんしょう /花粉症/
かぶ /株/蕪/
かぶしき /株式/
かぶと /兜/
かべ /壁/
かま /鎌/釜/蒲/窯/竃/
かまど /竃/
かみ /上/紙/髪/神/
かみなり /雷/
かめい /仮名/
かめん /仮面/
かも /鴨/
かや /萱/茅/栢/
かゆ /粥/
から /空/殻/唐/
からす /烏/
からだ /体/
かり /仮/狩/
かりゅう /下流/
かれ /彼/
かわ /側/川/革/河/皮/
かわら /瓦/
かん /間/換/巻/感/甘/観/完/函/関/舘/館/韓/陥/閑/鑑/還/貫/諌/莞/艦/肝/翰/缶/緩/簡/管/看/監/環/潅/澗/漢/汗/歓/款/棺/桓/柑/敢/憾/慣/患/幹/干/寛/官/姦/堪/喚/勧/勘/刊/寒/冠/侃/乾/神/甲/竿/
かんかく /感覚/
かんきょう /環境/
かんきょうせってい /環境設定/
かんきょうへんすう /環境変数/
かんけい /関係/
かんげい /歓迎/
かんこく /韓国/
かんさい /関西/
かんしゃ /感謝/
かんしゅう /慣習/
かんしん /感心/
かんじ /漢字/幹事/
かんじょう /感情/
かんすう /関数/
かんすうめい /関数名/
かんせい /完成/
かんせつてき /間接的/
かんぜん /完全/
かんそう /感想/
かんそく /観測/
かんたん /簡単/
かんてん /観点/
かんとう /関東/
かんとく /監督/
かんどう /感動/
かんぺき /完璧/
かんむり /冠/
かんり /管理/
かんりしゃ /管理者/
かんりにん /管理人/
かんりょう /完了/
かんれん /関連/
が /我/駕/餓/雅/賀/蛾/芽/臥/画/牙/俄/峨/
がい /外/街/害/概/骸/鎧/該/蓋/碍/涯/慨/崖/劾/凱/咳/
がいかい /外界/
がいこく /外国/
がいじ /外字/
がいとう /該当/
がいねん /概念/
がいぶ /外部/
がいよう /概要/
がく /楽/額/学/顎/岳/
がくせい /学生/
がくぶ /学部/
がぞう /画像/
がぞうしょり /画像処理/
がぞうじょうほう /画像情報/
がっ /合/
がっかい /学会/
がっかいし /学会誌/
がっこう /学校/
がっしょう /合唱/
がっち /合致/
がつ /月/
がまん /我慢/
がめん /画面/
がら /柄/
がん /元/顔/丸/含/願/頑/雁/贋/翫/岩/眼/癌/玩/巌/岸/
き /気/記/期/機/規/基/木/起/企/帰/奇/貴/棄/危/寄/紀/希/季/黄/器/軌/既/亀/揮/鬼/岐/飢/汽/忌/生/喜/騎/幾/輝/旗/棋/稀/祈/毅/伎/机/徽/嬉/畿/
きいろ /黄色/
きおく /記憶/
きかい /機械/機会/
きかく /企画/規格/
きかん /期間/
きがる /気軽/
ききょう /桔梗/
きぎょう /企業/
きく /鞠/菊/掬/
きけん /危険/
きこう /機構/
きごう /記号/〓/↓/↑/←/→/〒/※/▼/▽/▲/△/■/□/◆/◇/◎/●/○/★/☆/§/£/¢/￥/℃/″/′/°/♀/♂/∴/∞/≧/≦/≠/÷/×/±/】/【/』/『/》/《/〉/〈/〕/〔/“/‥/…/‖/‐/―/〇/〆/々/仝/〃/ゞ/ゝ/ヾ/ヽ/￣/¨/｀/´/゜/゛/・/
きさい /記載/
きし /岸/
きしゅ /機種/
きじ /記事/
きじすう /記事数/
きじせんたく /記事選択/
きじゅつ /記述/
きじゅん /基準/
きず /傷/
きせき /奇跡/
きせつ /季節/
きそく /規則/
きぞく /帰属/
きた /北/
きたい /期待/
きち /吉/
きちょう /貴重/
きっぷ /切符/
きつ /詰/橘/喫/吃/吉/桔/
きてい /規定/
きどう /起動/
きにゅう /記入/
きぬ /絹/
きぬた /砧/
きね /杵/
きのう /機能/昨日/
きび /黍/
きふ /寄付/
きぶん /気分/
きほん /基本/
きほんてき /基本的/
きぼう /希望/
きみ /君/
きも /肝/
きゃく /客/脚/却/
きゃくほん /脚本/
きゅう /久/吸/急/泣/救/休/及/求/旧/給/糾/級/窮/究/球/灸/汲/朽/弓/宮/仇/丘/九/笈/
きゅうがた /旧型/
きゅうきょく /究極/
きゅうけい /休憩/
きゅうしゅう /九州/
きゅうじん /求人/
きゅうりょう /給料/
きょ /居/去/距/許/虚/渠/挙/拠/拒/巨/鋸/
きょう /今日/京/強/狭/橋/鏡/胸/共/香/狂/経/叫/教/驚/饗/響/郷/興/脅/矯/況/挟/恭/恐/怯/彊/峡/境/喬/卿/匡/協/凶/競/兇/僑/侠/供/享/亨/兄/
きょういく /教育/
きょうきゅう /供給/
きょうくん /教訓/
きょうしゅく /恐縮/
きょうせい /強制/
きょうちょう /強調/
きょうつう /共通/
きょうと /京都/
きょうふ /恐怖/
きょうみ /興味/
きょうゆう /共有/
きょうりつ /共立/
きょうりょく /協力/強力/
きょか /許可/
きょく /曲/局/極/
きょくしょう /極小/
きょくたん /極端/
きょくめい /曲名/
きょくもく /曲目/
きょじん /巨人/
きょだい /巨大/
きょねん /去年/
きょひ /拒否/
きょり /距離/
きよみず /清水/
きり /桐/霧/
きろく /記録/
きろめーとる /粁/
きわ /際/
きん /今/近/金/筋/謹/襟/衿/菌/緊/禽/禁/琴/欽/欣/斤/錦/巾/均/勤/僅/芹/
きんき /近畿/
きんけん /金券/
きんし /禁止/
きんじょ /近所/
きんぺん /近辺/
きんぼう /近傍/
きんむ /勤務/
ぎ /技/疑/議/誼/蟻/義/祇/欺/擬/戯/宜/妓/儀/偽/犠/
ぎじゅつ /技術/
ぎじゅつしゃ /技術者/
ぎじゅつてき /技術的/
ぎせい /犠牲/
ぎふ /岐阜/
ぎもん /疑問/
ぎゃく /逆/虐/
ぎゃくかんすう /逆関数/
ぎゃくしゅう /逆襲/
ぎゅう /牛/
ぎゅうにゅう /牛乳/
ぎょ /魚/御/禦/漁/
ぎょう /行/仰/業/暁/尭/凝/形/
ぎょうかい /業界/
ぎょうしゃ /業者/
ぎょく /玉/
ぎろん /議論/
ぎん /銀/吟/
く /口/苦/工/駈/駆/躯/矩/玖/狗/区/句/倶/九/供/貢/久/宮/庫/功/紅/駒/
くい /杭/
くう /空/
くうかん /空間/
くうき /空気/
くうはく /空白/
くき /茎/
くぎり /区切/
くさ /草/
くさり /鎖/
くし /櫛/串/
くしろ /釧路/
くじら /鯨/
くすり /薬/
くず /屑/
くそ /糞/
くだ /管/
くち /口/
くちびる /唇/
くつ /靴/掘/沓/窟/屈/
くつわ /轡/
くとうてん /句読点/
くどう /駆動/
くに /国/
くび /首/
くふう /工夫/
くべつ /区別/
くぼ /窪/
くま /熊/隈/
くまがい /熊谷/
くまがや /熊谷/
くみ /組/
くみあい /組合/
くめ /粂/
くも /雲/蜘蛛/
くら /蔵/倉/
くらい /位/
くり /繰/栗/
くるま /車/
くれない /紅/
くろ /黒/
くろう /苦労/
くわ /鍬/桑/
くん /君/訓/薫/勲/
ぐ /虞/愚/具/
ぐあい /具合/
ぐう /隅/遇/寓/偶/宮/
ぐうぜん /偶然/
ぐたいてき /具体的/
ぐん /群/郡/軍/
け /気/化/家/毛/怪/祁/卦/仮/
けい /形/型/系/兄/計/継/恵/軽/経/傾/鶏/頚/警/詣/蛍/荊/茎/罫/繋/渓/桂/景/敬/携/掲/憩/慧/慶/径/契/珪/圭/啓/刑/係/京/競/境/稽/畦/
けいい /敬意/経緯/
けいか /経過/
けいかく /計画/
けいかん /警官/
けいけん /経験/
けいこ /稽古/
けいこう /傾向/
けいさい /掲載/
けいさん /計算/
けいさんき /計算機/
けいしき /形式/
けいしょう /継承/
けいじ /刑事/
けいせん /罫線/
けいぞく /継続/
けいたい /形態/
けいやく /契約/
けいゆ /経由/
けいれつ /系列/
けいろ /経路/
けが /怪我/
けさ /袈裟/
けしょう /化粧/
けた /桁/
けっか /結果/
けっきょく /結局/
けっこう /結構/
けっこん /結婚/
けっさく /傑作/
けってい /決定/
けってん /欠点/
けつ /穴/決/結/訣/血/潔/欠/傑/
けつごう /結合/
けつろん /結論/
けむり /煙/
けもの /獣/
けん /見/間/件/研/肩/犬/嫌/権/験/顕/険/遣/軒/賢/謙/県/絹/硯/献/牽/検/捲/拳/懸/憲/建/堅/圏/剣/券/兼/健/倦/倹/繭/鍵/喧/
けんい /権威/
けんか /喧嘩/
けんきゅう /研究/
けんきゅうしつ /研究室/
けんきゅうしゃ /研究者/
けんきゅうしょ /研究所/
けんきゅうじょ /研究所/
けんこう /健康/
けんさく /検索/
けんじょう /謙譲/
けんせつてき /建設的/
けんとう /検討/
けんり /権利/
げ /下/外/解/
げい /鯨/迎/芸/
げき /激/撃/戟/劇/隙/
げきじょう /劇場/
げっかん /月刊/
げつ /月/
げん /原/現/言/限/源/元/減/厳/玄/弦/幻/舷/験/嫌/絃/諺/眼/
げんいん /原因/
げんき /元気/
げんきゅう /言及/
げんこう /原稿/
げんご /言語/
げんさく /原作/
げんざい /現在/
げんし /原子/
げんしょう /現象/
げんじつ /現実/
げんじつてき /現実的/
げんじょう /現状/
げんそく /原則/
げんてい /限定/
げんてん /原点/
げんぱつ /原発/
げんみつ /厳密/
こ /子/小/個/故/古/己/固/庫/弧/去/拠/戸/呼/湖/粉/誇/顧/黄/木/鼓/孤/乎/虎/雇/股/胡/枯/狐/姑/虚/跨/鈷/糊/菰/
こい /恋/鯉/
こう /行/高/構/工/公/向/効/校/交/考/項/稿/後/更/講/好/広/候/幸/康/抗/紅/降/購/功/貢/光/航/甲/口/格/興/荒/恒/港/神/孝/皇/攻/厚/耕/鉱/慌/酵/肯/硬/浩/江/梗/拘/巧/孔/仰/香/鋼/郊/衡/綱/洪/控/晃/黄/勾/弘/侯/絞/溝/坑/膏/腔/昂/紘/宏/鴻/喉/佼/垢/杭/倖/耗/閤/砿/肱/庚/后/巷/糠/
こうい /行為/
こうえん /講演/公園/
こうか /効果/高架/
こうかい /公開/高階/
こうかん /交換/
こうがく /工学/
こうぎ /抗議/
こうけん /貢献/
こうこう /高校/
こうこく /広告/
こうさつ /考察/
こうしゃ /後者/
こうしん /更新/
こうじ /麹/
こうせい /構成/
こうそく /高速/
こうそくか /高速化/
こうぞう /構造/
こうちく /構築/
こうちゃ /紅茶/
こうど /高度/
こうどう /行動/
こうにゅう /購入/
こうはん /後半/
こうひょう /公表/
こうほ /候補/
こうもく /項目/
こうりつ /効率/
こうりょ /考慮/
こえ /声/肥/
こおり /氷/
こく /国/黒/鵠/酷/穀/告/刻/克/石/谷/
こくさい /国際/
こくない /国内/
ここの /九/
こころ /心/
こころざし /志/
こし /腰/
こしき /甑/
こしょう /故障/
こじん /個人/
こじんてき /個人的/
こせい /個性/
こたえ /答/
こつ /骨/惚/忽/
こてい /固定/
こと /事/異/言/殊/琴/
ことがら /事柄/
ことし /今年/
ことば /言葉/
ことぶき /寿/
こども /子供/
こな /粉/
こべつ /個別/
こま /狛/駒/
こまいぬ /狛/
こみ /込/
こむ /込/
こめ /米/
こも /菰/
こもじ /小文字/
こよみ /暦/
これ /此/
ころ /頃/
ころも /衣/
こわ /声/
こん /今/金/混/根/魂/艮/紺/痕/梱/昆/昏/懇/恨/婚/墾/坤/困/献/建/
こんかい /今回/
こんきょ /根拠/
こんげつ /今月/
こんげつごう /今月号/
こんご /今後/
こんざつ /混雑/
こんしゅう /今週/
こんじょう /根性/
こんど /今度/
こんどう /混同/
こんなん /困難/
こんにち /今日/
こんねん /今年/
こんぽん /根本/
こんや /今夜/
こんらん /混乱/
ご /後/語/御/誤/護/碁/梧/悟/吾/呉/午/伍/互/五/期/娯/
ごいけん /御意見/
ごう /合/号/強/轟/豪/濠/拷/壕/劫/剛/業/郷/
ごうい /合意/
ごうけい /合計/
ごうせい /合成/
ごかい /誤解/
ごく /獄/極/
ごご /午後/
ごじゅん /語順/
ごぜん /午前/
ごらく /娯楽/
ごろ /頃/
ごん /言/権/
ごんご /言語/
さ /差/左/茶/鎖/詐/砂/瑳/沙/査/唆/叉/佐/些/再/作/
さい /際/最/歳/才/西/再/妻/載/裁/菜/細/斎/祭/砦/砕/犀/采/災/済/栽/採/彩/宰/塞/哉/催/債/財/殺/切/
さいかい /最下位/
さいきょう /最強/
さいきん /最近/
さいこう /最高/
さいご /最後/
さいしゅう /最終/
さいしゅうてき /最終的/
さいしょ /最初/
さいしょう /最小/
さいしょうち /最小値/
さいしん /最新/
さいしんばん /最新版/
さいせい /再生/
さいそう /再送/
さいたま /埼玉/
さいだい /最大/
さいちゅう /最中/
さいてい /最低/
さいど /再度/
さいはいふ /再配布/
さいぼう /細胞/
さいよう /採用/
さいりよう /再利用/
さお /竿/
さか /酒/坂/阪/逆/
さかい /堺/境/
さかき /榊/
さかさ /逆/
さかずき /杯/
さかな /魚/肴/
さかや /酒屋/
さが /性/嵯峨/
さき /先/碕/埼/崎/咲/
さぎ /鷺/
さぎょう /作業/
さく /作/冊/錯/索/策/窄/柵/朔/昨/搾/咋/削/酢/
さくしゃ /作者/
さくじつ /昨日/
さくじょ /削除/
さくせい /作成/
さくねん /昨年/
さくひん /作品/
さくら /桜/
さけ /酒/鮭/
ささ /笹/
さしだしにん /差出人/
さじ /匙/
さち /幸/
さっ /早/
さっそく /早速/
さつ /札/冊/擦/薩/殺/撮/察/刷/
さつき /皐/
さと /里/
さば /鯖/
さび /錆/寂/
さま /様/
さむらい /侍/
さめ /鮫/
さら /更/皿/
さらす /晒/
さる /猿/
さわ /沢/
さん /山/三/散/餐/酸/賛/讃/蚕/纂/算/産/燦/桟/撒/惨/参/傘/
さんか /参加/
さんかしゃ /参加者/
さんこう /参考/
さんこうしりょう /参考資料/
さんこうぶんけん /参考文献/
さんご /珊瑚/
さんしょう /参照/
さんせい /賛成/
さんちょう /山頂/
さんろく /山麓/
ざ /座/挫/坐/
ざい /財/在/罪/材/剤/
ざっし /雑誌/
ざつ /雑/
ざん /残/暫/斬/
ざんねん /残念/
し /私/子/氏/指/紙/覗/使/誌/死/旨/姿/姉/伺/至/師/歯/止/試/飼/雌/賜/資/諮/詩/詞/視/脂/肢/紫/糸/祉/獅/枝/施/斯/孜/支/思/志/市/屍/始/士/四/嗣/史/司/刺/仔/仕/次/示/自/矢/
しあい /試合/
しあげ /仕上/
しお /汐/塩/潮/
しか /鹿/
しかい /司会/
しかいしゃ /司会者/
しかく /資格/
しかた /仕方/
しかん /弛緩/
しき /色/式/拭/識/織/
しぎ /鴫/
しげん /資源/
しこう /指向/
しこく /四国/
しごと /仕事/
しし /宍/
しじ /指示/支持/
しじょう /史上/
しず /静/
しずく /雫/滴/
しせい /姿勢/
しぜん /自然/
しそう /思想/
した /下/舌/
しだい /次第/
しち /質/七/
しっぱい /失敗/
しつ /失/質/疾/漆/湿/悉/室/嫉/執/叱/
しつもん /質問/
しつれい /失礼/
してい /指定/
してき /指摘/
してつ /私鉄/
しとみ /蔀/
しな /品/
しの /篠/
しば /芝/柴/
しばしば /屡/
しぶ /渋/
しぶや /渋谷/
しべ /蕊/
しぼう /脂肪/
しま /縞/島/
しみず /清水/
しめい /氏名/
しも /下/
しもて /下手/
しゃ /車/者/社/煮/写/斜/遮/謝/紗/赦/捨/射/舎/砂/
しゃいん /社員/
しゃかい /社会/
しゃく /釈/借/尺/石/爵/酌/杓/灼/錫/昔/勺/
しゃしょう /車掌/
しゃしん /写真/
しゃない /社内/
しゃりょう /車両/
しゅ /手/主/種/修/首/酒/取/趣/腫/珠/狩/殊/朱/守/衆/
しゅう /集/修/週/秋/祝/拾/習/醜/酬/輯/蹴/襲/衆/舟/臭/繍/終/秀/洲/愁/州/就/宗/周/収/囚/執/讐/蒐/酋/
しゅうい /周囲/
しゅうかん /週間/
しゅうごう /集合/
しゅうしゅう /蒐集/
しゅうせい /修正/
しゅうそく /収束/
しゅうだん /集団/
しゅうちょう /酋長/
しゅうてん /終点/
しゅうはすう /周波数/
しゅうへん /周辺/
しゅうまつ /週末/
しゅうりょう /終了/
しゅうろん /修論/
しゅく /宿/祝/粛/縮/淑/夙/叔/
しゅご /主語/
しゅさい /主催/
しゅし /主旨/
しゅじん /主人/
しゅだい /主題/
しゅだん /手段/
しゅちょう /主張/
しゅっか /出荷/
しゅっちょう /出張/
しゅっぱつ /出発/
しゅっぱん /出版/
しゅっぱんしゃ /出版社/
しゅつ /出/
しゅつえん /出演/
しゅつりょく /出力/
しゅほう /手法/
しゅみ /趣味/
しゅるい /種類/
しゅん /春/瞬/駿/舜/峻/俊/竣/
しゅんかん /瞬間/
しゅんこう /竣工/
しょ /所/初/書/暑/諸/藷/薯/署/緒/庶/処/渚/曙/
しょう /小/証/商/象/少/消/勝/賞/将/称/障/照/症/章/承/省/償/唱/正/紹/昭/掌/詳/傷/衝/奨/生/渉/笑/性/焼/晶/招/焦/祥/彰/召/装/裳/相/昇/床/松/庄/尚/精/昌/訟/匠/捷/抄/鐘/肖/硝/梢/哨/醤/礁/娼/上/鞘/詔/声/姓/樟/鍾/星/政/宵/升/青/沼/廠/蒋/妾/嘗/鉦/樵/粧/湘/蕉/
しょうかい /紹介/
しょうがい /障害/
しょうきょ /消去/
しょうぎょう /商業/
しょうぎょうてき /商業的/
しょうこ /証拠/
しょうごう /照合/
しょうさい /詳細/
しょうじょ /少女/
しょうじょう /症状/
しょうせつ /小説/
しょうなん /湘南/
しょうねん /少年/
しょうばい /商売/
しょうひ /消費/
しょうひしゃ /消費者/
しょうひょう /商標/
しょうひょうけん /商標権/
しょうひん /商品/
しょうぶ /勝負/菖蒲/
しょうめい /証明/
しょうよう /商用/
しょうらい /将来/
しょうりゃく /省略/
しょうわ /昭和/
しょき /初期/
しょきけい /初期型/
しょく /色/燭/拭/食/蝕/触/職/織/殖/植/飾/埴/嘱/
しょくじ /食事/
しょくどう /食堂/
しょしんしゃ /初心者/
しょぞく /所属/
しょめい /署名/
しょゆう /所有/
しょり /処理/
しょりけい /処理系/
しよう /使用/仕様/
しようほう /使用法/
しら /白/
しり /尻/
しりょう /資料/
しる /汁/
しるし /印/
しれい /指令/
しろ /城/白/代/
しろうと /素人/
しん /心/新/真/親/身/神/伸/森/寝/辛/辰/進/信/震/針/診/薪/芯/臣/紳/秦/疹/申/深/浸/榛/晋/振/慎/審/娠/唇/侵/請/
しんかんせん /新幹線/
しんがい /侵害/
しんけい /神経/
しんけん /真剣/
しんごう /信号/
しんさく /新作/
しんさつ /診察/
しんしゃ /新車/
しんしゅつ /新出/
しんじゅく /新宿/
しんじん /新人/
しんせいひん /新製品/
しんせだい /新世代/
しんせつ /親切/新設/
しんぱい /心配/
しんぶん /新聞/
しんぽ /進歩/
しんや /深夜/
しんよう /信用/
しんらい /信頼/
しんらいせい /信頼性/
しんわ /神話/
じ /時/事/自/字/次/示/地/辞/治/寺/磁/持/似/路/児/耳/慈/滋/痔/侍/除/仕/璽/爾/而/蒔/
じいしき /自意識/
じかい /次回/
じかん /時間/
じき /直/時期/
じぎょう /事業/
じぎょうぶ /事業部/
じく /宍/軸/竺/
じけん /事件/
じこ /事故/自己/
じこう /事項/
じこく /時刻/
じさく /自作/
じしょ /辞書/
じしん /自身/自信/地震/
じじつ /事実/
じじょう /事情/
じせい /時制/
じたい /自体/事態/
じたく /自宅/
じだい /時代/
じっ /十/
じっか /実家/
じっけん /実験/
じっこう /実行/
じっさい /実際/
じっしゅう /実習/
じっせき /実績/
じったい /実体/
じつ /日/実/
じつげん /実現/
じつざい /実在/
じつよう /実用/
じつようか /実用化/
じつれい /実例/
じてん /時点/
じてんしゃ /自転車/
じどう /自動/
じどうしゃ /自動車/
じどうてき /自動的/
じぶん /自分/
じむきょく /事務局/
じもと /地元/
じゃ /邪/蛇/
じゃく /弱/若/寂/着/惹/
じゃっかん /若干/
じゃま /邪魔/
じゅ /受/需/綬/樹/授/寿/呪/儒/就/
じゅう /重/十/住/従/渋/柔/充/獣/銃/縦/戎/汁/什/拾/
じゅうし /重視/
じゅうしょ /住所/
じゅうしん /重心/
じゅうたい /渋滞/
じゅうふく /重複/
じゅうぶん /十分/
じゅうよう /重要/
じゅうらい /従来/
じゅく /熟/塾/
じゅしん /受信/
じゅつ /述/術/
じゅもん /呪文/
じゅよう /需要/
じゅん /順/醇/遵/巡/純/盾/潤/準/淳/殉/旬/循/准/楯/
じゅんかい /巡回/
じゅんすい /純粋/
じゅんちょう /順調/
じゅんばん /順番/
じゅんび /準備/
じゆう /自由/
じょ /女/如/除/恕/徐/序/叙/助/鋤/
じょう /上/情/常/場/状/乗/条/城/定/譲/丈/剰/浄/蒸/醸/冗/錠/畳/成/壌/静/盛/嬢/杖/丞/穣/擾/
じょうい /上位/
じょうき /上記/
じょうきょう /状況/
じょうけん /条件/
じょうし /上司/
じょうしき /常識/
じょうたい /状態/
じょうだん /冗談/
じょうほう /情報/
じょうほうしょり /情報処理/
じょうらん /擾乱/
じょうりゅう /上流/
じょうれん /常連/
じょがい /除外/
じょく /辱/
じょし /女子/
じょしゅ /助手/
じょせい /女性/
じょゆう /女優/
じょりょく /助力/
じん /人/尽/靭/陣/迅/訊/腎/甚/尋/壬/塵/刃/仁/神/臣/
じんこう /人工/
じんせい /人生/
す /素/須/子/守/巣/酢/州/主/数/笥/諏/
すい /水/吹/錘/錐/酔/遂/衰/翠/粋/睡/炊/推/帥/垂/出/穂/
すいしん /推進/
すいそく /推測/
すいろん /推論/
すう /数/雛/趨/枢/嵩/崇/
すうじ /数字/
すうち /数値/
すうねん /数年/
すうふん /数分/
すえ /末/
すえひろ /末広/
すがた /姿/
すき /隙/鋤/
すぎ /椙/杉/
すけ /介/助/
すげ /菅/
すこぶる /頗/
すじ /筋/
すず /鈴/
すずめ /雀/
すそ /裾/
すで /既/
すな /砂/
すなお /素直/
すべて /総/
すみ /隅/炭/墨/
すり /摺/
すわ /諏訪/
すん /寸/
ず /図/頭/豆/事/厨/
ずい /髄/瑞/随/
ずいぶん /随分/
ずけい /図形/
ずし /逗子/
せ /世/背/瀬/畝/施/
せい /生/声/世/星/成/性/西/製/正/姓/青/勢/斉/静/醒/逝/請/誓/誠/聖/精/盛/清/栖/棲/晴/整/政/征/制/凄/省/歳/情/婿/背/牲/
せいか /成果/
せいかい /正解/
せいかく /正確/性格/
せいかつ /生活/
せいき /世紀/
せいきゅう /請求/
せいぎょ /制御/
せいげん /制限/
せいこう /成功/
せいしき /正式/
せいしつ /性質/
せいしゅん /青春/
せいしん /精神/
せいじょう /正常/
せいせい /生成/
せいせき /成績/
せいちょう /成長/
せいでんき /静電気/
せいとう /正当/
せいとくてき /生得的/
せいど /制度/
せいのう /性能/
せいひん /製品/
せいやく /制約/
せいり /整理/
せいりつ /成立/
せいれき /西暦/
せかい /世界/
せかいじゅう /世界中/
せき /昔/積/席/夕/関/寂/碩/蹟/跡/赤/責/脊/績/籍/石/析/斥/戚/惜/隻/堰/咳/
せきにん /責任/
せけん /世間/
せたがや /世田谷/
せち /節/
せっきょくてき /積極的/
せっけい /設計/
せっけん /石鹸/
せってい /設定/
せつ /雪/説/節/切/設/折/窃/摂/接/拙/殺/
せつじょく /雪辱/
せつぞく /接続/
せつめい /説明/
せみ /蝉/
せり /芹/
せりふ /台詞/
せわ /世話/
せわにん /世話人/
せん /先/線/戦/繊/船/川/選/占/鮮/閃/銑/銭/遷/践/賎/詮/薦/腺/羨/箭/穿/旋/煽/煎/潜/染/洗/浅/泉/栓/撰/扇/尖/専/宣/千/仙/舛/
せんげん /宣言/
せんこう /先行/
せんしゅ /選手/
せんしゅう /先週/
せんしゅけん /選手権/
せんじつ /先日/
せんせい /先生/
せんそう /戦争/
せんたく /選択/洗濯/
せんだん /栴檀/
せんち /糎/
せんちめーとる /糎/
せんでん /宣伝/
せんとう /先頭/
せんぱい /先輩/
せんめい /鮮明/
せんもん /専門/
せんもんか /専門家/
せんよう /専用/
せんろ /線路/
ぜ /是/
ぜい /税/脆/説/
ぜいきん /税金/
ぜったい /絶対/
ぜつ /絶/舌/
ぜに /銭/
ぜひ /是非/
ぜん /前/全/膳/繕/禅/然/漸/善/
ぜんいん /全員/
ぜんかい /前回/
ぜんかく /全角/
ぜんかくかな /全角仮名/
ぜんこく /全国/
ぜんこくてき /全国的/
ぜんしゃ /前者/
ぜんじんるい /全人類/
ぜんぜん /全然/
ぜんたい /全体/
ぜんてい /前提/
ぜんぶ /全部/
ぜんぷく /全幅/
そ /組/鼠/遡/阻/訴/蘇/素/粗/租/祖/礎/疎/疏/狙/楚/曽/曾/岨/塑/想/措/
そう /騒/総/層/相/想/送/早/霜/鎗/遭/走/装/藻/蒼/葬/荘/草/聡/綜/糟/窓/痩/争/燥/漕/槽/槍/巣/曹/操/掻/挿/掃/捜/惣/宋/爽/奏/壮/喪/倉/叢/双/創/僧/宗/贈/匝/
そうおう /相応/
そうさ /操作/捜査/匝瑳/
そうさく /創作/
そうしん /送信/
そうぞう /想像/
そうだん /相談/
そうち /装置/
そうちゃく /装着/
そうてい /想定/
そうとう /相当/
そうほう /双方/
そうりょう /送料/
そうろう /候/
そがい /阻害/
そく /足/側/速/息/即/測/束/捉/則/促/
そくせん /側線/
そくど /速度/
そこ /底/
そしき /組織/
そつ /率/卒/
そつぎょう /卒業/
そで /袖/
そと /外/
その /其/園/
そば /蕎麦/
そぼ /祖母/
そら /空/
それがし /某/
そん /損/存/遜/村/尊/孫/
そんけい /尊敬/
そんざい /存在/
そんちょう /尊重/
ぞう /臓/贈/造/蔵/憎/増/像/雑/象/
ぞうか /増加/
ぞく /続/族/賊/属/俗/
ぞくせい /属性/
ぞん /存/
ぞんじ /存知/
た /他/太/多/詑/汰/田/手/
たい /大/代/袋/体/隊/対/態/鯛/逮/退/貸/苔/腿/胎/滞/泰/替/戴/怠/待/帯/岱/耐/堆/台/太/黛/
たいおう /対応/
たいかい /大会/
たいけい /体系/
たいしょ /対処/
たいしょう /対象/大将/
たいしょうせい /対称性/
たいせつ /大切/
たいてい /大抵/
たいでん /帯電/
たいど /態度/
たいふう /台風/
たいへん /大変/
たいりょう /大量/
たえ /妙/
たか /鷹/高/
たから /宝/
たき /瀧/滝/
たきぎ /薪/
たく /鐸/託/琢/沢/拓/択/托/宅/啄/卓/度/濯/
たくさん /沢山/
たけ /茸/岳/丈/竹/
たこ /蛸/凧/
たしょう /多少/
たすう /多数/
たたみ /畳/
ただ /唯/只/
たち /館/
たちぎ /立木/
たちば /立場/
たつ /辰/竜/達/
たつみ /巽/
たて /竪/縦/楯/
たな /棚/
たに /谷/
たにん /他人/
たぬき /狸/
たね /種/
たば /束/
たび /度/旅/
たぶん /多分/
たま /霊/玉/球/弾/
たまご /卵/
たましい /魂/
たみ /民/
ため /為/
たら /鱈/
たる /樽/
たわら /俵/
たん /単/端/反/鍛/誕/胆/耽/短/炭/湛/淡/歎/旦/探/担/坦/嘆/丹/箪/
たんい /単位/
たんこうぼん /単行本/
たんご /単語/
たんじゅん /単純/
たんじょう /誕生/
たんじょうび /誕生日/
たんす /箪笥/
たんちょう /単調/
たんとう /担当/
たんぱく /蛋白/
たんまつ /端末/
だ /駄/陀/楕/舵/柁/打/惰/妥/堕/唾/蛇/
だい /大/第/内/代/台/題/弟/
だいいち /第一/
だいがく /大学/
だいがくいん /大学院/
だいきぼ /大規模/
だいこん /大根/
だいご /醍醐/
だいじ /大事/
だいじょうぶ /大丈夫/
だいたい /大体/
だいたん /大胆/
だいひゃっか /大百科/
だいひょう /代表/
だいひょうてき /代表的/
だいぶぶん /大部分/
だいめい /題名/
だく /諾/濁/
だくおん /濁音/
だそく /蛇足/
だつ /奪/脱/
だとう /妥当/
だめ /駄目/
だれ /誰/
だん /男/段/断/弾/暖/談/檀/壇/団/
だんかい /段階/
だんたい /団体/
ち /値/恥/地/知/茅/馳/遅/致/置/稚/痴/池/智/治/血/質/千/乳/弛/
ちいき /地域/
ちか /地下/
ちかてつ /地下鉄/
ちから /力/
ちきゅう /地球/
ちく /地区/逐/蓄/筑/竹/畜/築/
ちくせき /蓄積/
ちしき /知識/
ちず /地図/
ちち /父/乳/
ちつ /窒/秩/
ちてき /知的/
ちてん /地点/
ちのう /知能/
ちほう /地方/
ちまた /巷/
ちゃ /茶/
ちゃく /着/嫡/
ちゅう /中/注/昼/虫/宙/駐/鋳/酎/註/衷/柱/抽/忠/仲/
ちゅうい /注意/
ちゅうがく /中学/
ちゅうけい /中継/
ちゅうごく /中国/
ちゅうし /中止/
ちゅうしゃじょう /駐車場/
ちゅうしゅつ /抽出/
ちゅうしょう /抽象/
ちゅうしん /中心/
ちゅうと /中途/
ちゅうもく /注目/
ちゅうもん /注文/
ちゅうりゃく /中略/
ちょ /貯/著/苧/瀦/樗/緒/猪/
ちょう /長/超/肇/弔/重/帳/調/張/鳥/頂/跳/諜/蝶/腸/脹/聴/眺/町/牒/潮/朝/暢/挑/懲/徴/彫/庁/帖/寵/喋/凋/兆/丁/澄/
ちょうさ /調査/
ちょうし /調子/銚子/
ちょうせい /調整/
ちょうはつ /長髪/
ちょうふく /重複/
ちょく /直/捗/勅/
ちょくげき /直撃/
ちょくご /直後/
ちょくせつ /直接/
ちょくせつてき /直接的/
ちょくぜん /直前/
ちょさく /著作/
ちょさくけん /著作権/
ちょさくしゃ /著作者/
ちょさくぶつ /著作物/
ちょしゃ /著者/
ちょっこう /直交/
ちん /椿/陳/鎮/賃/珍/沈/朕/
つ /津/都/
つい /対/鎚/追/槌/椎/墜/
ついか /追加/
つう /通/痛/
つうか /通過/
つうかい /痛快/
つうがく /通学/
つうしん /通信/
つうじょう /通常/
つうち /通知/
つか /塚/
つが /栂/
つき /月/付/槻/
つぎ /次/
つくえ /机/
つくだ /佃/
つくば /筑波/
つげ /柘/
つごう /都合/
つじ /辻/
つた /蔦/
つち /土/
つつ /砲/筒/
つつみ /堤/
つづみ /鼓/
つどい /集/
つな /綱/
つね /常/
つの /角/
つば /鍔/
つばき /椿/
つばさ /翼/
つばめ /燕/
つぶ /粒/
つぼ /壷/坪/
つま /妻/嬬/
つみ /罪/
つむ /錘/
つむぎ /紬/
つめ /爪/
つゆ /露/
つら /面/
つり /釣/吊/
つる /鶴/弦/蔓/
つるぎ /剣/
て /手/
てい /定/程/鼎/釘/鄭/邸/逓/蹄/諦/訂/艇/締/禎/碇/汀/梯/提/挺/抵/悌/弟/廷/庭/底/帝/堤/呈/貞/剃/偵/停/低/亭/体/丁/
ていあん /提案/
ていか /定価/
ていき /提起/
ていきょう /提供/
ていぎ /定義/
ていじ /提示/
ていせい /訂正/
ていでん /停電/
ていど /程度/
ていねい /丁寧/
てかず /手数/
てがみ /手紙/
てき /的/敵/鏑/適/笛/滴/擢/摘/
てきせつ /適切/
てきとう /適当/
てきど /適度/
てきよう /適用/
てくび /手首/
てじゅん /手順/
てつ /鉄/迭/轍/撤/徹/哲/
てつがく /哲学/
てつがくしゃ /哲学者/
てつどう /鉄道/
てつや /徹夜/
てびき /手引/
てふだ /手札/
てま /手間/
てまえ /手前/
てもと /手元/
てら /寺/
てん /点/店/天/転/顛/甜/纏/添/展/填/典/貼/殿/
てんかい /展開/
てんき /天気/
てんくう /天空/
てんこう /転校/
てんさい /転載/
てんそう /転送/
で /弟/
でい /泥/
でき /出来/溺/
でぐち /出口/
でん /電/田/澱/殿/伝/
でんか /電化/
でんき /電気/
でんげん /電源/
でんし /電子/
でんしゃ /電車/
でんたつ /伝達/
でんわ /電話/
でんわだい /電話代/
と /都/登/途/図/戸/頭/十/土/徒/渡/塗/斗/吐/賭/度/杜/砥/屠/砺/妬/堵/鍍/兎/菟/
とい /問/
とう /等/頭/当/討/董/東/投/冬/盗/闘/騰/陶/鐙/透/逃/踏/豆/謄/藤/蕩/到/統/糖/筒/答/祷/痘/燈/灯/涛/湯/淘/棟/梼/桃/搭/悼/嶋/島/宕/套/塘/塔/唐/刀/凍/党/倒/登/読/道/納/逗/
とういつ /統一/
とうかいどう /東海道/
とうきょう /東京/
とうきょうと /東京都/
とうけい /統計/
とうげ /峠/
とうこう /投稿/
とうこうしゃ /投稿者/
とうしょう /闘将/
とうじ /当時/
とうじつ /当日/
とうじょう /登場/
とうぜん /当然/
とうちゃく /到着/
とうひょう /投票/
とうほう /当方/
とうほく /東北/
とうめん /当面/
とうろく /登録/
とお /十/
とおり /通/
とかい /都会/
とき /時/鴇/
とく /特/得/篤/禿/督/涜/徳/匿/読/
とくさつ /特撮/
とくしゅ /特殊/
とくしゅう /特集/
とくしゅうごう /特集号/
とくせい /特性/
とくちょう /特徴/
とくてい /特定/
とくてん /得点/
とくばん /特番/
とくべつ /特別/
とけい /時計/
とこ /常/床/
ところ /所/
とし /年/歳/
としょかん /図書館/
とち /土地/橡/栃/
とちゅう /途中/
とつ /突/凸/
とつぜん /突然/
とど /椴/
とない /都内/
となり /隣/
との /殿/
とび /鳶/
とびら /扉/
とま /苫/
とみ /富/
とも /共/供/友/
ともだち /友達/
とら /寅/
とり /酉/鳥/
とろ /瀞/
とん /豚/頓/遁/沌/敦/惇/屯/噸/団/問/
ど /度/奴/土/怒/努/
どう /道/動/瞳/導/同/銅/胴/童/洞/撞/憧/堂/働/
どういつ /同一/
どうかん /同感/
どうき /同期/
どうぐ /道具/
どうさ /動作/
どうし /動詞/同士/
どうじ /同時/
どうじょう /同上/同乗/
どうせい /同姓/
どうちょう /同調/
どうてき /動的/
どうにゅう /導入/
どうぶつ /動物/
どうめい /同名/
どうよう /同様/
どうろ /道路/
どく /毒/読/独/
どくしゃ /読者/
どくじ /独自/
どくりつ /独立/
どこ /何処/
どにち /土日/
どの /殿/
どよう /土曜/
どりょく /努力/
どろ /泥/
どん /鈍/曇/呑/
な /名/那/奈/菜/納/南/
ない /内/
ないせん /内線/
ないぶ /内部/
ないよう /内容/
ないりん /内輪/
なえ /苗/
なか /中/仲/
なかま /仲間/
なかみ /中身/
ながら /乍/
なぎ /凪/薙/
なぎさ /渚/
なぐ /薙/
なごや /名古屋/
なし /梨/
なぜ /何故/
なぞ /謎/
なだ /灘/
なっ /納/
なっとく /納得/
なつ /夏/捺/
なな /七/
なに /何/
なの /七/
なべ /鍋/
なま /生/
なまえ /名前/
なまり /鉛/
なみ /波/並/
なみだ /涙/
なら /奈良/楢/
なわ /縄/苗/
なわて /畷/
なん /何/難/南/軟/楠/男/納/
なんかい /何回/
なんきょく /南極/
なんじ /汝/
なんど /何度/
なんにん /何人/
なんねん /何年/
に /二/荷/仁/児/尼/迩/弐/
にい /新/
にがて /苦手/
にく /肉/
にし /西/
にじ /虹/
にじゅう /廿/
にせ /偽/
にち /日/
にちじ /日時/
にちや /日夜/
にちよう /日曜/
にっぽん /日本/
にほん /日本/
にほんがわ /日本側/
にほんご /日本語/
にほんごか /日本語化/
にほんごにゅうりょく /日本語入力/
にほんじん /日本人/
にもの /煮物/
にゃく /若/
にゅう /入/乳/
にゅういん /入院/
にゅうしゅ /入手/
にゅうりょく /入力/
にょ /女/如/
にょう /尿/女/
にら /韮/
にわ /庭/
にわとり /鶏/
にん /人/任/妊/忍/認/
にんい /任意/
にんき /人気/
にんげん /人間/
にんしき /認識/
にんじゃ /忍者/
にんずう /人数/
ぬ /奴/
ぬか /糠/
ぬし /主/
ぬの /布/
ぬま /沼/
ね /音/値/寝/根/祢/禰/
ねい /寧/祢/禰/
ねぎ /葱/
ねこ /猫/
ねだん /値段/
ねつ /熱/
ねん /年/念/粘/燃/撚/捻/然/
ねんかん /年間/
ねんだい /年代/
ねんばん /年版/
ねんぴ /燃費/
ねんまえ /年前/
ねんれい /年齢/
の /埜/之/廼/乃/野/
のう /農/膿/脳/能/納/濃/悩/嚢/
のうぎょう /農業/
のうど /濃度/
のうにゅう /納入/
のうりょく /能力/
のき /軒/
のち /後/
のぶ /信/
のみ /蚤/
のり /法/糊/
は /破/葉/歯/波/端/派/覇/播/把/巴/羽/刃/
はあく /把握/
はい /背/配/輩/肺/牌/盃/杯/敗/排/拝/廃/俳/灰/
はいいろ /灰色/
はいけい /背景/
はいけん /拝見/
はいし /廃止/
はいそう /配送/
はいふ /配布/
はいり /背理/
はいりほう /背理法/
はいれつ /配列/
はえ /蝿/
はか /墓/
はかい /破壊/
はかま /袴/
はかり /秤/
はがね /鋼/
はぎ /萩/矧/
はく /泊/白/薄/迫/舶/粕/箔/柏/拍/博/剥/伯/
はくい /白衣/
はこ /箱/函/
はざま /硲/
はし /箸/橋/端/
はしら /柱/
はじ /恥/
はじめ /肇/
はす /蓮/
はず /筈/
はずれ /外/
はぜ /櫨/
はた /幡/旗/機/端/畑/
はたけ /畠/畑/
はたん /破綻/
はだ /肌/
はだか /裸/
はち /鉢/八/蜂/
はっ /法/
はっけん /発見/
はっこう /発行/
はっしん /発信/
はっせい /発生/
はっそう /発送/発想/
はってん /発展/
はっぴょう /発表/
はつ /髪/初/発/醗/溌/
はつおん /発音/
はつげん /発言/
はつばい /発売/
はで /派手/
はと /鳩/
はな /花/鼻/華/
はなし /話/噺/
はなわ /塙/
はね /羽/
はは /母/
ははおや /母親/
はば /幅/
はま /浜/
はまぐり /蛤/
はやし /林/
はやぶさ /隼/
はら /腹/原/
はり /針/
はる /春/
はるか /遥/
はん /版/半/坂/判/反/飯/頒/煩/釆/範/販/藩/般/繁/畔/班/犯/汎/氾/板/斑/搬/帆/叛/伴/凡/
はんい /範囲/
はんえい /反映/
はんかく /半角/
はんかくかたかな /半角片仮名/
はんかくかな /半角仮名/
はんきょう /反響/
はんたい /反対/
はんだん /判断/
はんてい /判定/
はんのう /反応/
はんばい /販売/
はんぱ /半端/
はんぶん /半分/
はんろん /反論/
ば /場/馬/罵/婆/
ばあい /場合/
ばい /倍/陪/賠/売/買/狽/煤/楳/梅/媒/培/
ばいすう /倍数/
ばか /馬鹿/
ばく /麦/駁/莫/縛/爆/漠/曝/博/暴/幕/
ばしょ /場所/
ばしょう /芭蕉/
ばち /罰/
ばっすい /抜粋/
ばつ /罰/閥/抜/伐/末/筏/
ばめん /場面/
ばん /番/判/板/万/晩/盤/磐/伴/蛮/挽/蕃/
ばんぐみ /番組/
ばんごう /番号/
ひ /日/彼/比/扉/火/陽/費/樋/飛/非/避/誹/被/肥/罷/緋/秘/碑/皮/疲/泌/斐/披/批/悲/庇/妃/否/卑/匪/灯/氷/
ひいらぎ /柊/
ひえ /稗/
ひかく /比較/
ひかり /光/
ひかわ /簸川/
ひがい /被害/
ひがし /東/
ひき /匹/疋/
ひきすう /引数/
ひげ /髭/
ひこ /彦/
ひざ /膝/
ひし /菱/
ひじ /肘/
ひじょう /非常/
ひたい /額/
ひたち /日立/
ひだ /飛騨/
ひだり /左/
ひだりがわ /左側/
ひっす /必須/
ひつ /必/逼/筆/畢/弼/泌/
ひつぎ /棺/
ひつじ /羊/未/
ひつよう /必要/
ひつようせい /必要性/
ひづけ /日付/
ひてい /否定/
ひで /英/
ひと /一/人/
ひとけ /人気/
ひとこと /一言/
ひとたび /一度/
ひとみ /瞳/
ひとり /一人/
ひなん /非難/
ひのき /桧/
ひはん /批判/
ひふ /皮膚/
ひま /暇/
ひみつ /秘密/
ひめ /媛/姫/
ひも /紐/
ひゃく /百/
ひょう /表/豹/評/票/漂/氷/標/彪/俵/拍/兵/瓢/
ひょうか /評価/
ひょうき /表記/
ひょうげん /表現/
ひょうし /表紙/
ひょうしょう /表象/
ひょうじ /表示/
ひょうじゅん /標準/
ひょうじゅんてき /標準的/
ひょうたん /瓢箪/
ひょうばん /評判/
ひよう /費用/
ひら /平/
ひる /昼/蛭/蒜/
ひるま /昼間/
ひれ /鰭/
ひろ /裕/
ひん /頻/賓/貧/瀕/浜/斌/彬/品/
ひんぱん /頻繁/
び /鼻/美/眉/毘/微/尾/備/
びおん /鼻音/
びじん /美人/
びみ /美味/
びみょう /微妙/
びゃく /白/
びゅう /謬/
びょう /秒/平/鋲/苗/病/描/廟/猫/錨/
びょういん /病院/
びょうき /病気/
びわ /枇杷/琵琶/
びん /瓶/敏/貧/便/
びんじょう /便乗/
ふ /父/負/附/赴/賦/譜/腐/符/浮/普/敷/扶/怖/府/布/冨/富/婦/夫/埠/付/不/風/歩/膚/斧/阜/
ふあん /不安/
ふう /風/封/夫/富/楓/
ふうちょう /風潮/
ふうみ /風味/
ふえ /笛/
ふか /付加/
ふかのう /不可能/
ふき /蕗/葺/
ふきゅう /普及/
ふく /覆/幅/腹/福/服/複/復/副/伏/
ふくざつ /複雑/
ふくしゃ /複写/
ふくしゅう /復讐/
ふくすう /複数/
ふくせい /複製/
ふくろ /袋/
ふこう /不幸/
ふごうか /符号化/
ふさ /房/
ふし /節/
ふしぎ /不思議/
ふしぜん /不自然/
ふすま /襖/
ふそく /不足/
ふた /二/双/
ふたご /双子/
ふたり /二人/
ふたん /負担/
ふだ /札/
ふだん /普段/
ふち /淵/縁/
ふちょう /不調/
ふっかつ /復活/
ふつ /沸/払/弗/
ふつう /普通/
ふつごう /不都合/
ふで /筆/
ふところ /懐/
ふな /鮒/船/舟/
ふね /船/舟/
ふべん /不便/
ふみ /文/
ふめい /不明/
ふゆ /冬/
ふよう /芙蓉/
ふん /分/糞/雰/紛/粉/奮/焚/扮/憤/墳/噴/吻/
ふんしつ /紛失/
ぶ /分/部/無/舞/武/撫/侮/不/歩/奉/蕪/
ぶきみ /不気味/
ぶじ /無事/
ぶた /豚/
ぶつ /物/仏/
ぶつりてき /物理的/
ぶどう /葡萄/
ぶなん /無難/
ぶひん /部品/
ぶぶん /部分/
ぶもん /部門/
ぶん /分/文/聞/
ぶんか /文化/
ぶんかつ /分割/
ぶんけん /文献/
ぶんしょ /文書/
ぶんしょう /文章/
ぶんぽう /文法/
ぶんや /分野/
ぶんるい /分類/
へい /閉/平/陛/蔽/並/柄/弊/幣/塀/兵/併/丙/病/
へいがい /弊害/
へいき /平気/
へいきん /平均/
へいげん /平原/
へいれつ /並列/
へき /壁/碧/癖/僻/
へた /下手/
へび /蛇/
へや /部屋/
へら /箆/
へん /変/辺/編/返/遍/篇/片/偏/
へんか /変化/
へんかん /変換/
へんけん /偏見/
へんげ /変化/
へんこう /変更/
へんしゅう /編集/
へんじ /返事/
へんすう /変数/
へんすうめい /変数名/
へんとう /返答/
へんぴん /返品/
べ /辺/
べい /米/
べいこく /米国/
べっと /別途/
べつ /別/蔑/瞥/
べつめい /別名/
べに /紅/
べん /勉/鞭/弁/娩/便/
べんきょう /勉強/
べんぎ /便宜/
べんごし /弁護士/
べんとう /弁当/
べんり /便利/
ぺーじ /頁/
ほ /保/穂/輔/補/甫/歩/捕/圃/鋪/舗/火/帆/
ほう /方/法/泡/砲/放/報/鵬/鳳/飽/鋒/邦/豊/訪/蓬/萌/芳/胞/烹/朋/捧/抱/庖/崩/峯/峰/宝/奉/呆/包/俸/倣/縫/封/褒/蜂/
ほうえい /放映/
ほうき /放棄/
ほうげん /方言/
ほうこう /方向/
ほうこく /報告/
ほうしき /方式/
ほうしゅう /報酬/
ほうしん /方針/
ほうそう /放送/
ほうそく /法則/
ほうどう /報道/
ほうび /褒美/
ほうほう /方法/
ほうめん /方面/
ほうりつ /法律/
ほお /頬/
ほか /他/外/
ほく /北/
ほくりく /北陸/
ほけん /保険/
ほこ /矛/鉾/
ほご /保護/
ほし /星/
ほしょう /保証/
ほそく /補足/
ほぞん /保存/
ほたる /蛍/
ほっ /法/
ほっかいどう /北海道/
ほつ /発/
ほとけ /仏/
ほとんど /殆ど/
ほど /程/
ほね /骨/
ほのお /炎/
ほら /洞/
ほり /堀/
ほろ /幌/
ほん /本/翻/奔/反/
ほんき /本気/
ほんぎょう /本業/
ほんしつてき /本質的/
ほんじつ /本日/
ほんせん /本線/
ほんたい /本体/
ほんだい /本題/
ほんとう /本当/
ほんにん /本人/
ほんぶ /本部/
ほんぶん /本文/
ほんや /本屋/
ほんやく /翻訳/
ほんらい /本来/
ぼ /母/暮/簿/戊/慕/墓/募/模/
ぼいん /母音/
ぼう /某/妨/防/貿/貌/謀/膨/紡/冒/棒/望/暴/房/忙/忘/坊/剖/傍/亡/乏/妄/肪/帽/
ぼうし /帽子/
ぼうそう /暴走/
ぼうとう /冒頭/
ぼく /僕/木/穆/睦/牧/朴/撲/墨/卜/目/
ぼさつ /菩薩/
ぼしゅう /募集/
ぼたん /釦/
ぼだい /菩提/
ぼっ /坊/
ぼつ /没/勃/
ぼん /盆/凡/
ま /間/目/真/麻/魔/磨/摩/馬/
まい /枚/毎/昧/妹/埋/舞/米/
まいすう /枚数/
まいにち /毎日/
まいる /哩/
まえ /前/
まえしょり /前処理/
まき /巻/槙/牧/
まきた /真北/
まく /膜/幕/
まくら /枕/
まぐろ /鮪/
まこと /誠/
まご /孫/
まさ /正/柾/
まじめ /真面目/
ます /桝/鱒/升/舛/
また /又/俣/亦/
まち /街/町/
まつ /松/末/沫/抹/
まつりごと /政/
まで /迄/
まと /的/
まど /窓/
まどぐち /窓口/
まなこ /眼/
まね /真似/
まひがし /真東/
まほう /魔法/
まぼろし /幻/
まま /侭/
まみなみ /真南/
まめ /豆/
まゆ /繭/
まゆずみ /黛/
まよなか /真夜中/
まる /丸/
まろ /麿/
まん /万/満/漫/慢/蔓/
まんえん /万円/
まんが /漫画/
まんぞく /満足/
み /実/味/三/身/未/箕/巳/魅/
みき /幹/
みぎ /右/
みぎがわ /右側/
みことのり /詔/
みさお /操/
みさき /岬/
みささぎ /陵/
みず /水/
みずうみ /湖/
みせ /店/
みそ /味噌/
みそか /晦/
みぞ /溝/
みち /道/
みつ /蜜/密/
みてい /未定/
みどく /未読/
みどり /緑/
みな /皆/
みなさま /皆様/
みなと /湊/港/
みなみ /南/
みなもと /源/
みね /峰/
みの /蓑/
みのる /稔/
みみ /耳/
みゃく /脈/
みや /宮/
みやこ /都/
みょう /名/明/命/妙/
みょうにち /明日/
みらい /未来/
みり /粍/
みりめーとる /粍/
みん /眠/民/
む /夢/無/霧/矛/牟/務/武/六/謀/
むい /六/
むいみ /無意味/
むかし /昔/
むかんけい /無関係/
むぎ /麦/
むく /椋/
むげん /無限/
むこ /婿/
むこう /無効/
むし /無視/虫/
むしょう /無償/
むすこ /息子/
むすめ /娘/
むせいか /無声化/
むせきにん /無責任/
むせん /無線/
むだ /無駄/
むな /胸/棟/
むね /旨/胸/棟/
むのう /無能/
むら /群/村/
むらさき /紫/
むり /無理/
むりょう /無料/
むれ /群/
むろ /室/
め /目/女/芽/雌/
めい /名/明/命/迷/姪/鳴/銘/盟/冥/
めいかく /明確/
めいき /明記/
めいさく /名作/
めいし /名詞/
めいしょう /名称/
めいじ /明示/
めいれい /命令/
めいわく /迷惑/
めし /飯/
めす /牝/雌/
めつ /滅/
めん /面/麺/緬/綿/棉/免/
めんきょ /免許/
めんどう /面倒/
も /茂/模/摸/喪/
もう /蒙/耗/網/盲/猛/毛/孟/妄/亡/望/
もく /目/木/杢/黙/
もくじ /目次/
もくてき /目的/
もくひょう /目標/
もじ /文字/
もじれつ /文字列/
もち /餅/勿/
もちろん /勿論/
もっとも /尤も/
もつ /物/
もと /下/本/元/基/
もとい /基/
もなか /最中/
もの /物/者/
ものがたり /物語/
もみ /籾/
もも /桃/
もり /森/
もん /問/文/門/紋/悶/聞/
もんく /文句/
もんだい /問題/
もんだいてん /問題点/
もんめ /匁/
や /屋/家/夜/矢/弥/野/耶/爺/冶/也/八/
やきゅう /野球/
やく /約/役/訳/薬/躍/厄/益/
やくしゃ /訳者/
やくそく /約束/
やくちゅう /訳注/
やくほん /訳本/
やくわり /役割/
やしろ /社/
やじ /野次/
やすい /靖/
やっこ /奴/
やつ /奴/
やど /宿/
やなぎ /柳/
やぶ /薮/
やま /山/
やまい /病/
やり /鑓/
ゆ /諭/油/由/輸/癒/愈/愉/湯/遊/
ゆい /由/唯/
ゆいいつ /唯一/
ゆう /有/優/由/夕/友/郵/誘/裕/融/遊/右/勇/雄/祐/憂/幽/悠/湧/猶/宥/佑/邑/猷/揖/涌/柚/
ゆうい /有為/
ゆうかい /誘拐/
ゆうが /優雅/
ゆうがた /夕方/
ゆうこう /有効/
ゆうしょう /優勝/
ゆうじん /友人/
ゆうせん /優先/
ゆうめい /有名/
ゆうめいじん /有名人/
ゆうよう /有用/
ゆうりょく /有力/
ゆえ /故/
ゆか /床/
ゆき /雪/
ゆたか /裕/
ゆび /指/
ゆみ /弓/
ゆめ /夢/
よ /代/世/余/夜/予/預/輿/誉/与/四/
よい /宵/
よう /用/様/要/陽/遥/葉/養/踊/謡/耀/羊/窯/熔/溶/洋/楊/曜/擁/揺/揚/庸/容/妖/幼/傭/腰/八/
ようい /用意/容易/
ようきゅう /要求/
ようし /用紙/
ようす /様子/
ようそ /要素/
ようそう /様相/
ようび /曜日/
ようほう /用法/
ようぼう /要望/
ようやく /要約/
ようりょう /容量/
よく /翼/翌/浴/沃/欲/抑/慾/
よこ /横/
よこはま /横浜/
よし /由/
よそう /予想/
よそく /予測/
よだん /余談/
よてい /予定/
よど /淀/
よなか /夜中/
よね /米/
よぶん /余分/
よめ /嫁/
よゆう /余裕/
よる /夜/
よろい /鎧/
よん /四/
ら /等/裸/螺/羅/
らい /来/雷/頼/莱/礼/
らいしゅう /来週/
らいねんど /来年度/
らく /楽/落/酪/絡/洛/
らん /覧/欄/嵐/乱/蘭/藍/濫/卵/
り /裏/里/離/理/利/痢/裡/璃/李/履/吏/梨/
りえき /利益/
りかい /理解/
りき /力/
りく /陸/
りじゅん /利潤/
りち /律/
りっぱ /立派/
りつ /率/立/葎/律/
りてん /利点/
りゃく /略/掠/
りゅう /流/隆/立/龍/竜/粒/硫/留/溜/劉/柳/
りゅうきゅう /琉球/
りゅうこう /流行/
りゅうつう /流通/
りゆう /理由/
りょ /虜/旅/慮/侶/
りょう /量/寮/両/領/陵/遼/諒/良/糧/稜/瞭/療/猟/涼/梁/料/凌/僚/亮/了/漁/霊/
りょういき /領域/
りょうかい /了解/
りょうきん /料金/
りょうこう /良好/
りょうしゃ /両者/
りょうほう /両方/
りょうめ /両目/
りょうり /料理/
りょく /力/緑/
りよう /利用/
りようしゃ /利用者/
りろん /理論/
りろんてき /理論的/
りん /隣/輪/麟/鱗/臨/琳/燐/淋/林/厘/倫/鈴/
りんご /林檎/
りんせつ /隣接/
る /流/瑠/
るい /涙/類/累/塁/
れい /例/齢/麗/霊/零/隷/鈴/苓/礼/玲/怜/嶺/励/冷/伶/令/戻/
れいがい /例外/
れき /歴/暦/
れきし /歴史/
れっしゃ /列車/
れつ /列/裂/烈/劣/
れん /恋/蓮/連/聯/練/簾/煉/漣/憐/廉/錬/
れんきゅう /連休/
れんさい /連載/
れんしゅう /練習/
れんぞく /連続/
れんぞくち /連続値/
れんらく /連絡/
れんらくさき /連絡先/
ろ /露/路/炉/櫓/魯/呂/
ろう /朗/郎/蝋/聾/老/牢/漏/浪/榔/楼/弄/婁/労/糧/露/狼/廊/篭/
ろうか /廊下/
ろうひ /浪費/
ろうりょく /労力/
ろく /緑/録/肋/禄/六/
ろくが /録画/
ろん /論/
ろんぎ /論議/
ろんぶん /論文/
ろんり /論理/
わ /話/和/我/輪/倭/
わい /歪/
わいろ /賄賂/
わき /脇/
わく /枠/惑/
わくせい /惑星/
わけ /訳/
わざ /技/業/
わし /鷲/
わしゃ /話者/
わた /綿/
わたくし /私/
わたし /私/
わだい /話題/
わに /鰐/
わら /藁/
わらび /蕨/
わらべ /童/
わり /割/
わりばし /割箸/
われ /我/
わん /腕/碗/湾/椀/
