;; -*- mode: fundamental; coding: euc-jp -*-
;; Large size dictionary for SKK system
;; Copyright (C) 1988-1995, 1997, 1999-2014
;;
;; Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
;; Hironobu Takahashi <takahasi@tiny.or.jp>,
;; Masahiro Doteguchi, Miki Inooka,
;; Yukiyoshi Kameyama <kameyama@kuis.kyoto-u.ac.jp>,
;; Akihiko Sasaki, Dai Ando, Junichi Okukawa,
;; Katsushi Sato and Nobuhiro Yamagishi
;; NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
;; MITA Yuusuke <clefs@mail.goo.ne.jp>
;; SKK Development Team <skk@ring.gr.jp>
;;
;; Maintainer: SKK Development Team <skk@ring.gr.jp>
;; Version: $Id: SKK-JISYO.L,v 1.1798 2026/02/28 00:10:01 czkmt Exp $
;; Keywords: japanese
;; Last Modified: $Date: 2026/02/28 00:10:01 $
;;
;; This dictionary is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or
;; (at your option) any later version.
;;
;; This dictionary is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with Daredevil SKK, see the file COPYING.  If not, write to
;; the Free Software Foundation Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.
;;
;; ACKNOWLEDGEMENT
;;
;; この辞書は、SKK 原作者の佐藤雅彦先生が、第 1 版作成のために東北大学
;; 電気通信研究所佐藤研究室 (当時) の学生さん達とともに scratch から作
;; 成されたのをその起源とし、その後、無数のユーザからのユーザ辞書の提
;; 供やフォームによる追加・校閲によって今尚日々メンテナンスされている日
;; 本で最大規模の、GPL による copy free の辞書です。
;;
;; この辞書の作成にご尽力頂いた全ての方に感謝すると共に、これをお読み
;; のあなたのご協力を是非ともお待ちしております。
;;
;;   http://openlab.ring.gr.jp/skk/registdic.cgi
;;
;; にアクセスし、フォームに是非あなたの新語・誤登録指摘・コメントを書
;; いて下さい。
;;
;; また、実際に辞書の編集をしてみたいという方は、
;;
;;   http://openlab.ring.gr.jp/skk/cvs-ja.html#account
;;
;; をご覧の上、cvs account の発行申し込みをして下さい。
;;
;; 辞書の編集方針は skk/dic/READMEs/committers.txt をご参照下さい。
;; そこに記載のない事項、またその変更については、その都度 SKK Openlab
;; ML で話し合いで決められます。
;;
;; okuri-ari entries.
をs /惜/
ゐr /居/
われらg /我等/
われしr /我知/
われw /我/
われt /我/
われr /我/
われn /我/
われm /我/
われh /我/
われg /我/
わるよi /悪酔/
わるびr /悪怯/
わるだくm /悪巧/
わるすg /悪過/
わるがしこs /悪賢/
わるがしこk /悪賢/
わるがしこi /悪賢/
わるがしこg /悪賢/
わるs /悪/惡;「悪」の旧字(人名用漢字)/
わるk /悪/惡;「悪」の旧字(人名用漢字)/
わるi /悪/惡;「悪」の旧字(人名用漢字)/
わるg /悪/惡;「悪」の旧字(人名用漢字)/
わるb /悪/
わりもどs /割り戻/割戻/
わりふt /割り振/割振/
わりふr /割り振/割振/
わりふn /割り振/割振/
わりふc /割り振/割振/
わりびk /割引/割り引/
わりびi /割り引/割引/
わりつk /割り付/割付/
わりだs /割り出/割出/
わりこn /割り込/割込/
わりこm /割り込/割込/
わりきt /割り切/割切/
わりきr /割り切/割切/
わりきn /割り切/割切/
わりきc /割り切/割切/
わりいr /割り入;卵を-れる/
わりあt /割り当/割当/
わりあi /割り合/割合/
わりt /割/
わりs /割/
わりn /割;-に(合う)/
わりk /割/
わらぶk /藁葺/
わらいなk /笑い泣/
わらいとb /笑い飛/
わらいつづk /笑い続/
わらいだs /笑い出/
わらいじn /笑い死/
わらいころg /笑い転/
わらいこk /笑い転/
わらいくずr /笑い崩/
わらいかえs /笑い返/
わらw /笑/嗤;(jeer) 人の失敗を嗤う/
わらu /笑/嗤;(jeer) 人の失敗を嗤う/
わらt /笑/嗤;(jeer) 人の失敗を嗤う/
わらo /笑/嗤;(jeer) 人の失敗を嗤う/
わらk /笑/嗤/
わらi /笑/嗤;(jeer) 人の失敗を嗤う/
わらh /笑/嗤/
わらe /笑/嗤;(jeer) 人の失敗を嗤う/
わらc /笑/嗤;(jeer) 人の失敗を嗤う/
わめきちr /喚き散/
わめきたt /喚き立/
わめk /喚/叫/
わめi /喚/叫/
わびずまi /侘住/
わびしs /侘/
わびしk /侘/
わびしi /侘/
わびしg /侘/
わびs /侘/
わびr /侘/
わのr /輪乗/
わななk /戦慄/
わななi /戦慄/
わなg /輪投/
わとj /和綴/
わづらh /煩/
わだかまt /蟠/
わだかまr /蟠/
わだかまn /蟠/
わだかまc /蟠/
わたりあるk /渡り歩/
わたりあるi /渡り歩/
わたりあw /渡り合/
わたりあu /渡り合/
わたりあt /渡り合/
わたりあo /渡り合/
わたりあi /渡り合/
わたりあe /渡り合/
わたりあc /渡り合/
わたしこn /渡し込/
わたしこm /渡し込/
わたしw /私/
わたしt /私/
わたしn /私/
わたしm /私/
わたしh /私/
わたしg /私/
わたくしw /私/
わたくしt /私/
わたくしn /私/
わたくしm /私/
わたくしh /私/
わたくしg /私/
わたt /渡/亘;(範囲・期間) ５日間に亘る/亙;=亘る (人名用漢字) (NB:本来の字)/渉/航/
わたs /渡/
わたr /渡/亘;(範囲・期間) ５日間に亘る/亙;=亘る (人名用漢字) (NB:本来の字)/渉/航/
わたn /渡/亘;(範囲・期間) ５日間に亘る/亙;=亘る (人名用漢字) (NB:本来の字)/渉/航/
わたc /渡/亘;(範囲・期間) ５日間に亘る/亙;=亘る (人名用漢字) (NB:本来の字)/渉/航/
わせだどおr /早稲田通/
わずらw /煩;(煩瑣) 煩わしい作業/患;(罹患) 肺病を患う/
わずらu /患;(罹患) 肺病を患う/煩;(煩瑣) 思い煩う/
わずらt /患;(罹患) 肺病を患う/煩;(煩瑣) 思い煩う/
わずらo /患;(罹患) 肺病を患う/煩;(煩瑣) 思い煩う/
わずらi /患;(罹患) 肺病を患う/煩;(煩瑣) 思い煩う/
わずらe /患;(罹患) 肺病を患う/煩;(煩瑣) 思い煩う/
わずらc /患;(罹患) 肺病を患う/煩;(煩瑣) 思い煩う/
わずk /僅/微;NB:「かすk」と同形/纔;≒僅か/毫;<rare> ≒僅か/
わすれはt /忘れ果/
わすれさt /忘れ去/
わすれさr /忘れ去/
わすれさn /忘れ去/
わすれさc /忘れ去/
わすれがたs /忘れ難/
わすれがたk /忘れ難/
わすれがたi /忘れ難/
わすれがたg /忘れ難/
わすr /忘/
わしづかm /鷲掴/
わしw /儂/
わしt /儂/
わしn /儂/
わしm /儂/
わしh /儂/
わしg /儂/
わざわi /災/禍;(字義:落とし穴)/厄;<rare>/
わざt /態/
わけなs /訳無/
わけなk /訳無/
わけなi /訳無/
わけしr /訳知/
わけいt /分け入/
わけいr /分け入/
わけいn /分け入/
わけいc /分け入/
わけあたe /分け与/
わけあw /分け合/
わけあu /分け合/
わけあt /分け合/
わけあo /分け合/
わけあi /分け合/
わけあe /分け合/
わけあc /分け合/
わけt /分/
わけr /分/
わけn /分/
わけc /分/
わくぐm /枠組/
わぎr /輪切/
わきまe /弁/
わきでz /湧き出/涌き出/
わきでy /湧き出/涌き出/
わきでt /湧き出/涌き出/
わきでs /湧き出/涌き出/
わきでr /湧き出/涌き出/
わきでn /湧き出/涌き出/
わきでm /湧き出/涌き出/
わきでc /湧き出/涌き出/
わきづk /脇付/
わきだs /湧き出/
わきたt /沸き立;boil/湧き立;pour out/涌き立;=湧き立つ/
わきたc /沸き立;boil/湧き立;pour out/涌き立;=湧き立つ/
わきがたm /脇固/
わきかえt /沸き返/
わきかえr /沸き返/
わきかえn /沸き返/
わきかえc /沸き返/
わきおこt /沸き起/
わきおこr /沸き起/
わきおこn /沸き起/
わきおこc /沸き起/
わきおk /沸き起/湧き起/
わきあg /湧き上;(rush) 雲が湧き上がる/沸き上;風呂が沸き上がる/
わかわかs /若々/
わかりやすs /分かり易/判り易/理解り易/
わかりやすk /分かり易/判り易/理解り易/
わかりやすi /分かり易/判り易/理解り易/
わかりやすg /分かり易/判り易/理解り易/
わかりにくs /分かり難/
わかりにくk /分かり難/
わかりにくi /分かり難/
わかりにくg /分かり難/
わかりきt /分かり切/
わかりきr /分かり切/
わかりきn /分かり切/
わかりきc /分かり切/
わかづくr /若作/
わかちあw /分かち合/
わかちあu /分かち合/
わかちあt /分かち合/
わかちあo /分かち合/
わかちあi /分かち合/
わかちあe /分かち合/
わかちあc /分かち合/
わかがえt /若返/
わかがえr /若返/
わかがえn /若返/
わかがえc /若返/
わかy /若/
わかt /判;(判別) 違いが判る/分;(非正則:わk)/解;(理解) 仕組が解る/別/頒;わけ与える/觧;「解」の異体字/理解;(当て字)/
わかs /若/稚/
わかr /別;(人と) 彼氏と別れる/判;(判別) 違いが判る/解;(理解) 仕組が解る/分;(非正則:わk)/理解;(当て字)/訣;(キッパリとわかれる)/觧;「解」の異体字/
わかn /解;(理解) 仕組が解る/判;(判別) 違いが判る/分;(非正則:わk)/理解;(当て字)/觧;「解」の異体字/
わかk /若/稚/
わかi /若/稚/
わかg /若/稚/
わかc /解;(理解) 仕組が解る/判;(判別) 違いが判る/分;(非正則:わk)/理解;(当て字)/觧;「解」の異体字/
わt /割/
わs /和/
わr /割/破/
わn /割/
わk /分/湧;(spring) 泉が湧く/沸;(boil) お湯が沸く/涌;≒湧く/訳/
わi /湧;(spring) 泉が湧く/沸;(boil) お湯が沸く/涌;≒湧く/
わg /我/
わc /割/
わb /詫;謝罪する/侘;侘び寂び/
ろんz /論/
ろんj /論/
ろくがどr /録画撮/
ろくs /録;記録/
ろくn /碌/
ろうをおs /労を惜/
ろうs /労;心身を労する/弄;策を弄する/聾;耳を聾する/
れんらくいただk /連絡頂/
れんらくいただi /連絡頂/
れんらくいたs /連絡致/
れんきゅうあk /連休明/
れっs /列/
れいれいs /麗々/
れいぎただs /礼儀正/
れいn /例/
るいs /類/
りんt /凛/
りりs /凛々/凛凛/律々;=凛々しい/
りようくだs /利用下/
りようs /利用/
りょこううかがi /旅行伺/
りょうほうとt /両方取/
りょうほうとr /両方取/
りょうほうとn /両方取/
りょうほうとc /両方取/
りょうびらk /両開/
りょうひらk /両開/
りょうしょうくだs /了承下/
りょうかいs /了解/
りょうs /領/諒;諒承/
りゅうこうおくr /流行遅/
りゃくs /略/
りまわr /利回/
りばらi /利払/
りづm /理詰/
りつk /利付/
りっs /律/
りだすk /利助/
りさg /利下/
りぐi /利食/
りくつぬk /理屈抜/
りくつどおr /理屈通/
りくつづk /陸続/
りくつp /理屈/
りくあg /陸揚/
りくs /戮/
りきn /力/
りきm /力/
りかいs /理解/
りおt /利落/
りあg /利上/
りs /利/
らんぎr /乱切/
らんs /濫/
らっs /拉/
らくがk /落書/
らくs /楽/
らくn /楽/
らくd /楽/
らうs /労/
よんd /読ん;※送り位置補正/
よわりはt /弱り果/
よわりきt /弱り切/
よわりきr /弱り切/
よわりきn /弱り切/
よわりきc /弱り切/
よわよわs /弱々/
よわふくm /弱含/
よわたr /世渡/
よわすg /弱過/
よわt /弱/
よわs /弱/
よわr /弱/
よわn /弱/
よわm /弱/
よわk /弱/
よわi /弱/
よわg /弱/
よわc /弱/
よろしk /宜/
よろこんd /喜ん;※送り位置補正/
よろこびいさn /喜び勇/
よろこびいさm /喜び勇/
よろこn /喜;(字義:お祝いしてよろこぶ)/悦;(字義:心のしこりが取れる)/歓;(字義:声を上げてよろこぶ)/慶;(祝福)お慶び申し上げます (字義:お祝いを持って行く)/
よろこb /喜;(字義:お祝いしてよろこぶ)/悦;(字義:心のしこりが取れる)/歓;(字義:声を上げてよろこぶ)/慶;(祝福)「お慶び申し上げます」 (字義:お祝いを持って行く)/
よろs /宜/
よろm /蹌踉/
よるおそs /夜遅/
よるおそk /夜遅/
よるおそi /夜遅/
よるおそg /夜遅/
よりわk /選り分/
よりぬk /選り抜/
よりぬi /選り抜/
よりによt /選りに選/
よりどr /選り取/
よりつk /寄付/
よりつi /寄付/
よりだs /選り出/
よりそw /寄り添/
よりそu /寄り添/
よりそt /寄り添/
よりそo /寄り添/
よりそi /寄り添/
よりそe /寄り添/
よりそc /寄り添/
よりごのm /選り好/
よりきt /寄り切/
よりきr /寄り切/
よりきn /寄り切/
よりきc /寄り切/
よりかk /寄り掛/
よりあわs /縒り合/
よりあつm /寄り集/
よりあw /縒り合/寄り合/
よりあu /寄り合/
よりあt /寄り合/
よりあo /寄り合/
よりあi /寄り合/
よりあe /寄り合/
よりあc /寄り合/
よめとr /嫁取/
よめいr /嫁入/
よみわk /読み分/
よみやすs /読み易/
よみやすk /読み易/
よみやすi /読み易/
よみやすg /読み易/
よみまちがw /読み間違/
よみまちがu /読み間違/
よみまちがt /読み間違/
よみまちがo /読み間違/
よみまちがi /読み間違/
よみまちがe /読み間違/
よみまちがc /読み間違/
よみふけt /読み耽/
よみふけr /読み耽/
よみふけn /読み耽/
よみふけc /読み耽/
よみはじm /読み始/
よみにくs /読み難/
よみにくk /読み難/
よみにくi /読み難/
よみにくg /読み難/
よみながs /読み流/
よみなおs /読み直/
よみなr /読み慣/
よみとおs /読み通/
よみとt /読み取/読取/
よみとr /読み取/読取/
よみとn /読み取/読取/
よみとk /読み解/
よみとi /読み解/
よみとc /読み取/読取/
よみとb /読み飛/
よみづらs /読み辛/
よみづらk /読み辛/
よみづらi /読み辛/
よみづらg /読み辛/
よみつづk /読み続/
よみちがe /読み違/
よみちr /読み散/
よみだs /読み出/読出/
よみすすn /読み進/
よみすすm /読み進/
よみすごs /読み過/
よみすt /読み捨/
よみこn /読み込/読込/詠み込;詩歌の中に入れる/
よみこm /読み込/読込/詠み込;詩歌の中に入れる/
よみくらb /読み比/読み較/
よみくだs /読み下/訓み下/
よみきt /読み切/読切/
よみきr /読み切/読切/
よみきn /読み切/読切/
よみきk /読み聞/
よみきc /読み切/読切/
よみがえt /甦/蘇;=甦る/蘓;「蘇」の異体字/
よみがえr /甦/蘇;=甦る/蘓;「蘇」の異体字/
よみがえn /甦/蘇;=甦る/蘓;「蘇」の異体字/
よみがえc /甦/蘇;=甦る/蘓;「蘇」の異体字/
よみがe /蘇/蘓;「蘇」の異体字/
よみかえs /読み返/
よみかk /読み書/
よみかe /読み替/
よみおとs /読み落/
よみおw /読み終/
よみおt /読み落/
よみおe /読み終/
よみあやまt /読み誤/
よみあやまr /読み誤/
よみあやまn /読み誤/
よみあやまc /読み誤/
よみあさt /読み漁/
よみあさr /読み漁/
よみあさn /読み漁/
よみあさc /読み漁/
よみあw /読み合/
よみあk /読み飽/
よみあg /読み上/
よみs /嘉/
よみd /読み;※送り位置補正/
よまわr /夜回/
よふかs /夜更/
よふk /夜更/
よびよs /呼び寄/呼寄/
よびもどs /呼び戻/
よびならw /呼び習/
よびとm /呼び止/
よびつづk /呼び続/
よびつk /呼び付/呼付/
よびだs /呼び出/呼出/
よびたt /呼び立/
よびすt /呼び捨/
よびさm /呼び覚/
よびこn /呼び込/
よびこm /呼び込/
よびかわs /呼び交/
よびかえs /呼び返/
よびかw /呼び交/
よびかk /呼び掛/呼掛/
よびおk /呼び起/
よびあつm /呼び集/
よばi /夜這/
よにg /夜逃/
よなよn /夜な夜/
よなおs /世直/
よなr /世慣/世馴/
よなk /夜泣/
よどおs /夜通/
よどn /淀/澱;=淀む/
よどm /淀/澱;=淀む/
よとおr /四通/
よていどおr /予定通/
よづr /夜釣/
よつg /世継/
よっぱらw /酔っ払/
よっぱらu /酔っ払/
よっぱらt /酔っ払/
よっぱらo /酔っ払/
よっぱらi /酔っ払/
よっぱらe /酔っ払/
よっぱらc /酔っ払/
よってたt /拠って立/
よっかk /寄っ掛/
よっt /四/
よだt /夜立/弥立;身の毛も弥立つ/
よだc /弥立;身の毛も弥立つ/
よそよそs /余所余所/
よそほu /裝;「装」の旧字(人名用漢字)/
よそおw /装/粧/裝;「装」の旧字(人名用漢字)/
よそおu /装/粧/裝;「装」の旧字(人名用漢字)/
よそおt /装/裝;「装」の旧字(人名用漢字)/粧/
よそおo /装/粧/裝;「装」の旧字(人名用漢字)/
よそおi /装/裝;「装」の旧字(人名用漢字)/粧/
よそおh /裝;「装」の旧字(人名用漢字)/
よそおe /装/粧/裝;「装」の旧字(人名用漢字)/
よそおc /装/粧/裝;「装」の旧字(人名用漢字)/
よそうどおr /予想通/
よそうs /予想/
よそw /装/
よそu /装/
よそt /装/
よそo /装/
よそi /装/
よそh /装/
よそe /寄/比/装/
よそc /装/
よせつk /寄せ付/
よせこz /寄せ来/
よせこy /寄せ来/
よせこs /寄せ来/
よせこr /寄せ来/
よせこn /寄せ来/
よせこi /寄せ来/
よせくr /寄せ来/
よせくn /寄せ来/
よせきy /寄せ来/
よせきt /寄せ来/
よせきs /寄せ来/
よせきn /寄せ来/
よせきm /寄せ来/
よせきd /寄せ来/
よせきc /寄せ来/
よせがk /寄せ書/寄書/
よせあつm /寄せ集/
よせあw /寄せ合/
よせあu /寄せ合/
よせあt /寄せ合/
よせあo /寄せ合/
よせあi /寄せ合/
よせあe /寄せ合/
よせあc /寄せ合/
よすg /良過/
よじのぼt /攀じ上/
よじのぼr /攀じ上/
よじのぼn /攀じ上/
よじのぼc /攀じ上/
よじt /捩/
よじr /捩/
よじn /捩/
よじk /捩/
よじc /捩/
よしなs /由無/
よしなk /由無/
よしなi /由無/
よしなg /由無/
よしあs /善し悪/
よごs /汚/
よごr /汚/
よこわr /横割/
よこばしt /横走/
よこばしr /横走/
よこばしn /横走/
よこばしc /横走/
よこばi /横這/
よこならb /横並/
よこながs /横流/
よこどr /横取/
よことb /横跳/
よこづk /横付/
よこっとb /横っ飛/横っ跳/
よこだおs /横倒/
よこずk /横好/
よこすべr /横滑/
よこしまs /邪/
よこしまn /邪/
よこしまd /邪/
よこくどおr /予告通/
よこぎt /横切/
よこぎr /横切/
よこぎn /横切/
よこぎc /横切/
よこがk /横書/
よこt /横/
よこs /寄越/遣/横;-すべり/
よくぶかs /欲深/
よくぶかk /欲深/
よくぶかi /欲深/
よくぶかg /欲深/
よくばt /欲張/
よくばr /欲張/
よくばn /欲張/
よくばc /欲張/
よくs /浴;bath/
よくb /欲/
よぎなk /余儀無/
よぎt /過/
よぎr /過/
よぎn /余儀/過/
よぎc /過/
よかr /善か;※送り位置補正/
ようりょうよk /要領良/
ようよu /漸/
ようやk /漸/
ようむk /用向/
ようちあさがk /夜討ち朝駆/
ようだt /用立/
ようたs /用足/
ようずm /用済/
ようじんぶかs /用心深/
ようじんぶかk /用心深/
ようじんぶかi /用心深/
ようじんぶかg /用心深/
ようしゃねがu /容赦願/
ようしゃねがi /容赦願/
ようしゃくだs /容赦下/
よういs /用意/
よういn /容易/
よういd /容易/
ようt /夜討/杳;-として姿を見せない/
ようs /要/擁;擁護/様/
ようn /様/陽/樣;「様」の旧字(人名用漢字)/
ようh /要;-は/
ようd /様/
よいどm /酔い止/
よいつぶs /酔い潰/
よいつぶr /酔い潰/
よいっぱr /宵っ張/
よいしr /酔い痴/
よいざm /酔い覚;/酔い醒/酔醒/
よいごs /宵越/
よあるk /夜歩/
よあそb /夜遊/
よあk /夜明/
よz /攀/
よw /酔/醉;「酔」の旧字(人名用漢字)/
よu /酔/醉;「酔」の旧字(人名用漢字)/
よt /酔/四/寄/因;(原因) ガス漏れに因る/選;選りすぐり NB:「えr」「すぐr」と同形/依;(依存) 仕送りに依る/拠;(根拠) 先行論文に拠る/４/醉;「酔」の旧字(人名用漢字)/撚;こよりを撚る/縒;≒撚る/憑/
よs /寄/良/善;(性質がよい)「善い行い」/止/好;好し/酔/佳;(縁起がよい)「佳い日」 (字義:形がすっきりしている)/醉;「酔」の旧字(人名用漢字)/譱;「善」の異体字/
よr /寄/依;(依存) 仕送りに依る/拠;(根拠) 先行論文に拠る/因;(原因) ガス漏れに因る/撚;こよりを撚る/縒;≒撚る/選;選りすぐり NB:「えr」「すぐr」と同形/憑/
よp /酔/
よo /酔/醉;「酔」の旧字(人名用漢字)/
よn /読/呼/詠;和歌を詠む/訓;字の訓み(=訓読み)/世/丗;「世」の異体字/讀;「読」の旧字/寄/依;(依存) 仕送りに依る/拠;(根拠) 先行論文に拠る/因;(原因) ガス漏れに因る/撚;こよりを撚る/縒;≒撚る/選;選りすぐり NB:「えr」「すぐr」と同形/憑/喚;(声を上げて呼び寄せる)/
よm /読/詠;和歌を詠む/訓;字の訓み(=訓読み)/讀;「読」の旧字/
よk /良/善;(性質がよい)「善い行い」/除;(put aside)自分の分を除ける NB:「のk」と同形/避;(avoid)車を避ける NB:「さk」と同形/好;NB:「すk」と同形/能;柔-く剛を制す/寄;-っかかる/譱;「善」の異体字/酔/佳;(縁起がよい)「佳い日」 (字義:形がすっきりしている)/醉;「酔」の旧字(人名用漢字)/
よj /攀/
よi /良/酔/好;(このましい),「好い天気」/善;(性質がよい)「善い行い」/佳;(縁起がよい)「佳い日」 (字義:形がすっきりしている)/醉;「酔」の旧字(人名用漢字)/譱;「善」の異体字/
よg /善;(性質がよい)「善い行い」/良/酔/好;(このましい),「好い天気」/佳;(縁起がよい)「佳い日」 (字義:形がすっきりしている)/醉;「酔」の旧字(人名用漢字)/譱;「善」の異体字/
よe /酔/醉;「酔」の旧字(人名用漢字)/
よc /酔/醉;「酔」の旧字(人名用漢字)/寄/依;(依存) 仕送りに依る/拠;(根拠) 先行論文に拠る/因;(原因) ガス漏れに因る/撚;こよりを撚る/縒;≒撚る/選;選りすぐり NB:「えr」「すぐr」と同形/憑/
よb /呼/喚;(声を上げて呼び寄せる)/
よa /良/
ゆわかs /湯沸/
ゆわえつk /結わえ付/
ゆわk /湯沸/
ゆれうごk /揺れ動/
ゆれうごi /揺れ動/
ゆるしがたs /許し難/
ゆるしがたk /許し難/
ゆるしがたi /許し難/
ゆるしがたg /許し難/
ゆるしあw /許し合/
ゆるしあu /許し合/
ゆるしあt /許し合/
ゆるしあo /許し合/
ゆるしあi /許し合/
ゆるしあe /許し合/
ゆるしあc /許し合/
ゆるぎなs /揺るぎ無/
ゆるぎなk /揺るぎ無/
ゆるぎなi /揺るぎ無/
ゆるがs /忽;-せ/
ゆるy /緩/
ゆるs /許/赦;罪を赦す/聴;ききいれる/緩/
ゆるr /緩;副詞(-り)/
ゆるn /緩/弛/
ゆるm /緩/弛/
ゆるk /緩/
ゆるi /緩/揺/
ゆるg /揺/緩/
ゆるb /弛;[文語]/緩;[文語]/
ゆりもどs /揺り戻/
ゆりかえs /揺り返/
ゆりおこs /揺り起/
ゆりおt /揺り落/
ゆりおk /揺り起/
ゆりうごk /揺り動/
ゆゆs /由々/由由/忌々;≒由々しい/
ゆめみz /夢見/
ゆめみy /夢見/
ゆめみt /夢見/
ゆめみs /夢見/
ゆめみr /夢見/
ゆめみn /夢見/
ゆめみm /夢見/
ゆめみk /夢見/
ゆめみc /夢見/
ゆめn /夢/
ゆみひk /弓引/
ゆみひi /弓引/
ゆみけずr /弓削;?/
ゆびづかi /指使/
ゆびさs /指差/
ゆびおr /指折/
ゆどおs /湯通/
ゆとうよm /湯桶読/
ゆですg /茹で過/
ゆであg /茹で上/
ゆづt /讓;「譲」の旧字(人名用漢字)/
ゆづr /讓;「譲」の旧字(人名用漢字)/
ゆだt /茹/
ゆだr /茹/
ゆだn /委/茹/
ゆだc /茹/
ゆたk /豊/豐;旧字/
ゆずりわたs /譲り渡/
ゆずりうk /譲り受/
ゆずりあw /譲り合/
ゆずりあu /譲り合/
ゆずりあt /譲り合/
ゆずりあo /譲り合/
ゆずりあi /譲り合/
ゆずりあe /譲り合/
ゆずりあc /譲り合/
ゆずt /譲/讓;「譲」の旧字(人名用漢字)/
ゆずr /譲/讓;「譲」の旧字(人名用漢字)/
ゆずn /譲/讓;「譲」の旧字(人名用漢字)/
ゆずc /譲/讓;「譲」の旧字(人名用漢字)/
ゆすりとt /強請り取/
ゆすりとr /強請り取/
ゆすりとn /強請り取/
ゆすりとc /強請り取/
ゆすぶt /揺振/
ゆすぶr /揺振/
ゆすぶn /揺振/
ゆすぶc /揺振/
ゆすt /強請/揺;非正則/
ゆすr /強請/揺;非正則/
ゆすn /強請/揺;非正則/
ゆすi /濯/
ゆすg /濯/
ゆすc /強請/揺;非正則/
ゆざm /湯冷/
ゆさぶt /揺さ振/揺振/
ゆさぶr /揺さ振/揺振/
ゆさぶn /揺さ振/揺振/
ゆさぶc /揺さ振/揺振/
ゆきわたt /行き渡/
ゆきわたr /行き渡/
ゆきわたn /行き渡/
ゆきわたc /行き渡/
ゆきまつr /雪祭/
ゆきなやn /行き悩/
ゆきなやm /行き悩/
ゆきどm /行き止/
ゆきどk /雪解/
ゆきとどk /行き届/
ゆきとどi /行き届/
ゆきづm /行き詰/
ゆきつk /行き着;-く先/行き付;-けの店/
ゆきつi /行き着/
ゆきちがw /行き違/
ゆきちがu /行き違/
ゆきちがt /行き違/
ゆきちがo /行き違/
ゆきちがi /行き違/
ゆきちがe /行き違/
ゆきちがc /行き違/
ゆきだおr /行き倒/
ゆきすg /行き過/行過/
ゆききd /行き来/
ゆきがk /行き掛/
ゆきかよw /行き通/
ゆきかよu /行き通/
ゆきかよt /行き通/
ゆきかよo /行き通/
ゆきかよi /行き通/
ゆきかよe /行き通/
ゆきかよc /行き通/
ゆきかえr /行き帰/
ゆきかw /行き交/
ゆきかu /行き交/
ゆきかt /行き交/
ゆきかo /行き交/
ゆきかi /行き交/
ゆきかe /行き交/
ゆきかc /行き交/
ゆきおr /雪下/
ゆきあたt /行き当/
ゆきあたr /行き当/
ゆきあたn /行き当/
ゆきあたc /行き当/
ゆきあw /行き合/
ゆきあu /行き合/
ゆきあt /行き当/行き合/行当/
ゆきあo /行き合/
ゆきあk /雪明/
ゆきあi /行き合/
ゆきあe /行き合/
ゆきあc /行き合/
ゆがn /歪/
ゆがm /歪/
ゆがk /湯掻/
ゆがi /湯掻/
ゆかs /床;(当て字)/
ゆえなs /故無/
ゆえなk /故無/
ゆえなi /故無/
ゆえなg /故無/
ゆえn /故/
ゆうりn /有利/
ゆうやk /夕焼/
ゆうめいすg /有名過/
ゆうまぐr /夕間暮/
ゆうびんうk /郵便受/
ゆうばr /夕晴/
ゆうばe /夕映/
ゆうすずm /夕涼/
ゆうしょうあらそi /優勝争/
ゆうしゅうn /優秀/
ゆうぐr /夕暮/
ゆうきづk /勇気付/
ゆうs /有/
ゆうn /優/
ゆうb /夕/
ゆいつk /結い付/
ゆいしょただs /由緒正/
ゆいあg /結い上/
ゆあg /湯上/
ゆw /結/
ゆu /結/
ゆt /結/揺/汰;砂金を汰る/淘;≒汰る/搖;「揺」の旧字(人名用漢字)/
ゆs /揺/搖;「揺」の旧字(人名用漢字)/
ゆr /揺/汰;砂金を汰る/淘;≒汰る/搖;「揺」の旧字(人名用漢字)/
ゆo /結/
ゆn /揺/汰;砂金を汰る/淘;≒汰る/搖;「揺」の旧字(人名用漢字)/
ゆk /行/逝;(死ぬ)/往;(字義:目的地へ行く) 道を往く/征;(字義:まっすぐ遠くへ行く) 荒野を征く/徃;「往」の異体字/
ゆi /結/
ゆh /結/
ゆg /湯/
ゆe /結/
ゆd /茹/
ゆc /結/揺/汰;砂金を汰る/淘;≒汰る/搖;「揺」の旧字(人名用漢字)/
やんごとなs /止事無/
やんごとなk /止事無/
やんごとなi /止事無/
やわらかk /柔/
やわs /柔/
やわr /柔;(字義:曲げても折れないしなやかさ)/軟;(字義:手応えがない)/和;-らぐ/
やわn /柔/
やわk /柔/
やわi /柔/
やわg /柔/
やわd /柔/
やりのこs /遣り残/やり残/
やりぬk /遣り抜/やり抜/
やりぬi /遣り抜/やり抜/
やりなおs /遣り直/やり直/
やりとr /遣り取/
やりとg /遣り遂/やり遂/
やりつくs /遣り尽/
やりつk /遣り付/
やりっぱなs /遣りっ放/
やりだs /遣り出/やり出/
やりそんz /遣り損/やり損/
やりそんj /遣り損/やり損/
やりそこなw /遣り損/やり損/
やりそこなu /遣り損/やり損/
やりそこなt /遣り損/やり損/
やりそこなo /遣り損/やり損/
やりそこなi /遣り損/やり損/
やりそこなe /遣り損/やり損/
やりそこなc /遣り損/やり損/
やりそこn /遣り損/やり損/
やりすごs /遣り過/やり過/
やりすg /遣り過/やり過/
やりこなs /遣り熟/
やりこn /遣り込/やり込/
やりこm /遣り込/やり込/
やりきr /遣り切;遣り切れない/やり切/
やりかえs /遣り返/やり返/
やりおe /遣り終/やり終/
やりあw /やり合/遣り合/
やりあu /遣り合/やり合/
やりあt /やり合/遣り合/
やりあo /やり合/遣り合/
やりあi /やり合/遣り合/
やりあe /やり合/
やりあc /遣り合/やり合/
やめr /止め;※送り位置補正/
やむをえz /止むを得/
やむをえn /止むを得/
やむをえm /止むを得/
やむごとなs /止事無/
やむごとなk /止事無/
やむごとなi /止事無/
やみとりひk /闇取り引/
やみつk /病み付/
やみつi /病み付/
やみがたs /止み難/
やみがたk /止み難/
やみがたi /止み難/
やみがたg /止み難/
やみあがr /病み上/
やみあg /病み上/
やまわk /山分/
やまもr /山盛/
やまむk /山向/
やままw /山回/
やまぶかs /山深/
やまぶかk /山深/
やまぶかi /山深/
やまぶかg /山深/
やまびらk /山開/
やまのぼr /山登/
やまづm /山積/
やまぞi /山沿/
やまそだt /山育/
やまごe /山越/
やまくずs /山崩/
やまくずr /山崩/
やまあるk /山歩/
やまs /疚/疾;(字義:体調が悪い)/
やぶれr /殕/
やぶりすt /破り捨/
やぶにらm /藪睨/
やぶさk /吝/
やぶt /破/敗;競争に敗れる/
やぶr /破/敗;競争に敗れる/
やぶn /破/敗;競争に敗れる/
やぶk /破/
やぶi /破/
やぶc /破/敗;競争に敗れる/
やはr /柔/軟/和/矢張/
やはi /柔/
やにさg /脂下/
やどなs /宿無/
やどさがs /宿探/
やどかr /宿借/
やどt /宿/
やどs /宿/
やどr /宿/
やどn /宿/
やどc /宿/
やといいr /雇い入/
やとw /雇/傭;=雇う/
やとu /雇/傭;=雇う/
やとt /雇/傭;=雇う/
やとo /雇/傭;=雇う/
やとi /雇/傭;=雇う/
やとh /雇/傭/
やとe /雇/傭;=雇う/
やとc /雇/傭;=雇う/
やつざk /八つ裂/
やつあたr /八つ当/
やつs /窶/
やつr /窶/
やってのk /遣って退/
やっつk /遣っ付/
やっt /八/漸;-と(終わった)/
やせほそt /痩せ細/
やせほそr /痩せ細/
やせほそn /痩せ細/
やせほそc /痩せ細/
やせおとろe /痩せ衰/
やすものがi /安物買/
やすみあk /休み明/
やすすg /安過/
やすくにどおr /靖国通/
やすうけあi /安請け合/安請合/
やすうr /安売/
やすあがt /安上/
やすあがr /安上/
やすあがn /安上/
やすあがc /安上/
やすあg /安上/
やすu /安/易;(easy) 見易い画面/廉;(cheap) 廉い品/
やすs /安/易;(easy) 見易い画面/廉;(cheap) 廉い品/
やすr /安/
やすp /安/
やすn /休/安/
やすm /休/安/易;(easy) 見易い画面/廉;(cheap) 廉い品/
やすk /安/易;(easy) 見易い画面/廉;(cheap) 廉い品/
やすi /安/易;(easy) 見易い画面/廉;(cheap) 廉い品/
やすg /安/易;(easy) 見易い画面/廉;(cheap) 廉い品/
やじt /野次/
やじr /野次/
やじn /野次/
やじc /野次/
やしなw /養/豢;<rare>/
やしなu /養/豢;<rare>/
やしなt /養/豢;<rare>/
やしなo /養/豢;<rare>/
やしなi /養/豢;<rare>/
やしなh /養/
やしなe /養/豢;<rare>/
やしなc /養/豢;<rare>/
やさしi /優し;※送り位置補正/易し;※送り位置補正/
やさs /優;(gentle)優しい人/易;(easy)易しい問題/
やけのこt /焼け残/
やけのこr /焼け残/
やけのこn /焼け残/
やけのこc /焼け残/
やけただr /焼け爛/
やけしn /焼け死/
やけこg /焼け焦/
やけおt /焼け落/
やけおc /焼け落/
やぐらなg /櫓投/
やくわr /役割/
やくよk /厄除/
やくまわr /役回/
やくひんくさs /薬品臭/
やくひんくさk /薬品臭/
やくひんくさi /薬品臭/
やくひんくさg /薬品臭/
やくばらi /厄払/
やくはらi /厄祓/
やくはらh /厄祓/
やくにたt /役に立/
やくにたc /役に立/
やくづk /役付/
やくだt /役立/
やくだc /役立/
やくたt /役立/
やくそくどおr /約束通/
やくs /訳;(translate) 仏詩を訳す/約;(promise) 再会を約す/扼;(hold) 拠点を扼する/譯;「訳」の旧字/
やくn /役/
やきもどs /焼戻/焼き戻/
やきはらw /焼き払/
やきはらu /焼き払/
やきはらt /焼き払/
やきはらo /焼き払/
やきはらi /焼き払/
やきはらe /焼き払/
やきはらc /焼き払/
やきなまs /焼き鈍/焼鈍/
やきなおs /焼き直/焼直/
やきつくs /焼き尽;劫火が全てを-す/
やきつk /焼き付/焼き尽/焼付/
やきつi /焼き付/焼付/
やきすt /焼き捨/
やきすg /焼き過/
やきしm /焼き締/焼締/
やきころs /焼き殺/
やきこn /焼き込/
やきこm /焼き込/
やききt /焼き切/
やききr /焼き切/
やききn /焼き切/
やききc /焼き切/
やきいr /焼き入/焼入/
やきあg /焼き上/
やがt /軈/
やかまs /喧/
やうやu /漸/
やうやk /漸/
やt /遣;(do)仕事を遣る, (使役)人を遣る/演;(play)『リア王』を演る/殺;(kill)首相を殺る/八;-っつ/
やs /痩/瘠;≒痩せる/
やr /遣;(do)仕事を遣る, (使役)人を遣る/演;(play)『リア王』を演る/殺;(kill)首相を殺る/破;破れ障子/
やn /止/病/遣;(do)仕事を遣る, (使役)人を遣る/演;(play)『リア王』を演る/殺;(kill)首相を殺る/已;≒止む/熄;(字義:火が消える)/
やm /止/辞;仕事を辞める/病/已;≒止む/熄;(字義:火が消える)/罷/辭;「辞」の旧字/
やk /焼/妬;(嫉妬) やきもちを妬く/灼;灼けた砂浜/燒;「焼」の旧字(人名用漢字)/
やi /焼/妬;(嫉妬) やきもちを妬く/燒;「焼」の旧字(人名用漢字)/灼;灼けた砂浜/
やc /遣;(do)仕事を遣る, (使役)人を遣る/演;(play)『リア王』を演る/殺;(kill)首相を殺る/
もんなs /文無/
もんどりうt /翻筋斗打/
もんどりうc /翻筋斗打/
もんぜんばらi /門前払/
もんくなs /文句無/
もろもろn /諸/
もろs /脆/
もろk /脆/
もろi /脆/
もろg /脆/
もれだs /漏れ出/
もれきk /洩れ聞/漏れ聞/
もれきi /洩れ聞/漏れ聞/
もりつk /盛り付/
もりたt /守り立/
もりさg /盛り下/
もりこn /盛り込/
もりこm /盛り込/
もりかえs /盛り返/
もりあわs /盛合/
もりあがt /盛り上/
もりあがr /盛り上/
もりあがn /盛り上/
もりあがc /盛り上/
もりあw /盛り合/
もりあg /盛り上/盛上/
もりs /守/
もらいっぱなs /貰いっ放;いつも-しで/
もらいそこn /貰い損/
もらいうk /貰い受/
もらw /貰/
もらu /貰/
もらt /貰/
もらo /貰/
もらi /貰/
もらe /貰/
もらc /貰/
もよおs /催/
もようがe /模様替/
もよr /最寄/
もよi /催/
もやw /舫/
もやu /舫/
もやt /舫/
もやo /舫/
もやi /舫/
もやe /舫/
もやc /舫/
もみほぐs /揉み解/
もみつぶs /揉み潰/
もみだs /揉み出/
もみこn /揉み込/
もみこm /揉み込/
もみけs /揉み消/もみ消/
もみあw /揉み合/
もみあu /揉み合/
もみあt /揉み合/
もみあo /揉み合/
もみあi /揉み合/
もみあc /揉み合/
ものわびs /物侘/
ものわすr /物忘/
ものやわr /物柔/
ものものs /物々/物物/
ものもうs /物申/
ものもt /物持/
ものもc /物持/
ものめずらs /物珍/
ものみだかs /物見高/
ものみだかk /物見高/
ものみだかi /物見高/
ものみだかg /物見高/
ものほs /物干;-し竿/物欲;-しげな顔/
ものなr /物慣/
ものたr /物足/
ものずk /物好/
ものすごs /物凄/
ものすごk /物凄/
ものすごi /物凄/
ものすごg /物凄/
ものしずk /物静/
ものしr /物知/
ものさびs /物寂/物淋/
ものごi /物乞/
ものぐるo /物狂/
ものぐさs /懶/
ものぐさk /懶/
ものぐさi /懶/
ものぐさg /懶/
ものがなs /物悲/
ものがたt /物語/
ものがたr /物語/
ものがたn /物語/
ものがたc /物語/
ものかk /物書/
ものかi /物書/
ものおもi /物思/
ものおぼe /物覚/
ものおz /物怖/
ものおj /物怖/
ものうs /物憂/懶/
ものうk /物憂/懶/
ものうi /物憂/懶/
ものうg /物憂/懶/
ものいw /物言/
ものいu /物言/
ものいr /物入/
ものいi /物言/
ものいe /物言/
ものs /物;本を物す/
もぬk /蛻/
もどってこz /戻って来/
もどってこy /戻って来/
もどってこs /戻って来/
もどってこr /戻って来/
もどってこn /戻って来/
もどってこi /戻って来/
もどってくr /戻って来/
もどってくn /戻って来/
もどってきy /戻って来/
もどってきt /戻って来/
もどってきs /戻って来/
もどってきn /戻って来/
もどってきm /戻って来/
もどってきd /戻って来/
もどってきc /戻って来/
もどt /戻/
もどs /戻/
もどr /戻/
もどn /戻/
もどk /擬/
もどc /戻/
もとめあw /求め合/
もとめあu /求め合/
もとめあt /求め合/
もとめあo /求め合/
もとめあi /求め合/
もとめあe /求め合/
もとめあc /求め合/
もとどおr /元通/
もとづk /基/
もとづi /基/
もとうr /元売/
もとz /基;?/
もとt /悖/戻;=悖る/基;base.「実体験を-にする」/
もとr /悖/戻;=悖る/
もとn /元/基/悖/戻;=悖る/求/許;手の届く範囲。「親の-」/下;≒許 「白日の-」/
もとm /求/
もとk /元/
もとh /許;手の届く範囲。「親の-」/
もとd /基;-づく/下;-で/元/許;手の届く範囲。「親の-」/
もとc /悖/戻;=悖る/
もてはやs /持て囃/持て栄/
もてなs /持て成/
もてあまs /持て余/
もてあそn /弄/玩;=弄ぶ/翫;=弄ぶ/
もてあそb /弄/玩;=弄ぶ/翫;=弄ぶ/
もつれこn /縺れ込/
もつれこm /縺れ込/
もつれあw /縺れ合/
もつれあu /縺れ合/
もつれあt /縺れ合/
もつれあo /縺れ合/
もつれあi /縺れ合/
もつれあe /縺れ合/
もつれあc /縺れ合/
もつr /縺/
もっぱr /専/專;「専」の旧字(人名用漢字)/
もっとm /最;(most)/尤;(reasonable)「それも-もだ」 (接続詞)「-も、異論もある」/
もってまわt /持って回/
もってまわr /持って回/
もってまわn /持って回/
もってまわc /持って回/
もってこz /持って来/
もってこy /持って来/
もってこs /持って来/
もってこr /持って来/
もってこn /持って来/
もってこi /持って来/
もってくr /持って来/
もってくn /持って来/
もってきy /持って来/
もってきt /持って来/
もってきs /持って来/
もってきn /持って来/
もってきm /持って来/
もってきd /持って来/
もってきc /持って来/
もってかえt /持って帰/
もってかえr /持って帰/
もってかえn /持って帰/
もってかえc /持って帰/
もっていt /持って行/
もっていk /持って行/
もっていc /持って行/
もったいぶt /勿体振/
もったいぶr /勿体振/
もったいぶn /勿体振/
もったいぶc /勿体振/
もったいなs /勿体無/
もったいなk /勿体無/
もったいなi /勿体無/
もったいなg /勿体無/
もっt /以/
もぢr /捩/
もちよt /持ち寄/
もちよr /持ち寄/
もちよn /持ち寄/
もちよc /持ち寄/
もちまわt /持ち回/持回/
もちまわr /持ち回/持回/
もちまわn /持ち回/持回/
もちまわc /持ち回/持回/
もちはこn /持ち運/
もちはこb /持ち運/
もちにg /持逃/持ち逃/
もちなおs /持ち直/
もちつづk /持ち続/
もちだs /持ち出/持出/
もちさt /持ち去/
もちさr /持ち去/
もちさn /持ち去/
もちさc /持ち去/
もちこたe /持ち堪/
もちこs /持ち越/持越/
もちこn /持ち込/持込/
もちこm /持ち込/持込/
もちぐさr /持ち腐/
もちくずs /持ち崩/
もちきr /持ち切/
もちかえt /持ち帰/
もちかえr /持ち帰/
もちかえn /持ち帰/
もちかえc /持ち帰/
もちかk /持ち掛/
もちかe /持ち替/
もちいt /用い;※送り位置補正/
もちあわs /持ち合/持合/
もちあるk /持ち歩/
もちあるi /持ち歩/
もちあw /持ち合/
もちあu /持ち合/
もちあt /持ち合/
もちあo /持ち合/
もちあi /持ち合/持合/
もちあg /持ち上/
もちあc /持ち合/
もちw /用;-ゐる/
もちi /用/
もだs /黙/
もだe /悶/
もたれあw /凭れ合/
もたれあu /凭れ合/
もたれあt /凭れ合/
もたれあo /凭れ合/
もたれあi /凭れ合/
もたれあe /凭れ合/
もたれあc /凭れ合/
もたらs /齎/
もたr /凭/靠;≒凭れる/
もたg /擡/
もじまちがi /文字間違/
もじばk /文字化/
もじどおr /文字通/
もじおt /文字落/
もじt /捩/
もじr /捩/
もじn /捩/
もじc /捩/
もしm /若し;※送り位置補正/
もしk /若し;※送り位置補正/
もぐりこn /潜り込/
もぐりこm /潜り込/
もぐt /潜/潛;旧字1/濳;旧字2/
もぐr /潜/潛;旧字1/濳;旧字2/
もぐn /潜/潛;旧字1/濳;旧字2/
もぐc /潜/潛;旧字1/濳;旧字2/
もくろn /目論/
もくろm /目論/
もくs /黙/目/
もぎとt /もぎ取/
もぎとr /もぎ取/
もぎとn /もぎ取/
もぎとc /もぎ取/
もがr /虎落/強請/
もがk /藻掻/
もがi /藻掻/
もえひろg /燃え広/
もえでz /萌え出/
もえでy /萌え出/
もえでt /萌え出/
もえでs /萌え出/
もえでr /萌え出/
もえでn /萌え出/
もえでm /萌え出/
もえでc /萌え出/
もえつk /燃え尽/
もえだs /燃え出/萌え出/
もえたぎt /燃え滾/
もえたぎr /燃え滾/
もえたぎn /燃え滾/
もえたぎc /燃え滾/
もえたt /燃え立/萌え立;萌え立つ緑/
もえたc /燃え立/萌え立;萌え立つ緑/
もえさかt /燃え盛/
もえさかr /燃え盛/
もえさかn /燃え盛/
もえさかc /燃え盛/
もえうつt /燃え移/
もえうつr /燃え移/
もえうつn /燃え移/
もえうつc /燃え移/
もえいd /萌え出/
もえあg /燃え上/
もうしわたs /申し渡/
もうしわけなs /申し訳無/
もうしわけなk /申し訳無/
もうしわけなi /申し訳無/
もうしわk /申し分/
もうしぶんなs /申し分無/
もうしぶんなk /申し分無/
もうしぶんなi /申し分無/
もうしひらk /申し開/
もうしひらi /申し開/
もうしのb /申し述/
もうしでz /申し出/
もうしでy /申し出/
もうしでt /申し出/
もうしでs /申し出/
もうしでr /申し出/
もうしでn /申し出/
もうしでm /申し出/
もうしでc /申し出/
もうしつたe /申し伝/申伝/
もうしつk /申し付/
もうしたt /申し立/申立/
もうしそe /申し添/
もうしこs /申し越/
もうしこn /申し込/申込/
もうしこm /申し込/申込/
もうしかn /申し兼/
もうしおくt /申し送;-り事項/申送/
もうしおくr /申し遅;-れました/申し送;-り事項/申送/
もうしおくn /申し送;-り事項/申送/
もうしおくc /申し送;-り事項/申送/
もうしうk /申し受/
もうしいr /申し入/申入/
もうしあわs /申し合/
もうしあw /申し合/
もうしあg /申し上/
もうs /申/
もうk /設/儲/
もうd /詣/
もy /燃/萌/萠;「萌」の異体字(人名用漢字)/
もt /持/盛/以/保;(維持) 体が保たない NB:「たもt」と同形/漏;(字義:雨がもれる)/洩;(字義:尾を引いて少しずつもれる)/
もs /若/燃/模/
もr /盛/漏;(字義:雨がもれる)/洩;(字義:尾を引いて少しずつもれる)/守;子-り/
もn /揉/盛/漏;(字義:雨がもれる)/洩;(字義:尾を引いて少しずつもれる)/
もm /揉/
もe /燃/萌;(sprout) 芽が萌える/萠;「萌」の異体字(人名用漢字)/
もc /持/保;(維持) 体が保たない NB:「たもt」と同形/盛/漏;(字義:雨がもれる)/洩;(字義:尾を引いて少しずつもれる)/
めんぼくなs /面目無/
めんぼくなk /面目無/
めんぼくなi /面目無/
めんばs /面罵/
めんどくさs /面倒臭/
めんどくさk /面倒臭/
めんどくさi /面倒臭/
めんどくさg /面倒臭/
めんどうくさs /面倒臭/
めんどうくさk /面倒臭/
めんどうくさi /面倒臭/
めんどうくさg /面倒臭/
めんくらw /面喰/
めんくらu /面喰/
めんくらt /面喰/
めんくらo /面喰/
めんくらi /面喰/
めんくらe /面喰/
めんくらc /面喰/
めんくr /面喰/面食/
めんくi /面食/
めんきょとr /免許取/
めんz /免/
めんs /面/
めんj /免/
めりこn /めり込/減り込/
めりこm /減り込/めり込/
めもt /メモ/
めもr /メモ/
めもn /メモ/
めもc /メモ/
めめs /女々/女女/
めまぐるs /目紛/
めべr /目減/
めぶk /芽吹/
めぶi /芽吹/
めばr /目張/
めばe /芽生/
めぬきどおr /目抜き通/
めぬk /目抜/
めどおs /目通/
めとt /娶/
めとr /娶/
めとn /娶/
めとc /娶/
めでたs /目出度/
めでたk /目出度/
めでたi /目出度/
めでたg /目出度/
めでt /目出/
めづらs /珍;旧仮名/珎;旧仮名,「珍」の異体字/
めづm /目詰/
めつk /目付/眼付/
めったうt /滅多打;(当て字)/メッタ打/
めったn /滅多;(当て字)/
めっs /滅/
めだt /目立/
めだc /目立/
めずらs /珍/珎;「珍」の異体字/
めじろどおr /目白通/
めじろおs /目白押/
めしはなt /召し放/
めしはなc /召し放/
めしとt /召し捕;捕縛する/召し取;[文語]呼び寄せる/
めしとr /召し捕;捕縛する/召し取;[文語]呼び寄せる/
めしとn /召し捕;捕縛する/召し取;[文語]呼び寄せる/
めしとc /召し捕;捕縛する/召し取;[文語]呼び寄せる/
めしつかw /召し使/
めしつかu /召し使/
めしつかt /召し使/
めしつかo /召し使/
めしつかi /召し使/
めしつかe /召し使/
めしつかc /召し使/
めしだs /召し出/
めしかかe /召し抱/
めしいr /召し入/
めしあg /召し上/
めしi /盲/
めざわr /目障/
めざまs /目覚/
めざとs /目敏/
めざとk /目敏/
めざとi /目敏/
めざとg /目敏/
めざs /目指/目刺;メザシ/
めざm /目覚/目醒/
めぐろどおr /目黒通/
めぐりめぐt /巡り巡/
めぐりあw /巡り合;-わせ/巡り会/回り合/巡り逢/
めぐりあu /巡り会/巡り合/巡り逢/
めぐりあt /巡り会/巡り合/巡り逢/
めぐりあo /巡り会/巡り合/巡り逢/
めぐりあi /巡り会/巡り合/巡り逢/
めぐりあe /巡り会/巡り合/巡り逢/
めぐりあc /巡り会/巡り合/巡り逢/
めぐt /巡/廻/回/繞/繚/
めぐs /愛;[文語]「-し乙女舞い出でつ」/
めぐr /巡/廻/回/繞/繚/
めぐn /恵/惠;「恵」の旧字(人名用漢字)/巡/廻/回/繞/繚/萌;(芽生える) =芽ぐむ/
めぐm /恵/萌;(芽生える) =芽ぐむ/惠;「恵」の旧字(人名用漢字)/
めぐk /愛;[文語]「-し乙女舞い出でつ」/
めぐc /巡/廻/回/繞/繚/
めくれあg /捲れ上/
めくるめk /目眩/
めくるめi /目眩/
めくらまs /目眩/
めくらうt /盲打/
めくらm /目眩/
めくばs /目配/
めくばr /目配/
めくt /捲/
めくr /捲/
めくn /捲/
めくc /捲/
めきk /目利/
めがk /目掛/
めかしこn /粧し込/
めかしこm /粧し込/
めかくs /目隠/
めかs /粧;お粧し/
めおs /目押/
めうつr /目移/
めいわくかk /迷惑掛/
めいじどおr /明治通/
めいきゅういr /迷宮入/
めいうt /銘打/
めいうc /銘打/
めいz /命;(order) 出張を命ずる/銘;(inscript) 肝に銘ずる/
めいt /滅入/
めいs /瞑;以て瞑すべし(=安心して死になさい)/
めいr /滅入/
めいn /滅入/
めいj /命;(order)/銘;(inscript) 肝に銘じる/
めいc /滅入/
めあわs /娶/
めあたらs /目新/
めあw /妻合/
めあt /目当/
めあk /目明/
めs /召/
めr /減/
めn /目/
めg /芽/
めd /愛/賞/目/
めb /目/
むりじi /無理強/
むりp /無理/
むりn /無理/
むらなk /ムラ無/
むらg /群/叢/簇/
むねんg /無念/
むねやk /胸焼/
むねあg /棟上/
むにきs /無に帰/
むなさわg /胸騒/
むなs /虚/空/
むとどk /無届/
むづかt /憤;旧仮名/
むづかs /難/
むづかr /憤/
むづかn /憤;旧仮名/
むづかc /憤;旧仮名/
むつみあw /睦み合/
むつみあu /睦み合/
むつみあt /睦み合/
むつみあo /睦み合/
むつみあi /睦み合/
むつみあc /睦み合/
むつかs /難/
むつn /睦/
むつm /睦/
むつb /睦/
むっt /六/
むちうt /鞭打/鞭/
むちうc /鞭打/鞭/
むだなk /無駄無/
むだづかi /無駄遣/無駄使/
むだn /無駄/
むだd /無駄/
むせびなk /咽び泣/噎び泣/
むせびなi /咽び泣/噎び泣/
むせかえt /噎せ返/噎返/蒸返/
むせかえr /噎せ返/噎返/
むせかえn /噎せ返/噎返/蒸返/
むせかえc /噎せ返/噎返/蒸返/
むせp /咽/
むせn /咽/噎/
むせb /咽/噎/
むずがゆs /むず痒/
むずがゆk /むず痒/
むずがゆi /むず痒/
むずがゆg /むず痒/
むずかt /憤/
むずかs /難/
むずかr /憤/
むずかn /憤/
むずかc /憤/
むすびなおs /結び直/
むすびつk /結び付/
むすびつi /結び付/
むすn /結/掬;(手ですくう)「水を掬ぶ」/
むすb /結/掬;(手ですくう)「水を掬ぶ」/
むしりとt /毟り取/
むしりとr /毟り取/
むしりとn /毟り取/
むしりとc /毟り取/
むしよk /虫除/
むしゃぶりつk /武者振り付/
むしゃぶりつi /武者振り付/
むしゃぶr /武者振/
むしぼs /虫干/
むしふうj /虫封/
むしばn /蝕/蠹/蠧;「蠹」の異体字/
むしばm /蝕/蠹/蠧;「蠹」の異体字/
むしとr /虫取/
むしくi /虫食/
むしかえs /蒸し返/
むしあつs /蒸し暑/
むしあつk /蒸し暑/
むしあつi /蒸し暑/
むしあつg /蒸し暑/
むしt /毟;毛羽を-/
むしs /無視/
むしr /寧;(rather) -ろ/毟;毛羽を-/
むしn /毟;毛羽を-/
むしc /毟;毛羽を-/
むさぼりよn /貪り読/
むさぼりよm /貪り読/
むさぼりくw /貪り食/貪り喰/
むさぼりくu /貪り食/貪り喰/
むさぼりくt /貪り食/貪り喰/
むさぼりくo /貪り食/貪り喰/
むさぼりくi /貪り食/貪り喰/
むさぼりくe /貪り食/貪り喰/
むさぼりくc /貪り食/貪り喰/
むさぼt /貪/
むさぼr /貪/
むさぼn /貪/
むさぼc /貪/
むさくるs /むさ苦/
むごt /惨/酷/
むごs /惨/酷;NB:「ひどi」と同形/
むごk /惨/酷;NB:「ひどi」と同形/
むごi /惨/酷;NB:「ひどi」と同形/
むごg /惨/酷;NB:「ひどi」と同形/
むこu /向/向こ;※送り位置補正/
むけなおs /向け直/
むくw /報/酬/
むくu /報/酬/
むくt /報/酬/
むくr /剥/
むくo /報/酬/
むくn /浮腫/
むくm /浮腫/
むくi /報;(原義:罪人への罰)/酬;(原義:酒を勧める)/
むくe /報/酬/
むくc /報/酬/
むきなおt /向き直/
むきなおr /向き直/
むきなおn /向き直/
むきなおc /向き直/
むきとt /剥き取/
むきとr /剥き取/
むきとn /剥き取/
むきとc /剥き取/
むきだs /剥き出/
むきあw /向き合/
むきあu /向き合/
むきあt /向き合/
むきあo /向き合/
むきあi /向き合/
むきあe /向き合/
むきあc /向き合/
むかしなつk /昔懐/
むかしきk /昔聞/
むかしきi /昔聞/
むかえとt /迎え取/
むかえとr /迎え取/
むかえとn /迎え取/
むかえとc /迎え取/
むかえうt /迎え撃/
むかえうc /迎え撃/
むかえいr /迎え入/
むかいあw /向かい合/向い合/
むかいあu /向かい合/向い合/
むかいあt /向かい合/向い合/
むかいあo /向かい合/向い合/
むかいあi /向かい合/向い合/
むかいあe /向かい合/向い合/
むかいあc /向かい合/向い合/
むかw /向/対/
むかu /向/対/
むかt /向/対/
むかo /向/対/
むかi /向/向か;※送り位置補正/対/
むかh /迎/対/邀/
むかe /迎/邀;<rare>(待ち受ける)/向/対/
むかc /向/対/
むt /六/
むs /蒸/咽;煙に咽せる/噎;=咽せる/
むr /群/蒸/
むk /向/剥/
むi /向/剥/
みわたs /見渡/
みわすr /見忘/
みわk /見分/
みれんt /未練/
みれんg /未練/
みよr /身寄/
みょうs /妙/
みょうn /妙/
みょうd /妙/
みやまいr /宮参/
みやぶt /見破/
みやぶr /見破/
みやぶn /見破/
みやぶc /見破/
みやびy /雅/
みやびs /雅/
みやびn /雅/
みやびd /雅/
みやづかe /宮仕/
みやすs /見易/
みやすk /見易/
みやすi /見易/
みやすg /見易/
みやこおt /都落/
みやt /見遣/
みやr /見遣/
みやn /見遣/
みやc /見遣/
みやb /雅/
みゃくうt /脈打/脈搏/
みゃくうc /脈打/脈搏/
みもだe /身悶/
みもt /身持/
みめよs /見目好/
みめよk /見目好/
みめよi /見目好/
みめよg /見目好/
みめうるわs /見目麗/
みむk /見向/
みむi /見向/
みみよr /耳寄/
みみなr /耳慣;-れない/耳鳴;-り/耳馴;≒耳慣れない/
みみざわr /耳障/
みみざとs /耳聡/
みみざとk /耳聡/
みみざとi /耳聡/
みみざとg /耳聡/
みみかk /耳掻/
みみうt /耳打/
みみあたらs /耳新/
みまわt /見回/
みまわs /見回/
みまわr /見回/
みまわn /見回/
みまわc /見回/
みまもt /見守/
みまもr /見守/
みまもn /見守/
みまもc /見守/
みまちがw /見間違/
みまちがu /見間違/
みまちがt /見間違/
みまちがo /見間違/
みまちがi /見間違/
みまちがe /見間違/
みまちがc /見間違/
みまがw /見紛/
みまがu /見紛/
みまがt /見紛/
みまがo /見紛/
みまがi /見紛/
みまがe /見紛/
みまがc /見紛/
みまかt /身罷/薨/
みまかr /身罷/薨/
みまかn /身罷/薨/
みまかc /身罷/薨/
みまw /見舞/
みまu /見舞/
みまt /見舞/
みまo /見舞/
みまi /見舞/
みまh /見舞/
みまe /見舞/
みまc /見舞/
みぶるi /身震/
みぶr /身振/
みひらk /見開/
みひらi /見開/
みばe /見栄/見映/
みはるk /見霽/
みはらs /見晴/
みはらi /未払/
みはなs /見放/
みはっt /見張/
みはじm /見始/観始/
みはからi /見計/
みはかr /見計/
みはt /見張;-って/見果;-てぬ夢/瞠;目を瞠る妙技/
みはr /見張;-り番/見晴;-らし/瞠;目を瞠る妙技/
みはn /見張;-り番/瞠;目を瞠る妙技/
みはc /見張;-り番/瞠;目を瞠る妙技/
みのまわr /身の回/
みのこs /見残/
みのがs /見逃/
みのt /実/稔;(esp.穀物) 稲穂が稔る/
みのr /実/稔;(esp.穀物) 稲穂が稔る/
みのn /実/稔;(esp.穀物) 稲穂が稔る/
みのg /見逃/
みのc /実/稔;(esp.穀物) 稲穂が稔る/
みねうt /峰打/
みぬk /見抜/
みぬi /見抜/
みにつk /身に付/
みにつi /身に付/
みにくs /醜;(ugly) 醜い根性/見難;(hard to see) 見難い表示/儖;<rare> ≒醜い/
みにくk /醜;(ugly) 醜い根性/見難;(hard to see) 見難い表示/儖;<rare> ≒醜い/
みにくi /醜;(ugly) 醜い根性/見難;(hard to see) 見難い表示/儖;<rare> ≒醜い/
みにくg /醜;(ugly) 醜い根性/見難;(hard to see) 見難い表示/儖;<rare> ≒醜い/
みにいt /見に行/
みにいk /見に行/
みにいc /見に行/
みならw /見習/見倣/
みならu /見習/見倣/
みならt /見習/見倣/
みならo /見習/見倣/
みならi /見習/見倣/
みならe /見習/見倣/
みならc /見習/見倣/
みなみむk /南向/
みなごろs /皆殺/
みなぎt /漲/
みなぎr /漲/
みなぎn /漲/
みなぎc /漲/
みなおなz /皆同/
みなおなj /皆同/
みなおs /見直/
みなs /見做/看做/皆;-さん/
みなr /見慣/見馴/
みなg /身投/
みとめがたs /認め難/
みとめがたk /認め難/
みとめがたi /認め難/
みとめがたg /認め難/
みとめあw /認め合/
みとめあu /認め合/
みとめあt /認め合/
みとめあo /認め合/
みとめあi /認め合/
みとめあe /認め合/
みとめあc /認め合/
みとどk /見届/
みとがm /見咎/
みとおs /見通/
みとうs /見透/見通;※仮名遣い「みとお-す」/
みとt /看取;最期を看取る/見取;見取り図/
みとr /看取;最期を看取る/見惚;-れる/見取;見取り図/見蕩;≒見惚れる/
みとn /看取;最期を看取る/見取;見取り図/
みとm /認/
みとc /看取;最期を看取る/見取;見取り図/
みてとt /見て取/
みてとr /見て取/
みてとn /見て取/
みてとc /見て取/
みてこz /見て来/
みてこy /見て来/
みてこs /見て来/
みてこr /見て来/
みてこn /見て来/
みてこi /見て来/
みてくr /見て来/見て呉/
みてくn /見て来/
みてきy /見て来/
みてきt /見て来/
みてきs /見て来/
みてきn /見て来/
みてきm /見て来/
みてきd /見て来/
みてきc /見て来/
みていt /見て行/
みていk /見て行/
みていc /見て行/
みづらs /見辛/
みづらk /見辛/
みづらi /見辛/
みづらg /見辛/
みづくろi /身繕/
みづかr /自/
みつもt /見積/
みつもr /見積/
みつもn /見積/
みつもc /見積/
みつめなおs /見つめ直/見詰め直/
みつめあw /見つめ合/見詰め合/
みつめあu /見つめ合/見詰め合/
みつめあt /見つめ合/見詰め合/
みつめあo /見つめ合/見詰め合/
みつめあi /見つめ合/見詰め合/
みつめあe /見つめ合/見詰め合/
みつめあc /見つめ合/見詰め合/
みつづk /見続/
みつぞろi /三つ揃/
みつけだs /見つけ出/見付け出/
みつくろw /見繕/
みつくろu /見繕/
みつくろt /見繕/
みつくろo /見繕/
みつくろi /見繕/
みつくろh /見繕/
みつくろe /見繕/
みつくろc /見繕/
みつくs /見尽/
みつかr /見付か;※送り位置補正/
みつs /密/
みつn /密/
みつm /見積;-もる/見詰;-める/凝視;当て字,=見詰める/瞶;=見詰める/
みつk /見付/
みつi /貢/
みつg /貢/
みつd /密/
みっt /三/
みぢかn /身近/
みちゆk /道行/
みちむk /道向/
みちみt /満ち満;(夢と希望に)-ちて/
みちびきだs /導き出/
みちびk /導/
みちびi /導/
みちづr /道連/
みちたr /満ち足/
みちがw /見違/
みちがu /見違/
みちがt /見違/
みちがo /見違/
みちがi /見違/
みちがe /見違/
みちがc /見違/
みちあふr /満ち溢/
みだれとn /乱れ飛/
みだれとb /乱れ飛/
みだれうt /乱れ打/
みだしなm /身嗜/
みだs /乱/見出/紊;≒乱す 「風紀を紊す」/亂;「乱」の旧字/
みだr /乱/淫;-ら/猥;-ら,-りに/妄;-りに/濫;-りに/紊;風紀の紊れ/亂;「乱」の旧字/
みたt /見立/
みたs /満/充/
みそんj /見損/
みそづk /味噌漬/
みそこn /見損/
みそいたm /味噌炒/
みそr /見逸/
みそm /見初/
みそi /禊/
みそg /禊/
みせびらk /店開/
みせつk /見せ付/
みせじまi /店仕舞/
みせがまe /店構/
みせかk /見せ掛/
みせあw /見せ合/
みせあu /見せ合/
みせあt /見せ合/
みせあo /見せ合/
みせあi /見せ合/
みせあe /見せ合/
みせあc /見せ合/
みずわr /水割/
みずもr /水漏/
みずみずs /瑞々/瑞瑞/水々;=瑞々しい/水水/
みずまわr /水回/
みずまs /水増/
みずまk /水撒/
みずぶとr /水太/
みずびたs /水浸/
みずはk /水捌/
みずだs /水出/
みずたまr /水溜/
みずたk /水炊/
みずぜm /水攻;城の水攻め/水責;拷問./
みずくさs /水臭/
みずくさk /水臭/
みずくさi /水臭/
みずくさg /水臭/
みずきr /水切/
みずがr /水涸/
みずかr /自/
みずいr /水入/
みずあらi /水洗/
みずあそb /水遊/
みずあかとr /水垢取/
みずあg /水揚/
みずあb /水浴/
みずp /水/
みすぼr /見窄/
みすごs /見過/
みすかs /見透/
みすt /見捨/見棄/ミス;[口]-って/
みすr /ミス/
みすn /ミス/
みすk /見透/
みすg /見過/
みすe /見据/視据;<rare>/
みすc /ミス/
みじんぎr /微塵切/
みじろi /身動/
みじろg /身動/
みじかすg /短過/
みじかs /短/身近/
みじかn /身近/
みじかm /短/
みじかk /短/身近/
みじかi /短/身近/
みじかg /短/身近/
みじm /惨/慘;「惨」の旧字/
みじk /短;非正則(みじかi)/
みしりおk /見知り置;お-きを/
みしりおi /見知り置;お-きを/
みしt /見知/
みしr /見知/
みしn /見知/
みしc /見知/
みさだm /見定/
みさげはt /見下げ果/
みさg /見下/
みごろs /見殺/
みごもt /身籠/妊/
みごもr /身籠/妊/
みごもn /身籠/妊/
みごもc /身籠/妊/
みごたe /見応/
みごしらe /身拵/
みこs /見越/
みこn /見込/
みこm /見込/
みぐるs /見苦/
みくらb /見比/見較/
みくだs /見下/
みぎまわr /右回/
みぎどなr /右隣/
みぎぞろe /右揃/
みぎそろe /右揃/
みぎきk /右利/
みぎがk /右書/
みぎs /右/
みきわm /見極/
みきt /見切/
みきr /見切/
みきn /見切/
みきk /見聞/
みきc /見切/
みがわr /身代/
みがまe /身構/
みがたm /身固/
みがきぬk /磨き抜/
みがきぬi /磨き抜/
みがきたt /磨き立/
みがきあg /磨き上/
みがk /磨/研;(技を)-く/
みがi /磨/研;(技を)-く/
みかわs /見交/
みかぎt /見限/
みかぎr /見限/
みかぎn /見限/
みかぎc /見限/
みかえt /見返/
みかえs /見返/
みかえr /見返/
みかえn /見返/
みかえc /見返/
みかw /見交/
みかn /見兼/
みかk /見掛/
みおわt /見終/
みおわr /見終/
みおわn /見終/
みおわc /見終/
みおぼe /見覚/
みおとs /見落/
みおとr /見劣/
みおくt /見送/
みおくr /見送/
みおくn /見送/
みおくc /見送/
みおw /見終/
みおt /見落/
みおr /見下/
みおe /見終/観終/
みえみe /見え見/
みえっぱr /見栄っ張/
みえすk /見え透/
みえすi /見え透/
みえかくr /見え隠/
みうしなw /見失/
みうしなu /見失/
みうしなt /見失/
みうしなo /見失/
みうしなi /見失/
みうしなe /見失/
みうしなc /見失/
みうごk /身動/
みうr /身売/
みうk /見受/
みいだs /見出/
みいt /見入;(gaze) 思わず見入る/魅入;(charm,主に受け身で) 音楽に魅入られる/
みいr /見入;(gaze) 思わず見入る/魅入;(charm,主に受け身で) 音楽に魅入られる/実入;(income) 実入りが少ない/
みいn /見入;(gaze) 思わず見入る/魅入;(charm,主に受け身で) 音楽に魅入られる/
みいc /見入;(gaze) 思わず見入る/魅入;(charm,主に受け身で) 音楽に魅入られる/
みあわs /見合/
みあやまt /見誤/
みあやまr /見誤/
みあやまn /見誤/
みあやまc /見誤/
みあたt /見当/
みあたr /見当/
みあたn /見当/
みあたc /見当/
みあw /見合/
みあu /見合/
みあt /見当/見合/
みあo /見合/
みあk /見飽/
みあi /見合/
みあg /見上/
みあe /見合/
みあc /見合/
みz /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みy /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みw /見/身/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みu /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みt /満;(字義:容器を一杯にする)/充;(字義:肉付きが良い)/見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/盈;(≒満ちる) 月盈つれば欠く/三/滿;旧字/觀;「観」の旧字/
みs /見/魅;(attract)/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みr /見/観;(字義:みわたす)/視;(字義:じっとみる)/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みp /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みo /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みn /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/看;(nurse) 病母を看る/身/診;(diagnose) 患者を診る/觀;「観」の旧字/
みm /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みk /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みj /身/見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みi /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みh /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みg /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みe /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みd /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みc /見/満/滿;旧字/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みb /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
みa /見/観;(字義:みわたす) 映画を-/視;(字義:じっとみる) TVを-/診;(diagnose) 患者を診る/看;(nurse) 病母を看る/觀;「観」の旧字/
まんまるs /真ん丸/
まんまるn /真ん丸/
まんまるk /真ん丸/
まんまるi /真ん丸/
まんまるd /真ん丸/
まんがかk /漫画描/
まんz /慢/
まんj /慢/
まゐr /參/
まわりもt /回り持/
まわりまわt /回り回/
まわりこn /回り込/
まわりこm /回り込/
まわしいr /回し入/
まわt /回/廻/周;(取り巻いて)「家の周り」/囘;「回」の旧字/巡;NB:「めぐr」と同形/
まわs /回/廻/周/囘;「回」の旧字/
まわr /回/周;(取り巻いて)「家の周り」/廻/巡;NB:「めぐr」と同形/囘;「回」の旧字/
まわn /回/周;(取り巻いて)「家の周り」/廻/巡;NB:「めぐr」と同形/囘;「回」の旧字/
まわc /回/周;(取り巻いて)「家の周り」/廻/巡;NB:「めぐr」と同形/囘;「回」の旧字/
まろy /円/
まろn /転/
まろm /円;-み/丸;-み/
まろb /転/
まれs /稀/希/
まれn /稀/希/
まれd /稀/希/
まるやk /丸焼/
まるもうk /丸儲/
まるめこn /丸め込/
まるめこm /丸め込/
まるみe /丸見/
まるなg /丸投/
まるだs /丸出/
まるがかe /丸抱/
まるがr /丸刈/
まるかじr /丸齧/
まるうつs /丸写/
まるあらi /丸洗/
まるs /丸/円/圓;「円」の旧字(人名用漢字)/槫;<rare>/
まるm /丸/円/圓;「円」の旧字(人名用漢字)/槫;<rare>/
まるk /丸/円/圓;「円」の旧字(人名用漢字)/槫;<rare>/
まるi /丸/円/圓;「円」の旧字(人名用漢字)/槫;<rare>/
まよいこn /迷い込/
まよいこm /迷い込/
まよw /迷/
まよu /迷/紕;広辞苑に掲載されています/
まよt /迷/
まよo /迷/
まよk /魔除/
まよi /迷/
まよh /迷/
まよe /迷/
まよc /迷/
まやかs /瞞/
まもりぬk /守り抜/
まもりぬi /守り抜/
まもりとおs /守り通/
まもりつづk /守り続/
まもなs /間も無/
まもなk /間も無/
まもなi /間も無/
まもなg /間も無/
まもt /守;(字義:取られぬようまもる)/護;(字義:傷付かぬようまもる)/防;<rare>(字義:来るものを抑える)/
まもr /守;(字義:取られぬようまもる)/護;(字義:傷付かぬようまもる)/防;<rare>(字義:来るものを抑える)/
まもn /守;(字義:取られぬようまもる)/護;(字義:傷付かぬようまもる)/防;<rare>(字義:来るものを抑える)/
まもc /守;(字義:取られぬようまもる)/護;(字義:傷付かぬようまもる)/防;<rare>(字義:来るものを抑える)/
まめy /忠実;忠実やかな/
まむk /真向/
まみr /塗/
まみe /見/
ままn /儘/
まほうつかi /魔法使/
まぶs /眩/塗/
まびk /間引/
まびi /間引/
まばらs /疎/
まばらn /疎/
まばらd /疎/
まばゆs /目映/眩/
まばゆk /目映/眩/
まばゆi /目映/眩/
まばゆg /目映/眩/
まばたk /瞬/
まばたi /瞬/
まばr /疎/
まはs /回/廻/
まのあt /目の当/
まのb /間延/
まねきよs /招き寄/
まねきいr /招き入/
まねz /真似/
まねy /真似/
まねt /真似/
まねs /真似/
まねr /真似/
まねn /真似/
まねm /真似/
まねk /招/真似/
まねi /招/
まねc /真似/
まねb /学/
まねa /真似/
まぬがr /免/
まぬかr /免/
まぬk /間抜/
まにうk /真に受/
まにあわs /間に合/
まにあw /間に合/
まにあu /間に合/
まにあt /間に合/
まにあo /間に合/
まにあi /間に合/
まにあe /間に合/
まにあc /間に合/
まなざs /眼差/目差/
まなn /学/學;「学」の旧字/斈;「学」の異体字/
まなb /学/學;「学」の旧字/斈;「学」の異体字/
まどろn /微睡/
まどろm /微睡/
まどがk /窓掛/
まどかk /窓掛/
まどw /惑/悗;<rare> 現を抜かす/
まどu /惑/悗;<rare> 現を抜かす/
まどt /惑/悗;<rare> 現を抜かす/
まどr /間取/
まどo /惑/悗;<rare> 現を抜かす/
まどk /円/
まどi /惑/悗;<rare> 現を抜かす/
まどh /惑/
まどe /惑/悗;<rare> 現を抜かす/
まどc /惑/悗;<rare> 現を抜かす/
まとわりつk /纏わり付/
まとわりつi /纏わり付/
まとめがi /まとめ買/
まとはずr /的外/
まといつk /纏い付/
まといつi /纏い付/
まとw /纏/繚;<rare>/
まとu /纏/繚;<rare>/
まとt /纏/繚;<rare>/
まとo /纏/繚;<rare>/
まとm /纏/纒;異体字/
まとi /纏/繚;<rare>/
まとh /纏/
まとe /纏/繚;<rare>/
まとc /纏/繚;<rare>/
まづs /不味/
まづk /不味/
まづi /不味/
まづg /不味/
まつりあg /祭り上/
まつまえづk /松前漬/
まつかざr /松飾/
まつw /纏/
まつt /祭/奉;(謙譲) NB:「たてまつr」と同形/祀;(worship) 先祖を祀る/纏;纏り縫い/
まつr /祭/祀;(worship) 先祖を祀る/奉;(謙譲) NB:「たてまつr」と同形/纏;纏り縫い/
まつn /祭/祀;(worship) 先祖を祀る/奉;(謙譲) NB:「たてまつr」と同形/纏;纏り縫い/
まつh /纏/
まつc /祭/祀;(worship) 先祖を祀る/奉;(謙譲) NB:「たてまつr」と同形/纏;纏り縫い/
まっぷたt /真っ二/
まっとu /全/
まったいr /真っ平/
まったs /全/
まったk /全/
まっすg /真っ直/
まっしろs /真っ白/
まっしろk /真っ白/
まっしろi /真っ白/
まっしろg /真っ白/
まっさかr /真っ盛/
まっこうくさs /抹香臭/
まっこうくさk /抹香臭/
まっこうくさi /抹香臭/
まっこうくさg /抹香臭/
まっくろs /真っ黒/
まっくろk /真っ黒/
まっくろi /真っ黒/
まっくろg /真っ黒/
まちわb /待ち侘/
まちゆk /街行/
まちぼうk /待ち惚/
まちぶs /待ち伏/
まちはずr /街外/町外/
まちのぞn /待ち望/
まちのぞm /待ち望/
まちのr /街乗/
まちどおs /待ち遠/
まちづくr /町作/
まちこg /待ち焦/
まちくたびr /待ち草臥/
まちきr /待ち切/
まちがw /間違/
まちがu /間違/
まちがt /間違/
まちがo /間違/
まちがi /間違/
まちがe /間違/
まちがc /間違/
まちかまe /待ち構/
まちかn /待ち兼/
まちうk /待ち受/待受/
まちあわs /待合/待ち合わ;※送り位置補正/
まちあぐn /待ち倦/
まちあぐm /待ち倦/
まちあw /待ち合/待合/
まちあk /待ち明/
まちあi /待ち合/待合/
まだるs /間怠/
まだるk /間怠/
まだるi /間怠/
まだるg /間怠/
まだらs /斑/
まだらn /斑/
まだらd /斑/
まだs /未だ;※送り位置補正/
またたk /瞬/
またたi /瞬/
またぎこs /跨ぎ越/
またぎk /又聞/
またがt /跨/
またがs /又貸/
またがr /跨/又借/
またがn /跨/
またがc /跨/
またm /又/
またi /跨/
またh /又/
またg /跨/
まぜっかえs /混ぜっ返;議論を-す/
まぜこn /混ぜ込/
まぜこm /混ぜ込/
まぜがk /交ぜ書/混ぜ書/
まぜかえs /混ぜ返/雑ぜ返/
まぜあわs /混ぜ合/
まぜあw /混ぜ合/
まずs /貧/不味/マズ/
まずk /不味/マズ/
まずi /不味/マズ/
まずg /不味/マズ/
まじろi /瞬/
まじろg /瞬/
まじりあw /混じり合/
まじりあu /混じり合/
まじりあt /混じり合/
まじりあo /混じり合/
まじりあi /混じり合/
まじりあe /混じり合/
まじりあc /混じり合/
まじめすg /真面目過/
まじなi /呪/
まじきr /間仕切/
まじw /交/
まじt /混/
まじr /混/
まじn /混/
まじk /間近/
まじh /交/雑/
まじe /交/雑/
まじc /混/
ましまs /在;天に在す我らが神よ/坐;≒在す/
ましt /況し;※送り位置補正/
まざりあw /混ざり合/
まざりあu /混ざり合/
まざりあt /混ざり合/
まざりあo /混ざり合/
まざりあi /混ざり合/
まざりあe /混ざり合/
まざりあc /混ざり合/
まさぐt /弄/
まさぐr /弄/
まさぐn /弄/
まさぐc /弄/
まさt /勝;(字義:力比べで勝つ)/優;(字義:美しさで秀でる)/
まさs /正/
まさr /勝;(字義:力比べで勝つ)/優;(字義:美しさで秀でる)/
まさn /正/勝;(字義:力比べで勝つ)/優;(字義:美しさで秀でる)/
まさc /勝;(字義:力比べで勝つ)/優;(字義:美しさで秀でる)/
まごびk /孫引/
まごu /紛;-う(かたなき) (音便)/
まことs /実;-しやか/真/
まことn /誠/真;-に/実;-に/
まげのb /曲げ伸/
まけつづk /負け続/
まけこs /負け越/
まぐまだm /マグマ溜/
まぐr /紛/
まくりあg /捲り上/
まくらs /枕/
まくひk /幕引/
まくしたt /捲し立/まくし立/
まくしあg /捲し上/
まくぎr /幕切/
まくあk /幕開/
まくt /捲/
まくr /捲/
まくn /捲/
まくc /捲/
まぎれこn /紛れ込/
まぎれこm /紛れ込/
まぎr /紛/
まきわr /薪割/
まきもどs /巻き戻/巻戻/
まきなおs /蒔き直;新規-し政策(New Deal)/巻き直;ゼンマイを-/
まきつk /巻き付/巻付/
まきつi /巻き付/巻付/
まきちらs /撒き散ら;※送り位置補正/
まきちr /撒き散/
まきぞe /巻き添/
まきこn /巻き込/
まきこm /巻き込/
まきかえs /巻き返/
まきおこs /巻き起/捲き起/巻起/
まきおk /巻き起/捲き起/巻起/
まきあg /巻き上/
まがりきt /曲がり切/
まがりきr /曲がり切/
まがりきn /曲がり切/
まがりきc /曲がり切/
まがまがs /禍々/禍禍/兇々/曲々;≒禍々しい/
まがw /紛/擬;<rare>/
まがu /紛/擬;<rare>/
まがt /曲/紛/擬;<rare>/枉/彎/弯;「彎」の異体字/
まがs /間貸/
まがr /曲/間借/枉/彎/弯;「彎」の異体字/
まがo /紛/擬;<rare>/
まがn /曲/枉/彎/弯;「彎」の異体字/
まがi /紛/擬/
まがh /紛/
まがe /紛/擬;<rare>/
まがc /紛/擬;<rare>/曲/枉/彎/弯;「彎」の異体字/
まかりまちがw /罷り間違/
まかりまちがu /罷り間違/
まかりまちがt /罷り間違/
まかりまちがo /罷り間違/
まかりまちがi /罷り間違/
まかりまちがe /罷り間違/
まかりまちがc /罷り間違/
まかりなt /罷り成/
まかりなr /罷り成/
まかりなn /罷り成/
まかりなc /罷り成/
まかりとおt /罷り通/
まかりとおr /罷り通/
まかりとおn /罷り通/
まかりとおc /罷り通/
まかりでz /罷り出/
まかりでt /罷り出/
まかりでr /罷り出/
まかりでn /罷り出/
まかなw /賄/
まかなu /賄/
まかなt /賄/
まかなo /賄/
まかなi /賄/
まかなh /賄/
まかなe /賄/
まかなc /賄/
まかせっきr /任せっ切/
まかせきt /任せ切/
まかせきr /任せ切/
まかせきn /任せ切/
まかせきc /任せ切/
まかt /罷/
まかs /任;(字義:大事なものを持たせる) 「仕事を任せる」/委;(字義:力を抜いて好きにさせる) 「躰を委せる」/
まかr /罷/
まかn /罷/
まかc /罷/
まえわたs /前渡/
まえもっt /前以/
まえむk /前向/
まえぶr /前触/
まえふr /前振/
まえばらi /前払/
まえづk /前付/
まえだおs /前倒/
まえがs /前貸/
まえがr /前借/
まえがk /前書/
まえかk /前掛/
まえおk /前置/
まえおi /前置/
まえうr /前売/
まえいわi /前祝/
まうs /申/
まうk /設/儲/
まうd /詣/
まいもどt /舞い戻/
まいもどr /舞い戻/
まいもどn /舞い戻/
まいもどc /舞い戻/
まいちt /舞い散/
まいちr /舞い散/
まいちn /舞い散/
まいちc /舞い散/
まいたt /舞い立/
まいたc /舞い立/
まいこn /舞い込/
まいこm /舞い込/
まいくるw /舞い狂/
まいくるu /舞い狂/
まいくるt /舞い狂/
まいくるo /舞い狂/
まいくるi /舞い狂/
まいくるe /舞い狂/
まいくるc /舞い狂/
まいおどt /舞い踊/
まいおどr /舞い踊/
まいおどn /舞い踊/
まいおどc /舞い踊/
まいおt /舞い落/
まいおr /舞い降/
まいおc /舞い落/
まいあg /舞い上/舞上/
まいt /参/參;旧字/詣;お宮に詣る/
まいr /参/詣;お宮に詣る/參;旧字/
まいn /参/詣;お宮に詣る/參;旧字/
まいc /参/詣;お宮に詣る/參;旧字/
まあたらs /真新/
まあi /間合/
まz /混/先;-ず/交/雑/
まw /舞/
まu /舞/
まt /待/舞/俟;期待する。「河清を-」「助力に-」/
まs /増/摩;(brush) 天を摩する/益/在/坐/
まr /放/
まo /舞/
まn /間/
まk /負/巻/撒;ばら撒く,敵を撒く/蒔;(字義:植えつける)種を蒔く/播;(字義:種をばらまく)種を播く/捲;袖を捲くる/敗;-ける/卷;「巻」の旧字(人名用漢字)/
まj /混;(字義:溶け合う)/交;(字義:立ちまじる)/雑;(字義:一緒くた)/
まi /舞/巻/撒;ばら撒く,敵を撒く/蒔;(字義:植えつける)種を蒔く/散/播;(字義:種をばらまく)種を播く/卷;「巻」の旧字(人名用漢字)/
まh /舞/
まg /曲/枉/
まe /舞/
まd /未/
まc /待/舞/俟;河清を俟つ/
ぽんびk /ぽん引/
ぽしゃt /ポシャ/
ぽしゃr /ポシャ/
ぽしゃn /ポシャ/
ぽしゃc /ポシャ/
ぼんおどr /盆踊/
ぼんあk /盆明/
ぼろs /ボロ/
ぼろk /ボロ/
ぼろi /ボロ/
ぼろg /ボロ/
ぼっs /没/
ぼこt /ボコ/
ぼこr /ボコ/
ぼこn /ボコ/
ぼこc /ボコ/
ぼくw /僕/
ぼくt /僕/
ぼくs /卜;うらなう/
ぼくn /僕/
ぼくm /僕/
ぼくh /僕/
ぼくg /僕/
ぼかs /暈/
ぼうよm /棒読/
ぼうびk /棒引/
ぼうだt /棒立/
ぼうそうs /暴走/
ぼうきr /棒切/
ぼうえいs /防衛/
ぼうy /坊/
ぼs /干/乾/
ぼr /惚/掘/彫/
ぼm /誉/褒/
ぼk /呆;(字義:赤子のようにぼっとする) NB:「ほうk」と同形/惚;(字義:何かに気を取られる)/暈;ピントが暈ける/
ほんよm /本読/
ほんみょうおなz /本名同/
ほんみょうおなj /本名同/
ほんぶr /本降/
ほんどおr /本通/
ほんどm /本泊/
ほんとb /本飛;?/
ほんづかi /本使/
ほんすべr /本滑/
ほんぎm /本決/本極/
ほんw /本/
ほろよi /微酔/
ほろびゆk /滅び行/
ほろびさt /滅び去/
ほろびさr /滅び去/
ほろびさn /滅び去/
ほろびさc /滅び去/
ほろにがs /ほろ苦/
ほろにがk /ほろ苦/
ほろにがi /ほろ苦/
ほろにがg /ほろ苦/
ほろn /滅/亡/
ほろb /滅/亡/
ほれぼr /惚れ惚/
ほれなおs /惚れ直/
ほれこn /惚れ込/
ほれこm /惚れ込/
ほりぬk /掘り抜/
ほりぬi /掘り抜/
ほりだs /掘り出;掘り出し物/彫り出;木材から仏像を彫り出す/
ほりすすn /掘り進/
ほりすすm /掘り進/
ほりさg /掘り下/
ほりこn /彫り込;carve.「名を-」/掘り込;dig.「井戸を-」/掘込/彫込/
ほりこm /彫り込;carve.「名を-」/掘り込;dig.「井戸を-」/掘込/彫込/
ほりくずs /掘り崩/
ほりかえs /掘り返/
ほりおk /掘り起/
ほりあt /掘り当/
ほりあg /彫り上;(仏像|刺青)を-げる/掘り上/
ほめたたe /褒め称/誉め称/
ほめたt /誉め立/
ほめそやs /誉称/褒称/褒め称/
ほめごろs /誉め殺/褒め殺/
ほめあg /誉め上/
ほまれたかs /誉れ高/
ほまれたかk /誉れ高/
ほまれたかi /誉れ高/
ほまれたかg /誉れ高/
ほまれおおk /誉大/
ほまr /誉/譽;旧字/
ほほばt /頬張/
ほほばr /頬張/
ほほばn /頬張/
ほほばc /頬張/
ほほえみかえs /微笑み返/
ほほえn /微笑/
ほほえm /微笑/頬笑/
ほふt /屠/
ほふr /屠/
ほふn /屠/
ほふc /屠/
ほのみe /仄見;真心が-える/
ほのじろs /仄白/
ほのじろm /仄白/
ほのじろk /仄白/
ほのじろi /仄白/
ほのじろg /仄白/
ほのぐらs /仄暗/
ほのぐらk /仄暗/
ほのぐらi /仄暗/
ほのぐらg /仄暗/
ほのm /仄/
ほのk /仄/側;-か(=仄か)/
ほねやすm /骨休/
ほねばt /骨張/
ほねばr /骨張/
ほねばn /骨張/
ほねばc /骨張/
ほねぬk /骨抜/
ほねなs /骨無/
ほねつg /骨接/
ほねぐm /骨組/
ほねおt /骨折/
ほねおr /骨折/
ほねおn /骨折/
ほねおc /骨折/
ほねp /骨/
ほどよs /程良/
ほどよk /程良/
ほどよi /程良/
ほどよg /程良/
ほどとおs /程遠/
ほどとおk /程遠/
ほどとおi /程遠/
ほどとおg /程遠/
ほどちかs /程近/
ほどちかk /程近/
ほどちかi /程近/
ほどちかg /程近/
ほどこs /施/
ほどn /程/
ほどk /解;NB:「とk」と同形/
ほどi /解;NB:「とk」と同形/
ほとんd /殆/
ほとばしt /迸/
ほとばしr /迸/
ほとばしn /迸/
ほとばしc /迸/
ほとn /殆/
ほてt /火照/熱/
ほてr /火照/熱/
ほてn /火照/熱/
ほてc /火照/熱/
ほつr /解/
ほっぽりだs /ほっぽり出/
ほっつきあるk /ほっつき歩/
ほっつきあるi /ほっつき歩/
ほっs /欲/
ほだs /絆/
ほそながs /細長/
ほそながk /細長/
ほそながi /細長/
ほそながg /細長/
ほそぎr /細切/
ほそy /細/
ほそt /細/
ほそs /細/
ほそr /細/
ほそn /細/
ほそm /細/
ほそk /細/
ほそi /細/
ほそg /細/
ほそc /細/
ほじくりだs /穿り出/
ほじくりかえs /穿り返/
ほじくt /穿/
ほじくr /穿/
ほじくn /穿/
ほじくc /穿/
ほじt /穿/
ほじr /穿/
ほじn /穿/
ほじc /穿/
ほしふr /星降/
ほしうらなi /星占/
ほしいままs /恣/縦/
ほしいままn /恣/縦/
ほしいままd /恣/縦/
ほしs /欲;非正則(ほs)/
ほしk /欲;非正則(ほs)/
ほしi /欲し;※送り位置補正/欲;非正則(ほs)/
ほしg /欲;非正則(ほs)/
ほごあずかr /保護預/
ほころn /綻/
ほころb /綻/
ほこりたかs /誇り高/
ほこりたかk /誇り高/
ほこりたかi /誇り高/
ほこりたかg /誇り高/
ほこりp /埃/
ほこt /誇/
ほこr /誇/
ほこn /誇/
ほこc /誇/
ほぐs /解/
ほぐr /解/
ほがr /朗/朖;「朗」の異体字/
ほかn /他/
ほおばt /頬張/
ほおばr /頬張/
ほおばn /頬張/
ほおばc /頬張/
ほおt /放/
ほおr /放/
ほおn /放/
ほおc /放/
ほえたt /吠え立/
ほうりなg /放り投/
ほうりだs /放り出/
ほうりこn /放り込/
ほうりこm /放り込/
ほうりあg /放り上/
ほうむりさt /葬り去/
ほうむりさr /葬り去/
ほうむりさn /葬り去/
ほうむりさc /葬り去/
ほうむt /葬/
ほうむr /葬/
ほうむn /葬/
ほうむc /葬/
ほうふn /豊富/
ほうっておk /放って置/
ほうっておi /放って置/
ほうっt /放/
ほうこくいたs /報告致/
ほうz /報;急を報ずる/奉;主君を奉ずる/封;二百石に封ずる/焙;茶を焙ずる/
ほうw /方/
ほうt /放;(字義:手を離す)/抛;(字義:高く投げる)/方/
ほうs /保/焙/
ほうr /放;(字義:手を離す)/抛;(字義:高く投げる)/
ほうn /放;(字義:手を離す)/抛;(字義:高く投げる)/方/
ほうm /方/
ほうk /呆/惚/
ほうj /報/奉/焙/
ほうh /方/
ほうg /方/
ほうc /放;(字義:手を離す)/抛;(字義:高く投げる)/
ほt /掘;(dig) 穴を掘る/放/彫;(carve) 仏像を彫る/
ほs /欲/干/乾;=干す (NB:「干す」は仮借用法)/補/保/
ほr /掘;(dig) 穴を掘る/彫;(carve) 仏像を彫る/惚;女に惚れる/耄/恍/抛/放/
ほn /掘;(dig) 穴を掘る/彫;(carve) 仏像を彫る/
ほm /褒;(字義:行いを評価する)/誉;(字義:持ち上げる)/賞;(字義:褒美をあてがう)/襃;「褒」の異体字/譽;「誉」の旧字/
ほe /吠;字義:犬が鳴く/吼;字義:大きな声を出す/咆;字義:含み声でほえる/哮;<rare> ≒吼える/
ほc /掘;(dig) 穴を掘る/彫;(carve) 仏像を彫る/
べんじたt /弁じ立/
べんz /弁/
べんs /便/
べんj /弁/
べとつk /べと付/
べとつi /べと付/
べつずr /別刷/
べつうr /別売/
べつあつかi /別扱/
べつs /別/
べつn /別/
べつd /別/
べたぬr /べた塗/
べたつk /べた付/
べたつi /べた付/
べいこくぎらi /米国嫌/
べs /可/
べk /可/
べi /可/
へんにゅうs /編入/
へんそうくだs /返送下/
へんじくだs /返事下/
へんこういたs /変更致/
へんこうs /変更/
へんかんg /変換/
へんかs /変化/
へんz /変/
へんt /変/
へんs /偏;人偏/貶/変/變;「変」の旧字/
へんn /変/變;「変」の旧字/
へんj /変/
へんd /変/變;「変」の旧字/
へりくだt /謙/遜/
へりくだr /謙/遜/
へりくだn /謙/遜/
へりくだc /謙/遜/
へらs /減ら;※送り位置補正/
へめぐt /経巡/経回/歴回/
へめぐr /経巡/経回/歴回/
へめぐn /経巡/経回/歴回/
へめぐc /経巡/経回/歴回/
へぼs /ヘボ/
へぼk /ヘボ/
へぼi /ヘボ/
へぼg /ヘボ/
へばりつk /へばり付/
へばりつi /へばり付/
へつらw /諂/諛/
へつらu /諂/諛/
へつらt /諂/諛/
へつらo /諂/諛/
へつらi /諂/諛/
へつらh /諛/諂/
へつらe /諂/諛/
へつらc /諂/諛/
へだたt /隔/
へだたr /隔/
へだたn /隔/
へだたc /隔/
へだt /隔/
へたりこn /へたり込/
へたりこm /へたり込/
へたn /下手/
へそまg /臍曲/
へしおt /圧し折/へし折/
へしおr /圧し折/へし折/
へしおn /圧し折/へし折/
へしおc /圧し折/へし折/
へこn /凹;NB:「くぼm」と同形/
へこm /凹;NB:「くぼm」と同形/
へいわn /平和/
へあg /経上/
へz /経;時を経る,役員を経る/經;「経」の旧字/歴;≒経る/
へy /経;時を経る,役員を経る/歴;≒経る/經;「経」の旧字/
へt /減/経;時を経る,役員を経る/經;「経」の旧字/歴;≒経る/
へs /圧;押し合い-し合い/減/経;時を経る,役員を経る/歴;≒経る/經;「経」の旧字/
へr /減/経;時を経る,役員を経る/歴;≒経る/經;「経」の旧字/
へn /経;時を経る,役員を経る/經;「経」の旧字/減/歴;≒経る/
へm /経;時を経る,役員を経る/歴;≒経る/經;「経」の旧字/
へk /経;時を経る,役員を経る/歴;≒経る/經;「経」の旧字/
へj /経;時を経る,役員を経る/歴;≒経る/經;「経」の旧字/
へi /剥;(薄く削る)/折;≒剥ぐ/
へg /剥;(薄く削る)/折;≒剥ぐ/
へd /経;時を経る,役員を経る/歴;≒経る/經;「経」の旧字/
へc /減/経;時を経る,役員を経る/歴;≒経る/經;「経」の旧字/
ぶんなぐt /打ん殴/ぶん殴/
ぶんなぐr /ぶん殴/打ん殴/
ぶんなぐn /ぶん殴/打ん殴/
ぶんなぐc /ぶん殴/打ん殴/
ぶんせつくぎr /文節区切/
ぶんかつばらi /分割払/
ぶんかつs /分割/
ぶんs /分/
ぶるi /震/
ぶりかえs /ぶり返;熱が-す/
ぶらさg /ぶら下/
ぶひんとr /部品取/
ぶばt /武張/
ぶばr /武張/
ぶばn /武張/
ぶばc /武張/
ぶどまr /歩留/
ぶどm /歩留/
ぶとt /太/
ぶとr /太/
ぶとn /太/
ぶとc /太/
ぶつぎr /ぶつ切/
ぶっとおs /ぶっ通/打っ通;<rare>/
ぶっとn /打っ飛/
ぶっとb /打っ飛/
ぶったぎt /ぶった切/ぶった斬/打っ手切/
ぶったぎr /ぶった切/ぶった斬/打っ手切/
ぶったぎn /ぶった切/ぶった斬/打っ手切/
ぶったぎc /ぶった切/ぶった斬/打っ手切/
ぶっこわs /ぶっ壊/
ぶっころs /ぶっ殺/ブッ殺/打っ殺/
ぶっこn /打っ込/ぶっ込/
ぶっこm /打っ込/ぶっ込/
ぶっかk /打っ掛/ぶっ掛/
ぶちこわs /ぶち壊/打ち壊;NB:「うちこわs」と同形/ブチ壊/
ぶちころs /打ち殺/ブチ殺/ぶち殺/
ぶちこn /打ち込;NB:「うちこm」と同形/
ぶちこm /打ち込;NB:「うちこm」と同形/
ぶちぎr /ブチ切;-れ/
ぶちきr /ブチ切;-れる/
ぶちかm /打ち噛/
ぶちあg /打ち上;NB:「うちあg」と同形/
ぶきみg /不気味/
ぶかs /深/
ぶかk /深/
ぶかi /深/
ぶかg /深/
ぶあつs /ぶ厚/分厚/部厚/
ぶあつk /ぶ厚/分厚/部厚/
ぶあつi /分厚/部厚/ぶ厚/
ぶあつg /分厚/部厚/ぶ厚/
ぶt /撲/打;NB:「うt」と同形/撃/振/
ぶs /撫/伏;(連濁)/
ぶr /振/
ぶn /振/
ぶk /拭/吹/葺/
ぶc /振/
ふんばt /踏ん張/
ふんばr /踏ん張/
ふんばn /踏ん張/
ふんばc /踏ん張/
ふんづm /糞詰/
ふんづk /踏ん付/
ふんぞりかえt /踏ん反り返/
ふんぞりかえr /踏ん反り返/
ふんぞりかえn /踏ん反り返/
ふんぞりかえc /踏ん反り返/
ふんぞt /踏ん反/
ふんぞr /踏ん反;-る,-り返る/
ふんぞn /踏ん反/
ふんぞc /踏ん反/
ふんじばt /ふん縛/
ふんじばr /ふん縛/
ふんじばn /ふん縛/
ふんじばc /ふん縛/
ふんぎt /踏ん切/
ふんぎr /踏ん切/
ふんぎn /踏ん切/
ふんぎc /踏ん切/
ふんs /扮;扮装/
ふわたr /不渡/
ふわk /腑分/
ふろあg /風呂上/
ふれまわt /触れ回/
ふれまわr /触れ回/
ふれまわn /触れ回/
ふれまわc /触れ回/
ふれこn /触れ込/
ふれこm /触れ込/
ふれあるk /触れ歩/
ふれあるi /触れ歩/
ふれあw /触れ合/触合/
ふれあu /触れ合/触合/
ふれあt /触れ合/触合/
ふれあo /触れ合/触合/
ふれあi /触れ合/触合/
ふれあe /触れ合/触合/
ふれあc /触れ合/触合/
ふるまw /振る舞/振舞/
ふるまu /振る舞/振舞/
ふるまt /振る舞/振舞/
ふるまo /振る舞/振舞/
ふるまi /振舞/振る舞/
ふるまh /振舞/
ふるまe /振舞/振る舞/
ふるまc /振る舞/振舞/
ふるぼk /古惚/
ふるすg /古過/
ふるくさs /古臭/
ふるくさk /古臭/
ふるくさi /古臭/
ふるくさg /古臭/
ふるえあg /震え上/
ふるいわk /篩い分/
ふるいたt /奮い立/奮い起/
ふるいたc /奮い立/奮い起/
ふるいおとs /篩い落/振るい落/振い落/
ふるいおこs /奮い起/
ふるいおt /振るい落/篩い落/
ふるいおk /奮い起/
ふるw /震/奮;気力を奮う/振;(generic) 刀を振う/揮;(発揮) 国力が揮う,腕を揮う/篩;(screen) 粉を篩う/
ふるu /奮;気力を奮う/振;(generic) 刀を振う/揮;(発揮) 国力が揮う,腕を揮う/震/篩;(screen) 粉を篩う/古/旧/故/舊;「旧」の旧字/
ふるt /奮;気力を奮う/振;(generic) 刀を振う/揮;(発揮) 国力が揮う,腕を揮う/震/篩;(screen) 粉を篩う/
ふるs /古/旧/故/舊;「旧」の旧字/
ふるo /奮;気力を奮う/振;(generic) 刀を振う/揮;(発揮) 国力が揮う,腕を揮う/震/篩;(screen) 粉を篩う/
ふるm /古/旧/故/舊;「旧」の旧字/
ふるk /古/旧/故/舊;「旧」の旧字/
ふるi /古/旧/震/奮;気力を奮う/振;(generic) 刀を振う/故/舊;「旧」の旧字/揮;(発揮) 国力が揮う,腕を揮う/篩;(screen) 粉を篩う/
ふるh /揮/振/震/奮/篩/
ふるg /古/旧/故/舊;「旧」の旧字/
ふるe /震/顫/奮;気力を奮う/振;(generic) 刀を振う/揮;(発揮) 国力が揮う,腕を揮う/篩;(screen) 粉を篩う/
ふるc /奮;気力を奮う/振;(generic) 刀を振う/揮;(発揮) 国力が揮う,腕を揮う/震/篩;(screen) 粉を篩う/
ふるb /古/
ふりわk /振り分/
ふりやn /降り止/
ふりやm /降り止/
ふりむk /振り向/
ふりむi /振り向/
ふりみだs /振り乱/
ふりまわs /振り回/
ふりまz /振り混/
ふりまk /振り撒/
ふりまi /振り撒/
ふりほどk /振り解/
ふりほどi /振り解/
ふりはらw /振り払/
ふりはらu /振り払/
ふりはらt /振り払/
ふりはらo /振り払/
ふりはらi /振り払/
ふりはらe /振り払/
ふりはらc /振り払/
ふりのこs /降り残;-してや光堂/
ふりぬk /振り抜/振抜/
ふりぬi /振り抜/振抜/
ふりにg /振り逃/
ふりつもt /降り積/
ふりつもr /降り積/
ふりつもn /降り積/
ふりつもc /降り積/
ふりつのt /降り募/
ふりつのr /降り募/
ふりつのn /降り募/
ふりつのc /降り募/
ふりつづk /降り続/
ふりつづi /降り続/
ふりつm /降り積/
ふりつk /振り付/振付/
ふりだs /振り出/降り出/振出/
ふりたs /振り足/
ふりそぼt /降り濡/
ふりそそi /降り注/
ふりそそg /降り注/
ふりすt /振り捨/
ふりしぼt /振り絞/
ふりしぼr /振り絞/
ふりしぼn /振り絞/
ふりしぼc /振り絞/
ふりしきt /降り頻/
ふりしきr /降り頻/
ふりしきn /降り頻/
ふりしきc /降り頻/
ふりさけみz /振り放け見;-れば春日なる/
ふりさけみy /振り放け見;-れば春日なる/
ふりさけみt /振り放け見;-れば春日なる/
ふりさけみs /振り放け見;-れば春日なる/
ふりさけみr /振り放け見;-れば春日なる/
ふりさけみn /振り放け見;-れば春日なる/
ふりさけみm /振り放け見;-れば春日なる/
ふりさけみk /振り放け見;-れば春日なる/
ふりさけみc /振り放け見;-れば春日なる/
ふりさk /振り放;-け見れば春日なる/
ふりこn /振り込/降り込;窓から雪が-む/振込/
ふりこm /振り込/振込/降り込;窓から雪が-む/降り籠;雨に-められる/
ふりきt /振り切/
ふりきr /振り切/
ふりきn /振り切/
ふりきc /振り切/
ふりかぶt /振り被/
ふりかぶr /振り被/
ふりかぶn /振り被/
ふりかぶc /振り被/
ふりかざs /振り翳/
ふりかえt /振り返/振返/
ふりかえr /振り返/振返/
ふりかえn /振り返/振返/
ふりかえc /振り返/振返/
ふりかk /降り掛;災難が-/振り掛;-け/
ふりかe /振り替/
ふりおとs /振り落/
ふりおt /振り落/
ふりあおi /振り仰/
ふりあおg /振り仰/
ふりあg /振り上/振上/
ふゆやすm /冬休/
ふゆばr /冬晴/
ふゆきとどk /不行届/
ふゆがr /冬枯/
ふやs /増や;※送り位置補正/殖や;※送り位置補正/
ふむk /不向/
ふみわk /踏み分/
ふみはずs /踏み外/
ふみぬk /踏み抜;床を-く/踏み貫;釘を-く/
ふみぬi /踏み抜;床を-く/踏み貫;釘を-く/
ふみにじt /踏み躙/
ふみにじr /踏み躙/
ふみにじn /踏み躙/
ふみにじc /踏み躙/
ふみならs /踏み均/
ふみなr /踏み鳴/
ふみとどm /踏み止/踏み留/
ふみつぶs /踏み潰/
ふみつk /踏み付/踏付/
ふみちr /踏み散/
ふみだs /踏み出/
ふみたおs /踏み倒/
ふみしm /踏み締/
ふみころs /踏み殺/
ふみこn /踏み込/踏込/
ふみこm /踏み込/踏込/
ふみこe /踏み越/
ふみきt /踏み切/
ふみきr /踏み切/
ふみきn /踏み切/
ふみきc /踏み切/
ふみかたm /踏み固/
ふみおこなw /踏み行/
ふみおこなu /踏み行/
ふみおこなt /踏み行/
ふみおこなo /踏み行/
ふみおこなi /踏み行/
ふみおこなc /踏み行/
ふみいt /踏み入/
ふみいr /踏み入/
ふみいn /踏み入/
ふみいc /踏み入/
ふみあr /踏み荒;花園を-らす/
ふまe /踏ま;※送り位置補正/
ふぶk /吹雪/乱吹;≒吹雪く/
ふぶi /吹雪/乱吹;≒吹雪く/
ふばらi /不払/
ふぬk /腑抜/
ふなよi /船酔/
ふなもr /舟盛/
ふなのr /船乗/
ふなづm /船積/
ふなr /不慣/
ふとどk /不届/
ふとt /太/肥/
ふとs /太/
ふとr /太/肥/
ふとn /太/肥/
ふとm /太/
ふとk /太/
ふとi /太/
ふとg /太/
ふとc /太/肥/
ふでづかi /筆遣/
ふでたt /筆立/
ふでおr /筆下/
ふでいr /筆入/
ふてぶてs /太々/
ふてくさt /不貞腐/ふて腐/
ふてくさr /不貞腐/ふて腐/
ふてくさn /不貞腐/ふて腐/
ふてくさc /不貞腐/ふて腐/
ふつくm /恚/慍/憤/
ふつかよi /二日酔/
ふつうn /普通/
ふつk /恚/憤/
ふっとn /吹っ飛/
ふっとb /吹っ飛/
ふってわk /降って湧/
ふってわi /降って湧/
ふっきr /吹っ切/
ふっかk /吹っ掛/
ふちどt /縁取/
ふちどr /縁取/
ふちどn /縁取/
ふちどc /縁取/
ふだんづかi /普段使/
ふたりk /二人/
ふたとおr /二通/
ふたたb /再/
ふたしk /不確/
ふたt /二/弍;「二」の異体字/
ふぞろi /不揃/
ふせi /防/拒;<rare>(寄せ付けない)/
ふせg /防/拒;<rare>(寄せ付けない)/
ふずくm /慍/憤/
ふすb /燻/
ふしまわs /節回/
ふしづk /節付/
ふしくれだt /節榑立/
ふしくれだc /節榑立/
ふしおがn /伏し拝/
ふしおがm /伏し拝/
ふしあw /不仕合/
ふざけt /巫山戯/
ふざけr /巫山戯/
ふざけn /巫山戯/
ふざけc /巫山戯/
ふさわs /相応/
ふさぎこn /塞ぎ込/鬱ぎ込/
ふさぎこm /塞ぎ込/鬱ぎ込/
ふさw /相応/
ふさu /相応/
ふさt /相応/
ふさo /相応/
ふさi /塞/相応/鬱;気が鬱ぐ/
ふさg /塞/鬱;気が鬱ぐ/
ふさc /相応/
ふけゆk /更け行/
ふけこn /老け込/
ふけこm /老け込/
ふけt /耽/
ふけr /耽/
ふけn /耽/
ふけc /耽/
ふくろばr /袋貼/
ふくろとj /袋綴/
ふくろだたk /袋叩/
ふくれあg /膨れ上/
ふくぶくs /福々/
ふくざつすg /複雑過/
ふくy /膨/脹/
ふくs /服;喪に服す/復;原状に復する/伏;権力に伏する/覆;NB:「くつがえs」と同形/
ふくr /膨/脹/
ふくn /含/
ふくm /含/
ふきわたt /吹き渡/
ふきわたr /吹き渡/
ふきわたn /吹き渡/
ふきわたc /吹き渡/
ふきよs /吹き寄/
ふきやn /吹き止/
ふきやm /吹き止/
ふきぬk /吹き抜/吹抜/
ふきながs /吹き流/
ふきなr /吹き鳴/
ふきとおs /吹き通/
ふきとt /拭き取/
ふきとr /拭き取/
ふきとn /吹き飛/拭き取/
ふきとc /拭き取/
ふきとb /吹き飛/
ふきでz /吹き出/噴き出/
ふきでy /吹き出/噴き出/
ふきでt /吹き出/噴き出/
ふきでs /吹き出/噴き出/
ふきでr /吹き出/噴き出/
ふきでn /吹き出/噴き出/
ふきでm /吹き出/噴き出/
ふきでk /吹き出/噴き出/
ふきでc /吹き出/噴き出/
ふきつづk /吹き続/
ふきつk /吹き付/
ふきちr /吹き散/
ふきだまt /吹き溜/
ふきだまr /吹き溜/
ふきだまn /吹き溜/
ふきだまc /吹き溜/
ふきだt /吹き溜/
ふきだs /吹き出/噴き出/
ふきだr /吹き溜/
ふきだn /吹き溜/
ふきだm /吹き溜/
ふきだc /吹き溜/
ふきすさn /吹き荒/
ふきすさb /吹き荒/
ふきさらs /吹き曝/
ふきさm /吹き冷/
ふきこn /吹き込/
ふきこm /吹き込/
ふきけs /吹き消;(blow out)蝋燭を吹き消す/拭き消;(wipe out)落書きを拭き消す/
ふききよm /拭き清/
ふきかえs /吹き返/
ふきかk /吹き掛;息を-ける/
ふきかe /吹替;洋画の吹替え/吹き替/葺き替;屋根を葺き替える/
ふきおr /吹き下/葺き下/
ふきあr /吹き荒/
ふきあg /吹き上/
ふがひなs /腑甲斐無/
ふがひなk /腑甲斐無/
ふがひなi /腑甲斐無/
ふがひなg /腑甲斐無/
ふがいなs /腑甲斐無/
ふがいなk /腑甲斐無/
ふがいなi /腑甲斐無/
ふがいなg /腑甲斐無/
ふかよm /深読/
ふかなさk /深情/
ふかすg /深過/
ふかおi /深追/
ふかいr /深入/
ふかs /深/蒸;芋を蒸す (NB:「むs」と同形)/更;夜を更す/潭;<rare>/
ふかm /深/潭;<rare>/
ふかk /深/潭;<rare>/
ふかi /深/潭;<rare>/
ふかg /深/潭;<rare>/
ふえふk /笛吹/
ふうじこn /封じ込/
ふうじこm /封じ込/
ふうしゃがたm /風車固/
ふうぎt /封切/
ふうがわr /風変/
ふうz /封/
ふうs /諷/風/
ふうn /風/
ふうj /封/
ふうd /風/
ふいr /不入/
ふあんていd /不安定/
ふy /増/殖;(そのもの自身を増加させる)「財を殖やす」/
ふt /振/降;雨が降る/
ふs /付/伏/臥;床に臥す/附;=付す/匐/賦/
ふr /振/触/降;雨が降る/経;我が身世に経る/觝;<rare> 法に觝れる/觸;「触」の旧字/經;「経」の旧字/狂;気が狂れる/
ふn /踏/蹈;≒踏む/履;(≒踏む) 薄氷を履む/振/降;雨が降る/践;(実践) 践み行う/
ふm /踏/履;(≒踏む) 薄氷を履む/践;(実践) 践み行う/蹈;≒踏む/
ふk /吹;笛を吹く/拭;床を拭く/噴;(burst)火を噴く/老;老けた男/更;夜が更ける/葺;屋根を葺く/深;-ける(≒更ける|老ける)/
ふi /吹;笛を吹く/拭;床を拭く/噴;(burst)火を噴く/葺;屋根を葺く/
ふe /増/殖;(procreate)「(猫|財産)が殖える」/
ふc /振/降;雨が降る/
びんぼうくさs /貧乏臭/
びんぼうくさk /貧乏臭/
びんぼうくさi /貧乏臭/
びんぼうくさg /貧乏臭/
びんじょうねあg /便乗値上/
びろs /広/
びろk /広/
びろi /広/
びろg /広/
びらk /開;海開き,俎開き,片開き/
びょうよm /秒読/
びょううt /鋲打/
びょううc /鋲打/
びみょうn /微妙/
びびt /ビビ/
びびr /ビビ/
びびn /ビビ/
びびc /ビビ/
びたt /浸/
びたr /浸/
びたn /浸/
びたc /浸/
びk /引/弾/
びi /引/弾/
ひんよk /品良/
ひんむk /引ん剥/
ひんむi /引ん剥/
ひんs /瀕;瀕死/貧/
ひわたr /火渡/
ひわr /干割/
ひろせどおr /広瀬通/
ひろすg /広過/
ひろいよm /拾い読/
ひろいだs /拾い出/
ひろいあつm /拾い集/
ひろいあg /拾い上/
ひろy /広/
ひろw /拾/広/
ひろu /拾/広/
ひろt /拾/広/
ひろs /広/廣;「広」の旧字(人名用漢字)/拾/博;知識が-い/宏/弘/
ひろo /拾/広/
ひろm /広/弘/廣;「広」の旧字(人名用漢字)/博;知識が-い/宏/
ひろk /広/宏/博;知識が-い/廣;「広」の旧字(人名用漢字)/拾/弘/
ひろi /広/拾/博;知識が-い/宏/弘/廣;「広」の旧字(人名用漢字)/
ひろg /広/拡;(enlarge)/展;(まとめてあったものをひろげる) 新聞を展げる/廣;「広」の旧字(人名用漢字)/擴;「拡」の旧字/博;知識が-い/宏/弘/拾;?/
ひろe /拾/広/
ひろc /拾/広/
ひれふs /平伏/
ひるやすm /昼休/
ひるすg /昼過/
ひるさがr /昼下/
ひるさg /昼下/
ひるがえt /翻/飜;「翻」の旧字(人名用漢字)/
ひるがえs /翻/飜;「翻」の旧字(人名用漢字)/
ひるがえr /翻/飜;「翻」の旧字(人名用漢字)/
ひるがえn /翻/飜;「翻」の旧字(人名用漢字)/
ひるがえc /翻/飜;「翻」の旧字(人名用漢字)/
ひるn /怯/
ひるm /怯/
ひりだs /放り出;NB:「ほうりだs」と同形/
ひらめk /閃/
ひらめi /閃/
ひらとj /平綴/
ひらづm /平積/
ひらきなおt /開き直/
ひらきなおr /開き直/
ひらきなおn /開き直/
ひらきなおc /開き直/
ひらあやまr /平謝/
ひらt /平/
ひらk /開/拓;処女地を拓く/啓;蒙を啓く/
ひらi /開/拓;処女地を拓く/啓;蒙を啓く/
ひらb /平;-べったい/
ひよわs /ひ弱/
ひよわk /ひ弱/
ひよわi /ひ弱/
ひよわg /ひ弱/
ひよt /日和/
ひよr /日和/
ひよn /日和/
ひよc /日和/
ひょうよm /票読/
ひょうへんs /豹変/
ひょうばんわるs /評判悪/
ひょうばんわるk /評判悪/
ひょうばんわるi /評判悪/
ひょうばんわるg /評判悪/
ひょうばんよs /評判良/
ひょうばんよk /評判良/
ひょうばんよi /評判良/
ひょうばんよg /評判良/
ひょうばんどおr /評判通/
ひょうじょうゆたk /表情豊/
ひょうじs /表示/
ひょうしぬk /拍子抜/
ひょうぐm /表組/
ひょうs /表;(manifest) 敬意を表す/評;(criticise) 作品を評す/
ひやとi /日雇/
ひやかs /素見/
ひやy /冷/
ひやs /冷/
ひやk /日焼/冷/
ひゃっぽゆずt /百歩譲/
ひゃっぽゆずr /百歩譲/
ひゃっぽゆずc /百歩譲/
ひゃくしょうよm /百姓読/
ひもとk /紐解/繙/
ひもとi /繙/紐解/
ひまつぶs /暇潰/
ひまs /日増/暇/閑/隙;(すきま)/
ひまn /閑/隙;(すきま)/
ひまd /閑/隙;(すきま)/
ひふk /火吹;-き竹,-き山/
ひびわr /罅割/ひび割/
ひびきわたt /響き渡/
ひびきわたr /響き渡/
ひびきわたn /響き渡/
ひびきわたc /響き渡/
ひびきあw /響き合/
ひびきあu /響き合/
ひびきあt /響き合/
ひびきあo /響き合/
ひびきあi /響き合/
ひびきあe /響き合/
ひびきあc /響き合/
ひびk /響/
ひびi /響/
ひのいr /日の入/
ひのb /日延/
ひねりつぶs /捻り潰/
ひねりだs /捻り出/
ひねくりまわs /捻くり回/
ひねt /捻/撚/陳;(age) 大根が陳る/拈;≒捻る/捫/
ひねr /捻/撚/陳;(age) 大根が陳る/拈;≒捻る/捫/
ひねn /捻/撚/陳;(age) 大根が陳る/拈;≒捻る/捫/
ひねk /捻/
ひねc /捻/撚/陳;(age) 大根が陳る/拈;≒捻る/捫/
ひにくt /皮肉/
ひにくr /皮肉/
ひにくn /皮肉/
ひにくc /皮肉/
ひなあそb /雛遊/
ひなb /鄙/
ひどu /酷/非道/
ひどs /酷/非道/
ひどr /日取/
ひどk /酷/非道/
ひどi /酷/非道/
ひどg /酷/非道/
ひとりよg /独り善/
ひとりだt /独り立/
ひとりじm /一人占/独り占/
ひとりごt /独り言/
ひとりごc /独り言/
ひとりぐr /一人暮/
ひとりあるk /一人歩/
ひとりあt /一人当/
ひとりk /一人/
ひとよs /人寄/
ひとよn /人呼/
ひとやすm /一休/
ひとやくかw /一役買/
ひとやくかu /一役買/
ひとやくかt /一役買/
ひとやくかo /一役買/
ひとやくかi /一役買/
ひとやくかe /一役買/
ひとやくかc /一役買/
ひとめぼr /一目惚/
ひとみしr /人見知/
ひとまわr /一回/
ひとまかs /人任/
ひとまt /人待/
ひとふでがk /一筆書/
ひとひねr /一捻/
ひとばらi /人払/
ひとはだぬi /一肌脱/
ひとはだぬg /一肌脱/
ひとはたらk /一働/
ひとはしr /一走/
ひとねむr /一眠/
ひとねいr /一寝入/
ひとにぎr /一握/
ひとなつk /人懐/
ひとなm /人並/
ひとどおr /人通/
ひととおr /一通/
ひととうr /一通;※仮名遣い「ひととお-り」/
ひとづきあi /人付き合/
ひとづかi /人使/
ひとつづk /一続/
ひとちがi /人違/
ひとだすk /人助/
ひとだかr /人集/
ひとたまr /一溜/
ひとたたk /一叩/
ひとたm /一溜/
ひとそろe /一揃/
ひとずk /人好/
ひとしr /人知/
ひとさわg /人騒;人騒がせな話/一騒;一騒ぎある/
ひとさらi /人攫/
ひとさがs /人探/人捜/
ひとごろs /人殺/
ひとごm /人込/人混/
ひとこいs /人恋/
ひとくぎr /一区切/
ひとくi /人喰/人食;-い鮫/
ひとぎらi /人嫌/
ひとぎk /人聞/
ひときr /一切/
ひとがんばr /一頑張/
ひとかかe /一抱/
ひとかi /人買/
ひとおもi /一思/
ひとえn /偏/
ひといきいr /一息入/
ひとあじちがw /一味違/
ひとあじちがu /一味違/
ひとあじちがt /一味違/
ひとあじちがo /一味違/
ひとあじちがi /一味違/
ひとあじちがe /一味違/
ひとあじちがc /一味違/
ひとあしはやk /一足早/
ひとあしはやi /一足早/
ひとあしちがi /一足違/
ひとあしおそk /一足遅/
ひとあしおそi /一足遅/
ひとあt /一当/
ひとあr /一荒/
ひとt /一/壱;「一」の大字/弌;「一」の異体字/壹;「壱」の旧字/１/1/
ひとs /等/均/斉/
ひとr /独;(字義:群れない)/孤;(字義:取り残される)/獨;「独」の旧字/
ひとm /一/
ひでt /日照/
ひでr /日照/
ひでn /日照/
ひでc /日照/
ひづk /日付/
ひつようn /必要/
ひつk /火付/
ひっぱりまわs /引っ張り回/
ひっぱりだs /引っ張り出/引っぱり出/
ひっぱりこn /引っ張り込/
ひっぱりこm /引っ張り込/
ひっぱりあg /引っ張り上/
ひっぱたk /引っ叩/
ひっぱたi /引っ叩/
ひっぱt /引っ張/引張/
ひっぱr /引っ張/引張/
ひっぱn /引っ張/引張/
ひっぱg /引っ剥;ビリッと-がす/
ひっぱc /引っ張/引張/
ひっとらe /引っ捕/
ひっつk /引っ付/
ひっつi /引っ付/
ひったくt /引っ手繰/
ひったくr /引っ手繰/
ひったくn /引っ手繰/
ひったくc /引っ手繰/
ひったt /引っ立/
ひっさらw /引っ攫/
ひっさらu /引っ攫/
ひっさらt /引っ攫/
ひっさらo /引っ攫/
ひっさらi /引っ攫/
ひっさらe /引っ攫/
ひっさらc /引っ攫/
ひっさg /提;NB:「さg」と同形/引っ提/引っ下/
ひっこぬk /引っこ抜/
ひっこぬi /引っこ抜/
ひっこしづかr /引越疲/
ひっこs /引っ越/引越/
ひっこn /引っ込/引込/
ひっこm /引っ込/引込/
ひっくるm /引っ括/
ひっくりかえt /引っくり返/ひっくり返/引っ繰り返/
ひっくりかえs /引っくり返/ひっくり返/引っ繰り返/
ひっくりかえr /引っくり返/ひっくり返/引っ繰り返/
ひっくりかえn /引っくり返/ひっくり返/引っ繰り返/
ひっくりかえc /引っくり返/ひっくり返/引っ繰り返/
ひっくくt /引っ括/
ひっくくr /引っ括/
ひっくくn /引っ括/
ひっくくc /引っ括/
ひっきりなs /引っ切り無/
ひっきt /引っ切/
ひっきr /引っ切/
ひっきn /引っ切/
ひっきc /引っ切/
ひっかぶt /引っ被/
ひっかぶr /引っ被/
ひっかぶn /引っ被/
ひっかぶc /引っ被/
ひっかかt /引掛/引っ掛/
ひっかかr /引っ掛/引掛/
ひっかかn /引っ掛/引掛/
ひっかかc /引っ掛/引掛/
ひっかえs /引っ返/
ひっかk /引っ掛/引っ掻/
ひっかi /引っ掻/
ひっかe /引っ替;取っ替え-え/
ひっs /筆/必/
ひだるs /饑/
ひだるk /饑/
ひだるi /饑/
ひだるg /饑/
ひだりよt /左四/
ひだりよr /左寄/
ひだりむk /左向/
ひだりまわr /左回/
ひだりまk /左巻/
ひだりきk /左利/
ひだりs /左/
ひだまr /日溜/
ひだt /肥立/
ひだs /養/
ひだm /日溜/
ひたはしt /直走/
ひたはしr /直走/
ひたはしn /直走/
ひたはしc /直走/
ひたかくs /直隠/
ひたt /浸/
ひたs /浸/漬/
ひたr /浸/
ひたn /浸/
ひたc /浸/
ひそy /密/秘/
ひそn /潜/潛;「潜」の旧字1/濳;「潜」の旧字2/顰;眉を顰める/
ひそm /潜/顰;眉を顰める/潛;「潜」の旧字1/濳;「潜」の旧字2/
ひそk /密/秘/祕;「秘」の旧字(人名用漢字)/
ひぜm /火攻;城を火攻めにする/火責;罪人を火責めにする/
ひずn /歪/
ひずm /歪/
ひじょうn /非常/
ひじかk /肘掛/
ひしゃi /拉/
ひしゃg /拉/
ひしめk /犇/
ひしめi /犇/
ひしm /犇/
ひしi /拉/柆;<rare> =拉ぐ/
ひしg /拉/柆;<rare> =拉ぐ/
ひざまづk /跪/
ひざまづi /跪/
ひざまずk /跪/
ひざまずi /跪/
ひざかk /膝掛/
ひざs /日射/日差/
ひさしぶr /久し振/
ひさかたぶr /久方振/
ひさs /久/尚;<rare>/
ひさi /鬻;(trade) 矛と盾を鬻ぐ/販;≒鬻ぐ/
ひさg /鬻;(trade) 矛と盾を鬻ぐ/販;≒鬻ぐ/拉;(crush) 箱が拉げる/提;≒提げる/
ひけs /火消/
ひぐr /日暮/
ひくすg /低過/
ひくs /低/
ひくm /低/
ひくk /低/
ひくi /低/
ひくg /低/
ひきわたs /引き渡/引渡/
ひきわr /碾き割/挽き割/
ひきわk /引き分/引分/
ひきよs /引き寄/
ひきもどs /引き戻/
ひきむすn /引き結/
ひきむすb /引き結/
ひきまわs /引き回/
ひきはらw /引き払/
ひきはらu /引き払/
ひきはらt /引き払/
ひきはらo /引き払/
ひきはらi /引き払/
ひきはらe /引き払/
ひきはらc /引き払/
ひきはなs /引き離/
ひきはi /引き剥/
ひきはg /引き剥/
ひきのb /引き伸/引き延/
ひきぬk /引き抜/
ひきぬi /引き抜/
ひきにg /轢き逃/
ひきなおs /引き直;風邪を-す/
ひきなr /弾き鳴/
ひきとおs /引き通/
ひきとt /引き取/引取/
ひきとr /引き取/引取/
ひきとn /引き取/引取/
ひきとm /引き止/
ひきとc /引き取/引取/
ひきつづk /引き続/引続/
ひきつづi /引き続/引続/
ひきつt /引き攣/
ひきつr /引き連/引き攣/
ひきつn /引き攣/
ひきつk /引き付/引付/
ひきつi /引き継/引継/
ひきつg /引き継/引継/
ひきつc /引き攣/
ひきちぎt /引き千切/
ひきちぎr /引き千切/
ひきちぎn /引き千切/
ひきちぎc /引き千切/
ひきちがi /引き違;-い(戸)/引違/
ひきだs /引き出/引出/弾き出/
ひきたおs /引き倒;贔屓の-し/引倒/
ひきたt /引き立/引立/
ひきたc /引き立/引立/
ひきずりまわs /引きずり回/引き摺り回/
ひきずりだs /引きずり出/引き摺り出/
ひきずりこn /引きずり込/引き摺り込/
ひきずりこm /引きずり込/引き摺り込/
ひきずりおr /引きずり下/
ひきずt /引き摺/
ひきずr /引き摺/
ひきずn /引き摺/
ひきずc /引き摺/
ひきしめr /引き締め;※送り位置補正/
ひきしぼt /引き絞/
ひきしぼr /引き絞/
ひきしぼn /引き絞/
ひきしぼc /引き絞/
ひきしm /引き締/引締/
ひきさt /引き去/
ひきさr /引き去/
ひきさn /引き去/
ひきさk /引き裂/
ひきさi /引き裂/
ひきさg /引き下/引下/
ひきさc /引き去/
ひきころs /轢き殺/
ひきこn /引き込/
ひきこm /引き込/引込/
ひきくらb /引き比/
ひきがたt /弾き語/
ひきがたr /弾き語/
ひきがたn /弾き語/
ひきがたc /弾き語/
ひきかえs /引き返/
ひきかe /引き換/引き替/引換/引替/
ひきおとs /引き落/
ひきおこs /引き起/引き起こ;※送り位置補正/
ひきおr /引き下/
ひきおk /引き起/惹き起;cause/
ひきうつs /引き写;文献を-/
ひきうk /引き受/引受/
ひきいr /引き入;仲間に-れる/
ひきあわs /引き合/
ひきあw /引き合/
ひきあu /引き合/
ひきあt /引き当/引当/引き合/
ひきあo /引き合/
ひきあi /引き合/引合/
ひきあg /引き上/引き揚/引上/
ひきあe /引き合/
ひきあc /引き合/
ひきw /率/
ひきi /率/
ひがしむk /東向/
ひがえr /日帰/
ひがw /日替/日変/
ひがn /僻/
ひがm /僻/
ひがk /日掛/
ひかりかがやk /光り輝/光輝/
ひかりかがやi /光り輝/光輝/
ひからb /干涸/乾涸/
ひかt /光/
ひかr /光/
ひかn /光/
ひかe /控/
ひかc /光/
ひえこn /冷え込/
ひえこm /冷え込/
ひえきt /冷え切/
ひえきr /冷え切/
ひえきn /冷え切/
ひえきc /冷え切/
ひいr /火入/
ひいd /秀/
ひあそb /火遊/
ひあg /干上/乾上/
ひy /冷/
ひt /引/放;屁を放る/
ひs /比/秘/引;-っさげる/
ひr /干/放;屁を放る/
ひp /引/
ひn /陳;-ねる,-ねこびた/非;似て非なる/冷;-んやり/放;屁を放る/
ひm /秘/祕;「秘」の旧字(人名用漢字)/
ひk /引/弾;ピアノを弾く/挽;コーヒー豆を挽く/退;軍を退く/碾;麦を碾く/轢;轢き殺す/曳;山車を曳く/牽;綱を牽く/索;見出しを索く/惹;(attract)心を惹かれる/魅;≒惹く/彈;「弾」の旧字(人名用漢字)/
ひi /引/弾;ピアノを弾く/挽;コーヒー豆を挽く/索;見出しを索く/彈;「弾」の旧字(人名用漢字)/退;軍を退く/碾;麦を碾く/轢;轢き殺す/曳;山車を曳く/牽;綱を牽く/惹;(attract)心を惹かれる/魅;≒惹く/
ひe /冷/
ひc /放;屁を放る/
ぱらw /払/
ぱらu /払/
ぱらt /払/
ぱらo /払/
ぱらi /払/
ぱらe /払/
ぱらc /払/
ぱにくt /パニク/
ぱにくr /パニク/
ぱにくn /パニク/
ぱにくc /パニク/
ぱにk /パニ/
ぱなs /放/
ぱしt /走/
ぱしr /走/
ぱしn /走/
ぱしc /走/
ぱくt /パク/
ぱくr /パク/
ぱくn /パク/
ぱくc /パク/
ぱt /張/
ぱr /張/
ぱn /張/
ぱc /張/
ばんごうづk /番号付/
ばんくるw /番狂/
ばれz /バレ/
ばれy /バレ/
ばれt /バレ/
ばれs /バレ/
ばれr /バレ/
ばれn /バレ/
ばれm /バレ/
ばれk /バレ/
ばれc /バレ/
ばらまk /散蒔/ばら撒/
ばらまi /ばら撒/散蒔/
ばらs /バラ/
ばらk /散/
ばらi /払/祓;悪魔祓い/拂;「払」の旧字(人名用漢字)/
ばやs /早/
ばやk /早/
ばやi /早/
ばやg /早/
ばなしs /話/
ばなr /離/
ばつぐんd /抜群/
ばっs /罰/
ばちがi /場違/
ばちあたr /罰当/
ばちあt /罰当/
ばたらk /働/
ばたくさs /バタ臭/
ばたくさk /バタ臭/
ばたくさi /バタ臭/
ばたくさg /バタ臭/
ばしt /走/
ばしr /走/
ばしn /走/
ばしc /走/
ばさn /挟/
ばさm /挟/
ばくs /縛;緊縛/
ばかよb /馬鹿呼/
ばかばかs /馬鹿馬鹿/バカバカ/
ばかたかs /馬鹿高;形容詞[φik(sg)]/バカ高/
ばかたかk /馬鹿高;形容詞[φik(sg)]/バカ高/
ばかたかi /馬鹿高;形容詞[φik(sg)]/バカ高/
ばかたかg /馬鹿高;形容詞[φik(sg)]/バカ高/
ばかくさs /馬鹿臭/
ばかくさk /馬鹿臭/
ばかくさi /馬鹿臭/
ばかくさg /馬鹿臭/
ばかt /馬鹿/
ばかs /魅/
ばかr /許/馬鹿/
ばかg /馬鹿;馬鹿げた/
ばいちかs /倍近/
ばいちかk /倍近/
ばいちかi /倍近/
ばいちかg /倍近/
ばいs /倍;double.「味方に倍する勢力」/陪;お供する。「宴席に陪する」/
ばあいわk /場合分/
ばあt /場当/
ばt /張/貼/
ばs /馳/
ばr /張/晴/貼/
ばn /張/貼/
ばk /化/
ばi /這/
ばc /張/貼/
はんびらk /半開/
はんとしちかs /半年近/
はんとしちかk /半年近/
はんとしちかi /半年近/
はんとしちかg /半年近/
はんていがt /判定勝/
はんていがc /判定勝/
はんだづk /半田付/
はんだずk /半田付/
はんそくまk /反則負/
はんごろs /半殺/
はんぐm /版組/
はんかくさs /半可臭;北海道方言/
はんかくさk /半可臭;北海道方言/
はんかくさi /半可臭;北海道方言/
はんかくさg /半可臭;北海道方言/
はんえいs /反映/
はんz /判/
はんs /反/
はんj /判/
はわたr /刃渡/
はれわたt /晴れ渡/
はれわたr /晴れ渡/
はれわたn /晴れ渡/
はれわたc /晴れ渡/
はればr /晴れ晴/
はれあg /腫れ上/
はるやすm /春休/
はるm /春/
はるk /遥/遼/遙;「遥」の旧字(人名用漢字)/
はりわたs /張り渡/
はりめぐr /張り巡/
はりまわs /張り回/
はりつけr /貼り付け;※送り位置補正/
はりつm /張り詰/
はりつk /貼り付/張り付/
はりつi /張り付/貼り付/
はりだs /張り出/貼り出/
はりたおs /張り倒/撲り倒/
はりさs /針刺/
はりさk /張り裂/
はりこn /張り込/貼り込;paste.「画像を-」/はり込/
はりこm /張り込/貼り込;paste.「画像を-」/はり込/
はりきt /張り切/
はりきr /張り切/
はりきn /張り切/
はりきc /張り切/
はりかe /貼り替/張り替/
はりあわs /貼り合/
はりあw /貼り合/張り合/
はりあu /張り合/
はりあt /張り合/
はりあo /張り合/
はりあi /張合/張り合/
はりあg /張り上/
はりあe /張り合/
はりあc /張り合/
はらへt /腹減/
はらへr /腹減/
はらへn /腹減/
はらへc /腹減/
はらばi /腹這/
はらちがi /腹違/
はらだt /腹立/
はらたt /腹立/
はらたc /腹立/
はらごしらe /腹拵/
はらぐろs /腹黒/
はらぐろk /腹黒/
はらぐろi /腹黒/
はらぐろg /腹黒/
はらきr /腹切/
はらがまe /腹構/
はらいわたs /払い渡/
はらいもどs /払い戻/払戻/
はらいのk /払い除/
はらいだs /払出/
はらいさg /払い下/払下/
はらいこn /払い込/払込/
はらいこm /払い込/払込/
はらいきよm /祓い清/
はらいs /腹癒/
はらw /払/拂;「払」の旧字(人名用漢字)/祓;悪霊を祓う/掃;ススを掃う/禳;≒祓う/
はらu /払/祓;悪霊を祓う/掃;ススを掃う/禳;≒祓う/拂;「払」の旧字(人名用漢字)/
はらt /払/拂;「払」の旧字(人名用漢字)/祓;悪霊を祓う/掃;ススを掃う/禳;≒祓う/
はらo /払/拂;「払」の旧字(人名用漢字)/祓;悪霊を祓う/掃;ススを掃う/禳;≒祓う/
はらn /孕/
はらm /孕/
はらi /払/祓;お祓い/拂;「払」の旧字(人名用漢字)/掃;ススを掃う/禳;≒祓う/
はらh /掃/払/祓/拂;「払」の旧字(人名用漢字)/
はらe /払/拂;「払」の旧字(人名用漢字)/祓;悪霊を祓う/掃;ススを掃う/禳;≒祓う/
はらc /払/祓;悪霊を祓う/掃;ススを掃う/禳;≒祓う/拂;「払」の旧字(人名用漢字)/
はよu /早/
はゆs /映/
はゆk /映/
はゆi /映/
はゆg /映/
はやりたt /逸り立/
はやだs /早出/
はやすg /早過/速過/
はやしたt /囃し立/
はやざk /早咲/
はやぐi /早食/
はやがわr /早変/
はやがえr /早帰/
はやおくr /早送/
はやおk /早起/
はやうt /早打/
はやいものがt /早い者勝/
はやt /流行/逸;気が逸る/早;≒逸る/
はやs /速;(quick)「足が速い」「速い仕事」/早;(early)「朝早い」「早い時期」/囃/疾;(矢のように速い)/捷;(動作・反応がはやい)/
はやr /流行/逸;気が逸る/早;≒逸る/
はやn /流行/逸;気が逸る/早;≒逸る/
はやm /早/速/
はやk /早;(early)「朝早い」「早い時期」/速;(quick)「足が速い」「速い仕事」/疾;(矢のように速い)/捷;(動作・反応がはやい)/
はやi /早;(early)「朝早い」「早い時期」/速;(quick)「足が速い」「速い仕事」/疾;(矢のように速い)/捷;(動作・反応がはやい)/
はやg /早;(early)「朝早い」「早い時期」/速;(quick)「足が速い」「速い仕事」/疾;(矢のように速い)/捷;(動作・反応がはやい)/
はやc /流行/逸;気が逸る/早;≒逸る/
はもt /ハモ/
はもr /ハモ/
はもn /ハモ/
はもc /ハモ/
はめこn /嵌め込/
はめこm /嵌め込/
はめz /ハメ/
はめy /ハメ/
はめt /ハメ/
はめs /ハメ/
はめr /ハメ/
はめn /ハメ/
はめm /ハメ/
はめk /ハメ/
はめc /ハメ/
はみでz /はみ出/食み出/
はみでy /はみ出/食み出/
はみでt /はみ出/食み出/
はみでs /はみ出/食み出/
はみでr /はみ出/食み出/
はみでn /はみ出/食み出/
はみでm /はみ出/食み出/
はみでk /はみ出/食み出/
はみでc /はみ出/食み出/
はみだs /はみ出/食み出/
はみがk /歯磨/
はまべちかs /浜辺近/
はまべちかk /浜辺近/
はまべちかi /浜辺近/
はまべちかg /浜辺近/
はまちかs /浜近/
はまちかk /浜近/
はまちかi /浜近/
はまちかg /浜近/
はまt /嵌/填/
はまr /嵌/填/
はまn /嵌/填/
はまc /嵌/填/
はべt /侍/
はべr /侍/
はべn /侍/
はべc /侍/
はぶr /羽振/
はぶk /省/羽振/
はぶi /省/
はふr /放/
はびこt /蔓延/
はびこr /蔓延/
はびこn /蔓延/
はびこc /蔓延/
はばよs /幅寄/
はばひろs /幅広/
はばひろk /幅広/
はばひろi /幅広/
はばひろg /幅広/
はばたk /羽搏/羽撃/
はばたi /羽搏/羽撃/
はばかt /憚/
はばかr /憚/
はばかn /憚/
はばかc /憚/
はばn /阻/難;<rare> ≒阻む/
はばm /阻/難;<rare> ≒阻む/
はねまわt /跳ね回/
はねまわr /跳ね回/
はねまわn /跳ね回/
はねまわc /跳ね回/
はねのk /撥ね除/
はねっかえr /跳ねっ返;-り娘/
はねかえt /跳ね返/
はねかえs /跳ね返/撥ね返/
はねかえr /跳ね返/
はねかえn /跳ね返/
はねかえc /跳ね返/
はねおk /跳ね起/
はねあg /跳ね上/
はぬk /歯脱/
はなればなr /離れ離/
はならb /歯並/
はなもt /鼻持/
はなびe /花冷/
はなひらk /花開/
はなひらi /花開/
はなばなs /華々/花々/華華/
はなはだs /甚/
はなはd /甚/
はなづm /鼻詰/
はなつまm /鼻抓/
はなじろn /鼻白/
はなじろm /鼻白/
はなしつづk /話し続/
はなしだs /話し出/話出/
はなしずk /話好/
はなしこn /話し込/
はなしこm /話し込/
はなしがi /放し飼/
はなしかk /話し掛/
はなしあw /話し合/
はなしあu /話し合/
はなしあt /話し合/
はなしあo /話し合/
はなしあi /話し合/
はなしあe /話し合/
はなしあc /話し合/
はなしs /話/
はなざかr /花盛/
はなさk /花咲/
はなぐもr /花曇/
はなうr /花売/
はなy /華/花/
はなt /放/
はなs /話/離;(separate) 間を離す/放;(release) 犬を放す/
はなr /離/放/
はなc /放/
はどm /歯止/
はではでs /派手派手/
はてしなs /果てし無/
はてしなk /果てし無/
はてしなi /果てし無/
はてs /果て;※送り位置補正/
はづs /外/
はづr /外/
はづn /弾;旧仮名/勢;旧仮名/彈;「弾」の旧字(人名用漢字)/
はづm /弾;旧仮名/勢;旧仮名/彈;「弾」の旧字(人名用漢字)/
はづk /辱/恥/
はつのr /初乗/
はつすべr /初滑/
はつかおあw /初顔合/
はつうr /初売/
はっぽうふさg /八方塞/
はっせいs /発生/
はっこうs /発行/
はっきs /発揮/
はっs /発/發;「発」の旧字/
はっp /葉っ;※送り位置補正/
はちきr /はち切/
はちうe /鉢植/
はちあw /鉢合/
はだざわr /肌触/
はだざむs /肌寒/
はだざむk /肌寒/
はだざむi /肌寒/
はだざむg /肌寒/
はださむs /肌寒/
はださむk /肌寒/
はださむi /肌寒/
はださむg /肌寒/
はだかk /肌掛/
はだあi /肌合/
はだk /開/
はたらきすg /働き過/
はたらきかk /働き掛/
はたらk /働/
はたらi /働/
はたふr /旗振/
はたたk /羽撃/
はたたi /羽撃/
はたけちがi /畑違/
はたきこn /叩き込/
はたきこm /叩き込/
はたあg /旗揚/
はたs /果/
はたk /叩/
はたi /叩/
はせさんz /馳せ参/
はせさんj /馳せ参/
はせいs /派生/
はずかしm /辱/
はずかs /恥/恥ずか;※送り位置補正/
はずs /外/
はずr /外/
はずn /弾/勢/彈;「弾」の旧字(人名用漢字)/
はずm /弾/勢/機/彈;「弾」の旧字(人名用漢字)/
はずk /恥/
はすむかi /斜向/
はすうきりあg /端数切上/
はじけとn /弾け飛/
はじけとb /弾け飛/
はじきとb /弾き飛/
はじきだs /弾き出/
はじきかえs /弾き返/
はじいt /恥じ入/
はじいr /恥じ入/
はじいn /恥じ入/
はじいc /恥じ入/
はじm /初;(順序,未経験)「初めてのSKK」/始;(開始)「SKKを始める」「姫始め」/創/甫/
はじk /弾/
はじi /弾/
はしをr /端折/
はしわたs /橋渡/
はしりまわt /走り回/
はしりまわr /走り回/
はしりまわn /走り回/
はしりまわc /走り回/
はしりぬk /走り抜/
はしりぬi /走り抜/
はしりつづk /走り続/
はしりだs /走り出/
はしりすg /走り過/
はしりさt /走り去/
はしりさr /走り去/
はしりさn /走り去/
はしりさc /走り去/
はしりこn /走り込/
はしりこm /走り込/
はしりがk /走り書/
はしょt /端折/
はしょr /端折/
はしょn /端折/
はしょc /端折/
はしゃi /燥/
はしゃg /燥/
はしたs /端/
はしたn /端/
はしたd /端/
はしぞm /箸初/
はしおt /端折/
はしおr /端折/
はしおn /端折/
はしおk /箸置/
はしおc /端折/
はしt /走/端;-た(金)/奔;(急いではしる)/赱;「走」の異体字/迸;(にげる)/
はしr /走/迸;(にげる)/奔;(急いではしる)/赱;「走」の異体字/
はしn /走/迸;(にげる)/奔;(急いではしる)/赱;「走」の異体字/
はしc /走/迸;(にげる)/奔;(急いではしる)/赱;「走」の異体字/
はざわr /歯触/
はさみこn /挟み込/
はさみこm /挟み込/
はさみうt /挟み撃/
はさみうc /挟み撃/
はさn /挟/夾;≒挟む/挾;旧字/剪;鋏で切ること/鋏;鋏で切ること/
はさm /挟/夾;≒挟む/剪;鋏で切ること/鋏;鋏で切ること/挾;旧字/
はごたe /歯応/
はこびだs /運び出/
はこびこn /運び込/
はこびこm /運び込/
はこいr /箱入/
はこn /運/
はこb /運/
はげましあw /励まし合/
はげましあu /励まし合/
はげましあt /励まし合/
はげましあo /励まし合/
はげましあi /励まし合/
はげましあe /励まし合/
はげましあc /励まし合/
はげまs /励ま;※送り位置補正/
はげおt /剥げ落/
はげおc /剥げ落/
はげあg /禿げ上/
はげs /激/烈/劇/
はげn /励/勵;旧字/
はげm /励/勵;旧字/
はぐくn /育/毓;「育」の異体字/
はぐくm /育/毓;「育」の異体字/
はぐr /逸/
はくおs /箔押/
はくs /博;博覧会/
はぎとt /剥ぎ取/
はぎとr /剥ぎ取/
はぎとn /剥ぎ取/
はぎとc /剥ぎ取/
はぎしr /歯軋/
はぎあわs /接ぎ合/
はぎあw /接ぎ合/
はぎr /歯切/端切/
はきもどs /吐き戻/
はきちがe /履き違/
はきちr /吐き散;西瓜の種を-らす/
はきだs /掃き出/吐き出/はき出/
はきだi /掃き出;?/
はきすt /吐き捨/
はきさしもどs /破棄差戻/
はききよm /掃き清/
はがれおt /剥がれ落/
はがれおc /剥がれ落/
はがゆs /歯痒/齒痒;旧字/
はがゆk /歯痒/齒痒;旧字/
はがゆi /歯痒/齒痒;旧字/
はがゆg /歯痒/齒痒;旧字/
はがs /剥/
はがr /剥/
はがi /羽交;-い(締め)/
はかりしr /計り知/
はかりかn /計り兼/
はかりうr /量り売/
はかまいr /墓参/
はかばかs /捗々/
はかなs /儚/果敢無/果無/
はかなn /果無/
はかなm /果無/
はかなk /儚/果敢無/果無/
はかなi /儚/果敢無/果無/
はかなg /儚/果敢無/果無/
はかどt /捗/
はかどr /捗/
はかどn /捗/
はかどc /捗/
はかt /図;和解を図る/測;距離を測る/計;時間を計る,見計らう/諮;委員会に諮る/謀;暗殺を謀る/圖;「図」の旧字/量;体重を量る/企/
はかr /図;和解を図る/測;距離を測る/計;時間を計る,見計らう/量;体重を量る/諮;委員会に諮る/謀;暗殺を謀る/企/圖;「図」の旧字/
はかn /図;和解を図る/測;距離を測る/計;時間を計る,見計らう/量;体重を量る/諮;委員会に諮る/謀;暗殺を謀る/企/圖;「図」の旧字/
はかc /図;和解を図る/測;距離を測る/計;時間を計る,見計らう/量;体重を量る/諮;委員会に諮る/謀;暗殺を謀る/企/圖;「図」の旧字/
はおt /羽織/
はおr /羽織/
はおn /羽織/
はおc /羽織/
はえぬk /生え抜/
はえそろw /生え揃/
はえそろu /生え揃/
はえそろt /生え揃/
はえそろo /生え揃/
はえそろi /生え揃/
はえそろe /生え揃/
はえそろc /生え揃/
はえかわt /生え変/
はえかわr /生え変/
はえかわn /生え変/
はえかわc /生え変/
はえかw /生え変/
はえe /早/速/
はいりこn /入り込/
はいりこm /入り込/
はいよt /這い寄/
はいよr /這い寄/
はいよn /這い寄/
はいよc /這い寄/
はいまわt /這い回/
はいまわr /這い回/
はいまわn /這い回/
はいまわc /這い回/
はいのぼt /這い上/這い登/
はいのぼr /這い上/這い登/
はいのぼn /這い上/這い登/
はいのぼc /這い上/這い登/
はいでz /這い出/
はいでy /這い出/
はいでt /這い出/
はいでs /這い出/
はいでr /這い出/
はいでn /這い出/
はいでm /這い出/
はいでc /這い出/
はいつくばt /這い蹲/
はいつくばr /這い蹲/
はいつくばn /這い蹲/
はいつくばc /這い蹲/
はいちがe /配置換/
はいだs /這い出/
はいずりまわt /這いずり回/
はいずりまわr /這いずり回/
はいずりまわn /這いずり回/
はいずりまわc /這いずり回/
はいこn /這い込/
はいこm /這い込/
はいあg /這い上/
はいt /入/這入/
はいs /排;(排除) 抵抗を排する/廃;(廃止) 制度を廃する/拝;(拝観) 仏を拝する,後塵を拝する/配;(配置) 部下を配する/
はいr /入/這入/
はいn /入/這入/
はいc /入/這入/
はあくd /把握/
はz /恥/爆/羞/耻;「恥」の異体字/
はy /生/栄;栄やす(=褒めそやす)/映;≒栄やす/早/榮;「栄」の旧字(人名用漢字)/
はw /這/歯/齒;旧字/匍/
はu /這/匍/
はt /果/貼;(paste) 糊で貼る/張;ピンと張る/這/匍/
はs /馳/派/
はr /貼;(paste) 糊で貼る。「(チラシ|レッテル|URL)を-」/張;ピンと張る。「(弓|アンテナ|リンク)を-」/晴/腫;瞼が腫れる/脹;≒腫れる/霽;≒晴れる/膨;<rare> ≒腫れる (NB:「ふくr」と同形/
はo /這/匍/
はn /跳;(自動詞)/撥;(他動詞) 泥を撥ねる/食;-んで/刎;(首を)-ねる/貼;(paste) 糊で貼る/張;ピンと張る/
はm /食/嵌/填/
はk /掃/吐/捌;在庫が捌ける/履;靴を履く/穿;ズボンを穿く/帚;≒掃く/菷;「帚」の異体字/刷;ブラシで刷く/佩;剣を佩く/着/帶;「帯」の旧字(人名用漢字)/
はj /恥;(原義:きまり悪い)/羞;(原義:身の縮む)/愧/慙/耻;「恥」の異体字/
はi /吐/履;靴を履く/這/掃/匍/穿;ズボンを穿く/帚;≒掃く/菷;「帚」の異体字/刷;ブラシで刷く/佩;剣を佩く/剥/矧;矢を矧ぐ(=作る)/
はg /剥/禿/矧;矢を矧ぐ(=作る)/
はe /生/映;(contrast)「夕陽に映える」/栄;(glory)「栄えある」 NB:「さかe」と同形/榮;「栄」の旧字(人名用漢字)/暎;「映」の異体字/這/匍/
はd /恥/愧/慙/羞/耻;「恥」の異体字/
はc /這/匍/貼;(paste) 糊で貼る/張;ピンと張る/
はb /羽/
のろけt /惚気/
のろけr /惚気/
のろけn /惚気/
のろけc /惚気/
のろくさs /鈍臭/
のろくさk /鈍臭/
のろくさi /鈍臭/
のろくさg /鈍臭/
のろw /呪/詛/咒;「呪」の異体字/
のろu /呪/詛/咒;「呪」の異体字/
のろt /呪/詛/咒;「呪」の異体字/
のろs /呪/鈍;NB:「にぶi」と同形/
のろo /呪/詛/咒;「呪」の異体字/
のろk /呪/鈍;NB:「にぶi」と同形/
のろi /呪/鈍;NB:「にぶi」と同形/詛/咒;「呪」の異体字/
のろg /呪/鈍;NB:「にぶi」と同形/
のろe /呪/詛/咒;「呪」の異体字/
のろc /呪/詛/咒;「呪」の異体字/
のりまわs /乗り回/
のりづk /糊付/
のりつぶs /乗り潰/
のりつづk /乗り続/
のりつk /乗り付/
のりつi /乗り継/
のりつg /乗り継/
のりだs /乗り出/
のりそこなw /乗り損/
のりそこなu /乗り損/
のりそこなt /乗り損/
のりそこなo /乗り損/
のりそこなi /乗り損/
のりそこなe /乗り損/
のりそこなc /乗り損/
のりすごs /乗り過/
のりすt /乗り捨/
のりこs /乗り越/
のりこn /乗り込/
のりこm /乗り込/
のりこe /乗り越/乗り超;<rare>/
のりくn /乗り組/乗組/
のりくm /乗り組/乗組/
のりきt /乗り切/
のりきr /乗り切/
のりきn /乗り切/
のりきc /乗り切/
のりかかt /乗り掛/
のりかかr /乗り掛/
のりかかn /乗り掛/
のりかかc /乗り掛/
のりかk /乗り掛/
のりかe /乗り換/乗換/乗り替/乗替/
のりおくr /乗り遅/
のりうつt /乗り移/
のりうつr /乗り移/
のりうつn /乗り移/
のりうつc /乗り移/
のりいt /乗り入/
のりいr /乗り入/乗入/
のりいn /乗り入/
のりいc /乗り入/
のりあわs /乗り合/
のりあw /乗り合/
のりあu /乗り合/
のりあt /乗り合/
のりあo /乗り合/
のりあi /乗り合/
のりあe /乗り合/
のりあc /乗り合/
のりs /糊/
のやk /野焼/
のめりこn /のめり込/
のめりこm /のめり込/
のみほs /飲み干/飲み乾/
のみはじm /飲み始/
のみなおs /飲み直/
のみつぶr /飲み潰/
のみつづk /飲み続/
のみたおs /飲み倒/
のみたr /飲み足/
のみすg /飲み過/
のみこn /飲み込/飲込/呑み込/
のみこm /飲み込/飲込/呑み込/
のみくらb /飲み比/
のみくだs /飲み下;薬を-す/
のみあるk /飲み歩/
のみあるi /飲み歩/
のみあk /飲み明;(朝まで)-かす/飲み飽;-きる/
のぼりつm /上り詰/登り詰/
のぼせあg /逆上せ上/
のぼt /登;(climb)山に登る/昇;(ascend)日が昇る/上/騰/
のぼs /上;議題に上せる/逆上;(風呂で|女に)逆上せる/上気;≒逆上せる/
のぼr /登;(climb)山に登る/上/昇;(ascend)日が昇る/騰/
のぼn /登;(climb)山に登る/上/昇;(ascend)日が昇る/騰/
のぼc /登;(climb)山に登る/上/昇;(ascend)日が昇る/騰/
のべつまくなs /のべつ幕無/
のぶとs /野太/
のぶとk /野太/
のぶとi /野太/
のぶとg /野太/
のびなやn /伸び悩/
のびなやm /伸び悩/
のびきt /伸び切/延び切/
のびきr /伸び切/延び切/
のびきn /伸び切/延び切/
のびきc /伸び切/延び切/
のびあg /伸び上/
のばなs /野放/
のばs /延/
ののしりあw /罵り合/
ののしりあu /罵り合/
ののしりあt /罵り合/
ののしりあo /罵り合/
ののしりあi /罵り合/
ののしりあe /罵り合/
ののしりあc /罵り合/
ののしt /罵/
ののしr /罵/
ののしn /罵/
ののしc /罵/
ののs /罵;非正則(ののしr)/
のづm /野積/
のっぴk /退っ引;-き(ならない)/
のっとt /乗っ取;(take over)会社を乗っ取る/則;(conform)規定に則る/
のっとr /乗っ取;(take over)会社を乗っ取る/則;(conform)規定に則る/法/
のっとn /乗っ取;(take over)会社を乗っ取る/則;(conform)規定に則る/
のっとc /乗っ取;(take over)会社を乗っ取る/則;(conform)規定に則る/
のちぞe /後添/
のちn /後/
のたれじn /野垂れ死/
のたまわk /曰/
のたまw /宣;(字義:広く行き渡らせる)/曰;(字義:口に出す)/
のたまu /宣;(字義:広く行き渡らせる)/曰;(字義:口に出す)/
のたまt /宣;(字義:広く行き渡らせる)/曰;(字義:口に出す)/
のたまo /宣;(字義:広く行き渡らせる)/曰;(字義:口に出す)/
のたまi /宣;(字義:広く行き渡らせる)/曰;(字義:口に出す)/
のたまh /宣/曰/
のたまe /宣;(字義:広く行き渡らせる)/曰;(字義:口に出す)/
のたまc /宣;(字義:広く行き渡らせる)/曰;(字義:口に出す)/
のたうちまわt /のたうち回/
のたうちまわr /のたうち回/
のたうちまわn /のたうち回/
のたうちまわc /のたうち回/
のぞみみz /望み見/
のぞみみy /望み見/
のぞみみt /望み見/
のぞみみs /望み見/
のぞみみr /望み見/
のぞみみn /望み見/
のぞみみm /望み見/
のぞみみk /望み見/
のぞみみc /望み見/
のぞきみz /覗き見/
のぞきみy /覗き見/
のぞきみt /覗き見/
のぞきみs /覗き見/
のぞきみr /覗き見/
のぞきみn /覗き見/
のぞきみm /覗き見/
のぞきみk /覗き見/
のぞきみc /覗き見/
のぞきこn /覗き込/
のぞきこm /覗き込/
のぞs /除/覗/
のぞn /望/臨;(面対する) (海|死)に臨む/
のぞm /望/臨;(面対する) (海|死)に臨む/
のぞk /除/覗/覘;≒覗く/臨;≒覗く/
のぞi /除/覗/覘;≒覗く/臨;≒覗く/
のぞg /除/覗/
のしあるk /伸し歩/
のしあるi /伸し歩/
のしあg /伸し上/
のざらs /野晒/
のこりわずk /残り僅/
のこりすくn /残り少/
のこt /残/殘;「残」の旧字/遺/
のこs /残/遺;(後世に伝える) 財産を遺す/殘;「残」の旧字/
のこr /残/遺/殘;「残」の旧字/
のこn /残/遺/殘;「残」の旧字/
のこc /残/遺/殘;「残」の旧字/
のけぞt /のけ反/仰け反/
のけぞr /仰け反/のけ反/
のけぞn /仰け反/のけ反/
のけぞc /仰け反/のけ反/
のきなm /軒並/
のがs /逃/迯;「逃」の異体字/
のがr /逃/遁;字義:隠れてのがれる/逸;字義:走ってのがれる/迯;「逃」の異体字/
のうなs /能無/
のt /乗/載;雑誌に載る/乘;「乗」の旧字(人名用漢字)/
のs /載;(物理的)机に載せる, (出版物)論文を載せる/乗/伸;餅を伸す/熨;アイロンで熨す/乘;「乗」の旧字(人名用漢字)/
のr /乗/載;雑誌|荷台に載る/伸;伸るか反るか/乘;「乗」の旧字(人名用漢字)/
のn /飲;字義:液体をのむ/呑;字義:噛まずにのみ下す/嚥/飮;「飲」の旧字/乗/載;雑誌に載る/乘;「乗」の旧字(人名用漢字)/
のm /飲;字義:液体をのむ/呑;字義:噛まずにのみ下す/嚥/飮;「飲」の旧字/
のk /退;「立ち退く」「押し退ける」 NB:「しりぞk」と同形/除;(put aside)「取り除ける」/乗/載/
のi /退;「立ち退く」「押し退ける」 NB:「しりぞk」と同形/
のg /逃/迯;「逃」の異体字/
のc /乗/載;雑誌に載る/乘;「乗」の旧字(人名用漢字)/
のb /伸/述;意見を述べる/延;(時間的)予定が延びる/陳;≒述べる/
ねんばらi /年払/
ねんごr /懇/
ねんおs /念押/
ねんいr /念入/
ねんz /念/拈;ひねる/
ねんj /念/
ねりまz /練り混/
ねりなおs /練り直/
ねりこn /練り込/
ねりこm /練り込/
ねりかたm /練り固/煉り固/
ねりあるk /練り歩/
ねりあるi /練り歩/
ねりあw /練り合/
ねらいすm /狙い澄/
ねらいうt /狙い撃/
ねらいうc /狙い撃/
ねらw /狙/
ねらu /狙/
ねらt /狙/
ねらo /狙/
ねらi /狙/
ねらe /狙/
ねらc /狙/
ねもこr /懇;「ねんごろ」の古い形/
ねめまわs /睨め回/
ねめつk /睨め付/
ねむりこn /眠り込/
ねむりこm /眠り込/
ねむt /眠/睡;(字義:瞼を垂れる)/
ねむs /眠/
ねむr /眠/睡;(字義:瞼を垂れる)/
ねむn /眠/睡;(字義:瞼を垂れる)/
ねむk /眠/
ねむi /眠/
ねむg /眠/
ねむc /眠/睡;(字義:瞼を垂れる)/
ねみだr /寝乱/
ねまわs /根回/
ねぼk /寝惚/寝呆/
ねぶかs /根深/
ねぶかk /根深/
ねぶかi /根深/
ねぶかg /根深/
ねぶt /舐;(lick) 飴を舐る/眠;sleep/
ねぶr /舐;(lick) 飴を舐る/眠;sleep/
ねぶn /舐;(lick) 飴を舐る/眠;sleep/
ねぶm /値踏/
ねぶc /舐;(lick) 飴を舐る/眠;sleep/
ねびk /値引/
ねびi /値引/
ねびe /寝冷/
ねばりぬk /粘り抜/
ねばりぬi /粘り抜/
ねばりづよs /粘り強/
ねばりづよk /粘り強/
ねばりづよi /粘り強/
ねばりづよg /粘り強/
ねばりつk /粘り着/
ねばりつi /粘り着/
ねばつk /粘着/
ねばつi /粘着/
ねばt /粘/
ねばr /粘/
ねばn /粘/
ねばk /粘/
ねばc /粘/
ねなおs /寝直/
ねなs /根無/
ねとt /寝取/
ねとr /寝取/
ねとn /寝取/
ねとm /寝泊/
ねとc /寝取/
ねづよs /根強/
ねづよk /根強/
ねづよi /根強/
ねづよg /根強/
ねづかr /寝疲/
ねづm /根詰/
ねづk /根付/
ねづi /根付/
ねつp /熱/
ねつk /寝付/
ねつi /寝付/
ねっちゅうs /熱中/
ねっしんd /熱心/
ねっs /熱/
ねっk /根っ;※送り位置補正/
ねちがe /寝違/
ねだt /強請/
ねだr /強請/
ねだn /強請/
ねだm /寝溜/
ねだc /強請/
ねたs /妬/
ねたn /妬/嫉/
ねたm /妬/嫉/
ねたk /妬/
ねたg /妬/
ねずみとr /鼠取/
ねすごs /寝過/
ねすg /寝過/
ねじまg /捻じ曲/捩じ曲/ねじ曲/
ねじふs /捻じ伏/捩じ伏/ねじ伏/
ねじこn /捩じ込/ねじ込/
ねじこm /捩じ込/ねじ込/
ねじきt /捩じ切/
ねじきr /捩じ切/
ねじきn /捩じ切/
ねじきc /捩じ切/
ねじあg /捩じ上;腕を-/
ねじt /捻/捩/
ねじr /捻/捩/
ねじn /捻/捩/
ねじk /拗/
ねじc /捻/捩/
ねしずm /寝静/
ねざs /根差/
ねざm /寝覚/
ねさg /値下/
ねころn /寝転/
ねころg /寝転/
ねころb /寝転/
ねこかわいg /猫可愛/
ねこn /寝込/
ねこm /寝込/
ねぐるs /寝苦/
ねくずr /値崩/
ねぎらw /労/犒;飲食物で将兵を慰労すること/
ねぎらu /労/犒;飲食物で将兵を慰労すること/
ねぎらt /労/犒;飲食物で将兵を慰労すること/
ねぎらo /労/犒;飲食物で将兵を慰労すること/
ねぎらi /労/犒;飲食物で将兵を慰労すること/
ねぎらe /労/犒;飲食物で将兵を慰労すること/
ねぎらc /労/犒;飲食物で将兵を慰労すること/
ねぎt /値切/
ねぎr /値切/
ねぎn /値切/
ねぎc /値切/
ねがえt /寝返/
ねがえr /寝返/
ねがえn /寝返/
ねがえc /寝返/
ねがいでz /願い出/
ねがいでy /願い出/
ねがいでt /願い出/
ねがいでs /願い出/
ねがいでr /願い出/
ねがいでn /願い出/
ねがいでm /願い出/
ねがいでk /願い出/
ねがいでc /願い出/
ねがいさg /願い下/
ねがw /願/希;(字義:めったにないものを求める)/
ねがu /願/希;(字義:めったにないものを求める)/
ねがt /願/希;(字義:めったにないものを求める)/
ねがo /願/希;(字義:めったにないものを求める)/
ねがi /願/希;(字義:めったにないものを求める)/
ねがh /願/
ねがe /願/希;(字義:めったにないものを求める)/
ねがc /願/希;(字義:めったにないものを求める)/
ねかしつk /寝かし付/
ねおk /寝起/
ねえs /姉/
ねうごk /値動/
ねうt /値打/
ねうc /値打/
ねいt /寝入/
ねいr /寝入/
ねいn /寝入/
ねいc /寝入/
ねあらi /値洗/
ねあがr /値上/根上/
ねあk /寝明/
ねあg /値上/
ねz /寝/捻/捩/寢;「寝」の旧字(人名用漢字)/
ねy /寝/寢;「寝」の旧字(人名用漢字)/
ねw /寝/寢;「寝」の旧字(人名用漢字)/
ねu /寝/寢;「寝」の旧字(人名用漢字)/
ねt /寝/練;案を練る/寢;「寝」の旧字(人名用漢字)/錬;鉄を錬る/煉;煉り羊羹/粘;NB:「ねばr」と同形/
ねs /寝/寢;「寝」の旧字(人名用漢字)/
ねr /寝/練;案を練る/錬;鉄を錬る/煉;煉り羊羹/粘;NB:「ねばr」と同形/寢;「寝」の旧字(人名用漢字)/
ねp /寝/寢;「寝」の旧字(人名用漢字)/
ねo /寝/寢;「寝」の旧字(人名用漢字)/
ねn /寝/寢;「寝」の旧字(人名用漢字)/練;案を練る/錬;鉄を錬る/煉;煉り羊羹/粘;NB:「ねばr」と同形/
ねm /寝/睨/寢;「寝」の旧字(人名用漢字)/
ねk /寝/根/寢;「寝」の旧字(人名用漢字)/
ねj /捻/捩/寝/寢;「寝」の旧字(人名用漢字)/
ねi /寝/寢;「寝」の旧字(人名用漢字)/
ねh /寝/寢;「寝」の旧字(人名用漢字)/
ねg /寝/寢;「寝」の旧字(人名用漢字)/
ねe /寝/寢;「寝」の旧字(人名用漢字)/
ねd /寝/寢;「寝」の旧字(人名用漢字)/
ねc /寝/練;案を練る/錬;鉄を錬る/煉;煉り羊羹/粘;NB:「ねばr」と同形/寢;「寝」の旧字(人名用漢字)/
ねb /寝/寢;「寝」の旧字(人名用漢字)/
ねa /寝/寢;「寝」の旧字(人名用漢字)/
ぬるs /微温/温/
ぬるn /温/
ぬるm /微温/温/
ぬるk /微温/温/
ぬるi /微温/温/
ぬるg /微温/温/
ぬりわk /塗り分/
ぬりなおs /塗り直;外壁を-す/
ぬりつぶs /塗り潰/
ぬりつk /塗り付/
ぬりこn /塗り込/
ぬりこm /塗り込/
ぬりかたm /塗り固/
ぬりかe /塗り替/塗替/
ぬめt /滑;NB:「すべr」と同形/
ぬめr /滑;NB:「すべr」と同形/
ぬめn /滑;NB:「すべr」と同形/
ぬめc /滑;NB:「すべr」と同形/
ぬのきr /布切/
ぬのうr /布売/
ぬすみみz /盗み見/
ぬすみみy /盗み見/
ぬすみみt /盗み見/
ぬすみみs /盗み見/
ぬすみみr /盗み見/
ぬすみみn /盗み見/
ぬすみみm /盗み見/
ぬすみみk /盗み見/
ぬすみみc /盗み見/
ぬすみとt /盗み取/
ぬすみとr /盗み取/
ぬすみとn /盗み取/
ぬすみとc /盗み取/
ぬすみだs /盗み出/
ぬすみぐi /盗み食/
ぬすみぎk /盗み聞/
ぬすみぎi /盗み聞/
ぬすn /盗/偸/盜;「盗」の旧字(人名用漢字)/
ぬすm /盗/偸/盜;「盗」の旧字(人名用漢字)/
ぬけでz /抜け出/
ぬけでy /抜け出/
ぬけでt /抜け出/
ぬけでs /抜け出/
ぬけでr /抜け出/
ぬけでn /抜け出/
ぬけでm /抜け出/
ぬけでc /抜け出/
ぬけだs /抜け出/脱け出/
ぬけがk /抜け駆/
ぬけおt /抜け落/
ぬけおc /抜け落/
ぬぐいさt /拭い去/
ぬぐいさr /拭い去/
ぬぐいさn /拭い去/
ぬぐいさc /拭い去/
ぬぐw /拭/
ぬぐu /拭/
ぬぐt /拭/
ぬぐo /拭/
ぬぐi /拭/
ぬぐe /拭/
ぬぐc /拭/
ぬくs /温/
ぬくn /温/
ぬくm /温/
ぬくk /温/
ぬくi /温/
ぬくg /温/
ぬぎっぱなs /脱ぎっ放/
ぬぎすt /脱ぎ捨/
ぬきんでy /抜きん出/
ぬきんでt /抜きん出/
ぬきんでr /抜きん出/
ぬきんでn /抜きん出/
ぬきんでm /抜きん出/
ぬきはなt /抜き放;腰の物を-つ/
ぬきとおs /貫き通/
ぬきとt /抜き取/
ぬきとr /抜き取/
ぬきとn /抜き取/
ぬきとc /抜き取/
ぬきでz /抜き出/
ぬきでy /抜き出/
ぬきでt /抜き出/
ぬきでs /抜き出/
ぬきでr /抜き出/
ぬきでn /抜き出/
ぬきでm /抜き出/
ぬきでk /抜き出/
ぬきでc /抜き出/
ぬきだs /抜き出/
ぬきずr /抜き刷/
ぬきさt /抜き去/
ぬきさs /抜き差/
ぬきさr /抜き去/
ぬきさn /抜き去/
ぬきさc /抜き去/
ぬきがたs /抜き難/
ぬきがたk /抜き難/
ぬきがたi /抜き難/
ぬきがたg /抜き難/
ぬきうt /抜き打/抜き撃/抜打/
ぬきあw /抜き合/
ぬきあu /抜き合/
ぬきあt /抜き合/
ぬきあo /抜き合/
ぬきあi /抜き合/
ぬきあe /抜き合/
ぬきあc /抜き合/
ぬきn /抽/擢/
ぬかるn /泥濘/
ぬかるm /泥濘/
ぬかばたらk /糠働/
ぬかずk /額突;足許に-く/
ぬかずi /額突;足許に-く/
ぬかr /泥濘/
ぬいとt /縫取/縫い取/
ぬいとr /縫取/縫い取/
ぬいとn /縫取/縫い取/
ぬいとj /縫い閉/
ぬいとc /縫取/縫い取/
ぬいつk /縫い付/
ぬいこn /縫い込/
ぬいこm /縫い込/
ぬいあわs /縫い合/
ぬいあw /縫い合/
ぬいあg /縫い上/
ぬw /抜/縫/
ぬu /縫/
ぬt /塗/縫/
ぬr /塗/濡/
ぬo /縫/
ぬn /塗/
ぬk /抜/貫;NB:「つらぬk」と同形/脱/拔;「抜」の旧字(人名用漢字)/
ぬi /抜/脱/縫/貫;NB:「つらぬk」と同形/拔;「抜」の旧字(人名用漢字)/
ぬg /脱/
ぬe /縫/
ぬc /縫/塗/
にんめいs /任命/
にんげんばなr /人間離/
にんげんくさs /人間臭/
にんげんくさk /人間臭/
にんげんくさi /人間臭/
にんげんくさg /人間臭/
にんげんぎらi /人間嫌/
にんげんr /人間/
にんきうすs /人気薄/
にんきうすk /人気薄/
にんきうすi /人気薄/
にんきうすg /人気薄/
にんz /任/
にんj /任/
にわかs /俄/
にわかn /俄/
にわかd /俄/
にわk /俄/
にらみつk /睨み付/
にらみかえs /睨み返/
にらみあw /睨み合/
にらみあu /睨み合/
にらみあt /睨み合/
にらみあo /睨み合/
にらみあi /睨み合/
にらみあe /睨み合/
にらみあc /睨み合/
にらn /睨/眈;<rare> (字義:狙ってみつめる)/
にらm /睨/眈;<rare> (字義:狙ってみつめる)/
によt /似寄/
によr /似寄/
によn /似寄/
によc /似寄/
にゅうりょくまt /入力待/
にゅうりょくまc /入力待/
にまいげr /二枚蹴/
にぼs /煮干/
にほんじんごのm /日本人好/
にほんざs /二本差/
にほんごふきかe /日本語吹替/
にほんごうt /日本語打/
にほんごうc /日本語打/
にぶt /鈍/
にぶs /鈍/
にぶr /鈍/
にぶn /鈍/
にぶk /鈍/
にぶi /鈍/
にぶg /鈍/
にぶc /鈍/
にふくm /煮含/
にばんせんj /二番煎/
にはじm /煮始/
にぬk /煮抜/
にぬi /煮抜/
になw /担/擔;「担」の旧字/
になu /担/擔;「担」の旧字/
になt /担/擔;「担」の旧字/
になo /担/擔;「担」の旧字/
になi /担/擔;「担」の旧字/
になe /担/擔;「担」の旧字/
になc /担/擔;「担」の旧字/
にとおr /二通/
にとk /煮溶/
にづくr /荷造/
につまt /煮詰/
につまr /煮詰/
につまn /煮詰/
につまc /煮詰/
につm /煮詰/
につk /煮付/
にちょうなg /二丁投/
にちしゅくやすm /日祝休/
にだs /煮出/
にたt /煮立/
にたk /煮炊/
にたc /煮立/
にじりよt /躙り寄/
にじりよr /躙り寄/
にじりよn /躙り寄/
にじりよc /躙り寄/
にじりでy /躙り出/
にじりでt /躙り出/
にじりでs /躙り出/
にじりでr /躙り出/
にじりでn /躙り出/
にじりでm /躙り出/
にじゅううつs /二重写/
にじみでy /滲み出/
にじみでt /滲み出/
にじみでr /滲み出/
にじみでn /滲み出/
にじみでm /滲み出/
にじみだs /滲み出/
にじt /躙/
にじr /躙/
にじn /滲/躙/
にじm /滲/
にじc /躙/
にしむk /西向/
にしm /煮染/
にごt /濁/
にごs /濁/
にごr /濁/
にごn /濁/
にごc /濁/
にころg /煮転/
にこy /柔/和;NB:「なごy」と同形/
にこn /煮込/
にこm /煮込/
にげまわt /逃げ回/
にげまわr /逃げ回/
にげまわn /逃げ回/
にげまわc /逃げ回/
にげまどw /逃げ惑/
にげまどu /逃げ惑/
にげまどt /逃げ惑/
にげまどo /逃げ惑/
にげまどi /逃げ惑/
にげまどe /逃げ惑/
にげまどc /逃げ惑/
にげだs /逃げ出/
にげさt /逃げ去/
にげさr /逃げ去/
にげさn /逃げ去/
にげさc /逃げ去/
にげこn /逃げ込/
にげこm /逃げ込/
にげきt /逃げ切/
にげきr /逃げ切/
にげきn /逃げ切/
にげきc /逃げ切/
にげかくr /逃げ隠/
にげかえt /逃げ帰/
にげかえr /逃げ帰/
にげかえn /逃げ帰/
にげかえc /逃げ帰/
にげおくr /逃げ遅/
にげおおs /逃げ果/
にげおt /逃げ落/
にげおc /逃げ落/
にげうs /逃げ失/
にくみあw /憎み合/
にくみあu /憎み合/
にくみあt /憎み合/
にくみあo /憎み合/
にくみあi /憎み合/
にくみあe /憎み合/
にくみあc /憎み合/
にくばなr /肉離/
にくにくs /憎々/
にくづk /肉付/
にくづi /肉付/
にくずr /荷崩/煮崩/
にくおどt /肉踊/
にくおどr /肉踊/
にくおどn /肉踊/
にくおどc /肉踊/
にくt /憎/
にくs /憎/難;(hard) 考え難い NB:「がたi」と同形/悪;≒憎い/
にくr /憎/
にくn /憎/
にくm /憎/
にくk /憎/難;(hard) 考え難い NB:「がたi」と同形/悪;≒憎い/
にくi /憎/難;(hard) 考え難い NB:「がたi」と同形/悪;≒憎い/
にくg /憎/難;(hard) 考え難い NB:「がたi」と同形/悪;≒憎い/
にぎわw /賑/
にぎわu /賑/
にぎわt /賑/
にぎわo /賑/
にぎわi /賑/
にぎわe /賑/
にぎわc /賑/
にぎりつぶs /握り潰/
にぎりしm /握り締/
にぎはh /賑/
にぎにぎs /賑々/賑賑/
にぎy /賑/
にぎw /賑/
にぎt /握/
にぎr /握/
にぎn /握/
にぎc /握/
にきr /煮切;-り酒/
にがわらi /苦笑/
にがりきt /苦り切/
にがりきr /苦り切/
にがりきn /苦り切/
にがりきc /苦り切/
にがみばしt /苦み走/
にがみばしr /苦み走/
にがみばしn /苦み走/
にがみばしc /苦み走/
にがにがs /苦々/
にがs /苦/逃;非正則(にg)/
にがr /苦/
にがp /苦/
にがm /苦/
にがk /苦/
にがi /苦/
にがg /苦/
にかよw /似通/
にかよu /似通/
にかよt /似通/
にかよo /似通/
にかよi /似通/
にかよe /似通/
にかよc /似通/
におうだt /仁王立/
においたt /匂い立/
においたc /匂い立/
におy /匂;匂やか/
におw /匂/臭;(悪臭) 靴が臭う/
におu /匂/臭;(悪臭) 靴が臭う/
におt /匂/臭;(悪臭) 靴が臭う/
におr /荷下/
におo /匂/臭;(悪臭) 靴が臭う/
におi /匂;よい匂い/臭;いやな臭い/
におe /匂/臭;(悪臭) 靴が臭う/
におc /匂/臭;(悪臭) 靴が臭う/
にえたぎt /煮え滾/
にえたぎr /煮え滾/
にえたぎn /煮え滾/
にえたぎc /煮え滾/
にえたt /煮え立/
にえたc /煮え立/
にえくりかえt /煮え繰り返/
にえくりかえr /煮え繰り返/
にえくりかえn /煮え繰り返/
にえくりかえc /煮え繰り返/
にえきt /煮え切/
にえきr /煮え切/
にえきn /煮え切/
にえきc /煮え切/
にえs /贄/
にいt /兄/
にいs /兄/
にあw /似合/
にあu /似合/
にあt /似合/
にあo /似合/
にあi /似合/
にあg /荷揚/煮上/
にあe /似合/
にあc /似合/
にz /似/煮/
にy /煮/似/
にw /似/煮/
にu /似/煮/
にt /似/煮/
にs /似/煮/
にr /似/煮/
にp /似/煮/
にo /似/煮/
にn /似/荷/煮/
にm /似/煮/
にk /煮/似/
にj /似/煮/
にi /似/煮/
にh /似/煮/
にg /逃/迯;「逃」の異体字/似/煮/
にe /煮/似/
にd /似/煮/
にc /似/煮/
にb /似/煮/
にa /似/煮/
なんばんづk /南蛮漬/
なんなn /垂/
なんなk /難無/
なんとおr /何通/
なんz /難/何/
なんt /何/
なんr /何/
なんn /何/
なんk /何/
なんj /難/何/
なんd /何/
なわばr /縄張/
なれなれs /馴々/
なれそm /馴れ初/
なれしたs /慣れ親/
なれあw /馴れ合/
なれあu /馴れ合/
なれあt /馴れ合/
なれあo /馴れ合/
なれあi /馴れ合/
なれあe /馴れ合/
なれあc /馴れ合/
なるべk /成る可/
なりわたt /鳴り渡/
なりわたr /鳴り渡/
なりわたn /鳴り渡/
なりわたc /鳴り渡/
なりゆk /成り行/成行/
なりやn /鳴り止/
なりやm /鳴り止/
なりふr /形振/
なりひびk /鳴り響/
なりひびi /鳴り響/
なりはt /成り果/
なりだs /鳴り出/
なりたt /成り立/成立/
なりたc /成り立/成立/
なりすm /成り済/
なりさg /成り下/
なりきt /成り切/
なりきr /成り切/
なりきn /成り切/
なりきc /成り切/
なりかわt /成り代/
なりかわr /成り代/
なりかわn /成り代/
なりかわc /成り代/
なりかw /成り代/成り変/
なりあg /成り上/
ならべたt /並べ立/
ならべかe /並べ替/並べ換/並べ変/
ならびたt /並び立/
ならびたc /並び立/
ならびかe /並び換/
ならづk /奈良漬/
ならいおぼe /習い覚/
ならw /習/慣/倣;imitate.「先人に倣う」/肄;<rare> ≒習う/
ならu /習/倣;imitate.「先人に倣う」/肄;<rare> ≒習う/
ならt /習/倣;imitate.「先人に倣う」/肄;<rare> ≒習う/
ならs /均/
ならo /習/倣;imitate.「先人に倣う」/肄;<rare> ≒習う/
ならn /並/列;(行列を作る)「店の前に列ぶ」/竝;「並」の旧字/双;(匹敵する)「双ぶ者なし」/
ならi /習/倣;imitate.「先人に倣う」/肄;<rare> ≒習う/
ならh /習/
ならe /習/倣;imitate.「先人に倣う」/肄;<rare> ≒習う/
ならc /習/倣;imitate.「先人に倣う」/肄;<rare> ≒習う/
ならb /並/列;(行列を作る)「店の前に列ぶ」/双;(匹敵する)「双ぶ者なし」/竝;「並」の旧字/
なよs /名寄/
なやみおおk /悩み多/
なやn /悩/惱;旧字/
なやm /悩/惱;旧字/
なめらk /滑/
なめまわs /舐め回/嘗め回/
なめとt /舐め取/
なめとr /舐め取/
なめとn /舐め取/
なめとc /舐め取/
なめつくs /舐め尽;猫がミルクを-す/嘗め尽;辛酸を-す/
なめつk /嘗め尽;辛酸を-くす/舐め尽;蜜を-くす/
なめずt /舐/
なめずr /舐/
なめずn /舐/
なめずc /舐/
なめあw /舐め合/
なめあu /舐め合/
なめあt /舐め合/
なめあo /舐め合/
なめあi /舐め合/
なめあg /舐め上/
なめあe /舐め合/
なめあc /舐め合/
なめs /鞣/
なめr /滑/
なみはずr /並外/並み外/
なみのr /波乗/
なみだもろs /涙脆/
なみだもろk /涙脆/
なみだもろi /涙脆/
なみだもろg /涙脆/
なみだt /波立/
なみだs /涙/
なみだg /涙/
なみだc /波立/
なみうt /波打/
なみうc /波打/
なみいt /並み居;-る強豪たち/
なみいr /並み居;-る強豪たち/
なみs /蔑;サ変/
なまやさs /生易/
なまやk /生焼/
なまめs /艶/
なまめk /艶/
なまめi /艶/
なまめg /艶/
なまぬるs /生温/
なまぬるk /生温/
なまぬるi /生温/
なまぬるg /生温/
なまにe /生煮/
なまなまs /生々/生生/
なまっちろs /生っ白/
なまっちろk /生っ白/
なまっちろi /生っ白/
なまっちろg /生っ白/
なまじろs /生白/
なまじろk /生白/
なまじろi /生白/
なまじろg /生白/
なまじi /憖/
なまじh /憖/
なまごろs /生殺/
なまぐさs /生臭/腥/
なまぐさk /生臭/腥/
なまぐさi /生臭/腥/
なまぐさg /生臭/腥/
なまくr /鈍;名詞(-ら)/
なまがわk /生乾/
なまえまk /名前負/
なまえつk /名前付/
なまあたたk /生暖/
なまt /訛;発音が訛る/鈍;腕が鈍る/譌;「訛」の異体字/
なまs /生/
なまr /鈍;腕が鈍る/訛;発音が訛る/譌;「訛」の異体字/
なまn /鈍;腕が鈍る/訛;発音が訛る/譌;「訛」の異体字/生/
なまm /生/
なまk /怠/懶/
なまd /生/
なまc /鈍;腕が鈍る/訛;発音が訛る/譌;「訛」の異体字/
なほs /治/直/
なべt /並べ;※送り位置補正/
なぶりごろs /嬲り殺;-し/
なぶりころs /嬲り殺/
なぶt /嬲/嫐;<rare> =嬲る/
なぶr /嬲/嫐;<rare> =嬲る/
なぶn /嬲/嫐;<rare> =嬲る/
なぶc /嬲/嫐;<rare> =嬲る/
なびk /靡/
なびi /靡/
なのりでz /名乗り出/
なのりでy /名乗り出/
なのりでt /名乗り出/
なのりでs /名乗り出/
なのりでr /名乗り出/
なのりでn /名乗り出/
なのりでm /名乗り出/
なのりでk /名乗り出/
なのりでc /名乗り出/
なのt /名乗/名宣;<rare>/名告;=名乗る/
なのr /名乗/名告;=名乗る/名宣;<rare>/
なのn /名乗/名告;=名乗る/名宣;<rare>/
なのm /斜;[文語]/
なのc /名乗/名告;=名乗る/名宣;<rare>/
なにひとt /何一/
なにはさておk /何は扨措/
なにはさておi /何は扨措/
なにげなs /何気無/
なにげなk /何気無/
なにげなi /何気無/
なにげなg /何気無/
なにげn /何気/
なにくw /何食/何喰/
なにかんがe /何考/
なにかt /何彼/
なにw /何/
なにt /何/
なにs /何/
なにn /何/
なにm /何/
なにk /何/
なにg /何/
ななまがr /七曲/
ななころびやおk /七転び八起/
ななこおr /斜子織/魚子織/
ななt /七/
ななs /名無/
ななm /斜/
なでまわs /撫で回/
なでつk /撫で付/
なでさすt /撫で擦/
なでさすr /撫で擦/
なでさすn /撫で擦/
なでさすc /撫で擦/
なであg /撫で上/
なづけt /名付け;※送り位置補正/
なづn /泥/
なづm /泥/
なづk /名付/
なつやすm /夏休/
なつむk /夏向/
なつまつr /夏祭/
なつかs /懐/懷;「懐」の旧字(人名用漢字)/
なつk /懐/懷;「懐」の旧字(人名用漢字)/
なっとくいただk /納得頂/
なっとくいただi /納得頂/
なっとくいt /納得行/
なっとくいk /納得行/
なっとくいc /納得行/
なっとくs /納得/
なだれこn /雪崩れ込/傾れ込/なだれ込/
なだれこm /雪崩れ込/傾れ込/なだれ込/
なだめすかs /宥め賺/
なだかs /名高/
なだかk /名高/
なだかi /名高/
なだかg /名高/
なだt /名立/
なだr /雪崩/傾;(傾く。崩れ落ちる。)/
なだm /宥/
なぞらu /準/擬/准;「準」の略字/凖;「準」の異体字/
なぞらh /準/擬/准;「準」の略字/凖;「準」の異体字/
なぞらe /準/擬/准;「準」の略字/
なぞとk /謎解/
なぞかk /謎掛/
なぞm /謎/
なぜn /何故/
なずらu /準/擬/准;「準」の略字/凖;「準」の異体字/
なずらh /準/擬/准;「準」の略字/凖;「準」の異体字/
なずn /泥/
なずm /泥/
なすりつk /擦り付;NB:「こすりつk」「すりつk」と同形/
なすt /擦;NB:「こすr」「すr」と同形/
なすr /擦;NB:「こすr」「すr」と同形/
なすn /擦;NB:「こすr」「すr」と同形/
なすc /擦;NB:「こすr」「すr」と同形/
なじみぶかs /馴染み深/
なじみぶかk /馴染み深/
なじみぶかi /馴染み深/
なじみぶかg /馴染み深/
なじt /詰/
なじr /詰/
なじn /馴染/詰/
なじm /馴染/
なじc /詰/
なしとg /成し遂/為し遂/
なしくずs /済し崩/なし崩/
なしえz /為し得/
なしえy /為し得/
なしえt /為し得/
なしえs /為し得/
なしえr /為し得/
なしえn /為し得/
なしえm /為し得/
なしえc /為し得/
なしうr /為し得/
なしうb /為し得/
なざs /名指/
なさけぶかs /情深/情け深/
なさけぶかk /情深/情け深/
なさけぶかi /情け深/情深/
なさけぶかg /情け深/情深/
なさけなs /情無/情け無/
なさけなk /情無/情け無/
なさけなi /情無/情け無/
なさけなg /情無/情け無/
なさけしr /情け知/
なさk /情/
なごりおs /名残惜/
なごやk /和や;※送り位置補正/
なごy /和/
なごr /名残/
なごn /和/
なごm /和/
なげわたs /投げ渡/
なげやt /投げ遣/
なげやr /投げ遣/
なげやn /投げ遣/
なげやc /投げ遣/
なげづr /投げ釣/
なげつk /投げ付/
なげだs /投げ出/
なげすt /投げ捨;「テレビを窓から投げ捨てろ」/
なげこn /投げ込/投込/
なげこm /投げ込/投込/
なげきかなs /嘆き悲/
なげかえs /投げ返/
なげかk /投げ掛/
なげおt /投げ落/
なげおr /投げ下/
なげうt /抛/擲;≒抛つ/
なげうc /抛/擲;≒抛つ/
なげいr /投げ入/
なげあw /投げ合/
なげあu /投げ合/
なげあt /投げ合/
なげあo /投げ合/
なげあi /投げ合/
なげあg /投げ上/
なげあe /投げ合/
なげあc /投げ合/
なげk /嘆/歎;≒嘆く (字義:溜め息が出る)/慨;<rare> (字義:胸が詰まる)/
なげi /嘆/歎;≒嘆く (字義:溜め息が出る)/慨;<rare> (字義:胸が詰まる)/
なげe /長/
なけr /泣け;※送り位置補正/
なぐりつk /殴り付/
なぐりたおs /殴り倒/
なぐりころs /殴り殺/
なぐりこn /殴り込/
なぐりこm /殴り込/
なぐりかk /殴り掛/
なぐりあw /殴り合/
なぐりあu /殴り合/
なぐりあt /殴り合/
なぐりあo /殴り合/
なぐりあi /殴り合/
なぐりあe /殴り合/
なぐりあc /殴り合/
なぐさめあw /慰め合/
なぐさめあu /慰め合/
なぐさめあt /慰め合/
なぐさめあo /慰め合/
なぐさめあi /慰め合/
なぐさめあe /慰め合/
なぐさめあc /慰め合/
なぐさn /慰/
なぐさm /慰/
なぐt /殴/撲/毆;「殴」の旧字/擲/
なぐr /殴/撲/擲/毆;「殴」の旧字/
なぐn /殴/撲/擲/毆;「殴」の旧字/
なぐc /殴/撲/擲/毆;「殴」の旧字/
なくなk /泣く泣/
なぎはらw /薙ぎ払/
なぎはらu /薙ぎ払/
なぎはらt /薙ぎ払/
なぎはらo /薙ぎ払/
なぎはらi /薙ぎ払/
なぎはらe /薙ぎ払/
なぎはらc /薙ぎ払/
なぎたおs /薙ぎ倒/
なきわめk /泣き喚/
なきわめi /泣き喚/
なきわかr /泣き別/
なきやn /泣き止/鳴き止/
なきやm /泣き止/鳴き止/
なきふs /泣き伏/
なきはらs /泣き腫/
なきはr /泣き腫/
なきねいr /泣き寝入/
なきぬr /泣き濡/
なきつづk /泣き続/
なきつくs /泣き尽/
なきつかr /泣き疲/
なきつk /泣き付/
なきつi /泣き付/
なきだs /泣き出/
なきたt /泣き立/
なきそぼt /泣き濡/
なきしずn /泣き沈/
なきしずm /泣き沈/
なきしきt /鳴き頻;百舌が-る/泣き頻/
なきしきr /鳴き頻;百舌が-る/泣き頻/
なきしきn /鳴き頻;百舌が-る/泣き頻/
なきしきc /鳴き頻;百舌が-る/泣き頻/
なきさけn /泣き叫/
なきさけb /泣き叫/
なきくらs /泣き暮/
なきくずr /泣き崩/
なきくr /泣き暮/
なきかわs /鳴き交/
なきかw /鳴き交/
なきかr /泣き嗄/
なきおとs /泣き落/泣落/
なきおt /泣き落/
なきあk /泣き明/
ながれゆk /流れ行/
ながれでy /流れ出/
ながれでt /流れ出/
ながれでs /流れ出/
ながれでr /流れ出/
ながれでn /流れ出/
ながれでm /流れ出/
ながれつづk /流れ続/
ながれだs /流れ出/
ながれこn /流れ込/
ながれこm /流れ込/
ながれおt /流れ落/
ながれおc /流れ落/
ながれあるk /流れ歩/
ながれあるi /流れ歩/
ながらh /存/
ながらe /存;-える/
ながもt /長持/
ながもc /長持/
ながめやt /眺め遣/
ながめやr /眺め遣/
ながめやn /眺め遣/
ながめやc /眺め遣/
ながほそs /長細/
ながほそk /長細/
ながほそi /長細/
ながほそg /長細/
ながびs /長引/
ながびk /長引/
ながびi /長引/
ながびg /長引/
ながながs /長々/
ながつづk /長続/
ながすぎr /長過/
ながすg /長過/
ながしつづk /流し続/
ながしさt /流し去/
ながしさr /流し去/
ながしさn /流し去/
ながしさc /流し去/
ながしこn /流し込/
ながしこm /流し込/
ながしうt /流し打/
ながしうc /流し打/
ながいk /長生/
ながt /長/
ながs /流/長/永/
ながr /流/長;-らく,-らえる/永/乍;(助動詞) 聞き乍ら/存;(ながらe?)/
ながm /眺/長/詠;詩歌をうたう NB:「よm」と同形/
ながk /長/永/
ながi /長/永/
ながg /長/永/
ながb /長/
なかよs /仲良/
なかよk /仲良/
なかまわr /仲間割/
なかまはずr /仲間外/
なかまいr /仲間入/
なかぬk /中抜/
なかづr /中吊/
なかだるm /中弛/
なかだt /仲立/
なかだc /仲立/
なかたがi /仲違/
なかじm /中締/
なかおt /中落/
なかおs /中押/
なかt /中;中つ枝,中つ道,中つ国/
なかr /勿/莫;-れ/
なかn /中/
なかb /半/
なおよs /尚良/
なおっt /直/
なおt /直;故障が直る/治;ケガが治る/
なおs /直;故障を直す/治;病を治す/癒;NB:「いやs」と同形/
なおr /直;故障が直る/治;ケガが治る/
なおn /直;故障が直る/治;ケガが治る/
なおc /直;故障が直る/治;ケガが治る/
なうt /名う;※送り位置補正/
ないまz /綯い交/
ないがしr /蔑/
なz /撫/
なw /綯/
なu /綯/
なt /鳴/成/綯/生;実が生る/為/爲;「為」の旧字(人名用漢字)/
なs /無/成;財を成す (「作る」の意が強い)/為;業績を為す (「行う」の意が強い)/生;子を生す/做;見做す/爲;「為」の旧字(人名用漢字)/亡;(dead)父も今は亡い/
なr /慣/鳴/成/生;実が生る/馴;馴れた犬/為/熟;熟れ寿司/狎;人間関係について言う時の「なれる」/爲;「為」の旧字(人名用漢字)/
なo /綯/
なn /鳴/成/生;実が生る/為/爲;「為」の旧字(人名用漢字)/
なm /並/舐;(字義:ペロリとなめる)/嘗;(字義:舌に乗せて味を見る)/無;(神を)-みする(=蔑ろにする)/竝;「並」の旧字/
なk /泣/鳴/亡;(死なれる)「母を亡くす」/失;(字義:手から滑り落ちる)「財布を失くす」/無/啼;声を出して泣く／鳴く/哭;号泣する/涕;涙を流す/嚶;鳥が鳴く/啾;細い声で泣く/
なi /無/泣/鳴/亡;(dead)父も今は亡い/綯/凪;海が凪ぐ/啼;声を出して泣く／鳴く/哭;号泣する/涕;涙を流す/嚶;鳥が鳴く/啾;細い声で泣く/薙;薙ぎ倒す/
なh /綯/
なg /投/凪;海が凪ぐ/薙;薙ぎ倒す/無/
なe /萎/痿;<rare>/綯/
なd /撫/名;-だたる/
なc /綯/鳴/成/生;実が生る/為/爲;「為」の旧字(人名用漢字)/
なb /並;-べて/
どんづまr /どん詰/
どんづm /どん詰/
どんくさs /鈍臭/
どんくさk /鈍臭/
どんくさi /鈍臭/
どんくさg /鈍臭/
どんs /鈍/
どわすr /度忘/
どろよk /泥除/
どろくさs /泥臭/
どろくさk /泥臭/
どろくさi /泥臭/
どろくさg /泥臭/
どよm /響;どよめく/響動/
どもt /吃/
どもr /吃/土盛/
どもn /吃/
どもc /吃/
どなりつk /怒鳴り付/
どなりちr /怒鳴り散/
どなりたt /怒鳴り立/
どなりこn /怒鳴り込/
どなりこm /怒鳴り込/
どなりあw /怒鳴り合/
どなりあu /怒鳴り合/
どなりあt /怒鳴り合/
どなりあo /怒鳴り合/
どなりあi /怒鳴り合/
どなりあe /怒鳴り合/
どなりあc /怒鳴り合/
どなt /怒鳴/
どなr /怒鳴/
どなn /怒鳴/
どなc /怒鳴/
どすぐろs /どす黒/ドス黒/
どすぐろk /どす黒/ドス黒/
どすぐろi /どす黒/ドス黒/
どすぐろg /どす黒/ドス黒/
どしゃぶr /土砂降/
どしゃくづr /土砂崩/
どしがたs /度し難/
どしがたk /度し難/
どしがたi /度し難/
どしがたg /度し難/
どこm /何処/
どこk /何処/
どくどくs /毒々/
どくづk /毒突/
どくづi /毒突/
どくけs /毒消/
どくいr /毒入/
どくs /毒/
どおs /遠/通;(連濁) 負け通し,立ち通し,千枚通し/
どおr /通/
どおm /遠/
どおk /遠/
どおi /遠/
どおg /遠/
どうようn /同様/
どうまわr /胴回/
どうせきs /同席/
どうじょうやぶr /道場破/
どうじn /同時/
どうじm /胴締/
どうけt /道化/
どうけr /道化/
どうけn /道化/
どうけc /道化/
どうぐだt /道具立/
どうきづk /動機付/
どうあg /胴上/
どうz /動/同/
どうr /通;※仮名遣い「どお-り」/
どうj /動/同/
どあi /度合/
どt /取/録/
どs /度/
どr /取/録/何/
どn /何;-の/取/録/
どm /止/留;局留め,靴下留め,札留め/
どk /退/解/融/
どi /退/
どc /取/録/
とんぼがえr /蜻蛉返/
とんでゆk /飛んで行/
とんでいt /飛んで行/
とんでいk /飛んで行/
とんでいc /飛んで行/
とんがt /尖/
とんがr /尖/
とんがn /尖/
とんがc /尖/
とろs /トロ/
とろk /蕩/盪;<rare> ≒蕩/トロ;[口]/
とろi /トロ/
とろg /トロ/
とりわすr /取り忘/
とりわk /取り分/取分/
とりよs /取り寄/取寄/鳥寄/
とりやm /取り止/
とりもなおs /取りも直/
とりもどs /取り戻/
とりもt /取り持/
とりもc /取り持/
とりむすn /取り結/
とりむすb /取り結/
とりみだs /取り乱/
とりまわs /取り回/取回/
とりまとm /取り纏/
とりまぎr /取り紛/
とりまz /取り混/
とりまk /取り巻/取巻/
とりまi /取り巻/取巻/
とりひろg /取り広/
とりひk /取り引/取引/
とりはらw /取り払/
とりはらu /取り払/
とりはらt /取り払/
とりはらo /取り払/
とりはらi /取り払/
とりはらe /取り払/
とりはらc /取り払/
とりはずs /取り外/取外/
とりはこn /取り運/
とりはこb /取り運/
とりはかt /取り計/
とりはかr /取り計/
とりはかn /取り計/
とりはかc /取り計/
とりのぞk /取り除/取除/
とりのぞi /取り除/取除/
とりのこs /取り残/
とりのがs /取り逃/
とりのk /取り除/
とりにg /取り逃/
とりなおs /取り直/録り直;歌の-/撮り直;写真の-/
とりなs /執り成/取り成/
とりつぶs /取り潰/取潰/
とりつくろw /取り繕/取繕/
とりつくろu /取り繕/取繕/
とりつくろt /取り繕/取繕/
とりつくろo /取り繕/取繕/
とりつくろi /取り繕/取繕/
とりつくろe /取り繕/取繕/
とりつくろc /取り繕/取繕/
とりつくs /取り尽/
とりつk /取り付/取付/取り尽/取り憑;霊が取り憑く/
とりつi /取り付/取り次/取り憑;霊が取り憑く/取付/取次/
とりつg /取り次/取次/
とりちがe /取り違/
とりちr /取り散/
とりだs /取り出/取出/
とりたt /取り立/取立/
とりそろe /取り揃/
とりそこn /取り損/
とりすがt /取り縋;(袖に)-る/
とりすがr /取り縋;(袖に)-る/
とりすがn /取り縋;(袖に)-る/
とりすがc /取り縋;(袖に)-る/
とりすm /取り澄/
とりしらb /取調/取り調/
とりしまt /取締/取り締/
とりしまr /取締/取り締/取り締ま;※送り位置補正/
とりしまn /取締/取り締/
とりしまc /取締/取り締/
とりしきt /取り仕切/
とりしきr /取り仕切/
とりしきn /取り仕切/
とりしきc /取り仕切/
とりしm /取り締/取締/
とりさばk /取り捌/
とりさばi /取り捌/
とりさt /取り去/
とりさr /取り去/
とりさn /取り去/
とりさg /取り下/
とりさc /取り去/
とりこわs /取り壊/取壊/
とりころs /取り殺/
とりこぼs /取り零/
とりこs /取り越/
とりこn /取り込/取込/
とりこm /取り込/取込/
とりけs /取り消/取消/
とりくずs /取り崩/取崩/
とりくn /取り組/
とりくm /取り組/取組/
とりきt /取り切/
とりきr /取り切/
とりきn /取り切/
とりきm /取り決/取り極/
とりきc /取り切/
とりかわs /取り交/取交/
とりかたm /取り固/
とりかこn /取り囲/
とりかこm /取り囲/
とりかえs /取り返/
とりかw /取り交/取交/
とりかk /取り掛/
とりかe /取り替/取り換/
とりおとs /取り落/
とりおさe /取り抑/
とりおこなw /執り行/
とりおこなu /執り行/
とりおこなt /執り行/
とりおこなo /執り行/
とりおこなi /執り行/
とりおこなe /執り行/
とりおこなc /執り行/
とりおs /取り押/
とりおk /取り置/
とりおi /取り置/
とりえz /取り得/
とりえy /取り得/
とりえt /取り得/
とりえs /取り得/
とりえr /取り得/
とりえn /取り得/
とりえm /取り得/
とりえc /取り得/
とりうr /取り得/
とりうb /取り得/
とりいそi /取り急/
とりいそg /取り急/
とりいt /取り入/取入/
とりいr /取り入/取入/
とりいn /取り入/取入/
とりいc /取り入/取入/
とりあわs /取り合/
とりあらそw /取り争/
とりあらそu /取り争/
とりあらそt /取り争/
とりあらそo /取り争/
とりあらそi /取り争/
とりあらそe /取り争/
とりあらそc /取り争/
とりあつかw /取り扱/取扱/
とりあつかu /取り扱/取扱/
とりあつかt /取り扱/取扱/
とりあつかo /取り扱/取扱/
とりあつかi /取り扱/取扱/
とりあつかe /取り扱/取扱/
とりあつかc /取り扱/取扱/
とりあつm /取り集/
とりあw /取り合/取合/
とりあu /取り合/取合/
とりあt /取り合/取合/
とりあo /取り合/取合/
とりあi /取り合/取合/
とりあg /取り上/採り上/
とりあe /取り敢/取り合/取合/
とりあc /取り合/取合/
とらぶt /トラブ/
とらぶr /トラブ/
とらぶn /トラブ/
とらぶc /トラブ/
とらがr /虎刈/
とらw /囚;旧習に囚われる/捕;官憲に捕われる/捉/
とらk /蕩/盪/
とらh /囚/捉/捕/
とらe /捉;動きを捉える/捕;犯人を捕える/把/
ともばたらk /共働/
ともなw /伴/
ともなu /伴/
ともなt /伴/
ともなo /伴/
ともなi /伴/
ともなh /伴/
ともなe /伴/
ともなc /伴/
ともだおr /共倒/
ともぐi /共食/
ともかせg /共稼/
ともえなg /巴投/
ともt /灯/点/燈;「灯」の旧字(人名用漢字)/
ともs /灯/点/燈;「灯」の旧字(人名用漢字)/
ともr /灯/点/燈;「灯」の旧字(人名用漢字)/
ともn /共/伴/倶;-に/灯/点/燈;「灯」の旧字(人名用漢字)/
ともc /灯/点/燈;「灯」の旧字(人名用漢字)/
とめおk /留め置/
とめおi /留め置/
とむらw /弔/訪/
とむらu /弔/訪/
とむらt /弔/訪/
とむらo /弔/訪/
とむらi /弔/訪/
とむらe /弔/訪/
とむらc /弔/訪/
とみn /頓;-に(≒急に)/
とまりこn /泊まり込/
とまりこm /泊まり込/
とまどw /戸惑/
とまどu /戸惑/
とまどt /戸惑/
とまどo /戸惑/
とまどi /戸惑/
とまどe /戸惑/
とまどc /戸惑/
とまt /止/泊/停/留/佇/
とまr /泊/止/停/留/
とまn /泊/止/停/留/
とまc /泊/止/停/留/
とぼしi /乏し;※送り位置補正/
とぼs /乏/点/
とぼk /惚/恍/
とほのk /遠退/
とほs /通/徹/遠/
とほk /遠/
とほi /遠/
とほg /遠/
とぶらh /弔/訪/
とびまわt /飛び回/
とびまわr /飛び回/
とびまわn /飛び回/
とびまわc /飛び回/
とびはn /飛び跳/
とびのt /飛び乗/
とびのr /飛び乗/
とびのn /飛び乗/
とびのk /飛び退/跳び退/
とびのi /飛び退/跳び退/
とびのc /飛び乗/
とびぬk /飛び抜/
とびとb /飛び飛/
とびでz /飛び出/
とびでy /飛び出/
とびでt /飛び出/
とびでs /飛び出/
とびでr /飛び出/
とびでn /飛び出/
とびでm /飛び出/
とびでk /飛び出/
とびでc /飛び出/
とびつk /飛び付/
とびつi /飛び付/
とびちt /飛び散/
とびちr /飛び散/
とびちn /飛び散/
とびちc /飛び散/
とびだs /飛び出/飛出/
とびたt /飛び立/
とびたc /飛び立/
とびすさt /飛び退/
とびすさr /飛び退/
とびすさn /飛び退/
とびすさc /飛び退/
とびさt /飛び去/
とびさr /飛び去/
とびさn /飛び去/
とびさc /飛び去/
とびこs /飛び越/
とびこn /飛び込/飛込/
とびこm /飛び込/飛込/
とびこe /飛び越/跳び越/飛越/跳越/
とびかw /飛び交/
とびかu /飛び交/
とびかt /飛び交/
とびかo /飛び交/
とびかi /飛び交/
とびかe /飛び交/
とびかc /飛び交/
とびおr /飛び降/飛び下/
とびおk /飛び起/
とびうつt /飛び移/
とびうつr /飛び移/
とびうつn /飛び移/
とびうつc /飛び移/
とびいt /飛び入/飛入/
とびいr /飛び入/飛入/
とびいn /飛び入/飛入/
とびいc /飛び入/飛入/
とびあるk /飛び歩/
とびあるi /飛び歩/
とびあg /飛び上/跳び上/
とばs /飛/
となりあw /隣り合/隣合/
となりあu /隣合/隣り合/
となりあt /隣り合/隣合/
となりあo /隣合/隣り合/
となりあi /隣合/隣り合/
となりあe /隣合/隣り合/
となりあc /隣合/隣り合/
となr /隣/鄰;「隣」の異体字/
となh /唱/称/
となe /唱/称;(call) 名を称える NB:「たたe」と同形/稱;「称」の異体字/
とどろk /轟/軣;「轟」の異体字/
とどろi /轟/軣;「轟」の異体字/
とどまt /滞/
とどこおt /滞/滯;「滞」の旧字(人名用漢字)/
とどこおr /滞/滯;「滞」の旧字(人名用漢字)/
とどこおn /滞/滯;「滞」の旧字(人名用漢字)/
とどこおc /滞/滯;「滞」の旧字(人名用漢字)/
とどけでz /届け出/
とどけでy /届け出/
とどけでt /届け出/届出/
とどけでs /届け出/
とどけでr /届け出/届出/
とどけでn /届け出/届出/
とどけでm /届け出/
とどけでk /届け出/
とどけでc /届け出/届出/
とどm /留/止/停/畄;「留」の異体字/
とどk /届/屆;「届」の旧字/
とどi /届/屆;「届」の旧字/
ととのえr /整;非正則(ととのe)/
ととのw /整/調;支度|縁談が調う/斉/
ととのu /整/調;支度|縁談が調う/斉/
ととのt /整/調;支度|縁談が調う/斉/
ととのo /整/調;支度|縁談が調う/斉/
ととのi /整/調;支度|縁談が調う/斉/
ととのh /整/斉/調/
ととのe /整/調;準備を調える/斉/
ととのc /整/調;支度|縁談が調う/斉/
とてm /迚/
とつi /嫁/
とつg /嫁/
とっぱらw /取っ払/
とっぱらu /取っ払/
とっぱらt /取っ払/
とっぱらo /取っ払/
とっぱらi /取っ払/
とっぱらe /取っ払/
とっぱらc /取っ払/
とってつk /取って付/
とってかわt /取って代/
とってかわr /取って代/
とってかわn /取って代/
とってかわc /取って代/
とってかえs /取って返/
とってかw /取って代/
とっておk /取って置/
とっておi /取って置/
とっつかm /取っ捕/
とっつk /取っ付/
とっつi /取っ付/
とっしんs /突進/
とっくみあw /取っ組み合/
とっくみあu /取っ組み合/
とっくみあt /取っ組み合/
とっくみあo /取っ組み合/
とっくみあi /取っ組み合/
とっくみあe /取っ組み合/
とっくみあc /取っ組み合/
とっくn /取っ組/
とっくm /取っ組/
とっかかt /取っ掛/
とっかかr /取っ掛/
とっかかn /取っ掛/
とっかかc /取っ掛/
とっかk /取っ掛/
とっかe /取っ替/
とっk /疾っ;※送り位置補正/
とだe /途絶/跡絶/
とじまr /戸締/
とじこもt /閉じ籠/
とじこもr /閉じ籠/
とじこもn /閉じ籠/
とじこもc /閉じ籠/
とじこn /綴じ込/
とじこm /閉じ込/綴じ込/
とじあw /綴じ合/
とじm /戸締/
としよt /年寄/
としよr /年寄/
としよn /年寄/
としよc /年寄/
としとt /年取/
としとr /年取/
としとn /年取/
としとc /年取/
としこs /年越/
としおi /年老/
としあk /年明/
とざs /鎖/閉;非正則(とz)/
ところてんつk /心太突/
ところせまs /所狭/
ところせu /所狭/
ところせs /所狭/
ところせk /所狭/
ところかまw /所構/
とこずr /床擦/
とこs /常/
とげとげs /刺々/刺刺/
とけだs /溶け出/
とけこn /溶け込/
とけこm /溶け込/
とけあw /溶け合/
とけあu /溶け合/
とけあt /溶け合/
とけあo /溶け合/
とけあi /溶け合/
とけあc /溶け合/
とくべつあつかi /特別扱/
とくべつn /特別/
とくばらi /特払/
とくちょうづk /特徴付/
とくs /得/督;利払いを-する/
とくn /特;-に/得;-な(話)/
とくj /得/
とくd /得/
とぎれr /途切れ;※送り位置補正/
とぎすm /研ぎ澄/
とぎr /途切/跡切/
ときほぐs /溶き解;卵を-します/
ときふs /説き伏/
ときはなt /解き放/
ときはなs /解き放/
ときはなc /解き放/
ときつk /説き付/
ときおよn /説き及/
ときおよb /説き及/
ときあk /解き明/説き明/
ときn /時/
ときm /時/
とがめだt /咎め立/
とがt /尖/
とがr /尖/
とがn /尖/
とがm /咎/
とがc /尖/
とおりぬk /通り抜/
とおりすi /通り過;?/
とおりすg /通り過/
とおりこs /通り越/
とおりがk /通り掛/
とおりかかt /通り掛/
とおりかかr /通り掛/
とおりかかn /通り掛/
とおりかかc /通り掛/
とおまわs /遠回/
とおまわr /遠回/
とおまk /遠巻/
とおぼe /遠吠/
とおのr /遠乗/
とおのk /遠退/遠の;※送り位置補正/
とおのi /遠退/
とおすg /遠過/
とおz /遠/
とおt /通/透/徹/
とおs /通/遠/徹;自分のやり方で徹す (NB:「てっs」と同形)/透;光を透す/
とおr /通/透/徹/
とおn /遠/通/透/徹/
とおm /遠/
とおk /遠/
とおi /遠/
とおg /遠/
とおc /通/透/徹/
とうろくs /登録/
とうとu /疾う疾/
とうとs /尊/貴/
とうとn /尊;(respect) 仏法を尊ぶ/貴;(value) 和を貴ぶ/
とうとk /尊/貴/
とうとi /尊/貴/
とうとg /尊/貴/
とうとb /尊;(respect) 仏法を尊ぶ/貴;(value) 和を貴ぶ/
とうぜんn /当然/
とうすg /遠過/
とうじつうr /当日売/
とうこうs /投稿/
とうけつs /凍結/
とうz /投/
とうt /通;※仮名遣い「とお-って」/
とうs /通;※仮名遣い「とお-す」/父/
とうr /通;※仮名遣い「とお-る」/
とうn /当/
とうj /投/
といなおs /問い直/問直/
といつm /問い詰;小一時間問い詰めたい/問詰/
といただs /問い質/
といかえs /問い返/
といかk /問い掛/問掛;名詞・カ行下一/
といあわs /問合/問い合わ;※送り位置補正/
といあw /問い合/問合/
とz /閉/綴/閇;「閉」の異体字/
とw /問/訪;祖国を訪う/
とu /問/疾/訪;祖国を訪う/
とt /取/採;案を-/撮;写真を-/録;DVDを-/盗;(steal)金を-/捕;鼠を-/脱/獲;賞を-/摂;養分を-/執;指揮を-/穫;(harvest)野菜を-/秉;(手にとる)/
とs /賭;賭博/
とr /取/撮;写真を-/採;案を-/摂;養分を-/捕;鼠を-/獲;賞を-,クジラを-/録;DVDを-/執;指揮を-/盗;(steal)金を-/穫;(harvest)野菜を-/脱;<rare> 帽子を-/秉;(手にとる)/
とp /取/
とo /問/訪;祖国を訪う/
とn /飛;fly/富/跳;jump/翔;take wing/取;[口]-んないと/撮;写真を-/採;案を-/摂;養分を-/捕;鼠を-/獲;賞を-/録;DVDを-/執;指揮を-/盗;(steal)金を-/穫;(harvest)野菜を-/秉;(手にとる)/冨;「富」の旧字(人名用漢字)/脱;<rare> 帽子を-/
とm /止/泊;宿に泊まる/富/留;気に留める/停;(park)車を停める/冨;「富」の旧字(人名用漢字)/畄;「留」の異体字/
とk /解;謎|包装を解く/説;(preach)教えを説く/溶;水に溶ける/融;熱で融ける/疾/梳;髪を梳く NB:「すk」と同形/熔;鉄を熔かす/鎔;「熔」の異体字/觧;「解」の異体字/
とj /閉/綴/閇;「閉」の異体字/
とi /問/解;謎|秘密を解く/説;(preach)教えを説く/研;庖丁を研ぐ/觧;「解」の異体字/訪;祖国を訪う/溶;水に溶ける/梳;髪を梳く NB:「すk」と同形/熔;鉄を熔かす/鎔;「熔」の異体字/磨;お米を磨ぐ (「研ぐ」も可)/砥;≒研ぐ/
とh /問/
とg /遂/研;庖丁を研ぐ/磨;お米を磨ぐ (「研ぐ」も可)/砥;≒研ぐ/
とe /問/訪;祖国を訪う/
とd /綴/閉/
とc /取/撮;写真を-/採;案を-/摂;養分を-/捕;鼠を-/獲;賞を-/録;DVDを-/執;指揮を-/盗;(steal)金を-/穫;(harvest)野菜を-/秉;(手にとる)/脱;<rare> 帽子を-/
とb /飛;fly/跳;jump/翔;take wing/
でんちぎr /電池切/
でんげんぬk /電源抜/
でんげんぎr /電源切/
でんげんいr /電源入/
でやすs /出易/
でやすk /出易/
でやすi /出易/
でやすg /出易/
でもどt /出戻/
でもどr /出戻/
でもどn /出戻/
でもどc /出戻/
でむかe /出迎/
でむk /出向/
でむi /出向/
でまわt /出回/
でまわr /出回/
でまわn /出回/
でまわc /出回/
でまかs /出任/
でばらw /出払/
でばらu /出払/
でばらt /出払/
でばらo /出払/
でばらi /出払/
でばらe /出払/
でばらc /出払/
でばt /出張/
でばr /出張/
でばn /出張/
でばc /出張/
ではらw /出払/
ではらu /出払/
ではらt /出払/
ではらo /出払/
ではらi /出払/
ではらc /出払/
ではじm /出始/
ではいr /出入/
でにくs /出難/
でにくk /出難/
でにくi /出難/
でにくg /出難/
でなおs /出直/
でてゆk /出て行/
でてこz /出て来/
でてこy /出て来/
でてこs /出て来/
でてこr /出て来/
でてこn /出て来/
でてこi /出て来/
でてくr /出て来/
でてくn /出て来/
でてきy /出て来/
でてきt /出て来/
でてきs /出て来/
でてきn /出て来/
でてきm /出て来/
でてきd /出て来/
でてきc /出て来/
でていt /出て行/
でていk /出て行/
でていc /出て行/
でづっぱr /出突っ張/
でつづk /出続/
でつくs /出尽/
でつk /出尽/
でっぱなs /出っ放/
でっぱt /出張/出っ張/
でっぱr /出っ張/出張/
でっぱn /出っ張/出張/
でっぱc /出っ張/出張/
でっちあg /捏ち上/でっち上/
でだs /出出/
でたt /出立/
でぞm /出初/
でそろw /出揃/
でそろu /出揃/
でそろt /出揃/
でそろo /出揃/
でそろi /出揃/
でそろe /出揃/
でそろc /出揃/
ですg /出過/
でしいr /弟子入/
でくわs /出会/
でくw /出喰/出食/
でぎt /出切/
でぎr /出切/
でぎn /出切/
でぎc /出切/
できばe /出来栄/出来映/
できなs /出来無/
できなk /出来無/
できなi /出来無/
できなg /出来無/
できだかばらi /出来高払/
できそこn /出来損/
できすg /出来過/
できあi /出来合/
できあg /出来上/
できz /出来/
できy /出来/
できw /出来/
できu /出来/
できt /出来/
できs /出来/
できr /出来/
できp /出来/
できo /出来/
できn /出来/
できm /出来/
できk /出来/
できj /出来/
できi /出来/
できh /出来/
できg /出来/
できe /出来/
できd /出来/
できc /出来/
できb /出来/
できa /出来/
でかせg /出稼/
でかけr /出掛け;※送り位置補正/
でかs /出来/デカ/
でかm /デカ/
でかk /出掛/デカ/
でかi /デカ/
でかg /デカ/
でおくr /出遅/
でいr /出入/
であるk /出歩/
であるi /出歩/
であw /出会/出逢/出合/
であu /出会/出逢/出合/
であt /出会/出逢/出合/
であo /出会/出逢/出合/
であi /出会/出逢/出合/
であe /出会/出逢/出合/
であc /出会/出逢/出合/
でz /出/
でy /出/
でw /出/
でu /出/
でt /出/照/
でs /出/
でr /出/照/
でp /出/
でo /出/
でn /出/照/
でm /出/
でk /出/
でj /出/
でi /出/
でh /出/
でg /出/
でe /出/
でd /出/
でc /出/照/
でb /出/
でa /出/
てんぷいたs /添付致/
てんびk /天引/
てんぱt /テンパ/
てんぱr /テンパ/
てんぱn /テンパ/
てんぱc /テンパ/
てんばいかいもどs /転売買戻/
てんとr /点取/
てんたかk /天高/
てんこもr /天こ盛/
てんかいs /展開/
てんz /転/点/
てんj /転/点/
てをだs /手を出/
てわたs /手渡/
てわk /手分/
てれくさs /照れ臭/
てれくさk /照れ臭/
てれくさi /照れ臭/
てれくさg /照れ臭/
てりはe /照り映/
てりつk /照り付/
てりこn /照り込/
てりこm /照り込/
てりかがやk /照り輝/
てりかがやi /照り輝/
てりかえs /照り返/
てらしあわs /照らし合/照し合/
てらしあw /照らし合/照し合/
てらw /衒/
てらu /衒/
てらt /衒/
てらs /照/
てらo /衒/
てらi /衒/
てらh /衒/
てらe /衒/
てらc /衒/
てやわらk /手柔/
てやわr /手柔/
てもどr /手戻/
てもt /手持/
てもc /手持/
てむk /手向/
てまわs /手回/
てまねk /手招/
てまどt /手間取/
てまどr /手間取/
てまどn /手間取/
てまどc /手間取/
てほどk /手解/
てぶr /手振/手ぶ;※送り位置補正/
てびろs /手広/
てびろk /手広;-く商売する/
てびろi /手広/
てびかe /手控/
てびk /手引/
てひどs /手酷/
てひどk /手酷/
てひどi /手酷/
てひどg /手酷/
てばやs /手早/
てばやk /手早/
てばやi /手早/
てばやg /手早/
てばなs /手放/手離;NB:辞書にはない表記/
てはじm /手始/
てぬるs /手緩/
てぬるk /手緩/
てぬるi /手緩/
てぬるg /手緩/
てぬk /手抜/
てにはいt /手に入/
てにはいr /手に入/
てにはいn /手に入/
てにはいc /手に入/
てにいr /手に入/
てならi /手習/
てなずk /手懐/
てなおs /手直/
てなr /手慣/
てどr /手取/
てとりあしとr /手取り足取/
てとr /手取/
てづよs /手強/
てづよk /手強/
てづよi /手強/
てづよg /手強/
てづまr /手詰/
てづくr /手作/
てづかm /手掴/
てづm /手詰/
てつやあk /徹夜明/
てつづk /手続/
てつだw /手伝/
てつだu /手伝/
てつだt /手伝/
てつだo /手伝/
てつだi /手伝/
てつだe /手伝/
てつだc /手伝/
てつk /手付/
てっとりばやs /手っ取り早/
てっとりばやk /手っ取り早/
てっとりばやi /手っ取り早/
てっとりばやg /手っ取り早/
てっとr /手っ取/
てっs /徹/
てぢかn /手近/
てちがi /手違/
てだすk /手助/
てだt /手立/手出/
てだs /手出/
てだr /手練/
てすr /手摺/
てじm /手締/
てざわr /手触/
てざs /手差/
てさばk /手捌/
てさぐr /手探/
てさs /手差/
てさg /手提/
てごわs /手強/
てごわk /手強/
てごわi /手強/
てごわg /手強/
てごたh /手應/
てごたe /手応;手応え/手應;「応」旧字/
てこずt /梃摺/
てこずr /梃摺/
てこずn /梃摺/
てこずc /梃摺/
てこいr /梃入/テコ入/
てくらg /手暗/
てくばr /手配/
てぎわよs /手際良/
てぎわよk /手際良/
てぎわよi /手際良/
てぎr /手切/
てきびs /手厳/
てきとうn /適当/
てきs /適;適切/敵;衆寡敵せず/
てきn /的/
てきd /的/
てがたs /手堅/
てがたk /手堅/
てがたi /手堅/
てがたg /手堅/
てがかr /手掛/
てがk /手書/手掛/手懸;≒手掛ける,手掛かり/
ておくr /手遅/
ておt /手落/
ておs /手押/
ておi /手負/
ておc /手落/
てうt /手打;-ち(ウドン,になる)/
ていよk /体良;体裁よく/
ていたs /手痛/
ていたk /手痛/
ていたi /手痛/
ていたg /手痛/
ていせいいたs /訂正致/
ていしいたs /停止致/
ていぎづk /定義付/
ていきょうs /提供/
ていs /呈;(show) 活況を呈する/挺;身を挺する/訂;(correct) 原稿を訂する/締;?/
ていr /手入/
てあらs /手荒;手荒い祝福/
てあらk /手荒;手荒い祝福/手粗/
てあらi /手洗;お手洗い/手荒;手荒い祝福/
てあらg /手荒;手荒い祝福/
てあぶr /手焙/
てあつs /手厚/
てあつk /手厚/
てあつi /手厚/
てあつg /手厚/
てあw /手合/
てあt /手当/
てあm /手編/
てあi /手合/
てあg /手上/
てz /手/
てt /照/
てr /照/
てn /手/照/
てm /手/
てg /手/
てd /手/
てc /照/
づらs /辛/
づらk /辛/
づらi /辛/
づらg /辛/
づよs /強/
づよk /強/
づよi /強/
づよg /強/
づとm /勤/
づつn /包/
づつm /包/
づたi /伝/
づくs /尽/
づくr /作/造/做/
づきあi /付き合/
づかr /疲/
づかi /遣/使/
づr /連/釣/吊/
づm /積/詰/
づk /付/漬/突/
づi /付/
つんぼs /聾/
つんぼn /聾/
つんぼd /聾/
つんざk /劈/
つんざi /劈/
つれもどt /連れ戻/
つれもどs /連れ戻/
つれもどr /連れ戻/
つれもどn /連れ戻/
つれもどc /連れ戻/
つれまわs /連れ回/
つれてゆk /連れて行/
つれてこz /連れて来/
つれてこy /連れて来/
つれてこs /連れて来/
つれてこr /連れて来/
つれてこn /連れて来/
つれてこi /連れて来/
つれてくr /連れて来/
つれてくn /連れて来/
つれてきy /連れて来/
つれてきt /連れて来/
つれてきs /連れて来/
つれてきn /連れて来/
つれてきm /連れて来/
つれてきd /連れて来/
つれてきc /連れて来/
つれていt /連れて行/
つれていk /連れて行/
つれていc /連れて行/
つれだt /連れ立/
つれだs /連れ出/
つれだc /連れ立/
つれそw /連れ添/
つれそu /連れ添/
つれそt /連れ添/
つれそo /連れ添/
つれそi /連れ添/
つれそe /連れ添/
つれそc /連れ添/
つれさt /連れ去/
つれさr /連れ去/
つれさn /連れ去/
つれさc /連れ去/
つれこn /連れ込/連込/
つれこm /連れ込/連込/
つれかえt /連れ帰/
つれかえr /連れ帰/
つれかえn /連れ帰/
つれかえc /連れ帰/
つれあi /連れ合/
つるしあg /吊るし上/
つるs /吊/
つるn /交尾/連/
つるm /連/交尾/
つりだs /釣り出/吊り出/
つりさg /吊り下/
つりこn /釣り込/
つりこm /釣り込/
つりあw /釣り合/釣合/
つりあu /釣り合/釣合/
つりあt /釣り合/釣合/
つりあo /釣り合/釣合/
つりあi /釣り合/釣合/
つりあg /釣り上;魚を釣り上げる/吊り上;ロープで吊り上げる/釣上/
つりあe /釣り合/釣合/
つりあc /釣り合/釣合/
つらよごs /面汚/
つらぬきとおs /貫き通/
つらぬk /貫/
つらぬi /貫/
つらがまe /面構/
つらあt /面当/
つらs /辛/ツラ/
つらn /連/列/
つらk /辛/ツラ/
つらi /辛/ツラ/
つらg /辛/ツラ/
つよすg /強過/
つよs /強/
つよm /強/
つよk /強/
つよi /強/
つよg /強/
つゆはらi /露払/
つやがたr /艶語/
つやy /艶/
つやp /艶/
つもりつm /積もり積/
つもt /積/
つもr /積/
つもn /積/
つもc /積/
つめよt /詰め寄/
つめよr /詰め寄/
つめよn /詰め寄/
つめよc /詰め寄/
つめたs /冷/
つめたk /冷/
つめたi /冷/
つめたg /冷/
つめこn /詰め込/
つめこm /詰め込/
つめかk /詰め掛/
つめかe /詰め替/
つめあわs /詰め合/詰合/
つめあw /詰め合/
つめt /冷/詰/
つめr /詰/
つめn /詰/
つむt /瞑/
つむr /瞑/
つむn /瞑/
つむi /紡/
つむg /紡/
つむc /瞑/
つみまs /積み増/積増/
つみほr /罪滅;※送り過剰?/
つみぶかs /罪深/
つみぶかk /罪深/
つみぶかi /罪深/
つみぶかg /罪深/
つみのこs /積み残/積残/
つみなおs /積み直/積直/
つみとt /摘み取/
つみとr /摘み取/
つみとn /摘み取/
つみとc /摘み取/
つみつくr /罪作/
つみだs /積み出/
つみたt /積立/積み立/
つみこn /積み込/
つみこm /積み込/
つみかさn /積み重/積重/
つみかe /積み替/積替/
つみおr /積み降/
つみあg /積み上/積上/
つみs /罪/
つみn /罪/
つみd /罪/
つまみだs /撮み出/
つまみぐi /撮み食/
つまびr /詳/審/
つまびk /爪弾/
つまびi /爪弾/
つまはじk /爪弾/
つまどt /褄取/
つまどr /褄取/
つまどn /褄取/
つまどc /褄取/
つまづk /躓/
つまづi /躓/
つまずk /躓/
つまずi /躓/
つまさきだt /爪先立/
つまさきだc /爪先立/
つまt /詰/
つまs /倹/約;<rare>≒倹しい (字義:紐で引き締める)/
つまr /詰/
つまn /撮/摘/抓/詰/
つまm /摘/抓/撮/
つぼn /蕾;梅が蕾む/窄;NB:「すぼm」と同形/
つぼm /蕾;梅が蕾む/窄;NB:「すぼm」と同形/
つぶらs /円/
つぶらn /円/
つぶらd /円/
つぶよr /粒選/
つぶやk /呟/
つぶやi /呟/
つぶひとt /粒一/
つぶだt /粒立/
つぶだc /粒立/
つぶぞろi /粒揃/
つぶしあw /潰し合/
つぶしあu /潰し合/
つぶしあt /潰し合/
つぶしあo /潰し合/
つぶしあi /潰し合/
つぶしあe /潰し合/
つぶしあc /潰し合/
つぶt /瞑;目を瞑る/
つぶs /潰/
つぶr /潰/瞑;目を瞑る/円;円らな瞳/
つぶn /瞑;目を瞑る/
つぶc /瞑;目を瞑る/
つひe /潰/費/幣/
つばめがえs /燕返/
つばs /唾/
つのt /募/
つのr /募/
つのn /募/
つのc /募/
つねt /抓/
つねr /抓/
つねn /常/抓/
つねc /抓/
つなわたr /綱渡/
つなひk /綱引/
つなぎなおs /繋ぎ直/
つなぎとm /繋ぎ止/
つなぎこn /繋ぎ込/
つなぎこm /繋ぎ込/
つなぎかe /継ぎ換/
つながt /繋/
つながr /繋;非正則(つなg)/
つながn /繋;非正則(つなg)/
つながc /繋;非正則(つなg)/
つなi /繋/継/繼;「継」の旧字/
つなg /繋/継;(つぐ?)/繼;「継」の旧字/
つどw /集/
つどu /集/
つどt /集/
つどo /集/
つどi /集/
つどh /集/
つどe /集/
つどc /集/
つとめあg /勤め上/
つとn /夙/
つとm /努;(exert) 普及に努める/務;(act) 役目を務める/勤;(work for) 会社に勤める/勉;≒努める (字義:無理をする)/力/
つづりあw /綴り合/
つづまy /約;人は己を-やかにし/
つづt /綴/
つづr /綴/
つづn /綴/
つづm /約/
つづk /続/續;旧字/
つづi /続/續;旧字/
つづc /綴/
つつみこn /包み込/
つつみこm /包み込/
つつみかくs /包み隠/
つつまs /慎/
つつぬk /筒抜/
つつしみぶかs /慎み深/
つつしみぶかk /慎み深/
つつしみぶかi /慎み深/
つつしみぶかg /慎み深/
つつしn /慎;(be prudent)「言葉を慎む」/謹;(respect)「謹みて申し上げる」/愼;「慎」の旧字(人名用漢字)/
つつしm /慎;(be prudent)「言葉を慎む」/謹;(respect)「謹みて申し上げる」/愼;「慎」の旧字(人名用漢字)/
つつがなs /恙無/
つつがなk /恙無/
つつがなi /恙無/
つつがなg /恙無/
つつs /慎;非正則(つつしm)/謹;非正則(つつしm)/
つつn /包/慎;NB:「つつしm」と同形/裹;屍を-む/障;[文語]差し支える/恙;≒障む/
つつm /包/慎;NB:「つつしm」と同形/裹;屍を-む/障;[文語]差し支える/恙;≒障む/
つつk /突/突突/
つつi /突/突突/
つっぷs /突っ伏/
つっぱなs /突っ放/
つっぱしt /突っ走/
つっぱしr /突っ走/
つっぱしn /突っ走/
つっぱしc /突っ走/
つっぱt /突っ張/突張/
つっぱr /突っ張/突張/
つっぱn /突っ撥/突っ張/突張/
つっぱc /突っ張/突張/
つっつk /突っ突/
つっつi /突っ突/
つったt /突っ立/
つったc /突っ立/
つっこn /突っ込/突込/
つっこm /突っ込/突込/
つっきt /突っ切/
つっきr /突っ切/
つっきn /突っ切/
つっきc /突っ切/
つっかえs /突っ返/
つっかk /突っ掛/
つっかh /支/閊/
つっかe /支/閊;≒支える/
つちふr /霾/土降/
つちかw /培/
つちかu /培/
つちかt /培/
つちかo /培/
つちかi /培/
つちかe /培/
つちかc /培/
つだw /伝/傳;「伝」の旧字(人名用漢字)/
つだu /伝/傳;「伝」の旧字(人名用漢字)/
つだt /伝/傳;「伝」の旧字(人名用漢字)/
つだo /伝/傳;「伝」の旧字(人名用漢字)/
つだi /伝/傳;「伝」の旧字(人名用漢字)/
つだe /伝/傳;「伝」の旧字(人名用漢字)/
つだc /伝/傳;「伝」の旧字(人名用漢字)/
つたなs /拙/
つたなk /拙/
つたなi /拙/
つたなg /拙/
つたえきk /伝え聞/
つたえきi /伝え聞/
つたw /伝/傳;「伝」の旧字(人名用漢字)/
つたu /伝/傳;「伝」の旧字(人名用漢字)/
つたt /伝/傳;「伝」の旧字(人名用漢字)/
つたo /伝/傳;「伝」の旧字(人名用漢字)/
つたi /伝/傳;「伝」の旧字(人名用漢字)/
つたh /伝/傳;「伝」の旧字(人名用漢字)/
つたe /伝/傳;「伝」の旧字(人名用漢字)/
つたc /伝/傳;「伝」の旧字(人名用漢字)/
つずr /綴;※仮名遣い「つづr」/
つじつまあw /辻褄合/
つごうよs /都合良/
つごうよk /都合良/
つごうよi /都合良/
つこうまつt /仕/
つこうまつr /仕/
つこu /使/
つげしr /告げ知/
つけわすr /付け忘/
つけまわs /付け回/
つけねらw /付け狙/
つけねらu /付け狙/
つけねらt /付け狙/
つけねらo /付け狙/
つけねらi /付け狙/
つけねらe /付け狙/
つけねらc /付け狙/
つけっぱなs /付けっ放;テレビ-し/
つけだs /付け出/
つけたs /付け足/
つけこn /付け込/漬け込/
つけこm /付け込/漬け込/
つけくわw /付け加/
つけくわe /付け加/
つけかe /付け替/
つけいt /付け入/
つけいr /付け入/
つけいn /付け入/
つけいc /付け入/
つけあわs /付け合/
つけあw /付け合/
つけあg /付け上/
つぐなw /償/
つぐなu /償/
つぐなt /償/
つぐなo /償/
つぐなi /償/
つぐなe /償/
つぐなc /償/
つぐn /噤/鉗;<rare>≒噤む (字義:首枷)/
つぐm /噤/鉗;<rare>≒噤む (字義:首枷)/
つくろw /繕/
つくろu /繕/
つくろt /繕/
つくろo /繕/
つくろi /繕/
つくろh /繕/
つくろe /繕/
つくろc /繕/
つくりはじm /作り始/
つくりなおs /作り直/造り直/創り直/
つくりつづk /作り続/
つくりつk /作り付/
つくりだs /作り出/創り出/
つくりそこn /作り損/
つくりこn /作り込/
つくりこm /作り込/
つくりかe /作り替/作り変/創り変/
つくりおk /作り置/
つくりおi /作り置/
つくりあg /作り上/
つくらh /繕/
つくばt /蹲/
つくばr /蹲/
つくばn /蹲/
つくばc /蹲/
つくt /作/創;innovate/造;fabricate/做;「作」の異体字/
つくs /尽/盡;「尽」の旧字(人名用漢字)/殲;<rare> (全滅させる) 敵を殲す/殱;「殲」の異体字/
つくr /作/創;innovate/造;fabricate/做;「作」の異体字/
つくn /捏/作/創;innovate/造;fabricate/做;「作」の異体字/
つくc /作/創;innovate/造;fabricate/做;「作」の異体字/
つぎわk /注ぎ分/
つぎたs /継ぎ足;テープを継ぎ足す/注ぎ足;(液体) 酒を注ぎ足す/
つぎこn /つぎ込/注ぎ込/
つぎこm /つぎ込/注ぎ込/
つぎn /次/
つきやぶt /突き破/
つきやぶr /突き破/
つきやぶn /突き破/
つきやぶc /突き破/
つきまとw /付き纏/
つきまとu /付き纏/
つきまとt /付き纏/
つきまとo /付き纏/
つきまとi /付き纏/
つきまとe /付き纏/
つきまとc /付き纏/
つきばらi /月払/
つきはなs /突き放/
つきはじm /月初/月始;?/
つきはt /尽き果/
つきぬk /突き抜/
つきとおs /突き通/
つきとm /突き止/
つきとb /突き飛/
つきでy /突き出/
つきでt /突き出/
つきでr /突き出/
つきでn /突き出/
つきでm /突き出/
つきづk /付き付/
つきつm /突き詰/
つきつk /突き付/
つきっきr /付きっ切/
つきだs /突き出/突出/
つきたt /突き立/
つきそw /付き添/付添/
つきそu /付き添/付添/
つきそt /付き添/付添/
つきそo /付き添/付添/
つきそi /付き添/付添/
つきそe /付き添/付添/
つきそc /付き添/付添/
つきすすn /突き進/
つきすすm /突き進/
つきしたがw /付き従/
つきしたがu /付き従/
つきしたがt /付き従/
つきしたがo /付き従/
つきしたがi /付き従/
つきしたがe /付き従/
つきしたがc /付き従/
つきさs /突き刺/
つきころs /突き殺/
つきくずs /突き崩/
つきぎr /月切/
つきぎm /月極/
つきがk /月掛/
つきかえs /突き返/
つきおとs /突き落/
つきおくr /月遅/
つきおt /突き落/
つきうごk /突き動/衝き動/
つきあわs /突き合/
つきあw /突き合/付き合/付合/
つきあu /付き合/付合/
つきあt /付き合;-って/突き当;-たり/付合/
つきあo /付き合/付合/
つきあk /月明/
つきあi /付き合/付合/
つきあg /突き上/
つきあe /付き合/付合/
つきあc /付き合/付合/
つきm /拒;[文語]/
つがw /番/
つがu /番/
つがt /番/
つがo /番/
つがi /番/
つがh /番/
つがe /番/
つがc /番/
つかれはt /疲れ果/
つかれきt /疲れ切/
つかれきr /疲れ切/
つかれきn /疲れ切/
つかれきc /疲れ切/
つかみとt /掴み取/
つかみとr /掴み取/
つかみとn /掴み取/
つかみとc /掴み取/
つかみだs /掴み出/
つかみあw /掴み合/
つかみあu /掴み合/
つかみあt /掴み合/
つかみあo /掴み合/
つかみあi /掴み合/
つかみあc /掴み合/
つかまつt /仕/
つかまつr /仕/
つかまつn /仕/
つかまつc /仕/
つかさどt /司/掌/
つかさどr /司/掌/
つかさどn /司/掌/
つかさどc /司/掌/
つかうまつt /仕/
つかうまつr /仕/
つかうまつn /仕/
つかうまつc /仕/
つかいわk /使い分/
つかいやすs /使い易/
つかいやすk /使い易/
つかいやすi /使い易/
つかいやすg /使い易/
つかいまわs /使い回/
つかいふるs /使い古/
つかいばしr /使い走/
つかいはじm /使い始/
つかいはt /使い果/
つかいのこs /使い残/
つかいにくs /使い難/
つかいにくk /使い難/
つかいにくi /使い難/
つかいにくg /使い難/
つかいなr /使い慣/使い馴/
つかいづらs /使い辛/
つかいづらk /使い辛/
つかいづらi /使い辛/
つかいづらg /使い辛/
つかいつづk /使い続/
つかいつk /使い尽/
つかいだs /使い出/
つかいすt /使い捨/
つかいこなs /使い熟/
つかいこn /使い込/
つかいこm /使い込/
つかいきt /使い切/
つかいきr /使い切/
つかいきn /使い切/
つかいきc /使い切/
つかいおw /使い終/
つかいおe /使い終/
つかw /使/遣;(金|気|人形)を遣う/
つかu /使/遣;(金|気|人形)を遣う/
つかt /使/遣;(金|気|人形)を遣う/
つかr /疲/
つかo /使/遣;(金|気|人形)を遣う/
つかn /掴/束;-ねる NB:「たばn」と同形/把;≒掴む/攫;大金を攫む/
つかm /掴/捕/捉;-まえる/把;≒掴む/攫;大金を攫む/
つかi /使/遣;(金|気|人形)を遣う/
つかh /遣/仕/使/支/閊/
つかe /使/仕;(serve) 上司に仕える/支;(hinder) 差し支える/閊;<rare> ≒支える/障;<rare> ≒支える/遣;(金|気|人形)を遣う/
つかc /使/遣;(金|気|人形)を遣う/
つうほうs /通報/
つうじあw /通じ合/
つうじあu /通じ合/
つうじあt /通じ合/
つうじあo /通じ合/
つうじあi /通じ合/
つうじあe /通じ合/
つうじあc /通じ合/
つうz /通/
つうj /通/
ついやs /費/費や;※送り位置補正/
ついてまわt /付いて回/
ついてまわr /付いて回/
ついてまわn /付いて回/
ついてまわc /付いて回/
ついえさt /潰え去/
ついえさr /潰え去/
ついえさn /潰え去/
ついえさc /潰え去/
ついy /費/
ついt /就;非正則(つi)/ツイ/
ついn /遂;-に/対/
ついe /潰;希望が潰える/費;財産が費える/弊;<rare> ≒潰える/
ついd /序/
ついb /啄/
つt /釣;魚を釣る/吊;吊るす/突/攣;足を攣る/
つr /連/釣;魚を釣る/吊;吊るす/攣;足を攣る/
つn /積/摘;花を摘む,鼻を摘まむ/詰/釣;魚を釣る/吊;吊るす/攣;足を攣る/
つm /詰/積/摘;花を摘む,鼻を摘まむ/
つk /付/着/突/漬/尽/就;地位に就く/点;火を点ける/吐;嘘を吐く/衝;不意を衝く/憑;霊が憑く/撞;鐘を撞く/搗;米を搗く/尾;跡を尾ける/築;垣を築く/附;=付/浸;≒漬ける/盡;「尽」の旧字(人名用漢字)/點;「点」の旧字/
つi /付/着/突/継;語り継ぐ/憑;霊が憑く/次/就;地位に就く/附;=付/点;火を点ける/繼;「継」の旧字/吐;嘘を吐く/衝;不意を衝く/撞;鐘を撞く/搗;米を搗く/築;垣を築く/點;「点」の旧字/注;ビールを注ぐ/接;木に竹を接ぐ/嗣;跡目を嗣ぐ/椄;(つぎ木する)/支;?/
つg /継;語り継ぐ/注;ビールを注ぐ/次/告/接;木に竹を接ぐ/嗣;跡目を嗣ぐ/椄;(つぎ木する)/繼;「継」の旧字/
つc /釣;魚を釣る/吊;吊るす/攣;足を攣る/
ぢs /持/
ちんさg /賃下/
ちんがs /賃貸/
ちんがr /賃借/
ちんあg /賃上/
ちりばm /鏤/
ちりぢr /散り散/
ちょんぎt /ちょん切/
ちょんぎr /ちょん切/
ちょんぎn /ちょん切/
ちょんぎc /ちょん切/
ちょくせんみとおs /直線見通/
ちょくせついt /直接行/
ちょくせついk /直接行/
ちょくせついc /直接行/
ちょくn /直;-に/
ちょくd /直/
ちょうむすb /蝶結/
ちょうどよs /丁度良/
ちょうどよk /丁度良/
ちょうどよi /丁度良/
ちょうどよg /丁度良/
ちょうしわるs /調子悪/
ちょうしわるk /調子悪/
ちょうしわるi /調子悪/
ちょうしわるg /調子悪/
ちょうしよs /調子良/
ちょうしよk /調子良/
ちょうしよi /調子良/
ちょうしよg /調子良/
ちょうけs /帳消/
ちょうz /長/
ちょうs /徴;特徴/朝;朝食/弔;弔問/寵;寵愛/
ちょうj /長/
ちゅうもんとr /注文取/
ちゅうづr /宙吊/
ちゅうちょなk /躊躇無/
ちゅうしs /中止/
ちゅうこうr /中古売/
ちゅうがえr /宙返/
ちゅうかんあたr /中間辺/
ちゅうおうよs /中央寄/
ちゅうおうどおr /中央通/
ちゅういぶかs /注意深/
ちゅういぶかk /注意深/
ちゅういぶかi /注意深/
ちゅういぶかg /注意深/
ちゅういがk /注意書/
ちゅういs /注意/
ちゅうs /注;annotate/註;=注する/誅;(punish) 巨悪を誅する/沖;(ascent) 天に沖する/冲;≒沖する/
ちゃのm /茶飲/
ちゃづk /茶漬/
ちゃくばらi /着払/
ちゃくs /着/
ちゃくm /茶汲/
ちゃかs /茶化;(当て字)/
ちゃうk /茶請/
ちゃいろs /茶色/
ちゃいろp /茶色/
ちゃいろk /茶色/
ちゃいろi /茶色/
ちゃいろg /茶色/
ちゃp /茶/
ちまよw /血迷/
ちまよu /血迷/
ちまよt /血迷/
ちまよo /血迷/
ちまよi /血迷/
ちまよe /血迷/
ちまよc /血迷/
ちばなr /乳離/
ちばしt /血走/
ちばしr /血走/
ちばしn /血走/
ちばしc /血走/
ちぬt /釁/血塗/
ちぬr /血塗/釁/
ちぬn /血塗/釁/
ちぬc /血塗/釁/
ちなまぐさs /血腥/血生臭/
ちなまぐさk /血腥/血生臭/
ちなまぐさi /血腥/血生臭/
ちなまぐさg /血腥/血生臭/
ちなn /因/
ちなm /因/
ちつじょだt /秩序立/
ちつじょだc /秩序立/
ちっt /些/
ちぢみこn /縮み込/
ちぢみこm /縮み込/
ちぢみあg /縮み上/
ちぢr /縮/
ちぢn /縮/
ちぢm /縮/
ちぢk /縮/
ちちばなr /乳離/
ちちくりあw /乳繰り合/
ちちくりあu /乳繰り合/
ちちくりあt /乳繰り合/
ちちくりあo /乳繰り合/
ちちくりあi /乳繰り合/
ちちくりあe /乳繰り合/
ちちくりあc /乳繰り合/
ちちくさs /乳臭/
ちちくさk /乳臭/
ちちくさi /乳臭/
ちちくさg /乳臭/
ちちくt /乳繰/
ちちくr /乳繰/
ちちくn /乳繰/
ちちくc /乳繰/
ちちおやごろs /父親殺/
ちぞm /血染/
ちじn /縮/
ちじm /縮;※仮名遣い(ちぢm)/
ちこu /近/
ちぎt /千切/契;(promise) 「女と契る」/
ちぎr /千切/契;(promise) 「女と契る」/
ちぎn /千切/契;(promise) 「女と契る」/
ちぎc /千切/契;(promise) 「女と契る」/
ちがw /違/交;<rare>/
ちがu /違/交;<rare>/
ちがt /違/交;<rare>/
ちがo /違/交;<rare>/
ちがi /違/交;<rare>/
ちがh /違/交/
ちがe /違/交;<rare>/
ちがc /違/交;<rare>/
ちからもt /力持/
ちからもc /力持/
ちからまかs /力任/
ちからなs /力無/
ちからなk /力無/
ちからなi /力無/
ちからづよs /力強/
ちからづよk /力強/
ちからづよi /力強/
ちからづよg /力強/
ちからづk /力付/
ちからつk /力尽/
ちからぞe /力添/
ちかよt /近寄/
ちかよs /近寄/
ちかよr /近寄/
ちかよn /近寄/
ちかよc /近寄/
ちかづs /近付/
ちかづk /近付/
ちかづi /近付/
ちかづg /近付/
ちかすg /近過/
ちかいあw /誓い合/
ちかいあu /誓い合/
ちかいあt /誓い合/
ちかいあo /誓い合/
ちかいあi /誓い合/
ちかいあe /誓い合/
ちかいあc /誓い合/
ちかw /誓/盟;<rare> (字義:血を啜ってちかいあう)/
ちかu /誓/盟;<rare> (字義:血を啜ってちかいあう)/
ちかt /誓/盟;<rare> (字義:血を啜ってちかいあう)/
ちかs /近/親;NB:「したs」と同形/誓/
ちかo /誓/盟;<rare> (字義:血を啜ってちかいあう)/
ちかk /近/誓/
ちかi /近/誓/盟;<rare> (字義:血を啜ってちかいあう)/
ちかh /誓/盟/
ちかg /近/誓/
ちかe /誓/盟;<rare> (字義:血を啜ってちかいあう)/
ちかd /近/
ちかc /誓/盟;<rare> (字義:血を啜ってちかいあう)/
ちいさn /小さ;※送り位置補正/
ちいさk /小/
ちいs /小/
ちt /散/
ちs /小/治/
ちr /散/
ちn /散/
ちk /小/
ちg /血/
ちc /散/
ちb /禿/
だんどr /段取/
だんとr /段取/
だんづk /段付/
だんちがi /段違/
だんせいむk /男性向/
だんじこn /談じ込/
だんじこm /談じ込/
だんぐm /段組/
だんくm /段組/
だんz /断/談/弾/
だんj /断/談/弾/
だれかれかまw /誰彼構/
だれw /誰/
だれt /誰/
だれn /誰/
だれm /誰/
だれk /誰/
だれg /誰/
だれd /誰/
だるs /ダル/怠/懶/
だるk /怠/懶/ダル/
だるi /怠/懶/ダル/
だるg /怠/懶/ダル/
だよr /便/頼/
だめづm /駄目詰/
だめおs /駄目押/
だめp /駄目/
だまりこn /黙り込/
だまりこm /黙り込/
だましこn /騙し込/
だましこm /騙し込/
だましうt /騙し討/
だまt /黙/默;「黙」の旧字(人名用漢字)/
だまs /騙/
だまr /黙/溜/默;「黙」の旧字(人名用漢字)/
だまn /黙/默;「黙」の旧字(人名用漢字)/
だまc /黙/默;「黙」の旧字(人名用漢字)/
だべt /駄弁/
だべr /駄弁/
だべn /駄弁/
だべc /駄弁/
だぶt /ダブ/
だぶr /ダブ/
だぶn /ダブ/
だぶc /ダブ/
だっs /脱/
だっk /抱っ;※送り位置補正/
だだっぴろs /だだっ広/
だだっぴろk /だだっ広/
だだっぴろi /だだっ広/
だだっぴろg /だだっ広/
だしぬk /出し抜/
だしぬi /出し抜/
だしっぱなs /出しっ放;水道-し/
だししぶt /出し渋/
だししぶr /出し渋/
だししぶn /出し渋/
だししぶc /出し渋/
だしきt /出し切/
だしきr /出し切/
だしきn /出し切/
だしきc /出し切/
だしおs /出し惜/
だしいr /出し入/
だしあw /出し合/
だしあu /出し合/
だしあt /出し合/
だしあo /出し合/
だしあi /出し合/
だしあe /出し合/
だしあc /出し合/
だくs /諾;サ変/
だきよs /抱き寄/
だきとt /抱き取/
だきとr /抱き取/
だきとn /抱き取/
だきとm /抱き留/
だきとc /抱き取/
だきつk /抱き付/
だきつi /抱き付/
だきすくm /抱き竦/
だきしm /抱き締/
だきこn /抱き込/
だきこm /抱き込/
だきかかe /抱き抱/
だきおこs /抱き起/
だきおr /抱き下/
だきあわs /抱き合/
だきあw /抱き合/
だきあu /抱き合/
だきあt /抱き合/
だきあo /抱き合/
だきあi /抱き合/
だきあg /抱き上/
だきあe /抱き合/
だきあc /抱き合/
だおs /倒/
だおr /倒;(連濁) 掛け声-,議論-/
だいめいどおr /題名通/
だいぶちがu /大分違/
だいびk /代引/
だいなs /台無/
だいっきらi /大っ嫌/
だいたいおなz /大体同/
だいたいおなj /大体同/
だいすk /大好/
だいきらi /大嫌/
だいs /題/
だt /立/建/
だs /出/堕;放縦に堕する/
だr /垂/
だm /溜/澑;異体字/
だk /抱/炊/
だi /抱/
だc /立/
たんせいこm /丹精込/
たんじゅんn /単純/
たんいじかんあt /単位時間当/
たんz /嘆/歎/
たんn /単/單;「単」の旧字(人名用漢字)/
たんj /嘆/歎/
たをr /手折/
たをm /撓/
たわむr /戯/戲;「戯」の旧字(人名用漢字)/
たわぶr /戯/
たわいなs /たわい無/
たわいなk /たわい無/
たわいなi /たわい無/
たわw /撓;-わ(に稔る)/
たわn /撓/
たわm /撓/
たわk /戯/
たれながs /垂れ流/
たれさg /垂れ下/
たれこn /垂れ込/
たれこm /垂れ込/垂れ籠/
たるs /タル/
たるn /弛/
たるm /弛/
たるk /タル/
たるi /タル/
たるg /タル/
たらしこn /誑し込/
たらしこm /誑し込/
たらいまわs /盥回/
たらz /足ら;※送り位置補正/
たらs /誑/蕩/
たよりなs /頼り無/
たよりなk /頼り無/
たよりなi /頼り無/
たよt /頼/便;letter/
たよr /頼/便;letter/
たよn /頼/便;letter/
たよc /頼/便;letter/
たゆたw /揺蕩/
たゆたu /揺蕩/
たゆたt /揺蕩/
たゆたo /揺蕩/
たゆたi /揺蕩/
たゆたh /揺蕩/
たゆたe /揺蕩/
たゆたc /揺蕩/
たゆn /弛/
たゆm /弛/
たやすs /容易/
たやすk /容易/
たやすi /容易/
たやすg /容易/
たもちつづk /保ち続/
たもt /保/
たもc /保/
ためらw /躊躇/猶豫/
ためらu /躊躇/猶豫/
ためらt /躊躇/猶豫/
ためらo /躊躇/猶豫/
ためらi /躊躇/猶豫/
ためらh /躊躇/猶豫/
ためらe /躊躇/猶豫/
ためらc /躊躇/猶豫/
ためしずr /試し刷/
ためこn /溜め込/
ためこm /溜め込/
ためs /試/
ためn /為/爲;「為」の旧字(人名用漢字)/
ためd /為/
たむろs /屯/
たむk /手向/
たまわt /賜/承/
たまわr /賜/承/
たまわn /賜/承/
たまわc /賜/承/
たまりかn /堪り兼/
たまよk /弾除/
たまつk /玉突/
たまだs /玉出/
たまげt /魂消/
たまげr /魂消/
たまげn /魂消/
たまげc /魂消/
たまぎr /弾切/魂消/
たまきt /玉木/
たまいr /玉入/
たまw /賜;(grant) 「勲章を賜う」/給/
たまu /給/賜;(grant) 「勲章を賜う」/
たまt /溜/澑;異体字/給/賜;(grant) 「勲章を賜う」/堪;堪らない/
たまs /偶/
たまr /溜/堪;堪らない/澑;異体字/
たまo /給/賜;(grant) 「勲章を賜う」/
たまn /偶;sometimes.「-の休み」/溜/堪;堪らない/澑;異体字/
たまi /給/賜;(grant) 「勲章を賜う」/
たまh /給/賜/
たまe /給/賜;(grant) 「勲章を賜う」/
たまc /給/賜;(grant) 「勲章を賜う」/溜/澑;異体字/
たべはじm /食べ始/
たべのこs /食べ残/
たべつづk /食べ続/
たべつくs /食べ尽/
たべちr /食べ散/
たべそこn /食べ損/
たべすg /食べ過/
たべくらb /食べ比/
たべきt /食べ切/
たべきr /食べ切/
たべきn /食べ切/
たべきc /食べ切/
たべかk /食べ掛/
たべおw /食べ終/
たべおe /食べ終/
たべあわs /食べ合/
たべあるk /食べ歩/
たべあるi /食べ歩/
たべあw /食べ合/
たべあk /食べ飽/
たべt /食べ;※送り位置補正/
たべr /食べ;※送り位置補正/
たぶらk /誑/
たふとs /貴/尊/
たふとm /貴/尊/
たふとk /貴/尊/
たふとi /貴/尊/
たふとg /貴/尊/
たふs /倒/
たふr /倒/斃/
たびゆk /旅行/
たびなr /旅慣/
たびだt /旅立/
たびだc /旅立/
たびかさn /度重/
たびs /旅/
たばなs /手放/
たばさn /手挟/手挾;「挟」旧字/
たばさm /手挟/手挾;「挟」旧字/
たばかt /謀/
たばかr /謀/
たばかn /謀/
たばかc /謀/
たばn /束/
たはむr /戲/
たのもs /頼も;※送り位置補正/
たのみこn /頼み込/
たのみこm /頼み込/
たのs /楽/愉;(字義:わだかまりを取り去る)/娯;(字義:笑い興ずる)/樂;「楽」の旧字(人名用漢字)/
たのn /頼/恃;(あてにする) 自ら恃むところ/
たのm /頼/恃;(あてにする) 自ら恃むところ/
たねまk /種蒔/種播/
たねぎr /種切/
たねあかs /種明/
たねあk /種明/
たにまわr /谷回/
たなびk /棚引;雲が-く/
たなびi /棚引;雲が-く/
たなざらs /店晒/
たなおろs /棚卸/
たなあg /棚上/
たどりつk /辿り着/
たどりつi /辿り着/
たどt /辿/到;?/
たどr /辿/
たどn /辿/
たどc /辿/
たとh /喩/譬/
たとe /例;(仮定・具体例)「例えば」/喩;(比喩)「生を旅に喩える」/譬;≒喩 (字義:本筋から逸れる)/
たでくu /蓼食/
たてめぐt /立て巡/
たてめぐr /立て巡/
たてめぐn /立て巡/
たてめぐc /立て巡/
たてまつt /奉/
たてまつr /奉/
たてまつn /奉/
たてまつc /奉/
たてまs /建増/建て増/
たてなおs /立て直;態勢を-/建て直;ビルを-/立直/建直/
たてとおs /立て通/
たてつづk /立て続/
たてつk /建て付;扉の建て付けが悪い/楯突;親に楯突く/建付/盾突;=楯突く/
たてつi /楯突;親に楯突く/盾突/
たてこもt /立て籠/
たてこもr /立て籠/
たてこもn /立て籠/
たてこもc /立て籠/
たてこn /立て込/建て込/
たてこm /立て込/建て込/
たてぐm /縦組/
たてきt /立て切/閉て切;障子を-/
たてきr /立て切/閉て切;障子を-/
たてきn /立て切/閉て切;障子を-/
たてきc /立て切/閉て切;障子を-/
たてがk /縦書/
たてかk /立て掛/
たてかe /立て替;代金を立て替える/建て替;家を建て替える/建替/立替/
たづさh /攜/携/
たづくr /田作/
たづn /尋/訊/訪/
たっとs /尊/貴/
たっとn /尊/貴/
たっとk /尊/貴/
たっとi /尊/貴/
たっとg /尊/貴/
たっとb /尊/貴/
たっせいs /達成/
たっs /達/逹;異体字/
たちよt /立ち寄/立寄/
たちよr /立ち寄/立寄/
たちよn /立ち寄/立寄/
たちよm /立ち読/立読/
たちよc /立ち寄/立寄/
たちゆk /立ち行/
たちもどt /立ち戻/
たちもどr /立ち戻/
たちもどn /立ち戻/
たちもどc /立ち戻/
たちむk /立ち向/
たちまわt /立ち回/
たちまわr /立ち回/
たちまわn /立ち回/
たちまわc /立ち回/
たちまt /忽/
たちまj /立ち交/
たちふさg /立ち塞/
たちはたらk /立ち働/
たちはたらi /立ち働/
たちのぼt /立ち上/
たちのぼr /立ち上/
たちのぼn /立ち上/
たちのぼc /立ち上/
たちのk /立ち退/立退/
たちのi /立ち退/立退/
たちならn /立ち並/
たちならb /立ち並/
たちなおt /立ち直/
たちなおr /立ち直/
たちなおn /立ち直/
たちなおc /立ち直/
たちどおs /立ち通/
たちどm /立ち止/
たちとおs /立ち通/
たちつづk /立ち続/
たちつくs /立ち尽/
たちっぱなs /立ちっ放/
たちすくn /立ち竦/
たちすくm /立ち竦/
たちさt /立ち去/
たちさr /立ち去/
たちさn /立ち去/
たちさg /立ち下/
たちさc /立ち去/
たちこn /立ち込/
たちこm /立ち籠/立ち込/
たちぐi /立食/
たちくらn /立ち眩/
たちくらm /立ち眩/立ち暗;=立ち眩み/
たちぎk /立ち聞/
たちきt /断ち切/裁ち切/截ち切/
たちきr /断ち切/裁ち切/截ち切/
たちきn /断ち切/裁ち切/截ち切/
たちきk /立ち聞/
たちきi /立ち聞/
たちきc /断ち切/裁ち切/截ち切/
たちがr /立枯/立ち枯;[園芸]stand dead/
たちかえt /立ち返/
たちかえr /立ち返/
たちかえn /立ち返/
たちかえc /立ち返/
たちかw /立ち代/
たちおくr /立ち後/立ち遅/
たちうt /太刀打/
たちいたt /立ち至/
たちいたr /立ち至/
たちいたn /立ち至/
たちいたc /立ち至/
たちいt /立ち入/立入/
たちいr /立ち入/立入/
たちいn /立ち入/立入/
たちいc /立ち入/立入/
たちあるk /立ち歩/
たちあるi /立ち歩/
たちあらわr /立ち現/
たちあげr /立ち上げ;※送り位置補正/
たちあw /立会/立ち会/立ち合/立合/
たちあu /立ち会/立ち合/立合/立会/
たちあt /立ち合/立ち会/立合/立会/
たちあo /立ち会/立ち合/立合/立会/
たちあi /立合/立会/立ち会/立ち合/
たちあg /立ち上/起ち上/立上/
たちあe /立会/立ち会/立ち合/立合/
たちあc /立ち会/立ち合/立合/立会/
ただよw /漂/
ただよu /漂/
ただよt /漂/
ただよo /漂/
ただよi /漂/
ただよh /漂/
ただよe /漂/
ただよc /漂/
ただたんn /只単/
ただt /直/
ただs /正/但;但し書き/質;(問い質す) 趣意を質す/糺;(糾弾する) 不正を糺す/匡;(型に押し込めて形を直す)/
ただr /爛/糜;<rare>/
ただc /直/
たたみこn /畳み込/
たたみこm /畳み込/
たたみかk /畳み掛/
たたづm /佇/
たたっきt /叩っ斬/
たたっきr /叩っ斬/
たたっきn /叩っ斬/
たたっきc /叩っ斬/
たたずn /佇/彳/
たたずm /佇/彳/
たたきふs /叩き伏/
たたきなおs /叩き直/
たたきつぶs /叩き潰/
たたきつk /叩き付/叩きつ;※送り位置補正/
たたきだs /叩き出/
たたきこわs /叩き壊/
たたきころs /叩き殺/
たたきこn /叩き込/
たたきこm /叩き込/
たたききt /叩き切/
たたききr /叩き切/
たたききn /叩き切/
たたききc /叩き切/
たたきかえs /叩き返/
たたきおとs /叩き落/
たたきおこs /叩き起/
たたきおk /叩き起/
たたきうt /叩き売/
たたきうr /叩き売/
たたきうn /叩き売/
たたきうc /叩き売/
たたきあg /叩き上/
たたかw /戦;(字義:武器で敵を倒す)/闘;(字義:二者が向き合い争う)/戰;「戦」の旧字(人名用漢字)/鬪;「闘」の旧字/斗;「闘」の略字/
たたかu /戦;(字義:武器で敵を倒す)/闘;(字義:二者が向き合い争う)/斗;「闘」の略字/戰;「戦」の旧字(人名用漢字)/鬪;「闘」の旧字/
たたかt /戦;(字義:武器で敵を倒す)/闘;(字義:二者が向き合い争う)/戰;「戦」の旧字(人名用漢字)/鬪;「闘」の旧字/斗;「闘」の略字/
たたかo /戦;(字義:武器で敵を倒す)/闘;(字義:二者が向き合い争う)/斗;「闘」の略字/戰;「戦」の旧字(人名用漢字)/鬪;「闘」の旧字/
たたかi /戦;(字義:武器で敵を倒す)/闘;(字義:二者が向き合い争う)/戰;「戦」の旧字(人名用漢字)/鬪;「闘」の旧字/斗;「闘」の略字/
たたかh /戰;「戦」の旧字(人名用漢字)/鬪;「闘」の旧字/
たたかe /戦;(字義:武器で敵を倒す)/闘;(字義:二者が向き合い争う)/戰;「戦」の旧字(人名用漢字)/斗;「闘」の略字/鬪;「闘」の旧字/
たたかc /戦;(字義:武器で敵を倒す)/闘;(字義:二者が向き合い争う)/斗;「闘」の略字/戰;「戦」の旧字(人名用漢字)/鬪;「闘」の旧字/
たたえt /湛/
たたえr /湛/
たたえn /湛/
たたえc /湛/
たたt /祟/
たたr /祟/
たたn /祟/畳/疊;「畳」の旧字(人名用漢字)/疉;「畳」の旧字2/疂;「畳」の旧字3/
たたm /畳/疊;「畳」の旧字(人名用漢字)/疉;「畳」の旧字2/疂;「畳」の旧字3/
たたk /叩/敲;(knock)「戸を敲く」/
たたi /叩/敲;(knock)「戸を敲く」/
たたh /称/湛/
たたe /称/讃/湛;水を-/賛/
たたc /祟/
たそがr /黄昏/
たずねいt /尋ね入/
たずねいr /尋ね入/
たずねいn /尋ね入/
たずねいc /尋ね入/
たずねあるk /訪ね歩/
たずねあるi /訪ね歩/
たずねあt /尋ね当/
たずさわt /携/
たずさわr /携/
たずさわn /携/
たずさわc /携/
たずさw /携/攜;異体字/
たずさe /携/攜;異体字/
たずn /尋;generic/訪;visit.「故国を訪ねる」/訊;inquire. 「道を訊ねる」/
たすけあw /助け合/
たすけあu /助け合/
たすけあt /助け合/
たすけあo /助け合/
たすけあi /助け合/
たすけあe /助け合/
たすけあc /助け合/
たすきぞr /襷反/
たすきがk /襷掛/
たすかr /助か;※送り位置補正/
たすk /助/援;(字義:手を差し伸べる)/扶;(字義:手で体を支えてやる)/佐;<rare>(字義:手を添える)/
たしょうちがu /多少違/
たしょうちがt /多少違/
たしょうちがi /多少違/
たしょうちがe /多少違/
たしょうたかs /多少高/
たしょうたかk /多少高/
たしょうたかi /多少高/
たしょうたかg /多少高/
たしょうおくr /多少遅/
たしなn /嗜;(like)詩を嗜む/
たしなm /嗜;(like)詩を嗜む/窘;(warn)非礼を窘める/
たしかめあw /確かめ合/
たしかめあu /確かめ合/
たしかめあt /確かめ合/
たしかめあo /確かめ合/
たしかめあi /確かめ合/
たしかめあe /確かめ合/
たしかめあc /確かめ合/
たしあわs /足し合/
たしあw /足し合/
たしk /確/慥;-か/
たけりたt /猛り立/
たけりたc /猛り立/
たけりくるw /猛り狂/
たけりくるu /猛り狂/
たけりくるt /猛り狂/
たけりくるo /猛り狂/
たけりくるi /猛り狂/
たけりくるc /猛り狂/
たけなわs /酣/闌;≒酣/
たけなわn /闌;≒酣/酣/
たけなわd /酣/闌;≒酣/
たけだけs /猛々/猛猛/
たけしたどおr /竹下通/
たけt /猛/哮;吠える/
たけs /猛/
たけr /猛/哮;吠える/
たけn /猛/哮;吠える/
たけk /猛/
たけi /猛/
たけc /猛/哮;吠える/
たけb /猛;[文語]-ぶ/建;≒猛ぶ/誥;≒猛ぶ/
たぐりよs /手繰り寄/
たぐりこn /手繰り込/
たぐりこm /手繰り込/
たぐu /比/類/
たぐt /手繰/
たぐr /手繰/
たぐn /手繰/
たぐi /類/
たぐh /比/類/
たぐc /手繰/
たくわe /蓄/貯/畜;<rare>/
たくらn /企/
たくらm /企/
たくまs /逞/
たくはh /蓄/貯/
たくs /託;委託/托;托卵/
たくr /綰/
たくn /巧/
たくm /巧/
たぎt /滾/激/
たぎr /滾/激/
たぎn /滾/激/
たぎc /滾/激/
たきつk /焚き付/焚付/
たきしm /薫き染/
たきこn /炊き込;炊き込みご飯/炊込/薫き込;香を薫き込む/
たきこm /炊き込;炊き込みご飯/炊込/薫き込;香を薫き込む/
たきあわs /炊き合/
たきあw /炊き合;筍とワカメを-わせる/
たきあg /炊き上;ふっくらと-げる/
たがやs /耕/畊;「耕」の異体字/畉;別字 (NB:「たがや・す」として使われる可能性は皆無)/
たがいちがi /互い違/
たがw /違/
たがu /違/
たがt /違/
たがo /違/
たがi /互/違/
たがh /違/
たがe /違/
たがc /違/
たかをくくt /高を括/
たかをくくr /高を括/
たかをくくn /高を括/
たかをくくc /高を括/
たからさがs /宝探/
たかぶt /昂/
たかぶr /昂/昂ぶ;※送り位置補正/亢ぶ;※送り位置補正/
たかぶn /昂/
たかぶc /昂/
たかのぞm /高望/
たかなt /高鳴/
たかなr /高鳴/
たかなn /高鳴/
たかなc /高鳴/
たかどm /高止/
たかてr /高照;‖枕詞(-らす)/
たかすg /高過/
たかt /集/
たかs /高/
たかr /集/高;高らか/
たかn /高/集/
たかm /高/
たかk /高/
たかi /高/
たかg /高;-が(知れた)/
たかc /集/
たかb /高/
たおれふs /倒れ伏/倒れ臥/
たおれこn /倒れ込/
たおれこm /倒れ込/
たおれr /殕/
たおしこn /倒し込/
たおしこm /倒し込/
たおy /嫋/
たおt /手折;花を手折る/
たおs /倒/
たおr /倒/手折;花を手折る/斃;(倒れて死ぬ) 戦地に斃れる/仆;(ぱたんと倒れる)/
たおn /手折;花を手折る/
たおc /手折;花を手折る/
たえまなs /絶え間無/
たえまなk /絶え間無/
たえまなi /絶え間無/
たえはt /絶え果/
たえぬk /耐え抜/
たえぬi /耐え抜/
たえだe /絶え絶/
たえしのn /堪え忍/
たえしのb /堪え忍/
たえきt /耐え切/
たえきr /耐え切/
たえきn /耐え切/
たえきc /耐え切/
たえがたs /耐え難/
たえがたk /耐え難/
たえがたi /耐え難/
たえがたg /耐え難/
たえかn /堪え兼/
たえいt /絶え入/
たえいr /絶え入/
たえいn /絶え入/
たえいc /絶え入/
たえz /絶え;※送り位置補正/
たえn /妙/
たうe /田植/
たいへんよs /大変良/
たいへんよk /大変良/
たいへんよi /大変良/
たいへんよg /大変良/
たいへんもうs /大変申/
たいへんおそs /大変遅/
たいへんおそk /大変遅/
たいへんおそi /大変遅/
たいへんおそg /大変遅/
たいげんどm /体言止/
たいおうづk /対応付/
たいおうs /対応/
たいあたr /体当/
たいあt /体当/
たいs /対/大/体;(obey)「意を体する」/對;「対」の旧字/帯/
たいr /平/
たあいなs /他愛無;当て字/
たあいなk /他愛無;当て字/
たあいなi /他愛無;当て字/
たy /絶/
たt /立/建/断/絶;消息を絶つ(途絶える)/経;時間が経つ/裁;布を裁つ/発;パリを発つ/起;風が起つ/截;截ち切る/勃;(erect)一物が勃つ/点;茶を点てる/閉;開け閉て/斷;「断」の旧字/發;「発」の旧字/經;「経」の旧字/強;?/
たs /足/誰;-そ/逹;「達」の異体字/
たr /垂/足/埀;「垂」の旧字/
たn /他/足/
たm /貯;(有用物) 金を貯める/溜/矯;(rectify) 癖を矯める/撓/揉/澑;「溜」の異体字/
たk /炊;飯を炊く/焚;風呂を焚く/長;一芸に長ける/薫;香を薫く/闌;≒長ける/
たi /炊;飯を炊く/焚;風呂を焚く/薫;香を薫く/
たh /他/堪/耐/
たe /耐/絶/堪;(値する) 見るに堪えない/
たc /立/断/経;時間が経つ/建/斷;「断」の旧字/絶;消息を絶つ(途絶える)/裁;布を裁つ/発;パリを発つ/起;風が起つ/截;截ち切る/勃/發;「発」の旧字/經;「経」の旧字/足/
たb /食/賜;[文語](バ行四段)/給;[文語](バ行四段)/
ぞんじあg /存じ上/
ぞんz /存/
ぞんj /存/
ぞろi /揃/
ぞろe /揃/
ぞくs /属/俗/
ぞくp /俗/
ぞくn /俗/
ぞくd /俗/
ぞうさなs /造作無/
ぞうさなk /造作無/
ぞうさなi /造作無/
ぞうs /蔵/
ぞt /反/
ぞr /反/
ぞn /反/
ぞm /初/染/
ぞi /沿/
ぞe /添/
ぞc /反/
そんざいs /存在/
そんz /損/
そんs /損/存/
そんn /損/
そんj /損/
そんd /損/
そろばんだかs /算盤高/
そろばんだかk /算盤高/
そろばんだかi /算盤高/
そろばんだかg /算盤高/
そろw /揃/
そろu /揃/
そろt /揃/
そろo /揃/
そろi /揃/
そろh /揃/
そろe /揃/
そろc /揃/
それとなk /其と無/
そりこn /剃り込/
そりこm /剃り込/
そりかえt /反り返/
そりかえr /反り返/
そりかえn /反り返/
そりかえc /反り返/
そりおとs /剃り落/
そらんz /諳/
そらんj /諳/
そらとぼk /空惚/
そらとb /空飛/
そらぞらs /空々/
そよi /戦/
そよg /戦/
そめわk /染め分/染分/
そめぬk /染め抜/
そめぬi /染め抜/
そめなおs /染め直;自分の色に-す/
そめだs /染め出/
そめこn /染め込/
そめこm /染め込/
そめあg /染め上/
そむk /背/叛;revolt/
そむi /背/叛;revolt/
そぼふt /そぼ降/
そぼふr /そぼ降/
そぼふn /そぼ降/
そぼふc /そぼ降/
そぼt /濡/
そぶr /素振/
そびえたt /聳え立/
そびえたc /聳え立/
そびe /聳/
そばだt /峙/
そねn /妬/嫉/猜/
そねm /妬/嫉/猜/
そなえつk /備え付/
そなw /備/具/
そなh /供/具/備/
そなe /供;(offer) お供え物/備;(prepare) 地震に備える/具;≒備える/
そとむk /外向/
そとまわr /外回/
そとづk /外付/
そとつk /外付/
そとがk /外掛/
そでぐr /袖刳/
そっけなs /素っ気無/
そっけなk /素っ気無/
そっけなi /素っ気無/
そだてあg /育て上/
そだt /育/毓;「育」の異体字/
そだr /具足/
そだc /育/毓;「育」の異体字/
そぞr /漫;-ろ/
そそりたt /聳り立/そそり立/
そそりたc /聳り立/そそり立/
そそばしt /遽走/
そそばしr /遽走/
そそばしn /遽走/
そそばしc /遽走/
そそのかs /唆/嗾;<rare> =唆す/
そそぎこn /注ぎ込/
そそぎこm /注ぎ込/
そそi /注/雪;(=すすg)「汚名を-ぐ」(cf.「雪辱」)/濯;(=すすg)「リンスを-ぐ」/灌;≒注ぐ/
そそg /注/灌;≒注ぐ/濯;(=すすg)「リンスを-ぐ」/雪;(=すすg)「汚名を-ぐ」(cf.「雪辱」)/
そしきだt /組織立/
そしt /謗;原義:あばく/誹;原義:言い立て、仲を裂く/譏;原義:鋭く問い質す/讒;原義:告げ口し陥れる/詆/
そしr /謗;原義:あばく/誹;原義:言い立て、仲を裂く/素知;当て字/そ知/譏;原義:鋭く問い質す/讒;原義:告げ口し陥れる/詆/
そしn /謗;原義:あばく/誹;原義:言い立て、仲を裂く/譏;原義:鋭く問い質す/讒;原義:告げ口し陥れる/詆/
そしc /謗;原義:あばく/誹;原義:言い立て、仲を裂く/譏;原義:鋭く問い質す/讒;原義:告げ口し陥れる/詆/
そこびe /底冷/
そこぬk /底抜/
そこなw /損/害/
そこなu /損/害/
そこなt /損/害/
そこなo /損/害/
そこなi /損/害/
そこなh /損/
そこなe /損/害/
そこなc /損/害/
そこしt /底知/
そこしr /底知/
そこしn /底知/
そこしc /底知/
そこいr /底入/
そこあg /底上/
そこn /損/害/
そぐw /似/
そぐu /似/
そぐt /似/
そぐo /似/
そぐi /似/
そぐe /似/
そぐc /似/
そくs /即;(即応) 実情に即する/則;(準則) 法に則する/促;(促進) 反省を促する/
そぎとt /削ぎ取/
そぎとr /削ぎ取/
そぎとn /削ぎ取/
そぎとc /削ぎ取/
そぎおとs /削ぎ落/
そうろu /候/
そうりょうちゃくばらi /送料着払/
そうらw /候/
そうらi /候/
そうらe /候/
そうめいs /聡明/
そうめいd /聡明/
そうふいただk /送付頂/
そうふいたs /送付致/
そうなm /総嘗/
そうとうn /相当/
そうていs /想定/
そうだんくだs /相談下/
そうだt /総立/
そうぞうs /騒々/
そうそu /然う然/
そうけだt /総毛立/
そうけだc /総毛立/
そうくずr /総崩/
そうz /総/
そうs /奏;「帝に奏する」「功を奏する」/草;「原稿を草する」/相/
そうn /躁;⇔鬱/
そうj /総/
そうd /躁;⇔鬱/
そいとg /添い遂/
そあくn /粗悪/
そw /沿;(go along) 道に沿う/添;寄り添う/副/
そu /沿;(go along) 道に沿う/添;寄り添う/副/
そt /沿;(go along) 道に沿う/添;寄り添う/剃;(shave)髭を剃る/反;(curve)板が反る/副/
そs /素/
そr /剃;(shave)髭を剃る/逸;(stray)話が逸れる/反;(curve)板が反る/其;-れ/
そo /沿;(go along) 道に沿う/添;寄り添う/副/
そn /其/素/剃;(shave)髭を剃る/反;(curve)板が反る/
そm /染/初;知り初める/
そi /沿;(go along) 道に沿う/添;寄り添う/副/削/殺/
そh /沿/添/副/
そg /削/殺/
そe /添;寄り添う/沿;(go along) 道に沿う/副/
そd /素/
そc /沿;(go along) 道に沿う/添;寄り添う/副/剃;(shave)髭を剃る/反;(curve)板が反る/
ぜんだt /膳立/
ぜんk /前/
ぜひきk /是非聞/
ぜひきi /是非聞/
ぜにうしなi /銭失/
ぜっくs /絶句/
ぜっs /絶/
ぜいぬk /税抜/
ぜいこm /税込/
ぜm /責/攻/
せんもんかむk /専門家向/
せんまいどおs /千枚通/
せんまいづk /千枚漬/
せんびk /線引/
せんぬk /栓抜/
せんにんぎr /千人斬/
せんなs /詮無/
せんなk /詮無/
せんなi /詮無/
せんなg /詮無/
せんたくばさm /洗濯挟/
せんたくs /選択/
せんぞがえr /先祖返/先祖帰;NB:辞書は多く「先祖返り」とする/
せんじつm /煎じ詰/
せんさいs /繊細/
せんさいn /繊細/
せんさいd /繊細/
せんかたなs /詮方無/
せんかたなk /詮方無/
せんかたなi /詮方無/
せんかたなg /詮方無/
せんz /詮;(consider)「-ずるに」/煎;(boil)「茶を煎ずる」/先/
せんs /宣;(declare)「革命を宣する」/僭;(ose)「王を僭する」/撰/
せんj /煎/先/
せわずk /世話好/
せわs /忙/
せりまk /競り負;⇔競り勝つ/
せりだs /迫り出/
せりかt /競り勝/
せりかc /競り勝/
せりおとs /競り落/
せりあw /競り合/
せりあu /競り合/
せりあt /競り合/
せりあo /競り合/
せりあi /競り合/
せりあg /競り上/迫り上/
せりあe /競り合/
せりあc /競り合/
せもたr /背凭/
せめよs /攻め寄/
せめほろb /攻め滅/
せめのぼt /攻め上/
せめのぼr /攻め上/
せめのぼn /攻め上/
せめのぼc /攻め上/
せめぬk /攻め抜/
せめぬi /攻め抜/
せめつづk /攻め続;城を攻め続ける/責め続;失敗を責め続ける/
せめたt /攻め立;敵を攻め立てる/責め立;失敗を責め立てる/
せめさいなn /責め苛/
せめさいなm /責め苛/
せめころs /責め殺/
せめこn /攻め込/
せめこm /攻め込/
せめぎあw /鬩ぎ合/
せめぎあu /鬩ぎ合/
せめぎあt /鬩ぎ合/
せめぎあo /鬩ぎ合/
せめぎあi /鬩ぎ合/
せめぎあe /鬩ぎ合/
せめぎあc /鬩ぎ合/
せめきt /攻め切/
せめきr /攻め切/
せめきn /攻め切/
せめきc /攻め切/
せめおとs /攻め落/責め落;<rare>/
せめおt /攻め落/
せめいt /攻め入/
せめいr /攻め入/
せめいn /攻め入/
せめいc /攻め入/
せめあぐn /攻め倦/
せめあぐm /攻め倦/
せめあw /攻め合;陣地を-/責め合;失敗を-/
せめあu /攻め合;陣地を-/責め合;失敗を-/
せめあt /攻め合;陣地を-/責め合;失敗を-/
せめあo /攻め合;陣地を-/責め合;失敗を-/
せめあi /攻め合;陣地を-/責め合;失敗を-/
せめあe /攻め合;陣地を-/責め合;失敗を-/
せめあc /攻め合;陣地を-/責め合;失敗を-/
せめr /攻め;※送り位置補正/
せめi /鬩/
せめg /鬩/
せまりこz /迫り来/
せまりこy /迫り来/
せまりこs /迫り来/
せまりこr /迫り来/
せまりこn /迫り来/
せまりこi /迫り来/
せまりくr /迫り来/
せまりくn /迫り来/
せまりきy /迫り来/
せまりきt /迫り来/
せまりきs /迫り来/
せまりきn /迫り来/
せまりきm /迫り来/
せまりきd /迫り来/
せまりきc /迫り来/
せまっくるs /狭っ苦/
せますg /狭過/
せまくるs /狭苦/
せまt /迫/逼/
せまs /狭/狹;「狭」の旧字(人名用漢字)/
せまr /迫/逼/
せまn /迫/逼/
せまm /狭/狹;「狭」の旧字(人名用漢字)/
せまk /狭/狹;「狭」の旧字(人名用漢字)/
せまi /狭/狹;「狭」の旧字(人名用漢字)/
せまg /狭/狹;「狭」の旧字(人名用漢字)/
せまc /迫/逼/
せぶm /瀬踏/
せばm /狭/狹;「狭」の旧字(人名用漢字)/
せはs /忙/
せのb /背伸/
せなかあw /背中合/
せつめいしょどおr /説明書通/
せつめいs /説明/
せつぞくs /接続/
せつs /切;切断/
せつn /切;切断/
せつk /責付/
せつi /責付/
せつd /切;切断/
せっぱつまt /切羽詰/
せっぱつまr /切羽詰/
せっぱつまn /切羽詰/
せっぱつまc /切羽詰/
せっぱつm /切羽詰/
せっていまちがi /設定間違/
せっていs /設定/
せっつk /責付/
せっつi /責付/
せっしょくs /接触/
せっきんs /接近/
せっきょうたr /説教垂/
せっきょうくさs /説教臭/
せっきょうくさk /説教臭/
せっきょうくさi /説教臭/
せっきょうくさg /説教臭/
せっs /接/
せちがらs /世知辛/
せちがらk /世知辛/
せちがらi /世知辛/
せちがらg /世知辛/
せせらわらw /せせら笑/嘲笑/
せせらわらu /嘲笑/せせら笑/
せせらわらt /せせら笑/嘲笑/
せせらわらo /せせら笑/嘲笑/
せせらわらi /せせら笑/嘲笑/
せせらわらe /せせら笑/嘲笑/
せせらわらc /嘲笑/せせら笑/
せけんずr /世間擦/
せきばらi /咳払/
せきにんもt /責任持/
せきにんとt /責任取/
せきにんとr /責任取/
せきにんとn /責任取/
せきにんとc /責任取/
せきとm /堰き止/塞き止/せき止/
せきたt /急き立/
せききt /急き切/
せききr /急き切/
せききn /急き切/
せききc /急き切/
せきがe /席替/
せおいこn /背負い込/背負込/
せおいこm /背負い込/背負込/
せおw /背負/
せおu /背負/
せおt /背負/
せおo /背負/
せおi /背負/
せおe /背負/
せおc /背負/
せうs /抄/
せいびs /整備/
せいちょうs /成長/
せいだs /精出/
せいぞろi /勢揃/
せいせいs /生成/
せいげんつk /制限付/
せいかくs /正確/
せいかくn /正確/
せいs /制;(control) 接戦を制する/征;(conquer) 夷狄を征する/製;(produce) 薬剤を製する/省/
せいn /聖;聖なる/
せz /為;do/
せy /為;do/
せt /競/迫/糶;<rare> =競り/
せr /迫/競/糶;<rare> =競り/
せn /迫/競/糶;<rare> =競り/
せm /攻;(attack)敵を攻める/責;(blame)失敗を責める/
せk /急/咳/堰;=塞く/塞;=堰く/
せi /急/咳/堰;=塞く/塞;=堰く/
せg /背/
せc /迫/競/糶;<rare> =競り/
ずわr /座/
ずれこn /ずれ込/
ずれこm /ずれ込/
ずれz /ズレ/
ずれy /ズレ/
ずれt /ズレ/
ずれs /ズレ/
ずれr /ズレ/
ずれn /ズレ/
ずれm /ズレ/
ずれk /ズレ/
ずれc /ズレ/
ずるs /狡/
ずるk /狡/
ずるi /狡/
ずるg /狡/
ずりおt /ずり落/
ずりおc /ずり落/
ずぶぬr /ずぶ濡/
ずぶとs /図太/
ずぶとk /図太/
ずぶとi /図太/
ずぶとg /図太/
ずぬk /頭抜/図抜/
ずどr /図取/
ずつk /頭突/
ずうずうs /図々/
ずs /誦;経を-す(る)/
ずr /刷/
ずm /済/住/濟;「済」の旧字/
ずk /好/尽;(連濁) 欲得尽く,納得尽く,他人尽く/付;※仮名遣い「づk」/
すんづm /寸詰/
すわりなおs /座り直/
すわりこn /座り込/
すわりこm /座り込/
すわt /座/坐/
すわr /座/坐/
すわn /座/坐/
すわc /座/坐/
すれちがw /すれ違/擦れ違/
すれちがu /すれ違/擦れ違/
すれちがt /すれ違/擦れ違/
すれちがo /すれ違/擦れ違/
すれちがi /すれ違/擦れ違/
すれちがe /すれ違/擦れ違/
すれちがc /すれ違/擦れ違/
すれあw /擦れ合/
すれあu /擦れ合/
すれあt /擦れ合/
すれあo /擦れ合/
すれあi /擦れ合/
すれあe /擦れ合/
すれあc /擦れ合/
するどs /鋭/
するどk /鋭/
するどi /鋭/
するどg /鋭/
すりよt /擦り寄/摩り寄;<rare>/
すりよr /擦り寄/摩り寄;<rare>/
すりよn /擦り寄/摩り寄;<rare>/
すりよc /擦り寄/摩り寄;<rare>/
すりむk /擦り剥/擦剥/
すりむi /擦剥/擦り剥/
すりへt /磨り減/
すりへr /磨り減/
すりへn /磨り減/
すりへc /磨り減/
すりぬk /擦り抜/すり抜/擦抜/擦り拔;旧字/
すりぬi /擦り抜/すり抜/擦抜/擦り拔;旧字/
すりつぶs /すり潰/磨り潰/摺り潰/
すりつk /擦り付;NB:「こすりつk」「なすりつk」と同形/
すりこn /刷り込;(imprint) 嗜好を刷り込まれる/摺り込;(rub into) 軟膏を摺り込む/摩り込;≒摺り込む/刷込/
すりこm /刷り込;(imprint) 嗜好を刷り込まれる/摺り込;(rub into) 軟膏を摺り込む/摩り込;≒摺り込む/刷込/
すりくだk /擂り碎;「砕」旧字/擂り砕/
すりくだi /擂り砕/擂り碎;「砕」旧字/
すりきt /擦り切/摺り切/摩り切;<rare>/
すりきr /擦り切/摺り切/摩り切;<rare>/
すりきn /擦り切/摺り切/摩り切;<rare>/
すりきc /擦り切/摺り切/摩り切;<rare>/
すりかわr /掏り替/
すりかw /掏り替/
すりかe /摩り替/すり替/掏り替/
すりあわs /擦り合;双方の案を-せる/摺り合;=擦り合わせる/
すりあw /擦り合/摺り合/
すりあg /刷り上/
すやk /素焼/
すもぐr /素潜/
すみわたt /澄み渡/
すみわたr /澄み渡/
すみわたn /澄み渡/
すみわたc /澄み渡/
すみわk /棲み分/住み分/
すみやk /炭焼/
すみなs /住み成;-したる庵あり/
すみなr /住み慣/住み馴/
すみつk /住み着/
すみつi /住み着/
すみこn /住み込/住込/
すみこm /住み込/住込/
すみくr /住み暮/
すみきt /澄み切/
すみきr /澄み切/
すみきn /澄み切/
すみきc /澄み切/
すみy /速/
すまu /住ま;※送り位置補正/
すまi /住ま;※送り位置補正/
すまh /住ま;※送り位置補正/
すぼn /窄/
すぼm /窄/
すべりどm /滑り止/
すべりだs /滑り出/
すべりこn /滑り込/
すべりこm /滑り込/
すべりおt /滑り落/
すべりおc /滑り落/
すべからk /須/
すべt /滑/全/総/總;「総」の旧字/辷;(国字)/
すべr /滑/辷;(国字)/
すべn /滑/辷;(国字)/
すべc /滑/辷;(国字)/
すぶr /素振/
すばらs /素晴/
すばやs /素早/
すばやk /素早/
すばやi /素早/
すばやg /素早/
すばなr /巣離/
すばr /素晴/
すなわt /即/則/乃/
すなわc /即/
すなどt /漁/
すなどr /漁/
すなどn /漁/
すなどc /漁/
すどまr /素泊/
すどおs /素通/
すどおr /素通/
すどm /素泊/
すでn /既/
すてさt /捨て去/
すてさr /捨て去/
すてさn /捨て去/
すてさc /捨て去/
すてきt /捨て切/
すてきr /捨て切/
すてきn /捨て切/
すてきd /素敵/
すてきc /捨て切/
すてがたs /捨て難/
すてがたk /捨て難/
すてがたi /捨て難/
すてがたg /捨て難/
すておk /捨て置/
すておi /捨て置/
すてr /捨て;※送り位置補正/
すづk /酢漬/
すっぽぬk /すっぽ抜/
すっぱぬk /素っ破抜/すっぱ抜/スッパ抜/
すっぱぬi /素っ破抜/すっぱ抜/スッパ抜/
すっとぼk /素っ恍/
すっとn /すっ飛/素っ飛/
すっとb /すっ飛/素っ飛/
すだt /巣立/
すだc /巣立/
すたt /廃/頽;NB:「くずおr」と同形/廢;「廃」の旧字/
すたr /廃/頽;NB:「くずおr」と同形/廢;「廃」の旧字/
すたn /廃/頽;NB:「くずおr」と同形/廢;「廃」の旧字/
すたc /廃/頽;NB:「くずおr」と同形/廢;「廃」の旧字/
すそわk /裾分/
すそとr /裾取/
すずなr /鈴生/
すずy /涼/
すずs /涼/凉;「涼」の旧字(人名用漢字)/
すずr /漫/
すずn /涼/凉;「涼」の旧字(人名用漢字)/
すずm /涼/凉;「涼」の旧字(人名用漢字)/
すすりなk /啜り泣/
すすりなi /啜り泣/
すすりこn /啜り込/
すすりこm /啜り込/
すすりあg /啜り上/
すすみでy /進み出/
すすみでt /進み出/
すすみでr /進み出/
すすみでn /進み出/
すすみでm /進み出/
すすt /啜/
すすr /啜/
すすn /進/啜/
すすm /進/勧;(advise) 留学を勧める/薦;(recommend) 本を薦める/奨;(encourage) 勉学を奨める/勸;「勧」の旧字/
すすk /煤/
すすi /濯;洗い物を-/漱;口を-/雪;恥を-/啌;<rare> ≒漱ぐ/
すすg /濯;洗い物を-/漱;口を-/雪;恥を-/啌;<rare> ≒漱ぐ/
すすc /啜/
すすb /煤;煤ぼけた暖炉/
すじちがi /筋違/
すじがねいr /筋金入/
すじあi /筋合/
すじt /捩/
すじr /捩/
すじn /捩/
すじc /捩/
すさt /退/
すさr /退/
すさn /荒;生活が荒む,風が吹き荒ぶ/退/遊;口遊む,筆の遊び (NB:「あそb」と同形)/進/
すさm /凄;-まじい/荒;生活が荒む/遊;口遊む/進/
すさc /退/
すさb /荒;風が吹き荒ぶ/遊;筆の遊び (NB:「あそb」と同形)/進/
すごもr /巣篭/
すごすg /凄過/
すごしやすs /過ごし易/
すごしやすk /過ごし易/
すごしやすi /過ごし易/
すごしやすg /過ごし易/
すごs /過/凄/
すごm /凄/
すごk /凄/
すごi /凄/
すごg /凄/
すこぶr /頗/
すこy /健/
すこs /少/
すげなs /素気無/
すげなk /素気無/
すげなi /素気無/
すげなg /素気無/
すげかe /挿げ替/すげ替/
すげn /素気;-なく断る/
すぐりぬk /選り抜/
すぐりぬi /選り抜/
すぐt /選;果実を選る NB:「えr」「よr」と同形/
すぐs /過/
すぐr /優/勝/選;果実を選る NB:「えr」「よr」と同形/秀/
すぐn /直/選;果実を選る NB:「えr」「よr」と同形/
すぐc /選;果実を選る NB:「えr」「よr」と同形/
すくなs /少;非正則(すくn)/尠;(字義:甚だしく少ない)/寡;(字義:頼れるものがない)/
すくなk /少;非正則(すくn)/少な;※送り位置補正/尠;(字義:甚だしく少ない)/寡;(字義:頼れるものがない)/
すくなi /少;非正則(すくn)/少な;※送り位置補正/尠;(字義:甚だしく少ない)/寡;(字義:頼れるものがない)/
すくなg /少;非正則(すくn)/尠;(字義:甚だしく少ない)/寡;(字義:頼れるものがない)/
すくいなg /掬い投/
すくいだs /救い出/
すくいあg /掬い上/
すくw /救/掬;「水を掬う」「足元を掬う」/巣喰/済;(宗教的に救済する)/抄;≒掬う/
すくu /救/掬;「水を掬う」「足元を掬う」/巣喰/済;(宗教的に救済する)/抄;≒掬う/巣く;※送り位置補正/
すくt /救/掬;「水を掬う」「足元を掬う」/巣喰/済;(宗教的に救済する)/抄;≒掬う/
すくo /救/掬;「水を掬う」「足元を掬う」/巣喰/済;(宗教的に救済する)/抄;≒掬う/
すくn /少/竦;足が竦んで/窘;<rare>/
すくm /竦/窘;<rare>/
すくi /救/掬;「水を掬う」「足元を掬う」/巣喰/済;(宗教的に救済する)/抄;≒掬う/
すくh /掬/救/済/抄/
すくe /救/掬;「水を掬う」「足元を掬う」/巣喰/済;(宗教的に救済する)/抄;≒掬う/
すくc /救/掬;「水を掬う」「足元を掬う」/巣喰/済;(宗教的に救済する)/抄;≒掬う/
すぎゆk /過ぎ行/
すぎさt /過ぎ去/
すぎさr /過ぎ去/
すぎさn /過ぎ去/
すぎさc /過ぎ去/
すぎn /過ぎ;※送り位置補正/
すきとおt /透き通/透き徹/
すきとおs /透き通/
すきとおr /透き通/透き徹/
すきとおn /透き通/透き徹/
すきとおc /透き通/透き徹/
すきとt /梳き取/
すきとr /梳き取/
すきとn /梳き取/
すきとc /梳き取/
すきずk /好き好/
すきこのn /好き好/
すきこのm /好き好/
すきこn /漉き込/鋤き込/
すきこm /漉き込/鋤き込/
すききらi /好き嫌/
すきかえs /鋤き返/
すきあw /好き合/
すきあu /好き合/
すきあt /好き合/
すきあo /好き合/
すきあi /好き合/
すきあe /好き合/
すきあc /好き合/
すがりつk /縋り付/
すがりつi /縋り付/
すがすがs /清々/
すがt /縋/
すがr /縋/末枯/尽/
すがn /縋/
すがm /眇;-める,矯めつ-めつ/
すがc /縋/
すかしみz /透かし見/
すかしみy /透かし見/
すかしみt /透かし見/
すかしみs /透かし見/
すかしみr /透かし見/
すかしみn /透かし見/
すかしみm /透かし見/
すかしみc /透かし見/
すかs /透;透して見る/賺;宥め賺す/
すえひろg /末広/
すえながs /末永/末長/
すえながk /末永/末長/
すえながi /末永/末長/
すえつk /据え付/据付/
すえたのm /末頼/
すえおそr /末恐/
すえおk /据え置/据置/
すえおi /据え置/据置/
すいよs /吸い寄/
すいとt /吸い取/
すいとr /吸い取/
すいとn /吸い取/
すいとc /吸い取/
すいつづk /吸い続/
すいつk /吸い付/
すいつi /吸い付/
すいだs /吸い出/吸出/
すいすg /吸い過/
すいこn /吸い込/
すいこm /吸い込/
すいあg /吸い上/
すいs /粋/
すいn /粋/
すいd /粋/
すあg /素揚/
すw /吸/据/喫;「煙草を喫う」 NB:比較的新しい表記/
すu /吸/喫;「煙草を喫う」 NB:比較的新しい表記/
すt /捨/吸/刷;本を刷る/棄;(字義:思い切ってすてる)/喫;「煙草を喫う」 NB:比較的新しい表記/擦;マッチを擦る/摺;版画を摺る/擂;胡麻を擂る/磨;墨を磨る/掏;財布を掏る/摩;天を摩る/剃;=そr/
すs /酸/
すr /擦;マッチを擦る/刷;本を刷る/為;do/摺;版画を摺る/擂;胡麻を擂る/磨;墨を磨る/掏;財布を掏る/摩;天を摩る/剃;=そr/爲;「為」の旧字(人名用漢字)/
すp /酸/
すo /吸/喫;「煙草を喫う」 NB:比較的新しい表記/
すn /済/住/棲;(動物が) 川に棲む/澄/拗;-ねる/濟;「済」の旧字/擦;マッチを擦る/刷;本を刷る/摺;版画を摺る/擂;胡麻を擂る/磨;墨を磨る/掏;財布を掏る/摩;天を摩る/剃;=そr/爲;「為」の旧字(人名用漢字)/清;≒澄む/栖;≒棲む/澂;「澄」の異体字/
すm /住/済/棲;(動物が) 川に棲む/澄/清;≒澄む/栖;≒棲む/濟;「済」の旧字/澂;「澄」の異体字/為;do/
すk /好/空/透/漉;紙を漉く/梳;(comb) 髪を梳く/鋤;(cultivate) 畑を鋤く/抄;≒漉く/剥;(slice) NB:「むk」と同形/耡;=鋤く/酸/
すi /酸/吸/空/喫;「煙草を喫う」 NB:比較的新しい表記/好/梳;(comb) 髪を梳く/透/済/濟;「済」の旧字/漉;紙を漉く/鋤;(cultivate) 畑を鋤く/抄;≒漉く/剥;(slice) NB:「むk」と同形/耡;=鋤く/
すg /過/直/
すe /据/吸/饐;(spoil) 饐えた臭い/喫;「煙草を喫う」 NB:比較的新しい表記/
すc /吸/喫;「煙草を喫う」 NB:比較的新しい表記/擦;マッチを擦る/刷;本を刷る/摺;版画を摺る/擂;胡麻を擂る/磨;墨を磨る/掏;財布を掏る/摩;天を摩る/剃;=そr/
すb /統/総;≒統べる/總;「総」の旧字/
じんどt /陣取/
じんどr /陣取/
じんどn /陣取/
じんどc /陣取/
じんとr /陣取/
じわr /地割/
じょさいなs /如才無/
じょさいなk /如才無/
じょさいなi /如才無/
じょうやとi /常雇/
じょうほうくだs /情報下/
じょうだんぬk /冗談抜/
じょうせきどおr /定石通/
じょうさs /状差/
じょうけんづk /条件付/
じょうz /乗/乘;「乗」の旧字(人名用漢字)/
じょうs /城/
じょうn /上/状/
じょうj /乗/乘;「乗」の旧字(人名用漢字)/
じょうd /状/
じょs /除;除算/叙;叙述/序/恕;(ゆるす)寛恕/
じゆうさんかd /自由参加/
じゆうd /自由/
じゅんばんまt /順番待/
じゅんばんまc /順番待/
じゅんじょよs /順序良/
じゅんじょよk /順序良/
じゅんじょよi /順序良/
じゅんじょだt /順序立/
じゅんぐr /順繰/
じゅんおくr /順送/
じゅんz /準/殉/准;「準」の略字/凖;「準」の異体字/
じゅんs /純/
じゅんn /順/純/
じゅんj /準/殉/准;「準」の略字/凖;「準」の異体字/
じゅんd /純/
じゅつごよb /述語呼/
じゅくs /熟;ripe/
じゅうりょうあg /重量挙/
じゅうらいどおr /従来通/
じゅうぶんn /十分/
じゅうぶんd /十分/
じゅうばこよm /重箱読/
じゅうなんn /柔軟/
じゅうだいn /重大/
じゅうじがたm /十字固/
じゅs /誦/呪/
じゅn /得/
じゃらs /戯/
じゃまくさs /邪魔臭/
じゃまくさk /邪魔臭/
じゃまくさi /邪魔臭/
じゃまくさg /邪魔臭/
じゃっかんことn /若干異/
じゃr /戯/
じむてづづk /事務手続/
じまんt /自慢/
じべt /地べ;※送り位置補正/
じひぶかs /慈悲深/
じひぶかk /慈悲深/
じひぶかi /慈悲深/
じひぶかg /慈悲深/
じひびk /地響/
じばk /字化/
じなr /地鳴/
じてんしゃのr /自転車乗/
じてんd /時点/
じづたi /地伝/
じづm /字詰/
じつづk /地続/
じつn /実/
じつh /実/
じっぱひとからg /十把一絡/
じっこうs /実行/
じっt /凝/
じだいおくr /時代遅/時代後/
じずm /字詰/
じしょひk /辞書引/
じさg /字下/
じこt /事故/
じこr /事故/
じこn /事故/
じこm /仕込/
じこc /事故/
じくばr /字配/
じきはずr /時期外/
じきs /直/
じきn /直;-に/
じきd /直/
じがたm /地固/
じかんぎr /時間切/
じかんおくr /時間遅/
じかづk /直付/
じかがk /直書/
じかn /直/
じかk /仕掛/
じあまr /字余/
じs /持;満を持して/辞;職を辞する/侍;(はべる) 帝に侍する/
じr /焦/
じn /死/染/
じm /染/
じk /敷/
じg /字/
しんぼうづよs /辛抱強/
しんぼうづよk /辛抱強/
しんぼうづよi /辛抱強/
しんぴてきd /神秘的/
しんぱいなs /心配無/
しんぱいなk /心配無/
しんぱいなi /心配無/
しんぱいなg /心配無/
しんちょうs /新調/
しんじんぶかs /信心深/
しんじんぶかk /信心深/
しんじんぶかi /信心深/
しんじんぶかg /信心深/
しんじゅくどおr /新宿通/
しんじつづk /信じ続/
しんじこn /信じ込/
しんじこm /信じ込/
しんじがたs /信じ難/
しんじがたk /信じ難/
しんじがたi /信じ難/
しんじがたg /信じ難/
しんじt /信じ;※送り位置補正/
しんじr /信じ;※送り位置補正/
しんしんともn /心身共/
しんこうs /進行/
しんけんd /真剣/
しんきくさs /辛気臭/心気臭;=辛気臭い/
しんきくさk /辛気臭/心気臭;=辛気臭い/
しんきくさi /辛気臭/心気臭;=辛気臭い/
しんきくさg /辛気臭/心気臭;=辛気臭い/
しんいr /新入/
しんz /信/進/死ん;※送り位置補正/
しんn /真/
しんj /信/
しをr /萎/
しわよs /皺寄/
しわぶk /咳/
しわぶi /咳/
しわがr /嗄/
しわs /吝/
しわk /仕分/仕訳;NB:簿記では送らず「仕訳」と書くのが普通/吝/
しわi /吝/
しわg /吝/
しろぬr /白塗/
しろぬk /白抜/
しろうとくさs /素人臭/
しろうとくさk /素人臭/
しろうとくさi /素人臭/
しろうとくさg /素人臭/
しろうとかんがe /素人考/
しろうとp /素人/
しろu /白/
しろs /白/
しろp /白/
しろm /白/
しろk /白/
しろi /白/
しろg /白/
しれわたt /知れ渡/
しれわたr /知れ渡/
しれわたn /知れ渡/
しれわたc /知れ渡/
しるs /記/著;形容詞, 明らかである/印;(mark) 足跡を印す/徴;(predict) 瑞兆を徴す/誌;≒記す/識;≒記す/標;掲げてしるす/示;?/
しるk /著;形容詞, 明らかである/
しるi /著;形容詞, 明らかである/
しるg /著;形容詞, 明らかである/
しりぬぐi /尻拭/
しりぬk /知り抜/
しりぬi /知り抜/
しりつくs /知り尽/
しりつk /知り尽/
しりぞk /退/斥/
しりぞi /退/斥/
しりさがr /尻下/
しりさg /尻下/
しりごm /尻込/
しりこそばゆi /尻擽/
しりきr /尻切/
しりあw /知り合/
しりあu /知り合/
しりあt /知り合/
しりあo /知り合/
しりあi /知り合/知合/
しりあg /尻上/
しりあe /知り合/
しりあc /知り合/
しらべあg /調べ上/
しらべr /調べ;※送り位置補正/
しらぬぞんz /知らぬ存/
しらちゃk /白茶/
しらじらs /白々/
しらz /知ら;※送り位置補正/
しらs /報/知ら;※送り位置補正/
しらn /白/
しらm /白/
しらk /白/
しらg /白;米を白げる(=精白する)/精;=白げる/
しらb /調/
しようくだs /使用下/
しようs /使用/
しようd /使用/
しょりs /処理/
しょぼs /ショボ/
しょぼk /ショボ/
しょぼi /ショボ/
しょぼg /ショボ/
しょってたt /背負って立/
しょってたc /背負って立/
しょっきあらi /食器洗/
しょっきr /初っ切/
しょっからs /塩っ辛/
しょっからm /塩っ辛/
しょっからk /塩っ辛/
しょっからi /塩っ辛/
しょっからg /塩っ辛/
しょたいじm /所帯染/
しょじs /所持/
しょしんしゃむk /初心者向/
しょざいなs /所在無/
しょざいなk /所在無/
しょざいなi /所在無/
しょげこn /悄気込/
しょげこm /悄気込/
しょげかえt /悄気返/
しょげかえr /悄気返/
しょげかえn /悄気返/
しょげかえc /悄気返/
しょげt /悄気/
しょげr /悄気/
しょげn /悄気/
しょげc /悄気/
しょくs /食/属;(漢音)属託(=嘱託)/嘱;属託/
しょきばらi /暑気払/
しょきかs /初期化/
しょうろうながs /精霊流/
しょうめんきt /正面切/
しょうめんきr /正面切/
しょうめんきn /正面切/
しょうめんきc /正面切/
しょうめいずm /証明済/
しょうめいs /証明/
しょうぶづよs /勝負強/
しょうぶづよk /勝負強/
しょうぶづよi /勝負強/
しょうぶづよg /勝負強/
しょうぶつよk /勝負強/
しょうどうがi /衝動買/
しょうだt /章立/
しょうじんおt /精進落/
しょうじいr /招じ入/請じ入/
しょうこだt /証拠立/
しょうこしらb /証拠調/
しょうこr /性懲/
しょうぎだおs /将棋倒/
しょうがつやすm /正月休/
しょうかいいただk /紹介頂/
しょうかいいたs /紹介致/
しょうz /生/請/
しょうs /称/証/賞/抄/頌/生;(呉音)/
しょうj /生/招/請/
しょいこn /背負い込/
しょいこm /背負い込/
しょw /背負/
しょu /背負/
しょt /背負/
しょs /処/署/書/
しょp /塩/
しょo /背負/
しょi /背負/
しょh /背負/
しょe /背負/
しょc /背負/
しゅんs /旬/
しゅんn /旬/
しゅんd /旬/
しゅびよk /首尾良/
しゅつりょくs /出力/
しゅっせばらi /出世払/
しゅくs /祝/
しゅうりがk /修理書/
しゅうねんぶかs /執念深/
しゅうねんぶかk /執念深/
しゅうねんぶかi /執念深/
しゅうねんぶかg /執念深/
しゅうねs /執念/
しゅうねk /執念/
しゅうねi /執念/
しゅうかんおくr /週間遅/
しゅうあk /週明/
しゅうs /執/修/
しゅt /主/
しゃれこn /洒落込/
しゃれこm /洒落込/
しゃれt /洒落/
しゃれr /洒落/
しゃれn /洒落/
しゃれc /洒落/
しゃらくさs /洒落臭/
しゃらくさk /洒落臭/
しゃらくさi /洒落臭/
しゃらくさg /洒落臭/
しゃべりだs /喋り出/
しゃべt /喋/諜;<rare>/
しゃべr /喋/諜;<rare>/
しゃべn /喋/諜;<rare>/
しゃべk /喋/
しゃべc /喋/諜;<rare>/
しゃぶりつk /しゃぶり付/
しゃぶりつi /しゃぶり付/
しゃっきんとr /借金取/
しゃちほこばt /鯱張/
しゃちほこばr /鯱張/
しゃちほこばn /鯱張/
しゃちほこばc /鯱張/
しゃしんうつr /写真写/
しゃしゃりでz /しゃしゃり出/
しゃしゃりでt /しゃしゃり出/
しゃしゃりでr /しゃしゃり出/
しゃしゃりでn /しゃしゃり出/
しゃこいr /車庫入/
しゃくりあg /しゃくり上/
しゃくt /抉;顎を-る (NB:「えぐr」「こじr」と同形)/決;=抉る/刳;=抉る/
しゃくs /癪/
しゃくr /抉;顎を-る (NB:「えぐr」「こじr」と同形)/決;=抉る/刳;=抉る/
しゃくn /抉;顎を-る (NB:「えぐr」「こじr」と同形)/決;=抉る/刳;=抉る/癪;-に障る/
しゃくd /癪/
しゃくc /抉;顎を-る (NB:「えぐr」「こじr」と同形)/決;=抉る/刳;=抉る/
しゃがr /嗄/
しゃs /謝/
しもやk /霜焼/
しもがr /霜枯/
しめわすr /閉め忘/
しめつk /締め付/締付/
しめだs /締め出/閉め出/
しめしあわs /示し合/
しめしあw /示し合/
しめこn /締め込/
しめこm /締め込/
しめくくt /締め括/
しめくくr /締め括/
しめくくn /締め括/
しめくくc /締め括/
しめきt /締め切;応募を-/閉め切;窓を-/締切/
しめきr /締め切;応募を-/閉め切;窓を-/締切/
しめきn /締め切;応募を-/閉め切;窓を-/締切/
しめきc /締め切;応募を-/閉め切;窓を-/締切/
しめいs /指名/
しめあg /締め上/
しめt /湿/〆/濕;「湿」の旧字(人名用漢字)/
しめs /示/湿/濕;「湿」の旧字(人名用漢字)/
しめr /湿/〆/濕;「湿」の旧字(人名用漢字)/
しめp /湿/濕;「湿」の旧字(人名用漢字)/
しめn /湿/〆/濕;「湿」の旧字(人名用漢字)/
しめc /湿/〆/濕;「湿」の旧字(人名用漢字)/
しむk /仕向/
しみとおt /沁み透/
しみとおr /沁み透/
しみとおn /沁み透/
しみとおc /沁み透/
しみでz /滲み出/染み出/
しみでy /滲み出/染み出/
しみでt /滲み出/染み出/
しみでs /滲み出/染み出/
しみでr /滲み出/染み出/
しみでn /滲み出/染み出/
しみでm /滲み出/染み出/
しみでc /滲み出/染み出/
しみつk /染み付/
しみつi /染み付/
しみだs /染み出/滲み出/
しみこn /染み込/
しみこm /染み込/
しみいt /染み入/
しみいr /染み入/
しみいn /染み入/
しみいc /染み入/
しみt /沁;非正則(しm)/
しみr /沁;非正則(しm)/
しみn /沁;非正則(しm)/
しみc /沁;非正則(しm)/
しまながs /島流/
しまいこn /仕舞い込/
しまいこm /仕舞い込/
しまw /仕舞/終/了/蔵/
しまu /仕舞/終/了/蔵/
しまt /仕舞/了/終/蔵/閉/
しまr /閉/
しまo /仕舞/終/了/蔵/
しまn /閉/
しまi /終/仕舞/了/蔵/
しまe /仕舞/終/了/蔵/
しまc /仕舞/終/了/蔵/閉/
しぼりだs /絞り出/搾り出/
しぼりこn /絞り込/
しぼりこm /絞り込/
しぼりあg /絞り上/
しぼt /絞/搾;(汁を取る) 乳を搾る/
しぼr /絞/搾;(汁を取る) 乳を搾る/
しぼn /萎/凋/絞/搾;(汁を取る) 乳を搾る/
しぼm /萎/凋/
しぼc /絞/搾;(汁を取る) 乳を搾る/
しぶt /渋/澁;「渋」の旧字(人名用漢字)/澀;「渋」の旧字2/
しぶs /渋/澁;「渋」の旧字(人名用漢字)/澀;「渋」の旧字2/
しぶr /渋/澁;「渋」の旧字(人名用漢字)/澀;「渋」の旧字2/
しぶn /渋/澁;「渋」の旧字(人名用漢字)/澀;「渋」の旧字2/
しぶm /渋/
しぶk /渋/澁;「渋」の旧字(人名用漢字)/澀;「渋」の旧字2/
しぶi /渋/澁;「渋」の旧字(人名用漢字)/澀;「渋」の旧字2/
しぶg /渋/澁;「渋」の旧字(人名用漢字)/澀;「渋」の旧字2/
しぶc /渋/澁;「渋」の旧字(人名用漢字)/澀;「渋」の旧字2/
しびr /痺/
しばりつk /縛り付/
しばりあg /縛り上/
しばらk /暫/
しばたk /瞬/
しばたi /瞬/
しばかr /柴刈;(薪) 山へ柴刈りに/芝刈;(芝生) 公園の芝刈り/
しばいじm /芝居染/
しばt /縛/
しばs /暫/
しばr /縛/暫/凍/
しばn /縛/
しばc /縛/
しはらw /支払/
しはらu /支払/
しはらt /支払/
しはらo /支払/
しはらi /支払/
しはらe /支払/
しはらc /支払/
しのびわらi /忍び笑/
しのびよt /忍び寄/
しのびよr /忍び寄/
しのびよn /忍び寄/
しのびよc /忍び寄/
しのびなk /忍び泣/
しのびなi /忍び泣/
しのびこn /忍び込/
しのびこm /忍び込/
しのびがたs /忍び難/
しのびがたk /忍び難/
しのびがたi /忍び難/
しのびがたg /忍び難/
しのびいt /忍び入/
しのびいr /忍び入/
しのびいn /忍び入/
しのびいc /忍び入/
しのばずどおr /不忍通/
しのつk /篠突;-く(雨)/
しのごn /四の五/
しのn /忍;恥を忍ぶ/偲;死者を偲ぶ/
しのi /凌/
しのg /凌/
しのb /偲;死者を偲ぶ/忍;恥を忍ぶ/
しにわかr /死に別/
しにものぐるi /死に物狂/
しにはt /死に果/
しにたe /死に絶/
しにぞこn /死に損/
しにそこn /死に損/
しにくs /為難/爲難;「為」旧字/
しにくk /為難/爲難;「為」旧字/
しにくi /為難/爲難;「為」旧字/
しにくg /為難/爲難;「為」旧字/
しにきr /死に切;(死ぬに)-れない/
しにかk /死に掛/
しにおくr /死に遅/
しにいそi /死に急/
しにいそg /死に急/
しなだr /撓垂/
しなぞろi /品揃/
しなぞろe /品揃/
しなさだm /品定/
しなぎr /品切/
しながe /品換/
しなおs /仕直/
しなw /撓/
しなu /撓/
しなt /撓/
しなs /為做/
しなr /撓/
しなo /撓/
しなn /撓/
しなi /撓/
しなh /撓/
しなe /撓/
しなc /撓/
しなb /萎/
しとy /淑/
しとm /仕留/爲留;「為」旧字/
しとg /仕遂/為遂/
しでかs /為出来/
しでk /仕出/為出/
してやt /為て遣/
してやr /為て遣/
してやn /為て遣/
してやc /為て遣/
してきどおr /指摘通/
してきs /指摘/
していs /指定/
しづらs /仕辛/
しづらk /仕辛/
しづらi /仕辛/
しづらg /仕辛/
しづr /垂/埀;「垂」の旧字/
しづn /沈;旧仮名/鎭;「鎮」の旧字(人名用漢字)/靜;「静」の旧字(人名用漢字)/
しづm /沈;旧仮名/鎭;「鎮」の旧字(人名用漢字)/靜;「静」の旧字(人名用漢字)/
しつりょうあたr /質量当/
しつらe /設/
しつけr /躾/
しつk /仕付;名詞・カ行下一/躾;名詞,カ行下一/
しっとぶかs /嫉妬深/
しっとぶかk /嫉妬深/
しっとぶかi /嫉妬深/
しっとぶかg /嫉妬深/
しったかぶt /知ったか振/
しったかぶr /知ったか振/
しったかぶn /知ったか振/
しったかぶc /知ったか振/
しっかt /確;-と/聢;-と/
しっかr /確/
しっs /失;遅きに失す/執/
しちめんどうくさs /七面倒臭/
しちめんどうくさk /七面倒臭/
しちめんどうくさi /七面倒臭/
しちめんどうくさg /七面倒臭/
しちながr /質流/
しちうk /質請/
しちいr /質入/
しだいしだいn /次第次第/
しだs /仕出/
しだr /垂/枝垂;-れ(柳)/
しだk /拉/
しだi /拉/
したよs /下寄/
したよm /下読/
したむk /下向/
したまわt /下回/
したまわr /下回/
したまわn /下回/
したまわc /下回/
したばたらk /下働/
したばe /下生/
したぬr /下塗/
したどt /下取/
したどr /下取/
したどn /下取/
したどc /下取/
したとr /下取/
したてひねr /下手捻/
したてなおs /仕立て直/
したてなg /下手投/
したてだしなg /下手出し投/
したてあg /仕立て上/
したづm /下積/
したつk /下付/
したったr /舌っ足/
したたりおt /滴り落/
したたりおc /滴り落/
したたt /滴/
したたr /滴/舌足/
したたn /滴/
したたm /認/
したたk /強/
したたc /滴/
したしらb /下調/
したしみぶかs /親しみ深/
したしみぶかk /親しみ深/
したしみぶかi /親しみ深/
したしみぶかg /親しみ深/
したしm /親し;※送り位置補正/親;非正則(したs)/
したざわr /舌触/
したごしらe /下拵/
したがw /従/随;(字義:相手のなすがままにする)「筆に随う」/順;(字義:道筋に沿って行く)「天命に順う」/从;「従」の本字 (字義:人が人について行く)/從;「従」の旧字(人名用漢字)/啝;<rare>/
したがu /従/随;(字義:相手のなすがままにする)「筆に随う」/順;(字義:道筋に沿って行く)「天命に順う」/从;「従」の本字 (字義:人が人について行く)/從;「従」の旧字(人名用漢字)/啝;<rare>/
したがt /従/随;(字義:相手のなすがままにする)「筆に随う」/順;(字義:道筋に沿って行く)「天命に順う」/从;「従」の本字 (字義:人が人について行く)/從;「従」の旧字(人名用漢字)/啝;<rare>/
したがo /従/随;(字義:相手のなすがままにする)「筆に随う」/順;(字義:道筋に沿って行く)「天命に順う」/从;「従」の本字 (字義:人が人について行く)/從;「従」の旧字(人名用漢字)/啝;<rare>/
したがk /下書/
したがi /従/随;(字義:相手のなすがままにする)「筆に随う」/順;(字義:道筋に沿って行く)「天命に順う」/从;「従」の本字 (字義:人が人について行く)/從;「従」の旧字(人名用漢字)/啝;<rare>/
したがh /従/随/順/从;「従」の本字/從;「従」の旧字(人名用漢字)/啝/
したがe /従/随;(字義:相手のなすがままにする)「筆に随う」/順;(字義:道筋に沿って行く)「天命に順う」/从;「従」の本字 (字義:人が人について行く)/從;「従」の旧字(人名用漢字)/啝;<rare>/
したがc /従/随;(字義:相手のなすがままにする)「筆に随う」/順;(字義:道筋に沿って行く)「天命に順う」/从;「従」の本字 (字義:人が人について行く)/從;「従」の旧字(人名用漢字)/啝;<rare>/
したうt /舌打/
したうk /下請/
したw /慕/
したu /慕/
したt /仕立/慕/
したs /親/
したo /慕/
したn /下/
したk /下/
したi /慕/
したh /慕/
したe /慕/
したc /慕/
しそんz /仕損/為損/
しそんj /仕損/為損/
しぜんn /自然/
しずみこn /沈み込/
しずみこm /沈み込/
しずまりかえt /静まり返/
しずまりかえr /静まり返/
しずまりかえn /静まり返/
しずまりかえc /静まり返/
しずy /静;-やか/
しずr /垂/
しずn /沈/沒;「没」の旧字/
しずm /沈/静/鎮;(字義:重みで押え付ける)謀反を鎮める/靜;「静」の旧字(人名用漢字)/鎭;「鎮」の旧字(人名用漢字)/沒;「没」の旧字/
しずk /静/靜;「静」の旧字(人名用漢字)/
しじょうむk /市場向/
しじどおr /指示通/
しさいr /子細/
しさs /示唆/
しごとはじm /仕事始/
しごとだかばらi /仕事高払/
しごk /扱/
しごi /扱/
しこうs /而/
しこt /凝;NB:「こr」と同形/痼/
しこr /凝;NB:「こr」と同形/痼/
しこn /仕込/凝;NB:「こr」と同形/痼/
しこm /仕込/
しこc /凝;NB:「こr」と同形/痼/
しげt /茂/繁/楙;<rare> ≒茂る/
しげs /繁/
しげr /茂/繁/楙;<rare> ≒茂る/
しげn /茂/繁/楙;<rare> ≒茂る/
しげm /茂/
しげk /繁/
しげc /茂/繁/楙;<rare> ≒茂る/
しけt /湿気;(get wet) 海苔が湿気る/時化;(storm) 海が時化る/
しけr /湿気;(get wet) 海苔が湿気る/時化;(storm) 海が時化る/
しけp /湿気/
しけn /湿気;(get wet) 海苔が湿気る/時化;(storm) 海が時化る/
しけc /湿気;(get wet) 海苔が湿気る/時化;(storm) 海が時化る/
しぐr /時雨/
しくn /仕組/
しくm /仕組/
しきんぐr /資金繰/
しきわm /爲極;「為」旧字/
しきりなおs /仕切り直/
しきはm /爲極;「為」旧字/
しきつm /敷き詰/
しきt /仕切;部屋を仕切る/頻;(frequent) 降り頻る,頻りに/
しきr /仕切;部屋を仕切る/頻;(frequent) 降り頻る,頻りに/
しきn /仕切;部屋を仕切る/頻;(frequent) 降り頻る,頻りに/
しきc /仕切;部屋を仕切る/頻;(frequent) 降り頻る,頻りに/
しがみつk /しがみ付/
しがみつi /しがみ付/
しかりつk /叱り付/
しかたなs /仕方無/
しかたなk /仕方無/
しかたなi /仕方無/
しかたなg /仕方無/
しかしながr /然し乍/併し乍/乍;「ながr」と同形/
しかくばt /四角張/
しかくばr /四角張/
しかくばn /四角張/
しかくばc /四角張/
しかくs /四角/
しかくk /四角/
しかくi /四角/
しかえs /仕返/
しかt /叱/確;-と/聢;(国字。字義:耳で確かに聞く)「聢と頼んだぞ」/
しかs /然;(however) 然しながら/併;≒然し/而;(then) 而して/
しかr /叱/然/
しかn /為兼/し兼/叱/爲兼;「為」旧字/
しかm /顰/
しかk /仕掛/仕懸;<rare> =仕掛け(る)/
しかc /叱/
しおやk /塩焼/
しおほs /爲果;「為」旧字/
しおづk /塩漬/
しおだm /潮溜/
しおたr /潮垂/
しおくt /仕送/爲送;「為」旧字/
しおくr /仕送/爲送;「為」旧字/
しおくn /仕送/爲送;「為」旧字/
しおくc /仕送/爲送;「為」旧字/
しおからs /塩辛/
しおからk /塩辛/
しおからi /塩辛/
しおからg /塩辛/
しおおs /爲果;「為」旧字/
しおr /萎/撓/枝折/霑/責/
しおk /仕置/爲置;「為」旧字/
しおi /仕置/爲置;「為」旧字/
しおe /為終/
しうt /仕打/
しいれr /仕入れ;※送り位置補正/
しいたg /虐/
しいt /強い;※送り位置補正/
しいs /弑/
しいr /仕入/
しあわs /幸/倖;≒幸せ/仕合;巡り合わせ・成り行き/
しあがt /仕上が;※送り位置補正/仕上/
しあがr /仕上/
しあがn /仕上/
しあがc /仕上/
しあw /仕合/為合/爲合;「為」旧字/
しあu /為合/爲合;「為」旧字/
しあt /為合/爲合;「為」旧字/
しあo /為合/爲合;「為」旧字/
しあi /為合/爲合;「為」旧字/
しあg /仕上/
しあe /為合/爲合;「為」旧字/
しあc /為合/爲合;「為」旧字/
しy /為;do/
しt /知/為;-て遣る/識;recognise/領;-る,-ろしめす (reign)/痴;-れ者/
しs /死/資;(contribute)発展に資す/歯;(仲間入りする)/齒;「歯」の旧字/為;do/
しr /知/識;recognise/領;-る,-ろしめす (reign)/痴;-れ者/為;do/
しn /死/知/為;do/識;recognise/領;-る,-ろしめす (reign)/痴;-れ者/染/沁;(≒染みる) 身に沁みる/凍;寒さで凍みる/滲;(≒染みる) 汗が滲み出る/浸;(≒染みる)/
しm /占/閉/締/染/絞;首を絞める/沁;(≒染みる) 身に沁みる/凍;寒さで凍みる/滲;(≒染みる) 汗が滲み出る/浸;(≒染みる)/〆;(期日や魚介類を)〆める/緊/閇;「閉」の異体字/為;do/
しk /敷/如/若/及/
しi /強/敷/誣;-いる(=欺く・こじつける)/如/若/及/
しh /強/誣/
しc /為;do/知/識;recognise/
ざんねんg /残念/
ざわt /騒/
ざらs /晒;(連濁) 店晒し,洗い晒し/曝/
ざつs /雑/
ざつn /雑/
ざつd /雑/
ざかr /盛/
ざいせきs /在籍/
ざs /座/差/坐;≒座/
ざr /戯/
ざm /覚/醒/冷/
ざk /咲/裂/
ざi /咲/裂/
ざe /冴/
さんまいおr /三枚下/
さんびょうしそろt /三拍子揃/
さんせいいたs /賛成致/
さんすくm /三竦/
さんしょうくだs /参照下/
さんしゅうくだs /参集下/
さんけづk /産気付/
さんけづi /産気付/
さんかくだs /参加下/
さんかいたs /参加致/
さんかs /参加/
さんz /参;馳せ参ずる/散;財を散ずる/
さんs /産/算;サ変(count)/参;サ変(participate)/賛;サ変(agree)/讃;サ変(praise)/
さんj /参;馳せ参じる/散;鬱憤を散じる/
さわぎだs /騒ぎ出/
さわぎたt /騒ぎ立/
さわy /爽/
さわt /触;touch/障;(hinder) 気に障る/觸;「触」の旧字/
さわr /触;touch/障;(hinder) [気癪]に障る/觸;「触」の旧字/
さわn /触;touch/障;(hinder) 気に障る/觸;「触」の旧字/
さわi /騒/騷;「騒」の旧字(人名用漢字)/
さわg /騒/騷;「騒」の旧字(人名用漢字)/
さわc /触;touch/障;(hinder) 気に障る/觸;「触」の旧字/
さりゆk /去り行/
さらけだs /曝け出/
さらあらi /皿洗/
さらw /攫;子供を攫う/浚;ドブを浚う/掠;≒攫う/復習;授業を復習う/渫;≒浚う/濬;≒浚う/
さらu /攫;子供を攫う/浚;ドブを浚う/掠;≒攫う/復習;授業を復習う/渫;≒浚う/濬;≒浚う/
さらt /攫;子供を攫う/浚;ドブを浚う/掠;≒攫う/復習;授業を復習う/渫;≒浚う/濬;≒浚う/
さらs /晒/曝/
さらo /攫;子供を攫う/浚;ドブを浚う/掠;≒攫う/復習;授業を復習う/渫;≒浚う/濬;≒浚う/
さらn /更/然ら;※送り位置補正/
さらk /曝/
さらi /攫;子供を攫う/浚;ドブを浚う/掠;≒攫う/復習;授業を復習う/渫;≒浚う/濬;≒浚う/
さらh /浚/渫/復習/
さらe /浚;ドブを浚う/渫;≒浚う/攫;子供を攫う/掠;≒攫う/復習;授業を復習う/濬;≒浚う/
さらc /攫;子供を攫う/浚;ドブを浚う/掠;≒攫う/復習;授業を復習う/渫;≒浚う/濬;≒浚う/
さらb /然ら;※送り位置補正/
さやばしt /鞘走;刀が-る/
さやばしr /鞘走;刀が-る/
さやばしn /鞘走;刀が-る/
さやばしc /鞘走;刀が-る/
さやあt /鞘当/
さめやr /覚め遣/醒め遣/冷め遣/
さめr /寤/
さむすg /寒過/
さむざむs /寒々/
さむu /寒/
さむs /寒/
さむm /寒/
さむk /寒/
さむi /寒/
さむg /寒/
さみs /寂/淋;NB:日本のみの用字/
さまよw /彷徨;(熟字訓)/さ迷/彷/
さまよu /彷徨;(熟字訓)/さ迷/彷/
さまよt /彷徨;(熟字訓)/さ迷/彷/
さまよo /彷徨;(熟字訓)/さ迷/彷/
さまよi /彷徨;(熟字訓)/さ迷/彷/
さまよe /彷徨;(熟字訓)/さ迷/彷/
さまよc /彷徨;(熟字訓)/さ迷/彷/
さまたg /妨/碍;<rare>/
さまざまn /様々/
さまがわr /様変/
さまがw /様変/
さまs /冷/醒/
さぼt /サボ/
さぼr /サボ/
さぼn /サボ/
さぼc /サボ/
さぶらw /候/
さぶらu /候/
さぶらt /候/
さぶらo /候/
さぶらi /候/
さぶらe /候/
さぶらc /候/
さびどm /錆止/
さびつk /錆付/錆び付/
さびつi /錆び付/錆付/
さびs /寂/淋;NB:日本のみの用字/寞;(ひとけがない)/寥;(まばら)/
さびr /寂/
さばおr /鯖折/
さばk /裁;(judge) 罪を裁く/捌;(dispose) 注文|魚を捌く/
さばi /裁;(judge) 罪を裁く/捌;(dispose) 注文|魚を捌く/
さながr /宛/
さとがえr /里帰/
さとうづk /砂糖漬/
さとt /悟/覚/
さとs /諭/聡;形容詞/悟/訓/説/敏;(字義:反応が早い)/慧;(字義:気が利く)/
さとr /悟/覚/
さとn /悟/覚/
さとk /聡;(字義:理解が早い)/敏;(字義:反応が早い)/慧;(字義:気が利く)/
さとi /聡;(字義:理解が早い)/敏;(字義:反応が早い)/慧;(字義:気が利く)/
さとg /聡;(字義:理解が早い)/敏;(字義:反応が早い)/慧;(字義:気が利く)/
さとc /悟/覚/
さとb /俚/
さておk /扨置/扨措/
さておi /扨置;何は-いて/扨措;=扨置いて/
さついr /札入/
さっぴk /差っ引/
さっぴi /差っ引/
さっちs /察知/
さっきだt /殺気立/
さっきだc /殺気立/
さっt /颯/
さっs /察/
さちうすs /幸薄/
さちうすk /幸薄/
さちうすi /幸薄/
さちうすg /幸薄/
さだm /定/
さだk /定/
さぞy /嘸;-や/
さぞk /嘸/
さそいだs /誘い出/
さそいこn /誘い込/
さそいこm /誘い込/
さそいあわs /誘い合/
さそいあw /誘い合/
さそw /誘/
さそu /誘/哘;<rare> NB:地名以外の用途は考えにくい/
さそt /誘/
さそo /誘/
さそi /誘/
さそe /誘/
さそc /誘/
さずk /授/
さすらw /流離/
さすらu /流離/
さすらt /流離/
さすらo /流離/
さすらi /流離/
さすらe /流離/
さすらc /流離/
さすt /擦;NB:「かすr」「こすr」「すr」「なすr」と同形/摩;NB:「すr」と同形/
さすr /擦;NB:「かすr」「こすr」「すr」「なすr」と同形/摩;NB:「すr」と同形/
さすn /擦;NB:「かすr」「こすr」「すr」「なすr」と同形/摩;NB:「すr」と同形/
さすc /擦;NB:「かすr」「こすr」「すr」「なすr」と同形/摩;NB:「すr」と同形/
さしわたs /差し渡/差渡/
さしもどs /差し戻/差戻/
さしむかi /差向/
さしむk /差し向/
さしまわs /差し回/
さしまねk /麾/
さしまねi /麾/
さしひかe /差し控/差控/
さしひk /差し引/差引/
さしひi /差し引/差引/
さしはさn /差し挟/挟;NB:「はさm」と同形/挿;口を-む/
さしはさm /差し挟/挟;NB:「はさm」と同形/挿;口を-む/
さしのぼt /差し上/差し昇/
さしのぼr /差し上/差し昇/
さしのぼn /差し上/差し昇/
さしのぼc /差し上/差し昇/
さしのb /差し延/差し伸/
さしぬi /刺し縫/
さしとおs /刺し通/
さしとm /差し止/差止/
さしでg /差し出/
さしづm /差し詰/
さしつらぬk /刺し貫/
さしつらぬi /刺し貫/
さしつかw /差し遣/
さしつかe /差し支/差支/
さしちがe /差し違/刺し違/
さしだs /差し出/差出/
さしたt /差し立/
さしせまt /差し迫/
さしせまr /差し迫/
さしせまn /差し迫/
さしせまc /差し迫/
さしずm /差し詰/差詰/
さししめs /指し示/
さしさわt /差し障/差障/
さしさわr /差し障/差障/
さしさわn /差し障/差障/
さしさわc /差し障/差障/
さしころs /刺し殺/
さしこn /差し込;プラグを差し込む/射し込;陽が射し込む/差込/
さしこm /差し込;プラグを差し込む/射し込;陽が射し込む/差込/指し込;?/
さしきt /指切/指し切/
さしきr /指切/指し切/
さしきn /指切/指し切/
さしきc /指切/指し切/
さしかわs /差し交/
さしかw /差し交/
さしかk /差し掛/
さしかe /差し替/差し換/挿し替/
さしおさe /差押/
さしおs /差し押/
さしおk /差し置/
さしおi /差し置/
さしいそi /差し急/
さしいそg /差し急/
さしいr /差し入/挿し入/差入/
さしあたt /差し当/
さしあたr /差し当/
さしあw /差し合/
さしあu /差し合/
さしあt /差し当/差し合/
さしあo /差し合/
さしあi /差し合/
さしあg /差し上/
さしあe /差し合/
さしあc /差し合/
ささわr /障/
ささやk /囁/
ささやi /囁/
ささげもt /捧げ持/
ささげもc /捧げ持/
ささくれだt /ささくれ立/
ささくれだc /ささくれ立/
ささえあw /支え合/
ささえあu /支え合/
ささえあt /支え合/
ささえあo /支え合/
ささえあi /支え合/
ささえあe /支え合/
ささえあc /支え合/
ささy /細/
ささi /捧/
ささg /捧/
ささe /支/
さげわたs /下げ渡/
さげどm /下げ止/
さげすn /蔑;(字義:目にも止めない)/貶;(字義:値を落とす)/
さげすm /蔑;(字義:目にも止めない)/貶;(字義:値を落とす)/
さけよi /酒酔/
さけのm /酒飲/
さけづk /酒漬/
さけずk /酒好/
さけくさs /酒臭/
さけくさk /酒臭/
さけくさi /酒臭/
さけくさg /酒臭/
さけn /叫/
さけb /叫/
さぐりだs /探り出/
さぐりあw /探り合/
さぐりあu /探り合/
さぐりあt /探り当/探り合/
さぐりあo /探り合/
さぐりあi /探り合/
さぐりあe /探り合/
さぐりあc /探り合/
さぐt /探/
さぐr /探/
さぐn /探/
さぐc /探/
さくづk /作付/
さくせいいたs /作成致/
さくせいs /作成/
さくs /策;維新を-す/
さきわたs /先渡/
さきよm /先読/
さきゆk /先行/
さきものがi /先物買/
さきみだr /咲き乱/
さきまわr /先回/
さきほこt /咲き誇/
さきほこr /咲き誇/
さきほこn /咲き誇/
さきほこc /咲き誇/
さきぶr /先触/
さきばらi /先払/
さきばしt /先走/
さきばしr /先走/
さきばしn /先走/
さきばしc /先走/
さきのこt /咲き残/
さきのこr /咲き残/
さきのこn /咲き残/
さきのこc /咲き残/
さきのb /先延/
さきどr /先取/
さきだt /先立/
さきだc /先立/
さきこぼr /咲き溢/
さきがk /先駆/
さきおくt /先送/
さきおくr /先送/
さきおくn /先送/
さきおくc /先送/
さきうt /先打/
さきうr /先売/
さきいt /先行/
さきいk /先行/
さきいc /先行/
さきt /先/
さきn /先/
さきg /先/
さがしまわt /捜し回/探し回/
さがしまわr /探し回/捜し回/
さがしまわn /探し回/捜し回/
さがしまわc /探し回/捜し回/
さがしだs /探し出/捜し出/
さがしあt /探し当/捜し当/
さがt /下/
さがs /探/捜;<esp.あるはずのものをさがす>/搜;「捜」の旧字(人名用漢字)/
さがr /下/下が;※送り位置補正/
さがn /下/
さがc /下/
さかもr /酒盛/
さかむs /酒蒸/
さかまk /逆巻/
さかまi /逆巻/
さかのぼt /遡/溯;≒遡る/泝;≒遡る/逆昇/
さかのぼr /遡/溯;≒遡る/泝;≒遡る/逆昇/逆のぼ;※送り位置補正/
さかのぼn /遡/溯;≒遡る/泝;≒遡る/逆昇/
さかのぼc /遡/溯;≒遡る/泝;≒遡る/逆昇/
さかなつr /魚釣/
さかなかk /魚懸/
さかなy /魚/
さかだt /逆立/
さかうらm /逆恨/
さかあg /逆上/
さかt /盛/
さかs /逆/賢/
さかr /逆/盛/
さかn /盛/
さかe /栄/盛/榮;「栄」の旧字(人名用漢字)/
さかc /盛/
さえわたt /冴え渡/さえ渡;NB:「冴え渡る」の方が一般的/
さえわたr /冴え渡/さえ渡;NB:「冴え渡る」の方が一般的/
さえわたn /冴え渡/さえ渡;NB:「冴え渡る」の方が一般的/
さえわたc /冴え渡/さえ渡;NB:「冴え渡る」の方が一般的/
さえずt /囀/哢;<rare>/
さえずr /囀/哢;<rare>/
さえずn /囀/哢;<rare>/
さえずc /囀/哢;<rare>/
さえぎt /遮/峺;<rare>/
さえぎr /遮/峺;<rare>/
さえぎn /遮/峺;<rare>/
さえぎc /遮/峺;<rare>/
さいわいs /幸/
さいわいn /幸/
さいわいd /幸/
さいわi /幸/
さいばしt /才走/
さいばしr /才走/
さいばしn /才走/
さいばしc /才走/
さいはt /最果/
さいなn /苛/嘖;<rare> NB:日本のみの用字/呵;<rare>/
さいなm /苛/嘖;<rare> NB:日本のみの用字/呵;<rare>/
さいこうn /最高/
さいげんs /再現/
さいきばしt /才気走/
さいきばしr /才気走/
さいきばしn /才気走/
さいきばしc /才気走/
さいかいs /再開/
さいt /最/
さいs /際/賽;(サ変) 御礼参りする/
さいn /際/
さt /去/
さs /差/刺;針を刺す/指;(point)上を指す/挿;カードを挿す/射;陽が射す/鎖;扉を鎖す/注;目薬を注す/点;口紅を点す/止;言い止す/然;然すれば/捺;印を捺す(=おす)/螫;<rare> 虫が螫す/插;「挿」の旧字/
さr /去/然/曝;[文語]/
さn /去/
さm /覚/冷;冷めた紅茶/醒;酔いが醒める/褪;色が褪める/然;然もあらん/覺;旧字/
さk /咲/避/割;時間を割く/裂;(仲|紙)を裂く/
さi /咲/裂;(仲|紙)を裂く/割;時間を割く/削/
さg /下/提;(手に持つ) 鞄を提げる/差/
さe /冴/冱;「冴」の異体字/
さc /去/
さb /錆/寂/銹;=錆びる/荒;≒寂び(れ)る/
ごわつk /強付/
ごわつi /強付/
ごわt /強/
ごろうz /御覧/
ごろうj /御覧/
ごろあw /語呂合/
ごろs /殺/頃/
ごろn /頃/
ごろd /頃/
ごれんらくねがw /御連絡願/
ごれんらくねがu /御連絡願/
ごれんらくねがt /御連絡願/
ごれんらくねがo /御連絡願/
ごれんらくねがi /御連絡願/
ごれんらくねがe /御連絡願/
ごれんらくねがc /御連絡願/
ごれんらくいただk /御連絡戴/御連絡頂/
ごれんらくいただi /御連絡戴/御連絡頂/
ごりようくだs /御利用下/ご利用下/
ごりかいくだs /御理解下/
ごりかいいただk /御理解頂/
ごりおs /ゴリ押/
ごらんくだs /御覧下/
ごようはじm /御用始/
ごようしゃくだs /御容赦下/
ごようおさm /御用納/
ごめんくだs /御免下/
ごまかs /誤魔化/胡麻化;NB:語源「胡麻菓子」/
ごぶがr /五分刈/
ごばらi /後払/
ごのm /好/
ごとうひょうくだs /御投票下/
ごとs /如/若/
ごとn /毎/
ごとk /如/若/
ごったがえs /ごった返/
ごちゅういくだs /御注意下/
ごたe /応/
ごぞんz /御存/
ごぞんj /御存/
ごしらe /拵/
ごしようくだs /御使用下/
ごしどうねがi /御指導願/
ごしどうくだs /御指導下/
ごしてきくだs /御指摘下/
ござt /御座/
ござr /御座/
ござn /御座/
ござi /御座/
ごさんしょうくだs /御参照下/
ごさんかくだs /御参加下/
ごくつぶs /穀潰/
ごきょうりょくくだs /御協力下/
ごきょうじねがi /御教示願/
ごきょうじくだs /御教示下/
ごきょうじいただk /御教示頂/
ごきょうじいただi /御教示頂/
ごきたいくだs /御期待下/
ごかつようくだs /御活用下/
ごかくにんくだs /御確認下/
ごえんりょくだs /御遠慮下/
ごえs /肥/
ごうじょっぱr /強情っ張/
ごうs /号/
ごいっぽうねがw /御一報願/
ごいっぽうねがu /御一報願/
ごいっぽうねがt /御一報願/
ごいっぽうねがo /御一報願/
ごいっぽうねがi /御一報願/
ごいっぽうねがe /御一報願/
ごいっぽうねがc /御一報願/
ごいっぽうくだs /御一報下/
ごいちどくくだs /御一読下/
ごあんしんくだs /御安心下/
ごs /越;(連濁) ガラス越し/期;(決意する) 必勝を期する/伍;(肩を並べる) 列国に伍す/
ごk /極/
ごe /越/超/
こんまk /根負/
こんばんh /今晩/
こんにちh /今日/
こんくらb /根競/
こんきよk /根気良/
こんz /混/
こんj /混/
こわばt /強張/
こわばr /強張/
こわばn /強張/
こわばc /強張/
こわづくr /声作/
こわすg /怖過/
こわs /壊/怖/恐/毀;≒壊す/壞;「壊」の旧字(人名用漢字)/強;強いご飯 NB:「つよi」と同形/
こわr /壊/毀;≒壊れる/壞;「壊」の旧字(人名用漢字)/
こわk /怖/恐/小分/強;強いご飯 NB:「つよi」と同形/
こわi /怖/恐/強;強いご飯 NB:「つよi」と同形/
こわg /怖/恐/強;強いご飯 NB:「つよi」と同形/
こわb /硬/
ころしあw /殺し合/
ころしあu /殺し合/
ころしあt /殺し合/
ころしあo /殺し合/
ころしあi /殺し合/
ころしあe /殺し合/
ころしあc /殺し合/
ころげこn /転げ込/
ころげこm /転げ込/
ころがりこn /転がり込/
ころがりこm /転がり込/
ころがりおt /転がり落/
ころがりおc /転がり落/
ころs /殺/
ころn /転/轉;「転」の旧字(人名用漢字)/
ころg /転/轉;「転」の旧字(人名用漢字)/
ころb /転/轉;「転」の旧字(人名用漢字)/
こりかたm /凝り固/
こらえきt /堪え切/
こらえきr /堪え切/
こらえきn /堪え切/
こらえきc /堪え切/
こらe /堪/怺/
こやすs /小安/
こやすk /小安/
こやすi /小安/
こやすg /小安/
こやs /肥や;※送り位置補正/
こもどr /小戻/
こもt /籠/篭;「籠」の異体字/隠/
こもr /篭;「籠」の異体字/籠/子守/隠/
こもn /篭;「籠」の異体字/籠/隠/
こもc /篭;「籠」の異体字/籠/隠/
こめつk /米搗/
こむらがえr /腓返/
こむずかs /小難/
こみだs /小見出/
こみいt /込み入/混み入;?/
こみいr /込み入/
こみいn /込み入/
こみいc /込み入/
こみあw /混み合/
こみあu /混み合/
こみあt /混み合/
こみあo /混み合/
こみあi /混み合/
こみあg /込み上/
こみあe /混み合/
こみあc /混み合/
こまわr /小回/コマ割/
こまりはt /困り果/
こまりぬk /困り抜/
こまりぬi /困り抜/
こまりきt /困り切/
こまりきr /困り切/
こまりきn /困り切/
こまりきc /困り切/
こまむすb /細結/
こまねk /拱/
こまねi /拱/
こまぬk /拱/
こまぬi /拱/
こまづかi /小間使/
こまつかi /小間使/
こまたすくi /小股掬/
こまぐm /駒組/
こまぎr /細切/小間切/
こまかi /細か;※送り位置補正/
こまy /細/濃/
こまt /困/
こまs /細/
こまr /困/
こまn /困/
こまm /小ま;※送り位置補正/
こまk /細/
こまi /細/
こまg /細/
こまc /困/
こぼt /毀/
こぼs /零;spill/溢/毀;=こぼ・つ/
こぼr /溢/零/毀;(こわれる) 橋が毀れる/
こほr /凍/氷/
こぶr /小振;†小振りな器/小降;†雨が小降りになる/
こびりつk /こびり付/
こびりつi /こびり付/
こびへつらw /媚び諂/
こびへつらu /媚び諂/
こびへつらt /媚び諂/
こびへつらo /媚び諂/
こびへつらi /媚び諂/
こびへつらc /媚び諂/
こばなr /子離/
こばしr /小走/
こばn /拒/
こばm /拒/
こはずk /小恥/
こはz /小恥/
このn /好/
このm /好/
こねまわs /捏ね回/
こねくりまわs /こねくり回/
こねあg /捏ね上;パン生地を-げる/
こにくs /小憎/
こにくr /小憎/
こにくk /小憎/
こにくi /小憎/
こにくg /小憎/
こなs /熟/
こなr /熟/
こなk /子泣/
こどもむk /子供向/
こどもづr /子供連/
こどもずk /子供好/
こどもじm /子供染/
こどもあつかi /子供扱/
こどもr /子供/
こどもp /子供/
ことわりきr /断り切/
ことわりがk /断り書/
ことわt /断/斷;旧字/判;(判断・理解する)/
ことわr /断/判;(判断・理解する)/斷;「断」の旧字/
ことわn /断/判;(判断・理解する)/斷;「断」の旧字/
ことわc /断/判;(判断・理解する)/斷;「断」の旧字/
ことよs /事寄/言寄/
こともなg /事も無/
ことほどさようn /事程左様/
ことほi /寿/
ことほg /言祝/寿/
ことばどおr /言葉通/
ことばづかi /言葉遣/言葉使/
ことばあそb /言葉遊/
ことはじm /事始/
ことなt /異/
ことなr /異/
ことなn /異/
ことなc /異/
こととh /言問/
ことづt /言伝/言傳;「伝」旧字/
ことづk /言付/託;=言付け(る)/
ことたt /事足/
ことたr /事足/
ことたn /事足/
ことたc /事足/
ことずk /託;※仮名遣い「ことづk」/
ことごとs /事々/
ことごとk /悉/尽;=悉く NB:「つk」と同形/盡;「尽」の旧字(人名用漢字)/
ことこまy /事細/
ことこまk /事細/
ことぎr /事切/
こときr /事切/
ことかk /事欠/
ことかi /事欠/
ことえr /言選/
こといm /言忌/
ことあたらs /事新/
ことあg /言挙/
ことw /断/斷;「断」の旧字/
ことn /異/殊;-に/
こてなg /小手投/
こてしらb /小手調/
こづかi /小遣/
こづr /子連/
こづk /小突/
こづi /小突/
こつあg /骨揚/
こっぴどs /こっ酷/
こっぴどk /こっ酷/
こっぴどi /こっ酷/
こっぴどg /こっ酷/
こっぱz /小っ恥/こっ恥/
こだわt /拘;原義:つまらぬことに気を取られる/拘泥/
こだわr /拘;原義:つまらぬことに気を取られる/拘泥/
こだわn /拘;原義:つまらぬことに気を取られる/拘泥/
こだわc /拘;原義:つまらぬことに気を取られる/拘泥/
こだまs /谺/
こだかs /小高/
こだかk /小高/
こだかi /小高/
こだかg /小高/
こだs /小出/
こたh /堪/答/應;「応」の旧字(人名用漢字)/
こたe /答;質問に答える/応;期待に応える,失敗が応える/堪;持ち堪える/應;「応」の旧字(人名用漢字)/
こぞt /挙/
こぞr /挙/
こぞn /挙/
こぞc /挙/
こそだt /子育/
こそi /刮/
こそg /刮/
こぜわs /小忙/
こせいゆたk /個性豊/
こすりつk /擦り付;NB:「なすりつk」「すりつk」と同形/
こすっからs /狡っ辛/
こすっからk /狡っ辛/
こすっからi /狡っ辛/
こすっからg /狡っ辛/
こすからs /狡辛/
こすからk /狡辛/
こすからi /狡辛/
こすからg /狡辛/
こすt /擦/錯;<rare> (ヤスリで磨く)/
こすs /狡/
こすr /擦/錯;<rare> (ヤスリで磨く)/
こすn /擦/錯;<rare> (ヤスリで磨く)/
こすk /狡/
こすi /狡/
こすg /濃過/狡/
こすc /擦/錯;<rare> (ヤスリで磨く)/
こじあk /抉じ開/
こじt /抉;蓋を抉る NB:「えぐr」「くじr」と同形/
こじs /誇示/
こじr /抉;蓋を抉る NB:「えぐr」「くじr」と同形/拗;仲が拗れる,風邪を拗らせる/
こじn /抉;蓋を抉る NB:「えぐr」「くじr」と同形/
こじc /抉;蓋を抉る NB:「えぐr」「くじr」と同形/
こしらh /拵/
こしらe /拵/
こしまわr /腰回/
こしぬk /腰抜/
こしなg /腰投/
こしづk /腰付/
こしくだk /腰砕/
こしかk /腰掛/
こざかs /小賢/
こさむs /小寒/
こさむk /小寒/
こさむi /小寒/
こさむg /小寒/
こごろs /子殺/
こごえはt /凍え果/
こごえじn /凍え死/
こごえしn /凍え死/
こごt /凝/
こごr /凝/
こごn /凝/屈/
こごm /屈/
こごe /凍/
こごc /凝/
こころよs /快/
こころよk /快/
こころよi /快/
こころよg /快/
こころゆるs /心許/
こころゆk /心行/
こころやすs /心安/
こころやすr /心安/
こころやすk /心安/
こころやすi /心安/
こころやすg /心安/
こころやさs /心優/
こころもとなs /心許無/
こころもとなk /心許無/
こころもとなi /心許無/
こころもとなg /心許無/
こころもt /心持/
こころもc /心持/
こころみだr /心乱/
こころみr /試み;※送り位置補正/
こころまどi /心惑/
こころまt /心待/
こころまc /心待/
こころぼそs /心細/
こころぼそk /心細/
こころぼそi /心細/
こころぼそg /心細/
こころぶとs /心太/
こころひk /心魅/
こころのこr /心残/
こころにくs /心憎/
こころにくk /心憎/
こころにくi /心憎/
こころにくg /心憎/
こころなs /心無/
こころなk /心無/
こころなi /心無/
こころなg /心無/
こころづよs /心強/
こころづよk /心強/
こころづよi /心強/
こころづよg /心強/
こころづくs /心尽/
こころづかi /心遣/心使/
こころづk /心付/
こころしずk /心静/
こころざs /志/
こころさみs /心淋/
こころさびs /心淋/心寂/
こころぐるs /心苦/
こころくばr /心配/
こころがまe /心構/
こころがk /心掛/
こころおだy /心穏/
こころおきなs /心置き無/
こころおきなk /心置き無/
こころおきなi /心置き無/
こころおt /心落/
こころおk /心置/
こころおi /心置/
こころえz /心得/
こころえy /心得/
こころえt /心得/
こころえs /心得/
こころえr /心得/
こころえn /心得/
こころえm /心得/
こころえk /心得/
こころえc /心得/
こころうごk /心動/
こころいr /心入/
こころあたたm /心温/心暖/
こころあたr /心当/
こころあt /心当/
こころs /心/
こころm /試/
こころh /心/
こころg /心/
ここのt /九/
ここちよs /心地良/心地好/
ここちよk /心地良/心地好/
ここちよi /心地良/心地好/
ここちよg /心地良/心地好/
ここn /個々/茲;-に/爰;-に/是;-に/
こげくさs /焦げ臭/
こげくさk /焦げ臭/
こげくさi /焦げ臭/
こげくさg /焦げ臭/
こけらおとs /柿落/
こけむs /苔生/
こけt /コケ/
こけr /コケ/
こけn /コケ/
こけc /コケ/
こぐらs /小暗;-い夕べ/木暗;-い森/
こぐらk /小暗;-い夕べ/木暗;-い森/
こぐらi /小暗;-い夕べ/木暗;-い森/
こぐらg /小暗;-い夕べ/木暗;-い森/
こくt /告/
こくs /酷/刻/
こくr /告/
こくn /告/酷/
こくd /酷/
こくc /告/
こぎつk /漕ぎ着/
こぎだs /漕ぎ出/
こぎたなs /小汚/
こぎたなk /小汚/
こぎたなi /小汚/
こぎたなg /小汚/
こきみよs /小気味良/小気味好/
こきみよk /小気味良/小気味好/
こきみよi /小気味良/小気味好/
こきみよg /小気味良/
こきつかw /扱き使/
こきつかu /扱き使/
こきつかt /扱き使/
こきつかo /扱き使/
こきつかi /扱き使/
こきつかe /扱き使/
こきつかc /扱き使/
こきざm /小刻/
こきおr /扱き下/
こがらs /木枯/
こがs /焦/
こがr /焦/木枯/
こかs /転/倒;NB:「たおs」と同形/
こおりづk /氷漬/
こおりつk /凍り付/
こおりつi /凍り付/
こおりけずr /氷削/
こおt /凍/氷;<rare>/
こおr /凍/氷;<rare>/
こおn /凍/氷;<rare>/
こおc /凍/氷;<rare>/
こえふとt /肥え太/
こえふとr /肥え太/
こえふとn /肥え太/
こえふとc /肥え太/
こえだs /声出/
こえたかk /声高/
こえがわr /声変/
こえかk /声掛/
こえt /超/
こうるさs /小煩/
こうるさk /小煩/
こうるさi /小煩/
こうるさg /小煩/
こうりょs /考慮/
こうむt /被;被害を被る NB:「かぶr」と同形/蒙;(≒被る) 御免蒙る/
こうむr /被;被害を被る NB:「かぶr」と同形/蒙;(≒被る) 御免蒙る/
こうむn /被;被害を被る NB:「かぶr」と同形/蒙;(≒被る) 御免蒙る/
こうむc /被;被害を被る NB:「かぶr」と同形/蒙;(≒被る) 御免蒙る/
こうだいn /広大/
こうそくn /高速/
こうせいn /公正/
こうしきr /抗し切/
こうごうs /神々/
こうごk /小動/
こうげきs /攻撃/
こうきゅうとr /高給取/
こうz /講/高/困/昂/嵩/考/
こうs /抗/航/
こうr /小売/
こうj /講;(哲学|策)を講じる/高;≒昂じる/昂;趣味が昂じて/嵩;≒昂じる/困;始末に困じる/
こうb /香/芳/
こいねがはk /希/
こいねがw /希/乞い願/冀/庶幾/
こいねがu /希/乞い願/冀/庶幾/
こいねがt /希/乞い願/冀/庶幾/
こいねがo /希/乞い願/冀/庶幾/
こいねがi /希/乞い願/冀/庶幾/
こいねがe /希/乞い願/冀/庶幾/
こいねがc /希/乞い願/冀/庶幾/
こいしたw /恋い慕/
こいしたu /恋い慕/
こいしたt /恋い慕/
こいしたo /恋い慕/
こいしたi /恋い慕/
こいしたe /恋い慕/
こいしたc /恋い慕/
こいおおk /恋多/
こいs /恋/戀;「恋」の旧字/
こz /来/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/
こy /肥/来/越/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/
こw /請;字義:しっかり目を見て頼む/乞;字義:憐れな声で頼む/恋/戀;「恋」の旧字/
こu /乞;字義:憐れな声で頼む/請;字義:しっかり目を見て頼む/恋/斯/買;(ウ音便)/戀;「恋」の旧字/
こt /凝;趣味に凝る,肩凝り/
こs /越/超;限界を超す/漉;(filter)油を漉す/濾;≒漉す/来/濃/鼓;勇を鼓する/糊;生活する/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/
こr /凝;趣味に凝る,肩凝り/懲;-りる,-らしめる/来;-られる/此;-れ/樵;(cut down) 木を樵る/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/
こo /乞;字義:憐れな声で頼む/請;字義:しっかり目を見て頼む/恋/戀;「恋」の旧字/
こn /込/来/混/捏/此;-の,-んな/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/凝;趣味に凝る,肩凝り/
こm /込/混/籠;音が籠る/篭;「籠」の異体字/
こk /濃/扱;稲を扱く/転;道で転ける,(補助動詞)売り転かす/放;屁を放く/痩;痩けた頬/倒;=転ける/
こi /濃/乞;字義:憐れな声で頼む/来/漕/請;字義:しっかり目を見て頼む/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/恋/戀;「恋」の旧字/扱;稲を扱く,稲を扱ぐ/放;屁を放く/
こh /乞/請/戀;「恋」の旧字/
こg /漕/焦/扱;稲を扱ぐ/濃/
こe /越/超;(特に「上回る」意で) ≒越える/肥;肥えた目/踰;字義:「越」は跳びこえ、「踰」は跨ぎこす/乞;字義:憐れな声で頼む/請;字義:しっかり目を見て頼む/恋/戀;「恋」の旧字/
こd /子/小/
こc /凝;趣味に凝る,肩凝り/
こb /媚/
げんなおs /験直/
げんつk /原付/
げんだいかなづかi /現代仮名遣/
げんじつばなr /現実離/
げんさくどおr /原作通/
げんきよk /元気良/
げんきづk /元気付/
げんz /減/
げんs /減/
げんn /現/
げんj /減/
げびt /下卑/
げびr /下卑/
げぎらi /毛嫌/
げきs /激/檄;檄文を発する/
げs /解/觧;「解」の異体字/
げr /蹴/
げn /実/
けんとうはずr /見当外/
けんとうちがi /見当違/
けんとうs /検討/
けんしょうずm /検証済/
けんいづk /権威付/
けんz /献/
けんs /検;サ変/験;経験/
けんj /献/
けわw /化粧/
けわu /化粧/
けわt /化粧/
けわs /険/峻;峻しい山道/險;「険」の旧字(人名用漢字)/
けわo /化粧/
けわi /化粧/
けわe /化粧/
けわc /化粧/
けりとb /蹴飛/
けりたおs /蹴り倒/
けりころs /蹴り殺/
けりこn /蹴り込;ボールを敵陣に-む/
けりこm /蹴り込;ボールを敵陣に-む/
けりいr /蹴り入/
けりあg /蹴り上/
けやぶt /蹴破/
けやぶr /蹴破/
けやぶn /蹴破/
けやぶc /蹴破/
けむt /煙/烟;「煙」の異体字/
けむs /煙/
けむr /煙/烟;「煙」の異体字/
けむn /煙/烟;「煙」の異体字/
けむk /煙/
けむi /煙/
けむg /煙/
けむc /煙/烟;「煙」の異体字/
けみs /閲/
けぶかs /毛深/
けぶかk /毛深/
けぶかi /毛深/
けぶかg /毛深/
けぶt /煙/烟;「煙」の異体字/
けぶs /煙/
けぶr /煙/烟;「煙」の異体字/
けぶn /煙/烟;「煙」の異体字/
けぶk /煙/
けぶi /煙/
けぶg /煙/
けぶc /煙/烟;「煙」の異体字/
けばだt /毛羽立/
けばだc /毛羽立/
けばs /ケバ/
けばk /ケバ/
けばi /ケバ/
けばg /ケバ/
けはh /化粧/
けなs /貶/
けなm /毛並/
けどt /気取/
けどr /気取/
けどn /気取/
けどc /気取/
けとb /蹴飛/
けづくろi /毛繕/
けづr /削/梳/
けつろんづk /結論付/
けつまずk /蹴躓/
けつまずi /蹴躓/
けっとb /蹴っ飛/
けっていづk /決定付/
けっていいたs /決定致/
けっていs /決定/
けっしゅうs /結集/
けっs /決/結;constipate/
けちくさs /ケチ臭/けち臭/
けちくさk /ケチ臭/けち臭/
けちくさi /ケチ臭/けち臭/
けちくさg /ケチ臭/けち臭/
けちr /蹴散/
けだるs /気怠/
けだるk /気怠/
けだるi /気怠/
けだるg /気怠/
けだかs /気高/
けだかk /気高/
けだかi /気高/
けだかg /気高/
けだs /蓋/
けたはずr /桁外/
けたちがi /桁違/
けたちがh /桁違/
けたぐr /蹴手繰/
けたおs /蹴倒/
けたt /蹴立/
けずりとt /削り取/
けずりとr /削り取/
けずりとn /削り取/
けずりとc /削り取/
けずt /削/梳;(クシで髪をとく)/
けずr /削/梳;(クシで髪をとく)/
けずn /削/梳;(クシで髪をとく)/
けずc /削/梳;(クシで髪をとく)/
けしわすr /消し忘/
けしとn /消し飛/
けしとm /消し止/
けしとb /消し飛/
けしさt /消し去/
けしさr /消し去/
けしさn /消し去/
けしさc /消し去/
けしこn /消し込/
けしこm /消し込/
けしきb /気色;気色ばむ/
けしかk /嗾/
けさがたm /袈裟固/
けこn /蹴込/
けこm /蹴込;-み(建築用語),-む(kick in)/
けぎらi /毛嫌/
けがs /汚;NB:「よごs」と同形/穢;<esp.禁忌的に>/涜;(神聖なものを)/
けがr /汚;NB:「よごr」と同形/穢;<esp.禁忌的に>/
けかえs /蹴返/
けおとs /蹴落/
けおt /蹴落/
けおs /気圧/
けうとs /気疎/
けうとk /気疎/
けうとi /気疎/
けうとg /気疎/
けいとうだt /系統立/
けいじs /掲示/
けいしきばt /形式張/
けいしきばr /形式張/
けいしきばn /形式張/
けいしきばc /形式張/
けいさんだかs /計算高/
けいさんだかk /計算高/
けいさんだかi /計算高/
けいさんだかg /計算高/
けいこくs /警告/
けいけんゆたk /経験豊/
けいけんs /経験/
けいきよk /景気良/
けいきづk /景気付/
けいかいn /軽快/
けいえいs /経営/
けいs /敬;敬意/詣;-す [文語]詣でる/啓;-す [文語]申し上げる/慶;慶事/
けあg /蹴上/
けy /蹴/
けt /蹴/
けs /消/怪;-しからん/決;(けして)/
けr /蹴/
けn /蹴/異/
けc /蹴/
ぐんs /軍;army/
ぐろs /黒/グロ;grotesque/
ぐろk /黒/グロ;grotesque/
ぐろi /黒/グロ;grotesque/
ぐろg /黒/グロ;grotesque/
ぐるs /苦/
ぐるm /包/
ぐるi /狂/
ぐらs /暮/
ぐちt /愚痴/
ぐちr /愚痴/
ぐちp /愚痴/
ぐちn /愚痴/
ぐちc /愚痴/
ぐずt /愚図/
ぐずr /愚図/
ぐずn /愚図/
ぐずc /愚図/
ぐさr /腐/
ぐうs /遇;(treat) 客として遇する/寓;ことよせる/
ぐあi /具合/
ぐs /具/
ぐr /暮/
ぐn /組/
ぐm /組/
ぐi /食/
くんよm /訓読/
くんづk /君付/
くんだr /下;-り NB:「くだr」と同形/
くわわt /加わ;※送り位置補正/
くわだt /企/
くわずぎらi /食わず嫌/
くわえこn /咥え込/銜え込/
くわえこm /咥え込/銜え込/
くわw /加/
くわs /詳/精/委/
くわr /区割/
くわk /区分/
くわe /加/咥;(字義:がっぷり噛み付く)/銜;(字義:馬の轡) ≒咥える/
くろびかr /黒光/
くろぬr /黒塗/
くろすg /黒過/
くろこg /黒焦/
くろz /黒/
くろu /黒/玄/
くろs /黒/玄/梍;<rare>/
くろp /黒/
くろm /黒/
くろk /黒/玄/梍;<rare>/
くろi /黒/玄/梍;<rare>/
くろg /黒/玄/梍;<rare>/
くれゆk /暮れ行/
くれなずn /暮れ泥/
くれなずm /暮れ泥/
くれかk /暮れ掛/
くるめk /眩/
くるめi /眩/
くるしみぬk /苦しみ抜/
くるしみぬi /苦しみ抜/
くるしまぎr /苦し紛/
くるw /狂/
くるu /狂/
くるt /狂/
くるs /苦/
くるo /狂/
くるn /包/
くるm /包/
くるi /狂/
くるh /狂/
くるe /狂/
くるc /狂/
くりもどs /繰り戻/繰戻/
くりひろg /繰り広/
くりのb /繰り延/繰延/
くりぬk /刳り貫/
くりぬi /刳り貫/
くりだs /繰り出/
くりさg /繰り下/
くりこs /繰り越/繰越/
くりこn /繰り込/
くりこm /繰り込/
くりかえs /繰り返/繰返/
くりかe /繰替/
くりいr /繰り入/
くりあわs /繰り合/
くりあw /繰り合/
くりあg /繰り上/繰上/
くらすg /暗過/
くらざらe /蔵浚/
くらがe /鞍替/
くらいどr /位取/
くらいづk /位付/
くらいつk /食らい付/喰らい付/
くらいつi /食らい付/喰らい付/
くらいこn /食らい込/喰らい込/
くらいこm /食らい込/喰らい込/
くらいs /位/
くらu /喰ら;※送り位置補正/食ら;※送り位置補正/
くらt /食/
くらs /暮/暗/昏;(字義:夕闇のくらさ)/冥;(字義:覆われて光がない)/暝;≒冥/眛;(字義:小さくてよく見えない)/罔;(字義:網で覆われて見えない)/
くらn /眩;(目を眩ます)/暗/
くらm /眩;(目を眩ます)/晦;(姿を晦ます)/暗/昏;(字義:夕闇のくらさ)/冥;(字義:覆われて光がない)/暝;≒冥/眛;(字義:小さくてよく見えない)/罔;(字義:網で覆われて見えない)/
くらk /暗/昏;(字義:夕闇のくらさ)/冥;(字義:覆われて光がない)/暝;≒冥/眛;(字義:小さくてよく見えない)/罔;(字義:網で覆われて見えない)/
くらi /暗/昏;(字義:夕闇のくらさ)/冥;(字義:覆われて光がない)/暝;≒冥/罔;(字義:網で覆われて見えない)/眛;(字義:小さくてよく見えない)/
くらg /暗/昏;(字義:夕闇のくらさ)/冥;(字義:覆われて光がない)/暝;≒冥/眛;(字義:小さくてよく見えない)/罔;(字義:網で覆われて見えない)/
くらe /喰ら;※送り位置補正/
くらb /比;字義:並べてくらべる/較;字義:突き合わせてくらべる/競;字義:勝負する/
くゆr /燻/薫/
くやしなk /悔し泣/
くやs /悔/口惜;=悔しい NB:「くちおs」と同形/
くやn /悔/
くやm /悔/
くもゆk /雲行/
くもがくr /雲隠/
くもt /曇/
くもr /曇/
くもn /曇/
くもc /曇/
くみわk /組分/組み分/
くみふs /組み伏/
くみとt /汲み取/
くみとr /汲み取/
くみとn /汲み取/
くみとc /汲み取/
くみつk /組付/組み付/
くみつi /組み付/
くみだs /汲み出/
くみたてr /組み立て;※送り位置補正/
くみたt /組み立/組立/
くみしやすs /与し易/
くみしやすk /与し易/
くみしやすi /与し易/
くみしやすg /与し易/
くみこn /組み込/組込/
くみこm /組込/組み込/
くみかわs /酌み交/
くみかw /酌み交/
くみかe /組替/組み換/組み替/組換;-え食品/
くみおk /汲み置/汲置/
くみおi /汲み置/汲置/
くみいr /組み入/組入/
くみあわs /組合/組み合/組み合わ;※送り位置補正/
くみあw /組み合/組合/
くみあg /汲み上;水|意見を汲み上げる/組み上;部品を組み上げる/組上/
くみs /与/與;「与」の旧字(人名用漢字)/
くまどt /隈取/
くまどr /隈取/
くまどn /隈取/
くまどc /隈取/
くぼn /窪/凹;NB:「へこm」と同形/
くぼm /窪/凹;NB:「へこm」と同形/
くべつs /区別/
くびりころs /縊り殺/
くびひねr /首捻/
くびなg /首投/
くびっぴk /首っ引/
くびくくr /首縊/
くびがたm /首固/
くびt /首/括;括れた胴 NB:「くくr」と同形/縊;(首吊り) 縊れて死ぬ/
くびr /括;括れた胴 NB:「くくr」と同形/縊;(首吊り) 縊れて死ぬ/
くびn /括;括れた胴 NB:「くくr」と同形/縊;(首吊り) 縊れて死ぬ/
くびc /括;括れた胴 NB:「くくr」と同形/縊;(首吊り) 縊れて死ぬ/
くばt /配/
くばr /配/
くばn /配/
くばc /配/
くはh /加/銜/
くどきおt /口説き落/
くどs /諄;(tedious) 諄い説教/
くどk /口説/諄;(tedious) 諄い説教/
くどi /口説/諄;(tedious) 諄い説教/
くどg /諄;(tedious) 諄い説教/
くづほr /頽/
くづs /崩;旧仮名/
くつろi /寛/
くつろg /寛/
くつずr /靴擦/
くつがへs /覆/
くつがへr /覆/
くつがえt /覆/
くつがえs /覆/
くつがえr /覆/
くつがえn /覆/
くつがえc /覆/
くっつk /くっ付/
くっつi /くっ付/
くっt /食;?/
くっs /屈/
くちをs /口惜/
くちよごs /口汚/
くちやかまs /口喧/
くちぶr /口振/
くちふうj /口封/
くちばしt /口走/
くちばしr /口走/
くちばしn /口走/
くちばしc /口走/
くちはばt /口幅/
くちはt /朽ち果/
くちなおs /口直/
くちなs /口無;(死人に)-し/
くちなr /口馴/口慣/
くちどr /口取/
くちどm /口止/
くちづk /口付;(蒼き胸乳に)-ける/
くちだs /口出/
くちぞe /口添/
くちずさn /口遊/
くちずさm /口遊/
くちすすi /漱/嗽;=漱ぐ/
くちすすg /漱/嗽;=漱ぐ/
くちさびs /口寂/
くちごもt /口籠/
くちごもr /口籠/
くちごもn /口籠/
くちごもc /口籠/
くちごたe /口答/
くちごm /口籠/
くちぎたなs /口穢/
くちぎたなk /口穢/
くちぎたなi /口穢/
くちぎたなg /口穢/
くちきr /口切/
くちきk /口利/
くちおs /口惜/
くちうるさs /口煩/
くちうるさk /口煩/
くちうるさi /口煩/
くちうるさg /口煩/
くちうつs /口移/
くちあたr /口当/
くちあt /口当/
くちz /口/
くだけちt /砕け散/
くだけちr /砕け散/
くだけちn /砕け散/
くだけちc /砕け散/
くだt /下/降/
くだs /下/降/
くだr /下/降/
くだn /下/降/
くだk /砕/碎;「砕」の旧字(人名用漢字)/
くだi /砕/碎;「砕」の旧字(人名用漢字)/
くだc /下/降/
くたびr /草臥/
くたs /腐/
くそあつs /糞暑/クソ暑/くそ暑/
くそあつk /糞暑/クソ暑/くそ暑/
くそあつi /糞暑/クソ暑/くそ暑/
くそあつg /糞暑/クソ暑/くそ暑/
くせn /癖/
くずれさt /崩れ去/
くずれさr /崩れ去/
くずれさn /崩れ去/
くずれさc /崩れ去/
くずれおt /崩れ落/
くずれおc /崩れ落/
くずきr /葛切/
くずおr /頽/
くずs /崩/
くずr /崩/
くすりづk /薬漬/
くすりうr /薬売/
くすぶt /燻/
くすぶr /燻/燻ぶ;※送り位置補正/
くすぶn /燻/
くすぶc /燻/
くすぐt /擽/
くすぐr /擽/
くすぐn /擽/
くすぐc /擽/
くすs /奇/
くすk /奇/
くすi /奇/
くすg /擽/奇/
くすb /燻;-べる NB:「燻る」の他動詞版。送りに注意/
くじびk /籤引/
くじk /挫/
くじi /挫/
くしざs /串刺/
くしけづr /梳/
くしけずt /梳/
くしけずr /梳/
くしけずn /梳/
くしけずc /梳/
くさわk /草分/
くさりはt /腐り果/
くさぶかs /草深/
くさぶかk /草深/
くさぶかi /草深/
くさぶかg /草深/
くさふかs /草深/
くさふかk /草深/
くさふかi /草深/
くさふかg /草深/
くさとr /草取/
くさかr /草刈/
くさt /腐/
くさs /臭/
くさr /腐/鏈;(つなぐ)/
くさn /腐/
くさm /臭/
くさk /臭/
くさi /臭/
くさg /臭/
くさc /腐/
くぐりぬk /潜り抜/くぐり抜/
くぐt /潜/潛;旧字/
くぐr /潜/潛;旧字/
くぐn /潜/潛;旧字/
くぐc /潜/潛;旧字/
くくりつk /括り付/
くくりあg /括り上/
くくt /括/
くくr /括/
くくn /括/
くくm /銜/含/
くくc /括/
くぎづk /釘付/
くぎt /区切/
くぎr /区切/
くぎn /区切/
くぎc /区切/
くえこn /崩え込/
くえこm /崩え込/
くうきいr /空気入/
くいやぶt /食い破/
くいやぶr /食い破/
くいやぶn /食い破/
くいやぶc /食い破/
くいのこs /食い残/
くいにg /食い逃/
くいとm /食い止/喰い止/
くいつぶs /食い潰/
くいつなi /食い繋;失業保険で-ぐ/
くいつなg /食い繋;失業保険で-ぐ/
くいつくs /食い尽/
くいつm /食い詰/
くいつk /食い尽/食い付/
くいつi /食い付/
くいちぎt /食い千切/
くいちぎr /食い千切/
くいちぎn /食い千切/
くいちぎc /食い千切/
くいちがw /食い違/喰い違/
くいちがu /食い違/喰い違/
くいちがt /食い違/喰い違/
くいちがo /食い違/喰い違/
くいちがi /食い違/喰い違/
くいちがe /食い違/喰い違/
くいちがc /食い違/喰い違/
くいちr /食い散/
くいたr /食い足/
くいすg /食い過/喰い過/
くいしばt /食い縛/喰い縛/
くいしばr /食い縛/喰い縛/
くいしばn /食い縛/喰い縛/
くいしばc /食い縛/喰い縛/
くいさg /食い下/
くいころs /食い殺/
くいこn /食い込/喰い込/
くいこm /食い込/喰い込/
くいきt /食い切/
くいきr /食い切/
くいきn /食い切/
くいきc /食い切/
くいいt /食い入/喰い入/
くいいr /食い入/喰い入/
くいいn /食い入/喰い入/
くいいc /食い入/喰い入/
くいあわs /食い合/
くいあらたm /悔い改/
くいあw /食い合/
くいあr /食い荒/
くいあk /食い飽/
くy /悔/
くw /食/喰;NB:「食」と区別して訓「くう」を表すための国字/
くu /食/喰;NB:「食」と区別して訓「くう」を表すための国字/
くt /食/朽/喰;NB:「食」と区別して訓「くう」を表すための国字/繰/刳/
くs /奇;奇しくも(=不思議にも)/屈;※送り過剰?/
くr /来/繰/暮/食/喰/呉/刳/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/眩;※送り過剰?/
くo /食/喰;NB:「食」と区別して訓「くう」を表すための国字/
くn /組/汲;水を汲む/酌;酒を酌む,意を酌む/苦;-にする/来;[口]-んな/繰/刳/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/
くm /組/汲;水を汲む/酌;酒を酌む,意を酌む/
くk /絎;衿裏を絎ける/
くi /食/喰;NB:「食」と区別して訓「くう」を表すための国字/悔/
くh /食/
くg /絎/
くe /食/喰;NB:「食」と区別して訓「くう」を表すための国字/
くc /朽/喰;NB:「食」と区別して訓「くう」を表すための国字/食/繰/刳/
くb /焼;-ぶ,(火に)-べる/
ぎんz /吟/
ぎんj /吟/
ぎりだt /義理立/
ぎりがたs /義理堅/
ぎりがたk /義理堅/
ぎりがたi /義理堅/
ぎりがたg /義理堅/
ぎらi /嫌/
ぎょりんがかr /魚鱗懸/
ぎょちょうどm /魚鳥止/
ぎょうぎょうs /仰々/仰仰/
ぎょうz /行/
ぎょs /御;御しやすい/
ぎゅうじt /牛耳/
ぎゅうじr /牛耳/
ぎゅうじn /牛耳/
ぎゅうじc /牛耳/
ぎゃっこうs /逆行/
ぎゃくもどr /逆戻/
ぎゃくむk /逆向/
ぎゃくまわr /逆回/
ぎゃくびk /逆引/
ぎゃくばr /逆張/
ぎゃくじょうs /逆上/
ぎゃくじゅうじがたm /逆十字固/
ぎゃくs /逆/
ぎゃくn /逆/
ぎゃくd /逆/
ぎむづk /義務付/
ぎt /切/
ぎs /擬;(似せる)山水に擬する/議;(議論)問題を議する/義/偽/
ぎr /切/斬/
ぎn /切/義/偽/
ぎm /決/
ぎd /義/偽/
ぎc /切/
きんとうわr /均等割/
きんちょうs /緊張/
きんじえz /禁じ得/
きんじえn /禁じ得/
きんz /禁/
きんj /禁/
きをつk /気を付/
きわどs /際疾/
きわどk /際疾/
きわどi /際疾/
きわどg /際疾/
きわだt /際立/
きわだc /際立/極立/
きわm /極/究;真相を究める/窮;進退窮まる/
きわd /際/
きろくやぶr /記録破/
きれこn /切れ込/
きれこm /切れ込/
きれいずk /綺麗好/
きれあg /切れ上;小股の-がった/
きれz /キレ;[口]/
きれt /キレ;[口]/
きれs /キレ;[口]/
きれr /キレ;[口]/
きれn /キレ;[口]/
きれm /キレ;[口]/
きれk /キレ;[口]/
きれc /キレ;[口]/
きりわk /切り分/
きりもどs /切り戻/
きりもr /切り盛/
きりもm /錐揉/
きりまわs /切り回;店を-す/
きりまz /切り混/
きりふs /切り伏/斬り伏/
きりふk /霧吹/
きりひろg /切り広/
きりひらk /切り開/切開/
きりひらi /切り開/切開/
きりはなs /切り離/切離/
きりはr /切り貼/
きりぬk /切り抜/切抜/
きりぬi /切り抜/切抜/
きりなおs /切り直/
きりどおs /切り通/切通/
きりとおs /切り通/切通/
きりとt /切り取/切取/
きりとr /切り取/切取/
きりとn /切り取/切取/
きりとc /切り取/切取/
きりづk /切り漬/
きりつm /切り詰/
きりつk /切り付/斬り付/
きりだs /切り出/切出/
きりたおs /切り倒;木を-/斬り倒;敵を-/
きりたt /切り立/
きりたc /切り立/
きりそろe /切り揃;前髪を-える/
きりすt /切り捨;弱者を-/斬り捨;-て御免/切捨/斬捨/
きりさk /切り裂/斬り裂/
きりさi /切り裂/斬り裂/
きりさg /切り下/切下/
きりころs /切り殺/斬り殺/
きりこn /切り込/切込/斬り込/
きりこm /切り込/切込/斬り込/
きりくずs /切り崩/
きりきざn /切り刻/
きりきざm /切り刻/
きりかえs /切り返/
きりかえr /切り換え;※送り位置補正/
きりかw /切り替/切替/
きりかk /斬り掛/切り掛/
きりかe /切り替/切替/切り換/切換/
きりおとs /切り落/
きりおt /切り落/
きりおr /切り下/
きりうr /切り売/
きりあw /斬り合/
きりあu /斬り合/
きりあt /斬り合/
きりあo /斬り合/
きりあi /斬り合/
きりあg /切り上/切上/
きりあe /斬り合/
きりあc /斬り合/
きらめk /煌/
きらめi /煌/
きらw /嫌/
きらu /嫌/
きらt /嫌/
きらo /嫌/
きらm /煌/
きらi /嫌/
きらh /嫌/
きらe /嫌/
きらc /嫌/
きらb /燦/
きよs /清/浄/
きよr /清/
きよm /清/浄/
きよk /清/浄/
きよi /清/浄/
きよg /清/浄/
きょぜつs /拒絶/
きょくりょくさk /極力避/
きょくs /曲/局/
きょうりょくくだs /協力下/
きょうみぶかs /興味深/
きょうみぶかk /興味深/
きょうみぶかi /興味深/
きょうみぶかg /興味深/
きょうだいn /強大/
きょうじゅくだs /教授下/
きょうじくだs /教示下/
きょうしゅくs /恐縮/
きょうざm /興醒/
きょうかしょどおr /教科書通/
きょうかぎr /今日限/
きょうz /興/
きょうs /供;(offer) 実用に供する/饗;(banquet) 客を饗する/狂;go mad/
きょうn /今日/
きょうm /今日/
きょうj /興/
きょうh /今日/
きゅうしょげr /急所蹴;痛/
きゅうしゅうs /吸収/
きゅうs /窮;返答に窮する/給;年金を給する/休;万事休す/急/仇;仇敵/
きゅうn /急/
きゅうd /急/
きやすs /気安/
きやすm /気休/
きやすk /気安/
きやすi /気安/
きやすg /気安/
きやs /着痩/
きゃくよs /客寄/
きゃくひk /客引/
きゃくあつかi /客扱/
きもちわるs /気持ち悪/気持悪/
きもちわるk /気持ち悪/気持悪/
きもちわるi /気持ち悪/気持悪/
きもちわるg /気持ち悪/気持悪/
きもちよs /気持ち良/
きもちよk /気持ち良/
きもちよi /気持ち良/
きもちよg /気持ち良/
きもだめs /肝試/
きもいr /肝煎/
きもt /気持/
きもs /キモ/
きもk /キモ/
きもi /キモ/
きもg /キモ/
きもc /気持/
きめつk /決め付/
きめこまk /木目細/きめ細/肌理細/
きめこn /決め込/
きめこm /決め込/木目込/
きむづかs /気難/
きむずかs /気難/
きみわるs /気味悪/
きみわるk /気味悪/
きみわるi /気味悪/
きみわるg /気味悪/
きみw /君/
きみt /君/
きみn /君/
きみm /君/
きみh /君/
きみg /君/
きまわs /着回/
きまりわるs /決まり悪/
きまりわるk /決まり悪/
きまりわるi /決まり悪/
きまりわるg /決まり悪/
きまぐr /気紛/
きまt /決;非正則(きm)/極/
きまr /極/決;非正則(きm)/
きまn /極/決;非正則(きm)/
きまc /極/決;非正則(きm)/
きぼういたs /希望致/
きぶくr /着脹/
きふるs /着古/
きふよm /棋譜読/
きびしi /厳し;※送り位置補正/
きびs /厳/嚴;「厳」の旧字(人名用漢字)/
きばt /気張/
きばr /気張;-る/気晴;-らし/
きばn /気張/
きばc /気張/
きはどs /際疾/
きはどk /際疾/
きはどi /際疾/
きはどg /際疾/
きはz /気恥/
きはm /窮/
きのぼr /木登/
きのうs /機能/
きのr /気乗/
きぬk /気抜/
きにいt /気に入/
きにいr /気に入/
きにいn /気に入/
きにいc /気に入/
きなくさs /きな臭/キナ臭/
きなくさk /きな臭/キナ臭/
きなくさi /きな臭/キナ臭/
きなくさg /きな臭/キナ臭/
きながs /着流/
きなr /着慣;着慣れた服/生成;(無加工) 生成りのシャツ/
きどおs /着通/
きどうs /起動/
きどt /気取/
きどr /気取/
きどn /気取/
きどc /気取/
きていどおr /規定通/
きていt /着て行/
きていk /着て行/
きていc /着て行/
きづかw /気遣/
きづかu /気遣/
きづかt /気遣/
きづかr /気疲/
きづかo /気遣/
きづかi /気遣/
きづかe /気遣/
きづかc /気遣/
きづm /気詰/
きづk /気付/築;旧仮名/気附/
きづi /気付/築;旧仮名/気附/
きつs /キツ/
きつk /気付;-け薬/着付;和服の-け/キツ/
きつi /キツ/
きつg /キツ/
きってすt /斬って捨/
きっかk /切っ掛/
きっs /喫/
きちがいじm /気違い染/
きちがi /気違/
きだt /気立/
きたむk /北向/
きたなs /汚/穢;<esp.禁忌的に>/
きたなr /汚/
きたなk /汚/穢;<esp.禁忌的に>/
きたなi /汚/穢;<esp.禁忌的に>/
きたなg /汚/穢;<esp.禁忌的に>/
きたえぬk /鍛え抜/
きたえぬi /鍛え抜/
きたえあg /鍛え上/
きたいどおr /期待通/
きたいくだs /期待下/
きたいs /期待/
きたt /来/來;「来」の旧字(人名用漢字)/
きたs /来/來;「来」の旧字(人名用漢字)/
きたr /来/來;「来」の旧字(人名用漢字)/
きたn /汚/
きたe /鍛/
きそづk /基礎付/
きそくただs /規則正/
きそいあw /競い合/
きそいあu /競い合/
きそいあt /競い合/
きそいあo /競い合/
きそいあi /競い合/
きそいあe /競い合/
きそいあc /競い合/
きそw /競/竸;異体字/
きそu /競/竸;異体字/
きそt /競/竸;異体字/
きそo /競/竸;異体字/
きそi /競/竸;異体字/
きそh /競/
きそe /競/竸;異体字/
きそc /競/竸;異体字/
きぜわs /気忙/
きせかe /着せ替/
きずつけあw /傷付け合/
きずつけあu /傷付け合/
きずつけあt /傷付け合/
きずつけあo /傷付け合/
きずつけあi /傷付け合/
きずつけあe /傷付け合/
きずつけあc /傷付け合/
きずつk /傷付/
きずつi /傷付/
きずきあg /築き上/
きずかi /気遣/
きずt /傷/
きずk /築/気付;※仮名遣い「きづk」/
きずi /築/
きじよm /記事読/
きしょくわるs /気色悪/
きしょくわるk /気色悪/
きしょくわるi /気色悪/
きしょくわるg /気色悪/
きしちかk /岸近/
きしt /軋/轢;<rare> ≒軋る/
きしr /軋/轢;<rare> ≒軋る/
きしn /軋/轢;<rare> ≒軋る/
きしm /軋/
きしc /軋/轢;<rare> ≒軋る/
きざわr /気障/
きざみつk /刻み付/
きざみこn /刻み込/
きざみこm /刻み込/
きざs /兆/
きざp /気障/
きざn /刻/
きざm /刻/
きさいs /記載/
きさk /気さ;※送り位置補正/
きこしめs /聞こし召/
きこn /着込/
きこm /着込/
きけんn /危険/
きぐm /木組/
きくばr /気配/
きくs /掬/
ききわすr /聞き忘/
ききわk /聞き分/
ききよs /聴き良/
ききよk /聴き良/
ききよi /聴き良/
ききよg /聴き良/
ききやすs /聞き易/
ききやすk /聞き易/
ききやすi /聞き易/
ききやすg /聞き易/
ききもr /聞き漏/聞き洩/
ききまちがi /聞き間違/
ききまちがe /聞き間違/
ききほr /聞き惚/聴き惚/
ききはじm /聴き始/聞き始/
ききのがs /聞き逃/聞逃/
ききのg /聞き逃/
ききにくs /聞き難/
ききにくk /聞き難/
ききにくi /聞き難/
ききにくg /聞き難/
ききながs /聞き流/聴き流/
ききなおs /聞き直/聴き直/
ききなr /聞き慣/聞き馴;≒聞き慣れる/
ききとどk /聞き届/
ききとがm /聞き咎/
ききとおs /聴き通/聞き通/
ききとt /聞き取/聴き取/聞取/
ききとr /聞き取/聴き取/聞取/
ききとn /聞き取/聴き取/聞取/
ききとc /聞き取/聴き取/聞取/
ききつづk /聞き続/聴き続/
ききつk /聞き付/
ききちがe /聞き違/
ききだs /聞き出;情報を聞き出す/効き出;薬が効き出す/
ききたがe /聞き違/
ききそこn /聞き損/
ききせまt /鬼気迫/
ききせまr /鬼気迫/
ききせまn /鬼気迫/
ききせまc /鬼気迫/
ききずt /聞き捨/
ききすg /効き過/
ききしt /聞き知/
ききしr /聞き知/
ききしn /聞き知/
ききしc /聞き知/
ききこn /聞き込/聴き込/
ききこm /聞き込/聴き込/
ききぐるs /聞き苦/
ききくらb /聞き比/聴き比/聴き較/聞き較/
ききがk /聞き書/
ききかじt /聞き齧/
ききかじr /聞き齧/
ききかじn /聞き齧/
ききかじc /聞き齧/
ききかえs /聞き返/
ききおよn /聞き及/
ききおよb /聞き及/
ききおぼe /聞き覚/
ききおとs /聞き落/
ききおt /聞き落/
ききおe /聞き終/聴き終/
ききいt /聞き入/聴き入/
ききいr /聞き入/聴き入/
ききいn /聞き入/聴き入/
ききいc /聞き入/聴き入/
ききあやまt /聞き誤/
ききあやまr /聞き誤/
ききあやまn /聞き誤/
ききあやまc /聞き誤/
ききあk /聞き飽;-きた話/聴き飽;-きたCD/
きがるs /気軽/
きがるk /気軽/
きがるi /気軽/
きがるg /気軽/
きがまe /気構/
きがつk /気が付/気が附/
きがつi /気が付/気が附/
きがかr /気掛/
きがn /気兼/
きがe /着替/
きかざt /着飾/
きかざr /着飾/
きかざn /着飾/
きかざc /着飾/
きかe /着替/着換/
きおくちがi /記憶違/
きおくr /気後/
きおいたt /気負い立/競い立/
きおいたc /気負い立/競い立/
きおいこn /気負い込/
きおいこm /気負い込/
きおw /気負/
きおu /気負/
きおt /気負/気落/
きおo /気負/
きおi /気負/
きおe /気負/
きおc /気負/
きえはt /消え果/
きえさt /消え去/
きえさr /消え去/
きえさn /消え去/
きえさc /消え去/
きえうs /消え失/
きえいt /消え入/
きえいr /消え入/
きえいn /消え入/
きえいc /消え入/
きいろs /黄色/
きいろp /黄色/
きいろm /黄色/
きいろk /黄色/
きいろi /黄色/
きいろg /黄色/
きあいはいt /気合入/
きあいはいr /気合入/
きあいはいn /気合入/
きあいはいc /気合入/
きあいいr /気合入/
きあi /気合/
きz /着/著;<rare> ≒着る/気;?/氣;「気」の旧字(人名用漢字)/
きy /消/来/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/着/著;<rare> ≒着る/
きw /気/氣;「気」の旧字(人名用漢字)/着/著;<rare> ≒着る/
きu /着/著;<rare> ≒着る/
きt /来/切/着/斬;人を斬る/著;<rare> ≒着る/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/伐;木を伐る/剪;盆栽を剪る/截;布地を截る/鑽;<rare> 火を鑽る(=火打ち石で火を起こす)/
きs /着/来/記;(note)別紙に記する/期;(expect)万全を期す,期せずして/帰;(lead to)水泡に帰す/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/歸;「帰」の旧字/皈;「帰」の異体字/著;<rare> ≒着る/
きr /切/着/斬;人を斬る/伐;木を伐る/剪;盆栽を剪る/截;布地を截る/鑽;<rare> 火を鑽る(=火打ち石で火を起こす)/著;<rare> ≒着る/
きp /着/著;<rare> ≒着る/
きo /着/著;<rare> ≒着る/
きn /気/来/着/機/氣;「気」の旧字(人名用漢字)/著;<rare> ≒着る/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/切/斬;人を斬る/伐;木を伐る/剪;盆栽を剪る/截;布地を截る/鑽;<rare> 火を鑽る(=火打ち石で火を起こす)/
きm /決/来/極;NB:「きわm」と同形/着/気/黄/决;「決」の異体字/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/氣;「気」の旧字(人名用漢字)/著;<rare> ≒着る/
きk /聞/聴;(注意してきく) 音楽を聴く/効;(effect) 薬が効く/利;(work) 気が利く,口を利く/訊;(inquire) 道を訊く/尋/着;-こなす/聽;「聴」の旧字(人名用漢字)/效;「効」の旧字/切/著;<rare> ≒着る/
きj /着/著;<rare> ≒着る/
きi /聞/聴;(注意してきく) 音楽を聴く/効;(effect) 薬が効く/利;(work) 気が利く,口を利く/尋/訊;(inquire) 道を訊く/效;「効」の旧字/聽;「聴」の旧字(人名用漢字)/着/著;<rare> ≒着る/
きh /気/氣;「気」の旧字(人名用漢字)/着/著;<rare> ≒着る/
きg /気/氣;「気」の旧字(人名用漢字)/着/著;<rare> ≒着る/
きe /消/着/著;<rare> ≒着る/
きd /気/氣;「気」の旧字(人名用漢字)/来/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/着/著;<rare> ≒着る/
きc /切/来/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/着/斬;人を斬る/伐;木を伐る/剪;盆栽を剪る/截;布地を截る/鑽;<rare> 火を鑽る(=火打ち石で火を起こす)/著;<rare> ≒着る/
きb /黄/着/著;<rare> ≒着る/
きa /着/著;<rare> ≒着る/
がんばりぬk /頑張り抜/
がんばりぬi /頑張り抜/
がんばりとおs /頑張り通/
がんばt /頑張/
がんばr /頑張/
がんばn /頑張/
がんばc /頑張/
がんつk /ガン付/
がんぜなs /頑是無/
がんぜなk /頑是無/
がんぜなi /頑是無/
がんぜなg /頑是無/
がわr /変/替/代/
がわk /乾/
がらあk /がら空/ガラ空/
がらs /辛/
がらm /絡/
がらk /辛/
がらi /辛/
がらg /辛/
がよi /通/
がまんできn /我慢出来/
がまんづよs /我慢強/
がまんづよk /我慢強/
がまんづよi /我慢強/
がまんづよg /我慢強/
がなりたt /がなり立;選挙カーが-てる/
がとu /難/
がっしょうひねr /合掌捻/
がっしょうづくr /合掌造/
がっこうがえr /学校帰/
がっs /合/
がたs /難;考え難い NB:「にくi」と同形/
がたr /語/
がたm /固/
がたk /難;考え難い NB:「にくi」と同形/
がたi /難;考え難い NB:「にくi」と同形/
がたg /難;考え難い NB:「にくi」と同形/
がぞうとr /画像取/
がさn /重/
がけくずr /崖崩/
がかr /係/
がえんz /肯/
がえんj /肯/
がえs /返/
がえr /帰/返/歸;「帰」の旧字/皈;「帰」の異体字/
がえn /肯/
がいs /害/概;概念/
がw /代/変/替/
がt /勝/
がs /貸/賀;年賀/
がr /刈/狩/借/
がk /書/駆/掛/
がi /買/
がe /替/換/
かんれんづk /関連付/
かんれんz /関連;?/
かんれんs /関連/
かんれんd /関連/
かんやどr /神宿/
かんべんねがw /勘弁願/
かんべんねがu /勘弁願/
かんべんねがt /勘弁願/
かんべんねがo /勘弁願/
かんべんねがi /勘弁願/
かんべんねがe /勘弁願/
かんべんねがc /勘弁願/
かんばしt /甲走/
かんばしr /甲走/
かんばしn /甲走/
かんばしc /甲走/
かんばs /芳;(generic, また特に比喩的に否定形で) 評判が芳しくない/香;香しい梅/馨/
かんのんびらk /観音開/
かんねんs /観念/
かんづm /缶詰/
かんづk /感付/
かんづi /感付/
かんちがi /勘違/
かんだかs /甲高/疳高/
かんだかk /甲高/疳高/
かんだかi /甲高/疳高/
かんだかg /甲高/疳高/
かんたんすg /簡単過/
かんせいs /完成/
かんすうよb /関数呼/
かんじょうてきすg /感情的過/
かんじょうだかs /勘定高;≒算盤高い/
かんじょうだかk /勘定高;≒算盤高い/
かんじょうだかi /勘定高;≒算盤高い/
かんじょうだかg /勘定高;≒算盤高い/
かんじやすs /感じ易/
かんじやすk /感じ易/
かんじやすi /感じ易/
かんじやすg /感じ易/
かんじまz /漢字混/
かんじとt /感じ取/
かんじとr /感じ取/
かんじとn /感じ取/
かんじとc /感じ取/
かんじつづk /感じ続/
かんじいt /感じ入/
かんじいr /感じ入/
かんじいn /感じ入/
かんじいc /感じ入/
かんしんs /感心/
かんしゃいたs /感謝致/
かんしゃs /感謝/
かんげいいたs /歓迎致/
かんけいs /関係/
かんぐt /勘繰/
かんぐr /勘繰/
かんぐn /勘繰/
かんぐc /勘繰/
かんきわm /感極/
かんきr /缶切/
かんがみr /鑑み;※送り位置補正/
かんがえぶかs /考え深/
かんがえぶかk /考え深/
かんがえぶかi /考え深/
かんがえぶかg /考え深/
かんがえぬk /考え抜/
かんがえぬi /考え抜/
かんがえなおs /考え直/
かんがえつk /考え付/
かんがえつi /考え付/
かんがえちがi /考え違;名詞/
かんがえだs /考え出/
かんがえすg /考え過/
かんがえこn /考え込/
かんがえこm /考え込/
かんがえおよn /考え及/
かんがえおよb /考え及/
かんがえあわs /考え併/
かんがえあw /考え合/
かんがいぶかs /感慨深/
かんがいぶかk /感慨深/
かんがいぶかi /感慨深/
かんがいぶかg /感慨深/
かんがm /鑑/鑒;異体字/
かんがh /考/
かんがe /考/稽;<rare>/勘;<rare>/攷;<rare>/
かんかつちがi /管轄違/
かんいr /缶入/
かんz /感;(feel)/観;(contemplate) 真理を観ずる/
かんt /冠/
かんs /関;関数/冠/姦;姦淫/刊/緘;(silence) 口を緘する/神/關;「関」の旧字/
かんj /感/
かんg /勘/
かんd /感/勘/
かわりはt /変わり果/
かわりつづk /変わり続/
かわむk /皮剥/
かわばたどおr /川端通/
かわづr /川釣/
かわぞi /川沿/
かわくだr /川下/
かわきr /皮切/
かわいs /可哀/可愛/
かわいr /可愛/
かわいk /可愛/
かわいi /可愛/
かわいg /可愛/
かわt /変/變;「変」の旧字/代/換/替/
かわs /交/躱;(avoid) 攻撃を躱す/
かわr /変/代/換/替/變;「変」の旧字/
かわn /変/代/換/替/變;「変」の旧字/
かわk /乾/渇;(thirst) 喉が渇く/
かわi /乾/渇;(thirst) 喉が渇く/
かわc /変/代/換/替/變;「変」の旧字/
かろy /軽/輕;「軽」の旧字/
かろu /辛/
かろn /軽/
かれんn /可憐/
かれはt /枯れ果/
かれw /彼/
かれt /涸/彼/
かれr /彼/涸/
かれn /涸/彼/
かれm /彼/
かれh /彼/
かれg /彼/
かれc /涸/
かるすg /軽過/
かるがるs /軽々/軽軽/
かるu /軽/輕;「軽」の旧字/
かるs /軽/輕;「軽」の旧字/
かるm /軽/輕;「軽」の旧字/
かるk /軽/輕;「軽」の旧字/
かるi /軽/輕;「軽」の旧字/
かるg /軽/輕;「軽」の旧字/
かりわたs /仮渡/
かりぬi /仮縫/
かりとt /刈り取/刈取/
かりとr /刈り取/刈取/
かりとn /刈り取/刈取/
かりとc /刈り取/刈取/
かりっぱなs /借りっ放;やべ、本-しだ/
かりだs /借り出;(borrow)本を借り出す/駆り出;(bring out)応援に駆り出す/狩り出;(hunt out)犯人を狩り出す/
かりたおs /借り倒/
かりたt /駆り立/
かりそm /仮初/
かりずまi /仮住/
かりずm /借り住/仮住/
かりさしおさe /仮差押/
かりこs /借り越/借越/
かりこn /狩り込/刈り込/刈込/
かりこm /狩り込/刈り込/刈込/
かりきt /借り切/
かりきr /借り切/
かりきn /借り切/
かりきc /借り切/
かりかs /借り貸/
かりかe /借り換/借換/
かりうk /借り受/
かりいr /借り入/刈り入/借入/刈入;名詞,ラ行下一/
かりあつm /駆り集/
かりあg /借り上/刈り上/
かりn /仮/
からめとt /搦め捕/
からめとr /搦め捕/
からめとn /搦め捕/
からめとc /搦め捕/
からむs /空蒸/
からみつk /絡み付/
からみつi /絡み付/
からみあw /絡み合/
からみあu /絡み合/
からみあt /絡み合/
からみあo /絡み合/
からみあi /絡み合/
からみあe /絡み合/
からみあc /絡み合/
からまわr /空回/
からぶt /空振/
からぶr /空振/
からぶk /乾拭/
からづm /空積/
からだk /空焚/
からたけわr /幹竹割/
からすg /辛過/
からさわg /空騒/
からくt /絡繰;[文語]-る/
からくr /絡繰;[文語]-る/
からくn /絡繰;[文語]-る/
からくc /絡繰;[文語]-る/
からうr /空売/
からあg /空揚/
からs /辛;(hot) 辛いカレー/枯ら;※送り位置補正/鹹;(salty) 鹹い味噌汁/
からp /空/
からn /絡/
からm /絡/辛;(hot) 辛いカレー/搦;搦め捕る/鹹;(salty) 鹹い味噌汁/
からk /辛;(hot) 辛いカレー/鹹;(salty) 鹹い味噌汁/
からi /辛;(hot) 辛いカレー/鹹;(salty) 鹹い味噌汁/
からg /絡;裾を絡げる/紮;≒絡げる/辛;(hot) 辛いカレー/鹹;(salty) 鹹い味噌汁/
かよわs /か弱/
かよわk /か弱/
かよわi /か弱/
かよわg /か弱/
かよいつづk /通い続/
かよいつm /通い詰/
かよいあw /通い合/
かよいあu /通い合/
かよいあt /通い合/
かよいあo /通い合/
かよいあi /通い合/
かよいあe /通い合/
かよいあc /通い合/
かよw /通/
かよu /通/
かよt /通/
かよo /通/
かよi /通/
かよe /通/
かよc /通/
かゆs /痒/癢;=痒い/
かゆm /痒/
かゆk /痒/癢;=痒い/
かゆi /痒/癢;=痒い/
かゆg /痒/癢;=痒い/
かやぶk /茅葺/
かやr /蚊遣/
かもしだs /醸し出/
かもs /醸/釀;「醸」の旧字(人名用漢字)/
かもr /鴨/
かむt /被/冠/
かむr /被/冠/
かむn /被/冠/
かむc /被/冠/
かみわk /噛み分/
かみゆi /髪結/
かみづm /紙詰/
かみつぶs /噛み潰/
かみつk /噛み付/
かみつi /噛み付/
かみちぎt /噛み千切/
かみちぎr /噛み千切/
かみちぎn /噛み千切/
かみちぎc /噛み千切/
かみだのm /神頼/
かみしほうがたm /上四方固/
かみしm /噛み締/
かみころs /噛み殺/
かみくだk /噛み砕/
かみくだi /噛み砕/
かみきt /噛み切/
かみきr /噛み切/紙切/髪切/
かみきn /噛み切/
かみきc /噛み切/
かみかざr /髪飾/
かみかくs /神隠/
かみおr /神降/
かみあわs /噛み合/
かみあw /噛み合/
かみあu /噛み合/
かみあt /噛み合/
かみあo /噛み合/
かみあi /噛み合/
かみあe /噛み合/
かみあc /噛み合/
かみs /神/
かみg /神;-ががり,-がかって (神懸かり・神憑り)/
かまびすs /喧/
かまw /構/
かまu /構/
かまt /構/
かまo /構/
かまk /感/
かまi /構/
かまh /構/
かまe /構/
かまc /構/
かぼそs /か細/
かぼそk /か細/
かぼそi /か細/
かぼそg /か細/
かへt /歸;「帰」の旧字/皈;「帰」の異体字/
かへr /歸;「帰」の旧字/皈;「帰」の異体字/
かぶわk /株分/
かぶりつk /齧り付;NB:「かじりつk」と同形/
かぶりつi /齧り付;NB:「かじりつk」と同形/
かぶt /被/齧;[文語](ラ行四段)「-り付く」/
かぶs /被/
かぶr /被/気触;かぶれる/齧;[文語](ラ行四段)「-り付く」/
かぶn /被/齧;[文語](ラ行四段)「-り付く」/
かぶk /傾;古語。「歌舞伎」の語源/
かぶi /傾;古語。「歌舞伎」の語源/
かぶc /被/齧;[文語](ラ行四段)「-り付く」/
かびくさs /黴臭/カビ臭/
かびくさk /カビ臭/黴臭/
かびくさi /黴臭/カビ臭/
かびくさg /黴臭/カビ臭/
かびz /黴/
かびy /黴/
かびt /黴/
かびs /黴/
かびr /黴/
かびn /黴/
かびm /黴/
かびk /黴/
かびc /黴/
かばw /庇/
かばu /庇/
かばt /庇/
かばo /庇/
かばi /庇/
かばe /庇/
かばc /庇/
かはらi /過払/
かはs /交/
かのうn /可能/
かねもうk /金儲/
かねもt /金持/
かねもc /金持/
かねまわr /金回/
かねばらi /金払/
かねづかi /金遣/
かねそなe /兼ね備/
かねあw /兼ね合/
かねあi /兼ね合/兼合/
かねz /兼/
かねy /兼/
かねt /予/兼/
かねs /兼/
かねr /兼/
かねn /兼/
かねm /兼/
かねc /兼/
かにばさm /蟹挟/
かならz /必/
かなづかi /仮名遣/
かなしばr /金縛/
かなぐりすt /かなぐり捨/
かなぎr /金切/
かなきr /金切/
かながk /仮名書/
かなw /叶;叶わぬ夢/敵;君には敵わないよ/適;(conform) 目的に適う/
かなu /叶;(come true) 夢が叶う/敵;(rival) 敵う者なし/適;(conform) 目的に適う/
かなt /叶;(come true) 夢が叶う/適;(conform) 目的に適う/敵;(rival) 敵う者なし/
かなs /悲;(字義:胸が張り裂ける)/哀;(字義:思いで胸がつかえる)/愛;(字義:≒哀) NB:「いとs」と同形/
かなo /叶;(come true) 夢が叶う/敵;(rival) 敵う者なし/適;(conform) 目的に適う/
かなi /叶;(come true) 夢が叶う/敵;(rival) 敵う者なし/適;(conform) 目的に適う/
かなe /叶;(come true) 夢が叶う/敵;(rival) 敵う者なし/適;(conform) 目的に適う/
かなd /奏/
かなc /叶;(come true) 夢が叶う/敵;(rival) 敵う者なし/適;(conform) 目的に適う/
かどk /角/
かていs /仮定/
かつぎだs /担ぎ出/
かつぎこn /担ぎ込/
かつぎこm /担ぎ込/
かつぎあg /担ぎ上/
かつt /嘗/
かつi /担/擔;「担」の旧字/
かつg /担/擔;「担」の旧字/
かつe /餓/
かっぱらw /掻っ払/
かっぱらu /掻っ払/
かっぱらt /掻っ払/
かっぱらo /掻っ払/
かっぱらi /掻っ払/
かっぱらc /掻っ払/
かっとn /かっ飛/
かっとb /かっ飛/
かってでz /買って出/
かってでy /買って出/
かってでt /買って出/
かってでr /買って出/
かってでn /買って出/
かってでm /買って出/
かってこz /買って来/
かってこy /買って来/
かってこs /買って来/
かってこr /買って来/
かってこn /買って来/
かってこi /買って来/
かってくr /買って来/
かってくn /買って来/
かってきy /買って来/
かってきt /買って来/
かってきs /買って来/
かってきn /買って来/
かってきm /買って来/
かってきd /買って来/
かってきc /買って来/
かっさらw /掻っ攫/
かっさらu /掻っ攫/
かっさらt /掻っ攫/
かっさらo /掻っ攫/
かっさらi /掻っ攫/
かっさらc /掻っ攫/
かっさばk /掻っ捌/
かっさばi /掻っ捌/
かっこわるs /格好悪/
かっこわるk /格好悪/
かっこわるi /格好悪/
かっこわるg /格好悪/
かっこうわるs /格好悪/
かっこうわるk /格好悪/
かっこうわるi /格好悪/
かっこうわるg /格好悪/
かっこうよs /格好良/
かっこうよk /格好良/
かっこうよi /格好良/
かっこn /掻っ込/
かっこm /掻っ込/
かっくr /かっ喰/かっ食/
かっきづk /活気付/
かっきづi /活気付/
かっs /渇/
かちまk /勝ち負/
かちほこt /勝ち誇/
かちほこr /勝ち誇/
かちほこn /勝ち誇/
かちほこc /勝ち誇/
かちのこt /勝ち残/
かちのこr /勝ち残/
かちのこn /勝ち残/
かちのこc /勝ち残/
かちぬk /勝ち抜/勝抜/
かちぬi /勝ち抜/勝抜/
かちにg /勝ち逃/
かちとt /勝ち取/
かちとr /勝ち取/
かちとn /勝ち取/
かちとc /勝ち取/
かちつづk /勝ち続/
かちっぱなs /勝ちっ放/
かちすすn /勝ち進/
かちすすm /勝ち進/
かちこs /勝ち越/
かちおt /搗ち落/
かちおc /搗ち落/
かちえz /勝ち得/贏ち得/
かちえy /勝ち得/贏ち得/
かちえt /勝ち得/贏ち得/
かちえs /勝ち得/贏ち得/
かちえr /勝ち得/贏ち得/
かちえn /勝ち得/贏ち得/
かちえm /勝ち得/贏ち得/
かちえk /勝ち得/贏ち得/
かちえc /勝ち得/贏ち得/
かちあw /搗ち合/
かちあu /搗ち合/
かちあt /搗ち合/
かちあo /搗ち合/
かちあi /搗ち合/
かちあg /勝ち上/搗ち上;[相撲]/
かちあc /搗ち合/
かたわらいたs /傍ら痛/
かたわらいたk /傍ら痛/
かたわらいたi /傍ら痛/
かたわらいたg /傍ら痛/
かたわr /傍/片割/
かたりつづk /語り続/
かたりつたe /語り伝/
かたりつくs /語り尽/
かたりつk /語り尽/
かたりつi /語り継/
かたりつg /語り継/
かたりだs /語り出/
かたりきk /語り聞/
かたりかk /語り掛/
かたりあw /語り合/
かたりあu /語り合/
かたりあt /語り合/
かたりあo /語り合/
かたりあk /語り明/
かたりあi /語り合/
かたりあe /語り合/
かたりあc /語り合/
かたよt /偏/片寄/
かたよs /片寄/
かたよr /偏/片寄/
かたよn /偏/片寄/
かたよc /偏/片寄/
かたむすb /片結/
かたむk /傾/
かたむi /傾/
かたべr /片減/
かたぶk /傾;古語/
かたぶi /傾;古語/
かたびらk /片開/
かたひらk /片開/
かたばかr /形許/
かたはらいたs /片腹痛/
かたはらいたk /片腹痛/
かたはらいたi /片腹痛/
かたはらいたg /片腹痛/
かたなs /形無/
かたどおr /型通/
かたどt /象/
かたどr /象/模;≒象る/方取;(気にかける)/
かたどn /象/
かたどc /象/
かたづくr /形作/
かたづk /片付/型付/
かたづi /片付/
かたつk /型付/肩付/
かたちづくt /形作/
かたちづくr /形作/
かたちづくn /形作/
かたちづくc /形作/
かたたたk /肩叩/
かたたがe /方違/
かたすk /肩透/
かたすg /硬過/
かたじけなs /忝/辱/
かたじけなk /忝/辱/
かたじけなi /忝/辱/
かたじけなg /忝/辱/
かたこr /肩凝/
かたぐるs /堅苦/
かたくるs /堅苦/
かたくn /頑/
かたがわr /肩代/
かたがw /肩代/
かたかk /肩掛/
かたおもi /片思/片想/
かたおs /型押/
かたえびがたm /片海老固/
かたいr /肩入/
かたy /片/
かたt /語/騙;(deceive) 名を騙る/
かたs /硬;(カチコチ)「硬い石／演奏」/固;(generic)/堅;(しっかり)「堅いやり方」/難;(difficult)/片;(clean) 部屋を-/
かたr /語/騙;(deceive) 名を騙る/
かたp /片/
かたn /語/騙;(deceive) 名を騙る/
かたm /固/硬/堅/傾;非正則(かたむk)/難;(difficult)/
かたk /固;(generic)/硬;(カチコチ)「硬い石／演奏」/堅;(しっかり)「堅いやり方」/難;(difficult)/
かたi /固;(generic)/硬;(カチコチ)「硬い石／演奏」/堅;(しっかり)「堅いやり方」/難;(difficult)/
かたg /傾;首を-げる/固;(generic)/硬;(カチコチ)「硬い石／演奏」/堅;(しっかり)「堅いやり方」/難;(difficult)/
かたd /片/
かたc /語/騙;(deceive) 名を騙る/
かぞくづr /家族連/
かぞくあw /家族合/
かぞえたt /数え立/
かぞえきt /数え切/
かぞえきr /数え切/
かぞえきn /数え切/
かぞえきc /数え切/
かぞえいr /数え入/
かぞえあg /数え上/
かぞe /数/數;旧字/
かそけs /幽/
かそけk /幽/
かぜむk /風向/
かぜとおs /風通/
かぜあt /風当/
かせぎだs /稼ぎ出/
かせi /稼/
かせg /稼/
かずすくn /数少/
かずしr /数知/
かずかぎりなs /数限り無/
かずかぎりなk /数限り無/
かずかぎりなi /数限り無/
かずかぎr /数限/
かずおおs /数多/
かずおおk /数多/
かずおおi /数多/
かずおおg /数多/
かずあw /数合/
かずあt /数当/
かずk /被/
かずi /被/
かすめとt /掠め取/
かすめとr /掠め取/
かすめとn /掠め取/
かすめとc /掠め取/
かすみわたt /霞み渡/
かすみわたr /霞み渡/
かすみわたn /霞み渡/
かすみわたc /霞み渡/
かすがどおr /春日通/
かすt /掠/擦;NB:「すr」「こすr」「なすr」と同形/
かすr /擦;NB:「すr」「こすr」「なすr」と同形/掠/
かすn /霞/擦;NB:「すr」「こすr」「なすr」と同形/掠/翳;<rare> ≒霞む 「目が翳む」/
かすm /霞/掠/翳;<rare> ≒霞む 「目が翳む」/
かすk /微;(字義:目立たない)/幽;(字義:薄暗くて良く見えない)/
かすc /擦;NB:「すr」「こすr」「なすr」と同形/掠/
かじりつk /齧り付/
かじりつi /齧り付/
かじょうがk /箇条書/
かじかn /悴/
かじかm /悴/
かじt /齧/噛/囓;「齧」の異体字/
かじr /齧/囓;「齧」の異体字/噛/
かじn /齧/囓;「齧」の異体字/噛/
かじc /齧/囓;「齧」の異体字/噛/
かしまs /姦/
かしつk /貸し付/貸付/
かしだs /貸し出/貸出/
かしずk /傅/
かしずi /傅/
かししぶt /貸し渋/
かししぶr /貸し渋/
かししぶn /貸し渋/
かししぶc /貸し渋/
かしこs /賢/畏;(おそれ多い)/
かしこm /畏/
かしこk /賢/畏;(おそれ多い)/
かしこi /賢/畏;(おそれ多い)/
かしこg /賢/畏;(おそれ多い)/
かしきt /貸し切/貸切/
かしきr /貸し切/貸切/
かしきn /貸し切/貸切/
かしきc /貸し切/貸切/
かしかr /貸し借/
かしi /傾/炊/爨/
かしg /炊;‖ガ行五段[gi]/爨;‖ガ行五段[gi]/傾/
かざりつk /飾り付/
かざりたt /飾り立/
かざむk /風向/
かざとおs /風通/
かざt /飾/餝;「飾」の異体字/錺;<rare>(金属でかざる)/
かざs /翳/
かざr /飾/錺;<rare>(金属でかざる)/餝;「飾」の異体字/
かざn /飾/錺;<rare>(金属でかざる)/餝;「飾」の異体字/
かざc /飾/錺;<rare>(金属でかざる)/餝;「飾」の異体字/
かさばt /嵩張/
かさばr /嵩張/
かさばn /嵩張/
かさばc /嵩張/
かさねあw /重ね合/
かさねあu /重ね合/
かさねあt /重ね合/
かさねあo /重ね合/
かさねあi /重ね合/
かさねあe /重ね合/
かさねあc /重ね合/
かさなりあw /重なり合/
かさなりあu /重なり合/
かさなりあt /重なり合/
かさなりあo /重なり合/
かさなりあi /重なり合/
かさなりあe /重なり合/
かさなりあc /重なり合/
かさなt /重な;※送り位置補正/
かさn /重/嵩/
かさm /嵩/
かこつk /託/
かこくn /苛酷/
かこいこn /囲い込/
かこいこm /囲い込/
かこw /囲/圍;「囲」の旧字/
かこu /囲/圍;「囲」の旧字/
かこt /託/囲/喞;≒託つ/圍;「囲」の旧字/
かこo /囲/圍;「囲」の旧字/
かこn /囲/圍;「囲」の旧字/
かこm /囲/圍;「囲」の旧字/
かこi /囲/圍;「囲」の旧字/
かこe /囲/圍;「囲」の旧字/
かこc /囲/圍;「囲」の旧字/
かげふm /影踏/
かげきすg /過激過/
かげt /翳/陰/
かげr /翳/陰/
かげn /翳/陰/
かげc /翳/陰/
かけわたs /架け渡;橋を-/掛け渡;簾を-/
かけよt /駆け寄/
かけよr /駆け寄/
かけよn /駆け寄/
かけよc /駆け寄/
かけもt /掛け持/掛持/
かけもc /掛け持/掛持/
かけめぐt /駆け巡/
かけめぐr /駆け巡/
かけめぐn /駆け巡/
かけめぐc /駆け巡/
かけまわt /駆け回/
かけまわr /駆け回/
かけまわn /駆け回/
かけまわc /駆け回/
かけひk /駆け引;(恋の)-き/駆引/
かけのぼt /駈け登/
かけのぼr /駈け登/
かけのぼn /駈け登/
かけのぼc /駈け登/
かけぬk /駆け抜/
かけどおs /駆け通/
かけてゆk /駆けて行/
かけていt /駈けて行/駆けて行/
かけていk /駆けて行/駈けて行/
かけていc /駆けて行/駈けて行/
かけつけt /駆け付け;※送り位置補正/
かけつk /駆け付/
かけちがw /掛け違/
かけちがu /掛け違/
かけちがt /掛け違/
かけちがo /掛け違/
かけちがi /掛け違/
かけちがc /掛け違/
かけだs /駆け出/駆出/掛け出;-した濡れ縁/掛出/
かけずりまわt /駆けずり回/
かけずりまわr /駆けずり回/
かけずりまわn /駆けずり回/
かけずりまわc /駆けずり回/
かけすt /掛け捨/
かけこn /駆け込/駆込/駈け込/駈込/
かけこm /駆け込/駆込/駈け込/駈込/
かけかe /掛け替/掛替/
かけおt /駆け落/駆落/
かけおr /駆け下/駆け降/駈け降/駈け下/
かけおc /駆け落/駆落/
かけあわs /掛け合/
かけあw /掛け合/
かけあu /懸合/掛合/懸け合/掛け合/
かけあg /駆け上/駈け上/
かけt /翔/
かけr /翔/
かけn /翔/
かけc /翔/
かぐわs /芳/香/馨/
かくりs /隔離/
かくまw /匿/
かくまu /匿/
かくまt /匿/
かくまo /匿/
かくまi /匿/
かくまe /匿/
かくまc /匿/
かくほs /確保/
かくばt /角張/
かくばr /角張/
かくばn /角張/
かくばc /角張/
かくのごとk /斯くの如/
かくのうs /格納/
かくにんねがi /確認願/
かくにんくだs /確認下/
かくにんおよb /確認及/
かくにんs /確認/
かくていs /確定/
かくづk /格付/
かくちょうたかs /格調高/
かくちょうたかk /格調高/
かくちょうたかi /格調高/
かくちょうたかg /格調高/
かくだいs /拡大/
かくしもt /隠し持/
かくしどr /隠し撮/
かくしとおs /隠し通/
かくしきばr /格式張/
かくしきt /隠し切/
かくしきr /隠し切/
かくしきn /隠し切/
かくしきc /隠し切/
かくさg /格下/
かくぎr /角切/
かくがr /角刈/
かくおt /角落/
かくあg /格上/
かくt /確/斯く;※送り位置補正/
かくs /隠/画;一線を画す/匿;(字義:入れ物に入れてかくす) ≒隠す/劃;≒画す/隱;「隠」の旧字/
かくr /隠/隱;「隠」の旧字/
かくm /匿;非正則(かくまu)/
かぎわk /嗅ぎ分/
かぎりなs /限り無/
かぎりなk /限り無/
かぎりなi /限り無/
かぎまわt /嗅ぎ回/
かぎまわr /嗅ぎ回/
かぎまわn /嗅ぎ回/
かぎまわc /嗅ぎ回/
かぎつk /嗅ぎ付/
かぎだs /嗅ぎ出/
かぎざk /鉤裂/
かぎあt /嗅ぎ当/
かぎt /限/
かぎr /限/
かぎn /限/
かぎc /限/
かきわすr /書き忘/
かきわk /掻き分;髪を-/書き分;文体を-/かき分/
かきよごs /書き汚/
かきやすs /書き易/
かきやすk /書き易/
かきやすi /書き易/
かきやすg /書き易/
かきもどs /書き戻/書戻/
かきもr /書き漏/
かきむしt /掻き毟/
かきむしr /掻き毟/
かきむしn /掻き毟/
かきむしc /掻き毟/
かきみだs /掻き乱/
かきまわs /掻き回/
かきまちがi /書き間違/
かきまちがe /書き間違/
かきまz /かき混/掻き混/
かきはじm /書き始/
かきのこs /書き残/
かきぬk /書き抜/
かきぬi /書き抜/
かきならs /掻き均/
かきならb /書き並/
かきながs /書き流;さらっと-す/
かきなおs /書き直/
かきなr /かき鳴/掻き鳴/書き慣/
かきとどm /書き留/
かきとt /書き取/書取/
かきとr /書き取/書取/
かきとn /書き取/書取/
かきとm /書き留/
かきとc /書き取/書取/
かきとb /書き飛/
かきつらn /書き連/
かきつづt /書き綴/
かきつづr /書き綴/
かきつづn /書き綴/
かきつづk /書き続/
かきつづc /書き綴/
かきつたe /書き伝/
かきつくs /書き尽/
かきつk /書き尽/書き付/
かきつi /書き継/
かきつg /書き継/
かきちr /書き散/
かきだs /書き出/書出/かき出/掻き出/
かきたt /書き立/
かきたs /書き足/
かきたr /書き足/
かきたm /書き溜/
かきぞm /書き初/
かきそんz /書き損/
かきそんj /書き損/
かきそこn /書き損/
かきそe /書き添/
かきすt /書き捨/かき捨/掻き捨/
かきしるs /書き記/
かきこn /書き込/書込/掻き込/
かきこm /書き込/書込/掻き込/
かきけs /かき消/掻き消/
かきくわe /書き加/
かきくもt /掻き曇/
かきくもr /掻き曇/
かきくもn /掻き曇/
かきくもc /掻き曇/
かきくどk /掻き口説/
かきくどi /掻き口説/
かきくだs /書き下/
かきくずs /書き崩/
かききt /掻き切/
かききr /掻き切/
かききn /掻き切/
かききe /掻き消/かき消/
かききc /掻き切/
かきかえr /書き換え;※送り位置補正/
かきかw /書き変/
かきかe /書き換/書換/書き替/書き変/
かきおろs /書下/描き下ろ;※送り位置補正/
かきおよn /書き及/
かきおよb /書き及/
かきおとs /書き落/
かきおさm /書き納/
かきおこs /書き起/
かきおくt /書き送/
かきおくr /書き送/
かきおくn /書き送/
かきおくc /書き送/
かきおt /書き落/
かきおr /書き下/書下/
かきおk /書き起/書き置/書置/
かきおi /書き置/書置/
かきおe /書き終/
かきうつs /書き写/
かきいだk /掻き抱/
かきいだi /掻き抱/
かきいr /書き入/
かきあらわs /書き表/
かきあらたm /書き改/
かきあやまt /書き誤/
かきあやまr /書き誤/
かきあやまn /書き誤/
かきあやまc /書き誤/
かきあつm /かき集/掻き集/
かきあg /書き上/
かがよu /耀/
かがよh /耀/
かがやきわたt /輝き渡/
かがやきわたr /輝き渡/
かがやきわたn /輝き渡/
かがやきわたc /輝き渡/
かがやk /輝/耀;(字義:ぎらぎらとかがやく)/赫;(字義:赤々と火照る)/
かがやi /輝/耀;(字義:ぎらぎらとかがやく)/赫;(字義:赤々と火照る)/
かがみこn /屈み込/
かがみこm /屈み込/
かがt /縢;sew/
かがr /縢;sew/
かがn /屈/縢;sew/
かがm /屈/
かがc /縢;sew/
かかわりあw /関わり合/係わり合/
かかわりあu /関わり合/係わり合/
かかわりあt /関わり合/係わり合/
かかわりあo /関わり合/係わり合/
かかわりあi /関わり合/係わり合/
かかわりあe /関わり合/係わり合/
かかわりあc /関わり合/係わり合/
かかわt /拘;(字義:引っ掛かる)「それにも拘らず」/係;(字義:紐でつながる) 「…に係る法律」 NB:「かかr」と同形/関;(字義:かんぬきのように事物をつなぐ) 「プロジェクトに関る」/
かかわr /係;(字義:紐でつながる) 「…に係る法律」 NB:「かかr」と同形/拘;(字義:引っ掛かる)「それにも拘らず」/関;(字義:かんぬきのように事物をつなぐ) 「プロジェクトに関る」/
かかわn /係;(字義:紐でつながる) 「…に係る法律」 NB:「かかr」と同形/拘;(字義:引っ掛かる)「それにも拘らず」/関;(字義:かんぬきのように事物をつなぐ) 「プロジェクトに関る」/
かかわc /係;(字義:紐でつながる) 「…に係る法律」 NB:「かかr」と同形/拘;(字義:引っ掛かる)「それにも拘らず」/関;(字義:かんぬきのように事物をつなぐ) 「プロジェクトに関る」/
かかりつk /掛かり付/
かかりすg /掛り過/
かかえこn /抱え込/
かかえこm /抱え込/
かかw /関;(字義:かんぬきのように事物をつなぐ) 「プロジェクトに関わる」/係;(字義:紐でつながる) 「…に係わる事例」/拘;(字義:引っ掛かる)「それにも拘わらず」/關;「関」の旧字/
かかt /掛/係/罹;病気に罹る/
かかr /係/掛/罹;病気に罹る/
かかn /係/掛/罹;病気に罹る/
かかg /掲/
かかe /抱/
かかc /係/掛/罹;病気に罹る/
かおりたかs /香り高/
かおりたかk /香り高/
かおりたかi /香り高/
かおりたかg /香り高/
かおりたt /香り立/
かおりたc /香り立/
かおむk /顔向/
かおみしr /顔見知/
かおまk /顔負/
かおぶr /顔触/
かおつk /顔付/
かおだt /顔立/
かおだs /顔出/
かおあわs /顔合/
かおあw /顔合/
かおt /薫/香/馨/
かおr /香/薫/馨/
かおn /香/薫/馨/
かおc /香/薫/馨/
かえりざk /返り咲/
かえりざi /返り咲/
かえりがk /帰り掛/
かえりうt /返り討/
かえりm /省;(反省) 我が身を省みる/顧;(look back) 過去を顧みる,危険を顧みない/
かえってこz /帰って来;子供が家に-/返って来;メールが-/
かえってこy /帰って来;子供が家に-/返って来;メールが-/
かえってこs /帰って来;子供が家に-/返って来;メールが-/
かえってこr /帰って来;子供が家に-/返って来;メールが-/
かえってこn /帰って来;子供が家に-/返って来;メールが-/
かえってこi /帰って来;子供が家に-/返って来;メールが-/
かえってくr /帰って来;子供が家に-/返って来;メールが-/
かえってくn /帰って来;子供が家に-/返って来;メールが-/
かえってきy /帰って来;子供が家に-/返って来;メールが-/
かえってきt /帰って来;子供が家に-/返って来;メールが-/
かえってきs /帰って来;子供が家に-/返って来;メールが-/
かえってきn /帰って来;子供が家に-/返って来;メールが-/
かえってきm /帰って来;子供が家に-/返って来;メールが-/
かえってきd /帰って来;子供が家に-/返って来;メールが-/
かえってきc /帰って来;子供が家に-/返って来;メールが-/
かえすがえs /返す返/
かえがたs /代え難/
かえがたk /代え難/
かえがたi /代え難/
かえがたg /代え難/
かえz /替/換/
かえy /替/換/
かえt /帰;家に帰る/返;我に返る,ひっくり返る/却/反;(反転する)/還;(元に戻る) 土に還る/歸;「帰」の旧字/皈;「帰」の異体字/孵;(孵化) 卵が孵る/替/換/卻;「却」の異体字/
かえs /返;金を返す,裏返す/帰;家に帰す/還;(元に戻す) 自然に還す/孵;(孵化) 卵を孵す/反;(≒返す) 反転する/歸;「帰」の旧字/皈;「帰」の異体字/替/換/
かえr /帰;家に帰る/返;我に返る,ひっくり返る/還;(元に戻る) 土に還る/孵;(孵化) 卵が孵る/反;(反転する)/替/換/歸;「帰」の旧字/皈;「帰」の異体字/
かえn /帰;家に帰る/返;我に返る,ひっくり返る/還;(元に戻る) 土に還る/孵;(孵化) 卵が孵る/反;(反転する)/替/換/歸;「帰」の旧字/皈;「帰」の異体字/
かえm /替/換/
かえc /帰;家に帰る/歸;「帰」の旧字/皈;「帰」の異体字/返;我に返る,ひっくり返る/還;(元に戻る) 土に還る/孵;(孵化) 卵が孵る/反;(反転する)/替/換/
かいもどs /買戻/買い戻/
かいもとm /買い求/
かいまみz /垣間見/
かいまみy /垣間見/
かいまみt /垣間見/
かいまみs /垣間見/
かいまみr /垣間見/
かいまみn /垣間見/
かいまみm /垣間見/
かいまみk /垣間見/
かいまみe /垣間見/
かいまみc /垣間見/
かいほうs /解放/
かいびかe /買い控/
かいのs /買い乗/
かいなおs /買い直/
かいなr /飼い馴/
かいなd /掻い撫/
かいどくd /買い得/
かいとt /買い取/買取/
かいとr /買い取/買取/
かいとn /買い取/買取/
かいとc /買い取/買取/
かいつまn /掻い摘/
かいつまm /掻い摘/
かいつづk /買い続/
かいつk /買い付/買付/
かいだs /買い出/
かいたたk /買い叩/
かいたたi /買い叩/
かいたs /買い足/
かいそろe /買い揃/
かいせつs /開設/
かいしょうなs /甲斐性無/
かいしゃがえr /会社帰/
かいしぶt /買い渋/
かいしぶr /買い渋/
かいしぶn /買い渋/
かいしぶc /買い渋/
かいしm /買い占/買占/
かいささe /買い支/
かいさいいたs /開催致/
かいごろs /飼い殺/
かいこs /買い越/
かいこn /買い込/
かいこm /買い込/
かいけつs /解決/
かいぐi /買い食/
かいくぐt /掻い潜/
かいくぐr /掻い潜/
かいくぐn /掻い潜/
かいくぐc /掻い潜/
かいきt /買い切/
かいきr /買い切/
かいきn /買い切/
かいきc /買い切/
かいがんまわr /海岸回/
かいがんちかs /海岸近/
かいがんちかk /海岸近/
かいがんちかi /海岸近/
かいがんちかg /海岸近/
かいがいs /甲斐甲斐/
かいかぶt /買い被/
かいかぶr /買い被/
かいかぶn /買い被/
かいかぶc /買い被/
かいかe /買い替/買い換/買替/
かいおk /買い置/
かいおi /買い置/
かいうk /買い受/
かいいr /買い入/買入/
かいあたe /買い与/
かいあさt /買い漁/
かいあさr /買い漁/
かいあさn /買い漁/
かいあさc /買い漁/
かいあおt /買い煽/
かいあおr /買い煽/
かいあおn /買い煽/
かいあおc /買い煽/
かいあw /貝合/
かいあg /買い上/
かいt /解/觧;「解」の異体字/
かいs /解;善意に解する/介;業者を介する,意に介しない/会;一堂に会する/會;「会」の旧字/觧;「解」の異体字/
かあs /母/
かw /変;(変化)色が変わる/代;(代理)代わりに出席する/交;挨拶を交わす/替;世代が替わる/買/換/飼/變;「変」の旧字/支;ささえる/
かu /買/飼/交/支;ささえる/
かt /勝/買/飼/刈;(crop)草を刈る/狩;(hunt)兎を狩る/且;-つて/駆;バイクを駆って/交;飛び交って/克;(overcome) 逆境に克つ/糅;-てて加えて/苅;「刈」の異体字/驅;「駆」の旧字/支;ささえる/上;(尺八の)カリ⇔減り(メリ)/搗/
かs /貸/化/課;税を課す/科;懲役を科す/嫁;富農に嫁す/架;橋を架す/和;=わ-する/仮;許す/呵/藉/淅/
かr /借/枯;草が枯れる/狩;(hunt)兎を狩る/刈;(crop)草を刈る/駆;(drive)車を駆る,衝動に駆られる/涸;川が涸れる/嗄;声が嗄れる/仮/上;(尺八の)カリ⇔減り(メリ)/苅;「刈」の異体字/驅;「駆」の旧字/
かo /買/飼/交/支;ささえる/
かn /兼/噛/彼/狩;(hunt)兎を狩る/刈;(crop)草を刈る/駆;(drive)車を駆る,衝動に駆られる/咬;かみつく。「蛇が咬む」/嚼;細かくかみ砕く/醸;[文語](酒を)かもす/上;(尺八の)カリ⇔減り(メリ)/苅;「刈」の異体字/驅;「駆」の旧字/
かm /噛/咬;かみつく。「蛇が咬む」/嚼;細かくかみ砕く/醸;[文語](酒を)かもす/
かk /書/掛/欠/駆;駆け足/賭;(bet) 金を賭ける/掻;痒いところを掻く/描;絵を描く NB:「えがk」と同形/画;線を画く/架;橋を架ける/駈;「駆」の旧字(人名用漢字)/翔;空を翔ける/斯;-く(も)/懸;命を懸ける/繋;(ひもでつなぐ)/闕;≒欠ける/舁;駕籠を舁く/畫;「画」の旧字/缺;「欠」の旧字/驅;旧字/
かi /買/書/描;絵を描く NB:「えがk」と同形/飼/画;線を画く/欠/掻/嗅/交/畫;「画」の旧字/缺;「欠」の旧字/支;ささえる/闕;≒欠ける/舁;駕籠を舁く/
かh /替/換/交/支/飼/代/買/變/
かg /嗅/
かe /変;(変化) 態度を変える/替;(取り替え) 部品を替える/代;(代用) あいさつに代える/換;(交換) 金に換える/買/飼/易/變;「変」の旧字/交/支;ささえる/
かc /勝/買/飼/交/支;ささえる/克;(overcome) 逆境に克つ/狩;(hunt)兎を狩る/刈;(crop)草を刈る/駆;(drive)車を駆る,衝動に駆られる/苅;「刈」の異体字/驅;「駆」の旧字/搗/
かb /黴;-びる/
おんよm /音読/
おんびk /音引/
おんなたらs /女誑/
おんなずk /女好/
おんなざかr /女盛/
おんなくさs /女臭/
おんなくさk /女臭/
おんなくさi /女臭/
おんなくさg /女臭/
おんなぎらi /女嫌/
おんなs /女/
おんなr /女/
おんなp /女/
おんなj /同;口語/
おんきs /恩着/
おんがえs /恩返/
おわらi /お笑/
おわたs /お渡/
おわすr /お忘/
おわかs /お若/
おわかr /お別/
おわかk /お若/
おわかi /お若/
おわかg /お若/
おわt /終/畢;(原義:鳥獣を獲る網)/
おわs /御座/在/
おわr /終/畢;(原義:鳥獣を獲る網)/終わ;※送り位置補正/
おわn /終/畢;(原義:鳥獣を獲る網)/
おわc /終/畢;(原義:鳥獣を獲る網)/
おろそk /疎/
おろおぼe /疎覚/
おろs /卸;(wholesale)商品を卸す,大根を卸す/下;NB:「くだs」と同形/
おろk /愚/
おれまがt /折れ曲/
おれまがr /折れ曲/
おれまがn /折れ曲/
おれまがc /折れ曲/
おれまg /折れ曲/
おれw /俺/
おれt /俺/
おれn /俺/
おれm /俺/
おれh /俺/
おれg /俺/
おりよk /折良/
おりめただs /折り目正/
おりまz /織り交/
おりまg /折り曲/
おりなs /織り成/
おりとt /折り取/折取/
おりとr /折り取/折取/
おりとn /折り取/折取/
おりとc /折り取/折取/
おりだs /織り出/
おりたたn /折り畳/折畳/
おりたたm /折り畳/折畳/
おりたt /降り立/下り立/
おりたc /降り立/下り立/
おりこn /折り込;チラシを折り込む/織り込;それはもう織り込み済みだ/折込/織込/
おりこm /折り込;チラシを折り込む/織り込;それはもう織り込み済みだ/折込/織込/
おりかさn /折り重/
おりかえs /折り返/折返/
おりいt /折り入/
おりいr /折り入/
おりいn /折り入/
おりいc /折り入/
おりあw /折り合/折合/
おりあu /折り合/折合/
おりあt /折り合/折合/
おりあs /折悪/
おりあo /折り合/折合/
おりあi /折り合/折合/
おりあe /折り合/折合/
おりあc /折り合/折合/
おりs /折/
およろこb /お慶/
およびがたs /及び難/
およびがたk /及び難/
およびがたi /及び難/
およびがたg /及び難/
およぎこn /泳ぎ込/
およぎこm /泳ぎ込/
およs /凡/お寄/
およr /お寄/
およn /及/
およm /御読/
およi /泳/游;<rare> (字義:水面をゆらゆらする)/
およg /泳/游;<rare> (字義:水面をゆらゆらする)/
およb /及/
おやゆずr /親譲/
おやすs /お安/
おやすm /お休/
おやすk /お安/
おやすi /お安/
おやm /お止/
おもんみz /惟/
おもんみy /惟/
おもんみt /惟/
おもんみs /惟/
おもんみr /惟/
おもんみn /惟/
おもんみm /惟/
おもんみc /惟/
おもんぱかt /慮/
おもんぱかr /慮/
おもんぱかn /慮/
おもんぱかc /慮/
おもんばかt /慮/
おもんばかr /慮/
おもんばかn /慮/
おもんばかc /慮/
おもわせぶr /思わせ振/
おももt /面持/
おもむきぶかs /趣深/
おもむきぶかk /趣深/
おもむきぶかi /趣深/
おもむきぶかg /趣深/
おもむk /赴;(go) 現場に赴く/趣;趣きがある/
おもむi /赴;(go) 現場に赴く/趣;趣きがある/
おもみづk /重み付/
おもはゆs /面映/
おもはゆk /面映/
おもはゆi /面映/
おもはゆg /面映/
おもはy /面映/
おもねt /阿/
おもねr /阿/
おもねn /阿/
おもねc /阿/
おもとm /お求/
おもてむk /表向/
おもてどおr /表通/
おもてだt /表立/
おもてだc /表立/
おもてがk /表書/
おもてあm /表編/
おもだt /主立/重立;=主立つ/
おもだc /重立;=主立つ/
おもすぎr /重過ぎ;※送り位置補正/
おもすg /重過/
おもしろおかs /面白可笑/
おもしろu /面白/
おもしろs /面白/
おもしろm /面白/
おもしろk /面白/
おもしろi /面白/
おもしろg /面白/
おもざs /面差/
おもぐるs /重苦/
おもくるs /重苦/
おもおもs /重々/重重/
おもいわずらw /思い煩/
おもいわずらu /思い煩/
おもいわずらt /思い煩/
おもいわずらo /思い煩/
おもいわずらi /思い煩/
おもいわずらe /思い煩/
おもいわずらc /思い煩/
おもいやt /思い遣/
おもいやr /思い遣/
おもいやn /思い遣/
おもいやc /思い遣/
おもいめぐr /思い巡/
おもいみだr /思い乱/
おもいのこs /思い残/
おもいなやn /思い悩/
おもいなやm /思い悩/
おもいなおs /思い直/
おもいなs /思い做/
おもいどおr /思い通/
おもいとどm /思い止/
おもいでぶかs /思い出深/想い出深/
おもいでぶかk /思い出深/想い出深/
おもいでぶかi /思い出深/想い出深/
おもいでぶかg /思い出深/想い出深/
おもいつづk /思い続/想い続/
おもいつm /思い詰/
おもいつk /思い付/
おもいつi /思い付/
おもいっきr /思いっ切/
おもいちがi /思い違/
おもいちがe /思い違/
おもいだs /思い出/
おもいたt /思い立/
おもいたc /思い立/
おもいすごs /思い過/
おもいすg /思い過/
おもいしt /思い知/
おもいしr /思い知/
おもいしn /思い知/
おもいしc /思い知/
おもいさだm /思い定/
おもいこn /思い込/
おもいこm /思い込/
おもいくらb /思い比/
おもいきt /思い切/
おもいきr /思い切/
おもいきn /思い切/
おもいきc /思い切/
おもいかえs /思い返/
おもいかn /思い兼/
おもいおよn /思い及/
おもいおよb /思い及/
おもいおもi /思い思/
おもいおk /思い起/
おもいえがk /思い描/
おもいえがi /思い描/
おもいうk /思い浮/
おもいいたt /思い至/
おもいいたr /思い至/
おもいいたn /思い至/
おもいいたc /思い至/
おもいいr /思い入/
おもいあまt /思い余/
おもいあまr /思い余/
おもいあまn /思い余/
おもいあまc /思い余/
おもいあt /思い当/
おもいあg /思い上/
おもy /重/
おもw /思/想;(字義:ある対象に向かいおもう)/念;(字義:心中で深くおもう)/憶;(字義:あれこれとおもう)/
おもu /思/想;(字義:ある対象に向かいおもう)/念;(字義:心中で深くおもう)/憶;(字義:あれこれとおもう)/重/
おもt /思/重/御持/お持/想;(字義:ある対象に向かいおもう)/念;(字義:心中で深くおもう)/憶;(字義:あれこれとおもう)/
おもs /重/
おもr /重/
おもo /思/想;(字義:ある対象に向かいおもう)/念;(字義:心中で深くおもう)/憶;(字義:あれこれとおもう)/
おもn /重/主/
おもm /重/
おもk /重/
おもi /思/重/想;(字義:ある対象に向かいおもう)/念;(字義:心中で深くおもう)/憶;(字義:あれこれとおもう)/
おもh /思/想/
おもg /重/
おもe /思/想;(字義:ある対象に向かいおもう)/念;(字義:心中で深くおもう)/憶;(字義:あれこれとおもう)/
おもd /重/
おもc /思/御持/お持/想;(字義:ある対象に向かいおもう)/念;(字義:心中で深くおもう)/憶;(字義:あれこれとおもう)/
おめざm /お目覚/
おめs /お召/
おめn /御目/
おむかe /お迎/
おみまi /御見舞/
おみのがs /お見逃/
おみとおs /御見通/お見通/
おみうk /お見受/
おみe /お見/
おまわr /お巡/
おまもr /御守/
おまちがi /お間違/
おまちがe /お間違/
おまかs /お任/
おまいr /御参/
おまt /お待/
おまk /御負/
おぼろs /朧/
おぼろn /朧/
おぼろg /朧/
おぼろd /朧/
おぼれじn /溺れ死/
おぼつかなs /覚束無/
おぼつかなk /覚束無/
おぼつかなi /覚束無/
おぼつかなg /覚束無/
おぼしめs /思し召/思召/
おぼえなおs /覚え直/
おぼえこn /覚え込/
おぼえこm /覚え込/
おぼy /覚/
おぼw /憶/
おぼt /覚/
おぼs /思/覚/
おぼr /溺/
おぼe /覚/憶;(特に、記憶) 年号を憶える/覺;「覚」の旧字/
おほm /お褒/
おほh /被/覆/
おぶw /負/
おぶu /負/
おぶt /負/
おぶo /負/
おぶi /負/
おぶe /負/
おぶc /負/
おびやk /脅/
おびただs /夥/
おびきよs /誘き寄/
おびきだs /誘き出/
おびk /誘;古語/
おびi /誘;古語/
おびe /怯/脅/
おひとよs /御人好/
おひさs /御久/お久/
おはらi /お祓/お払/
おはよu /お早/
おはなs /お話/
おのぼr /御上/
おののk /戦/
おののi /戦/
おのずかr /自/
おのずt /自/
おのずk /自/
おのおのn /各/
おのz /自/
おのr /己/
おのg /己;-が(じし)/
おねがi /お願/御願/
おねうt /お値打/
おにあi /お似合/
おなやm /お悩/
おながr /お流/
おなz /同/
おなk /お亡/お泣/
おなj /同/
おなi /同/
おどろきいt /驚き入/
おどろきいr /驚き入/
おどろきいn /驚き入/
おどろきいc /驚き入/
おどろk /驚/愕/駭/
おどろi /驚/愕/駭/
おどりでy /躍り出/
おどりでt /躍り出/
おどりでr /躍り出/
おどりでn /躍り出/
おどりでm /躍り出/
おどりだs /踊り出/
おどりこn /踊り込/
おどりこm /踊り込/
おどりくるw /踊り狂/
おどりくるu /踊り狂/
おどりくるt /踊り狂/
おどりくるo /踊り狂/
おどりくるi /踊り狂/
おどりくるe /踊り狂/
おどりくるc /踊り狂/
おどりかk /躍り掛/
おどりあk /踊り明/
おどしとt /脅し取/
おどしとr /脅し取/
おどしとn /脅し取/
おどしとc /脅し取/
おどt /踊;dance/踴;「踊」の異体字/躍;jump/
おどs /脅/威/縅;(鎧の札を綴る)/
おどr /踊;dance/躍;jump/踴;「踊」の異体字/
おどn /踊;dance/躍;jump/踴;「踊」の異体字/
おどk /脅/戯;-ける/嚇;字義:怒りを見せて恐れさせる/
おどc /踊;dance/躍;jump/踴;「踊」の異体字/
おとろe /衰/
おとりよs /お取り寄/お取寄/
おとりおk /お取り置/
おとなw /訪/
おとなu /訪/
おとなt /訪/
おとなs /大人/音無/
おとなp /大人/
おとなo /訪/
おとなi /訪/
おとなe /訪/
おとなc /訪/
おとどk /御届/お届/
おとだs /音出/
おとずr /訪/
おとしこn /落とし込/
おとしこm /落とし込/
おとしいr /陥/陷;「陥」の旧字(人名用漢字)/
おとしm /貶/
おとこざかr /男盛/
おとこくさs /男臭/
おとこくさk /男臭/
おとこくさi /男臭/
おとこくさg /男臭/
おとこr /男/
おとこp /男/
おとぎr /音切/
おとがm /お咎/
おとおs /お通/
おとあw /音合/
おとz /訪;非正則(おとずr)/
おとt /劣/
おとs /落/
おとr /劣/
おとn /劣/
おとm /お泊/
おとc /劣/
おでむかe /お出迎/
おてもt /お手持/
おてあw /お手合/
おてあg /お手上/御手上/
おつとm /お勤/
おつくr /お作;お作りします/お造;お造り(=刺身)/
おつきあi /お付き合/
おつかr /お疲/
おつかi /お使/
おつうj /お通/
おつs /乙/
おつn /乙/
おつg /御告/
おつd /乙/
おっぴろg /おっ広/
おっぱらw /追っ払/
おっぱらu /追っ払/
おっぱらt /追っ払/
おっぱらo /追っ払/
おっぱらi /追っ払/
おっぱらe /追っ払/
おっぱらc /追っ払/
おっぱじm /おっ始/
おっつk /追っ付/
おっちn /おっ死;‖ナ行五段(-ぬ)/
おったt /押っ立/追っ立/おっ立/
おったc /押っ立/おっ立/
おっしゃt /仰/仰有/
おっしゃr /仰/仰有/
おっしゃn /仰/仰有/
おっしゃi /仰/仰有/
おっしゃc /仰/仰有/
おっかぶs /押っ被/
おっかk /追っ掛/
おっt /追っ;※送り位置補正/
おちぶr /零落/落魄/
おちばたk /落葉焚/
おちのb /落ち延/
おちつきはらw /落ち着き払/
おちつきはらu /落ち着き払/
おちつきはらt /落ち着き払/
おちつきはらo /落ち着き払/
おちつきはらi /落ち着き払/
おちつきはらc /落ち着き払/
おちつk /落ち着/落着/
おちつi /落ち着/落着/
おちこn /落ち込/
おちこm /落ち込/
おちくぼn /落ち窪/
おちくぼm /落ち窪/
おちいt /陥/陷;「陥」の旧字(人名用漢字)/落ち入/落入/
おちいr /陥/落ち入/落入/陷;「陥」の旧字(人名用漢字)/
おちいn /陥/陷;「陥」の旧字(人名用漢字)/落ち入/落入/
おちいc /陥/陷;「陥」の旧字(人名用漢字)/落ち入/落入/
おちあw /落ち合/
おちあu /落ち合/
おちあt /落ち合/
おちあo /落ち合/
おちあi /落ち合/
おちあe /落ち合/
おちあc /落ち合/
おちr /落/堕ち;※送り位置補正/墜ち;※送り位置補正/落ち;※送り位置補正/
おちi /陥;非正則(おちいr)/
おだやk /穏/
おだy /穏/穩;旧字/
おだt /煽/
おだs /お出/
おためs /お試/
おたずn /お尋/
おたすk /お助/
おたけb /雄叫/
おたがi /御互/お互/
おたかs /御高/お高/
おたかk /お高/御高/
おたかi /御高/お高/
おたかg /御高/お高/
おたb /お食/
おぞまs /悍;ぞっとする/鈍;どんくさい/悍ま;※送り位置補正/
おぞけだt /怖気立/
おぞけだc /怖気立/
おぞm /悍;(hideous)「悍ましい事件」/鈍;<rare> dull/
おそろs /恐/
おそろi /お揃/
おそれおののk /恐れ戦/
おそれおののi /恐れ戦/
おそれおおs /畏れ多/恐れ多;NB:「畏れ多い」の方が本義を反映した用字/
おそれおおk /畏れ多/恐れ多;NB:「畏れ多い」の方が本義を反映した用字/
おそれおおi /畏れ多/恐れ多;NB:「畏れ多い」の方が本義を反映した用字/
おそれいt /恐れ入/
おそれいr /恐れ入/
おそれいn /恐れ入/
おそれいc /恐れ入/
おそれr /怐/
おそまk /遅蒔/
おそなe /お供/
おそすg /遅過/
おそざk /遅咲/
おそいこz /襲い来/
おそいこy /襲い来/
おそいこs /襲い来/
おそいこr /襲い来/
おそいこn /襲い来/
おそいこi /襲い来/
おそいくr /襲い来/
おそいくn /襲い来/
おそいきy /襲い来/
おそいきt /襲い来/
おそいきs /襲い来/
おそいきn /襲い来/
おそいきm /襲い来/
おそいきd /襲い来/
おそいきc /襲い来/
おそいかk /襲い掛/
おそw /教/襲/
おそu /襲/
おそt /襲/
おそs /遅/遲;旧字/
おそr /恐/怖;(こわがる)/畏;(敬いおそれる)/虞;(悪いことの起こる可能性) NB:送らぬ方が一般的/懼;びくびくする/惧;「懼」の異体字/
おそo /襲/
おそm /遅/遲;旧字/
おそk /遅/遲;旧字/
おそi /遅/襲/遲;旧字/
おそh /襲/
おそg /遅/遲;旧字/
おそe /襲/
おそc /襲/
おぜんだt /御膳立/
おせe /遅/
おすすm /お勧/
おすm /お住/
おじけづk /怖気付/
おじけづi /怖気付/
おじk /怖/
おしわk /押し分/
おしよs /押し寄/
おしやぶt /押し破/
おしやぶr /押し破/
おしやぶn /押し破/
おしやぶc /押し破/
おしやt /押し遣/
おしやr /押し遣/
おしやn /押し遣/
おしやc /押し遣/
おしもどs /押し戻/
おしみなs /惜しみ無/
おしみなk /惜しみ無/
おしみなi /惜しみ無/
おしまg /押し曲/
おしひろg /押し広/
おしひらk /押し開/
おしひらi /押し開/
おしひしi /押し拉/
おしひしg /押し拉/
おしはらi /お支払/
おしはかt /推し量/
おしはかr /推し量/
おしはかn /推し量/
おしはかc /推し量/
おしのk /押し退/
おしながs /押し流/
おしながk /お品書/
おしなb /押し並/
おしとどm /押し止/
おしとおs /押し通/
おしとm /押し止/
おしてしr /推して知/
おしつまt /押し詰/
おしつまr /押し詰/
おしつまn /押し詰/
おしつまc /押し詰/
おしつぶs /押し潰/圧し潰/
おしつつn /押し包/
おしつつm /押し包/
おしつk /押し付/
おしだまt /押し黙/
おしだまr /押し黙/
おしだまn /押し黙/
おしだまc /押し黙/
おしだs /押し出/
おしたおs /押し倒/
おしたt /押し立/
おしせまt /押し迫/
おしせまr /押し迫/
おしせまn /押し迫/
おしせまc /押し迫/
おしすすm /推し進/押し進/
おしさg /押し下/
おしころs /押し殺/圧し殺/
おしこn /押し込/押込/
おしこm /押し込/押込/
おしきt /押し切/
おしきs /御仕着/
おしきr /押し切/
おしきn /押し切/
おしきc /押し切/
おしかくs /押し隠/
おしかえs /押し返/
おしかr /お叱/
おしかk /押し掛/
おしえさとs /教え諭/
おしえこn /教え込/
おしえこm /教え込/
おしえあw /教え合/
おしえあu /教え合/
おしえあt /教え合/
おしえあo /教え合/
おしえあi /教え合/
おしえあe /教え合/
おしえあc /教え合/
おしうr /押し売/押売/
おしいだk /押し抱/
おしいだi /押し抱/
おしいt /押し入/
おしいr /押し入/
おしいn /押し入/
おしいc /押し入/
おしあわs /お幸/
おしあw /押し合/
おしあu /押し合/
おしあt /押し当/押し合/
おしあo /押し合/
おしあk /押し開/
おしあi /押し合/
おしあg /押し上/
おしあc /押し合/
おしr /御知/お知/
おしg /惜し;※送り位置補正/
おしe /教/
おさわg /お騒/
おさむs /御寒/お寒/
おさむk /御寒/お寒/
おさむi /御寒/お寒/
おさむg /御寒/お寒/
おさなs /幼/稚;NB:「いとけなi」「わかi」と同形/
おさなk /幼/稚;NB:「いとけなi」「わかi」と同形/
おさなi /幼/稚;NB:「いとけなi」「わかi」と同形/
おさなg /稚;NB:「いとけなi」「わかi」と同形/幼/
おさっs /御察/
おさそいあw /お誘い合/
おさえつk /押さえ付/抑え付/押え付/
おさえこn /押さえ込/抑え込/
おさえこm /押さえ込/抑え込/
おさえきt /抑え切/押さえ切/押え切/
おさえきr /抑え切/押さえ切/押え切/
おさえきn /抑え切/押さえ切/押え切/
おさえきc /抑え切/押さえ切/押え切/
おさn /幼/
おさm /収;騒ぎを-,成果を-/納;税を-/治;国を-/修;学業を-/收;「収」の旧字(人名用漢字)/
おさe /抑;(suppress) 怒りを抑える/押;(catch) 現場を押える/圧/壓;「圧」の旧字/
おごりたかb /驕り高/
おごそk /厳/嚴;「厳」の旧字(人名用漢字)/
おごt /奢;食事を奢る/驕;驕る平家/傲/
おごr /奢;食事を奢る/驕;驕る平家/傲/
おごn /奢;食事を奢る/驕;驕る平家/傲/
おごc /奢;食事を奢る/驕;驕る平家/傲/
おこりえz /起こり得/
おこりえy /起こり得/
おこりえt /起こり得/
おこりえs /起こり得/
おこりえr /起こり得/
おこりえn /起こり得/
おこりえm /起こり得/
おこりえc /起こり得/
おこりうr /起こり得/
おこりうb /起こり得/
おこぼr /お零/
おこのm /お好/
おこなw /行/行な;※送り位置補正/
おこなu /行/行な;※送り位置補正/
おこなt /行/
おこなo /行/
おこなi /行/行な;※送り位置補正/
おこなh /行/
おこなe /行/
おこなc /行/
おことわr /お断/
おこたt /怠/
おこたr /怠/
おこたn /怠/
おこたc /怠/
おこt /怒/起/興;(prosper)国が興る/
おこs /興;遺風を興す/起/熾;火を熾す/遣;=よこす/お越/起こ;※送り位置補正/
おこr /怒/興;(prosper)国が興る/起/
おこn /行/怒;[口] -んな/興;(prosper)国が興る/起/
おこg /烏滸;-がましい/痴/
おこc /怒/興;(prosper)国が興る/起/
おけr /於け;※送り位置補正/
おくりむかe /送り迎/
おくりなおs /送り直/
おくりとどk /送り届/
おくりつk /送り付/
おくりだs /送り出/
おくりたおs /送り倒/
おくりこn /送り込/
おくりこm /送り込/
おくりかえs /送り返/
おくゆかs /奥床;当て字/
おくゆk /奥行/
おくぶかs /奥深/
おくぶかk /奥深/
おくぶかi /奥深/
おくぶかg /奥深/
おくふかs /奥深/
おくふかk /奥深/
おくふかi /奥深/
おくふかg /奥深/
おくy /お悔/
おくt /送;(send)/贈;(present) 賞を贈る/
おくs /臆;臆病/奥;-さん/
おくr /送;(send)/贈;(present) 賞を贈る/遅/後;気後れ/遲;「遅」の旧字/
おくn /送;(send)/贈;(present) 賞を贈る/
おくc /送;(send)/贈;(present) 賞を贈る/
おぎなw /補/
おぎなu /補/
おぎなt /補/
おぎなo /補/
おぎなi /補/
おぎなe /補/
おぎなc /補/
おきわたs /沖渡/
おきわすr /置き忘/
おきびk /置き引/
おきぬk /起き抜/
おきにいr /お気に入/
おきなおt /起き直/
おきなおs /起き直/
おきなおr /起き直/
おきなおn /起き直/
おきなおc /起き直/
おきてやぶr /掟破/
おきづk /お気付/
おきだs /起き出/
おきたt /起き立/
おきたc /起き立/
おきざr /置き去/
おきがk /置き掛/
おきかえt /置き換え;※送り位置補正/
おきかえr /置き換え;※送り位置補正/
おきかw /置き換/置き変;?/置き代;?/
おきかe /置き換/置換/
おきあg /起き上/
おきm /お決/
おきk /御聞/お聞/
おがみたおs /拝み倒/
おがn /拝/拜;「拝」の旧字(人名用漢字)/
おがm /拝/拜;「拝」の旧字(人名用漢字)/
おかまi /お構/
おかぼr /岡惚/傍惚/
おかどちがi /御門違/お門違/
おかっぴk /岡っ引/
おかたi /お堅/
おかえs /御返/
おかえr /お帰/
おかいもとm /お買い求/
おかいあg /お買い上/
おかw /お変;お変わりありませんか/お代;ご飯お代わり/
おかs /犯;(violate)法を犯す/侵;(invade)権利を侵す/冒;(risk)危険を冒す/可笑;(当て字,funny)/奇/
おかk /お掛/お書/
おおわらi /大笑/
おおよろこb /大喜/
おおよs /凡/
おおもうk /大儲/
おおもr /大盛/
おおもi /お思/
おおむn /概/
おおみだs /大見出/
おおまわr /大回/
おおまちがi /大間違/
おおまk /大負/
おおまg /大曲/
おおぶr /大振;†「HR狙いの-」「-の器」/大降;†「-の雨」/
おおばんぶるまi /大盤振舞/大盤振る舞/
おおにぎw /大賑/
おおどおr /大通/
おおとのごもr /大殿籠;[文語]お眠り(になる)/
おおづm /大詰/
おおちがi /大違/
おおせつk /仰せ付/
おおすぎt /大過ぎ;※送り位置補正/
おおすg /多過/
おおしe /御教/お教/
おおさわg /大騒/
おおぐi /大食/
おおくr /御送/お送/
おおきすg /大き過/
おおがかr /大掛/
おおがk /大掛/
おおうりだs /大売出/
おおうつs /大写/
おおうk /大受/
おおいつくs /覆い尽/
おおいつk /覆い尽/
おおいそがs /大忙/
おおいそg /大急/
おおいかぶs /覆い被/
おおいかくs /覆い隠/
おおあばr /大暴/
おおあt /大当/
おおあr /大荒/
おおz /大/応;※仮名遣い「おう-ずる」/應;「応」の旧字(人名用漢字)/
おおw /覆/被/蔽/蓋/掩/奄;<rare>/
おおu /覆/被/蔽/蓋/掩/多;(ウ音便)/奄;<rare>/
おおt /覆/被/蔽/蓋/掩/奄;<rare>/
おおs /多/仰/雄々/夛;「多」の異体字/果;言い果せる/
おおr /大/多;-らか <rare>/
おおo /覆/被/蔽/蓋/掩/奄;<rare>/
おおm /多/大/夛;「多」の異体字/
おおk /大/多/夛;「多」の異体字/
おおj /応;※仮名遣い「おうじる」/應;「応」の旧字(人名用漢字)/
おおi /多/大/覆/夛;「多」の異体字/被/蔽/蓋/掩/奄;<rare>/
おおh /被/覆/
おおg /大/多/覆/夛;「多」の異体字/
おおe /覆/被/蔽/蓋/掩/奄;<rare>/
おおc /覆/被/蔽/蓋/掩/奄;<rare>/
おえらi /お偉/
おうぼしゃりまわr /応募者利回/
おうぼくだs /応募下/
おうばんぶるまi /椀飯振舞/椀飯振る舞/
おうこうs /横行/
おうかがi /お伺/
おうz /応/應;「応」の旧字(人名用漢字)/
おうr /お売/
おうj /応/應;「応」の旧字(人名用漢字)/
おいわi /お祝/
おいろなおs /御色直/
おいやt /追い遣/
おいやr /追い遣/
おいやn /追い遣/
おいやc /追い遣/
おいもとm /追い求/
おいまわs /追い回/追回/
おいはらw /追い払/
おいはらu /追い払/
おいはらt /追い払/
おいはらo /追い払/
おいはらi /追い払/
おいはらe /追い払/
おいはらc /追い払/
おいのr /お祈/
おいぬk /追い抜/
おいぬi /追い抜/
おいつづk /追い続/
おいつかw /追い使/
おいつかu /追い使/
おいつかt /追い使/
おいつかo /追い使/
おいつかi /追い使/
おいつかe /追い使/
おいつかc /追い使/
おいつm /追い詰/
おいつk /追い付/
おいつi /追い付/
おいちr /追い散/
おいだs /追い出/追出/
おいたt /生い立;-ち/追い立;-てる/
おいそがs /お忙/
おいすがt /追い縋/
おいすがr /追い縋/
おいすがn /追い縋/
おいすがc /追い縋/
おいしげt /生い茂/
おいしげr /生い茂/
おいしげn /生い茂/
おいしげc /生い茂/
おいこs /追い越/
おいこn /追い込/老い込/追込/
おいこm /追い込/老い込/追込/
おいかけまわs /追い掛け回/
おいかえs /追い返/
おいかr /お怒/
おいかk /追い掛/
おいおとs /追い落/
おいおt /追い落/
おいうt /追い討/追い打/追い撃/
おいあg /追い上/
おいt /於/
おいs /美味/
おいd /お出/
おあずk /お預/
おあi /御会/お会/
おz /怖/
おw /終/追/負/逐;(追放) 政権を逐う/
おu /追/負/生/逐;(追放) 政権を逐う/
おt /落/追/折/負/堕;†corrupt.「堕ちた生活」/墜;†go down.「飛行機が墜ちる」/織/居/墮;「堕」の旧字/逐;(追放) 政権を逐う/
おs /押/惜/推;(recommend) 新人を推す/圧;(圧力を加える) 指で圧す/捺;判子を捺す/壓;「圧」の旧字/
おr /降/下/折/織/居/堕;子供を-/
おp /追/
おo /追/逐;(追放) 政権を逐う/負/
おn /折/織/
おm /怖/追/
おk /起/置/於;於ける/追;追っかける/落;落っこちる/措;扨措く/擱;筆を擱く/大;-っきい/
おj /怖/
おi /追/負/老/置/於;於ける/生/措;「除外する」の意の時の「おく」/逐;(追放) 政権を逐う/
おh /負/追/生/
おe /終/負/追/逐;(追放) 政権を逐う/
おd /怖/
おc /落/堕/墜/追/負/逐;(追放) 政権を逐う/折/織/
おb /帯/帶;「帯」の旧字(人名用漢字)/
えんりょぶかs /遠慮深/
えんりょぶかk /遠慮深/
えんりょぶかi /遠慮深/
えんりょぶかg /遠慮深/
えんりょくだs /遠慮下/
えんむすb /縁結/
えんばらi /円払/
えんどおs /縁遠/
えんどおk /縁遠/
えんどおi /縁遠/
えんどおg /縁遠/
えんだt /円建/
えんじわk /演じ分/
えんじきt /演じ切/
えんじきr /演じ切/
えんじきn /演じ切/
えんじきc /演じ切/
えんきr /縁切/
えんz /演/
えんj /演/
えろs /エロ/
えろk /エロ/
えろi /エロ/
えろg /エロ/
えりわk /選り分/
えりぬk /選り抜/
えりぬi /選り抜/
えりごのm /選り好/
えりぐr /襟刳/
えらびぬk /選び抜/
えらびぬi /選び抜/
えらびとr /選び取/
えらびだs /選び出/
えらs /偉/
えらn /選/択;(字義:手に取ってえらぶ)/撰;(歌集を)-ぶ/
えらk /偉/
えらi /偉/
えらg /偉/
えらb /選/撰;(歌集を)-ぶ/択;(字義:手に取ってえらぶ)/偉;-ぶる/
えびぞt /海老反/
えびぞr /海老反/
えびぞn /海老反/
えびぞc /海老反/
えびがたm /海老固/
えとk /絵解/
えづk /餌付/
えつk /絵付/
えだわかr /枝分/
えだわk /枝分/
えだぶr /枝振/
えだがr /枝刈/
えだかr /枝刈/
えぐりだs /抉り出/
えぐt /抉/刔;<rare> =抉る/
えぐr /抉/刔;<rare> =抉る/
えぐn /抉/刔;<rare> =抉る/
えぐk /刳/
えぐi /刳/
えぐc /抉/刔;<rare> =抉る/
えきうr /駅売/
えきs /益/
えがたs /得難/
えがたk /得難/
えがたi /得難/
えがたg /得難/
えがきつづk /描き続/
えがきだs /描き出/
えがききt /描き切/
えがききr /描き切/
えがききn /描き切/
えがききc /描き切/
えがk /描/
えがi /描/
えかk /絵描/
えいz /映/詠/
えいr /絵入/
えいj /映/詠/
えz /得/獲;NB:「とr」と同形/
えy /得/獲;NB:「とr」と同形/
えt /得/獲;NB:「とr」と同形/選;NB:「よr」「すぐr」と同形/
えs /得/獲;NB:「とr」と同形/
えr /得/獲;NB:「とr」と同形/選;NB:「よr」「すぐr」と同形/
えn /得/笑/獲;NB:「とr」と同形/選;NB:「よr」「すぐr」と同形/
えm /笑/得/獲;NB:「とr」と同形/
えk /得/獲;NB:「とr」と同形/
えc /得/獲;NB:「とr」と同形/選;NB:「よr」「すぐr」と同形/
うんわるs /運悪/
うんわるk /運悪/
うんわるi /運悪/
うんわるg /運悪/
うんよk /運良/
うんめいづk /運命付/
うんだめs /運試/
うわむk /上向/
うわむi /上向/
うわまわt /上回/
うわまわr /上回/
うわまわn /上回/
うわまわc /上回/
うわばk /上履/
うわのs /上乗/
うわのr /上乗/
うわぬr /上塗/
うわてひねr /上手捻/
うわてなg /上手投/
うわてだしなg /上手出し投/
うわづm /上積/
うわずt /上擦/
うわずr /上擦/
うわずn /上擦/
うわずm /上澄/
うわずc /上擦/
うわすべr /上滑/
うわさどおr /噂通/
うわさs /噂/
うわがk /上書/
うわかk /上書;?/
うわz /上/
うわt /浮/
うわm /上/
うろたe /狼狽/
うろおぼe /うろ覚/空覚/疎覚/
うれゆk /売行/
うれのこt /売れ残/
うれのこr /売れ残/
うれのこn /売れ残/
うれのこc /売れ残/
うれしがなs /嬉し悲/
うれえr /慯/
うれu /憂/愁/患;NB:「わずらu」と同形/
うれs /嬉/
うれi /憂;(worry)/愁;(sorrow)/患;NB:「わずらi」と同形/
うれe /憂/愁/患;NB:「わずらu」と同形/
うるわs /麗/美/愛/
うるさs /煩/五月蝿/騒/
うるさk /煩/五月蝿/騒/
うるさi /煩/五月蝿/騒/
うるさg /煩/五月蝿/騒/
うるおw /潤/
うるおu /潤/
うるおt /潤/
うるおs /潤/
うるおo /潤/
うるおi /潤/
うるおe /潤/
うるおc /潤/
うるn /潤/
うるm /潤/
うりわたs /売り渡/売渡/
うりはらw /売り払/
うりはらu /売り払/
うりはらt /売り払/
うりはらo /売り払/
うりはらi /売り払/
うりはらe /売り払/
うりはらc /売り払/
うりぬk /売り抜/
うりとb /売り飛/
うりつづk /売り続/
うりつくs /売り尽/
うりつk /売り付/
うりだs /売り出/売出/
うりしぶt /売り渋/
うりしぶr /売り渋/
うりしぶn /売り渋/
うりしぶc /売り渋/
うりさばk /売り捌/
うりさばi /売り捌/
うりこs /売り越/
うりこn /売り込/
うりこm /売り込/
うりきt /売り切/
うりきr /売り切/
うりきn /売り切/
うりきc /売り切/
うりかi /売り買/
うりおs /売り惜/売惜/
うりいそi /売り急/
うりいそg /売り急/
うりあるk /売り歩/
うりあるi /売り歩/
うりあg /売り上/売上/
うりあb /売り浴/
うらわかs /うら若/
うらわかk /うら若/
うらわかi /うら若/
うらわかg /うら若/
うらやまs /羨/
うらやn /羨/
うらやm /羨/
うらなw /占/卜/
うらなu /占/卜/
うらなt /占/卜/
うらなo /占/卜/
うらなk /心泣/
うらなi /占/卜/
うらなg /裏投/
うらなe /占/卜/
うらなc /占/卜/
うらどおr /裏通/
うらどr /裏取/
うらづk /裏付/
うらさびs /心淋/心寂/
うらごs /裏漉/
うらぎt /裏切/
うらぎr /裏切/
うらぎn /裏切/
うらぎc /裏切/
うらがなs /心悲/
うらがえt /裏返;声が-/
うらがえs /裏返/
うらがえr /裏返;声が-/
うらがえn /裏返;声が-/
うらがえc /裏返;声が-/
うらがk /裏書/
うらかえs /裏返/
うらうt /裏打/
うらうc /裏打/
うらあm /裏編/
うらr /麗/
うらn /恨;(字義:心に傷を残す)/怨;(字義:押さえ付けられ鬱屈する)/憾;(遺憾・残念)「繁雑になる憾みがある」/
うらm /恨;(字義:心に傷を残す)/怨;(字義:押さえ付けられ鬱屈する)/憾;(遺憾・残念)「繁雑になる憾みがある」/
うらd /裏/
うやまw /敬/
うやまu /敬/
うやまt /敬/
うやまo /敬/
うやまi /敬/
うやまe /敬/
うやまc /敬/
うやうやs /恭/
うめもどs /埋め戻/
うめつくs /埋め尽/
うめつk /埋め尽/
うめたt /埋め立/
うめこn /埋め込/埋込/
うめこm /埋め込/埋込/
うめあわs /埋め合/
うめあw /埋め合/
うめk /呻/
うめi /呻/
うみわk /産み分/
うみづr /海釣/
うみつk /産み付/
うみだs /生み出/産み出/
うみそだt /産み育/
うみおとs /産み落/生み落/
うみおt /産み落/生み落/
うまれもt /生まれ持/
うまれつk /生まれ付/
うまれつi /生まれ付/
うまれそだt /生まれ育/生れ育/
うまれかわt /生れ変/
うまれかわr /生れ変/
うまれかわn /生れ変/
うまれかわc /生れ変/
うまれかw /生まれ変/
うまれおt /生まれ落/
うまれおc /生まれ落/
うまれあわs /生まれ合/
うまれあw /生まれ合/
うまのr /馬乗/
うまs /旨;(字義:こってりとしたうまみ)/巧;(字義:手の込んだ細工)/美味/上手/美;美し国/甘;NB:「あまi」と同形/
うまr /生/
うまm /旨;(字義:こってりとしたうまみ)/美味/甘;NB:「あまi」と同形/美/
うまk /上手/旨;(字義:こってりとしたうまみ)/巧;(字義:手の込んだ細工)/美味/甘;NB:「あまi」と同形/美/
うまi /上手/旨;(字義:こってりとしたうまみ)/美味/巧;(字義:手の込んだ細工)/甘;NB:「あまi」と同形/美/
うまg /上手/旨;(字義:こってりとしたうまみ)/美味/巧;(字義:手の込んだ細工)/甘;NB:「あまi」と同形/美/
うべなw /諾/
うべなu /諾/
うべなt /諾/
うべなo /諾/
うべなi /諾/
うべなe /諾/
うべなc /諾/
うぶs /初/
うぶn /初/
うぶd /初/
うばいとt /奪い取/
うばいとr /奪い取/
うばいとn /奪い取/
うばいとc /奪い取/
うばいつk /奪い尽/
うばいさt /奪い去/
うばいさr /奪い去/
うばいさn /奪い去/
うばいさc /奪い去/
うばいかえs /奪い返/
うばいあw /奪い合/
うばいあu /奪い合/
うばいあt /奪い合/
うばいあo /奪い合/
うばいあi /奪い合/
うばいあe /奪い合/
うばいあc /奪い合/
うばw /奪/
うばu /奪/
うばt /奪/
うばo /奪/
うばi /奪/
うばe /奪/
うばc /奪/
うのm /鵜呑/鵜飲;?/
うぬぼr /自惚/己惚/
うなだr /項垂/
うなずきかえs /頷き返/
うなずきあw /頷き合/
うなずきあu /頷き合/
うなずきあt /頷き合/
うなずきあo /頷き合/
うなずきあi /頷き合/
うなずきあe /頷き合/
うなずきあc /頷き合/
うなずk /頷/
うなずi /頷/
うながs /促/
うなt /唸/
うなs /魘/
うなr /唸/
うなn /唸/
うなc /唸/
うとs /疎/踈;異体字/
うとn /疎/
うとm /疎/
うとk /疎/踈;異体字/
うとi /疎/踈;異体字/
うとg /疎/踈;異体字/
うでだめs /腕試/
うでたてふs /腕立て伏/
うでぐm /腕組/
うできk /腕利/
うでがたm /腕固/
うでおs /腕押/
うつりゆk /移り行/
うつりこn /写り込;写真に写り込む/映り込;画面に映り込む/
うつりこm /映り込;画面に映り込む/写り込;写真に写り込む/
うつりかわt /移り変/
うつりかわr /移り変/
うつりかわn /移り変/
うつりかわc /移り変/
うつりかw /移り変/
うつむk /俯/
うつむi /俯/
うつぶs /俯/うつ伏/
うつしとt /写し取/
うつしとr /写し取/
うつしとn /写し取/
うつしとc /写し取/
うつしだs /映し出/写し出/
うつしこn /写し込/
うつしこm /写し込/
うつくs /美/
うつt /移/写;写真に写る/映;鏡に映る/遷;都が遷る/冩;「写」の旧字1/寫;「写」の旧字2/暎;「映」の異体字/伝染;(当て字) 風邪が伝染る/
うつs /移/写;(本|写真)を写す/映;鏡に映す/寫;「写」の旧字1/冩;「写」の旧字2/暎;「映」の異体字/鬱/
うつr /移/映;鏡に映る/写;写真に写る/虚;-ろ (名詞)/空;≒虚ろ/伝染;(当て字) 風邪が伝染る/遷;都が遷る/寫;「写」の旧字1/冩;「写」の旧字2/暎;「映」の異体字/
うつn /移/映;鏡に映る/写;写真に写る/伝染;(当て字) 風邪が伝染る/遷;都が遷る/寫;「写」の旧字1/冩;「写」の旧字2/暎;「映」の異体字/鬱/
うつk /虚;-け/空;-け(者)/
うつd /鬱/
うつc /移/映;鏡に映る/写;写真に写る/伝染;(当て字) 風邪が伝染る/遷;都が遷る/寫;「写」の旧字1/冩;「写」の旧字2/暎;「映」の異体字/
うっとうs /鬱陶/欝陶;「鬱」異体字/
うってでz /打って出/
うってでy /打って出/
うってでt /打って出/
うってでs /打って出/
うってでr /打って出/
うってでn /打って出/
うってでm /打って出/
うってでk /打って出/
うってでc /打って出/
うってかわt /打って変/
うってかわr /打って変/
うってかわn /打って変/
うってかわc /打って変/
うっちゃt /打っ棄/打っ遣/
うっちゃr /打っ棄/打っ遣/
うっちゃn /打っ棄/打っ遣/
うっちゃc /打っ棄/打っ遣/
うったえかk /訴え掛/
うったe /訴/
うっすr /薄/
うちわもm /内輪揉/
うちわたs /内渡/
うちよs /打ち寄/
うちやぶt /打ち破/討ち破/
うちやぶr /打ち破/討ち破/
うちやぶn /打ち破/討ち破/
うちやぶc /打ち破/討ち破/
うちもr /討ち漏/
うちまわr /内回/
うちまちがi /打ち間違/
うちまちがe /打ち間違/
うちまk /打ち負/
うちほろb /討ち滅/
うちふt /打ち振/
うちふr /打ち振/
うちふn /打ち振/
うちふc /打ち振/
うちひしi /打ち拉/
うちひしg /打ち拉/
うちはらw /打ち払/
うちはらu /打ち払/
うちはらt /打ち払/
うちはらo /打ち払/
うちはらi /打ち払/
うちはらe /打ち払/
うちはらc /打ち払/
うちはなs /打ち放/
うちはたs /討ち果/
うちはt /討ち果/
うちぬk /打ち抜/撃ち抜/打抜/
うちぬi /打ち抜/撃ち抜/打抜/
うちながm /打ち眺/
うちなおs /打ち直/
うちなr /打ち鳴/
うちどm /打ち止/打止/
うちとおs /打ち通/
うちとt /打ち取/討ち取/
うちとr /打ち取/討ち取/
うちとn /打ち取/討ち取/
うちとk /打ち解/
うちとc /打ち取/討ち取/
うちつづk /打ち続/
うちつk /打ち付/
うちっぱなs /打ちっ放;-しのコンクリ壁/
うちだs /打ち出/
うちたおs /打ち倒/
うちたt /打ち立/
うちそんj /打ち損/
うちすt /打ち捨/
うちじn /討ち死/
うちさわi /打ち騒/
うちさわg /打ち騒/
うちこわs /打ち壊/
うちころs /打ち殺/
うちこn /打ち込/撃ち込;銃弾を-む/打込/
うちこm /打ち込/撃ち込;銃弾を-む/打込/
うちけs /打ち消/打消/
うちくだk /打ち砕/
うちくだi /打ち砕/
うちくずs /打ち崩/
うちきょうz /打ち興/
うちきょうj /打ち興/
うちきt /打ち切/打切/
うちきr /打ち切/打切/
うちきn /打ち切/打切/
うちきc /打ち切/打切/
うちがk /内掛/
うちかえs /打ち返/
うちかt /打ち勝/打ち克/
うちかr /打ち枯/
うちかk /打ち掛/打掛/打ち欠/
うちかi /打ち欠/
うちかc /打ち勝/打ち克/
うちおとs /打ち落/撃ち落/
うちおt /打ち落/撃ち落/
うちおr /打ち下/
うちいt /討ち入/
うちいr /討ち入/
うちいn /討ち入/
うちいc /討ち入/
うちあわs /打合/打ち合/
うちあw /打ち合/打合/撃ち合/
うちあu /打ち合/撃ち合/
うちあt /打ち合/撃ち合/
うちあo /打ち合/撃ち合/
うちあk /打ち明/
うちあi /撃ち合/打ち合/
うちあg /打ち上/打上/
うちあe /打ち合/撃ち合/
うちあc /打ち合/撃ち合/
うたれづよs /打たれ強/
うたれづよk /打たれ強/
うたれづよi /打たれ強/
うたれづよg /打たれ強/
うたぐりぶかs /疑り深/
うたぐりぶかk /疑り深/
うたぐりぶかi /疑り深/
うたぐりぶかg /疑り深/
うたぐt /疑/
うたぐr /疑/
うたぐn /疑/
うたぐc /疑/
うたがいなs /疑い無/
うたがいなk /疑い無/
うたがいなi /疑い無/
うたがw /疑/
うたがu /疑/
うたがt /疑/
うたがo /疑/
うたがi /疑/
うたがe /疑/
うたがc /疑/
うたいはじm /歌い始/
うたいつづk /歌い続/
うたいだs /歌い出/
うたいあk /歌い明/
うたいあg /歌い上/謳い上/
うたw /歌/唄;(気軽にうたう)/謳;(主張する) 高性能を謳う/謡;(無伴奏でうたう)/唱;(はっきりとうたう)/謠;「謡」の旧字(人名用漢字)/謌;「歌」の異体字/詠;和歌を詠う/
うたu /歌/唄;(気軽にうたう)/謳;(主張する) 高性能を謳う/詠;和歌を詠う/唱;(はっきりとうたう)/謡;(無伴奏でうたう)/謠;「謡」の旧字(人名用漢字)/謌;「歌」の異体字/
うたt /歌/唄;(気軽にうたう)/謳;(主張する) 高性能を謳う/謡;(無伴奏でうたう)/唱;(はっきりとうたう)/謌;「歌」の異体字/詠/謠;「謡」の旧字(人名用漢字)/
うたo /歌/唄;(気軽にうたう)/謳;(主張する) 高性能を謳う/謡;(無伴奏でうたう)/唱;(はっきりとうたう)/謠;「謡」の旧字(人名用漢字)/謌;「歌」の異体字/詠;和歌を詠う/
うたi /歌/謳;(主張する) 高性能を謳う/唄;(気軽にうたう)/謡;(無伴奏でうたう)/謌;「歌」の異体字/唱;(はっきりとうたう)/謠;「謡」の旧字(人名用漢字)/詠;和歌を詠う/
うたe /歌/唄;(気軽にうたう)/謡;(無伴奏でうたう)/謌;「歌」の異体字/唱;(はっきりとうたう)/謳;(主張する) 高性能を謳う/謠;「謡」の旧字(人名用漢字)/詠;和歌を詠う/
うたc /歌/唄;(気軽にうたう)/謳;(主張する) 高性能を謳う/唱;(はっきりとうたう)/謡;(無伴奏でうたう)/謠;「謡」の旧字(人名用漢字)/謌;「歌」の異体字/詠;和歌を詠う/
うそぶk /嘯/
うそぶi /嘯/
うそくさs /嘘臭/
うそくさk /嘘臭/
うそくさi /嘘臭/
うそくさg /嘘臭/
うせつまt /右折待/
うせつまc /右折待/
うずまk /渦巻/
うずまi /渦巻/
うずたかs /堆/
うずたかk /堆/
うずたかi /堆/
うずたかg /堆/
うずくまt /蹲/踞/
うずくまr /蹲/踞/
うずくまn /蹲/踞/
うずくまc /蹲/踞/
うずくm /蹲/
うずm /埋;NB:「うm」と同形/
うずk /疼/
うずi /疼/
うすわらi /薄笑/
うすらさむs /薄ら寒/
うすらさむk /薄ら寒/
うすらさむi /薄ら寒/
うすらさむg /薄ら寒/
うすよごr /薄汚/
うすすg /薄過/
うすぐらs /薄暗/
うすぐらk /薄暗/
うすぐらi /薄暗/
うすぐらg /薄暗/
うすくらg /薄暗/
うすぎたなs /薄汚/
うすぎたなk /薄汚/
うすぎたなi /薄汚/
うすぎたなg /薄汚/
うすぎr /薄切/
うすきみわるs /薄気味悪/
うすきみわるk /薄気味悪/
うすきみわるi /薄気味悪/
うすきみわるg /薄気味悪/
うすあきなi /薄商/
うすあおs /薄青/
うすあおm /薄青/
うすあおk /薄青/
うすあおi /薄青/
うすあおg /薄青/
うすs /薄/
うすr /薄/
うすp /薄/
うすm /薄/
うすk /薄/
うすi /薄/
うすg /薄/
うしろむk /後ろ向/後向/
うしろづk /後ろ付/
うしろぐらs /後ろ暗/
うしろぐらk /後ろ暗/
うしろぐらi /後ろ暗/
うしろぐらg /後ろ暗/
うしみt /丑三/
うしなw /失/喪;(字義:人の死を悼んで泣く)「父を喪う」/
うしなu /失/喪;(字義:人の死を悼んで泣く)「父を喪う」/
うしなt /失/喪;(字義:人の死を悼んで泣く)「父を喪う」/
うしなo /失/喪;(字義:人の死を悼んで泣く)「父を喪う」/
うしなi /失/喪;(字義:人の死を悼んで泣く)「父を喪う」/
うしなe /失/喪;(字義:人の死を悼んで泣く)「父を喪う」/
うしなc /失/喪;(字義:人の死を悼んで泣く)「父を喪う」/
うしおi /牛追/
うしr /後/
うしn /失;非正則(うしなu)/
うざs /ウザ/
うざk /ウザ/
うざi /ウザ/
うざg /ウザ/
うさんくさs /胡散臭/
うさんくさk /胡散臭/
うさんくさi /胡散臭/
うさんくさg /胡散臭/
うごめk /蠢/蠕;<rare> ≒蠢く/
うごめi /蠢/蠕;<rare> ≒蠢く/
うごきまわt /動き回/
うごきまわr /動き回/
うごきまわn /動き回/
うごきまわc /動き回/
うごきはじm /動き始/
うごきだs /動き出/
うごk /動/
うごi /動/
うけわたs /受け渡/受渡/
うけもどs /受け戻/
うけもt /受け持/受持/
うけもc /受け持/
うけながs /受け流/
うけとt /受け取/受取/
うけとr /受け取/受取/
うけとn /受け取/受取/
うけとm /受け止/
うけとc /受け取/受取/
うけつk /受け付/受付/
うけつi /受け継/受継/
うけつg /受け継/受継/
うけたまわt /承/
うけたまわr /承/
うけたまわn /承/
うけたまわc /承/
うけたまw /受け賜;NB:語源に忠実な表記。通常は「承る」/
うけこたe /受け答/
うけがw /肯/
うけがu /肯/
うけがt /肯/
うけがo /肯/
うけがi /肯/
うけがe /肯/
うけがc /肯/
うけおw /請け負/請負/
うけおu /請け負/請負/
うけおt /請け負/請負/
うけおo /請け負/請負/
うけおi /請け負/請負/
うけおe /請け負/請負/
うけおc /請け負/請負/
うけうr /受け売/受売/請け売/請売/
うけいr /受け入/受入/受け容/
うけあw /請け合/受け合/
うけあu /請け合/受け合/
うけあt /請け合/受け合/
うけあo /請け合/受け合/
うけあi /請け合/請合/受け合/
うけあe /請け合/受け合/
うけあc /請け合/受け合/
うきぼr /浮き彫/
うきでz /浮き出/
うきでy /浮き出/
うきでt /浮き出/
うきでs /浮き出/
うきでr /浮き出/
うきでn /浮き出/
うきでm /浮き出/
うきでk /浮き出/
うきでc /浮き出/
うきだs /浮き出/
うきたt /浮き立/
うきたc /浮き立/
うきしずm /浮き沈/
うきがs /浮貸/
うきうk /浮き浮/
うきあしだt /浮き足立/浮足立/
うきあしだc /浮き足立/浮足立/
うきあg /浮き上/
うがちすg /穿ち過/
うがいs /嗽/
うがt /穿/鑿/
うがc /穿/鑿/
うかれさわi /浮かれ騒/
うかれさわg /浮かれ騒/
うかびでy /浮かび出/
うかびでt /浮かび出/
うかびでs /浮かび出/
うかびでr /浮かび出/
うかびでn /浮かび出/
うかびでm /浮かび出/
うかびあg /浮かび上/
うかがいしt /窺い知/
うかがいしr /窺い知/
うかがいしn /窺い知/
うかがいしc /窺い知/
うかがw /伺;用件を伺う/窺;様子を窺う (字義:のぞいて見る)/覘;(字義:じっと見る)/
うかがu /伺;用件を伺う/窺;様子を窺う (字義:のぞいて見る)/覘;(字義:じっと見る)/
うかがt /伺;用件を伺う/窺;様子を窺う (字義:のぞいて見る)/覘;(字義:じっと見る)/
うかがo /伺;用件を伺う/窺;様子を窺う (字義:のぞいて見る)/覘;(字義:じっと見る)/
うかがi /伺;用件を伺う/窺;様子を窺う (字義:のぞいて見る)/覘;(字義:じっと見る)/
うかがe /伺;用件を伺う/窺;様子を窺う (字義:のぞいて見る)/覘;(字義:じっと見る)/
うかがc /伺;用件を伺う/窺;様子を窺う (字義:のぞいて見る)/覘;(字義:じっと見る)/
うかt /合格;当て字/
うかr /合格;当て字/浮か;※送り位置補正/
うかn /浮/合格;当て字/
うかc /合格;当て字/
うかb /浮/
うおつr /魚釣/
うえよs /上寄/
うえつk /植え付/上付/植付/
うえこn /植え込/植込/
うえこm /植え込/植込/
うえd /上/
ういろううr /外郎売/
ういういs /初々/
うz /埋/
うw /植/
うt /打/撃;(fire) 銃を撃つ/討;(kill) 仇を討つ/売/射;≒撃つ/撲;(punch) 頬を撲つ/搏;脈搏つ/攵/攴/賣;「売」の旧字(人名用漢字)/
うs /失/憂/
うr /売/熟/得/賣;「売」の旧字(人名用漢字)/
うn /生/産;子供を産む/膿;傷が膿む/売/賣;「売」の旧字(人名用漢字)/倦;人生に倦む/績/
うm /埋/生/産;子供を産む/倦;人生に倦む/膿;傷が膿む/績/
うk /受/浮/請;請け負う/憂/承;伝統を承ける/享;生を享ける/泛;≒浮/
うi /浮/憂/泛;≒浮/
うg /憂/
うe /植/飢/
うd /茹/
うc /打/討;(kill) 仇を討つ/撃;(fire) 銃を撃つ/売/射;≒撃つ/撲;(punch) 頬を撲つ/搏;脈搏つ/攵/攴/賣;「売」の旧字(人名用漢字)/
うb /得/
いんしょうぶかs /印象深/
いんしょうぶかk /印象深/
いんしょうぶかi /印象深/
いんしょうぶかg /印象深/
いんしょうづk /印象付/
いんきくさs /陰気臭/
いんきくさk /陰気臭/
いんきくさi /陰気臭/
いんきくさg /陰気臭/
いんs /因/飲/淫/
いんn /陰/
いわばしr /石走;滝、垂水、近江にかかる枕詞。「-る垂水の上のさわらびの」/
いわw /祝/
いわu /祝/
いわt /祝/
いわr /謂/
いわo /祝/
いわk /曰/
いわi /祝/
いわe /祝/
いわc /祝/
いわb /言わ;※送り位置補正/
いろわk /色分/
いろよi /色好/
いろめきたt /色めき立/
いろめきたc /色めき立/
いろどt /彩/
いろどr /彩/色取/
いろどn /彩/
いろどc /彩/
いろづかi /色使/
いろづk /色付/
いろづi /色付/
いろちがi /色違/
いろだs /色出/
いろこs /色濃/
いろこk /色濃/
いろこi /色濃/
いろけづk /色気付/
いろけづi /色気付/
いろおt /色落/
いろあわs /色合/
いろあw /色合/
いろあs /色褪/
いろあi /色合/
いろp /色/
いろn /色/
いろm /色;色めく/
いれわすr /入れ忘/
いれまz /入れ混/
いれなおs /入れ直/
いれちがw /入れ違/
いれちがu /入れ違/
いれちがt /入れ違/
いれちがo /入れ違/
いれちがi /入れ違/
いれちがc /入れ違/
いれたt /入れ立/
いれこn /入れ込/
いれこm /入れ込/
いれぐi /入れ食/
いれかw /入れ替/入れ換/
いれかe /入れ替/入れ換/
いれあg /入れ揚/
いりみだr /入り乱/
いりまj /入り交/
いりびたt /入り浸/
いりびたr /入り浸/
いりびたn /入り浸/
いりびたc /入り浸/
いりつk /煎り付/炒り付/
いりたt /入り立/
いりたc /入り立/
いりこn /入り込/
いりこm /入り込/
いりくn /入り組/
いりくm /入り組/
いらだt /苛立/
いらだc /苛立/
いらいらしi /苛苛し;※送り位置補正/
いらw /弄/苛/綺/
いらu /弄/苛/綺/
いらt /苛/弄/綺/
いらs /貸;古語/
いらo /弄/苛/綺/
いらi /弄/苛/綺/
いらh /苛/弄/
いらe /応/答/弄/苛/綺/
いらd /苛/
いらc /弄/苛/綺/
いやまs /弥増/いや増/
いやしくm /苟/
いやしm /卑し;※送り位置補正/
いやおうなs /否応無/
いやおうなk /否応無/
いやおうなi /否応無/
いやs /癒/卑/賤;<esp.身分が低い>/医;(字義:「癒」はなおること、「医」はなおすこと)/嫌/厭/
いやr /嫌/
いやn /嫌/厭/
いやm /厭/
いやg /嫌/
いやd /嫌/厭/
いもほr /芋掘/藷掘/
いもはg /芋接/
いもつg /芋継/
いもざs /芋刺/
いみぶかs /意味深/
いみぶかk /意味深/
いみぶかi /意味深/
いみぶかg /意味深/
いみづk /意味付/
いみきらw /忌み嫌/
いみきらu /忌み嫌/
いみきらt /忌み嫌/
いみきらo /忌み嫌/
いみきらi /忌み嫌/
いみきらe /忌み嫌/
いみきらc /忌み嫌/
いみあi /意味合/
いみs /意味/
いまわs /忌/
いまひとt /今一/
いましばらk /今暫/
いましm /戒/縛;ロープで縛る/誡;(≒戒) 注意を与える/警;警戒・用心する/
いまいまs /忌々/
いまy /今/
いまs /今/在/坐;≒在す/
いまn /今/
いまd /未/
いぶりだs /燻り出/
いぶかt /訝/
いぶかs /訝/
いぶかr /訝/
いぶかn /訝/
いぶかc /訝/
いぶt /燻/
いぶs /燻/
いぶr /燻/
いぶn /燻/
いぶk /息吹/気吹;=息吹き/
いぶi /息吹/気吹;=息吹き/
いぶc /燻/
いびつs /歪/
いびつn /歪/
いびつd /歪/
いばt /威張/
いばr /威張/
いばn /威張/
いばc /威張/
いのちもe /命燃/
いのちびろi /命拾/
いのちとr /命取/
いのちごi /命乞/
いのちがk /命懸/
いのこt /居残/
いのこr /居残/
いのこn /居残/
いのこc /居残/
いのt /祈/
いのr /祈/
いのn /祈/
いのc /祈/
いねむr /居眠/
いねかr /稲刈/
いぬじn /犬死/
いぬk /居抜;居抜き物件/射貫;矢で射貫く/
いぬi /居抜;居抜き物件/射貫;矢で射貫く/
いならn /居並/
いならb /居並/
いななk /嘶/
いななi /嘶/
いなかじm /田舎染/
いなかくさs /田舎臭/
いなかくさk /田舎臭/
いなかくさi /田舎臭/
いなかくさg /田舎臭/
いなおt /居直/
いなおr /居直/
いなおn /居直/
いなおc /居直/
いなy /否/
いなn /否/
いなm /否/
いなk /否/
いどn /挑/
いどm /挑/
いとなn /営/營;旧字/
いとなm /営/營;旧字/
いとけなs /稚/幼/
いとけなk /稚/幼/
いとけなi /稚/幼/
いとけなg /稚/幼/
いとw /厭/
いとu /厭/
いとt /厭/
いとs /愛/
いとo /愛/厭/
いとm /射止/
いとk /幼/
いとi /厭/
いとe /厭/
いとc /厭/
いでたt /出で立/
いてつk /凍て付/凍てつ;※送り位置補正/
いてつi /凍て付/
いづらs /居辛/
いづらk /居辛/
いづらi /居辛/
いづらg /居辛/
いつわt /偽/僞;「偽」の旧字(人名用漢字)/
いつわr /偽/僞;「偽」の旧字(人名用漢字)/
いつわn /偽/僞;「偽」の旧字(人名用漢字)/
いつわc /偽/僞;「偽」の旧字(人名用漢字)/
いつのまn /何時の間;-に/
いつづk /居続/
いつくしn /慈/
いつくしm /慈/
いつくs /慈/
いつz /何時/
いつt /五/
いつm /何時/
いつk /居着/何時/
いつi /居着/
いっぽんだt /一本立/
いっぱんn /一般/
いってんばr /一点張/
いってこz /行って来/
いってこy /行って来/
いってこs /行って来/
いってこr /行って来/
いってこn /行って来/
いってこi /行って来/
いってくr /行って来/
いってくn /行って来/
いってきy /行って来/
いってきt /行って来/
いってきs /行って来/
いってきn /行って来/
いってきm /行って来/
いってきk /言って聞/
いってきd /行って来/
いってきc /行って来/
いっそうs /一掃/
いっせいn /一斉/
いっしょn /一緒/
いっしむくi /一矢報/
いっこだt /一戸建/
いっきよm /一気読/
いっきn /一気/
いっかつs /一括/
いっs /逸/
いちりんざs /一輪挿/
いちやづk /一夜漬/
いちもんなs /一文無/
いちもくおk /一目置/
いちもくおi /一目置/
いちはやs /逸速;(文語) -し/逸早;(文語) -し/いち速/いち早/一早/一速/
いちはやk /一早/逸早/逸速/いち速/いち早/一速/
いちはやi /いち速/いち早/一早/逸早/一速/逸速/
いちとr /位置取/
いちづk /位置付/
いちずk /位置付;※仮名遣い「いちづk」/
いちじるs /著/
いちぎm /位置決/
いちがいn /一概/
いちおs /一押/
いちs /位置/
いだk /抱/懐;恋慕の情を-く/
いだi /抱/懐;恋慕の情を-く/
いたわt /労/
いたわs /労;そいつはお-しい/
いたわr /労/
いたわn /労/
いたわc /労/
いためつk /痛め付/
いたみどm /痛み止/
いたみいt /痛み入/
いたみいr /痛み入/
いたみいn /痛み入/
いたみいc /痛み入/
いたぶt /甚振/
いたぶr /甚振/
いたぶn /甚振/
いたぶc /甚振/
いたばさm /板挟/
いただk /頂/戴/
いただi /頂/戴/
いたずらn /徒;vain.「徒な出費」/
いたすg /痛過/
いたしかゆs /痛し痒/
いたがゆs /痛痒/
いたがゆk /痛痒/
いたがゆi /痛痒/
いたがゆg /痛痒/
いたいたs /痛々/
いたw /労/
いたt /至/到;≒至る/致;<rare>/
いたs /致/痛/イタ/
いたr /至/到;≒至る/致;<rare>/
いたn /痛;頭を痛める/傷;筋を傷める,野菜が傷む/悼;死を悼む/至/到;≒至る/致;<rare>/愴;≒悼む/慯;≒悼む,≠傷む/
いたm /痛;頭を痛める/傷;筋を傷める,野菜が傷む/炒/悼;死を悼む/愴;≒悼む/慯;≒悼む,≠傷む/
いたk /痛/イタ/
いたi /痛/イタ/
いたg /痛/イタ/
いたc /至/到;≒至る/致;<rare>/
いぞr /居反/
いそがs /忙/
いそs /勤/
いそi /急/
いそg /急/
いずr /何/孰;-れにせよ/
いずm /居住/
いすわt /居座/
いすわr /居座/
いすわn /居座/
いすわc /居座/
いすくm /射竦/
いじわるs /意地悪/
いじわるk /意地悪/
いじわるi /意地悪/
いじわるg /意地悪/
いじりまわs /弄り回/
いじょうn /異常/
いじっぱr /意地っ張/
いじくりまわs /弄くり回/
いじきたなs /意地汚/
いじきたなk /意地汚/
いじきたなi /意地汚/
いじきたなg /意地汚/
いじt /弄/
いじs /維持/
いじr /弄/
いじn /弄/
いじm /苛/
いじk /弄/
いじc /弄/
いしょうあw /衣装合/
いしゅがえs /意趣返/
いしやk /石焼/
いしなg /石投/
いしとr /石取/
いしづくr /石造/
いしぐm /石組/
いしきs /意識/
いざなw /誘/
いざなu /誘/
いざなt /誘/
いざなo /誘/
いざなi /誘/
いざなe /誘/
いざなc /誘/
いざt /躄/膝行/
いざr /躄/膝行/
いざn /躄/膝行/
いざc /躄/膝行/
いさみたt /勇み立/
いさみたc /勇み立/
いささk /些;(字義:細かい)/聊;(字義:一時的)/
いさぎよs /潔/
いさぎよk /潔/
いさぎよi /潔/
いさぎよg /潔/
いさかw /諍/
いさかu /諍/
いさかt /諍/
いさかo /諍/
いさかi /諍/
いさかe /諍/
いさかc /諍/
いさいかまw /委細構/
いさn /勇/諫/諌;「諫」の異体字/
いさm /勇/諫/諌;「諫」の異体字/
いごk /動/
いごi /動/
いこうs /移行/
いこw /憩/憇;「憩」の異体字/
いこu /憩/憇;「憩」の異体字/
いこt /憩/憇;「憩」の異体字/
いこo /憩/憇;「憩」の異体字/
いこn /鋳込;cast/射込;shoot/
いこm /鋳込;cast/射込;shoot/
いこi /憩/憇;「憩」の異体字/
いこe /憩/憇;「憩」の異体字/
いこc /憩/憇;「憩」の異体字/
いけどt /生け捕/
いけどr /生け捕/
いけどn /生け捕/
いけどc /生け捕/
いけすk /いけ好/
いけn /不可;当て字/
いくとおr /幾通/
いくt /幾/
いくr /幾/
いぎもうしたt /異議申立/
いぎぶかs /意義深/
いぎぶかk /意義深/
いぎぶかi /意義深/
いぎぶかg /意義深/
いぎたなs /寝穢/
いぎたなk /寝穢/
いぎたなi /寝穢/
いぎたなg /寝穢/
いきわたt /行き渡/
いきわたr /行き渡/
いきわたn /行き渡/
いきわたc /行き渡/
いきわかr /生き別/
いきりたt /熱り立/
いきりたc /熱り立/
いきまk /息巻/
いきまi /息巻/
いきのこt /生き残/
いきのこr /生き残/
いきのこn /生き残/
いきのこc /生き残/
いきのb /生き延/
いきぬk /息抜;(relief)ちょっと息抜き/生き抜;(survive)乱世を生き抜く/
いきぬi /生き抜;(survive)乱世を生き抜く/
いきなやn /行き悩/
いきなやm /行き悩/
いきながらe /生き存/
いきながr /生き長/生き永/
いきどおt /憤/
いきどおr /憤/
いきどおn /憤/
いきどおc /憤/
いきどm /行き止/
いきとどk /行き届/
いきとどi /行き届/
いきてゆk /生きて行/
いきていt /生きて行/
いきていk /生きて行/
いきていc /生きて行/
いきづかi /息遣/息使;?/
いきづm /行き詰;計画が行き詰まる/息詰;息詰まる熱戦/
いきづk /息衝/
いきづi /息衝/
いきつづk /生き続/
いきつk /行き着;-く先/行き付;-けの店/
いきつi /行き着/
いきつg /息継/
いきちがw /行き違/
いきちがu /行き違/
いきちがt /行き違/
いきちがo /行き違/
いきちがi /行き違/
いきちがe /行き違/
いきちがc /行き違/
いきだおr /行き倒/
いきたe /息絶/
いきせききt /息せき切/息急き切/
いきせききr /息急き切/息せき切/
いきせききn /息急き切/息せき切/
いきせききc /息急き切/息せき切/
いきせk /息急;息急き切って/
いきすg /行き過/行過/
いきごn /意気込/
いきごm /意気込/
いきぐるs /息苦/
いきぎr /息切/
いきがかt /行き掛/
いきがかr /行き掛/
いきがかn /行き掛/
いきがかc /行き掛/
いきがk /行き掛/
いきかよw /行き通/
いきかよu /行き通/
いきかよt /行き通/
いきかよo /行き通/
いきかよi /行き通/
いきかよe /行き通/
いきかよc /行き通/
いきかえt /生き返;(蘇生) 死者が生き返る/
いきかえr /生き返;(蘇生) 死者が生き返る/行き帰;(往復)/
いきかえn /生き返;(蘇生) 死者が生き返る/
いきかえc /生き返;(蘇生) 死者が生き返る/
いきかw /行き交/
いきかu /行き交/
いきかt /行き交/
いきかo /行き交/
いきかi /行き交/
いきかe /行き交/
いきかc /行き交/
いきおいよk /勢い良/
いきおいづk /勢い付/
いきおいづi /勢い付/
いきおいこn /勢い込/
いきおいこm /勢い込/
いきおいあまt /勢い余/
いきおいあまr /勢い余/
いきおいあまc /勢い余/
いきおi /勢/
いきうつs /生き写/
いきうm /生き埋/
いきいそi /生き急/
いきいそg /生き急/
いきいk /生き生/
いきあたt /行き当/
いきあたr /行き当/
いきあたn /行き当/
いきあたc /行き当/
いきあw /行き合/
いきあu /行き合/
いきあt /行き当/行き合/行当/
いきあo /行き合/
いきあi /行き合/
いきあe /行き合/
いきあc /行き合/
いきs /息/粋/粹;「粋」の旧字(人名用漢字)/
いきr /熱/
いきn /息/粋/粹;「粋」の旧字(人名用漢字)/
いきm /息/
いきg /粋;粋がる/意気;意気がる/
いきd /粋/粹;「粋」の旧字(人名用漢字)/
いがみあw /啀み合/
いがみあu /啀み合/
いがみあt /啀み合/
いがみあo /啀み合/
いがみあi /啀み合/
いがみあe /啀み合/
いがみあc /啀み合/
いがいt /意外/
いがいn /意外/
いがいd /意外/
いがn /啀/
いがm /啀/
いかんなk /遺憾無/
いかりくるw /怒り狂/
いかりくるu /怒り狂/
いかりくるt /怒り狂/
いかりくるo /怒り狂/
いかりくるi /怒り狂/
いかりくるe /怒り狂/
いかりくるc /怒り狂/
いかしきt /活かし切/
いかしきr /活かし切/
いかしきn /活かし切/
いかしきc /活かし切/
いかがw /如何;-わしい/
いかおなz /以下同/
いかおなj /以下同/
いかt /怒/厳/忿;<rare>/
いかr /怒/忿;<rare>/
いかn /以下/何如/如何/怒/忿;<rare>/
いかm /厳;厳めしい/
いかk /射掛;矢を-ける/
いかg /如何/
いかd /如何/
いかc /怒/忿;<rare>/
いえどm /雖/
いえr /癒え;※送り位置補正/
いいわたs /言い渡/言渡/
いいわすr /言い忘/
いいわk /言い分/
いいよどn /言い淀/
いいよどm /言い淀/
いいよt /言い寄/
いいよr /言い寄/
いいよn /言い寄/
いいよc /言い寄/
いいもr /言い漏/
いいまわs /言い回/
いいまちがw /言い間違/
いいまちがu /言い間違/
いいまちがt /言い間違/
いいまちがo /言い間違/
いいまちがi /言い間違/
いいまちがe /言い間違/
いいまちがc /言い間違/
いいまぎr /言い紛/
いいまk /言い負/
いいまg /言い曲/
いいふるs /言い古/
いいふくm /言い含/
いいふr /言い触/
いいひろm /言い広/
いいひらk /言い開/
いいひらi /言い開/
いいはなt /言い放/
いいはなc /言い放/
いいはじm /言い始/
いいはt /言い張/
いいはr /言い張/
いいはn /言い張/
いいはc /言い張/
いいのこs /言い残/
いいのがr /言い逃/
いいのk /言い退/
いいぬk /言い抜/
いいにくs /言い難/
いいにくk /言い難/
いいにくi /言い難/
いいにくg /言い難/
いいならw /言い習/
いいなおs /言い直/
いいとおs /言い通/
いいづらs /言い辛/
いいづらk /言い辛/
いいづらi /言い辛/
いいづらg /言い辛/
いいつのt /言い募/
いいつのr /言い募/
いいつのn /言い募/
いいつのc /言い募/
いいつづk /言い続/
いいつたe /言い伝/
いいつくろw /言い繕/
いいつくろu /言い繕/
いいつくろt /言い繕/
いいつくろo /言い繕/
いいつくろi /言い繕/
いいつくろc /言い繕/
いいつくs /言い尽/
いいつk /言い尽/言い付/
いいつi /言い継/
いいつg /言い継/
いいっぱなs /言いっ放/
いいちがe /言い違/
いいちr /言い散;あることないこと-らす/
いいだs /言い出/
いいたがe /言い違/
いいたt /言い立/
いいたs /言い足/
いいたr /言い足/
いいそんj /言い損/
いいそこn /言い損/
いいそe /言い添/
いいすt /言い捨/
いいすg /言い過/
いいしぶt /言い渋/
いいしぶr /言い渋/
いいしぶn /言い渋/
いいしぶc /言い渋/
いいしt /言い知/
いいしr /言い知/
いいしn /言い知/
いいしc /言い知/
いいこm /言い籠/
いいけs /言い消/
いいくるm /言い包/
いいきt /言い切/
いいきr /言い切/
いいきn /言い切/
いいきk /言い聞/
いいきc /言い切/
いいがたs /言い難/
いいがたk /言い難/
いいがたi /言い難/
いいがたg /言い難/
いいがk /言い掛/
いいかわs /言い交/
いいかえs /言い返/
いいかえr /言い替え;※送り位置補正/
いいかw /言い交/
いいかn /言い兼/
いいかk /言い掛/
いいかe /言い換/言い替/
いいおよn /言い及/
いいおよb /言い及/
いいおとs /言い落/
いいおくt /言い送/
いいおくr /言い送/
いいおくn /言い送/
いいおくc /言い送/
いいおw /言い終/
いいおk /言い置/
いいおi /言い置/
いいおe /言い終/
いいあるk /言い歩/
いいあるi /言い歩/
いいあらわs /言い表/
いいあらたm /言い改/
いいあらそw /言い争/
いいあらそu /言い争/
いいあらそt /言い争/
いいあらそo /言い争/
いいあらそi /言い争/
いいあらそe /言い争/
いいあらそc /言い争/
いいあやまt /言い誤/
いいあやまr /言い誤/
いいあやまn /言い誤/
いいあやまc /言い誤/
いいあw /言い合/
いいあu /言い合/
いいあt /言い当/言い合/
いいあo /言い合/
いいあi /言い合/
いいあe /言い合/
いいあc /言い合/
いあわs /居合/
いあw /居合/
いあu /居合/
いあt /居合/
いあo /居合/
いあi /居合/
いあe /居合/
いあc /居合/
いz /居/射/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いy /癒/居/射/言;[口]そう言や(=そう言えば)/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いw /言/云/謂;(字義:何かに関していう)/射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いu /言/云/謂;(字義:何かに関していう)/射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いt /言/行/入/居/射/云/炒;卵を炒る/煎;≒炒る/凍/要/逝;(die) 祖父が逝く/謂;(字義:何かに関していう)/鋳;金物を鋳る/将;兵を将る/率;≒将る/熬/鑄;「鋳」の旧字(人名用漢字)/往;(前進) 荒野を往く/
いs /医;サ変/逸;※送り過剰?/射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いr /入/射/要/居/炒;卵を炒る/煎;≒炒る/鋳;金物を鋳る/容;進言を容れる/淹;茶を淹れる/挿;指を挿れる/将;兵を将る/率;≒将る/熬/鑄;「鋳」の旧字(人名用漢字)/
いp /射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いo /言/云/謂;(字義:何かに関していう)/射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いn /居/異;-な物/去/要;[口]要んない(=要らない)?/往/入/射/炒;卵を炒る/煎;≒炒る/鋳;金物を鋳る/将;兵を将る/率;≒将る/熬/鑄;「鋳」の旧字(人名用漢字)/忌/斎;清める/
いm /忌/居/斎;清める/射/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いk /行/生;(字義:芽が出る)/活;(字義:水が流れる)「特技が活きる」/逝;(die) 祖父が逝く/往;(前進) 荒野を往く/射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/良/好/善/可/
いj /射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いi /言/良/云/可/好/善/謂;(字義:何かに関していう)/射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いh /云/言/射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いg /射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いe /言/癒/云/謂;(字義:何かに関していう)/射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いd /出/射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いc /言/行/云/謂;(字義:何かに関していう)/入/射/要/居/炒;卵を炒る/煎;≒炒る/鋳;金物を鋳る/将;兵を将る/率;≒将る/熬/鑄;「鋳」の旧字(人名用漢字)/逝;(die) 祖父が逝く/往;(前進) 荒野を往く/
いb /射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
いa /射/居/鋳;金物を鋳る/将;兵を将る/率;≒将る/鑄;「鋳」の旧字(人名用漢字)/
あんないいたs /案内致/
あんぜんd /安全/
あんしんくだs /安心下/
あんしんs /安心/
あんz /案;(devise)「一計を案ずる」,(worry)「案ずるより産むが易し」/按;(押さえ、揉む)「腰を按ずる」,(考察する)「これを按ずるに…」/
あんn /暗/
あんk /餡/
あんj /案/按/
あんd /編ん;※送り位置補正/
あわれn /憐/
あわれm /憐/
あわびむすb /鮑結/
あわだt /泡立;(bubble) 石鹸が泡立つ/粟立;(鳥肌) 肌が粟立つ/
あわだc /泡立;(bubble) 石鹸が泡立つ/粟立;(鳥肌) 肌が粟立つ/
あわただs /慌/遽/
あわせよn /併せ読/
あわせよm /併せ読/
あわせもt /合わせ持/
あわせもc /合わせ持/
あわせのn /併せ呑/
あわせのm /併せ呑/
あわおどr /阿波踊/
あわあわs /淡淡/淡々/
あわt /慌/周章/
あわs /併;(並べる) 考え併せる/合/淡/
あわr /哀;(かなしく思いあわれむ)/憐;(気の毒に思いあわれむ)/恤/閔/
あわk /淡/
あわi /淡/
あわg /淡/
あれはt /荒れ果/
あれくるw /荒れ狂/
あれくるu /荒れ狂/
あれくるt /荒れ狂/
あれくるo /荒れ狂/
あれくるi /荒れ狂/
あれくるe /荒れ狂/
あれくるc /荒れ狂/
あるきまわt /歩き回/
あるきまわr /歩き回/
あるきまわn /歩き回/
あるきまわc /歩き回/
あるきつづk /歩き続/
あるきつかr /歩き疲/
あるきだs /歩き出/
あるきさt /歩き去/
あるきさr /歩き去/
あるきさn /歩き去/
あるきさc /歩き去/
あるk /歩/
あるi /歩/或/
ありふr /有り触/
ありつk /有り付/
ありつi /有り付/
ありきたr /在り来/
ありがとu /有り難/有難/
ありがたy /有り難/有難/
ありがたs /有り難/有難/
ありがたm /有り難/有難/
ありがたk /有り難/有難/
ありがたi /有り難/有難/
ありがたg /有り難/有難/
ありえz /有り得/
ありえy /有り得/
ありえt /有り得/
ありえs /有り得/
ありえr /有り得/
ありえn /有り得/
ありえm /有り得/
ありえk /有り得/
ありえc /有り得/
ありうr /有り得/
ありうb /有り得/
ありあわs /有り合/
ありあまt /有り余/
ありあまr /有り余/
ありあまn /有り余/
ありあまc /有り余/
ありあw /有り合/在り合/
ありk /歩;[文語]/
あらわs /表;(represent) 意味を表す/現;(show) 姿を現す/著;(author) 小説を著す/顕;(manifest) 名を顕す/露;(字義:透明なので見える)/
あらわr /表/現/顕/
あらわn /露;(字義:透明なので見える)/顕;(字義:顔を見せている)/
あらわd /露;(字義:透明なので見える)/顕;(字義:顔を見せている)/
あらだt /荒立/
あらたn /新/
あらたm /改;generic/革;(思い切って変える)「国政を革める」/検;(inspect)「切符を検める」/更;(renew)「契約を更める」/
あらそw /争/爭;「争」の旧字(人名用漢字)/
あらそu /争/爭;「争」の旧字(人名用漢字)/
あらそt /争/爭;「争」の旧字(人名用漢字)/
あらそo /争/爭;「争」の旧字(人名用漢字)/
あらそi /争/爭;「争」の旧字(人名用漢字)/
あらそe /争/爭;「争」の旧字(人名用漢字)/競/
あらそc /争/爭;「争」の旧字(人名用漢字)/
あらすg /粗過/
あらさがs /粗探/
あらけずr /荒削/
あらがw /抗/諍/争;NB:「あらそu」と同形/爭;「争」の旧字(人名用漢字)/
あらがu /抗/諍/争;NB:「あらそu」と同形/爭;「争」の旧字(人名用漢字)/
あらがt /抗/諍/争;NB:「あらそu」と同形/爭;「争」の旧字(人名用漢字)/
あらがo /抗/諍/争;NB:「あらそu」と同形/爭;「争」の旧字(人名用漢字)/
あらがk /荒書/
あらがi /抗/諍/争;NB:「あらそu」と同形/爭;「争」の旧字(人名用漢字)/
あらがe /抗/諍/争;NB:「あらそu」と同形/爭;「争」の旧字(人名用漢字)/
あらがc /抗/諍/争;NB:「あらそu」と同形/爭;「争」の旧字(人名用漢字)/
あらかせg /荒稼/
あらかじm /予/豫;「予」の旧字/
あらいながs /洗い流/
あらいなおs /洗い直/
あらいだs /洗い出/
あらいきよm /洗い清/
あらいおとs /洗い落/
あらいおt /洗い落/
あらいあg /洗い上/
あらあらs /荒々/
あらz /非/
あらw /表/現/洗/
あらu /洗/
あらt /新/洗/
あらs /粗;(rough) きめが粗い/荒;(wild) 波が荒い/麁;<rare> ≒粗い/
あらr /荒/
あらp /荒/粗/
あらo /洗/
あらk /荒;(wild) 波が荒い/粗;(rough) きめが粗い/麁;<rare> ≒粗い/
あらj /非/
あらi /洗/荒;(wild) 波が荒い/粗;(rough) きめが粗い/麁;<rare> ≒粗い/
あらg /荒;(wild) 波が荒い/粗;(rough) きめが粗い/麁;<rare> ≒粗い/
あらe /洗/
あらc /洗/
あらb /荒/
あゆみよt /歩み寄/
あゆみよr /歩み寄/
あゆみよn /歩み寄/
あゆみよc /歩み寄/
あゆみつづk /歩み続/
あゆn /歩/
あゆm /歩/
あやまt /誤;-って NB:「誤ち」は許容されにくい,(err) 選択を誤る/過;-ち/謝;(apologize) ゴメンと謝る/謬;≒誤る/
あやまr /謝;(apologise) ゴメンと謝る/誤;(err) 選択を誤る/謬;≒誤る/
あやまn /謝;(apologise) ゴメンと謝る/誤;(err) 選択を誤る/謬;≒誤る/
あやまc /過;-ち/誤;-って NB:「誤ち」は許容されにくい,(err) 選択を誤る/謝;(apologize) ゴメンと謝る/謬;≒誤る/
あやつt /操/
あやつr /操/
あやつn /操/
あやつc /操/
あやかt /肖/
あやかr /肖/
あやかn /肖/
あやかc /肖/
あやu /危/
あやs /怪;(不審) 怪しい人物/妖;(艶かしい,不気味) 妖しいムード/恠;<rare> ≒怪しい/
あやm /殺;人を殺める/危;≒殺める/怪;-む (いぶかる)/
あやb /危/
あめふt /雨降/
あめふr /雨降/
あめふn /雨降/
あめふc /雨降/
あめあg /雨上/
あみだs /編み出/
あみこn /編み込/
あみこm /編み込/
あみかk /網掛/
あみうt /網打/
あみあg /編み上/編上/
あまやどr /雨宿/
あまもよi /雨催/
あまもr /雨漏/
あまねs /遍/普/
あまねk /遍/普/
あまとb /天飛/
あまてr /天照/
あまつさe /剰;-え NB:本来は「あまっさえ」の誤用/
あまっさe /剰/
あまだr /雨垂/
あまずp /甘酸/
あますg /甘過/
あまごi /雨乞/
あまくだt /天下/天降;=天下り/
あまくだr /天下/天降;=天下り/
あまくだn /天下/天降;=天下り/
あまくだc /天下/天降;=天下り/
あまぎごe /天城越/
あまがけt /天翔/
あまがけr /天翔/
あまがけn /天翔/
あまがけc /天翔/
あまからs /甘辛/
あまからk /甘辛/
あまからi /甘辛/
あまからg /甘辛/
あまかけt /天翔/
あまかけr /天翔/
あまかけn /天翔/
あまかけc /天翔/
あまy /甘/
あまt /余/甘/餘;「余」の旧字/
あまs /余/甘/餘;「余」の旧字/
あまr /余/餘;「余」の旧字/
あまn /甘/余/餘;「余」の旧字/天/
あまm /甘/
あまk /甘/
あまi /甘/
あまg /甘/
あまe /甘/
あまc /甘;-っちょろい/余/餘;「余」の旧字/
あほくさs /阿呆臭/
あほくさk /阿呆臭/
あほくさi /阿呆臭/
あほくさg /阿呆臭/
あほうくさs /阿呆臭/
あほうくさk /阿呆臭/
あほうくさi /阿呆臭/
あほうくさg /阿呆臭/
あほr /阿呆/
あぶりだs /炙り出/
あぶらじm /油染/
あぶらあg /油揚/
あぶらk /脂/油/
あぶらg /脂/
あぶなs /危;非正則(あぶn)/
あぶなm /危;非正則(あぶn)/
あぶなk /危;非正則(あぶn)/
あぶなi /危;非正則(あぶn)/
あぶなg /危;非正則(あぶn)/
あぶt /焙;(字義:容器の中であぶる) 豆を焙る/炙;(字義:直火であぶる) 肉を炙る/炮/
あぶr /炙;(字義:直火であぶる) 肉を炙る/焙;(字義:容器の中であぶる) 豆を焙る/溢;職に溢れる/炮/
あぶn /危/炙;(字義:直火であぶる) 肉を炙る/焙;(字義:容器の中であぶる) 豆を焙る/炮/
あぶc /炙;(字義:直火であぶる) 肉を炙る/焙;(字義:容器の中であぶる) 豆を焙る/炮/
あふれでy /溢れ出/
あふれでt /溢れ出/
あふれでs /溢れ出/
あふれでr /溢れ出/
あふれでn /溢れ出/
あふれでm /溢れ出/
あふれだs /溢れ出/
あふれかえt /溢れ返/
あふれかえr /溢れ返/
あふれかえn /溢れ返/
あふれかえc /溢れ返/
あふr /溢/
あびせかk /浴びせ掛/
あびs /浴/
あばれまわt /暴れ回/
あばれまわr /暴れ回/
あばれまわn /暴れ回/
あばれまわc /暴れ回/
あばれだs /暴れ出/
あばきたt /暴き立/
あばr /暴/
あばk /暴/発/
あばi /暴/発/
あはなt /畔放/
あなほr /穴掘/
あなねらi /穴狙/
あなどt /侮/
あなどr /侮/
あなどn /侮/
あなどc /侮/
あなずr /侮/
あながt /強/
あなうm /穴埋/
あなあk /穴開/
あともどr /後戻/
あとまわs /後回/
あとばらi /後払/
あとづk /後付;-けの理論/跡付;(変遷を)-ける/
あとつg /跡継/
あとずさt /後退/
あとずさr /後退/
あとずさn /後退/
あとずさc /後退/
あとすこs /後少/
あとくさr /後腐/
あとかたづk /後片付/後片づ;※送り位置補正/
あとおs /後押/
あとおi /後追/
あとu /能/
あとd /後;後づけの理由/跡;(trace)歴史を跡づける/
あでy /艶/
あてはまt /当て嵌/
あてはまr /当て嵌/
あてはまn /当て嵌/
あてはまc /当て嵌/
あてはm /当て嵌/
あてながk /宛て名書/
あてつk /当て付/
あてこすt /当て擦/
あてこすr /当て擦/
あてこすn /当て擦/
あてこすc /当て擦/
あてこn /当て込/
あてこm /当て込/
あてt /宛/
あつらh /誂/
あつらe /誂/
あつまt /集/集ま;※送り位置補正/
あつまr /集/集ま;※送り位置補正/
あつまn /集/
あつまc /集/
あつすg /暑過/熱過/厚過/
あつぐるs /暑苦/
あつくるs /暑苦/
あつぎr /厚切/
あつかw /扱/
あつかu /扱/
あつかt /扱/
あつかo /扱/
あつかi /扱/
あつかe /扱/
あつかc /扱/
あつu /暑;暑い部屋/熱;熱い湯/厚;厚い本/篤;篤い友情/
あつs /暑;暑い部屋/厚;厚い本/熱;熱い湯/圧/篤;篤い友情/
あつm /集/厚/熱/暑/蒐;(探しあつめる)/聚;<rare> (一処にあつめる)/輯;<rare> (あつめて纏める)/纂;<rare> ≒輯/
あつk /熱;熱い湯/暑;暑い部屋/厚;厚い本/篤;篤い友情/扱;非正則(あつかu)/
あつi /熱;熱い湯/暑;暑い部屋/厚;厚い本/篤;篤い友情/
あつg /暑;暑い部屋/熱;熱い湯/厚;厚い本/篤;篤い友情/
あつb /厚/
あったm /温/暖/
あったk /暖/温/
あっけなi /呆気な;※送り位置補正/
あっs /圧/
あだうt /仇討/仇打/
あだp /婀娜/
あたりちr /当たり散/当り散/
あたりかまw /辺り構/
あたらしi /新し;※送り位置補正/
あたらs /新/
あたまわr /頭割/
あたまだs /頭出/
あたまがk /頭書/
あたまうt /頭打/
あたためなおs /温め直;味噌汁を-/暖め直;部屋を-/
あたためあw /温め合/暖め合/
あたためあu /温め合/暖め合/
あたためあt /温め合/暖め合/
あたためあo /温め合/暖め合/
あたためあi /温め合/暖め合/
あたためあe /温め合/暖め合/
あたためあc /温め合/暖め合/
あたたかs /暖/
あたたかk /暖/
あたたかi /暖/
あたたかg /暖/
あたたm /温;(字義:料理があたたかい) 体を温める/暖;(字義:日が当たってあたたかい) 部屋を暖める/
あたたk /暖;暖かい部屋/温;温かい料理/
あたかm /恰;-も/宛;-も/
あたいs /価;price. (字義:商人のつける売値)/値;value. (字義:そのものの価値)/價;「価」の旧字(人名用漢字)/
あたw /能/
あたu /能/
あたt /当;大当り/中;食中り/
あたr /辺;この辺り/当;大当り/中;食中り/新;非正則(あたらs)/邊;「辺」の旧字1/邉;「辺」の旧字2/
あたo /能/
あたn /当;大当り/中;食中り/
あたi /能/
あたh /与/
あたe /与/與;「与」の旧字(人名用漢字)/能/
あたc /当;大当り/中;食中り/
あそんd /遊ん;※送り位置補正/
あそびほうk /遊び呆/遊び惚/
あそびすg /遊び過/
あそびあるk /遊び歩/
あそびあるi /遊び歩/
あそびあk /遊び明/
あそn /遊/游;<rare>(字義:およぐ) ≒遊ぶ/
あそb /遊/游;<rare>(字義:およぐ) ≒遊ぶ/
あせにぎt /汗握/
あせにぎr /汗握/
あせにぎn /汗握/
あせにぎc /汗握/
あせくさs /汗臭/
あせくさk /汗臭/
あせくさi /汗臭/
あせくさg /汗臭/
あせt /焦/
あせs /汗/
あせr /焦/
あせn /焦/
あせc /焦/
あせb /汗;汗ばむ/
あずけいr /預け入/
あずかりしt /与り知/
あずかりしr /与り知/
あずかt /与;(授与)「お誉めに与る」 (関与) 「与り知らぬ」/預;(預託) 子供を預る/
あずかr /与;(授与)「お誉めに与る」 (関与) 「与り知らぬ」/預;(預託) 子供を預る/
あずかn /与;(授与)「お誉めに与る」 (関与) 「与り知らぬ」/預;(預託) 子供を預る/
あずかc /与;(授与)「お誉めに与る」 (関与) 「与り知らぬ」/預;(預託) 子供を預る/
あずk /預/
あじわいぶかs /味わい深/
あじわいぶかk /味わい深/
あじわいぶかi /味わい深/
あじわいぶかg /味わい深/
あじつk /味付/
あじちがi /味違/
あじだs /味出/
あじけなs /味気無/
あじけなk /味気無/
あじけなi /味気無/
あじけなg /味気無/
あじけs /味消/
あじきなs /味気無/
あじきなk /味気無/
あじきなi /味気無/
あじきなg /味気無/
あじw /味/
あじt /アジ/
あじs /味/
あじr /アジ/
あじn /味;-な(もの)/アジ/
あじd /味/
あじc /アジ/
あしまわs /足回/
あしまわr /足回/
あしぶm /足踏/
あしふm /足踏/
あしばらi /足払/
あしなr /足慣/
あしなm /足並/
あしどr /足取/
あしとr /足取/
あしでまとi /足手纏/
あしてまとi /足手纏/
あしたs /晨;あさ/
あししげk /足繁/
あしがらm /足搦/
あしがたm /足固/
あしがかr /足掛/
あしかk /足掛/
あしk /悪/惡;「悪」の旧字(人名用漢字)/
あざわらw /嘲笑/
あざわらu /嘲笑/
あざわらt /嘲笑/
あざわらo /嘲笑/
あざわらi /嘲笑/
あざわらe /嘲笑/
あざわらc /嘲笑/
あざやk /鮮;非正則(あざy)/
あざむk /欺/
あざむi /欺/
あざなw /糾/
あざなu /糾/
あざなt /糾/
あざなo /糾/
あざなi /糾/
あざなe /糾/
あざなc /糾/
あざけt /嘲/
あざけr /嘲/
あざけn /嘲/
あざけc /嘲/
あざy /鮮/
あさやk /朝焼/
あさはやs /朝早/
あさはやk /朝早/
あさはやi /朝早/
あさはやg /朝早/
あさづk /浅漬/
あさすg /浅過/
あさぐろs /浅黒/
あさぐろk /浅黒/
あさぐろi /浅黒/
あさぐろg /浅黒/
あさがえr /朝帰/
あさおk /朝起/
あさいr /浅煎/
あさt /漁/
あさs /浅/淺;「浅」の旧字/
あさr /漁/
あさp /朝/
あさn /漁/
あさm /浅;浅ましい/淺;「浅」の旧字/
あさk /浅/淺;「浅」の旧字/
あさi /浅/淺;「浅」の旧字/
あさg /浅/淺;「浅」の旧字/
あさc /漁/
あこがr /憧/憬;≒憧れ(る)/
あこu /赤/
あげつらw /論/
あげつらu /論/
あげつらt /論/
あげつらo /論/
あげつらi /論/
あげつらe /論/
あげつらc /論/
あげおr /上げ下/
あげあしとr /揚げ足取/
あげt /上/
あけわたs /明け渡/明渡/
あけひろg /開け広/明け広/
あけはなt /開け放/
あけはなs /開け放/
あけっぴろg /開けっ広/明けっ広/
あけっぱなs /開けっ放/明けっ放/
あけたt /開け閉/
あけくれr /明け暮れ;※送り位置補正/
あけくr /明け暮/
あぐn /倦/
あぐm /倦/
あくめいたかs /悪名高/
あくめいたかk /悪名高/
あくめいたかi /悪名高/
あくめいたかg /悪名高/
あくみょうだかs /悪名高/
あくみょうだかk /悪名高/
あくみょうだかi /悪名高/
あくみょうだかg /悪名高/
あくがr /憧;古語。「離れる」の意/
あくr /明く;※送り位置補正/
あきれはt /呆れ果/
あきれかえt /呆れ返/
あきれかえr /呆れ返/
あきれかえn /呆れ返/
あきれかえc /呆れ返/
あきらめきt /諦め切/
あきらめきr /諦め切/
あきらめきn /諦め切/
あきらめきc /諦め切/
あきらm /諦/
あきらk /明/
あきやすm /秋休/
あきばr /秋晴/
あきなw /商/賈;<rare> ≒商う/
あきなu /商/賈;<rare> ≒商う/
あきなt /商/賈;<rare> ≒商う/
あきなo /商/賈;<rare> ≒商う/
あきなi /商/賈;<rare> ≒商う/
あきなe /商/賈;<rare> ≒商う/
あきなc /商/賈;<rare> ≒商う/
あきたt /飽き足/
あきたr /飽き足/
あきたn /飽き足/
あきたc /飽き足/
あきr /明/呆/顕;(原義:顔を見せる) 正体を顕らかにする/煥;<rare>/
あがりこn /上がり込/
あがりこm /上がり込/
あがなw /贖;(redeem)罪を贖う/購;(buy)本を購う/
あがなu /贖;(redeem)罪を贖う/購;(buy)本を購う/
あがなt /贖;(redeem)罪を贖う/購;(buy)本を購う/
あがなo /贖;(redeem)罪を贖う/購;(buy)本を購う/
あがなi /贖;(redeem)罪を贖う/購;(buy)本を購う/
あがなe /贖;(redeem)罪を贖う/購;(buy)本を購う/
あがなc /贖;(redeem)罪を贖う/購;(buy)本を購う/
あがt /上/騰;物価が騰がる/挙が;※送り位置補正/揚が;※送り位置補正/上が;※送り位置補正/
あがr /上/騰;物価が騰がる/挙が;※送り位置補正/揚が;※送り位置補正/上が;※送り位置補正/
あがn /上/騰;物価が騰がる/
あがm /崇/
あがk /足掻/
あがi /足掻/
あがc /上/騰;物価が騰がる/
あかるすg /明る過/
あかるs /明/
あかるm /明/
あかるk /明/
あかるi /明/
あかるg /明/
あからm /赧/
あかぬk /垢抜/
あかちゃk /赤茶/
あかじm /垢染/
あかしだt /証立/
あかぐろs /赤黒/
あかぐろk /赤黒/
あかぐろi /赤黒/
あかぐろg /赤黒/
あかs /証/赤/朱/證;旧字/紅/赫;顔が赫い/
あかr /明/灯/赤/明か;※送り位置補正/
あかp /赤/
あかn /赤/
あかm /赤/紅/朱/
あかk /赤/紅/朱/赫;顔が赫い/
あかi /赤/紅/朱/赫;顔が赫い/
あかg /赤/紅/朱/赫;顔が赫い/
あおりたt /煽り立/
あおむk /仰向/
あおむi /仰向/
あおびかr /青光/
あおばどおr /青葉通/
あおたがi /青田買/
あおじろs /青白/蒼白/
あおじろm /青白/蒼白/
あおじろk /青白/蒼白/
あおじろi /青白/蒼白/
あおじろg /青白/蒼白/
あおぐろs /青黒/黝/
あおぐろm /青黒/黝/
あおぐろk /青黒/黝/
あおぐろi /青黒/黝/
あおぐろg /青黒/黝/
あおくさs /青臭/
あおくさm /青臭/
あおくさk /青臭/
あおくさi /青臭/
あおくさg /青臭/
あおぎみz /仰ぎ見/
あおぎみy /仰ぎ見/
あおぎみt /仰ぎ見/
あおぎみs /仰ぎ見/
あおぎみr /仰ぎ見/
あおぎみn /仰ぎ見/
あおぎみm /仰ぎ見/
あおぎみk /仰ぎ見/
あおぎみc /仰ぎ見/
あおy /青/
あおu /青/蒼;(血の気のない青) 顔が蒼い/碧;(澄んだ青緑) 碧い瞳/
あおt /煽;火を煽る/呷;酒を呷る/
あおs /青/蒼;(血の気のない青) 顔が蒼い/碧;(澄んだ青緑) 碧い瞳/
あおr /煽;火を煽る/呷;酒を呷る/
あおp /青/
あおn /煽;火を煽る/呷;酒を呷る/
あおm /青/蒼;(血の気のない青) 顔が蒼い/碧;(澄んだ青緑) 碧い瞳/
あおk /青/蒼;(血の気のない青) 顔が蒼い/碧;(澄んだ青緑) 碧い瞳/
あおi /青/蒼;(血の気のない青) 顔が蒼い/碧;(澄んだ青緑) 碧い瞳/仰/扇;団扇で扇ぐ/
あおg /仰/扇;団扇で扇ぐ/青/蒼;(血の気のない青) 顔が蒼い/碧;(澄んだ青緑) 碧い瞳/
あおc /煽;火を煽る/呷;酒を呷る/
あえt /敢/敢え;※送り位置補正/
あえi /喘/
あえg /喘/
あいわs /相和/
あいようs /愛用/
あいみたがi /相身互/
あいみz /相見/
あいみy /相見/
あいみt /相見/
あいみs /相見/
あいみr /相見/
あいみn /相見/
あいみm /相見/
あいみc /相見/
あいまt /相俟/
あいぼr /相惚/
あいひとs /相等/
あいはんs /相反/
あいはn /相食;骨肉-む/
あいはm /相食;骨肉-む/
あいのr /相乗/
あいなかb /相半/
あいなt /相成/
あいなr /相成/
あいなn /相成/
あいなc /相成/
あいともなw /相伴/
あいともなu /相伴/
あいともなt /相伴/
あいともなo /相伴/
あいともなi /相伴/
あいともなc /相伴/
あいてどt /相手取/
あいてどr /相手取/
あいてどn /相手取/
あいてどc /相手取/
あいつらn /相連/
あいつとm /相勤/
あいつうz /相通/
あいつうj /相通/
あいつi /相次/相継/
あいつg /相次/相継/
あいたいs /相対/
あいそわらi /愛想笑/
あいそよk /愛想良/
あいそづk /愛想尽/
あいじょうぶかs /愛情深/
あいじょうぶかk /愛情深/
あいじょうぶかi /愛情深/
あいじょうぶかg /愛情深/
あいしあw /愛し合/
あいしあu /愛し合/
あいしあt /愛し合/
あいしあo /愛し合/
あいしあi /愛し合/
あいしあe /愛し合/
あいしあc /愛し合/
あいさつがわr /挨拶代/
あいことn /相異/
あいかわr /相変/
あいかw /相変/
あいうt /相討/相打;相打ち/
あいいr /相容/
あいs /愛/
あいr /愛/
あいk /愛/
あいi /相/
あw /合;(一致) 話が合う/会;人と会う/併/逢;(人と|運命的にあう) 巡り逢う/遭;(偶然、特によくないことにあう) 事故に遭う/會;「会」の旧字/遇;≒遭う/
あu /合;(一致) 話が合う/会;人と会う/遭;(偶然、特によくないことにあう) 事故に遭う/逢;(人と|運命的にあう) 巡り逢う/遇;≒遭う/會;「会」の旧字/
あt /当/宛/充/会;人と会う/合;(一致) 話が合う/有;(⇔無)時間が有る/在;(⇔不在)眼前に在る/遭;(偶然、特によくないことにあう) 事故に遭う/逢;(人と|運命的にあう) 巡り逢う/該/當;「当」の旧字/會;「会」の旧字/遇;≒遭う/
あs /褪/悪/惡;「悪」の旧字(人名用漢字)/
あr /荒/有;(⇔無)時間が有る/在;(⇔不在)眼前に在る/或;(certain) 或る時/
あo /合;(一致) 話が合う/会;人と会う/會;「会」の旧字/遭;(偶然、特によくないことにあう) 事故に遭う/逢;(人と|運命的にあう) 巡り逢う/遇;≒遭う/
あn /編/彼;-の/有;(⇔無)時間が有る/在;(⇔不在)眼前に在る/浴;湯浴み/
あm /編/浴;湯浴み/
あk /開/飽;原義:満腹する/空/明;(夜|年|喪)が明ける/厭;原義:(脂身のように)しつこくて嫌になる/倦;原義:疲れて嫌になる/飫/有;[口]文句有っか/
あi /合;(一致) 話が合う/会;人と会う/空/開/逢;(人と|運命的にあう) 巡り逢う/遭;(偶然、特によくないことにあう) 事故に遭う/會;「会」の旧字/遇;≒遭う/飽;原義:満腹する/明;夜が明ける/厭;原義:(脂身のように)しつこくて嫌になる/倦;原義:疲れて嫌になる/飫/
あh /合/會;「会」の旧字/
あg /上/挙;(示すためにあげる) (例|手)を挙げる/揚;(高くあげる) (旗|からあげ)を揚げる/擧;「挙」の旧字/
あe /会;人と会う/合;(一致) 話が合う/逢;(人と|運命的にあう) 巡り逢う/敢;(dare) 敢えて/和;(調味料等と混ぜる) 胡麻和え/韲;≒和える/遭;(偶然、特によくないことにあう) 事故に遭う/會;「会」の旧字/遇;≒遭う/
あc /合;(一致) 話が合う/会;人と会う/遭;(偶然、特によくないことにあう) 事故に遭う/逢;(人と|運命的にあう) 巡り逢う/遇;≒遭う/會;「会」の旧字/有;(⇔無)時間が有る/在;(⇔不在)眼前に在る/
あb /浴/
>わたs /渡/
>わすr /忘/
>わk /分/
>ようn /様/
>ようd /様/
>ゆk /行/
>やすu /易/
>やすs /易/
>やすm /易/
>やすk /易/
>やすi /易/
>やすg /易/
>やt /遣/
>やr /遣/
>やn /止/遣/
>やm /止/
>やc /遣/
>もらw /貰/
>もらu /貰/
>もらt /貰/
>もらo /貰/
>もらi /貰/
>もらe /貰/
>もらc /貰/
>もt /漏/
>もr /漏/
>もn /漏/
>もc /漏/
>みz /見/
>みy /見/
>みt /見/
>みs /見/
>みr /見/
>みn /見/
>みm /見/
>みc /見/
>まわs /回/
>まよw /迷/
>まよu /迷/
>まよt /迷/
>まよo /迷/
>まよi /迷/
>まよe /迷/
>まよc /迷/
>まどw /惑/
>まどu /惑/
>まどt /惑/
>まどo /惑/
>まどi /惑/
>まどe /惑/
>まどc /惑/
>まちがw /間違/
>まちがu /間違/
>まちがt /間違/
>まちがo /間違/
>まちがi /間違/
>まちがe /間違/
>まちがc /間違/
>まうs /申/
>まs /増/
>ほs /欲/
>ふうn /風/
>ふうd /風/
>ぱらw /払/
>ぱらu /払/
>ぱらt /払/
>ぱらo /払/
>ぱらi /払/
>ぱらe /払/
>ぱらc /払/
>ぱなs /放/
>ばかr /許/
>はらw /払/
>はらu /払/
>はらt /払/
>はらo /払/
>はらi /払/
>はらe /払/
>はらc /払/
>はべt /侍/
>はべr /侍/
>はべn /侍/
>はべc /侍/
>はなs /放/
>はじm /始;(開始)「考え始める」「姫始め」/
>はt /果/
>のこt /残/
>のこs /残/
>のこr /残/
>のこn /残/
>のこc /残/
>ねがw /願/
>ねがu /願/
>ねがt /願/
>ねがo /願/
>ねがi /願/
>ねがe /願/
>ねがc /願/
>ぬk /抜/
>ぬi /抜/
>にくs /難;(hard) 考え難い NB:「がたi」と同形/
>にくk /難;(hard) 考え難い NB:「がたi」と同形/
>にくi /難;(hard) 考え難い NB:「がたi」と同形/
>にくg /難;(hard) 考え難い NB:「がたi」と同形/
>ながr /乍;(助動詞) 聞き乍ら/
>なおs /直;故障を直す/
>なs /無/
>なr /慣/
>なk /無/
>なi /無/
>なg /無/
>どおs /通;(連濁) 負け通し,立ち通し,千枚通し/
>とおs /通/
>とt /取/
>とr /取/
>とn /飛;fly/取/
>とm /止/留;気に留める/
>とc /取/
>とb /飛;fly/
>できz /出来/
>できy /出来/
>できw /出来/
>できu /出来/
>できt /出来/
>できs /出来/
>できr /出来/
>できp /出来/
>できo /出来/
>できn /出来/
>できm /出来/
>できk /出来/
>できj /出来/
>できi /出来/
>できh /出来/
>できg /出来/
>できe /出来/
>できd /出来/
>できc /出来/
>できb /出来/
>できa /出来/
>でz /出/
>でy /出/
>でw /出/
>でu /出/
>でt /出/
>でs /出/
>でr /出/
>でp /出/
>でo /出/
>でn /出/
>でm /出/
>でk /出/
>でj /出/
>でi /出/
>でh /出/
>でg /出/
>でe /出/
>でd /出/
>でc /出/
>でb /出/
>でa /出/
>てきn /的/
>てきd /的/
>づらs /辛/
>づらk /辛/
>づらi /辛/
>づらg /辛/
>づk /付/
>づi /付/
>つのt /募/
>つのr /募/
>つのn /募/
>つのc /募/
>つづk /続/
>つづi /続/
>つくs /尽/
>つかr /疲/
>つk /尽/付/着/
>つi /付/着/継;語り継いで/
>つg /継;語り継ぐ/
>ちがe /違/
>ちt /散/
>ちr /散/
>ちn /散/
>ちc /散/
>だs /出/
>たまw /給/
>たまu /給/
>たまt /給/
>たまo /給/
>たまi /給/
>たまh /給/
>たまe /給/
>たまc /給/
>たてまつt /奉/
>たてまつr /奉/
>たてまつn /奉/
>たてまつc /奉/
>たおs /倒/
>たt /立/
>たs /足/
>たc /立/
>ぞm /初/
>そこなw /損/
>そこなu /損/
>そこなt /損/
>そこなo /損/
>そこなi /損/
>そこなe /損/
>そこなc /損/
>そこn /損/
>そm /初;知り初める/
>ずm /済/
>ずk /好/
>すすn /進/
>すすm /進/
>すg /過/
>じょうn /状/
>じょうd /状/
>しまw /終/了/
>しまu /終/了/
>しまt /終/了/
>しまo /終/了/
>しまi /終/了/
>しまe /終/了/
>しまc /終/了/
>しぶt /渋/
>しぶr /渋/
>しぶn /渋/
>しぶc /渋/
>さt /去/
>さs /止;言い止す/
>さr /去/
>さn /去/
>さg /下/
>さc /去/
>ごs /越;(連濁) ガラス越し/
>ころs /殺/
>こz /来/
>こy /来/
>こs /来/
>こr /来/
>こn /込/来/
>こm /込/
>こi /来/
>くわe /加/
>くるw /狂/
>くるu /狂/
>くるt /狂/
>くるo /狂/
>くるi /狂/
>くるe /狂/
>くるc /狂/
>くらb /比;字義:並べてくらべる/較;字義:突き合わせてくらべる/
>くだs /下/
>くr /来/呉/
>くn /来/
>ぎらi /嫌/
>ぎm /決/
>きy /来/
>きt /来/切/
>きs /来/
>きr /切/
>きn /来/切/
>きm /来/
>きd /来/
>きc /来/切/
>がらm /絡/
>がたs /難;考え難い NB:「にくi」と同形/
>がたk /難;考え難い NB:「にくi」と同形/
>がたi /難;考え難い NB:「にくi」と同形/
>がたg /難;考え難い NB:「にくi」と同形/
>がt /勝/
>がk /掛/
>かわs /交/
>かえs /返;金を返す,裏返す/
>かw /交;挨拶を交わす/
>かn /兼/
>かk /掛/
>かe /替;(取り替え) 部品を替える/
>おわt /終/
>おわr /終/
>おわn /終/
>おわc /終/
>おとs /落/
>おさm /納/
>おこs /起/
>おくr /遅/
>おおs /果;言い果せる/
>おw /終/
>おt /落/
>おr /下/
>おk /起/置/
>おi /置/
>おe /終/
>おc /落/
>えz /得/
>えy /得/
>えt /得/
>えs /得/
>えr /得/
>えn /得/
>えm /得/
>えc /得/
>うr /得/
>うb /得/
>いただk /頂/戴/
>いただi /頂/戴/
>いたs /致/
>いt /行/入/
>いr /入/
>いn /入/
>いk /行/
>いc /行/入/
>あわs /合/
>あるk /歩/
>あるi /歩/
>あさt /漁/
>あさr /漁/
>あさn /漁/
>あさc /漁/
>あぐn /倦/
>あぐm /倦/
>あw /合/
>あu /合/
>あt /合/当/
>あo /合/
>あk /飽/
>あi /合/飽/
>あg /上/
>あe /合/
>あc /合/
;; okuri-nasi entries.
! /！/感嘆符/
!! /！！/
!= /≠/
" /″;second/“;doublequote(open)/”;doublequote(close)/〃;繰り返し記号/
# /#1/#3/#2/＃;number/#0/#8/#4/#5/
#% /#1％/
#) /#1）/
#,# /#1，#1/#1、#1/
#-# /#1〜#1/#1-#1/
#-#-# /#1−#1−#1/
#. /#1．/
#.# /#1．#1/#0月#0日/
#/# /#0月#0日/#1／#1/#1月#1日/
#:# /#1：#1/
#F /#1Ｆ/
#bit /#0ビット/#1ビット/
#cm /#1ｃｍ/
#copy /#0部/
#d /#0日/
#door /#0ドア/#1ドア/
#f /#0階/#1Ｆ/#1階/
#feet /#1フィート/
#fu /#9歩/
#g /#0G/#1ギガ/
#gatu /#1月/
#gatu#niti /#1月#1日/
#giga /#1ギガ/
#gin /#9銀/
#gyoku /#9玉/
#h /#0時間/#1時/#0時/
#h#m /#0時#0分/
#hi /#9飛/
#hisha /#9飛車/
#hu /#9歩/
#inch /#1インチ/
#ji /#1時/
#k /#0金/
#ka /#1日/
#kaku /#9角/
#kei /#9桂/
#kg /#1ｋｇ/
#kin /#9金/
#kyou /#9香/
#lsize /#0Lサイズ/#1Ｌサイズ/
#m /#0Mbytes/#1ｍ/#0月/
#m# /#0月#0日/
#m#d /#0月#0日/
#mega /#1メガ/
#mei /#1名/
#mile /#1マイル/
#min /#0分/
#mm /#1ｍｍ/#2ｍｍ/
#narigin /#9成銀/
#narikei /#9成桂/
#narikyou /#9成香/
#nen /#1年/
#nichi /#1日/
#page /#0ページ/#1ページ/#0 ページ/
#pin /#0ピン/
#room /#0部屋/
#ryu /#9龍/
#ryuu /#9竜/
#t /#1ｔ/#0坪/
#to /#9と/
#uma /#9馬/
#y /#0年/
#y#m#d /#0年#0月#0日/
#yard /#1ヤード/
#yen /#1円/#0円/#8円/
#、# /#1、#1/
#、#てん /#1、#1点/
#、#にち /#1、#1日/
#、#にん /#1、#1人/
#、#ねん /#1、#1年/
#、#ふん /#1、#1分/
#、#まい /#1、#1枚/
#、#まん /#1、#1万/
#。 /#1．/
#。# /#1．#1/#1.#1/
#。#。# /#1．#1．#1/
#。#にん /#1．#1人/
#。#めが /#1.#1Mbyte/
#：# /#1：#1/
#ー# /#1―#1/
#あん /#3案/#1案/#0案/#2案/
#あんだ /#0安打/
#い /#0位/#1位/#3位/#2位/
#う /#3宇;寺院/#1宇/#0宇/#2宇/
#えき /#3駅/#1駅/#0駅/#2駅/
#えだ /#3枝/#1枝/#0枝/#2枝/
#えん /#1円/#0円/#8円/#3円/#0えん/#2円/
#えんさつ /#3円札/
#おうふく /#1往復/
#おく /#1億;10^8/#3億;10^8/#0億;10^8/#2億;10^8/
#おく#せんまん /#1億#1千万/
#おくえん /#0億円/#1億円/#3億円/
#おくねんまえ /#3億年前/
#おり /#3折/#1折/#0折/#2折/
#おん /#3音/#1音/#0音/#2音/
#か /#3日/#3価/#0日/#1日/#2日/#1価/#0価/#2価/#3顆;ハンコ/#1顆/#0顆/#2顆/#3架/#1架/#0架/#2架/#3荷;荷物/#1荷/#0荷/#2荷/
#かい /#1回/#0回/#1階/#0階/#2階/#3回/#1Ｆ/#3階/#2回/
#かいせい /#0回生/#1回生/#3回生/
#かいせん /#0回線;lines/#1回戦;rounds/
#かいだて /#3階建/#0階建/#3階建て/#0階建て/
#かいてん /#0回転/#3回転/
#かいはつ /#3開発/
#かいぶん /#3回分/#0回分/
#かいめ /#0回目/#3回目/
#かかん /#1日間/
#かく /#3格/#1格/#0格/#2格/#3画/#1画/#0画/#2画/
#かくけい /#3角形/
#かげつ /#1ヶ月/#0ヶ月/#3ヶ月/#0カ月/#3箇月/#0 ヶ月/
#かこく /#0カ国/#2カ国/
#かさね /#3重/#1重/#0重/#2重/
#かしょ /#0箇所/#1ヶ所/#1個所/#0ヶ所/#0カ所/#2カ所/
#かじょう /#2カ条/
#かっけい /#3角形/
#かねん /#0カ年/
#かぶ /#3株/#1株/#0株/#2株/
#かぶん /#3日分/#0日分/
#かめ /#1日目/
#かもく /#0科目/
#から# /#1〜#1/
#からむ /#1カラム/
#かん /#1巻/#3巻/#3冠/#3缶/#1缶/#0缶/#2缶/#0巻/#2巻/#1冠/#0冠/#2冠/#3管/#1管/#0管/#2管/#3貫;3.75kg/#1貫/#0貫/#2貫/
#がい /#0階/#1階/#3階/#2階/
#がいだて /#3階建/#0階建/#3階建て/#0階建て/
#がた /#3型/#1型/#0型/#2型/
#がつ /#0月/#1月/#3月/#2月/
#がつ#か /#1月#1日/#0月#0日/
#がつ#にち /#1月#1日/#0月#0日/#2月#2日/#2月#1日/
#がつごう /#0月号/#3月号/#1月号/
#がつちゅう /#0月中/
#がつまつ /#1月末/
#がめん /#1画面/
#がん /#3貫/#1貫/#0貫/#2貫/
#き /#3期/#1期/#0機/#0期/#1基/#2期/#3機/#1機/#2機/#3基/#0基/#2基/
#きゃく /#3脚/#1脚/#3客/#1客/#0客/#2客/#0脚/#2脚/
#きゅう /#3級/#1級/#0級/#2級/#3球/#1球/#0球/#2球/
#きょう /#3強/#1強/#0強/#2強/
#きょうか /#0教科/
#きょく /#1曲/#3曲/#0曲/#2曲/#3局/#1局/#0局/#2局/
#きれ /#3切/#1切/#0切/#2切/
#きろ /#1キロ/#2キロ/#1Km/#1kg/#1kbyte/#1Ｋ/#1ｋ/
#きろばいと /#1kb/#1kbytes/#3kb/#0kb/#2kb/
#きん /#3金/#1金/#0金/#2金/#3禁/#1禁/#0禁/#2禁/#3斤;600g/#1斤;600g/#0斤;600g/#2斤;600g/
#ぎが /#1Ｇ/
#ぎょう /#0行/#1行/#2行/#3行/
#ぎょうめ /#0行目/#1行目/
#ぎん /#3斤/#1斤/#0斤/#2斤/
#く /#3区/#1区/#0区/#2区/#3句/#1句/#0句/#2句/#3口/#1口/#0口/#2口/
#くち /#1口/#3口/#0口/#2口/
#くみ /#1組/#3組/#0組/#2組/
#ぐ /#3具/#1具/#0具/#2具/
#ぐらむ /#1グラム/
#け /#3ヶ/#1ヶ/#0ヶ/#2ヶ/
#けいとう /#0系統/#1系統/
#けた /#3桁/#1桁/#2桁/#0桁/
#けん /#0件/#1件/#1軒/#3間;6尺/#3軒/#3件/#2件/#0軒/#2軒/#1間;6尺/#0間;6尺/#2間;6尺/#3鍵/#1鍵/#0鍵/#2鍵/#0 件/
#けんめ /#1軒目/
#げん /#1限/#3元/#1元/#0元/#2元/#3弦;string/#1弦/#0弦/#2弦/#3軒/#1軒/#0軒/#2軒/#3限/#0限/#2限/
#げんそく /#1原則/
#げんめ /#1限目/
#こ /#3個/#1個/#0個/#2個/#3戸/#1戸/#0戸/#2戸/#3ヶ/#1ヶ/#0ヶ/#2ヶ/#3コ/#1コ/#0コ/#2コ/
#こう /#0項/#0校/#1項/#3項/#2項/#3校/#1校/#2校/
#こうかんけい /#0項関係/
#こく /#3石/#1石/#0石/#2石/
#こし /#3腰/#1腰/#0腰/#2腰/
#こま /#0コマ/#1コマ/#3コマ/#3齣/#1齣/#0齣/#2齣/
#こり /#3梱/#1梱/#0梱/#2梱/
#こん /#3献/#1献/#0献/#2献/
#ご /#0語/#1語/#3語/#2語/
#ごう /#3号/#0号/#1号/#2号/#3合/#0合/#1合/#2合/#5號;「号」の旧字/#3號;「号」の旧字/#2號;「号」の旧字/#0號;「号」の旧字/#1號;「号」の旧字/
#ごうかん /#0号館/#1号館/#1号缶/#0号缶/
#ごうき /#1号機/
#ごうしつ /#0号室/#2号室/
#ごうしゃ /#0号車/#1号車/
#ごうせん /#0号線/
#ごく /#3石/#1石/#0石/#2石/
#さ /#3差/#1差/#0差/#2差/
#さい /#0歳/#1才/#1歳/#2歳/#3歳/#3才/#0才/#2才/
#さお /#3棹/#1棹/#0棹/#2棹/
#さく /#3作/#1作/#0作/#2作/
#さつ /#1冊/#3冊/#0冊/#3札/#1札/#0札/#2札/#2冊/#3刷/#1刷/#0刷/#2刷/
#さつめ /#3冊目/
#さら /#3皿/#1皿/#0皿/#2皿/
#さん /#3山/#1山/#0山/#2山/
#し /#0氏/#3子/#3死/#1死/#0死/#2死/#3氏/#1氏/#2氏/#1子/#0子/#2子/
#しあい /#0試合/
#しき /#3式/#1式/#0式/#2式/#3色/#1色/#0色/#2色/
#しってん /#1失点/
#しつ /#0室/#1室/#3室/#2室/
#しな /#3品/#1品/#0品/#2品/
#しゃ /#1者/#3者/#0者/#2者/#3社/#1社/#0社/#2社/
#しゃく /#3尺/#1尺/#0尺/#2尺/
#しゅ /#3種/#0種/#1種/#2種/#3首/#1首/#0首/#2首/
#しゅう /#1週/#3集/#1集/#0集/#2集/#3週/#0週/#2週/#3周/#1周/#0周/#2周/#3輯/#1輯/#0輯/#2輯/
#しゅうかん /#1週間/#0週間/#3週間/
#しゅうかんご /#0週間後/
#しゅうねん /#1周年/#3周年/
#しゅるい /#0種類/#1種類/#2種類/
#しょう /#1章/#0章/#1勝/#3章/#2章/#3床/#1床/#0床/#2床/#3勝/#0勝/#2勝/
#しょう#せつ /#1章#1節/
#しょう#はい /#1勝#1敗/
#しょうめん /#3正面/
#しょく /#1色/#0色/#3食/#1食/#0食/#2食/#3色/#2色/
#しん /#0進/#1進/#3進/#2進/
#しんすう /#0進数/#1進数/#3進数/
#しんほう /#0進法/#1進法/#3進法/
#じ /#0時/#1時/#2時/#0次/#3次/#1次/#3時/#0字/#3字/#1字/#2字/#2次/#3児/#1児/#0児/#2児/#3寺/#1寺/#0寺/#2寺/
#じ#ふん /#0時#0分/#1時#1分/
#じ#ぷん /#0時#0分/
#じかい /#1次会/#3次会/
#じかん /#0時間/#1時間/#3時間/#2時間/
#じかんはん /#1時間半/
#じかんめ /#1時間目/
#じく /#3軸/#1軸/#0軸/#2軸/
#じげん /#1次元/#0次元/
#じごろ /#0時頃/
#じしけん /#1次試験/#3次試験/
#じたこうしき /#3次多項式/
#じはん /#1時半/#0時半/#3時半/
#じほうていしき /#3次方程式/
#じみゃく /#3次脈/
#じゃく /#3弱/#1弱/#0弱/#2弱/#3尺/#1尺/#0尺/#2尺/
#じゅう /#1重/#3重/#0重/#2重/
#じゅん /#3巡/#1巡/#0巡/#2巡/
#じゅんめ /#3巡目/
#じょ /#2女/#3女/#1女/#0女/
#じょう /#3畳/#0条/#0畳/#0乗/#1畳/#3錠/#1錠/#0錠/#2錠/#3乗/#1乗/#2乗/#3条/#1条/#2条/#2畳/#3帖/#1帖/#0帖/#2帖/
#じよせん /#1次予選/#3次予選/
#すう /#1数/#3数/#0数/#2数/
#すうか /#3数花/
#すうせい /#1数性/
#すじ /#3筋/#1筋/#0筋/#2筋/
#すてーじ /#1ステージ/
#すてっぷ /#1ステップ/
#すん /#2寸/#3寸/#1寸/#0寸/
#ず /#3図/#1図/#0図/#2図/
#ずん /#3寸/#1寸/#0寸/#2寸/
#せい /#1声/#3世/#1世/#0世/#2世/#3声/#0声/#2声/
#せいき /#0世紀/#1世紀/
#せいりょく /#3勢力/
#せき /#3隻;船/#1隻;船/#0隻;船/#2隻;船/#3席/#1席/#0席/#2席/#3石/#1石/#0石/#2石/
#せたい /#0世帯/
#せだい /#1世代/
#せだいめ /#3世代目/
#せっと /#1セット/
#せつ /#1節/#3節/#0節/#2節/
#せん /#1千/#3選/#3線/#1線/#0線/#2線/#3千/#0千/#2千/#3銭/#1銭/#0銭/#2銭/#1選/#0選/#2選/
#せんえん /#1千円/#2千円/
#せんち /#1cm/#1センチ/#3cm/#0cm/#2cm/
#せんまん /#3千万/
#ぜん /#3膳/#1膳/#0膳/#2膳/
#そう /#3層/#0相/#0層/#3艘;船/#1艘;船/#3双;手袋/#1双;手袋/#0艘;船/#1漕/#1層/#2層/#3相/#1相/#2相/#2艘/#0双/#2双/#3漕/#0漕/#2漕/
#そうさ /#1走査/
#そく /#3足;履物/#1足;履物/#3速;ギア/#1速;ギア/#0速/#2速/#0足/#2足/#3束/#1束/#0束/#2束/
#そろい /#3揃/#1揃/#0揃/#2揃/
#ぞく /#1属/#3属/#0属/#2属/
#たい /#0体/#3体/#1体/#2体/
#たく /#3択/#1択/#0択/#2択/
#たば /#1束/#3束/#0束/#2束/
#たま /#3玉/#1玉/#0玉/#2玉/
#たん /#3反/#1反/#0反/#2反/
#だ /#0打/#3打/#3駄/#1駄/#0駄/#2駄/#1打/#2打/
#だい /#0台/#0代/#1台/#3代/#3題/#0題/#1代/#3台/#3大/#1大/#0大/#2大/#1題/#2題/#2台/#2代/
#だいめ /#3台目/#3代目/
#ださ /#0打差/#3打差/
#だすう /#0打数/
#だてん /#0打点/
#だん /#3段/#0段/#1段/#2段/
#だんかい /#1段階/
#だんぐみ /#0段組み/
#だんめ /#1段目/#0段目/
#ち /#0値/#3値/#1値/#2値/
#ちーむ /#0チーム/
#ちっぷ /#1チップ/
#ちゃく /#0着/#3着/#1着/#2着/
#ちょ /#3著/#1著/#0著/#2著/
#ちょう /#3兆;10^12/#1兆;10^12/#0兆;10^12/#2兆;10^12/#3丁/#1丁/#0丁/#2丁/#3挺/#1挺/#0挺/#2挺/#3張/#1張/#0張/#2張/
#ちょうえん /#1兆円/#3兆円/
#ちょうめ /#1丁目/#0丁目/#2丁目/#3丁目/
#つ /#1つ/#0つ/#2つ/#3つ/#3ツ/#1ツ/#0ツ/#2ツ/
#つい /#3対/#1対/#0対/#2対/
#つう /#1通/#0通/#3通/#2通/
#つうめ /#1通目/
#つがい /#3番/#1番/#0番/#2番/
#つき /#3月/#0月/#1月/#2月/
#つつみ /#3包/#1包/#0包/#2包/
#つぶ /#3粒/#1粒/#0粒/#2粒/
#つぼ /#1坪/#3坪/#0坪/#2坪/
#つめ /#1つ目/
#て /#3手/#1手/#0手/#2手/
#てい /#3訂/#1訂/#0訂/#2訂/
#ていばん /#3訂版/
#てん /#0点/#1点/#3点/#2点/#3店/#1店/#0店/#2店/
#てんせっと /#0点セット/
#と /#3斗;10升/#1斗;10升/#0斗;10升/#2斗;10升/
#とう /#1等/#0頭/#3党/#3頭/#1頭/#1党/#0党/#2党/#3等/#0等/#2等/#3灯/#1灯/#0灯/#2灯/#2頭/
#とうしん /#1頭身/
#とおり /#1通り/
#とん /#3噸;ton(1000kg)/#1噸;ton(1000kg)/#0噸;ton(1000kg)/#2噸;ton(1000kg)/
#ど /#1度/#3度/#0度/#2度/#3°;degree/#1°;degree/#0°;degree/#2°;degree/#3℃;celsius/#1℃;celsius/#0℃;celsius/#2℃;celsius/
#どめ /#1度目/#3度目/
#なん /#2男/#3男/#1男/#0男/
#にち /#1日/#0日/#3日/#2日/
#にちかん /#3日間/#0日間/
#にちぶん /#1日分/
#にん /#0人/#1人/#3人/#2人/
#にんぐみ /#1人組/
#にんぶん /#0人分/#1人分/
#にんめ /#3人目/
#ねん /#1年/#0年/#3年/#2年/
#ねん#がつ#にち /#0年#0月#0日/#1年#1月#1日/
#ねん#くみ /#1年#1組/
#ねんかん /#0年間/#1年間/
#ねんご /#3年後/
#ねんせい /#0年生/#3年生/#1年生/
#ねんだい /#0年代/
#ねんど /#0年度/#1年度/#2年度/
#ねんはん /#0年半/
#ねんぶん /#3年分/#0年分/
#ねんまえ /#3年前/#1年前/
#ねんめ /#0年目/#1年目/
#はい /#1敗/#3杯;飲物,イカ,タコ,船/#1杯;飲物,イカ,タコ,船/#0杯/#2杯/#3敗/#0敗/#2敗/
#はいめ /#3杯目/
#はく /#0泊;宿泊/#1泊;宿泊/#0拍;脈拍/#3泊;宿泊/#3拍;脈拍/#1拍;脈拍/#2拍;脈拍/#2泊;宿泊/
#はく#か /#3泊#3日/
#はこ /#1箱/#3箱/#0箱/#2箱/
#はしら /#3柱/#1柱/#0柱/#2柱/
#はち /#3鉢/#1鉢/#0鉢/#2鉢/
#はつ /#0発/#3発/#1発/#2発/
#はり /#1針/#3張り;弓・幕等/#1張り;弓・幕等/#3針/#0針/#2針/#3張/#1張/#0張/#2張/
#はん /#3犯/#1犯/#0犯/#2犯/#3版/#1版/#0版/#2版/#3翻/#1翻/#0翻/#2翻/
#ばい /#1倍/#1杯/#3倍/#0倍/#2倍/#3杯/#0杯/#2杯/
#ばいすう /#1倍数/
#ばいたい /#0倍体/#3倍体/
#ばいと /#1バイト/#0バイト/
#ばん /#3晩/#1番/#0番/#2番/#3番/#1晩/#0晩/#2晩/
#ばんがい /#0番街/#3番街/
#ばんだい /#0番台/
#ばんち /#0番地/
#ばんて /#3番手/
#ばんどおり /#0番通り/#3番通り/
#ばんめ /#0番目/#1番目/#3番目/
#ぱーせんと /#1％;percent/#3％;percent/#0％;percent/#2％;percent/
#ぱい /#3敗/#1敗/#0敗/#2敗/#3杯/#1杯/#0杯/#2杯/
#ぱく /#0拍/#0泊/#3拍/#1拍/#2拍/#3泊/#1泊/#2泊/
#ぱこ /#3箱/#1箱/#0箱/#2箱/
#ぱっく /#0パック/
#ぱつ /#0発/#3発/#1発/#2発/
#ぱん /#3版/#1版/#0版/#2版/#3犯/#1犯/#0犯/#2犯/
#ひき /#1匹/#3匹/#0匹/#2匹/
#ひゃくねん /#3百年/
#ひょう /#0票;vote/#3票;vote/#1票;vote/#2票;vote/#3俵;たわら/#1俵;たわら/#0俵;たわら/#2俵;たわら/
#ひん /#3品/#1品/#0品/#2品/
#び /#3尾/#1尾/#0尾/#2尾/
#びーと /#0ビート/
#びき /#1匹/#3匹/#0匹/#2匹/
#びっと /#1ビット/
#びょう /#0秒/#1秒/#3秒/#0票/#2秒/#3票/#1票/#2票/
#びょうかん /#0秒間/
#びょうし /#1拍子/#3拍子/
#びん /#1便/#3便/#0便/#2便/
#ぴき /#1匹/#3匹/#0匹/#2匹/
#ぴょう /#1票/#0票/#3票/#2票/#3俵/#1俵/#0俵/#2俵/
#ぴん /#3品/#1品/#0品/#2品/
#ふ /#3符/#1符/#0符/#2符/
#ふぃーと /#3呎/#1呎/#0呎/#2呎/
#ふく /#3服/#1服/#0服/#2服/#3幅/#1幅/#0幅/#2幅/
#ふくろ /#1袋/#3袋/#0袋/#2袋/
#ふり /#3振り;刀剣類/#3振/#1振/#0振/#2振/
#ふん /#1分/#0分/#3分/#2分/
#ふん#びょう /#1分#1秒/#0′#0″/
#ふんかん /#0分間/
#ぶ /#0部/#3部/#2分/#3分/#1分/#0分/#1部/#2部/
#ぶおんぷ /#3分音符/#1分音符/#0分音符/
#ぶきゅうふ /#3分休符/#1分休符/#0分休符/
#ぶもん /#0部門/
#ぶんかつ /#3分割/
#ぶんの# /#1分の#1/#3分の#3/
#ぶんの#びょうし /#0分の#0拍子/#3分の#3拍子/#1分の#1拍子/
#ぶんや /#0分野/
#ぷ /#3符/#1符/#0符/#2符/
#ぷく /#3幅/#1幅/#0幅/#2幅/#3服/#1服/#0服/#2服/
#ぷん /#0分/#1分/#3分/#2分/
#ぷんかん /#0分間/
#へい /#3瓶/#1瓶/#0瓶/#2瓶/
#へるつ /#1Hz/#3Hz/#0Hz/#2Hz/
#へん /#0編/#1片/#0辺/#1編/#3辺/#1辺/#2辺/#3編/#2編/#3篇/#1篇/#0篇/#2篇/#3片/#0片/#2片/#3遍/#1遍/#0遍/#2遍/
#べん /#3遍/#1遍/#0遍/#2遍/
#ぺーじ /#1ページ/#0ページ/#3ページ/#0頁/#3頁/#1頁/#2頁/
#ぺん /#3片/#1片/#0片/#2片/#3辺/#1辺/#0辺/#2辺/#3遍/#1遍/#0遍/#2遍/#3編/#1編/#0編/#2編/#3篇/#1篇/#0篇/#2篇/
#ほ /#3歩/#1歩/#0歩/#2歩/
#ほう /#3包/#1包/#0包/#2包/
#ほん /#0本/#1本/#3本/#2本/
#ほんだて /#1本立て/
#ほんば /#3本場;[麻雀]/
#ぼん /#1本/#2本/#0本/#3本/
#ぽ /#3歩/#1歩/#0歩/#2歩/
#ぽん /#1本/#0本/#3本/#2本/
#ぽんど /#0ポンド/#0£;pond,pound/#3£;pond,pound/#1£;pond,pound/#2£;pond,pound/
#まい /#1枚/#0枚/#2枚/#3枚/
#まいぐみ /#0枚組/#1枚組/
#まいぶん /#0枚分/
#まいめ /#2枚目/
#まいる /#3哩/#1哩/#0哩/#2哩/
#まき /#3巻き;糸や巻物など/#1巻き;糸や巻物など/
#まく /#3幕/#1幕/#0幕/#2幕/
#まくもの /#3幕物/
#ます /#0マス/#3枡/#1枡/#0枡/#2枡/
#まん /#1万/#0万/#3万/#2万/
#まんえん /#1万円/#0万円/#3万円/
#まんごく /#3万石/
#まんねん /#3万年/
#みり /#1mm/#3粍/#1粍/#0粍/#2粍/#3mm/#0mm/#2mm/
#むね /#0棟/#3棟/#1棟/#2棟/
#めーとる /#1メートル/
#めい /#0名/#1名/#3名/#2名/
#めいさま /#3名様/
#めが /#1Mbyte/#1メガ/
#めん /#1面/#3面/#0面/#2面/
#もう /#3毛/#1毛/#0毛/#2毛/
#もじ /#1文字/#0文字/#3文字/
#もじめ /#0文字目/#1文字目/#3文字目/
#もん /#1問;question/#3門;gate/#1門;gate/#0門;gate/#2門;gate/#3問;question/#0問;question/#2問;question/#3文/#1文/#0文/#2文/
#や /#3夜/#1夜/#0夜/#2夜/
#よう /#3葉/#1葉/#0葉/#2葉/
#り /#1人/#3里/#1里/#0里/#2里/
#りーる /#1リール/#0リール/
#りゅう /#3粒/#1粒/#0粒/#2粒/
#りょう /#3両/#1両/#0両/#2両/
#りょうへんせい /#0両編成/
#りん /#1輪/#3厘/#1厘/#0厘/#2厘/#3輪/#0輪/#2輪/
#りんか /#3輪花/
#るい /#3類/#1類/#0類/#2類/#3塁/#1塁/#0塁/#2塁/
#るいだ /#2塁打/#0塁打/
#れつ /#0列/#3列/#1列/#2列/#0裂/#1裂/#3裂/#2裂/
#れつめ /#3列目/
#れん /#0連/#3連/#1連/#2連/
#れんきゅう /#1連休/
#れんしょう /#1連勝/
#れんそう /#0連装/
#れんだ /#3連打/#0連打/
#れんちゃん /#3連荘;[麻雀]/
#れんぱい /#1連敗/
#れんぱつ /#3連発/#0連発/
#れんぷ /#1連符/#3連符/#0連符/
#ろう /#3浪/#1浪/#0浪/#2浪/
#ろばん /#0路盤/
#わ /#0話/#1話/#3羽;鳥,ウサギ/#3話/#2話/#1羽;鶏1羽/#0羽;鶏1羽/#2羽;鶏1羽/#3把;葱1把/#1把;葱1把/#0把;葱1把/#2把;葱1把/
#わり /#0割/#3割/#1割/#2割/
#わりびき /#1割引/#3割引/#1割り引き/
#わりまし /#1割増/
$ /＄;dollar/¢;※cent/£;※pond,pound/
% /％/‰;※permill/パーセント/
& /＆/アンド/アンパサンド/
' /′;minute/‘/’/アポストロフィ/´;accent aigu/
'' /″;second/”;doublequote(closing)/
's /ズ/
( /（/［/『/【/〔/
(#) /（#2）/
(#)#-# /（#1）#1-#1/
) /）/］/』/】/
* /＊/※/×/
+ /＋;plus/┼;罫線/╋;罫線(太)/┿;罫線(横太)/╂;罫線(縦太)/
+- /±/
, /，/、/
- /−;minus/―;dash/‐;hyphen/─;罫線/━;太い罫線/マイナス/ー;長音/ … /〜/
-- /―;dash/――/
--- /――/
---- /――/
-: /÷/
-> /→/
-| /┤/┫/
. /．/・/。/…;.../
.# /．#1/
.. /‥/
... /…/・・・;中黒x3/……;三点ダッシュx2 →....../
...... /……/
.com /ドットコム/
.net /ドットネット/
/ /／/÷/
/. /スラッシュドット;slashdot.org/slashdot/スラド/
/= /≠/
0 /０;アラビア数字/〇;漢数字/ゼロ/zero/零/
0base /ゼロベース/
0emission /ゼロエミッション/
0metre /ゼロメートル;sea level/
0sum /ゼロサム/
0sumgame /ゼロサムゲーム;zero-sum game/
1 /１/一/壱;「一」の大字/弌;「一」の異体字/壹;「壱」の旧字/ワン/one/
10 /十/テン/ten/
100 /百/ハンドレッド/hundred/
1000 /千/サウザンド/thousand/
10^-1 /deci;[SI接頭語]/d/デシ/
10^-12 /pico;[SI接頭語]/p/ピコ/
10^-15 /femto;[SI接頭語]/f/フェムト/
10^-18 /atto;[SI接頭語]/a/アト/
10^-2 /centi;[SI接頭語]/c/センチ/
10^-21 /zepto;[SI接頭語]/z/ゼプト/
10^-24 /yocto;[SI接頭語]/y/ヨクト/
10^-3 /milli;[SI接頭語]/m/ミリ/
10^-6 /micro;[SI接頭語]/μ/マイクロ/ミクロ/
10^-9 /nano;[SI接頭語]/n/ナノ/
10^1 /deca;[SI接頭語]/da/デカ/
10^12 /tera;[SI接頭語]/T/テラ/
10^15 /peta;[SI接頭語]/P/ペタ/
10^18 /exa;[SI接頭語]/E/エクサ/
10^2 /hecto;[SI接頭語]/h/ヘクト/
10^21 /zetta;[SI接頭語]/Z/ゼタ/
10^24 /yotta;[SI接頭語]/Y/ヨタ/
10^3 /kilo;[SI接頭語]/K/キロ/
10^6 /mega;[SI接頭語]/M/メガ/
10^9 /giga;[SI接頭語]/G/ギガ/
10th /テンス/
11 /十一/イレブン/イレヴン/eleven/
12 /十二/トウェルブ/トウェルヴ/twelve/
13 /十三/サーティーン/thirteen/
14 /十四/フォーティーン/fourteen/
15 /十五/フィフティーン/fifteen/
16 /十六/シックスティーン/sixteen/
17 /十七/セブンティーン/セヴンティーン/seventeen/
18 /十八/エイティーン/eighteen/
19 /十九/ナインティーン/nineteen/
1bound /ワンバウンド;和製英語(one-hopper)/
1box /ワンボックス/
1boxcar /ワンボックスカー/
1chip /ワンチップ/
1click /ワンクリック/
1coin /ワンコイン/
1cup /ワンカップ;[商標]大関 (言い換え語:カップ酒)/
1cushion /ワンクッション;和製英語。「-置く」/
1drink /ワンドリンク/
1key /ワンキー/
1man /ワンマン/
1manlive /ワンマンライブ/
1manshow /ワンマンショー;one-man show/
1more /ワンモア;one more/
1night /ワンナイト/
1out /ワンアウト/ワンナウト/
1pattern /ワンパターン/
1phrase /ワンフレーズ/
1piece /ワンピース/ワンピ/
1point /ワンポイント/
1pointadvice /ワンポイントアドバイス/
1push /ワンプッシュ/
1rank /ワンランク/
1room /ワンルーム/
1roommansion /ワンルームマンション/
1scene /ワンシーン;one scene/
1set /ワンセット/
1shot /ワンショット/
1shoulder /ワンショルダー/
1side /ワンサイド/
1sidegame /ワンサイドゲーム/
1size /ワンサイズ/
1st /ファースト/
1staid /ファーストエイド;first-aid/
1stalbum /ファーストアルバム/
1stbase /ファーストベース/
1stclass /ファーストクラス/ファースト・クラス/
1stcontact /ファーストコンタクト/
1step /ワンステップ/
1stfly /ファーストフライ/
1stgoro /ファーストゴロ;和製語(grounder)/
1stimpression /ファーストインプレッション/
1stkiss /ファーストキス;first kiss/
1stlady /ファーストレディ/
1stmit /ファーストミット/
1stname /ファーストネーム/
1stop /ワンストップ/
1tempo /ワンテンポ;和製語/
1time /ワンタイム/
1top /ワントップ/
1touch /ワンタッチ/
1way /ワンウェイ/ワンウェー/
2 /２/二/弍;「二」の異体字/ツー/two/
20 /二十/トウェンティ/twenty/
2base /ツーベース;double/
2bass /ツーバス/
2beat /ツービート/
2by4 /ツーバイフォー/
2nd /セカンド/
2ndbase /セカンドベース/
2ndclass /セカンドクラス/
2ndfly /セカンドフライ/
2ndgoro /セカンドゴロ;和製語(grounder)/
2ndhouse /セカンドハウス/
2ndlife /セカンドライフ/
2ndopinion /セカンドオピニオン/
2out /ツーアウト/
2piece /ツーピース/
2platoons /ツープラトン/
2run /ツーラン/
2shot /ツーショット/
2step /ツーステップ/
2tone /ツートン;two-tone/ツートーン/
2tonecolor /ツートンカラー;two-tone/
2tonecolour /ツートンカラー;two-tone/
2top /ツートップ/
2way /ツーウェイ/
2x4 /ツーバイフォー/
3 /３/三/スリー/three/
30 /三十/サーティ/thirty/
3base /スリーベース;triple/
3dots /・・・;中黒x3/
3f /スリーエフ/
3m /スリーエム;www.3m.com/
3out /スリーアウト/
3piece /スリーピース/
3rd /サード/
3rdbase /サードベース/
3rdfly /サードフライ/
3rdgoro /サードゴロ;和製語(grounder)/
3rdparty /サードパーティ/サードパーティー/
3run /スリーラン/
3season /スリーシーズン;three-season/
3size /スリーサイズ;和製英語(mesurements) NB:バスト・ウエスト・ヒップ/
3star /★ ★ ★/
4 /４/四/フォー/four/
40 /四十/フォーティ/fourty/
4beat /フォービート/
4th /フォース/
5 /５/五/ファイブ/five/
50 /五十/フィフティ/fifty/
5th /フィフス/
6 /６/六/シックス/six/
60 /六十/シックスティ/sixty/
6th /シックスス/
7 /７/七/セブン/seven/
70 /七十/セブンティ/seventy/
7bridge /セブンブリッジ/
7star /セブンスター/
7th /セブンス/
8 /８/八/エイト/eight/
80 /八十/エイティ/eighty/
8ball /エイトボール;eight-ball/
8beat /エイトビート/
8mm /８ｍｍ/
8th /エイス/
9 /９/九/ナイン/nine/
90 /九十/ナインティ/ninety/
9ball /ナインボール;nine-ball/
9th /ナインス/
: /：/…/
:- /÷/
:= /≒/
< /〈;山括弧/＜;不等号/←;<-/⊂;subset/《;二重山括弧 →<</クレッシェンド;次第に強く/crescendo/
<- /←/
<-> /⇔/
<< /《;二重山括弧/≪;much smaller/
<= /≦/
<=> /⇔/
<> /≠/◇;菱形/⇔/
= /＝;equal/〓;下駄/≡;合同/
=/ /≠/
=: /≒/
=> /⇒/》/
=| /〒/
> /〉;山括弧/＞;不等号/→/⇒/》;二重山括弧 →>>/≫;much larger/アクセント;その音を特に強く/accent/ディミヌエンド;次第に弱く/diminuendo/デクレッシェンド;次第に弱く/decrescendo/
>= /≧/
>> /》;二重山括弧/≫;much larger/
>あい /愛/
>あじ /味;醤油味,薄塩味/
>あつ /圧;(pressure) 脳圧,内部圧,人口圧/
>あて /宛/
>あと /跡;火傷跡,焚火跡,西郷邸跡/痕/後;もう20分後,死に後/
>あまり /余り/
>あん /案/
>い /委;(委員会) 欧州委/医/
>いか /以下;300円-/
>いがい /以外;関係者-,彼女-,麺類-/
>いき /域/行き/行/
>いくさ /軍;複合時はほとんどがこの字。「船軍,馬軍,死に軍」/
>いこう /以降;19世紀-,来月-/
>いご /以後/
>いじょう /以上;18才-/
>いぜん /以前;石器時代-,就任-/
>いち /市/
>いっしき /一式;道具-,書類-/
>いっしょく /一色;万博-,戦争-/
>いったい /一帯/
>いっぱ /一派/
>いっぱい /一杯;胸-,夢-,茶碗-/
>いない /以内;４位-,300円-/
>いらい /以来;建国-,結成-,十九世紀-/
>いろ /色/
>いん /員/印;銀行印,風景印,蔵書印/因;心因,内在因,究極因/
>うえ /上;兄上,1学年上(年齢),宮島口上(住所)/
>うじ /氏/
>うす /薄;期待薄,望み薄,可能性薄/
>うまれ /生まれ;博多-,満州-/
>うら /裏;路地裏,体育館裏,9回裏/
>え /絵;歌仙絵,役者絵/会;(集会) 香会,華厳会,菖蒲会/
>えいぎょうしょ /営業所/
>えき /駅/益;純益,売却益,営業益/液;電解液,除光液,標準液/
>えん /園/塩;硝酸塩,酸性塩,食卓塩/炎/宴;(party) 詩宴,曲水宴,花見宴/
>おう /王;長屋王,二冠王,遅刻王/
>おき /沖;十勝沖,島根県沖,台湾沖/置き;(間隔) 2時間-,三日-,４年-/
>おもて /表;畳表,3回表,江戸表/
>おやかた /親方/
>おり /織;西陣織,博多織,透かし織/
>おん /音/
>か /化/下/科/課/家/可/歌/禍;薬禍,女禍,文字禍/
>かい /会/界/回/階/海/解;(solution) [極最][大小長短]-/
>かいし /開始/
>かぎり /限り/
>かく /格;主役格,主犯格,城主格/核/角;同位角,結合角,変形角,２四角(将棋)/
>かぜ /風;向い風,先輩風,解散風/
>かた /方/型/過多;胃酸-,在庫-,自慰-/
>かてい /過程;(process) 崩壊-,構築-,移行-/
>かのう /可能/
>かぶ /下部;胴体-,組織-/
>かん /感;(sense) 躍動感/観;(view) 歴史観/間/館/官/刊;岩波書店刊,大正６年刊/艦/管/缶/
>かんきょう /環境;経済環境,再生環境/
>かんび /完備;寮-,空調-,託児所-/
>が /画/
>がい /街/外/
>がお /顔;(連濁) 思案顔,呆れ顔,得意顔/
>がかり /係;飼育係,相談係,お客様係/
>がく /学;法人類学,社会政策学,品質管理学/額;預金額,負債額,債務額/
>がくと /学徒/
>がしら /頭;(top)潮頭,(leader)人足頭,数奇屋頭/
>がた /型;(type)量産型,紋切り型/形;(form)亀甲形,短冊形,三日月形/方;八割方,豊臣方,夕暮れ方/
>がっか /学科;物理-/
>がま /窯;焼き物を焼くかま。「瓦窯」/釜;湯を沸かすかま。「茶釜」/
>がみ /紙/
>がら /柄;花柄,格子柄,職業柄/
>がわ /側/革/皮/
>がん /眼;鑑識眼,審美眼,遠視眼/
>き /器;(instrument) 抽籤器/機;(machine)印刷機, (chance)逆転機/期;period/記;(記録) 釣行記,魚服記/鬼;殺人鬼,隠形鬼(おんぎょうき),食人鬼/旗;flag/忌;開山忌,桜桃忌(太宰治の命日),十三回忌/紀;(紀律)校紀, (時代)帝紀,第４紀/
>きかん /期間/
>きごう /記号;合同-,ト音-/
>きじゅん /基準;業界-,採録-/
>きち /基地;普天間-,米軍-,秘密-/
>きのう /機能;通信-,代表-/
>きゃく /客;買物客,旅行客,乗船客/
>きゅう /級/宮;(宮殿)平安宮, (天宮)天蠍宮/
>きょう /教/強/狂;(-mania) 色情狂,映画狂,政治狂/卿;枢機卿,護国卿,陸軍卿/境;夢幻境,人外境,三昧境/郷;(土地)温泉郷,(境地)酔郷,理想郷/
>きょく /局/
>きん /筋;上腕筋,肋間筋,呼吸筋/禁;１８禁,転載禁,四重禁/菌;納豆菌,梅毒菌,好熱菌/金;見舞金,一時金,手切れ金/
>きんこう /近郊/
>きんし /禁止;侵入-,駐停車-/
>きんぺん /近辺/
>ぎ /儀;地球儀,月球儀,天球儀/着/技;(technique) 画技,筆技,舌技/
>ぎみ /気味;自嘲-,風邪-/
>ぎょう /業;輸入業,販売業,回収業/
>ぎん /銀;(銀行の略称) 兵庫銀,東京三菱銀/
>く /区/苦;二重苦,惑業苦,借金苦/
>くみ /組/
>くらい /位/
>くん /君/訓;師訓,人生訓,熟字訓/
>ぐ /具;茶具,装身具,剣道具/
>ぐう /宮/
>ぐち /口/
>ぐつ /靴/
>ぐみ /組/組み/
>ぐん /郡;†(county)/群;†(group)/軍;女性軍,共和国軍/
>け /家/
>けい /系/形/型/計;温度計,電位計,体脂肪計/刑;絞首刑,斬首刑,石打ち刑/
>けいさつしょ /警察署/
>けいすう /係数;摩擦-,温暖化-/
>けいゆ /経由;高崎-,香港-/
>けいゆう /経由;=けいゆ/
>けん /権/圏;(bloc) 勢力圏,フランス語圏/券;(ticket) お米券/研;(研究所) 佐藤研,ベル研/拳;酔拳,百裂拳,薩摩拳/県/兼/
>けんじん /県人;栃木-/
>げ /気;楽し気,危な気,親し気/下;正五位下/
>げい /芸;足芸,一発芸,座敷芸/
>げき /劇/
>げん /減;(decrease) 税収減,収入減/源;(source) 動力源,エネルギー源/
>げんしょう /現象;心霊-,老化-,毛細管-/
>げんてい /限定/
>こ /個/庫/
>こう /港/工;旋盤工,写植工,板金工/高/口/稿;最終稿,未定稿/
>こうい /行為;裏切り-,反逆-,違反-/
>こうか /効果;節電-,ノーベル賞-,減税-/
>こうき /後期;明治-,博士-/
>こうこう /高校;徳島-,農業-/
>こうざ /講座/
>こうじょ /控除;扶養-,雑損-/
>こうない /構内;上野駅-,東大-,研究所-/
>こうにん /公認;民主党-/
>こうりつ /効率/
>こく /国/
>こつ /骨/
>こゆう /固有/
>こん /婚/
>ご /後/語/
>ごう /号/郷;(昔の行政区画)白川郷,十津川郷,白崎郷/
>ごえ /声/
>ごと /毎/事/
>ごろ /頃/
>さ /差/
>さい /歳;(年齢)/才/斎;(雅号) 六無斎,稗田八方斎/祭/
>さいかい /再開/
>さき /先/
>さく /策/作;鴎外作,苦心作/
>さま /様/
>さん /産/山/酸/
>ざ /座/
>ざい /剤/罪/材;集成材,黄楊材,檜材/財;(goods)代替財,文化財,自由財/
>ざいじゅう /在住/
>ざけ /酒/
>ざま /様;昔様,死に様,振り向き様/
>ざら /皿/
>ざん /残;収支-,支払-,信用-/
>し /市/氏/誌/紙/視/師/史/士;弁理士,救命士,代理士/死;毒死,腹上死,悶絶死/司;斎院司,児童社会福祉司,少年保護司/子/詞;言詞,指示詞,女性詞/
>しかく /資格;在留-,調理師-/
>しき /式/職;中宮職(律令制),大工職/
>ししゃ /支社;大阪-,函館-/
>しじょう /市場;大豆-,香港-,買手-/
>しせつ /施設;音響-,排水-,軍事-/
>した /下/
>しだい /次第;(up to) 状況-,君-, (完了)出来-/
>しつ /室/質;蛋白質,粘液質/
>してん /支店/
>しぶ /支部;名古屋-,中国-/
>しぼう /志望;第二-,画家-/
>しゃ /者/車/
>しゅ /主;造物主,救世主,先入主/手/酒/腫/
>しゅう /集/州/宗;法華宗,修験宗,三論宗/臭;素人臭,腐敗臭/衆;一向衆,玄人衆,職人衆/
>しゅうだん /集団/
>しゅうへん /周辺/
>しゅうりょう /終了/
>しゅぎ /主義/
>しゅぎしゃ /主義者;(-ist) 至上-,民族-,敬虔-/
>しゅしょう /首相;東条-,中国-/
>しゅっしん /出身/
>しゅどう /主導;政治-,民間-/
>しょ /書/所/署;小松川-,湾岸-/
>しょう /症/証/省/商/賞/小;(「小学校」の略)池田-,泉台-/相;(大臣) 厚労相,司法相,情報相/匠;(craftspeople) 織匠(おりしょう・しょくしょう),彫匠,剣匠/
>しょうがい /障害;意識-,[腎肝]機能-/
>しょき /初期;昭和-,離乳-,発病-/
>しょく /色;独自色,政治色,小泉色/食;宇宙食,療養食,減塩食/職;首相職,課長職,一般職/
>しょとう /初頭;19世紀-,2038年-/
>しよう /仕様;寒冷地-,輸出-/
>しん /心;愛郷心,反米心,不動心/審/
>じ /時/路;家路,木曽路,甲州路/辞;接尾辞,限定辞,形容辞/地;漆地,木綿地/
>じかん /次官;国務-,財務-,農水-/
>じく /軸;地軸,結晶軸,再編軸/
>じこう /事項;補足-,確認-,免責-/
>じしん /自身;私-,人物-,首相-/
>じたい /自体/
>じだい /時代;幼年-,田沼-,アケメネス朝-/
>じてん /辞典/
>じま /島/
>じゃく /弱/尺/
>じゅう /中/
>じゅく /塾;画塾,書道塾,英語塾/
>じゅつ /術/
>じゅん /順/
>じょ /所/
>じょう /上/状/場/嬢;鶯嬢,(人名一般に付いて)静香嬢/
>じょうきょう /状況;被害-,活動-,出願-/
>じょうしょう /上昇;価格-,沸点-/
>じょうせい /情勢;チェチェン-,中東-,経済-/
>じょうたい /状態;健康-,泥酔-,潰滅-/
>じょうぶ /上部;大腿-,機体-/
>じょし /女史;女性に付ける敬称。「中根-」/
>じる /汁/
>じん /人/陣/
>す /酢;辛子酢,合成酢,醤酢/
>すい /水;汚染水,処理水,環流水/
>すう /数/
>すえ /末;来月末/
>すじ /筋;外交筋,投機筋,牛筋/
>すんぜん /寸前;爆発-,卒倒-/
>ず /図/酢/
>ずく /尽く;欲-,相対-/
>ずみ /済/
>せい /性;絵画性/制;(system) 会員制/製;(made in,by) 中国製/生;(学生) 早大生/
>せいけん /政権;軍事-,大平-,民主党-/
>せいど /制度;奴隷-,返金-,安全保障-/
>せき /籍;日本籍,中国籍/席;優先席,無料席,可動席/
>せつ /説/
>せん /戦;(battle,game) 中盤戦,対米戦/線;(line)山手線,絶縁線/腺;[解剖](gland) 汗腺,唾液腺/選;(選挙)参院選, (選集)名詩選/専;商専(商業専門学校),売り専,熟女専/船;貨物船,日本船/
>せんこう /専攻;応物-,印哲-,18世紀-/先行;人気-,理論-,黒星-/
>せんしゅう /専修;露文-/
>せんせい /先生/
>せんよう /専用;自分-/
>ぜい /税/勢/
>ぜん /然;超然,紳士然,大家然(たいかぜん)/前;紀元前,出生前,使用前/膳;祝膳,酒肴膳,(料理のコース名)[松竹梅花]膳,海の幸膳/善;絶対善,公共善,至高善/
>ぜんき /前期;2007年度-,東大-/
>ぜんご /前後;(概数) 20人-/
>ぜんしゅう /全集/
>ぜんたい /全体/
>そ /素;語彙素,韻律素(prosodeme),繊維素/
>そう /層/相/槽/僧;帰依僧,学問僧,破戒僧/奏/
>そうそう /早々/
>そうとう /相当;三億円-/
>そうほう /双方;日中-,当事者-/
>そく /則/
>そだち /育ち;街-,和歌山-/
>そつ /卒;京大卒,理学部卒/
>そん /損;純損,累損,含み損/尊/
>ぞい /沿/
>ぞう /像;女性像,二宮尊徳像/増;税収増,前年比増/蔵;個人蔵,○○美術館蔵/贈/
>ぞく /族/
>ぞん /損;(連濁) 丸損,聞き損,評価損/
>たい /帯/隊/態;(voice) 受動態,中間態,可能態/対;巨人対阪神,信号対雑音比/
>たいおう /対応/
>たいこう /対抗;地域-,都市-,企業-/大綱;防衛-,戦略-,改革-/
>たいしょう /対象;蒐集-,攻撃-/
>たいせい /態勢;臨戦-,着陸-,支援-/体制;安保-,量産-,小泉-/
>たく /宅;部長宅,鈴木宅,被害者宅/
>たけ /茸;榎茸,一夜茸,山鳥茸/
>たち /達/
>たて /立て;出来-,洗い-,脱ぎ-/
>たん /譚/
>たんい /単位/
>たんとう /担当;営業-,人事-,入力-/
>だ /打;殊勲打,逆転打,有効打/
>だい /台/大/代/
>だいがく /大学/
>だか /高/
>だけ /岳/
>だん /談/団/
>ち /値/地/知;経験知,絶対知,直観知/
>ちく /地区;名古屋-,南部-/
>ちほう /地方;熱帯-,東北-/
>ちゃ /茶;白茶,人参茶,健康茶/
>ちゃく /着;成田着,香港着,空港着/
>ちゅう /中/注/
>ちゅうし /中止/
>ちょ /著;漱石著,高橋源一郎著/
>ちょう /町/長/調/超/帳;出納帳,漢字練習帳,料理帳/庁/
>ちょうか /超過;債務-,輸出-/
>ちょく /直;市場直,左直(野球)/
>ちょくご /直後/
>ちょくぜん /直前/
>ちん /賃;乗車賃,床屋賃,貸し賃/
>つい /対/
>つう /通;(expert)事情通/痛;(pain)神経痛/
>つき /付き/付/
>づき /付き/
>づら /面/
>づれ /連れ;(男|女|子供|家族)-/
>てい /邸/亭;三遊亭,好文亭/艇;上陸艇,掃海艇,消防艇/体;職人体/
>ていか /低下;学力-,価格-/
>ていし /停止;供給-,営業-/
>ていしょく /定食;酢豚-,唐揚-/
>ていど /程度/
>てき /的/
>てん /点/展/
>で /出;(出身) 大学出,音大出,法学部出/
>でん /殿;大安殿(だいあんでん),神楽殿,弘徽殿/伝;八犬伝,西域伝,漱石伝/
>と /都/徒;政治学徒/
>とう /等/党;労働党,大衆党,猫党(≒-好き)/棟;(building) 高層棟,居住棟/
>とうしょ /当初;発足-,制定/
>とうじ /当時/
>とうりょう /当量;(equivalent) 仕事-,化学-/
>とくゆう /特有/
>とどけ /届;婚姻届,退学届/
>とも /共/
>ど /度/土;構造土,砂壌土,珪藻土/
>どう /道/堂;郁文堂,六角堂,御影堂/
>どうし /同士/
>どうぜん /同然/
>どき /時;(連濁) 飯時,日暮時,辞め時/
>どくじ /独自/
>どくとく /独特/
>どころ /所/
>どの /殿/
>ども /共;男共,女共,雑魚共/
>どん /丼;親子-,カツ-,天-/
>ない /内/
>ないぞう /内蔵;電池-/
>なか /仲;恋仲,夫婦仲,兄弟仲/
>ながら /乍ら;(接続助詞)「歩き乍ら」「若い乍らも」/
>など /等/
>なみ /並み/並;馬並,世間並/
>なり /也/
>に /似;父親似,女優似,広末似/煮;大和煮,甘辛煮,炒め煮/
>ぬし /主;荷主,企業主,落し主/
>ね /音;色音,若音,忍び音/
>ねがい /願/
>ねつ /熱;気化熱,進学熱,地中熱/
>のう /能/
>は /派/波;電磁波,正弦波,第二波/
>はい /杯/拝;(書簡などで自分の名に付す) 夏目拝/
>はく /博/泊;(宿泊) 会社泊,現地泊,那覇泊/
>はだ /肌;乾燥肌,姉御肌,天才肌/
>はつ /発/初;世界初,青森初/
>はば /幅/
>はん /半/班/版/藩/
>はんい /範囲;行動-,出題-/
>ば /場;重力場,問屋場,公事場/
>ばい /倍/
>ばつ /閥;東大閥,官僚閥/
>ばなし /話/
>ばん /版;†(edition) 決定版,岩波版/盤;†(disk,board) 再発盤,将棋盤/判;†(size) 四六判,キャビネ判/
>ひ /比/費/
>ひつ /筆;(written by) 定家筆,天皇筆/
>ひょう /表/票/評;映画評,人物評,辛口評/
>ひん /品/
>び /日/美;肉体美,造形美,脚線美/
>びょう /病/
>ふ /府/
>ふう /風/
>ふか /不可/
>ふきん /付近;現場-,御徒町-/
>ふじん /夫人;社長-,鈴木-/
>ふぜい /風情;(軽蔑)役人-,(卑下)私-/
>ふのう /不能;修復-,観測-/
>ふん /墳/
>ぶ /部/
>ぶつ /物/
>ぶり /振り;(三日|数ヶ月|5年)-/
>ぶん /分;三日-/文;sentence/
>へい /兵;擲弾兵,人民兵,負傷兵/
>へき /壁;(wall) 防音壁,火口壁,子宮壁/癖;(habit) 病癖,妄想癖,逃避癖/
>へん /編;(あむこと)/篇;(あまれたもの) 天国篇,地獄篇,東北篇/
>べ /部;語り部,酒部,(部曲)大伴部/辺;岸辺,寄辺,船辺/
>べつ /別/
>べん /弁/
>ほ /補;(assistant) 警部補,次官補/舗;(shop) 菓子舗,佃煮舗,新聞舗/
>ほう /法/砲;迫撃砲,対戦車砲,無反動砲/
>ほうめん /方面/
>ほど /程/
>ほんい /本位;金-,お客様-/
>ぼ /簿/
>ぼう /某;(匿名)田中某,中島某/坊;(僧侶)正覚坊,風来坊,懲罰房/房;(部屋)雑居房,居住房,懲罰房/帽;(帽子) 学生帽,安全帽,婦人帽/
>ぼうし /防止;事故-,盗難-/
>ぼく /木;封印木,接骨木,旅人木/
>ぼん /本/
>ま /間;(space)切れ間,(room)応接間,伊勢間/魔;記録魔,強姦魔,切り裂き魔/
>まい /枚/
>まえ /前/
>まち /町/
>まっき /末期;室町-,妊娠-/
>まつ /末;19世紀末,年度末/
>まで /迄;明日迄,何所迄/
>まる /丸;(船舶名)海王丸,福竜丸,(幼名)日吉丸/
>み /味;外連味,皮肉味,苦味(NB:形容詞語幹につく場合「味」は当て字)/
>みすい /未遂;強盗-,傷害-/
>みん /民/
>むき /向き;[東西南北]-,(子供|大人|[男女]性)-/
>むけ /向け;(成人|企業|開発者)-/
>むひ /無比;強力-,壮大-,痛快-/
>むら /村/
>め /目;三日目,細目(NB:形容詞語幹につき傾向を表す場合「目」は当て字)/
>めい /名/
>めいぎ /名義/
>めん /面/
>もう /網/
>もく /目/
>もと /元/
>もの /物;輸入物,人情物/者;薄情者,伊賀者/
>もん /紋;(紋所) 九曜紋,三つ紋 (文様) 竜紋,鹿の子紋/門;(gate)玄武門,(門下生)蕪村門,[生物]触手動物門/
>や /屋/野;(大脳皮質の)感覚野,聴覚野,視覚野/
>やく /役;越後屋役,調整役,懸賞役/訳;仏語訳,大學訳/薬;頭痛薬,民間薬/
>やす /安;割安,反動安,10円安/
>ゆ /湯;腰湯,生姜湯,蜜柑湯/油;白樺油,肉桂油,不乾油/
>ゆえ /故;病弱-/
>ゆき /行き/行/
>よ /余;百人余,三年余/
>よう /用/様;唐様,天竺様,言い様/
>ようご /用語;宗教学-,連珠-/
>ようひん /用品;介護-,スポーツ-/
>よく /欲;色欲,征服欲,支配欲/翼/浴/
>よこ /横;玄関横,銀行横,画面横/
>よてい /予定/
>よぼう /予防;虫歯-,性病-/
>より /寄り;[東西南北上下左右町海]-/
>らい /来;三年来,入社来,昨年来/
>らん /欄/
>り /裡;(〜のうちに)秘密裡,盛況裡,無意識裡/裏;秘密裏,極秘裏,隠密裏/吏;(役人) 執行吏,税関吏,官公吏/理;理学部/
>りつ /率;(ratio) 換算率,死亡率/立/律;(law) 因果律,五言律,自然律/
>りゃく /略;前文略,敬称略/
>りゅう /流;二刀流,火砕流,仙波流/瘤/
>りょう /料/量/領;日本領,松平領/陵;(墓地) 天皇-,中山-(孫文),武蔵野-(昭和天皇)/
>りょく /力/
>るい /類/
>れい /例/令;戒厳令,禁止令,待機令/
>れき /歴;(history) 運転歴,離婚歴/暦;(calendar) 宇宙暦,寛政暦,自然暦/
>ろ /炉;電気炉,反応炉,溶融炉/路/
>ろう /郎;(男性名作成用)/
>ろく /録/
>ろん /論/
>わ /羽/
>わき /脇/
>わく /枠;深夜枠,自由枠,広告枠,2人枠/
>わざ /技;(technique) 腰技,包丁技,対空技/
>わん /湾;若狭湾,諫早湾/
? /？/
@ /＠/
A /Å;†angstrom/Α;†Alpha/А;†(Cyrillic)/アンペア;電流の単位,SI基本単位/
ACM /Abstract Control Model;USB/
AIDS /エイズ/後天性免疫不全症候群/
ALFEE /アルフィー/
AND /論理積/
AP /アプリケーション/
Adam /アダム/
Alpha /Α/
America /アメリカ/
April /エイプリル/
Arbeit /アルバイト/
Atena /アテナ/
Audrey /オードリー/
Australia /オーストラリア/
B /Β;Beta (Greek)/Б;Be (Cyrillic)/
B-spline /Ｂ−スプライン/
BBQ /バーベキュー/
BKK /バンコク/
BSE /Bovine Spongiform Encephalopathy/
Bach /バッハ/
Barbara /バーバラ/
Barium /バリウム/
Be /Б;Cyrillic/
Benedict /ベネディクト/
Benz /ベンツ/
Berkeley /バークレー/
Beryl /ベリル/
Beta /Β/
Bezier /ベジエ/
Biff /ビフ/
Bonjours /ボンジュール;※Bonjour?/
Booby /ブービー/
Box /□/
Brown /ブラウン/
Budapest /ブダペスト/
CD /コンパクト・ディスク/Compact Disk/
CDC /Communication Device Class;USB/
CISC /複雑命令セット計算機/Complex Instruction Set Computer/
CORBA /Common Object Request Broker Architecture;アプリケーションを異なる言語・プロセス・OS間で動作させるための規格。プログラミング言語がCORBAを利用するためにIDLを使う。OMGが策定した。/
CS /コミュニケーションサーバ/
CTC /伊藤忠テクノサイエンス/
Caesar /シーザー/カエサル/
Calbee /カルビー/
Camille /カミーユ/
Carter /カーター/
Ch /Ч;Cha (Cyrillic)/
Cha /Ч;Cyrillic/
Chanel /シャネル/
Charlie /チャーリー/
Chi /Χ/
Chlamydia /クラミジア/
Christ /キリスト/
Christmas /クリスマス/
Claire /クレール/
Claudel /クローデル/
Constantine /コンスタンチン/
Crea /クレア/
Cyrillic /А;A/Б;Be/В;Ve/Г;Ge/Д;De/Е;Je/Ё;Jo/Ж;Zhe/З;Ze/И;I/Й;I-kratkoje (J)/К;Ka/Л;El/М;Em/Н;En/О;O/П;Pe/Р;Er/С;Es/Т;Te/У;U/Ф;Ef/Х;Xa/Ц;Tse/Ч;Cha/Ш;Sha/Щ;Scha/Ъ;Znak (Tvjordyj znak)/Ы;Y/Ь;Znak (Xjaxkij znak)/Э;E/Ю;Ju/Я;Ja/
D /Δ;Delta/Д;De (Cyrillic)/
DB /データベース/
DBA /データベース管理者/
DBMS /dbms/
DOM /Document Object Model;W3C/
DTD /Document Type Definition;XMLドキュメントのデータ構造を定めたもの。/
Daffy /ダフィー/
Dagger /ダガー/
De /Д;Cyrillic/
Delta /Δ/
Deutschland /ドイツ/独逸/
Diamond /◇;菱形/◆;菱形/
Dick /ディック/
Disney /ディズニー/
E /Ε;Epsilon/Э;Cyrillic/
EE /Η;Eta/
Edinburgh /エディンバラ/
Edward /エドワード/
Ef /Ф;Cyrillic/
Egypt /エジプト/
El /Л;Cyrillic/
Elizabeth /エリザベス/
Em /М;Cyrillic/
En /Н;Cyrillic/
Epsilon /Ε/
Er /Р;Cyrillic/
Es /С;Cyrillic/
Eskimo /エスキモー/
Esquimau /エスキモー/
Eta /Η/
Euro /ユーロ/
Europa /ヨーロッパ/
Eve /イブ/
Evil /エビル/
F /Φ;†Phi (Greek)/Ф;†Ef (Cyrillic)/
FEN /極東放送/Far East Network/
FSF /Free Software Foundation/
Fourier /フーリエ/
Franken /フランケン/
Frankenstein /フランケンシュタイン/
G /Γ;†Gamma (Greek)/Г;†Ge (Cyrillic)/
GHQ /総司令部/連合国軍総司令部/General Headquarters/
GLPL /GNU Library Public License/
GPL /GNU General Public License;(concat "http:\057\057www.gnu.org\057licenses\057gpl.ja.html")/
GUI /グラフィカルユーザインタフェース/
GW /ゲートウェイ/
Gamma /Γ/
Ge /Г;Cyrillic/
George /ジョージ/
Giants /ジャイアンツ/
Giraffu /ジラフ;※giraffe?/
Goddard /ゴダール;Godard?/
Greek /Α;Alpha/Β;Beta/Γ;Gamma/Δ;Delta/Ε;Epsilon/Ζ;Zeta/Η;Eta/Θ;Theta/Ι;Iota/Κ;Kappa/Λ;Lambda/Μ;Mu/Ν;Nu/Ξ;Xi/Ο;Omicron/Π;Pi/Ρ;Rho/Σ;Sigma/Τ;Tau/Υ;Upsilon/Φ;Phi/Χ;Chi/Ψ;Psi/Ω;Omega/
Grimm /グリム/
Guile /ガイル/
HP /ヒューレット・パッカード/
HTML /Hyper Text Markup Language;W3C/
Harvard /ハーバード/
Henry /ヘンリー/
Hudson /ハドソン/
Hungarian /ハンガリアン/
Hungary /ハンガリー/
I /Ι;Iota/アイ/И;Cyrillic/
I'm /アイム/
I-kratkoje /Й;Cyrillic/
IBM /アイ・ビー・エム/日本アイ・ビー・エム株式会社/
ICU /国際基督教大学;International Christian University/
IDFT /逆離散フーリエ変換;Inverse Discrete Fourier Transform/
IDL /Interface Definition Language;CORBAオブジェクトをコールするために必要な情報を提供する。/
ISO /国際標準化機構;International Organization for Standardization/
Indian /インディアン/
Internet /インターネット/
Iota /Ι/
Itriangle /▽/
J /Й;Cyrillic(I-kratkoje)/
JICC /ＪＩＣＣ出版;[出版社名]/
JIP /日本電子計算;www.jip.co.jp/
JISC /日本工業標準調査会;www.jisc.go.jp/
Ja /Я;Cyrillic/
Jadeite /ジェダイト/
James /ジェームス/
Jamiroquai /ジャミロクワイ;ミュージシャン,バンド名/
Jane /ジェーン/
Je /Е;Cyrillic/
Jenny /ジェニー/
Jimmy /ジミー/
Jo /Ё;Cyrillic/
Joe /ジョー/
John /ジョン/
Jr. /ジュニア/
Ju /Ю;Cyrillic/
Julian /ジュリアン/
Julie /ジュリー/
Jupiter /ジュピター/
K /Κ;†Kappa (Greek)/К;†Ka (Cyrillic)/ケルビン;(kelvin)熱力学温度の単位,SI基本単位/Χ;※(KH) Chi/
KH /Χ;Chi/
Ka /К;Cyrillic/
Kappa /Κ/
Katze /カッツェ/
Kh /Х;Xa (Cyrillic)/
Kiki /キキ/
Knuth /クヌース/
Kodak /コダック/
Kunzite /クンツァイト/
L /£;pond/Λ;Lambda/Л;El (Cyrillic)/
LPF /ローパス・フィルタ/
Lagrange /ラグランジュ/
Lambda /Λ/
Laura /ローラ/
Lebesgue /ルベーグ/
Lilliput /リリパット/
Linus /ライナス/
Lolita /ロリータ/
London /ロンドン/
Los_Angeles /ロサンゼルス/
Lucy /ルーシー/
Lynch /リンチ/
M /Μ;†Mu (Greek)/М;†Em (Cyrillic)/
ML /メイリングリスト/メーリングリスト/
MPT /マルチポートトランシーバー/
MSA /マイクロソフトウェア　アソシエイツ/マイクロソフトウェアアソシエイツ/日米相互防衛援助協定/Micro Software Associates/
Mach /マッハ/
Manhattan /マンハッタン/
Marcica /マーシカ/
Marie /マリー/マリ/
Mario /マリオ/
Mars /マーズ/
Martha /マーサ/
Martin /マーティン/
Mary /メアリ/
Melby /メルビー/
Mercury /マーキュリー/メルクリウス/
Miami /マイアミ/
Michael /マイケル/
Mickey /ミッキー/
Microsoft /マイクロソフト/
Milky /ミルキー/
Minerva /ミネルヴァ/
Motorola /モトローラ/
Mr. /ミスター/
Mrs. /ミセス/
Ms. /ミズ/
Mu /Μ/
N /Ν;Nu/Н;En (Cyrillic)/
NEC /日本電気/
NFS /Network File System/
NRT /成田/
NTT /日本電信電話/
NY /ニューヨーク/
Nausicaa /ナウシカ/
Nephrite /ネフライト/
Neuman /ノイマン/フォン・ノイマン/ヤーノッシュ・フォン・ノイマン/
Newsweek /ニューズウィーク/
Nijmegen /ナイメヘン/
Norman /ノルマン/
Norway /ノルウェー/
Nu /Ν/
O /Ο;†Omicron/О;†(Cyrillic)/Ω;※(OO) Omega/
OMG /the Object Management Group;CORBA策定のためのフレームワークを提供するために組織された。/(concat "http:\057\057www.omg.org\057")/
OO /Ω;Omega/
OR /オペレーションズリサーチ/論理和/
OS /オペレーティングシステム/
Olympic /オリンピック/
Omega /Ω/
Omicron /Ο/
Oo /◎/
P /Π;†Pi (Greek)/П;†Pe (Cyrillic)/
PH /Φ;Phi/
POA /Portable Object Adapter/
PS /P.S./Ψ;Psi/
Palabora /パラボーラ/
Patty /パティ/
Pe /П;Cyrillic/
Peanuts /ピーナッツ/
Peter /ピーター/ピョートル/ペーター/
Phi /Φ/
Philips /フィリップス/
Pi /Π/
Polaroid /ポラロイド/
Psi /Ψ/
R /Ρ;†Rho (Greek)/Р;†Er (Cyrillic)/
RDB /関係データベース;relational database/
RE /正規表現;regular expression/
RISC /限定命令セット計算機/Restricted Instruction Set Computer/
RPC /Remote Procedure Call/
RPG /ロールプレイングゲーム/
Rana /ラナ/
Rho /Ρ/
Richard /リチャード/
Ritchie /リッチー/
Robert /ロバート/ロベルト/
Robin /ロビン/
Rose /ローズ/
Russia /А;→Cyrillic/Б/В/Г/Д/Е/Ё/Ж/З/И/Й/К/Л/М/Н/О/П/Р/С/Т/У/Ф/Х/Ц/Ч/Ш/Щ/Ъ/Ы/Ь/Э/Ю/Я/
S /Σ;Sigma/С;Es (Cyrillic)/
SAX /The Simple API for event-based XML parsing/
SFO /サンフランシスコ/
SPA /製造小売業;繊研新聞社のデスク山崎光弘氏が翻案した略語/Specality Store Retailer of Private Label Apparel/
Sailormoon /セーラームーン/
Saint /聖/
Sally /サリー/
Sandy /サンディー/
Sappho /サッフォー/
Scha /Щ;Cyrillic/
Scotch /スコッチ/
Sh /Ш;Sha (Cyrillic)/
ShSh /Щ;Scha (Cyrillic)/
Sha /Ш;Cyrillic/
Sheena /シーナ/
Shsh /Щ;Scha (Cyrillic)/
Sibip /シビップ/
Sigma /Σ/
Singapore /シンガポール/
Sony /ソニー/
Square /□/
Stallman /ストールマン/
Suesan /スーザン/
Sweden /スウェーデン/
Sylpheed /シルフィード/
T /Τ;†Tau (Greek)/Т;†Te (Cyrillic)/
TA /ターミナルアダプタ/
TDL /東京ディズニーランド/
TH /Θ;Theta/
TV /テレビ/
Tau /Τ/
Te /Т;Cyrillic/
Theta /Θ/
Ti /Ｔｉ/
Tiananmen /天安門/
Tibet /チベット/
Toppe /トッピー/
Toronto /トロント/
Ts /Ц;Tse (Cyrillic)/
Tse /Ц;Cyrillic/
Turing /チューリング/
U /Υ;Upsilon/У;Cyrillic/
Unisys /ユニシス/
Upsilon /Υ/
V /В;Ve (Cyrillic)/
Valentine /バレンタイン/
Ve /В;Cyrillic/
Vega /ベガ/
Venus /ビーナス/ビィーナス/
Versailles /ベルサイユ/ヴェルサイユ/
Vietnam /ベトナム/
W3C /The World Wide Web Consortium/
WG /ワーキンググループ/
WS /ワークステーション/
WW# /第#2次世界大戦/
WW1 /第一次世界大戦/歐州大戰;旧字/
WW2 /太平洋戦争/第二次世界大戦/大東亜戰爭;旧字/
Watson /ワトソン/
X /Ξ;Xi/Х;Xa (Cyrillic)/
XEROX /ゼロックス/
XML /Extensible Markup Language/
Xa /Х;Cyrillic/
Xi /Ξ/
Y /Υ;Upsilon/Й;Cyrillic(I-kratkoje)/Ы;Cyrillic/
Yapoos /ヤプーズ/
Ye /Е;Cyrillic/
Yo /Ё;Cyrillic/
Yu /Ы;Y (Cyrillic)/
Z /Ζ;Zeta/З;Ze (Cyrillic)/
Ze /З;Cyrillic/
Zeta /Ζ/
Zh /Ж;Zhe (Cyrillic)/
Zhe /Ж;Cyrillic/
Znak /Ъ;Cyrillic(Tvjordyj znak)/Ь;Cyrillic(Xjaxkij znak)/
Zoisite /ゾイサイト/
[ /［/【/〔/『/
[[ /『/
[] /□/
\ /＼/￥/
\/ /∨/
] /］/】/〕/』/
]] /』/
^ /↑/∧/アクセント;その音を特に強く/accent/
^^ /↑/
^v /↓/
_ /＿/　;全角スペース/
` /‘;singlequote/｀;accent grave/
`` /“/
a /α;alpha/エー/エイ/アー;(独語)/а;cyrillic/ア/
a# /A#0/Ａ#1/
a#size /A#0サイズ/Ａ#1サイズ/
a4 /Ａ４/
aaa /トリプルA/
aachen /アーヘン/
aalen /アーレン/
aalto /アールト/
aaron /アロン/アーロン/
abacus /アバカス/
abba /アバ/
abbado /アバド/
abbas /アッバス/アッバース/アバス/
abbey /アビー/
abbeyroad /アビーロード/
abbie /アビー/
abbott /アボット/
abby /アビー/
abduction /アブダクション/
abdul /アブドゥル/
abdullah /アブドラ/アブダラ/アブドーラ/アブドゥラ/
abec /アベック;※avec? エイベック?/
abel /アーベル/アベル/
abelia /アベリア/
abend /アーベント/
abgata /ＡＢ型/
abidjan /アビジャン/
abigail /アビゲイル/
ability /アビリティ/
able /エイブル/
abnormal /アブノーマル/
aborigine /アボリジニ/アボリジニー/
abort /アボート/
about /アバウト/
above /アバブ/
abra /アブラ/
abraham /アブラハム/エイブラハム/
abrams /エイブラムス/
abril /アブリル/
abroad /アブロード/ＡＢｒｏａｄ/
absalom /アブサロム/
absinthe /アブサン/
absolute /アブソリュート/
absorber /アブソーバー/アブソーバ/
abstract /アブストラクト/抽象/
abstraction /アブストラクション/
abu /アブ/アブー/
abudabi /アブダビ/
abuja /アブジャ/
abyss /アビス/
abyssinia /アビシニア/
abyssinian /アビシニアン/
ac /アクチニウム/Actinium/
acacia /アカシア/
acadapter /ACアダプタ/ACアダプター/
academia /アカデミア/
academic /アカデミック/
academie /アカデミー/
academism /アカデミズム/
academy /アカデミー/
acappella /アカペラ;a cappella/
acapulco /アカプルコ/
acca /アッカ;www.acca.ne.jp/
accel /アクセル;accelerator/
accelerando /アチェレランド/アッチェレランド;[音楽]次第に速く/
accelerator /アクセラレータ/アクセル/アクセラレーター/
accent /アクセント/´;accent aigue/｀;accent grave/＾;accent circonflexe/¨;trema,umlaut/アクサン;仏語/
accentaigu /アクサンテギュ;accent aigue/´/
accentcirconflexe /アクサンシルコンフレックス;accent circonflexe/＾/
accentgrave /アクサングラーブ;accent grave/アクサングラーヴ/｀/
accept /アクセプト/
acceptable /アクセプタブル/
acceptor /アクセプター/アクセプタ/
access /アクセス/
accesscounter /アクセスカウンター/アクセスカウンタ/
accessibility /アクセシビリティ/アクセシビリティー/
accesslog /アクセスログ/
accessor /アクセサ/アクセッサ/アクセッサー/
accessory /アクセサリー/アクセサリ/
accesspoint /アクセスポイント/
accesstime /アクセスタイム/
accident /アクシデント/
accidental /アクシデンタル/
accidentally /アクシデンタリ/
accommodation /アコモデーション/
accord /アコード/
accordion /アコーディオン/
account /アカウント/
accountability /アカウンタビリティ;(言い換え:説明責任)/アカウンタビリティー/アカンタビリティ/
accounting /アカウンティング/
accoustic /アクースティック;※acoustic?/
accra /アクラ/
accumulator /アキュムレータ/
accuracy /アキュラシー/
ace /エース/
acepilot /エースパイロット/
acerola /アセロラ/
acestriker /エースストライカー/
acetal /アセタール/
acetaldehyde /アセトアルデヒド/
acetamido /アセトアミド/
acetaminophen /アセトアミノフェン;C8H9NO2/
acetate /アセテート/
aceto /アセト/
acetone /アセトン;CH3COCH3/
acetonitrile /アセトニトリル/
acetyl /アセチル;CH3CO-/
acetylcholine /アセチルコリン/
acetylcoa /アセチルCoA/
acetylene /アセチレン/
achaemenes /アケメネス/
achievement /アチーブメント/
achille /アシル/
achilles /アキレス/
achilleus /アキレス/アキレウス/
acid /アシッド/
acidjazz /アシッドジャズ/
ackerman /アッカーマン/
ackermann /アッカーマン/
aclass /Ａクラス/Aクラス/
acm /米国計算機学会;Association for Computing Machinery. www.acm.org/
acme /アクメ/
acne /アクネ/
acom /アコム;[企業名]消費者金融。www.acom.co.jp/
aconcagua /アコンカグア;-川(チリ)/
aconitine /アコニチン/
acosta /アコスタ/
acoustic /アコースティック/
acousticguitar /アコースティックギター/
acoustics /アコースティックス/
acquapazza /アクアパッツァ;(It) acqua pazza/アクアパッツア/
acre /エーカー/
acro /アクロ/
acrobat /アクロバット/
acrobatic /アクロバティック/
acrobatreader /アクロバットリーダー/
acrolein /アクロレイン/
acronym /アクロニム/
acropolis /アクロポリス/
across /アクロス/
acryl /アクリル/
acrylonitrile /アクリロニトリル/
act /アクト/
actin /アクチン/
actinium /アクチニウム;[元素]89,Ac/
actinoid /アクチノイド/
action /アクション/
actiongame /アクションゲーム/
actionprogram /アクションプログラム/
actionscene /アクションシーン/
activate /アクティベート/
activation /アクティベーション/
activator /アクティベーター/アクティベータ/
active /アクティブ/アクティヴ/
activewindow /アクティブウィンドウ/
activist /アクティビスト/
activity /アクティビティ/アクティビティー/
actor /アクター/アクタ/
actress /アクトレス/
actual /アクチュアル/
actuality /アクチュアリティ/
actually /アクチュアリー/
actualtime /アクチュアルタイム/
actuary /アクチュアリー;保険数理士/
actuator /アクチュエータ/アクチュエーター/
acup /Aカップ;10cm/Ａカップ/
acute /アキュート/
acyclovir /アシクロビル/
ad /アド/
ada /Ada/エイダ/アーダ/アダ/
adac /アドバンスド・データ・コントロールズ;www.adac.co.jp/
adagio /アダージョ/
adam /アダム/アダン/
adams /アダムス/
adapt /アダプト/
adaptation /アダプテーション/
adapter /アダプタ/アダプター/
adaptive /アダプティブ/アダプティヴ/
adaptor /アダプタ/アダプター/
adballoon /アドバルーン;和製英語(advertising balloon)/
adc /Ａ／Ｄコンバータ/
add /アッド/
adderley /アダレイ/
addessability /アドレッサビリティ/
addict /アディクト/
addiction /アディクション/
addie /アディ/
addin /アドイン;add-in/
addisababa /アジスアベバ;Addis Ababa/
addisabeba /アジスアベバ;Ababa Abeba/
addon /アドオン/
address /アドレス/
addressbar /アドレスバー/
addressbook /アドレスブック/
addressing /アドレッシング/アドレシング/
addressingmode /アドレッシングモード/
addy /アディ/
adela /アデラ/
adelaide /アデレード/
adele /アデル/アデール/アデーレ/
aden /アデン/
adenine /アデニン;A/
adenoid /アデノイド/
adenosine /アデノシン/
adenovirus /アデノウイルス/アデノウィルス/
adept /アデプト/
adhoc /アドホック;ad hoc/
adidas /アディダス;www.adidas.com/
adieu /アデュー/
adios /アディオス/
adjani /アジャーニ/
adjust /アジャスト/
adjustable /アジャスタブル/
adjuster /アジャスター/アジャスタ/
adjustment /アジャストメント/
adler /アドラー/
adlib /アドリブ;ad lib/
admin /アドミン/
administer /アドミニスター/
administration /アドミニストレーション/
administrator /アドミニストレータ/アドミニストレーター/
admission /アドミッション/
admittance /アドミタンス/
adobe /アドビ;www.adobe.com/Ａｄｏｂｅ/
adolescence /アドレッセンス;青春/アドゥレセンス/
adolf /アドルフ/
adolfo /アドルフォ/
adolph /アドルフ/
adolphe /アドルフ/
adonai /アドナイ/
adonis /アドニス/
adopt /アドプト/
adopter /アダプタ;adapter?/
adorno /アドルノ/
adrenalin /アドレナリン/
adrenaline /アドレナリン/
adria /アドリア/
adrian /エイドリアン/アドリアン/
adriana /アドリアーナ/
adriano /アドリアーノ/
adrien /アドリアン/
adrienne /アドリエンヌ;仏語/エイドリアン/
adrive /Aドライブ;A:/Ａドライブ/
adslmodem /ADSLモデム/
adult /アダルト/
adultdvd /アダルトDVD/
adultgoods /アダルトグッズ/
adultshop /アダルトショップ/
adultsite /アダルトサイト/
adultvideo /アダルトビデオ/
advance /アドバンス/アドヴァンス/
advanced /アドバンスト/アドバンスド/アドヴァンスト/アドヴァンスド/
advantage /アドバンテージ/
advent /アドベント/
adventure /アドベンチャー/
adventuregame /アドベンチャーゲーム/
advertise /アドバタイズ/
advertisement /アドバタイズメント/アド/
advertising /アドバタイジング/
advice /アドバイス/アドヴァイス/
advise /アドバイズ;[動詞]/アドバイス;※名詞「アドバイス」はadvice/
adviser /アドバイザー/アドバイザ/
advisor /アドバイザー/アドバイザ/アドヴァイザー/
advisory /アドバイザリー/アドバイザリ/アドヴァイザリ/アドバイサリ/
adware /アドウェア/
adwords /アドワーズ/
ady /アディ/
aegis /イージス/
aeolia /エオリア/
aeolian /エオリアン;ABCDEFGA/
aeolus /アイオロス/
aeon /イオン;www.aeon.info/
aera /アエラ;[雑誌名]朝日新聞社/AERA/
aerial /エアリアル/
aero /エアロ/
aerobi /エアロビ;aerobics/
aerobics /エアロビクス/
aerobike /エアロバイク;和製英語(stationary bike)/
aerodynamics /エアロダイナミクス/
aeroflot /アエロフロート;www.aeroflot.ru/
aerogramme /エアログラム/
aerosol /エアゾール/
aerospace /エアロスペース/
aeschylus /アイスキュロス/
aesop /イソップ/
aesthe /エステ/
aesthesalon /エステサロン;aesthetic salon/
aesthetic /エステティック/
aesthetician /エステティシャン/
aestheticsalon /エステティックサロン;aesthetic salon/
affair /アフェア/
affiliate /アフィリエイト/アフィリエート/
affiliateprogram /アフィリエイトプログラム/
affiliater /アフィリエイター/
affine /アフィン/
affinity /アフィニティ/アフィニティー/
affordance /アフォーダンス/
afghan /アフガン/
afghanistan /アフガニスタン;.af/
aflatoxin /アフラトキシン/
afreco /アフレコ;after recording/
africa /アフリカ/
africaans /アフリカーンス/
african /アフリカン/
afrikaans /アフリカーンス/
afro /アフロ/
afrohair /アフロヘア/
after /アフター/
afterbeat /アフタービート/
afterburner /アフターバーナー/
aftercare /アフターケア/
afterdark /アフターダーク/
afterfive /アフターファイブ/
afterfollow /アフターフォロー;和製英語(follow-up)/
afternoon /アフタヌーン/
afterservice /アフターサービス/
ag /銀/Silver/
again /アゲイン/アゲーン/
against /アゲインスト/アゲンスト/
agamben /アガンベン/
agamemnon /アガメムノン/
agape /アガペー/
agaricus /アガリクス;ハラタケ属/
agarose /アガロース/
agata /Ａ型/アガタ/
agate /アゲート/
agatha /アガサ/アガタ/
agathe /アガット/アガーテ/アガート/
age /エイジ/エージ/
agency /エージェンシー/
agenda /アジェンダ/会議事項/
agent /エージェント/エイジェント/
aggregate /アグリゲート/
aggregator /アグリゲータ/
aggressive /アグレッシブ/アグレッシヴ/
agharta /アガルタ/
agile /アジャイル/
agility /アジリティ/アジリティー/
aging /エイジング/エージング/
agit /アジト/
agitation /アジテーション/
agitato /アジタート/
agitpunkt /アジト/
agnes /アグネス/アニエス/
agni /アグニ/
agogo /アゴゴ/
agora /アゴラ/
agra /アグラ/
agree /アグリー/
agreement /アグリーメント/
agri /アグリ/
agribusiness /アグリビジネス/
agriculture /アグリカルチャー/
aguilera /アギレラ/
aguirre /アギーレ/
agustin /アグスティン/
ah /アー/
ahead /アヘッド/
ahriman /アーリマン/
ai /AI/人工知能/
aias /アイアス/アイアース/
aibo /アイボ;[商標]ソニー/
aic /アイク;[企業名]消費者金融。aic.jp/
aid /エイド/
aida /アイーダ/
aids /エイズ/後天性免疫不全症候群/
aidsvirus /エイズウイルス/
aiexpert /ＡＩエキスパート/
aiful /アイフル;[企業名]消費者金融。www.aiful.co.jp/
aila /アイラ/
aileen /アイリーン/
aim /エイム/
aimar /アイマール/
aime /エメ/
aimee /エメ/エーメ/
aiming /エイミング/
aina /アイナ/
aino /アイノ/
ainu /アイヌ/
aiolos /アイオロス/
air /エア/エアー/
aira /アイラ/
airbag /エアバッグ/
airborn /エアボーン/
airborne /エアボーン/
airbrush /エアブラシ/
airbus /エアバス/
aircap /エアキャップ;ぷちぷち/
aircheck /エアチェック/
aircleaner /エアクリーナー/
aircon /エアコン;air conditioner/
airconditioner /エアコンディショナー;air conditioner/
aircraft /エアクラフト/
airduct /エアダクト;air duct/
airflow /エアフロー/
airforce /エアフォース;air force/
airforceone /エアフォースワン;Air Force One/
airfrance /エールフランス;www.airfrance.fr/
airgun /エアガン/
airhockey /エアホッケー/
airi /アイリ/
airline /エアライン/
airlines /エアラインズ/
airlock /エアロック/
airmail /エアメール/
airplane /エアプレーン/
airplants /エアプランツ/
airpocket /エアポケット/
airport /エアポート/
airs /エアーズ/
airship /エアシップ/
airsystem /エアシステム/
airterminal /エアターミナル/
airticket /エアチケット/
airvalve /エアバルブ;air valve/
airway /エアウェイ/
airways /エアウェイズ/
aischylos /アイスキュロス/
aisha /アイシャ/アイーシャ/アーイシャ/
aisle /アイル;通路/
ajanta /アジャンタ/アジャンター/
ak /Alaska/アラスカ/
akademeia /アカデメイア/
akapella /アカペラ;※a capella?/ア・カペラ;※a capella?/
akashic /アカシック/
akbar /アクバル/
akcl /AKCL/AKCL(Austin Kyoto Common Lisp)/
akeem /アキーム/
aki /アキ/
akim /アキーム/
akkad /アッカド/
akropolis /アクロポリス/
aku /アク/
al /アル/アルミニウム/Aluminum/アラバマ/Alabama/
ala /アラ/ア・ラ・/
alabama /アラバマ;AL/
alabaster /アラバスター/
alacarte /アラカルト;a la carte/ア・ラ・カルト/
aladdin /アラジン/
alaikum /アライクム;(アラビア語)/
alain /アラン/
alamo /アラモ/
alamode /アラモード;a la mode/ア・ラ・モード/
alamos /アラモス/
alan /アラン/
alanine /アラニン;Ala/
alarcon /アラルコン/
alarm /アラーム/
alaska /アラスカ;AK/
alawi /アラウィ/
alba /アルバ;[商標]セイコー/
alban /アルバン/
albania /アルバニア;.al/
albatross /アルバトロス;信天翁/
albedo /アルベド/
albeit /アルバイト;曹長石/
albeniz /アルベニス/
albert /アルバート/アルベルト/アルベール/
alberta /アルバータ/アルベルタ/
alberti /アルベルティ/
alberto /アルベルト/
albina /アルビナ/
albino /アルビノ/
albion /アルビオン/
albirex /アルビレックス;[Jリーグ]新潟/
albrecht /アルブレヒト/
album /アルバム/
albumin /アルブミン/
albumtitle /アルバムタイトル/
albuquerque /アルバカーキ/
alceste /アルセスト;le Misanthrope/
alchemist /アルケミスト/
alcohol /アルコール/
alcohollamp /アルコールランプ/
alcove /アルコーブ/
alda /アルダ/
aldehyde /アルデヒド/
aldente /アルデンテ;al dente/
alder /アルダー/
aldo /アルド/
ale /エール/アレ/
alec /アレック/
alegre /アレグレ/
alegrias /アレグリアス/
alejandro /アレハンドロ/
aleksandr /アレクサンドル/
aleksei /アレクセイ/
alena /アレナ/
aleph /アレフ/アーレフ/
aleppo /アレッポ;シリア/
alert /アラート/
ales /アレス/
alesi /アレジ/
alessandra /アレッサンドラ/
alessandro /アレッサンドロ/アレサンドロ/
alessio /アレッシオ/
aleutian /アリューシャン/
alex /アレックス/
alexa /アレクサ/
alexander /アレキサンダー/アレクサンダー/アレグザンダー;(英)/アレクサンデル/アレクサンドル/アレクザンダー/
alexandra /アレクサンドラ/アレキサンドラ/アレグザンドラ;(英)/
alexandre /アレクサンドル/
alexandria /アレキサンドリア/アレクサンドリア/
alexandrite /アレキサンドライト/
alexandros /アレクサンドロス/
alexei /アレクセイ/
alexis /アレクシス/アレクシ;仏語/
alf /アルフ/
alfa /アルファ/
alfalfa /アルファルファ/
alfaromeo /アルファロメオ;www.alfaromeo.com/
alfee /アルフィー/
alfine /アルフィーネ;(It) al fine/
alfons /アルフォンス/
alfonso /アルフォンソ/
alfred /アルフレッド/アルフレート;(独語)/
alfredo /アルフレード/
alge /アルジェ/
alger /アルジェ/
algeria /アルジェリア;.dz/
algernon /アルジャーノン/
algin /アルギン/
algol /アルゴル/
algorithm /アルゴリズム/算法/
alhambra /アルハンブラ/
ali /アリ/アリー/
alias /エイリアス/エリアス/エーリアス;<rare>/
aliasing /エイリアシング/エリアシング/
alibaba /アリババ/
alibi /アリバイ/
alice /アリス/
alicia /アリシア/
alien /エイリアン/
alighieri /アリギエリ/
align /アライン/
alignment /アライメント/アラインメント/
alina /アリーナ/
alisa /アリサ/
alison /アリソン/アリスン/
alistair /アリステア/
alitalia /アリタリア;www.alitalia.it/
alive /アライブ/アライヴ/
aljazeera /アルジャジーラ;al-Jazeera. www.aljazeera.net/アルジャズィーラ/
alk /アルク/
alkali /アルカリ/
alkaline /アルカリ/
alkaloid /アルカロイド/
alkan /アルカン/
alkane /アルカン/
alkene /アルケン;C[n]H[2n]/
alkoxide /アルコキシド/
alkyd /アルキド/
alkyl /アルキル;C[n]H[2n-1]-/
alkyne /アルキン;C[n]H[2n-2],RC≡CR/
all /オール/∀/
alla /アラ/アッラ/アーラ/
allabout /オールアバウト;all about/オール・アバウト・/
allah /アラー/アッラー/
allan /アラン/
allback /オールバック/
allclear /オールクリア/
allcolor /オールカラー/
allcolour /オールカラー/
allegory /アレゴリー/
allegra /アレグラ/
allegretto /アレグレット/
allegria /アレグリア/
allegro /アレグロ/
allelopathy /アレロパシー/
allemand /アルマン/
allemande /アルマンド/
allen /アレン/アラン/
allene /アレン/
aller /アレ;仏語/
allergen /アレルゲン/
allergy /アレルギー/アレルギ/
alley /アレイ/アレー/
allgreen /オールグリーン/
alliance /アライアンス/
allicin /アリシン/
allie /アリー/
allied /アライド/
alliedtelesis /アライドテレシス;www.allied-telesis.co.jp/
alligator /アリゲーター/
allinone /オールインワン;all-in-one/
allison /アリソン/
allman /オールマン/
allnight /オールナイト/
allnude /オールヌード/
allo /アロ;(接頭辞)異-/
allocate /アロケート/
allocation /アロケーション/割り当て/
allocator /アロケータ/
allose /アロース/
allow /アラウ/
alloy /アロイ/
allpass /オールパス/
allround /オールラウンド/
allseason /オールシーズン/
allspice /オールスパイス/
allstanding /オールスタンディング/
allstar /オールスター/
allstargame /オールスターゲーム/
allstars /オールスターズ/
alltime /オールタイム/
allweather /オールウェザー/
ally /アリー/
allyl /アリル/
alma /アルマ/
almanac /アルマナック/
almaty /アルマトゥイ/
almighty /オールマイティ/オールマイティー/
alminium /アルミニウム;※aluminium/
almodovar /アルモドバル/
almond /アーモンド/
aloe /アロエ/
aloha /アロハ/
alohashirt /アロハシャツ/
alois /アロイス/
alone /アローン/アロン/
along /アロング/
alonso /アロンソ/アロンゾ/
alonzo /アロンゾ/
alpaca /アルパカ/
alpen /アルペン/
alpena /アルピナ/
alpenhorn /アルペンホルン/
alpenroute /アルペンルート;立山の観光道路。www.alpen-route.com/
alpenski /アルペンスキー/
alpha /α/アルファ/アルファー/
alphabet /アルファベット/
alphatron /アルファトロン/
alphonse /アルフォンス/
alphonso /アルフォンソ/
alphorn /アルプホルン/
alpine /アルパイン/
alpinist /アルピニスト/
alps /アルプス/
alqaeda /アルカイダ;al-Qaeda/
alright /オーライ/オールライト/
als /アルス/
alsace /アルザス/
alt /アルト/
alta /アルタ/
altai /アルタイ/
altamira /アルタミラ/
altar /オルター;祭壇/
altea /アルテア/
alter /アルター/オルター/
altered /オルタード/アルタード/
alterna /オルタナ;alternative/
alternate /オルタネイト/オルタネート/
alternative /オルタナティヴ/オルタナティブ/
althorn /アルトホルン/
althusser /アルチュセール/
altkey /ALTキー/オルトキー/
alto /アルト/
altoflute /アルトフルート/
altohorn /アルトホルン;alto horn/
altrecorder /アルトリコーダー/
altsax /アルトサックス/
alumi /アルミ;aluminium/
alumifoil /アルミホイル;aluminium foil/
alumina /アルミナ/
aluminium /アルミ;Al/アルミニウム;[元素]13,Al/
aluminum /アルミニウム;[元素]13,Al/
alumisash /アルミサッシ;aluminum sash/
alumite /アルマイト/
alvarez /アルバレス/
alvaro /アルバロ/
alvin /アルヴィン/
always /オールウェイズ/
alyosha /アリョーシャ/
alyson /アリソン/
alyssa /アリッサ/
alyssum /アリッサム/
alz /アルツ/
alzheimer /アルツハイマー/
am /アメリシウム/Americium/アム/エーエム/エイエム/
ama /アマ;amateur/
amabile /アマービレ/
amadeus /アマデウス/
amalg /Ц;※これはキリル文字のtse/
amalgam /アマルガム/
amalia /アマリア/
amalthaea /アマルテア/
amalthea /アマルテア/
amanda /アマンダ/
amande /アマンド;(Fr) アーモンド/
amantadine /アマンタジン/
amara /アマラ/
amaranth /アマランス/
amaranthus /アマランサス/
amaretto /アマレット/
amaro /アマロ/
amaryllis /アマリリス/
amateur /アマチュア/
amateurism /アマチュアリズム/
amati /アマティ/
amato /アマート/
amazing /アメイジング/アメージング/
amazon /アマゾン/
amazoness /アマゾネス/
ambassador /アンバサダー/
amber /アンバー/
ambient /アンビエント/
ambition /アンビション/
ambitious /アンビシャス/
ambivalence /アンビバレンス/アンビヴァレンス/
ambivalent /アンビバレント/アンビヴァレント/
ambroise /アンブロワーズ/
ambrose /アンブローズ/
ambrosia /アンブロシア/
ambulance /アンビュランス/
ambush /アンブッシュ/
ameba /アメーバ/
amedas /アメダス;AMeDAS/
amedee /アメデ/
amefoot /アメフト;American football/
amelia /アメリア/
amelie /アメリ/アメリー/
amen /アーメン/Ａ面/アメン/
amenity /アメニティ/アメニティー/
america /アメリカ/亜米利加/
american /アメリカン/
americana /アメリカーナ/
americancherry /アメリカンチェリー/
americancoffee /アメリカンコーヒー/
americancurl /アメリカンカール/
americandream /アメリカンドリーム/
americanexpress /アメリカンエキスプレス;www.americanexpress.com/
americanfootball /アメリカンフットボール/
americanism /アメリカニズム/
americanleague /アメリカンリーグ/
americanshorthair /アメリカンショートヘア/
americium /アメリシウム;[元素]95,Am/
amethyst /アメジスト/紫水晶/紫石英/
ametrine /アメトリン/
amex /アメックス/アメリカンエキスプレス/
ami /アミ/
amide /アミド/
amie /アミ/
amiel /アミエル/
amiens /アミアン/
amigo /アミーゴ/
amina /アミナ/
amine /アミン/
amino /アミノ/
amman /アンマン/
ammon /アモン/
ammonia /アンモニア/
ammonite /アンモナイト/
ammonium /アンモニウム/
ammons /アモンズ/
amnesty /アムネスティ/
amo /アモ/
amoeba /アメーバ/
amor /アモール;(西) 愛/
amoral /アモラル/
amore /アモーレ;(It) 愛/
amoroso /アモローソ/
amorphous /アモルファス/
amortization /アモチゼーション/
amos /アモス/
amount /アマウント/
amour /アムール/
amp /アンプ/アンプリファイア/
ampere /アンペア;A/アンペール;Andre-Marie Ampere (1775-1836)/
ampersand /アンパサンド;&/アンパーサンド/
amphetamine /アンフェタミン/
amphitheater /アンフィシアター;円形劇場/
amphitheatre /アンフィシアター;円形劇場/
ample /アンプル/
ampoule /アンプル/
ampul /アンプル/
amradio /AMラジオ/
amrduk /マルドゥーク/
amrita /アムリタ;[ヒンドゥー教] 不死の水/
amsterdam /アムステルダム/
amulet /アミュレット/
amun /アモン/
amur /アムール;黒竜江/
amuse /アミューズ/
amusement /アミューズメント/
amusementpark /アミューズメントパーク/
amway /アムウェイ;www.amway.com/
amy /エイミー/
amyl /アミル/
amylase /アミラーゼ/
amylose /アミロース/
an /アン/
ana /アナ/
anabel /アナベル/
anabell /アナベル/
anabolic /アナボリック/
anachro /アナクロ;anachronism/
anachronism /アナクロニズム/アナクロ/
anaconda /アナコンダ/
anaerobics /アネロビクス/
anaheim /アナハイム/
anais /アナイス/
anakin /アナキン/
anal /アナル/エイナル/
analfuck /アナルファック/
analizer /アナライザ;※analyzer/
analizing /アナライジング;※analyzing/
analog /アナログ/
analogdata /アナログデータ/
analogrecord /アナログレコード/
analogue /アナログ/
analogy /アナロジー/
analsex /アナルセックス/
analvib /アナルバイブ;anal vibrator/
analyse /アナライズ/
analyser /アナライザ/アナライザー/
analysis /アナリシス/
analyst /アナリスト/
analyze /アナライズ/
analyzer /アナライザ/アナライザー/
ananas /アナナス/
anaphylaxie /アナフィラキシー;(独語)/
anaphylaxis /アナフィラキシー/
anarchism /アナーキズム/アナキズム/
anarchist /アナーキスト/アナキスト/
anarcho /アナルコ/
anarchy /アナーキー/
anastasia /アナスタシア/
anatol /アナトール/
anatole /アナトール/
anatolia /アナトリア/
anc /アクティブノイズコントロール;active noise control/
anchor /アンカー/
anchorage /アンカレッジ/アンカレジ/
anchorman /アンカーマン/
anchovy /アンチョビ/アンチョビー/
ancien /アンシャン/
ancienregime /アンシャンレジーム;ancien regime/
ancient /アンシャン;仏語/アンシエント/アンシェント/エインシェント/
and /アンド/∧/∩/＆/かつ/および/&/
andalucia /アンダルシア/
andaman /アンダマン/
andante /アンダンテ/
andantino /アンダンティーノ/
anders /アンダース/
andersen /アンデルセン/
anderson /アンダーソン/アンデルソン/
andes /アンデス/
andor /アンドール/
andorra /アンドラ;.ad/
andrade /アンドラーデ/
andre /アンドレ/
andrea /アンドレア/
andreas /アンドレアス/
andree /アンドレ/
andrei /アンドレイ/
andres /アンドレス/
andretti /アンドレッティ/
andrew /アンドリュー/
andrews /アンドリューズ/
andrey /アンドレイ/
androgen /アンドロゲン/
android /アンドロイド/
andromeda /アンドロメダ/
andrun /エンドラン/
andy /アンディ/アンディー/
anecdote /アネクドート/
anelka /アネルカ/
anemone /アネモネ/
anergy /アネルギー/
ange /アンジュ;(Fr)天使/
angel /エンジェル/エンゼル/アンヘル/アンジェル/アンゲル/
angela /アンジェラ/アンヘラ/アンゲラ/
angeles /エンジェルス;※angels?/
angelfish /エンゼルフィッシュ/
angelic /エンジェリック/アンジェリック/
angelica /アンジェリカ/アンゼリカ/
angelico /アンジェリコ/
angelina /アンジェリーナ/
angelique /アンジェリーク;(Fr)天使の/アンジェリック/アンジェリク/
angelis /アンジェリス/
angelo /アンジェロ/
angelot /アンジェロ;(Fr)小天使/
angelplan /エンゼルプラン/
angels /エンジェルス;[MLB]/エンジェルズ;[MLB]/
angelus /アンジェラス/
anger /アンガー/アンジェ/
angers /アンジェ/
angie /アンジー/
angkor /アンコール/
angkorwat /アンコールワット;Angkor Wat/
angle /アングル/∠/
anglo /アングロ/
anglosaxon /アングロサクソン;Anglo-Saxon/
angola /アンゴラ;.ao/
angora /アンゴラ/
angry /アングリー/
angstrom /オングストローム/Å/
anguilla /アングイラ;.ai/セントキッツネ;.kn/
angulo /アングロ/
angus /アンガス/
anilide /アニリド/
aniline /アニリン/
anima /アニマ/
animage /アニメージュ;徳間書店/
animal /アニマル/
animals /アニマルズ/
animation /アニメーション/
animato /アニマート/
animator /アニメーター/
animax /アニマックス;www.animax.co.jp/
anime /アニメ/
animechara /アニメキャラ;animation character/
animesong /アニメソング/
animetic /アニメチック;和製英語/
animism /アニミズム/
animus /アニムス/
anion /アニオン/
anisakis /アニサキス/
anise /アニス/
anison /アニソン/
anita /アニタ/アニータ/
anjelica /アンジェリカ/
ankara /アンカラ/
ankh /アンク/
ankle /アンクル/
anklet /アンクレット/
anklung /アンクルン/
ann /アン/
anna /アンナ/アナ/
annabel /アナベル/
annabell /アナベル/
annabella /アナベラ/
annabelle /アナベル/
annales /アナール;(Fr) 年報。「-学派」/
annamillers /アンナミラーズ;Anna Miller's/
annan /アナン/
annapolis /アナポリス/
annapurna /アンナプルナ/
anne /アンネ/アンヌ/アン/
annealing /アニーリング/
annette /アネット/アネッテ/
annex /アネックス/
anni /アンニ/アニ/
annick /アニック/
annie /アニー/
annika /アニカ/アンニカ/
annis /アニス/
anniston /アニストン/
anniversary /アニバーサリー/
annotation /アノテーション/
announce /アナウンス/
announcement /アナウンスメント/
announcer /アナウンサー/
anntena /アンテナ;※antenna?/
annual /アニュアル/
anny /アニー/
ano /アノ/
anode /アノード/
anomaly /アノマリー/
anomie /アノミー/
anomy /アノミー/
anonymous /アノニマス/
anorak /アノラック/
another /アナザー/
anritsu /アンリツ;www.anritsu.co.jp(?)/
ansar /アンサール/
ansel /アンセル/
anselmo /アンセルモ/
ansermet /アンセルメ/
ansi /ANSI/
answer /アンサー/アンサ/
ant /アント/
antananarivo /アンタナナリボ;マダガスカル(tnr)/
antares /アンタレス/
antelope /アンテロープ/
antenna /アンテナ/
antennashop /アンテナショップ/
anthem /アンセム/
anthocyanin /アントシアニン/
anthology /アンソロジー/
anthony /アンソニー/アントニー/
anthracene /アントラセン;C14H10/
anthurium /アンスリウム/
anthy /アンシー/
anti /アンチ/
antiaging /アンチエイジング;anti-aging/
antialias /アンチエイリアス/
antialiasing /アンチエイリアシング/
antichrist /アンチキリスト/
anticlimax /アンチクライマックス/
antico /アンティコ/
antidote /アンチドート/
antigone /アンティゴネ/アンティゴネー/アンチゴネー/アンチゴネ/
antihero /アンチヒーロー/
antilles /アンティル;An,.an/
antilock /アンチロック/
antimon /アンチモン;[元素]51,Sb/
antimony /アンチモン;[元素]51,Sb/アンチモニー/アンティモニー/
antinomy /アンチノミー/
antiochia /アンティオキア/
antipasto /アンティパスト/
antique /アンティーク/
antishock /アンチショック/
antithese /アンチテーゼ/
antivirus /アンチウイルス/アンチウィルス/
antlers /アントラーズ;[Jリーグ]鹿島/
antoine /アントワーヌ/
antoinette /アントワネット/
anton /アントン/
antoni /アントニ/
antonia /アントニア/
antonin /アントナン/
antonio /アントニオ/
antonius /アントニウス/
antony /アントニー/
antwerp /アントワープ/
anu /アヌ/
anus /アヌス/エイヌス/
anvil /アンビル;金床/アンヴィル/
any /エニー/エニ/エニイ/何か/
anya /アーニャ/
anycast /エニーキャスト/エニキャスト/
anything /エニシング/
ao /(concat "and\057or")/
aodai /アオザイ;ao dai/
aorist /アオリスト/
ap /アクセスポイント/
apache /アパッチ/
apart /アパート/
apartheid /アパルトヘイト/
apartment /アパートメント/アパート/
apathy /アパシー/
apatite /アパタイト/
aperitif /アペリティフ/
aperture /アパーチャ/
apex /アペックス;advanced purchase excursion/
aphorism /アフォリズム/
aphrodite /アフロディテ/アフロディーテ/
apia /アピア/
apo /アポ/
apocalypse /アポカリプス/
apoint /アポイント/
apointment /アポイントメント/
apollinaire /アポリネール/
apollo /アポロ/
apollon /アポロン/
apollonia /アポロニア/
apolo /アポロ/
aporia /アポリア/
aposteriori /アポステリオリ;a posteriori/
apostrophe /’/アポストロフィ;'/アポストロフ/
apotosis /アポトーシス/
appalachian /アパラチア/
apparel /アパレル/
apparelmaker /アパレルメーカー/
appartement /アパルトマン;仏語/
appassionata /アパッショナータ/
appassionato /アパッショナート/
appeal /アピール/
appealpoint /アピールポイント;和製英語/
appearance /アピアランス/
appellation /アペラシオン;(Fr) 呼称/
append /アペンド/
appendix /アペンディックス/付録/
appia /アッピア/
applause /アプローズ/
apple /アップル/Ａｐｐｌｅ/
applecomputer /アップルコンピュータ;www.apple.com/
applepie /アップルパイ/
appleseed /アップルシード/
applet /アプレット/
appleton /アップルトン/
appli /アプリ;application/
appliance /アプライアンス/
application /アプリケーション/アプリケイション/応用/
applicationcontext /アプリケーションコンテキスト/
applicationmodal /アプリケーションモーダル/
applicationserver /アプリケーションサーバ/
applicationsoft /アプリケーションソフト/
applique /アップリケ/
apply /アプライ/
appo /アポ;appointment/
appoint /アポイント/
appointer /アポインター/
appointment /アポイントメント/
apprication /アプリケーション/
approach /アプローチ/
approx /〜/≒/
apres /アプレ/
apricot /アプリコット/
april /エイプリル/
aprilfool /エイプリルフール/
apriori /アプリオリ;a priori/
apron /エプロン/
aprondress /エプロンドレス/
aqaba /アカバ;ヨルダン/
aqua /アクア/
aquablue /アクアブルー/
aquacise /アクアサイズ/
aquafresh /アクアフレッシュ;[商標]/
aqualung /アクアラング/
aquamarine /アクアマリン/藍玉/
aquanaut /アクアノート/
aquapolis /アクアポリス/
aquarium /アクアリウム/
aquarius /アクエリアス;水瓶座/
aquatic /アクアティック/
aquatint /アクアチント/
aquinas /アクィナス/
aquitaine /アキテーヌ/
ar /Argon/Arkansas/アーカンソー/アルゴン/人工現実感/アール/
arab /アラブ/アラブ首長国連邦/
arabella /アラベラ/
arabesque /アラベスク/
arabia /アラビア/
arabian /アラビアン/
arabiannight /アラビアンナイト/
arabiannights /アラビアンナイト/アラビアンナイツ/
arabic /アラビック/
arabinose /アラビノース/
arafat /アラファト/
aragon /アラゴン/
aral /アラル/
aram /アラム/
aramid /アラミド/
aranjuez /アランフェス/
arank /Aランク/Ａランク/
ararat /アララト/アララット/
arbeit /アルバイト/バイト/
arbeiter /アルバイター/
arbiter /アービタ/
arbitor /アービター;arbiter?/
arbitrage /アービトラージ/
arbitration /アービトレーション/
arc /アーク/⌒/
arcade /アーケード/
arcadegame /アーケードゲーム/
arcadia /アルカディア/
arcana /アルカナ/
arcanciel /アルカンシェル;(Fr) arc-en-ciel, 虹/
arch /アーチ/
archaic /アルカイック/
arche /アルシュ/アルケー/
archer /アーチャー/
archery /アーチェリー/
archet /アルシェ;(Fr)弓/
archetype /アーキタイプ/
archi /アーキ/
archie /アーチー/
archimedes /アルキメデス/
architect /アーキテクト/
architecture /アーキテクチャ/アーキテクチャー/
archive /アーカイブ/アーカイヴ/
archivefile /アーカイブファイル/
archiver /アーカイバ/
archives /アーカイブス/
archon /アルコン/
archy /アーチー/
arco /アルコ/
arcturus /アルクトゥルス/
ardant /アルダン/
arden /アーデン/
ardija /アルディージャ;[Jリーグ]大宮/
are /アール;100m^2/アー/
area /エリア/域/空間/
areaguide /エリアガイド/
areamap /エリアマップ/
areastudy /エリアスタディ/エリアスタディー/
arena /アリーナ/アレーナ;(西語)「闘牛の-」/
arenas /アレナス/
arendt /アーレント/アレント/
ares /アレス/
arezzo /アレッツォ/
argent /アラザン/アルジャン;仏語/
argentina /アルゼンチン;.ar/
argentine /アルゼンチン/
argentinetango /アルゼンチンタンゴ;Argentine tango/
argento /アルジェント/
argerich /アルゲリッチ/
arginine /アルギニン;Arg/
argo /アルゴ/
argon /アルゴン;[元素]18,Ar/
argos /アルゴス/
argument /アーギュメント/引数/
arguments /アーギュメンツ/
argus /アーガス/
ari /アリ/
aria /アリア/
ariadne /アリアドネ/
ariane /アリアン/
arias /アリアス/
arie /アリ/
ariel /アリエル/
aries /アリエス;牡羊座/
arietta /アリエッタ/
arioso /アリオーソ/
arirang /アリラン/
aris /アリス/
arisa /アリサ/
aristophanes /アリストパネス/アリストファネス/
aristoteles /アリストテレス/
aristotelis /アリストテレス/
aristotle /アリストテレス/
arity /アリティ/
arizona /アリゾナ;AZ/
ark /アーク;箱舟/
arkansas /アーカンソー;AR/
arkas /アルカス/
arkwright /アークライト/
arlene /アーレン/
arlequin /アルルカン/
arles /アルル/
arlington /アーリントン/
arm /アーム/
armadillo /アルマジロ/
armageddon /アルマゲドン/ハルマゲドン/
armagnac /アルマニャック/
armand /アルマンド/アーマンド/アルマン/
armando /アルマンド/
armani /アルマーニ;www.armani.it/
armas /アルマス/
armband /アームバンド/
armchair /アームチェア/
armenia /アルメニア;.am/
armeria /アルメリア/
armin /アーミン/
armitage /アーミテージ/
armor /アーマー/
armored /アーマード/
armour /アーマー/
armoured /アーマード/
armrest /アームレスト/
arms /アームズ/
armstrong /アームストロング/
armwrestling /アームレスリング/
army /アーミー/
arnaud /アルノー/
arne /アルネ/
arno /アルノ/アルノー/
arnold /アーノルド/アルノルト/アルノルド/
arnoul /アルヌール/
arnould /アルヌール/
arnoux /アルヌー/
aroma /アロマ/
aromacandle /アロマキャンドル;和製英語/
aromacology /アロマコロジー/
aromaoil /アロマオイル/
aromatherapy /アロマテラピー/アロマセラピー/
aromatic /アロマティック/
aronalpha /アロンアルファ;[商標]東亜合成/
around /アラウンド/
arowana /アロワナ/
arp /アルプ/
arpa /アルパ/
arpeggio /アルペジオ/
arpeggione /アルペジオーネ/
arpegio /アルペジオ;※arpeggio?/
arrabbiata /アラビアータ/
arrange /アレンジ/
arrangement /アレンジメント/
arranger /アレンジャー/
array /アレイ/アレー/配列/
arrival /アライバル/
arriving /アライビング/
arrow /アロー/→;->/←;<-/↑;^/↓;v/⇒;=>/⇔;<=>,equiv/
ars /アルス;(Lat)芸術/
arsenal /アーセナル/
arsene /アルセーヌ/
arsenic /アースニック;As/アルセニック/アーセニック/
arsine /アルシン;AsH3/
art /アート/
artaud /アルトー/
artdeco /アールデコ;art deco/
artdirector /アートディレクター/
artemis /アルテミス/
artemisia /アルテミシア/アルテミジア/
artflower /アートフラワー;artificial flower/
arthur /アーサー/アルチュール/アルトゥール/アルテュール/
artichoke /アーティチョーク/
article /アーティクル/
articulate /アーティキュレート/アーティキュレイト/
articulation /アーティキュレーション/
artifact /アーティファクト/アーチファクト/
artificial /アーティフィシャル/
artisan /アルティザン/アルチザン/
artist /アーティスト/アーチスト/
artistic /アーティスティック/
artists /アーティスツ/
artnouveau /アールヌーボー;art nouveau/アールヌーヴォー/
arto /アルト/
arts /アーツ/
artur /アルトゥール/
arturo /アルトゥーロ/
artwork /アートワーク/
aruba /アルーバ;.aw/
arya /アーリア/
aryl /アリール/
as /アズ/ヒ素/砒素/Arsenic/
asa /アサ/アーサ/
asahibeer /アサヒビール/
asbestos /アスベスト/
ascension /アセンション/アセンション島;.ac/
ascii /アスキー/ASCII/
asciiart /アスキーアート/
asciicode /ASCIIコード/アスキーコード/
ascot /アスコット;[商標]ホンダ/
ascottie /アスコットタイ/
asgard /アスガルド/
ash /アッシュ/
ashgabad /アシガバード/
ashkenazy /アシュケナージ/
ashley /アシュリー/アシュレイ/
ashram /アシュラム/
ashtray /アッシュトレイ/
asia /アジア/エイジア/亜細亜/アーシア/
asiacup /アジアカップ/
asian /アジアン/エイジアン/
asiana /アシアナ;www.asiana.co.kr/
aside /アサイド/
asimo /アシモ;[商標]ホンダ/
asimov /アシモフ/アジモフ/
asistance /アシスタンス;※assistance?/
ask /アスク/
asklepios /アスクレピオス/
asmara /アスマラ/
asmo /アスモ/
asoka /アショカ/アショーカ/
aspara /アスパラ;asparagus/
asparagine /アスパラギン;Asn/
asparagus /アスパラガス/
aspartame /アスパルテーム/
aspect /アスペクト/
asperger /アスペルガー/
asphalt /アスファルト/
aspirin /アスピリン;C9H8O4/
aspite /アスピーテ/
ass /アス/
assad /アサド/
assai /アッサイ/
assalam /アッサラーム;(アラビア語)/
assam /アッサム/
assassin /アサシン/
assault /アサルト/
assemble /アセンブル/
assembler /アセンブラ/
assembly /アセンブリ/
assert /アサート/
assessment /アセスメント/アセス/
asset /アセット/遺産/
assign /アサイン/割り当て/
assignment /アサインメント/代入/
assisi /アッシジ/
assist /アシスト/
assistance /アシスタンス/
assistant /アシスタント/
assoc /アソック/
associate /アソシエイト/
associates /アソシエイツ/
association /アソシエーション/
associative /アソシアティブ/アソシエイティブ/
assort /アソート/
assurance /アシュアランス/
assyria /アッシリア/
asta /アスタ/
astatine /アスタチン;[元素]85,At/
astec /アステック/
astem /アステム/京都高度技術研究所;※abbrev: Advanced Software Technology & Mechatronics Research Institute of Kyoto. www.astem.or.jp/
asterisk /アスタリスク/
asteroid /アステロイド/
asti /アスティ/
aston /アストン/
astor /アスター/アストル/
astra /アストラ/
astrakhan /アストラハン/
astral /アストラル/
astro /アストロ/
astrology /アストロロジー/
astros /アストロズ;[MLB]/
astroscope /アストロスコープ/
astrud /アストラッド/
asuncion /アスンシオン/
aswan /アスワン/
asyl /アジール;(独語)/
asylum /アサイラム/
asymmetry /アシンメトリー/
at /アット/アト/アスタチン/Astatine/＠/
atacama /アタカマ/
atari /アタリ/
atelier /アトリエ/
atempo /ア・テンポ/アテンポ;a tempo/
athena /アテナ/アテーナー/Ａｔｈｅｎａ/Athena/
athenae /アテナイ/アテネ/
athenai /アテナイ/
athene /アテネ/
athens /アセンズ/
atherom /アテローム;(独語)/
atheroma /アテローマ/アテローム/
athlete /アスリート/
athletic /アスレチック/アスレティック/
athleticclub /アスレチッククラブ/アスレティッククラブ/
athletics /アスレチックス/
athlon /アスロン/
athome /アットホーム/
athos /アトス/
atkins /アトキンス/
atlanta /アトランタ/
atlantic /アトランティック/
atlantis /アトランティス/アトランチス/
atlas /アトラス/
atm /自動現金取り扱い機/自動預貯金機/
atman /アートマン/
atmark /アットマーク;@/
atmosphere /アトモスフィア/アトモスフェア/
atok /Ａｔｏｋ/ATOK/エイトック/
atom /アトム/
atomic /アトミック/
atony /アトニー/
atopie /アトピー/
atopy /アトピー/
atrandom /アトランダム/
atrium /アトリウム/
atropine /アトロピン/
att /ＡＴ＆Ｔ;www.att.com/
attach /アタッチ/
attache /アタッシュ/
attachecase /アタッシュケース;attache case/
attachment /アタッチメント/
attack /アタック/
attacker /アタッカー/
attacking /アタッキング/
attend /アテンド/
attendant /アテンダント/
attent /アテント/
attention /アテンション/
attenuator /アッテネータ/アッテネーター/
attest /アテスト/
attika /アッティカ/
attila /アッティラ/
attlee /アトリー/
atto /アト;[SI接頭語]a,10^-18/
attract /アトラクト/
attraction /アトラクション/
attractive /アトラクティブ/
attractor /アトラクター/アトラクタ/
attribute /アトリビュート/属性/
attu /アッツ/
atype /Aタイプ/Ａタイプ/
au /金/Gold/
aubade /オーバード/
auberge /オーベルジュ/
aubrey /オーブリー/
auckland /オークランド/
auction /オークション/
audi /アウディ;www.audi.com/
audience /オーディエンス/
audio /オーディオ/
audiocable /オーディオケーブル/
audiocd /オーディオCD/
audiofile /オーディオファイル/
audiology /オージオロジ/
audioplayer /オーディオプレイヤー/オーディオプレーヤー/
audiosystem /オーディオシステム/
audiovisual /オーディオビジュアル/
audition /オーディション/
auditorium /オーディトリアム/
audrey /オードリー/オドレイ/
auf /アウフ/
aufheben /アウフヘーベン/
auftact /アウフタクト/
augarten /アウガルテン/
auger /オーガ/オージェ/
augsburg /アウクスブルク/
august /オーガスト/アウグスト/オーギュスト/
augusta /オーガスタ/
auguste /オーギュスト/
augustin /オーギュスタン/アウグスティン/オギュスタン/
augustine /オーガスティン/
augustinus /アウグスティヌス/アウグスチヌス/
augusto /アウグスト/
augustus /アウグストゥス/オーガスタス/
aulait /オレ/
aunt /アント/
aura /オーラ/アウラ/
aurelius /アウレリウス/
aurora /オーロラ/アウロラ/アウローラ/
aurorasauce /オーロラソース/
auroravision /オーロラビジョン;和製英語/
aus /アウス/
auschwitz /アウシュビッツ/アウシュヴィッツ/
auslese /アウスレーゼ/
ausone /オーゾンヌ/
aussie /オージー/
auster /オースター/
austin /オースティン/オースチン/
australia /オーストラリア;.au/
australiagp /オーストラリアGP;[F1]/
australian /オーストラリアン/
austria /オーストリア;.at/
authentic /オーセンティック/
author /オーサ/オーサー/
authoring /オーサリング/
authorise /オーソライズ/
authority /オーソリティ/オーソリティー/
authorize /オーソライズ/
auto /オート/
autobacks /オートバックス;www.autobacks.com/
autobahn /アウトバーン/
autobianchi /アウトビアンキ;www.autobianchi.com/
autobike /オートバイ/
autocamp /オートキャンプ/
autocomplete /オートコンプリート/
autocorrect /オートコレクト/
autofill /オートフィル/
autofocus /オートフォーカス/
autograph /オートグラフ/
autolease /オートリース/
autoload /オートロード/
autoloading /オートローディング/
autoloan /オートローン/
autolock /オートロック/
autologin /オートログイン/
automa /オートマ/
automata /オートマタ/オートマトン;※単数形(automaton)/
automatic /オートマチック/オートマティック/
automation /オートメーション/
automaton /オートマトン/
automobile /オートモービル/
automount /オートマウント/
autopilot /オートパイロット/
autorace /オートレース/
autoraise /オートレイズ/
autorepeat /オートリピート/
autoreverse /オートリバース/
autumn /オータム/
auxin /オーキシン/
availability /アベイラビリティ/
available /アベイラブル/アヴェイラブル/使用可能/利用可能/
aval /アバール/
avant /アバン/アヴァン/
avantgarde /アバンギャルド;avant-garde/アヴァンギャルド/
avanti /アバンティ/アヴァンティ/
avanture /アバンチュール/
avatar /アバター/アバタール/
ave /アベ/アヴェ/
avec /アベック/
avemaria /アヴェマリア;Ave Maria/アベマリア/
avenue /アベニュー/アヴェニュー/
average /アベレージ/
averagehitter /アベレージヒッター/
avex /エイベックス;www.avex.co.jp/
avignon /アヴィニョン/
avila /アビラ/
avispa /アビスパ;[Jリーグ]福岡/
avocado /アボカド/
avogadro /アボガドロ/アヴォガドロ/
avonlea /アボンリー/アヴォンリー/
avril /アヴリル;(Fr) 4月/アブリル/
avsystem /AVシステム/
award /アワード/
awards /アワーズ/アウォーズ/
aware /アウェア/
awareness /アウェアネス/
away /アウェイ/アウェー/
awaygame /アウェイゲーム/アウェーゲーム/
awayteam /アウェイチーム/アウェーチーム/
awk /オーク/
awning /オーニング/
ax /アックス/アクス/
axe /アックス/アクス/
axel /アクセル/
axelrod /アクセルロッド/
axiom /アクシオム/ アクシアム/公理/
axis /アクシス/
axon /Ａｘｏｎ/
ay /エイ/エー/
ayala /アヤラ/
ayatullah /アヤトラ/
aych /エイチ/エッチ/
ayeaye /アイアイ;aye-aye. お猿さんだよ/
ayersrock /エアーズロック/
aykroyd /エイクロイド/
ayler /アイラー/
ayrton /アイルトン/
aytch /エイチ/エッチ/
ayurveda /アーユルヴェーダ/アーユルベーダ/
ayutthaya /アユタヤ/
ayyub /アイユーブ/
az /Arizona/アリゾナ/
aza /アザ/
azalea /アゼリア/アザレア/
azan /アザーン/
azane /アザン/
azel /アゼル/
azerbaijan /アゼルバイジャン;.az/
azido /アジド/
azine /アジン/
aznar /アスナール/
azteca /アステカ/
azulene /アズレン;C10H8/
azur /アジュール/アズール/
b /β;beta/ビー/ベー;(独語)/б;be (cyrillic)/ホウ素/硼素/Boron/
b# /Ｂ#1/B#0/
b#size /B#0サイズ/Ｂ#1サイズ/
b-spline /Ｂ−スプライン/
ba /バリウム/Barium/
baal /バール/
bab /バーブ/
baba /バーバ/ババ/
babe /ベイブ/ベーブ/
babel /バベル/
baberuth /ベーブルース;(1895-1948) Babe Ruth/ベイブルース/
babies /ベイビーズ/
babs /バブス/
baby /ベビー/ベイビー/ベイビィ/
babybath /ベビーバス/
babybed /ベビーベッド/
babyboom /ベビーブーム/
babyboomer /ベビーブーマー;baby boomer/
babycar /ベビーカー;和製英語(pushchair)/
babydoll /ベビードール/
babyface /ベビーフェイス/
babyfood /ベビーフード/
babylon /バビロン/
babylonia /バビロニア/
babylotion /ベビーローション/
babyoil /ベビーオイル/
babypowder /ベビーパウダー/
babyseat /ベビーシート/
babysitter /ベビーシッター/
babywear /ベビーウェア/
bacall /バコール/
bacardi /バカルディ/
baccalaureat /バカロレア/
baccarat /バカラ/
bacchos /バッコス/
bacchus /バッカス/
baccus /バッカス/
bach /バッハ/Ｂａｃｈ/
bachelard /バシュラール/
bachelor /バチェラー/
bacillus /バチルス/
back /バック/
backband /バックバンド/
backbone /バックボーン/
backchain /バックチェイン/
backchorus /バックコーラス;background chorus/
backdancer /バックダンサー/
backdoor /バックドア/
backdrop /バックドロップ/
backend /バックエンド/
backfire /バックファイア/
backgammon /バックギャモン/
backgear /バックギア/
background /バックグラウンド/バックグランド/背景/
backhand /バックハンド/
backhaus /バックハウス/
backhome /バックホーム;和製英語/
backing /バッキング/
backlight /バックライト/
backlog /バックログ/
backmargin /バックマージン/
backmirror /バックミラー/
backnet /バックネット/
backnumber /バックナンバー/
backoffice /バックオフィス/
backorder /バックオーダー/
backpack /バックパック/
backpacker /バックパッカー/
backpacking /バックパッキング/
backplane /バックプレーン/
backpressure /バックプレッシャー/
backprint /バックプリント/
backpropagation /バックプロパゲーション/
backquote /バッククォート/バッククオート/
backs /バックス/
backscreen /バックスクリーン/
backscroll /バックスクロール/
backside /バックサイド/
backslash /バックスラッシュ/＼/
backspace /バックスペース/
backspin /バックスピン/
backstage /バックステージ/
backswing /バックスイング/
backtrace /バックトレース/
backtrack /バックトラック/
backtracking /バックトラッキング/
backup /バックアップ/
backupfile /バックアップファイル/
backward /バックワード/
backy /バッキー/
backyard /バックヤード/
bacon /ベーコン/
baconegg /ベーコンエッグ/
bacteria /バクテリア/
bad /バッド/
badenbaden /バーデンバーデン/
badend /バッドエンド/
badge /バッジ/バッヂ/
badi /バディ/
badminton /バドミントン/
badnews /バッドニュース/
badtiming /バッドタイミング/
badtrip /バッドトリップ/
baffle /バッフル/バフル/
baffy /バフィー;4-wood/バッフィー/
bag /バッグ/
bagatell /バガテル/
bagdad /バグダッド/
bagel /ベーグル/
baggage /バゲージ/
baggio /バッジョ/
baghdad /バグダード/
bagnacaoda /バーニャカウダ;(It)bagna cauda/
bagpipe /バグパイプ/
baguette /バゲット;フランスパン/
baguio /バギオ;フィリピン/
bahamas /バハマ;.bs/
bahamut /バハムート/
bahrain /バーレーン;.bh/
bahraingp /バーレーンGP;[F1]/
baht /バーツ/
baikal /バイカル/
baikonur /バイコヌール;カザフスタン/
bailey /ベイリー/
bain /ベイン/バン;(Fr)風呂/
baiser /ベーゼ;(Fr)キス/
baka /バカ/
bake /ベーク/ベイク/
baked /ベークド/
bakelite /ベークライト/
baker /ベイカー/ベーカー/
bakery /ベーカリー/
bakhtin /バフチン/
baking /ベーキング/
bakingpowder /ベーキングパウダー/
bakken /バッケン/
baku /バクー/
bal /バル/
balalaika /バラライカ/
balance /バランス/
balancer /バランサ/バランサー/
balancesheet /バランスシート/
balancing /バランシング/
balaphone /バラフォン/
balcon /バルコン/
balcony /バルコニー/
baldwin /ボールドウィン/
balenciaga /バレンシアガ/
bali /バリ/
balinese /バリニーズ/
balios /バリオス/
balk /ボーク/
balkan /バルカン/
ball /ボール/
ballack /バラック/
ballad /バラッド/バラード/
ballade /バラード/
ballantine /バランタイン/
ballard /バラード/
ballast /バラスト/
ballbearing /ボールベアリング/
ballerina /バレリーナ/
ballet /バレエ/
balletdancer /バレエダンサー/
balley /ベイリー/
balleys /ベイリーズ;Balleys's/
ballistic /バリスティック/
balloon /バルーン/
ballpark /ボールパーク/
ballpen /ボールペン;和製英語(ballpoint)/
bally /バリー;www.bally.com/
balm /バーム/バルム/
balrog /バルログ/
balsa /バルサ/
balsamico /バルサミコ/
balthasar /バルタザール/バルタザル/
balthazar /バルタザール/バルタザル/
baltic /バルチック/
baltimore /ボルチモア/ボルティモア/
balzac /バルザック/
bamako /バマコ/
bamberg /バンベルク/
bambi /バンビ/
bambino /バンビーノ;(It)子供/
bamboo /バンブー/
bamiyan /バーミヤン;アフガニスタン/
ban /バン/
banach /バナッハ/
banana /バナナ/
bananachips /バナナチップス/
bancroft /バンクロフト/
band /バンド/
banda /バンダ;(It)楽団/
bandage /バンデージ/
bandaid /バンドエイド;[商標]band-aid/
bandana /バンダナ;※bandanna/
bandanna /バンダナ/
banderas /バンデラス/
bandgap /バンドギャップ/
bandman /バンドマン/
bandmaster /バンドマスター/バンマス/
bandmember /バンドメンバー/
bandneon /バンドネオン/
bandoneon /バンドネオン/
bandpass /バンドパス/
bandscore /バンドスコア/
bandung /バンドン;インドネシア/
bandwagon /バンドワゴン/
bandwidth /バンド幅/
bane /ベイン/
banff /バンフ/
bang /バン/
bangalore /バンガロール/
bangkok /バンコク/
bangladesh /バングラデシュ;.bd/
bangle /バングル/
bangui /バンギ/
banjo /バンジョー/
bank /バンク/
bankbutton /バンクボタン/
banker /バンカー;銀行家/
banking /バンキング/
banks /バンクス/
banmas /バンマス;bandmaster/
banner /バナー/
banquet /バンケット/
banshee /バンシー/
bansri /バンスリ/バンスリー/
bantam /バンタム/
baobab /バオバブ/
baptisma /バプテスマ/
baptist /バプテスト/バプティスト/
baptiste /バプティスト/バティスト/
bar /バー/バール;-のようなもの/−;minus/｜;pipe/‖/
barabbas /バラバ/
baraja /バラハ/
barb /バーブ/
barbados /バルバドス;.bb/
barbapapa /バーバパパ/
barbara /バーバラ/バルバラ;quelle connerie la guerre!/
barbaresco /バルバレスコ/
barbarian /バーバリアン/
barbaroi /バルバロイ;(ギリシア語)/
barbecue /バーベキュー/
barbell /バーベル/
barber /バーバー/
barbera /バルベーラ/バルベラ/
barbie /バービー/
barbital /バルビタール/
barbra /バーブラ/
barcarole /バルカローレ/バルカロール/
barcarolle /バルカロール/
barcelona /バルセロナ/
barcode /バーコード/
barcodereader /バーコードリーダー/バーコードリーダ/
bardot /バルドー/
bare /ベア/
barebone /ベアボーン/
barenboim /バレンボイム/
baretop /ベアトップ;和製英語/
bargain /バーゲン/
bargainsale /バーゲンセール/
barge /バージ/
bari /バーリ/
baricade /バリケード;※barricade/
barilla /バリラ/
bariquand /バリカン;仏語/
baritone /バリトン/
baritonesax /バリトンサックス/
barium /バリウム/
bark /バーク/
barlounge /バーラウンジ/
barn /バーン/
barnabas /バルナバ/
barnaby /バーナビー/
barnard /バーナード/
barnes /バーンズ/
barney /バーニー/
barneys /バーニーズ;www.barneys.com/
barnum /バーナム/
barolo /バローロ/
barometer /バロメーター/バロメータ/
baron /バロン/
baroque /バロック/
barouh /バルー/
barrack /バラック/
barracks /バラック/
barracuda /バラクーダ/
barrel /バレル/バーレル/
barrett /バレット/
barricade /バリケード/
barrichello /バリチェロ/
barrier /バリア/バリアー/
barrierfree /バリアフリー/
barrior /バリア;barrier?/
barron /バロン/
barry /バリー/
barrymore /バリモア/
bart /バート/
bartender /バーテンダー/バーテン/
barter /バーター/
barth /バルト/
barthes /バルト/
bartholin /バルトリン/
bartholomew /バーソロミュー/バルトロマイ/
bartime /バータイム/
bartok /バルトーク/
bartoli /バルトリ/
barton /バートン/
barye /バリー/バーリー/バリ/
baryon /バリオン/
baryton /バリトン/
base /ベース/基底/
baseball /ベースボール/
basecamp /ベースキャンプ/
baseclock /ベースクロック/
basel /バーゼル/
baseline /ベースライン/
basement /ベースメント/
basename /ベースネーム/
baserunning /ベースランニング/
baseup /ベースアップ;和製英語(raise)/
bash /バッシュ/
bashing /バッシング/
bashkortostan /バシコルトスタン/
basic /ベーシック/
basie /ベイシー/
basil /バジル/ベイジル/
basilico /バジリコ/
basilisk /バシリスク/
basis /ベーシス/基礎/
bask /バスク/
baske /バスケ;basketball/
basket /バスケット/
basketball /バスケットボール/
basketshoes /バスケットシューズ/
basque /バスク/
basra /バスラ;イラク/
bass /バス/ベース/バース;人名/
bassclarinet /バスクラリネット/
bassdrum /バスドラム/
basset /バセット/
basseterre /バセテール/
bassguitar /ベースギター/
bassist /ベーシスト/
bassline /ベースライン/
basso /バッソ/
bassoon /バスーン/ファゴット;fagotto(It)/
basssolo /ベースソロ/
bastard /バスター/バスタード/
bastian /バスティアン/
bastien /バスティアン/
bastille /バスティーユ/バスチーユ/
bat /バット/
bataille /バタイユ/
batalha /バタリア/
batavia /バタヴィア/
batch /バッチ/
batchfile /バッチファイル/
batchsize /バッチサイズ/
bateau /バトー;(Fr)船/
bateson /ベイトソン/
bath /バス/バース/
bathmat /バスマット/
bathrobe /バスローブ/
bathroom /バスルーム/
bathtime /バスタイム/
bathtowel /バスタオル/
bathtub /バスタブ/
batista /バティスタ/
batman /バットマン/
baton /バトン/
batontouch /バトンタッチ;和製英語(baton pass)/
batontwirling /バトントワリング/
batsu /×/
batter /バッター/
batterbox /バッターボックス;batter's box/
battery /バッテリー/バッテリ/
batterypack /バッテリーパック/
batting /バッティング/
battingcenter /バッティングセンター/
battle /バトル/
battleaxe /バトルアックス/
battler /バトラー/
battleroyal /バトルロワイヤル/バトルロイヤル/
battrang /バッチャン/
baud /ボー/
baudelaire /ボードレール/ボオドレエル/
baudrate /ボーレート/
baudrillard /ボードリヤール/
bauer /バウアー/
bauhaus /バウハウス/
baulk /ボーク/
baum /バウム;(独語)木/ボーム/
baumann /バウマン/
baume /ボーメ/
baumkuchen /バウムクーヘン/バームクーヘン/
bautista /バウティスタ/
bauxite /ボーキサイト/
bavarois /ババロア/
bavaroise /ババロワーズ/バヴァロワーズ/ババロアーズ/バヴァロアーズ/
baxter /バクスター/
bay /ベイ/
bayarea /ベイエリア/
baybridge /ベイブリッジ/
bayer /バイエル/
bayern /バイエルン/
bayes /ベイズ/
bayesian /ベイジアン/
bayleaf /ベイリーフ/
bayley /ベイリー/
bayon /バイヨン/
bayreuth /バイロイト/
bayside /ベイサイド/
baystars /ベイスターズ/
baz /バズ/
bazaar /バザール/
bazar /バザー/バザール/
bazillus /バチルス/
bazooka /バズーカ/
bbc /BBC/
bbs /掲示板/
bclass /Ｂクラス/Bクラス/
bcup /Bカップ;12.5cm/Ｂカップ/
bday /バースディ;BirthDAY/
bdrive /Bドライブ;B:/Ｂドライブ/
be /ビー/ベリリウム/Beryllium/б;cyrillic/
beach /ビーチ/
beachball /ビーチボール/
beachboys /ビーチボーイズ/
beachparasol /ビーチパラソル;和製英語(beach umbrella)/
beachresort /ビーチリゾート/
beachsandal /ビーチサンダル/
beachvolley /ビーチバレー/
beachvolleyball /ビーチバレーボール/
beacon /ビーコン/
bead /ビーズ/
beads /ビーズ/
beadscushion /ビーズクッション/
beagle /ビーグル/
beaker /ビーカー/
beam /ビーム/
beamsabre /ビームサーベル/
bean /ビーン;豆/
beanball /ビーンボール/
beans /ビーンズ/
bear /ベア/ベアー/
bearing /ベアリング/
bears /ベアーズ/
beart /ベアール/
beast /ビースト/
beat /ビート/
beatbox /ビートボックス/
beater /ビーター/
beatles /ビートルズ/
beatnik /ビートニク/
beatrice /ベアトリーチェ/ベアトリス/
beatrix /ベアトリクス/ビアトリクス/ベアトリックス/
beatriz /ベアトリス/
beats /ビーツ/
beau /ボー;仏語/
beaucaillou /ボーカイユ/
beaujolais /ボジョレー/ボージョレ/ボジョレ/ボージョレー/
beaujolaisnouveau /ボジョレーヌーボー;Beaujolais nouveau/ボージョレーヌーボー/ボージョレヌーボー/ボージョレヌーヴォー/ボージョレーヌーヴォー/ボジョレーヌーヴォー/
beaune /ボーヌ/
beaute /ボーテ/ボテ;(Fr)美/
beautiful /ビューティフル/
beauty /ビューティ/ビューティー/
beauvoir /ボーヴォワール/
beauxarts /ボザール;(Fr) beaux-arts. 美術/
beaver /ビーバー/
bebe /ベベ/
bebop /ビバップ/
bec /ベック;(Fr)嘴,マウスピース/
because /ビコーズ/∵/
bechamel /ベシャメル/
bechamelsauce /ベシャメルソース;bechamel sauce/
bechet /ベシェ/
beck /ベック/
beckenbauer /ベッケンバウアー/
becker /ベッケル/
becket /ベケット/
beckett /ベケット/
beckham /ベッカム/
beckie /ベッキー/
becky /ベッキー/
becquerel /ベクレル/
bed /ベッド/
bedcover /ベッドカバー/
bedin /ベッドイン/
bedouin /ベドウィン/
bedroom /ベッドルーム/
bedscene /ベッドシーン/
bedsheets /ベッドシーツ/
bedside /ベッドサイド/
bedtime /ベッドタイム/
bedtown /ベッドタウン;和製英語(dormitory)/
bee /ビー/
beef /ビーフ/
beefcurry /ビーフカレー/
beefjerky /ビーフジャーキー/
beefsteak /ビーフステーキ/
beefstew /ビーフシチュー/
beefstroganoff /ビーフストロガノフ/
beem /ビーム/
been /ビーン/
beep /ビープ/
beer /ビール/ビア/麦酒/
beergarden /ビアガーデン/
beerhall /ビアホール/
beerken /ビール券/
beermug /ビアマグ/
beet /ビート;砂糖大根/
beethoven /ベートーヴェン/ベートーベン/
beetle /ビートル/
beets /ビーツ;甜菜/
before /ビフォア/ビフォー/
begin /ビギン/
beginner /ビギナー/
beginners /ビギナーズ/
beginnersluck /ビギナーズラック/
begins /ビギンズ/
begonia /ベゴニア/
beguine /ビギン;[音楽]begin the -/
behavior /ビヘイビア/
behind /ビハインド/
beige /ベージュ/
beignet /ベニエ/
beijing /ペキン/北京/
being /ビーイング/
beirach /バイラーク/
beirut /ベイルート/
beit /バイト/
bejart /ベジャール/
bel /ベル/
bela /ベラ/
belarus /ベラルーシ;.by/
belcanto /ベルカント;bel canto/
belem /ベレン/
belen /ベレン/
belfast /ベルファスト/
belgie /ベルギー/
belgiegp /ベルギーGP;[F1]/
belgium /ベルギー;.be/
belief /ビリーフ/
believe /ビリーヴ/ビリーブ/
believer /ビリーバー/
belinda /ベリンダ/
belize /ベリーズ;.bz/
bell /ベル/
bella /ベラ/
belladonna /ベラドンナ/
bellamy /ベラミー/ベラミ/
bellbottom /ベルボトム/
bellcore /ベルコア/
belle /ベル/
belleepoque /ベルエポック;la Belle Epoque/
bellemaison /ベルメゾン/
bellini /ベリーニ/
bellken /ベル研/Ｂｅｌｌ研/
bellman /ベルマン/
bellmare /ベルマーレ;[Jリーグ]湘南/
bellof /ベロフ/
bells /ベルズ/
belltree /ベルツリー/
bellucci /ベルッチ/
belly /ベリー/
bellydance /ベリーダンス/
bellydancer /ベリーダンサー/
belmondo /ベルモンド/
belmont /ベルモント/
belmopan /ベルモパン/
below /ビロウ/ビロー/
belt /ベルト/
beltconveyer /ベルトコンベア/ベルトコンベアー/ベルトコンベヤー/ベルトコンベヤ/
beltconveyor /ベルトコンベア/ベルトコンベアー/ベルトコンベヤー/ベルトコンベヤ/
beltran /ベルトラン/
belz /ベルツ/
bem /ベム/
ben /ベン/
benares /ベナレス/
bench /ベンチ/
benchmark /ベンチマーク/
benchmarktask /ベンチマーク・タスク/
benchmarktest /ベンチマークテスト/
benchpress /ベンチプレス/
benchtime /ベンチタイム/
bend /ベンド/
bender /ベンダー/ベンダ/
bending /ベンディング/
bene /ベネ/
benedict /ベネディクト/
benedicte /ベネディクト/
benedictine /ベネディクティン/
benedictus /ベネディクトゥス/
benedikt /ベネディクト/
benefit /ベネフィット/
benelux /ベネルクス;ベルギー・オランダ・ルクセンブルク/
benesse /ベネッセ;www.benesse.co.jp/
benetton /ベネトン;www.benetton.com/
bengal /ベンガル/
bengala /ベンガラ/
bengali /ベンガル/
benghazi /ベンガジ/
benguela /ベンゲラ/
benin /ベニン;.bj/ベナン/
bening /ベニング/
benitez /ベニテス/
benjamin /ベンジャミン/ベンヤミン/
benjaron /ベンジャロン/
benjie /ベンジー/
benjy /ベンジー/
bennet /ベネット/
bennett /ベネット/
bennie /ベニー/
benny /ベニー/
benoit /ブノワ/ブノア/
benson /ベンソン/
bent /ベント/
bentham /ベンサム/
benthos /ベントス;底生生物/
bentley /ベントレー/ベントリー/
benzaldehyde /ベンズアルデヒド/
benzene /ベンゼン/
benzin /ベンジン/
benzine /ベンジン/
benzo /ベンゾ/
benzoyl /ベンゾイル/
benzyl /ベンジル/
beograd /ベオグラード/
beowulf /ベオウルフ/ベーオウルフ/
bera /ベラ/
berardi /ベラルディ/
berber /ベルベル/
beret /ベレー/
beretta /ベレッタ/
berg /バーグ/ベルク/ベルグ/
bergamasque /ベルガマスク/
bergamo /ベルガモ;イタリア/
bergamot /ベルガモット/
bergamotto /ベルガモット;イタリア語/
bergen /ベルゲン/ベルヘン/バーゲン/ベルヘンバーゲン/
berger /ベルジェ/バーガー/
bergerac /ベルジュラック/
bergman /バーグマン/
bergson /ベルクソン/
berimbau /ビリンバウ/
bering /ベーリング/
berio /ベリオ/
berkeley /バークレー;カリフォルニア/バークリー/バークレイ/
berkelium /バークリウム;[元素]97,Bk/
berkley /バークレー/バークリー/バークレイ/
berlin /ベルリン/
berlinphil /ベルリンフィル;Berliner Philharmonisches Orchester/
berlioz /ベルリオーズ/
berlitz /ベルリッツ;www.berlitz.com/
berlusconi /ベルルスコーニ/
bermuda /バミューダ;.bm/バーミューダ/
bern /ベルン/
berna /ベルナ/
bernanke /バーナンキ/
bernard /バーナード/ベルナール/ベルナルド/ベルナルト/
bernardo /ベルナルド/
bernd /ベルント/
berne /ベルヌ/
bernhard /ベルンハルト/バーンハード/
bernhardt /ベルナール/
bernie /バーニー/
bernini /ベルニーニ/
bernoulli /ベルヌーイ/
bernstein /バーンスタイン/
beroff /ベロフ/
berra /ベラ/
berret /ベレー/
berri /ベリ/
berrichello /バリチェロ/
berry /ベリー/ベリ/
berserk /バーサーク/
berserker /バーサーカー/ベルセルク;[北欧神話](NB:英語のberserkは逆成)/
bert /バート/ベルト/ベール/
berta /ベルタ/
bertha /バーサ/ベルタ/
berthold /ベルトルト/
bertini /ベルティーニ/
bertolt /ベルトルト/
bertram /バートラム/ベルトラム/
bertrand /ベルトラン/バートランド/
beryl /ベリル/
beryllium /ベリリウム;[元素]4,Be/
besancon /ブザンソン/
beside /ビサイド/
bess /ベス/
bessel /ベッセル/
bessie /ベッシー/
besson /ベッソン/
bessy /ベッシー/
best /ベスト/
best# /ベスト#0/ベスト#1/
bestalbum /ベストアルバム/
bestdresser /ベストドレッサー/
besteffort /ベストエフォート/
besteleven /ベストイレブン/
bestlap /ベストラップ/
bestmatch /ベストマッチ/
bestmember /ベストメンバー/
bestnine /ベストナイン/
bestone /ベストワン/
bestrap /ベストラップ/
bestseason /ベストシーズン/
bestseller /ベストセラー/
bestsellers /ベストセラーズ/
bestshot /ベストショット/
bestten /ベストテン/
bestthree /ベストスリー/
besttime /ベストタイム/
bet /ベット/
beta /β/ベータ/β版/
betacarotene /βカロチン/ベータカロチン/
betacarotin /βカロチン/ベータカロチン/
betarelease /ベータリリース/βリリース/
betatest /βテスト/ベータテスト/
betaversion /βバージョン/ベータバージョン/
betelgeuse /ベテルギウス/ペテルギウス/
beth /ベス/
bethlehem /ベツレヘム/
betsy /ベッツィ/
betta /ベタ/
better /ベター/
betty /ベティ/ベティー/
between /ビトウィーン/ビトゥイーン/
beulah /ビューラー/
beverage /ビバレッジ/
beverley /ビヴァリー/ビバリー/
beverly /ビバリー/ビヴァリー/
beverlyhills /ビバリーヒルズ;Beverly Hills/
beyond /ビヨンド/
bezel /ベゼル/
bezier /ベジェ/ベジエ/
bf /ブルキナファソ/Burkina Faso/
bflets /Bフレッツ;[商標]NTT/
bg /バックグラウンド/
bgata /Ｂ型/
bh /ボーリウム/Bohrium/
bhakti /バクティ/
bhutan /ブータン;.bt/
bhutto /ブット/
bi /バイ;2/ビスマス/Bismuth/
biafra /ビアフラ/
bian /ビアン/
bianca /ビアンカ/
bianchi /ビアンキ/
bianco /ビアンコ/
bias /バイアス/
biathlon /バイアスロン/
bibimbap /ビビンバ;(朝鮮語)/
bible /バイブル/
biblio /ビブリオ/
bibliography /ビブリオグラフィー/
biblos /ビブロス/
bibtex /BibTeX/
biccamera /ビックカメラ;www.biccamera.com/
bicolor /バイカラー/
bicolour /バイカラー/
bicycle /バイシクル/
bid /ビッド/
bidders /ビッダーズ;www.bidders.co.jp/
bidding /ビディング/
bidet /ビデ/
biedermeier /ビーダーマイヤー/
biela /ビエラ/
bien /ビアン/
biennale /ビエンナーレ/
bierce /ビアス/
biet /ビート;(蘭語)/
biff /ビフ/
bifidus /ビフィズス/
big /ビッグ/
bigband /ビッグバンド/
bigbang /ビッグバン/
bigblue /ビッグブルー/
bigcomic /ビッグコミック;小学館/
bigendian /ビッグエンディアン/
bigevent /ビッグイベント/
bigfoot /ビッグフット/
bighorn /ビッグホーン/
biglobe /ビッグローブ;www.biglobe.ne.jp/
bigmac /ビッグマック/
bigname /ビッグネーム/
bignews /ビッグニュース/
bigsight /ビッグサイト;www.bigsight.jp/
bigsize /ビッグサイズ/
bigtex /BigTeX/
bigwave /ビッグウェーブ/
bijou /ビジュー/
bike /バイク/オートバイ/
biker /バイカー/
bikerace /バイクレース/
bikini /ビキニ/
bikiniline /ビキニライン/
bikinipants /ビキニパンツ/
bilane /ビラン/
bilbao /ビルバオ/
bilbo /ビルボ/
bilin /ビリン/
biline /ビリン/
bilingual /バイリンガル/
bilirubin /ビリルビン/
bill /ビル/
billboard /ビルボード/
billiard /ビリヤード/
billiards /ビリヤード/
billie /ビリー/
billing /ビリング/
billion /ビリオン;1,000,000,000/
billionaire /ビリオネア/
billy /ビリー/
biman /ビーマン/
bimetal /バイメタル/
bin /ビン/バイナリ/
bina /ビーナ/
binary /バイナリ/バイナリー/
binarydump /バイナリダンプ/
binaryeditor /バイナリエディタ/
binaryfile /バイナリファイル/
binaural /バイノーラル/
bind /バインド/
binder /バインダー/バインダ/
binding /バインディング/ビンディング/
bing /ビング/
bingo /ビンゴ/
bingogame /ビンゴゲーム/
binladen /ビンラディン;Bin Laden/
binoche /ビノシュ/
bintan /ビンタン/
bio /バイオ/
biochemical /バイオケミカル/
biochip /バイオチップ/
bioethics /バイオエシックス/
biofermin /ビオフェルミン/
biogas /バイオガス/
biography /バイオグラフィー/
biohazard /バイオハザード/
biology /バイオロジー/
biomass /バイオマス/
biomedical /バイオメディカル/
biometrics /バイオメトリクス/
bionics /バイオニクス/
biopsy /バイオプシー;生検/
bioreactor /バイオリアクター/
biorhythm /バイオリズム/
bios /バイオス;basic I／O system/ビオス;[生物]/
bioscience /バイオサイエンス/
biosensor /バイオセンサー/
biotech /バイオテック;biotechnology/バイテク/
biotechnology /バイオテクノロジー/
biotin /ビオチン;ビタミンH/
biotop /ビオトープ;(独語) 野生生物の生育場所。ギリシャ語のBIO(生物)とTOP(場所)の合成語/
biotope /ビオトープ;野生生物の生育場所。ギリシャ語のBIO(生物)とTOP(場所)の合成語/
biphenyl /ビフェニル;C6H5-C6H5/ビフェニール/
bipolar /バイポーラ/
birch /バーチ/
bird /バード/
birdie /バーディー/バーディ/
birdland /バードランド/
birds /バーズ/
birdseye /バーズアイ/
birdwatching /バードウォッチング/
bireleys /バヤリース;[商標]/バャリース/
birgit /ビルギット/
birman /バーマン;猫/
birmingham /バーミンガム/
birth /バース/
birthday /バースデー/バースディ/
birthdaycake /バースデーケーキ/
birthdaycard /バースデーカード/
birthdayparty /バースデーパーティー/バースデーパーティ/バースディパーティ/
birthdaypresent /バースデープレゼント/バースディプレゼント/
biscuit /ビスケット/ビスキュイ;仏語/
bisexual /バイセクシャル/バイセクシュアル/
bishkek /ビシュケク/
bishop /ビショップ/
bismuth /ビスマス;[元素]83,Bi/
bison /バイソン/Bison/
bisphenol /ビスフェノール/
bissau /ビサウ/
bistro /ビストロ;仏語/
bit /ビット/
bit-field /ビットフィールド/
bitch /ビッチ/
bite /バイト/
bitfield /ビットフィールド/ビット場/
bitimage /ビットイメージ/
bitmap /ビットマップ/
bitmapfont /ビットマップフォント/
bitnet /ビットネット/BITNET/
bitrate /ビットレート/
bits /ビッツ/
bitstream /ビットストリーム/
bitte /ビッテ/
bitter /ビター/
bitters /ビターズ/
bittersweet /ビタースイート/ビタースウィート/
bivouac /ビバーク/
biz /ビズ;business/
bizarre /ビザール/
bizerre /ビザール;※bizarre/
bizet /ビゼー/
bjorn /ビョルン/
bk /バークリウム/Berkelium/
black /ブラック/
blackbass /ブラックバス/
blackberry /ブラックベリー/
blackbird /ブラックバード/
blackbox /ブラックボックス/
blackhawk /ブラックホーク/
blackhole /ブラックホール/
blackhumour /ブラックユーモア/
blackjack /ブラックジャック/
blackjoke /ブラックジョーク/
blacklist /ブラックリスト/
blackmagic /ブラックマジック/
blackmarket /ブラックマーケット/
blackmonday /ブラックマンデー/
blackmore /ブラックモア/
blackmusic /ブラックミュージック/
blackonyx /ブラックオニキス/
blackopal /ブラックオパール/
blackout /ブラックアウト/
blackpearl /ブラックパール/
blackpepper /ブラックペッパー/
blackrider /ブラックライダー/
blacksheep /ブラックシープ/
blackstone /ブラックストーン/
blacktea /ブラックティー/
blackthorn /ブラックソーン/
blacktiger /ブラックタイガー/
blade /ブレード/ブレイド/
bladerunner /ブレードランナー/
bladeserver /ブレードサーバ/
blain /ブレーン/ブラン/
blair /ブレア/
blaise /ブレーズ/
blake /ブレイク/ブレーク/
blakey /ブレイキー/
blanc /ブラン/
blanca /ブランカ/
blanche /ブランシュ/
blanchot /ブランショ/
blancmanger /ブラマンジェ/ブランマンジェ;blanc-manger/
blanco /ブランコ/
blank /ブランク/ブラン/
blanket /ブランケット/
blas /ブラス/
blast /ブラスト/
blaster /ブラスター/
blatt /ブラット;(独語)/
blazer /ブレザー/
bldg /ビル/
bleach /ブリーチ/
bleaching /ブリーチング/
blend /ブレンド/
blendcoffee /ブレンドコーヒー/
blending /ブレンディング/
bleomycin /ブレオマイシン/
bless /ブレス/
bley /ブレイ/ブレー/
blik /ブリキ;(蘭語)/
blind /ブラインド/
blindtest /ブラインドテスト/
blindtouch /ブラインドタッチ/
blink /ブリンク/
bliss /ブリス/
blister /ブリスター/
blitz /ブリッツ/
blizzard /ブリザード/
blob /ブロブ/ブロッブ/
bloc /ブロック/
block /ブロック/
blockdevice /ブロックデバイス/
blockdiagram /ブロックダイアグラム/
blocker /ブロッカー/
blockflote /ブロックフレーテ/
blocking /ブロッキング/
blog /ブログ;weBLOG/
blogger /ブロガー/
blois /ブロア/
blond /ブロンド/
blonde /ブロンド/
blondee /ブロンディ/ブロンディー/
blood /ブラッド/
bloodstone /ブラッドストーン/
bloody /ブラディ/ブラッディ/
bloom /ブルーム/
bloomberg /ブルームバーグ/
bloomer /ブルマ/ブルマー/ブルーマー/
blooming /ブルーミング/
blossom /ブロッサム/
blouse /ブラウス/
blouson /ブルゾン/
blow /ブロー/ブロウ/
blower /ブロワー/
blowing /ブローイング/
blowser /ブラウザ;※browser?/
blue /ブルー/
bluebacks /ブルーバックス/
blueberry /ブルーベリー/
blueberryjam /ブルーベリージャム/
bluebird /ブルーバード/
bluecheese /ブルーチーズ/
bluechip /ブルーチップ/
bluecollar /ブルーカラー/
blueday /ブルーデイ/
bluegill /ブルーギル/
blueglass /ブルーグラス;bluegrass?/
bluegrass /ブルーグラス/
bluejays /ブルージェイズ;[MLB]Blue Jays/
bluejeans /ブルージーンズ/
bluemonday /ブルーマンデー/
bluemoon /ブルームーン/
bluemountain /ブルーマウンテン/
bluenote /ブルーノート/ＢｌｕｅＮｏｔｅ/
blueocean /ブルーオーシャン/
blues /ブルース/ブルーズ/
bluescreen /ブルースクリーン/
bluesheet /ブルーシート/
bluesy /ブルージー/
bluetooth /ブルートゥース;www.bluetooth.com/
bluetopaz /ブルートパーズ/
bluetrain /ブルートレイン/
bluewave /ブルーウェーブ/
bluff /ブラフ/
bluish /ブルーイッシュ/
blum /ブルーム/
bluray /ブルーレイ;(DVD)Blu-Ray/
blush /ブラッシュ/ブラッシ/
blushup /ブラッシュアップ;※brushup?/
bmpfile /BMPファイル/
bnf /BNF(Backus-Naur Form)/
bo /ボ/
boa /ボア/
board /ボード/
boarder /ボーダー/
boardgame /ボードゲーム/
boarding /ボーディング/
boardlevel /ボードレベル/
boat /ボート/
boatrace /ボートレース/
bob /ボブ/
bobbie /ボビー/
bobbin /ボビン/
bobby /ボビー/
bobcat /ボブキャット/
bobsleigh /ボブスレー/
bobtail /ボブテイル/ボブテール/
bocca /ボッカ;(It)口/
boccaccio /ボッカチオ/
boch /ボッホ/
bochum /ボッフム/
bodin /ボダン/
body /ボディ/ボディー/バディ/ボデー/バディー/
bodyart /ボディーアート/ボディアート/
bodybag /ボディバッグ/
bodyblow /ボディーブロー/ボディブロー/
bodyboard /ボディボード/ボディーボード/
bodybuil /ボディビル/
bodybuild /ボディビル/ボディービル/
bodybuilder /ボディビルダー/
bodybuilding /ボディビルディング/
bodycare /ボディケア/
bodycheck /ボディチェック;和製英語(frisk)/ボディーチェック/
bodycolor /ボディーカラー/
bodycolour /ボディーカラー/
bodycon /ボディコン;body-conscious/
bodycream /ボディクリーム/ボディークリーム/
bodyguard /ボディガード/ボディーガード/
bodylanguage /ボディランゲージ/
bodyline /ボディライン/ボディーライン/
bodylotion /ボディローション/ボディーローション/
bodymake /ボディメイク/
bodypaint /ボディペイント/
bodypainting /ボディペインティング/
bodypercussion /ボディパーカッション/ボディーパーカッション/
bodypierce /ボディピアス/ボディーピアス/
bodypress /ボディプレス/
bodyshampoo /ボディシャンプー/
bodysize /ボディサイズ/ボディーサイズ/
bodyslam /ボディスラム/
bodysoap /ボディソープ/ボディーソープ/
boeing /ボーイング;www.boeing.com/
bogart /ボガート/
bogen /ボーゲン/
bogey /ボギー/
bogota /ボゴタ;コロンビア/
bohemia /ボヘミア/
bohemian /ボヘミアン/
bohm /ベーム/
bohn /ボーン/
bohr /ボーア/
bohringer /ボーランジェ/
boil /ボイル/
boiled /ボイルド/
boiler /ボイラー/ボイラ/
boiotia /ボイオティア/
boke /ボケ/
bolan /ボラン/
bold /ボールド/
bolero /ボレロ/
bolivia /ボリビア;.bo/
bolo /ボーロ/
bologna /ボローニャ/
bolsheviki /ボリシェヴィキ;Bol'sheviki/
bolshoi /ボリショイ;(露語)/
bolt /ボルト/
boltzmann /ボルツマン/
bomb /ボム/
bombay /ボンベイ/
bombe /ボンベ;(独語)/ボンブ;(仏語)/
bomber /ボンバー/
bombo /ボンバ/ボンボ/
bon /ボン/
bonanza /ボナンザ/
bonaparte /ボナパルト/
bonbon /ボンボン/
bond /ボンド/
bondage /ボンデージ/
bonds /ボンズ/
bone /ボーン/
bonechina /ボーンチャイナ/
bonehead /ボーンヘッド/
boneless /ボンレス/
bonelessham /ボンレスハム/
bongo /ボンゴ/
bongoes /ボンゴ/
bonheur /ボヌール;(Fr)幸福/
bonita /ボニータ/
bonjour /ボンジュール/
bonn /ボン/
bonnard /ボナール/
bonnet /ボンネット/
bonney /ボニー/
bonnie /ボニー/
bonny /ボニー/
bonus /ボーナス/
bonustrack /ボーナストラック/
boo /ブー/
booby /ブービー/
boogie /ブギー/ブギ/
boogiewoogie /ブギウギ/
booing /ブーイング/
book /ブック/Book/
bookcase /ブックケース/
bookcenter /ブックセンター/
bookcover /ブックカバー;和製英語(jacket)/
bookdesign /ブックデザイン/
bookend /ブックエンド/
booker /ブッカー/
bookfair /ブックフェア/
bookguide /ブックガイド/
booking /ブッキング/
booklet /ブックレット/
booklist /ブックリスト/
bookmaker /ブックメーカー/
bookmark /ブックマーク/
bookmart /ブックマート/
bookoff /ブックオフ;www.bookoff.co.jp/
bookpost /ブックポスト/
bookreview /ブックレビュー/
books /ブックス/
bookservice /ブックサービス/
bookshelf /ブックシェルフ/
bookstand /ブックスタンド/
bookstore /ブックストア/
bool /ブール/
boole /ブール/
boolean /ブーリアン/ブーリアン関数/
boom /ブーム/
boomer /ブーマー/
boomerang /ブーメラン/
boost /ブースト/
booster /ブースター/
boot /ブート/
bootable /ブータブル/
bootdisk /ブートディスク/
booth /ブース/
bootleg /ブートレグ/ブートレッグ/
bootloader /ブートローダ/ブートローダー/
boots /ブーツ/
bootsector /ブートセクタ/
bootstrap /ブートストラップ/
bop /バップ/
borane /ボラン;BH3/
bord /ボード;坑道/
bordeaux /ボルドー/
borden /ボーデン/
border /ボーダー/
bordercollie /ボーダーコリー;border collie/
borderless /ボーダレス/ボーダーレス/
borderline /ボーダーライン/
bore /ボア/
boreas /ボレアス;北風/
borel /ボレル/
borg /ボーグ;cyborg/ボルグ/
borges /ボルヘス/
borgia /ボルジア/
borie /ボリー/
boring /ボーリング/
boris /ボリス/
borland /ボーランド/
born /ボーン/
borne /ボーン/
borneo /ボルネオ/
borneol /ボルネオール/
borodin /ボロディン/
boron /ボロン;B/
boronia /ボロニア/
borromeo /ボロメオ/
borrow /ボロー/バロー/バロウ/
borshch /ボルシチ;(露語)борщ/
borzoi /ボルゾイ/
bosch /ボッシュ/
bose /ボーズ/ボース/
bosendorfer /ベーゼンドルファー/
bosnia /ボスニア/
boson /ボソン/ボース粒子/
bosporus /ボスポラス/ボスポラス海峡/
boss /ボス/
bossa /ボサ;波/ボッサ/
bossanova /ボサノバ;bossa nova/ボサノヴァ/
boston /ボストン/ボストン大学/
bostonbag /ボストンバッグ/
bostonterrier /ボストンテリア/
bot /ボット;robot/⊥/
botanical /ボタニカル/
both /ボス/
botswana /ボツワナ;.bw/
botticelli /ボッティチェリ/
bottle /ボトル/
bottlekeep /ボトルキープ;和製英語/
bottlemail /ボトルメール/
bottleneck /ボトルネック/
bottling /ボトリング/
bottom /ボトム/⊥/下/底/
bottomline /ボトムライン/
bottoms /ボトムス/
bottomup /ボトムアップ/
botulinus /ボツリヌス/
bougainvillea /ブーゲンビリア/ブーゲンビレア/
bouillabaisse /ブイヤベース/
bouillon /ブイヨン/
boulanger /ブーランジェ;(Fr)パン職人/ブランジェ/
boulangerie /ブーランジェリー;(Fr)パン屋/ブランジェリー/ブーランジュリー/ブランジュリー/
boulevard /ブールバール/ブールヴァール/
boulez /ブーレーズ/ブレーズ/
boulogne /ブローニュ/ブーローニュ/
bounce /バウンス/
bound /バウンド/
boundary /バウンダリー/バウンダリ/
bounding /バウンディング/
bouquet /ブーケ/
bouquetgarni /ブーケガルニ/
bourbaki /ブルバキ/
bourbon /バーボン/ブルボン/
bourdieu /ブルデュー/
bourgeois /ブルジョワ/ブルジョア/
bourgeoisie /ブルジョアジー/ブルジョワジー/
bourges /ブールジュ/
bourgogne /ブルゴーニュ/
boutique /ブティック/
boutiquehotel /ブティックホテル;boutique hotel/
bouzouki /ブズーキ/
bovary /ボヴァリー/
bow /ボウ;弓/バウ;お辞儀/
bowgun /ボウガン/ボーガン/
bowie /ボウイ/
bowing /ボーイング;運弓/ボウイング/
bowl /ボール/ボウル/
bowling /ボーリング/ボウリング/
box /ボックス/□/■/
boxer /ボクサー/
boxercise /ボクササイズ/
boxerpants /ボクサーパンツ/
boxing /ボクシング/
boxseat /ボックスシート/
boxset /BOXセット/ボックスセット/
boy /ボーイ/
boycott /ボイコット/
boyer /ボイヤー/ボワイエ/
boyfriend /ボーイフレンド/
boyish /ボーイッシュ/
boyle /ボイル/
boys /ボーイズ/
boyscout /ボーイスカウト/
boyslove /ボーイズラブ;boy's love,和製英語(=yaoi)/
boysoprano /ボーイソプラノ/
bq /“;backquote/
br /臭素/Bromine/
bra /ブラ;brassiere/
brabus /ブラバス;www.brabus.com/
brace /ブレース/｛/｝/
bracelet /ブレスレット/
bracket /ブラケット/［/］/
brad /ブラッド/
bradbury /ブラッドベリ/
bradley /ブラッドリー/ブラッドレイ/ブラッドレー/
brady /ブレイディ/ブレディ/ブレイディー/ブレディー/
brahman /ブラフマン/ブラーマン/ブラフマー/
brahmana /バラモン/
brahmin /バラモン/
brahms /ブラームス/
brain /ブレイン/ブレーン/
brainbuster /ブレーンバスター/
brainstorming /ブレーンストーミング/ブレインストーミング/
brake /ブレーキ/
brakedrum /ブレーキドラム/
brakelamp /ブレーキランプ/
brakelever /ブレーキレバー/
brakeoil /ブレーキオイル/
brakepedal /ブレーキペダル/
braking /ブレーキング/
bram /ブラム/
bramante /ブラマンテ/
branca /ブランカ/
branch /ブランチ/
brand /ブランド/
brandenburg /ブランデンブルク/
brandimage /ブランドイメージ/
branding /ブランディング/
brandmaker /ブランドメーカー/
brando /ブランド/
brandon /ブランドン/
brands /ブランズ/
brandshop /ブランドショップ/
brandt /ブラント/
brandy /ブランデー/
branford /ブランフォード/
brank /Bランク/Ｂランク/
braque /ブラック/
brasilia /ブラジリア/
brass /ブラス/
brassband /ブラスバンド/
brassiere /ブラジャー/
brassy /ブラッシー/
brat /ブラット/
bratislava /ブラチスラヴァ/
braudel /ブローデル/
braun /ブラウン;-管/
brautigan /ブローティガン/
brave /ブレイブ/
braves /ブレーブス;[MLB]/
bravo /ブラボー/ブラヴォー/ブラーボ/ブラーヴォ/
bray /ブレイ/ブレー/
brazil /ブラジル;.br/
brazilgp /ブラジルGP;[F1]/
brazilian /ブラジリアン/
brazzaville /ブラザヴィル/
bread /ブレッド/
break /ブレイク/ブレーク/ブレーキ;※brake?/
breakbeats /ブレイクビーツ/
breakdance /ブレイクダンス/
breakdancer /ブレイクダンサー/
breakdown /ブレークダウン/
breaker /ブレーカー/ブレーカ/
breakfast /ブレックファースト/
breaking /ブレーキング/
breakpoint /ブレークポイント/ブレイクポイント/
breakthrough /ブレークスルー/ブレイクスルー/
breast /ブレスト/
breath /ブレス/
breathe /ブリーズ/
breathing /ブリージング/ブレッシング/
brecht /ブレヒト/
brecker /ブレッカー/
bree /ブリー/ブレー/
breed /ブリード/
breeder /ブリーダー/
breeding /ブリーディング/
breeze /ブリーズ/
breezing /ブリージング/
bremen /ブレーメン/
brenda /ブレンダ/
brendan /ブレンダン/
brendel /ブレンデル/
brentano /ブレンターノ/
bresenham /ブレゼンハム/
bresson /ブレッソン;Henri Cartier-Bresson/
brest /ブレスト/
bret /ブレット/
bretagne /ブルターニュ/
breton /ブルトン/ブレトン/
brett /ブレット/
bretton /ブレトン/
brettonwoods /ブレトンウッズ;Bretton Woods/
brevis /ブレビス/ブレヴィス/
brewers /ブリュワーズ;[MLB]/
brewery /ブルワリー/
brezhnev /ブレジネフ/
brian /ブライアン/
bribri /ブリブリ/
brice /ブライス/
brick /ブリック/
bricolage /ブリコラージュ/
bridal /ブライダル/
bride /ブライド/
bridge /ブリッジ/
bridgestone /ブリヂストン;www.bridgestone.co.jp/ブリジストン/
bridget /ブリジット/
bridgetown /ブリッジタウン/
bridging /ブリッジング/
brief /ブリーフ/
briefcase /ブリーフケース/
briefing /ブリーフィング/
bright /ブライト/
brightness /ブライトネス/
brigid /ブリジッド/
brigit /ブリジット/
brigitte /ブリジット/ブリギッテ/
brillante /ブリランテ/
brillat /ブリア/ブリヤ/
brilliant /ブリリアント/
brilliantcut /ブリリアントカット/
bring /ブリング/
brio /ブリオ/
brioche /ブリオッシュ/
brion /ブリオン/
brisbane /ブリスベン;豪州/ブリスベーン/ブリズベーン/
brisee /ブリゼ/
bristol /ブリストル/
brit /ブリット/
britain /ブリテン;.gb/
britannia /ブリタニア/
britannica /ブリタニカ/
british /イギリス/ブリティッシュ/
britney /ブリトニー/
britten /ブリテン/
brix /ブリックス/
brno /ブルノ/
broach /ブローチ;(工具)/
broad /ブロード/
broadband /ブロードバンド/
broadbandrouter /ブロードバンドルータ/
broadcast /ブロードキャスト/
broadcaster /ブロードキャスター/
broadsword /ブロードソード/
broadway /ブロードウェイ/ブロードウェー/
broca /ブローカ/
broccoli /ブロッコリー/
broch /ブロッホ/
brocken /ブロッケン/
broderick /ブロデリック/
broglie /ブロイ/
broiler /ブロイラー/
broke /ブローク/
broken /ブロークン/
broker /ブローカー/
brom /ブロム;Br/
bromide /ブロマイド/
bromo /ブロモ/
bromodichloromethane /ブロモジクロロメタン;(CHBrCl2) トリハロメタンの一種/
bromoform /ブロモホルム;(CHBr3) トリハロメタンの一種/
bronte /ブロンテ/
bronx /ブロンクス/
bronze /ブロンズ/
brooch /ブローチ/
brook /ブルック/
brookes /ブルックス/
brooklyn /ブルックリン/
brooks /ブルックス/
brother /ブラザー/
brotherhood /ブラザーフッド/
brothers /ブラザーズ/
brouter /ブルータ/
brow /ブラウ;眉/ブロウ;?/
brown /ブラウン/
brownie /ブラウニー/
browning /ブラウニング/ブローニング/
brownsauce /ブラウンソース/
brownsugar /ブラウンシュガー/
browny /ブラウニー/
browse /ブラウズ/
browser /ブラウザ/ブラウザー/
browsersoft /ブラウザソフト/
browsing /ブラウジング/
browzer /ブラウザ;browser?/
brubeck /ブルーベック/
bruce /ブルース/
bruckner /ブルックナー;(1824-96)Josef Anton Bruckner/
brueghel /ブリューゲル/
brule /ブリュレ/
brulee /ブリュレ/
brumaire /ブリュメール/
brunch /ブランチ/
brunei /ブルネイ/
brunelleschi /ブルネレスキ/
brunello /ブルネッロ/
brunette /ブルネット/
brunhild /ブリュンヒルト/
brunhilde /ブリュンヒルデ/
bruni /ブルーニ/
brunnhilde /ブリュンヒルデ/
bruno /ブルーノ/ブリューノ/ブリュノ/
brunswick /ブランズウィック/
bruschetta /ブルスケッタ/
brush /ブラシ/ブラッシュ/
brushing /ブラッシング/
brushup /ブラッシュアップ/
brussels /ブラッセル/
brut /ブリュット/
brute /ブルート/
brutus /ブルータス/
bruxelles /ブリュッセル/
bryan /ブライアン/
bryant /ブライアント/
bryce /ブライス/
bsantenna /BSアンテナ/
bsd /BSD/
bsd# /(concat "BSD\057#0")/
bsdi /BSDI/
bsdigital /BSデジタル/
bsdlicence /BSDライセンス/
bsdlicense /BSDライセンス/
bse /Bovine Spongiform Encephalopathy/
bskey /BSキー/バックスペースキー/
bspline /Bスプライン/
bstuner /BSチューナー/BSチューナ/
btype /Bタイプ/Ｂタイプ/
bubble /バブル/
bubblegum /バブルガム/
bubblejet /バブルジェット/
bubblesort /バブルソート/
bubbling /バブリング/
bubbly /バブリー/
bubbule /バブル;※bubble?/
bucharest /ブカレスト/
buche /ビュッシュ/
buchwald /ブッフバルト/
buck /バック/ブック/
bucket /バケット/バケツ/
bucketrelay /バケツリレー;和製英語(bucket brigade)/
buckingham /バッキンガム/
buckle /バックル/
buckler /バックラー/
buckskin /バックスキン/
bucky /バッキー/
bud /バド/バッド/
budapest /ブダペスト/
buddha /ブッダ/仏陀/
buddhagaya /ブッダガヤ/
buddy /バディ/
budget /バジェット/
budweiser /バドワイザー/
buena /ブエナ/
bueno /ブエノ/
buenos /ブエノス/
buenosaires /ブエノスアイレス;Buenos Aires/
buffalo /バッファロー/バファロー/
buffaloes /バファローズ/バッファローズ/
buffer /バッファ/バッファー/作業域/
buffered /バッファード/
bufferin /バファリン;[商標]ライオン。www.bufferin.net/
buffering /バッファリング/
bufferoverflow /バッファオーバーフロー/
bufferoverrun /バッファオーバーラン/
buffersize /バッファサイズ/
buffet /ビュッフェ/
buffle /バッフル/
buffon /ブッフォン/
bug /バグ/
bugfix /バグフィックス/バグフィクス/
buggy /バギー/
bugle /ビューグル/
buglist /バグリスト/
bugreport /バグレポート/
buick /ビュイック;www.buick.com/
buil /ビル/
build /ビルド/
builder /ビルダー/ビルダ/
buildin /ビルドイン/
building /ビルディング/ビル/ビルヂング/
built-in /ビルトイン/
builtin /ビルトイン/
bujumbura /ブジュンブラ/
bukhara /ブハラ/
bukowski /ブコウスキー/
bulb /バルブ/
bulgari /ブルガリ;www.bulgari.com/
bulgaria /ブルガリア;.bg/
bulgogi /プルコギ;(朝鮮語)/
bulk /バルク/
bull /ブル/
bulldog /ブルドッグ/ブルドック;[企業名]www.bulldog.co.jp/
bulldozer /ブルドーザー/ブルドーザ/
bulletin /ブリテン/
bulletinboard /ブレティンボード/
bullpen /ブルペン/
bump /バンプ/
bumper /バンパー/
bumpmapping /バンプマッピング/
buncher /バンチャ/
bundesliga /ブンデスリーガ;(独語)/
bundle /バンドル/
bundling /バンドリング/
bungalow /バンガロー/
bungee /バンジー/
bungeejump /バンジージャンプ/
bunin /ブーニン/
bunker /バンカー;[ゴルフ]/
bunkershot /バンカーショット/
bunny /バニー/
bunnygirl /バニーガール/
buns /バンズ/
bunt /バント/
bunuel /ブニュエル/
buoy /ブイ/
burberry /バーバリー;www.burberry.com/
burckhardt /ブルクハルト/
burden /バーデン/
bureau /ビューロー/
burg /ブルク;(独語接尾辞)Salzburg,Luxemburg/
burger /バーガー/
burgerking /バーガーキング;www.bk.com/
burgmuller /ブルグミュラー/
burgos /ブルゴス/
burgundy /バーガンディー/バーガンディ/
burial /ベリアル/
burka /ブルカ/
burkinafaso /ブルキナファソ;Burkina Faso,(Burkina Faso) .bf/
burlesque /バーレスク/
burma /ビルマ/
burn /バーン/
burnaby /バーナビー/
burner /バーナー/
burnet /バーネット;ワレモコウ/
burning /バーニング/
burnout /バーンアウト/
burns /バーンズ/
burnt /バーント/
burrell /バレル/
burroughs /バロウズ/バローズ/
burst /バースト/
burster /バースター/
burt /バート/
burton /バートン/
burundi /ブルンジ;.bi/ブルンディ/
buryat /ブリャート/
bus /バス/
busch /ブッシュ/
busclock /バスクロック/
buserror /バスエラー/Ｂｕｓ Ｅｒｒｏｒ/
busguide /バスガイド;和製英語(bus tour guide)/
bush /ブッシュ/
bushbaby /ブッシュベイビー/
bushman /ブッシュマン/
business /ビジネス;.biz/
businesscenter /ビジネスセンター/
businesscentre /ビジネスセンター/
businesschance /ビジネスチャンス/
businessclass /ビジネスクラス/
businesshotel /ビジネスホテル/
businessletter /ビジネスレター/
businesslike /ビジネスライク/
businessman /ビジネスマン/
businessmanner /ビジネスマナー/
businessmodel /ビジネスモデル/
businessperson /ビジネスパーソン/
businessplan /ビジネスプラン/
businessscene /ビジネスシーン/
businessschool /ビジネススクール/
businesssoft /ビジネスソフト/
busjack /バスジャック/
busmaster /バスマスタ/バスマスター/
buspower /バスパワー/
busstop /バスストップ/
bust /バスト/
buster /バスター/
busterminal /バスターミナル/
busters /バスターズ/
bustier /ビスチェ/
bustline /バストライン/
bustour /バスツアー;bus tour/
bustsize /バストサイズ/
busttop /バストトップ/
bustup /バストアップ;和製英語/
busy /ビジー/ビジィ/
but /バット/
butadiene /ブタジエン/
butan /ブタン;C4H10/
butane /ブタン;C4H10/
butanol /ブタノール;C4H9OH/
butch /ブッチ/
butcher /ブッチャー/
butene /ブテン;=butylene/
butler /バトラー/
butor /ビュトール/
butt /バット/ブット/
butter /バター/
buttercream /バタークリーム/
buttercup /バターカップ/
butterfly /バタフライ/
butterflyknife /バタフライナイフ/
butterknife /バターナイフ/
butterrice /バターライス/
butterroll /バターロール;和製語/
buttersauce /バターソース/
butterworth /バタワース/
butting /バッティング/
button /ボタン/バトン;人名/
buttonhole /ボタンホール/ボタン穴/
butyl /ブチル;CH3CH2CH2CH2-/
butylene /ブチレン/
buy /バイ/
buyer /バイヤー/
buyers /バイヤーズ/
buying /バイイング/
buyout /バイアウト/
buzz /バズ/
buzzer /ブザー/
buzzing /バジング/
bvlgari /ブルガリ;vはラテン語表記を模したもの/
by /バイ/
bye /バイ/バーイ/
byebye /バイバイ;bye-bye/
bypass /バイパス/
bypath /バイパス/
byron /バイロン/
byte /バイト/Ｂｙｔｅ/
byte-compile /バイトコンパイル/
byte-compiler /バイトコンパイラ/
bytecode /バイトコード/
bytecompile /バイトコンパイル/
bytecompiler /バイトコンパイラ/
bytes /バイツ/
byzantine /ビザンチン/
c /℃/¢;cent/シー/ツェー;(独語)/セー;(仏語)/炭素/Carbon/Ｃ言語/
c++ /Ｃ＋＋/C++/
c++compiler /C++コンパイラ/
ca /カルシウム/Calcium/California/カリフォルニア/カルフォルニア/
caay /チャイ;Hindi/
cab /キャブ/
cabaca /カバサ/
cabala /カバラ/
cabaret /キャバレー/
cabbage /キャベツ/
cabernet /カベルネ/
cabin /キャビン/
cabinet /キャビネット/キャビネ;仏語/
cable /ケーブル/
cablecar /ケーブルカー/
cablemodem /ケーブルモデム/
cabletv /ケーブルテレビ/ケーブルTV/
cabling /ケーブリング/
caboverde /カーボベルデ;(Cabo Verde) .cv/カーボヴェルデ/
cabrera /カブレラ/
cacao /カカオ/
cachable /キャッシャブル/
cache /キャッシュ/
cachememory /キャッシュメモリ/キャッシュメモリー/
caching /キャッシング/
caco /カコ/
cactus /カクタス;サボテン/
cad /CAD/キャド;computer-aided design/
caddie /キャディ/キャディー/
caddy /キャディ/キャディー/
cadence /ケイデンス/
cadenza /カデンツァ/
cadet /カデット/
cadfael /カドフェル/
cadillac /キャデラック/
cadiz /カディス/
cadmium /カドミウム;[元素]48,Cd/
cadsoft /CADソフト/
cady /キャディー/
caen /カーン/
caesar /シーザー/カエサル/
caesium /セシウム;[元素]55,Cs/
caetla /サエラ;(Fr)ca et la/
cafe /カフェ/
cafeaulait /カフェオレ;cafe au lait/カフェ・オ・レ/
cafebar /カフェバー/
cafelatte /カフェラッテ;(It)cafe latte/
cafeteria /カフェテリア/
cafeterrace /カフェテラス/
cafeterrasse /カフェテラス/
caffeine /カフェイン/
cage /ケージ/
cagliari /カリアリ/
cagliostro /カリオストロ/
cahier /カイエ;(Fr)ノート/
caillois /カイヨワ/
caiman /カイマン/
cain /カイン/ケイン/
caine /ケイン/
cairns /ケアンズ;豪州/
cairo /カイロ/
caisson /ケーソン/
cajon /カホン/
cajun /ケイジャン/
cake /ケーキ/
cakecut /ケーキカット;和製英語/
cakemix /ケーキミックス;cake mix/
cakeset /ケーキセット/
cakewalk /ケークウォーク/
cakra /チャクラ/
calais /カレー/
calbee /カルビー;www.calbee.co.jp/
calceolaria /カルセオラリア/
calcite /カルサイト;方解石/
calcium /カルシウム;[元素]20,Ca/
calciumion /カルシウムイオン;calcium ion/
calculus /カルキュラス/
calcutta /カルカッタ;NB:現在は「コルカタ」/コルカタ;kolkata/
caldera /カルデラ/
caldina /カルディナ/
caleca /カレカ/
caledonia /カレドニア/
calendar /カレンダー/カレンダ/
calender /カレンダ/
calgary /カルガリー/
caliber /キャリバー/
calibration /キャリブレーション/
calico /キャラコ/キャリコ/
calif /カリフ/
california /カリフォルニア/カルフォルニア/
californium /カリフォルニウム;[元素]98,Cf/
caligari /カリガリ/
caligula /カリギュラ/
calimba /カリンバ/
caliph /カリフ/
call /コール/
callas /カラス/
callaway /キャロウェイ/
callback /コールバック/
callcenter /コールセンター/
callcentre /コールセンター/
called /コールド/
calledgame /コールドゲーム;和製英語/
caller /コーラー/呼出し側/
callgirl /コールガール/
calligraphy /カリグラフィー/カリグラフィ/
calling /コーリング/
calliope /カリオペ/
callisto /カリスト/
callose /カロース/
calloway /キャロウェイ/
callsign /コールサイン/
callus /カルス/
calm /カーム/
calme /カルム;仏語/
calorie /カロリー/
caloriemate /カロリーメイト/
calpis /カルピス;www.calpis.co.jp/
caltech /カルテック;カリフォルニア工科大学。www.caltech.edu/
calume /カルメ/
calvados /カルヴァドス/カルバドス/
calvan /カルバン/カルヴァン/
calvary /カルバリー/
calvin /カルヴァン/カルヴィン/カルビン/
calvinklein /カルバンクライン/カルバン・クライン/
calvino /カルヴィーノ;(1923-1985) Italo Calvino/
calypso /カリプソ/
cam /カム/
camara /カマラ/
camber /キャンバー/
cambodia /カンボジア;.kh/
cambria /カンブリア/
cambridge /ケンブリッジ/
camel /キャメル/
camelia /カメリア/
camellia /カメリア/
camelot /キャメロット/
camembert /カマンベール/
cameo /カメオ/
camera /カメラ/
cameraangle /カメラアングル;camera angle/
cameraeye /カメラアイ/
cameraman /カメラマン/
camerawork /カメラワーク/
cameron /キャメロン/
cameroon /カメルーン;.cm/
cameroun /カメルーン/
camilla /カミラ/
camille /カミーユ/
camino /カミーノ/
camion /カミオン/
camisole /キャミソール/
camoranesi /カモラネージ/
camouflage /カモフラージュ/カムフラージュ/
camp /キャンプ/
campaign /キャンペーン/
campaigngirl /キャンペーンガール/キャンギャル/
campana /カンパーナ/
campanella /カンパネラ/カンパネルラ/カンパネッラ/
campanula /カンパニュラ/
campari /カンパリ/
campariorange /カンパリオレンジ/
camparisoda /カンパリソーダ/
campbell /キャンベル/
camper /キャンパー/
campfire /キャンプファイヤー/キャンプファイアー/
camphor /カンフル/
campin /キャンプイン;和製英語/
camping /キャンピング/
campingcar /キャンピングカー;和製英語(camper)/
campo /カンポ;(西語) 草原/
campos /カンポス/
campra /カンプラ/
campus /キャンパス/
campuslife /キャンパスライフ/
campusmap /キャンパスマップ/
camry /カムリ;[商標]トヨタ/
camus /カミュ/
can /キャン/カン;缶/
canaan /カナン/カナーン/
canada /カナダ;.ca/加奈陀/
canadagp /カナダGP;[F1]/
canadian /カナディアン/
canal /カナル/キャナル/
canape /カナッペ/
canard /カナード/カナール;(Fr) 家鴨/
canaria /カナリア/カナリヤ/
canary /カナリア/カナリヤ/
canasta /カナスタ/
canberra /キャンベラ/
cancan /カンカン/
cancel /キャンセル/
canceler /キャンセラ/
cancellation /キャンセレーション/
canceller /キャンセラー/キャンセラ/
cancer /キャンサー;癌/
cancion /カンシオン;(西語)歌/
cancun /カンクン;メキシコ/
candela /カンデラ;cd/
candice /キャンディス/
candid /カンディード/キャンディッド/
candida /カンジダ/
candide /カンディード/
candies /キャンディーズ/
candle /キャンドル/
candlelight /キャンドルライト/
candleservice /キャンドルサービス/
candlestand /キャンドルスタンド/
candy /キャンディ/キャンディー/キャンデー/
cane /ケイン/ケーン/籐/
canet /カネ/
canetti /カネッティ/
canister /キャニスター/
canna /カンナ/
cannabis /カンナビス/
canne /カンヌ/
cannedbeef /コンビーフ/
cannele /カヌレ/
cannes /カンヌ/
cannibalism /カニバリズム/
cannon /キャノン/
cannonball /キャノンボール/
canoe /カヌー/
canola /キャノーラ/カノーラ/
canon /カノン/キャノン/キヤノン;[企業名]www.canon.com/
canonical /カノニカル/
canopus /カノープス/
canopy /キャノピー/
canossa /カノッサ/
cant /カント/
cantabile /カンタービレ/
cantata /カンタータ/交声曲/
canter /キャンター/カンター/
canterbury /カンタベリー/
canto /カント/
cantona /カントナ/
cantor /カントール/カントル/
canvas /キャンバス/カンバス/カンヴァス/
canvastop /キャンバストップ/
canyon /キャニオン/
canzone /カンツォーネ/
canzonette /カンツォネッタ/
cap /キャップ/∩/
capa /キャパ/
capability /ケーパビリティ/
capacitance /キャパシタンス/
capacity /キャパシティ/キャパシティー/
capati /チャパティ/
capcom /カプコン;www.capcom.co.jp/
cape /ケープ/
capek /チャペック/
capella /カペラ/
caper /ケイパー/ケーパー/
capet /カペー/
capetown /ケープタウン/
capeverde /カーボベルデ;Cape Verde (cv)/
capital /キャピタル/
capitalgain /キャピタルゲイン/
capitalism /キャピタリズム/
capitol /キャピトル/
capo /カーポ/
capoeira /カポエイラ/カポエラ/
caponata /カポナータ/
capote /カポーテ/カポーティ/
cappadocia /カッパドキア/
cappuccino /カプチーノ;イタリア語/
capra /キャプラ/
capri /カプリ/
capriccio /カプリッチョ/カプリッチオ/
capriccioso /カプリチオーソ/
caprice /カプリス/
capricious /カプリシャス/
capricorn /カプリコーン;山羊座/カプリコン/
capripants /カプリパンツ;capri pants/
caprolactam /カプロラクタム/
capsaicin /カプサイシン/
capsule /カプセル/
capsulehotel /カプセルホテル;和製英語/
captain /キャプテン/
captaincy /キャプテンシー/
caption /キャプション/
capture /キャプチャ/キャプチャー/取込/
captureboard /キャプチャボード/キャプチャーボード/
capturecard /キャプチャカード/キャプチャーカード/
capybara /カピバラ/
car /カー/
cara /キャラ/カラ/カーラ/
caracas /カラカス/
caramel /キャラメル/カラメル/
caramelo /カルメラ/
caraque /カラク/
carat /カラット;200mg/キャラット/
caraudio /カーオーディオ/
caravan /キャラバン/キャラヴァン/
caravansarai /キャラバンサライ/
caravansary /キャラバンサライ/
caraway /キャラウェイ/
carbattery /カーバッテリー/
carbide /カーバイド/
carbine /カービン/
carbon /カーボン/
carbonara /カルボナーラ/
carbonate /カーボネイト/カーボネート/
carboncopy /カーボンコピー;CC/
carbonfiber /カーボンファイバー/
carbonnanotube /カーボンナノチューブ/
carbonyl /カルボニル/
carboxyl /カルボキシル/
carbuncle /カーバンクル/
carburetor /キャブレター/キャブ/
carchase /カーチェイス/
card /カード/
cardamon /カルダモン/
cardbus /カードバス/
cardcase /カードケース/
cardealer /カーディーラー/
cardgame /カードゲーム/
cardiff /カーディフ/
cardigan /カーディガン/
cardin /カルダン/
cardinal /カーディナル/
cardinals /カージナルス;[MLB]/
cardioid /カージオイド/カーディオイド/
cardloan /カードローン/
cardmodem /カードモデム/
cardreader /カードリーダー/カードリーダ/
cards /トランプ/カーズ/
cardslot /カードスロット/
cardwindow /カードウインドー/
care /ケア/
career /キャリア/キャリアー/
careerpath /キャリアパス/
careerplan /キャリアプラン/
careerup /キャリアアップ;和製英語/
careerwoman /キャリアウーマン/
careful /ケアフル/
carehouse /ケアハウス/
careless /ケアレス/
carelessmiss /ケアレスミス/
caremanagement /ケアマネジメント/
caremanager /ケアマネージャー/
careplan /ケアプラン/
caret /カレット;^/キャレット/
carey /キャリー/
carferry /カーフェリー;和製英語/
cargo /カーゴ/
carib /カリブ/
caribbean /カリビアン/
caribou /カリブー/
caricature /カリカチュア/
carillon /カリヨン/
carina /カリーナ/
carini /カリーニ/
carita /カリタ/
caritas /カリタス/
carl /カール/
carla /カーラ/カルラ/
carlease /カーリース/
carlife /カーライフ/
carlo /カルロ/
carlos /カルロス/
carlotta /カルロッタ/
carlson /カールソン/
carlton /カールトン/
carlyle /カーライル/
carmela /カルメラ/
carmen /カルメン/カーメン/
carmichael /カーマイケル/
carmine /カーマイン/カルミン/カーミン/
carmona /カルモナ/
carna /カルナ/
carnation /カーネーション/
carnaval /カルナバル/
carnavi /カーナビ;car navigation system/
carnavigation /カーナビゲーション;car navigation system/
carnegie /カーネギー/カーネギーメロン大学/
carnegiemellon /カーネギーメロン/
carnelian /カーネリアン/
carnet /カルネ/
carney /カーニー/
carnival /カーニバル/
carnot /カルノー/
carnotcycle /カルノーサイクル/
carol /キャロル/
carole /キャロル/
carolina /キャロライナ/カロライナ/カロリーナ/カロリナ/
caroline /キャロライン/キャロリン/カロリーヌ/
caroling /カロリング/
carolyn /キャロリン/キャロライン/カロリン/
carossa /カロッサ/
carotene /カロチン/カロテン/
carotenoid /カロチノイド/カロテノイド/
carothers /カロザース/
carotin /カロチン/カロテン/
carotinoid /カロチノイド/カロテノイド/
carousel /カルーセル/
carp /カープ/
carpaccio /カルパッチョ/
carpathia /カルパチア/
carpeaux /カルポー/
carpenter /カーペンター/
carpenters /カーペンターズ/
carpet /カーペット/
carport /カーポート/
carr /カー/
carrace /カーレース/
carrageenin /カラギーナン/
carrasco /カラスコ/
carre /カレ/
carrefour /カルフール;(Fr)十字路/
carreras /カレーラス/
carriage /キャリッジ/
carrie /キャリー/
carrier /キャリア/キャリアー/
carriere /カリエール/
carrol /キャロル/
carroll /キャロル/
carrot /キャロット/
carry /キャリー/カレー;※curry?/
carrybag /キャリーバッグ/
carrying /キャリング/
carryingcase /キャリングケース/
carryover /キャリーオーバー/
cars /カーズ/
carsex /カーセックス/
carshop /カーショップ/
carson /カーソン/
carsten /カルステン/
carstereo /カーステレオ/
cart /カート/
carta /カルタ;(葡語)/
carte /カルテ/カルト;(Fr) カード。 cf. a la carte/
cartel /カルテル/
carter /カーター/
cartesian /カルテジアン/
carthago /カルタゴ/
cartier /カルティエ;www.cartier.com/
cartinine /カルニチン/
carton /カートン/カルトン/
cartoon /カートゥーン/
cartrace /カートレース/
cartridge /カートリッジ/
cartrige /カートリッジ;※cartridge/
carve /カーブ;彫る/カーヴ/
carver /カーヴァー/カーバー/
carving /カービング/
cary /ケアリー/ケーリー/
casa /カーサ/
casablanca /カサブランカ/
casals /カザルス/
casanova /カサノヴァ/カサノバ/
casas /カサス/
cascade /カスケード/
cascading /カスケーディング/
case /ケース/ケイス/CASE/
casebycase /ケースバイケース/
casein /カゼイン/
casestudy /ケーススタディ/ケーススタディー/
casette /カセット/
casettedeck /カセットデッキ/
casettetape /カセットテープ/
caseworker /ケースワーカー/
cash /キャッシュ/
cashback /キャッシュバック/
cashcard /キャッシュカード/
cashcorner /キャッシュコーナー/
cashdispencer /キャッシュディスペンサー/
cashe /キャッシュ;※cache?/
cashew /カシュー/
cashewnut /カシューナッツ/
cashflow /キャッシュフロー/
cashier /キャッシャー/
cashing /キャッシング/
cashless /キャッシュレス/
cashmere /カシミヤ/カシミア/
casimir /カシミール/
casing /ケーシング/
casino /カジノ/
casio /カシオ/
casiopea /カシオペア;バンド名 (NB:星座名はcassiopeia)/
cask /キャスク/
casl /CASL/
casper /カスパー/
casque /カスク/
cass /キャス/
cassandra /カサンドラ/カッサンドラ/
cassano /カッサーノ/
cassave /キャッサバ/
cassel /カッセル/
casserole /キャセロール/
cassette /カセット/
cassini /カッシーニ/
cassiopeia /カシオペア/
cassis /カシス/
cassissoda /カシスソーダ/
cassius /カシアス/
cassou /カスー/
cassoulet /カスレ/
casssini /カッシーニ/
cast /キャスト/
casta /カスタ/
castanet /カスタネット/
castanets /カスタネット/
caste /カースト/
castello /カステロ/
castelo /カステロ/
caster /キャスター/
castilla /カステラ/
casting /キャスティング/
castingvote /キャスティングボート/
castle /キャッスル/
castleton /キャッスルトン/
castor /カストル/カスター/
castrato /カストラート/
castries /カストリーズ/
castro /カストロ/
casual /カジュアル/
casualfashion /カジュアルファッション/
casualwear /カジュアルウェア/
cat /キャット/
cata /カタ/
catacomb /カタコンベ/
catacombe /カタコンベ/
catalina /カタリナ/カタリーナ/
catalog /カタログ/
catalogspec /カタログスペック/
catalogue /カタログ/
catalonia /カタロニア/
cataluna /カタルニア/
catalunya /カタルーニャ;スペイン/
catalyst /カタリスト/
catania /カターニア/
catanol /セタノール;C16H35OH/
catapult /カタパルト/
catarina /カタリナ/カタリーナ/
catarrh /カタル/
catastrophe /カタストロフ/
catastrophy /カタストロフィ/カタストロフィー/
catch /キャッチ/
catchball /キャッチボール/
catchcopy /キャッチコピー;和製英語/
catcher /キャッチャー/
catcherfly /キャッチャーフライ/
catchermit /キャッチャーミット/
catchphone /キャッチホン/
catchphrase /キャッチフレーズ/
catchsales /キャッチセールス;和製英語/
catchup /キャッチアップ/
catchy /キャッチー/
catechin /カテキン/
catechol /カテコール/
categorical /カテゴリカル/
categorise /カテゴライズ/
categorize /カテゴライズ/
category /カテゴリ/カテゴリー/範疇/
caterina /カテリーナ/
catering /ケータリング/
caterpillar /キャタピラ/
catfight /キャットファイト/
catfish /キャットフィッシュ;鯰/
catfood /キャットフード/
cath /キャス/
cathari /カタリ/
catharina /カタリナ/
catharsis /カタルシス/
cathay /キャセイ/カセイ/
cathedral /カテドラル/カセドラル/
cathereine /キャサリン/
catherine /キャサリン/カトリーヌ/
catheter /カテーテル/
cathode /カソード/
catholic /カトリック/カソリック/
catholicism /カトリシズム/
cathy /キャシー/
cation /カチオン/
catnip /キャットニップ/
cato /カトー/
cats /キャッツ/
catseye /キャッツアイ;cat's-eye/
catshow /キャットショー/
catsup /ケチャップ/
cattle /キャトル/
cattleya /カトレア/カトレヤ/
catv /ケーブルテレビ/
catwalk /キャットウォーク/
caucasoid /コーカソイド/
caucasus /コーカサス/
cauchy /コーシー/
cauliflower /カリフラワー/
caulking /コーキング/
cause /コーズ/
caution /コーション/
cavalier /キャバリア/キャバリエ/カバリエ/
cavalleria /カヴァレリア/
cave /ケーブ/
caviar /キャビア/
cavitation /キャビテーション/
cavity /キャビティ/キャビティー/
caxias /カシアス/
caxixi /カシシ/
cay /ケイ/
cayenne /カイエン/カイエンヌ/
cayennepepper /カイエンペッパー/カイエンヌペッパー/
cayman /ケイマン;.ky/
cc /カーボンコピー;carbon copy/
ccdcamera /CCDカメラ;charge-coupled device camera/
cclass /Cクラス/Ｃクラス/
ccompiler /Cコンパイラ/
ccr /CCR(Creedence Clearwater Revival)/
ccup /Cカップ;15cm/Ｃカップ/
cd /コンパクトディスク/キャッシュディスペンサー/カドミウム/Cadmium/カンデラ;光度の単位,SI基本単位/CD/
cdb /Command Description Block/
cdbook /CDブック/
cdcase /CDケース/
cddrive /CDドライブ/
cdjacket /CDジャケット/
cdot /・/
cdots /…/
cdplayer /CDプレーヤー/CDプレイヤー/
cdrack /CDラック/
cdradicase /CDラジカセ/
cdreview /CDレビュー/
cdrive /Cドライブ;C:/Ｃドライブ/
cdrom /CD-ROM/ＣＤ−ＲＯＭ/
cds /ＣｄＳ/
cdshop /CDショップ/
ce /セリウム/Cerium/
ceausescu /チャウシェスク/
cebu /セブ;フィリピン/
cecil /セシル/
cecile /セシール/セシル/
cecilia /セシリア/
cedille /セディーユ/
cedric /セドリック/
cee /シー/
ceiling /シーリング/
ceilinglight /シーリングライト/
celadon /セラドン/
celan /ツェラン/
celeague /セリーグ/セ・リーグ/セントラルリーグ/
celeb /セレブ;celebrity/
celebes /セレベス/
celebration /セレブレーション/
celebrity /セレブリティ/
celeron /セレロン/
celery /セロリ/セルリ/セルリー/
celesta /チェレスタ/
celeste /セレステ/セレスト/セレスティ/
celestin /セレスタン/
celestite /セレスタイト/
celia /セリア/
celica /セリカ/
celine /セリーヌ/
cell /セル/
cellanime /セルアニメ;cell animation/
cellar /セラー/セルラー;?/
cellinstance /セルインスタンス/
cellist /チェリスト/
cellmotor /セルモーター;和製英語(starter)/
cello /チェロ/
cellophane /セロファン/セロハン/
cellophanetape /セロハンテープ/
cellosonata /チェロソナタ/
cellular /セルラー/
cellulase /セルラーゼ/
cellulite /セルライト/
celluloid /セルロイド/
cellulose /セルロース/
celsior /セルシオ/
celsius /セルシウス/℃/
celt /ケルト/
celtic /ケルティック/セルティック/
cembalo /チェンバロ/
cemedine /セメダイン;www.cemedine.co.jp/
cement /セメント/
cemetery /セメタリー/
censor /センサー;検閲/
census /センサス/
cent /セント/¢/
centaur /ケンタウロス/
centauri /ケンタウリ/
center /センター/センタ/
centercourt /センターコート/
centerfly /センターフライ/
centering /センタリング/
centerline /センターライン/
centerover /センターオーバー;和製英語/
centerpole /センターポール/
centi /センチ/
centime /サンチーム/
central /セントラル/
centralheating /セントラルヒーティング/
centralleague /セントラルリーグ/
centralpark /セントラルパーク/
centre /センター/
centreline /センターライン/
centric /セントリック/
centrism /セントリズム;econo-,ego-,ethno-/
centromere /セントロメア/
centronics /セントロニクス/
century /センチュリー/
cephem /セフェム/
cepheus /ケフェウス/
cepstral /ケプストラル/
cepstrum /ケプストラム/
ceramic /セラミック/
ceramicheater /セラミックヒーター/
ceramics /セラミックス/セラミクス/
cerberus /ケルベロス;英語綴り/
cercle /セルクル;(Fr)輪/
cereal /シリアル/
ceremony /セレモニー/
cerezo /セレッソ;[Jリーグ]大阪/
ceria /セリア/
cerise /スリーズ;(Fr) 桜/
cerium /セリウム;[元素]58,Ce/
certan /セルタン/
certification /サーティフィケーション/
cervantes /セルバンテス/
cesar /セザール/セサル/
cesare /チェーザレ/チェザレ/チェザーレ/
cesium /セシウム;[元素]55,Cs/
cesp /CESP/CESP(Common Extended Self-contained Prolog)/
cessna /セスナ/
cestlavie /セラヴィ;C'est la vie./
cetane /セタン/
ceylon /セイロン/錫蘭/
cezanne /セザンヌ/
cf /カリホルニウム/Californium/
cg /コンピュータ・グラフィックス/
ch /チャンネル/チャネル/ч;cha (cyrillic)/χ;chi/
cha /ч;cyrillic/
chablis /シャブリ/
chacha /チャチャ/
chachacha /チャチャチャ/
chaco /チャコ/
chaconne /シャコンヌ/
chad /チャド;.td/
chador /チャドル/
chadwick /チャドウィック/
chaff /チャフ/
chagall /シャガール/
chaikovski /チャイコフスキー/
chaikovskii /チャイコフスキー;Чайковский/
chailly /シャイー/
chain /チェーン/チェイン/
chainletter /チェーンレター/
chainlock /チェーンロック/
chainmail /チェーンメール/
chainsaw /チェーンソー/
chainsmoker /チェーンスモーカー/
chair /チェア/チェアー/
chairman /チェアマン/
chakra /チャクラ/
chalaza /カラザ;卵の中にある紐状のもの/
chalcedony /カルセドニー/
chalk /チョーク/
chalking /チョーキング;白亜化/
challenge /チャレンジ/
challengeable /チャレンジャブル/チャレンジブル/
challenger /チャレンジャー/
challenging /チャレンジング/
chalmers /チャルマース/
chalone /ケイロン/
chamber /チャンバー/チェンバー/
chamberlain /チェンバレン/
chambers /チェンバース/
chambre /シャンブル;(Fr)部屋/
chameleon /カメレオン/
chamomile /カモミール/
chamonix /シャモニ/
chamorro /チャモロ/
champ /チャンプ/
champagne /シャンパン/シャンパーニュ/シャンペン/
champagneglass /シャンパングラス/
champignon /シャンピニオン;(Fr) きのこ/
champion /チャンピオン/チャンピォン/
champions /チャンピオンズ/
championship /チャンピオンシップ/
champselysees /シャンゼリゼ;Champs-Elysees/
chan /チャン/チェン;Jackie Chan/
chance /チャンス/
chandelier /シャンデリア/
chandler /チャンドラー/
chandra /チャンドラ/
chanel /シャネル;www.chanel.com/
chang /チャン/チャング/
change /チェンジ/
changer /チェンジャー/
changeup /チェンジアップ/
channel /チャンネル/チャネル/
channeler /チャネラー/
channeling /チャネリング/
chanson /シャンソン/
chansonnier /シャンソニエ/
chant /チャント/
chantal /シャンタル/
chanter /シャンテ;(Fr)歌う/
chantilly /シャンティイ/
chaos /カオス/ケイオス/
chaotic /カオティック/ケイオティック/カオス的/
chapati /チャパティ/
chapeau /シャポー;(Fr)帽子/シャッポ/
chapel /チャペル/
chapelle /シャペル;仏語/
chaplin /チャップリン/
chapman /チャップマン/
chappy /チャッピー/
chapter /チャプター/
char /キャラ;character/キャラクタ/シャール/
chara /キャラ;character/
character /キャラクター/キャラクタ/
characterdesign /キャラクターデザイン/
characterdevice /キャラクタデバイス/
charactergoods /キャラクターグッズ/
characterset /キャラクタセット/キャラクターセット/
charade /シャレード/
charango /チャランゴ/
charcoal /チャコール/
charcoalgray /チャコールグレー/
charcoalgrey /チャコールグレー/
chardin /シャルダン/
chardonnay /シャルドネ/
chardonnet /シャルドネ/
charge /チャージ/
chargeback /チャージバック/
charger /チャージャー/
charging /チャージング/
chari /チャリ/
chariot /チャリオット/
charisma /カリスマ/
charity /チャリティー/チャリティ/
charityconcert /チャリティーコンサート/チャリティコンサート/
charlemagne /シャルルマーニュ/
charlene /シャリーン/シャーリーン/シャーリン/
charles /チャールズ/シャルル/チャールス/
charleston /チャールストン/
charley /チャーリー/
charlie /チャーリー/
charlotte /シャーロット/シャルロット/シャルロッテ/
charlton /チャールトン/
charly /チャーリー/
charm /チャーム/
charmin /シャーミン/
charming /チャーミング/
charmpoint /チャームポイント/
charmy /チャーミー;和製英語(charming)/
charon /シャロン/カロン/カローン/
charpentier /シャルパンティエ/
charpy /シャルピー/
chart /チャート/
charter /チャーター/チャータ/
chartfile /チャートファイル/
chartres /シャルトル/
chase /チェイス/
chasen /ChaSen/茶筅/
chaser /チェイサー/
chasing /チェイシング/
chasm /キャズム/
chassis /シャーシ/
chat /チャット/シャ;(Fr)ねこ/
chateau /シャトー;(Fr)城/
chateaubriand /シャトーブリアン/
chatelet /シャトレー/シャトレ/
chatnoir /シャノワール;(Fr)chat noir,黒猫/シャノアール/シャ・ノワール/
chatroom /チャットルーム/
chattering /チャタリング/
chatterley /チャタレイ/チャタレー/
chaucer /チョーサー/
chaud /ショー/
chausson /ショーソン/
cheap /チープ/
cheaper /チーパー/
cheat /チート/
chebyshev /チェビチェフ/
checa /チェカ/
chech /チェコ/
chechen /チェチェン/
check /チェック/
checkbox /チェックボックス/
checker /チェッカー/チェッカ/
checkerflag /チェッカーフラッグ;checkered flag/
checkerplayer /チェッカープレイヤー/
checkers /チェッカーズ/
checkin /チェックイン/チェック・イン/
checking /チェッキング/
checklist /チェックリスト/
checkmate /チェックメイト/
checkout /チェックアウト/チェック・アウト/
checkpoint /チェックポイント/
checksheet /チェックシート/
checksum /チェックサム/
cheddar /チェダー/
cheddarcheese /チェダーチーズ/
cheek /チーク/
cheekdance /チークダンス;和製英語(cheek-to-cheek)/
cheer /チア/
cheerful /チアフル/
cheergirl /チアガール;和製英語(cheerleader)/
cheerleader /チアリーダー/
cheerleading /チアリーディング/
cheers /チアーズ/
cheese /チーズ/
cheeseburger /チーズバーガー/
cheesecake /チーズケーキ/
cheesecream /チーズクリーム/
cheesefondue /チーズフォンデュ/
cheesepain /チーズパン/
cheesesouffle /チーズスフレ/
cheetah /チーター/
cheeze /チーズ;※cheese/
chef /シェフ/
cheiron /ケイロン/ケイローン/
chekhov /チェーホフ/
cheko /チェコ/
chelate /キレート/
chelsea /チェルシー/
chemical /ケミカル/
chemise /シュミーズ/シミーズ/
chemist /ケミスト/
chemistry /ケミストリー/
chen /チェン/
cheney /チェイニー/
chenille /シェニール/
chenin /シュナン/
chennai /マドラス;インド(maa)/チェンナイ/
cheque /チェック/
cher /シェール;仏語/
chere /シェール;仏語/シェアー/
cherenkov /チェレンコフ/
cheri /シェリ/
cherie /シェリー/シェリ/
cherimoya /チェリモヤ/
cherish /チェリッシュ/
chernobyl /チェルノブイリ/
cherokee /チェロキー/
cherry /チェリー/
cherryboy /チェリーボーイ/
cherubim /ケルビム;智天使/
cherubini /ケルビーニ/
chervil /チャービル/
cheryl /シェリル/
chess /チェス/
chest /チェスト/
chester /チェスター/
chesterfield /チェスターフィールド/
chestpass /チェストパス/
chet /チェット/
chevre /シェーブル;(Fr) 山羊/シェーヴル/
chevrolet /シボレー/
chewable /チュアブル/
chewinggum /チューインガム/
chi /χ/カイ/
chiangmai /チェンマイ;Chiang Mai/
chianti /キャンティ/キアンティ/
chiara /キアラ/キアーラ/
chiboust /シブースト/
chic /シック/
chicago /シカゴ/
chicane /シケイン/
chicca /キッカ/
chick /チック/
chicken /チキン/
chickencurry /チキンカレー/
chickennugget /チキンナゲット/
chickenrace /チキンレース/
chickenrice /チキンライス;chicken and rice/
chickensoup /チキンスープ/
chicory /チコリ/チコリー/
chief /チーフ/
chien /シャン;(Fr)犬/
chiffon /シフォン/
chiffoncake /シフォンケーキ/
chignon /シニヨン/
chihuahua /チワワ/
child /チャイルド/子/
children /チルドレン/
childseat /チャイルドシート/
chile /チリ;.cl/
chilipepper /チリペッパー;chili pepper/
chilipowder /チリパウダー/
chilisauce /チリソース/
chilled /チルド/
chiller /チラー/
chilly /チリー/
chima /チマ;(朝鮮語)/
chimachogori /チマチョゴリ;(朝鮮語)/
chimaira /キマイラ/
chime /チャイム/
chimera /キメラ/キマイラ/
chimney /チムニー/
chimpanzee /チンパンジー/
chin /チン/
china /チャイナ/
chinadress /チャイナドレス/
chinatown /チャイナタウン/
chinchilla /チンチラ/
chinese /チャイニーズ/
chinois /シノワ;(Fr)中国の/
chinoise /シノワーズ/
chinoiserie /シノワズリ/シノワズリー/
chip /チップ/
chipin /チップイン;chip in/
chips /チップス/
chipset /チップセット/
chiquita /チキータ/
chirac /シラク/
chirico /キリコ/
chiron /ケイロン/ケイローン/
chiropractic /カイロプラクティック/
chita /チタ/
chitin /キチン/
chitosan /キトサン/
chittagong /チッタゴン;バングラデシュ/
chivas /シーバス/
chivasregal /シーバスリーガル/
chive /チャイブ/
chlamydia /クラミジア/
chloe /クロエ/
chloral /クロラール/
chlorella /クロレラ/
chloride /クロライド;塩化/クロリド/
chlorine /クロリン;Cl/
chloris /クロリス/
chloro /クロロ;塩素/
chlorobenzene /クロロベンゼン;C6H5Cl/
chloroethylene /クロロエチレン;C2H3Cl/
chloroform /クロロホルム/クロロフォルム/
chlorophyll /クロロフィル/
chloroplene /クロロプレン/
chloroplenegum /クロロプレンゴム/
chlorpromazine /クロルプロマジン/
choco /チョコ/
chocoball /チョコボール/
chocobar /チョコバー/
chococake /チョコケーキ/
chocochip /チョコチップ;chocolate-chips/
chococream /チョコクリーム/
chocoflake /チョコフレーク/
chocoice /チョコアイス;choc-ice/
chocolat /ショコラ/
chocolate /チョコレート/
chocolatecake /チョコレートケーキ/
chocolateparfait /チョコレートパフェ/
chocoparfait /チョコパフェ/
chogori /チョゴリ;(朝鮮語)/
choice /チョイス/
choke /チョーク/
choker /チョーカー/
choking /チョーキング/
cholera /コレラ/
cholesterol /コレステロール/
choline /コリン;C5H14ON/
cholinesterase /コリンエステラーゼ/
chombo /チョンボ/
chomsky /チョムスキー/
chon /チョン;100chon=1won/
chonbo /チョンボ/
chondroitin /コンドロイチン/
chonggag /チョンガー;(朝鮮語)ch'ong-gak/総角/
chop /チョップ/
chopard /ショパール;www.chopard.com/
chopin /ショパン/
chopper /チョッパー/
choppy /チョッピー/
chopstick /チョップスティック;お箸/
choral /コーラル/コラール/
chorale /コラール/
chord /コード/
chordbook /コードブック/
chordname /コードネーム;[音楽]/
chords /コーズ/
chordwork /コードワーク/
chorizo /チョリソ/
choro /ショーロ/
choros /コロス/
chorus /コーラス/
chorusline /コーラスライン/
choucreme /シュークリーム;chou a la creme/
chow /チャウ/
chowder /チャウダー/
chris /クリス/
chrissie /クリッシー/
christ /キリスト/クリスト/クライスト/
christa /クリスタ/
christamas /クリスマス/
christao /キリシタン/
christchurch /クライストチャーチ;ニュージーランド/
christel /クリステル/
christensen /クリステンセン/
christer /クリステル/
christi /クリスティ/
christian /クリスチャン/クリスティアン/
christiandior /クリスチャンディオール/クリスチャン・ディオール/
christiane /クリスティアーネ/
christie /クリスティ/クリスティー/
christies /クリスティーズ;Christie's. www.christies.com/
christina /クリスティーナ/クリスチーナ/クリスティナ/
christine /クリスティーヌ/クリスティン/クリスティーン/クリスティーネ/クリスティネ/
christmas /クリスマス/
christmascake /クリスマスケーキ/
christmascard /クリスマスカード/
christmascarol /クリスマスキャロル/
christmaseve /クリスマスイブ/クリスマスイヴ/
christmasparty /クリスマスパーティー/クリスマスパーティ/
christmaspresent /クリスマスプレゼント/
christmassale /クリスマスセール/
christmassong /クリスマスソング/
christmastree /クリスマスツリー/
christo /クリスト/
christof /クリストフ/
christoph /クリストフ/
christophe /クリストフ/
christopher /クリストファー/
christy /クリスティーナ/
chro /クロ/
chrom /クロム;Cr/
chromakey /クロマキー;chroma-key/
chromatic /クロマチック/クロマティック/
chromatin /クロマチン/
chromato /クロマト/
chromatogram /クロマトグラム/
chromatograph /クロマトグラフ/
chromatography /クロマトグラフィー/クロマトグラフィ/
chrome /クローム/クロム;[元素]24,Cr/
chromium /クロミウム;[元素]24,Cr/
chronicle /クロニクル/
chrono /クロノ/
chronograph /クロノグラフ/
chronology /クロノロジー/
chronometer /クロノメーター/
chrysanthemum /クリサンセマム;菊/
chrysler /クライスラー/
chrysoprase /クリソプレーズ/
chuck /チャック/
chunk /チャンク/
church /チャーチ/
churchill /チャーチル/
chute /シュート/
chutney /チャツネ/
ci /チェックイン/
ciao /チャオ/
ciboulette /シブレット/
cicero /キケロ/
cider /サイダー/
cidre /シードル;仏語/
ciel /シエル/シェル/
cigar /シガー/
cigarette /シガレット/
cigarettecase /シガレットケース/
ciguatera /シガテラ/
cima /シーマ;[商標]日産/
cincinnati /シンシナティ;USA/
cinco /シンコ/チンコ/
cinderella /シンデレラ/
cindy /シンディ/シンディー/
cine /シネ;(Fr) cinema/
cineclub /シネクラブ/
cinema /シネマ/
cinemascope /シネマスコープ/
cinematheque /シネマテーク/
cineraria /シネラリア/サイネリア/
cinesco /シネスコ;cinemascope/
cinnamon /シナモン/
cinnamonstick /シナモンスティック/
cinnamonsugar /シナモンシュガー/
cinnamontea /シナモンティー/
cinzano /チンザノ/
cipher /サイファー;0/
circle /サークル/○/◎/●/
circlek /サークルK;www.circlek.co.jp/サークルＫ/
circuit /サーキット/
circuittraining /サーキットトレーニング/
circular /サーキュラー/
circulation /サーキュレーション/
circulator /サーキュレーター/
circumscribe /サーカムスクライブ/
circumscription /サーカムスクリプション/
circus /サーカス/
cisc /CISC/
cisco /シスコ;www.cisco.com/
cisse /シセ/
cite /シテ/
citeaux /シトー/
citi /シティ/
citibank /シティバンク;www.citibank.com/
citicorp /シティコープ;www.citicorp.com/
citigroup /シティグループ;www.citigroup.com/
citizen /シチズン/
citroen /シトロエン;www.citroen.fr/
citron /シトロン/
citrus /シトラス/
citterio /チッテリオ/
city /シティ/シティー/
citycenter /シティセンター/
citycycle /シティサイクル/
cityhall /シティホール/シティーホール/
cityhotel /シティホテル/シティーホテル/
citylife /シティライフ/
civic /シビック/
civil /シビル/
civilian /シビリアン/
civiliancontrol /シビリアンコントロール/
civilization /シヴィライゼーション/
cl /塩素/Chlorine/
clafouti /クラフティ/クラフティー/
clafoutis /クラフティ/クラフティー/
claidha /クレイダ;Compensate for Loudness by Analyzing Input-signal Digital Hearing Aid/
claim /クレーム/
claimer /クレーマー;和製英語/クレイマー/
clair /クレア/クレール/
claire /クレア/クレール/
clam /クラム/
clamchouder /クラムチャウダー/
clamp /クランプ/
clampmeter /クランプメーター/
clan /クラン/
clancy /クランシー/
clap /クラップ/
clapton /クラプトン/
clara /クララ/
clare /クレア/
clarence /クラレンス/
claret /クラレット/
clarice /クラリス/
clarinet /クラリネット/
clarino /クラリーノ/
clarion /クラリオン/
claris /クラリス/
clarissa /クラリッサ/
clarisse /クラリス/
claritin /クラリチン/
clark /クラーク/
clarke /クラーク/
clarte /クラルテ;(Fr) 明かり/
clash /クラッシュ/クラシュ;<rare>/
clasp /クラスプ/
class /クラス/
classic /クラシック/
classical /クラシカル/
classicballet /クラシックバレエ/
classiccar /クラシックカー/
classiclife /クラシックライフ/
classicmusic /クラシックミュージック/
classics /クラシックス/
classification /クラシフィケーション/クラスフィケーション/分類/
classifier /クラシファイア/
classique /クラシック;仏語/
classlibrary /クラスライブラリ/
classmate /クラスメイト/クラスメート/
claude /クロード/
claudel /クローデル/
claudette /クローデット/
claudia /クラウディア/クローディア/
claudio /クラウディオ/
claudius /クラウディウス/クローディアス/
claus /クラウス/
clause /クローズ/
clavecin /クラヴサン/クラブサン/
claves /クラベス/
clavichord /クラヴィコード/クラビコード/
clavinet /クラビネット/クラヴィネット/
clavinova /クラビノーバ;[商標]YAMAHA/
clavis /クラヴィス;ラテン語/
claw /クロー/
clay /クレイ/クレー/
claycourt /クレーコート/クレイコート/
clean /クリーン/
cleanenergy /クリーンエネルギー/
cleaner /クリーナー/
cleanhit /クリーンヒット/
cleaning /クリーニング/
cleaninstall /クリーンインストール/
cleanroom /クリーンルーム/
cleanser /クレンザー/
cleansing /クレンジング/
cleanup /クリーンアップ/クリーンナップ/クリンナップ/
clear /クリア/クリアー/
clearance /クリアランス/
clearcase /クリアケース/
clearcut /クリアカット/
clearfile /クリアファイル/
clearglass /クリアガラス/
clearing /クリアリング/
clearmiss /クリアミス;和製英語/
cleek /クリーク;5-wood/
clef /クレフ/クレ;仏語/
clelia /クレリア/
clem /クレム/
clematis /クレマチス/
clemence /クレメンス/クレマンス/
clemenceau /クレマンソー/
clemens /クレメンス/
clement /クレマン/クレメント/
clemente /クレメンテ/
clementi /クレメンティ/
clementine /クレモンティーヌ/クレメンタイン/
cleo /クレオ/
cleobury /クレバリー/
cleome /クレオメ/
cleopatra /クレオパトラ/
clerc /クレール/
cleric /クレリック/
clerk /クラーク/
cleveland /クリーブランド;USA/クリーヴランド/
clever /クレバー/
cleves /クレーヴ/クレーブ/
cli /クリ/
cliche /クリシェ/
click /クリック/
clickable /クリッカブル/
clicker /クリッカー/
client /クライアント/
clientmachine /クライアントマシン/
cliff /クリフ/
cliffhanger /クリフハンガー/
clifford /クリフォード/
climate /クライメート/クライメイト/
climax /クライマックス/
climb /クライム/
climber /クライマー/
climbing /クライミング/
climbingwall /クライミングウォール/
clime /クライム/
clinch /クリンチ/
clinet /クリネ/
clinic /クリニック/
clinique /クリニーク;仏語/
clinker /クリンカー/
clint /クリント/
clinton /クリントン/
clio /クリオ/
clione /クリオネ/
clip /クリップ/
clipart /クリップアート/
clipboard /クリップボード/
clipper /クリッパー/
clipping /クリッピング/
clique /クリーク/
clisp /CLISP/
clitoris /クリトリス/
clive /クライヴ/クライブ/
cloak /クローク/
clock /クロック/
clockup /クロックアップ/
clone /クローン/
cloning /クローニング/
clooney /クルーニー/
clop /クロップ/
clos /CLOS(Common Lisp Object System)/CLOS/
close /クローズ/クロース;近い/
closed /クローズド/
closeplay /クロスプレー/
closer /クローザー/クローザ/
closet /クローゼット/クロゼット/
closeup /クローズアップ/
closing /クロージング/
closure /クロージャー/クロージャ/閉包/
cloth /クロス/クロース/
clothing /クロージング/
cloud /クラウド/
cloudy /クラウディ/クラウディー/
clove /クローブ;丁子/
clover /クローバー/
cltl# /ＣＬｔＬ#1/CLtL#0/
club /クラブ/倶楽部/
clubber /クラバー/
clubevent /クラブイベント/
clubhouse /クラブハウス/
clubmember /クラブメンバー/
clubmusic /クラブミュージック/
clubscene /クラブシーン/
clubteam /クラブチーム/
clue /クルー/
cluster /クラスター/クラスタ/
clustering /クラスタリング/
clutch /クラッチ/
clx /CLX(Common Lisp X Interface)/CLX/
clyde /クライド/
cm /コマーシャル/センチ/センチメートル/キュリウム/Curium/Ｃｍ/
cmdline /コマンドライン/
cmsong /CMソング/ＣＭソング/
cmu /カーネギーメロン大学;Carnegie Melon University. www.cmu.edu/CMU/
cmucl /CMU-CL/
co /コ/コバルト/Cobalt/株式会社/Colorado/コロラド/
co2 /ＣＯ2/
coach /コーチ/
coaching /コーチング/
coal /コール/
coaltar /コールタール;coal-tar/
coart /コート;※coat? court?/
coast /コースト/
coastal /コースタル/
coaster /コースター/
coat /コート/
coates /コーツ/
coathanger /コートハンガー/
coating /コーティング/
coatingstaff /コーチングスタッフ/
coats /コーツ/
cobalt /コバルト;[元素]27,Co/
cobaltblue /コバルトブルー/
cobb /コブ/コッブ/コップ/カッブ/カブ/
cobe /コービー;Cosmic Background Explorer/
cobol /コボル/COBOL/
cobra /コブラ/
coca /コカ/
cocacola /コカコーラ/
cocaine /コカイン/
cochin /コーチン/
cock /コック/
cockatrice /コカトリス/
cocker /コッカー/
cockerspaniel /コッカースパニエル/
cocking /コッキング/
cockpit /コックピット/コクピット/
cocktail /カクテル/
cocktailbar /カクテルバー/
cocktailglass /カクテルグラス/
cocktailparty /カクテルパーティー/カクテルパーティ/
coco /ココ/ＣｏＣｏ/
cocoa /ココア/
cocoamilk /ココアミルク/
cocoapowder /ココアパウダー/
coconut /ココナッツ/ココナツ/
coconutmilk /ココナッツミルク/ココナツミルク/
coconuts /ココナッツ/ココナツ/
coconutsmilk /ココナッツミルク/ココナツミルク/
cocoon /コクーン;繭/
cocos /ココス;.cc/
cocostore /ＣｏＣＯストア;?/
cocotte /ココット/
cocteau /コクトー/
cocu /コキュ/
cod /コッド/
coda /コーダ/
code /コード/
codebase /コードベース/
codebook /コードブック/
codebooks /コードブックス/
codec /コーデック/
codeine /コデイン/
codeka /コード化/
codeless /コードレス/
codelessmouse /コードレスマウス/
codename /コードネーム/
codepoint /コードポイント/
coder /コーダー/
codeset /コードセット/
codesign /コデザイン/
codex /コーデックス/
coding /コーディング/
codon /コドン/
coelacanth /シーラカンス/
coen /コーエン/クーン/
coentro /コエンドロ/
coenzyme /コエンザイム/
coffee /コーヒー/珈琲/
coffeebreak /コーヒーブレイク/
coffeecup /コーヒーカップ/
coffeehouse /コーヒーハウス/
coffeejelly /コーヒーゼリー/
coffeemaker /コーヒーメーカー/
coffeemill /コーヒーミル/
coffeepot /コーヒーポット/
coffeeshop /コーヒーショップ/
coffeetime /コーヒータイム/
coffin /コフィン/
cogeneration /コジェネレーション/
cogito /コギト/
cognac /コニャック/
cohen /コーヘン/コーエン/
coherence /コヒーレンス/
coherency /コヒーレンシ/コヒレンシ;<rare>/
coherent /コヒーレント/
cohort /コホート/コーホート/
coil /コイル/
coilspring /コイルスプリング/
coimbra /コインブラ/
coin /コイン/
coincase /コインケース/
coincidence /コインシデンス/
coinlaundry /コインランドリー;和製英語(coin-washer)/
coinlocker /コインロッカー/
coinparking /コインパーキング/
cointoss /コイントス/
cointreau /コアントロー/
coke /コーク/コークス;(独語koks)/
col /コル/
cola /コーラ/
colbert /コルベール/コルバート/
colchicine /コルヒチン/
colchicum /コルチカム/
cold /コールド/
coldcream /コールドクリーム/
coldspray /コールドスプレー/
cole /コール/
coleman /コールマン/
coleslaw /コールスロー/
colette /コレット/
coleus /コリウス/
colgate /コルゲート/
colin /コリン/コラン/
coliseum /コロシアム/
collaborate /コラボレート/コラボレイト/
collaboration /コラボレーション/
collage /コラージュ/
collagen /コラーゲン/
collar /カラー/
collard /コラール/
collateral /コラテラル/
collect /コレクト/
collectcall /コレクトコール/
collection /コレクション/
collective /コレクティブ/
collector /コレクター/コレクタ/
collectors /コレクターズ/
collectorsitem /コレクターズアイテム;collector's item/
colleen /コリーン/
college /カレッジ/コレージュ;仏語/
collider /コライダー/
collie /コリー/
collier /コリア/
collina /コリーナ/
collins /コリンズ/
collision /コリジョン/コリージョン;<rare>/
collocation /コロケーション/
colloid /コロイド/
collotype /コロタイプ/
colo /コロ/
colombe /コロンブ/
colombia /コロンビア;.co/コロムビア/
colombo /コロンボ/
colon /コロン/
colonel /カーネル/コロネル/
colonial /コロニアル/
colonna /コロンナ/
colony /コロニー/
color /カラー/色/
colorado /コロラド/
colorbox /カラーボックス/
colorchange /カラーチェンジ/
colorchart /カラーチャート/
colorcontact /カラーコンタクト;color contact (lens)/
colorcontactlens /カラーコンタクトレンズ;color contact lens/
colorcoordinator /カラーコーディネーター/
colorcopy /カラーコピー/
colored /カラード/
colorfilm /カラーフィルム/
colorful /カラフル/
colorillust /カラーイラスト;color illustration/
coloring /カラーリング/
colorio /カラリオ;[商標]epson/
colorist /カラリスト/
colormap /カラーマップ/
colorpage /カラーページ/
colorpalette /カラーパレット/
colorprinter /カラープリンタ/カラープリンター/
colorscanner /カラースキャナ/
colorstone /カラーストーン/
colortv /カラーテレビ/
colorvariation /カラーバリエーション/
colossae /コロサイ/
colosseum /コロシアム/コロセウム/
colossus /コロッサス/
colour /カラー/
colourchange /カラーチェンジ/
colourchart /カラーチャート/
colourcontact /カラーコンタクト;colour contact (lens)/
colourcontactlens /カラーコンタクトレンズ;colour contact lens/
colourcopy /カラーコピー/
coloured /カラード/
colourfilm /カラーフィルム/
colourful /カラフル/
colourillust /カラーイラスト;colour illustration/
colouring /カラーリング/
colourpage /カラーページ/
colourpalette /カラーパレット/
colourprinter /カラープリンタ/カラープリンター/
colourscanner /カラースキャナ/
colourstone /カラーストーン/
colourtv /カラーテレビ/
colourvariation /カラーバリエーション/
colt /コルト/
coltrane /コルトレーン/
columbia /コロンビア/
columbine /コロンバイン;US/
columbium /コロンビウム;[元素]41,Cb(Nb)/
columbus /コロンブス/コロンバス;オハイオ州の州都/
columella /コルメラ/
column /コラム/カラム/
columnist /コラムニスト/
columnshift /コラムシフト/
com /コム/コン/
coma /コマ/コーマ/
comb /コーム/コム/
combat /コンバット/
combi /コンビ/
combinat /コンビナート/
combination /コンビネーション/
combinator /コンビネータ/
combine /コンバイン/
combing /コーミング/
combo /コンボ/
combobox /コンボボックス/
combodrive /コンボドライブ/
come /カム/コメ;イタリア語/
comeback /カムバック/カンバック/
comedian /コメディアン/
comedical /コメディカル;co-medical/
comedie /コメディー;仏語/
comedy /コメディ/コメディー/喜劇/
comely /カムリ/
comeon /カモン/
comeout /カムアウト/
comer /カマー/
comet /コメット/
comfort /コンフォート/
comfrey /コンフリー/
comic /コミック/
comical /コミカル/
comicband /コミックバンド;comic band/
comicmarket /コミックマーケット/コミケ/
comics /コミックス/
comiket /コミケ/コミケット;コミケの運営会社。www.comiket.co.jp/コミ/
coming /カミング/
comingout /カミングアウト/
comingsoon /カミングスーン/
comma /コンマ/カンマ/，/、;読点/
command /コマンド/
commander /コマンダー/
commandline /コマンドライン/
commandlineoption /コマンドラインオプション/
commandmode /コマンドモード/
commando /コマンド/コマンドー/
commandprompt /コマンドプロンプト/
comme /コム/
commeca /コムサ;(Fr) comme ca/
commedia /コメディア;イタリア語/
comment /コメント/
commentary /コメンタリー/
commentator /コメンテーター/コメンテータ/
commenter /コメンター/
commentout /コメントアウト;comment out/
commerce /コマース/
commercial /コマーシャル/
commercialism /コマーシャリズム/
commercialpaper /コマーシャルペーパー/
commission /コミッション/
commissioner /コミッショナー/
commit /コミット/
commitment /コミットメント/
committee /コミッティー/コミッティ/
committer /コミッター/コミッタ/
commodity /コモディティ/コモディティー/
commodore /コモドール/
common /コモン/共通/
commons /コモンズ/
commonsense /コモンセンス/
commonwealth /コモンウェルス/
commu /コミ;communication/コミュ;community/
commune /コミューン/
communicate /コミュニケート/
communication /コミュニケーション/
communications /コミュニケーションズ/
communicative /コミュニカティブ/
communicator /コミュニケーター/
communique /コミュニケ/
communism /コミュニズム/コミュニスム/
communist /コミュニスト/共産主義者/
community /コミュニティ/コミュニティー/
communitybus /コミュニティバス/
communityfm /コミュニティFM/
communitysite /コミュニティサイト/
commuter /コミューター/
como /コモ/
comodo /コモド/
comoros /コモロ;.km/
comp /コンプ/カンプ/
compa /コンパ/
compact /コンパクト/
compactcamera /コンパクトカメラ/
compactdisk /コンパクトディスク/
compaction /コンパクション/
compactsize /コンパクトサイズ/
companion /コンパニオン/
company /カンパニー/
compaq /コンパック/
comparator /コンパレータ/
compare /コンペア/
compartment /コンパートメント/
compass /コンパス/
compati /コンパチ;compatible/
compatibility /コンパチビリティ/コンパチ/
compatible /コンパチブル/コンパチ/互換/
compe /コンペ;competition/
competency /コンピテンシー/
competition /コンペティション/コンペ/
competitive /コンペティティブ/
compi /コンピ;compilation/
compilation /コンピレーション/コンピ/コンピレイション/
compile /コンパイル/
compileoption /コンパイルオプション/
compiler /コンパイラ/コンパイラー/
complete /コンプリート/
completion /コンプリーション/
complex /コンプレックス/
compliance /コンプライアンス/
compo /コンポ/
component /コンポーネント/
compose /コンポーズ/
composer /コンポーザー/コンポーザ/
composite /コンポジット/
composition /コンポジション/
compost /コンポスト/
compote /コンポート/
compound /コンパウンド/
compress /コンプレス/
compression /コンプレッション/
compressor /コンプレッサー/コンプレッサ/
compton /コンプトン/
compulsory /コンパルソリー/
compuserve /コンピュサーブ/コンピューサーブ/
computation /コンピュテーション/
computer /コンピュータ/コンピューター/
computer-science /コンピュータサイエンス/
computer-software /コンピュータソフトウェア/
computergame /コンピュータゲーム/コンピューターゲーム/
computergraphics /コンピュータグラフィックス;CG/
computermusic /コンピュータミュージック/
computerscience /コンピュータサイエンス/
computersoftware /コンピュータソフトウェア/
computersystem /コンピュータシステム/コンピューターシステム/
computervirus /コンピュータウイルス/コンピュータウィルス/コンピューターウイルス/コンピューターウィルス/
computervision /コンピュータビジョン/コンピュータービジョン/
computing /コンピューティング/
comte /コント/
comtec /コムテック/
comtesse /コンテス/
con /コン/
conakry /コナクリ/
conan /コナン/
conbrio /コンブリオ;con brio/コン・ブリオ/
concealer /コンシーラー/
concentrate /コンセントレート/
concentration /コンセントレーション/
concentrator /コンセントレータ/コンセントレーター/
concept /コンセプト/
conception /コンセプション/
conceptual /コンセプチュアル/
concern /コンサーン/
concert /コンサート/コンセール;仏語/
concertgebouw /コンセルトヘボウ/
concerthall /コンサートホール/
concertmaster /コンサートマスター/
concerto /コンチェルト/
concerttour /コンサートツアー/
conchiglie /コンキリエ/
concierge /コンシェルジュ/コンシェルジェ/
concious /コンシャス/
concise /コンサイス/簡明な/
conclave /コンクラーベ/
concord /コンコルド/コンコード/
concordance /コンコーダンス/
concorde /コンコルド/
concours /コンクール;仏語/
concourse /コンコース/
concrete /コンクリート/コンクレート;具象/
concreteblock /コンクリートブロック/
concretejungle /コンクリートジャングル/
concurrency /コンカレンシー/
concurrent /コンカレント/
conde /コンデ/
condense /コンデンス/
condensedmilk /コンデンスミルク/
condensemilk /コンデンスミルク;condensed milk/
condenser /コンデンサ/コンデンサー/
condition /コンディション/
conditioner /コンディショナー/
conditioning /コンディショニング/
condom /コンドーム/
condominium /コンドミニアム/
condor /コンドル/
condorcet /コンドルセ/
conduct /コンダクト/
conductance /コンダクタンス/
conductor /コンダクター/コンダクタ/
conduit /コンジット/
condyloma /コンジローム/
cone /コーン/
cones /コーンズ/
confectionary /コンフェクショナリー;菓子屋/
confede /コンフェデ;confederation/
confederation /コンフェデレーション/
confer /カンファー/
conference /カンファレンス/コンファレンス/
confidential /コンフィデンシャル/
config /コンフィグ/コンフィギュレーション;configuration/
configuration /コンフィギュレーション/コンフィグレーション/
configure /コンフィギュア/
confirm /コンファーム/
confit /コンフィ/
confiture /コンフィチュール/
conflict /コンフリクト/競合/衝突/
confocal /コンフォーカル/
conga /コンガ/
congas /コンガ/
conglomerate /コングロマリット/
congo /コンゴ;(コンゴ民主共和国).cd, (コンゴ共和国).cg/
congratulations /コングラチュレーション/コングラッチュレーション/
congress /コングレス/
congruence /≡/
congruent /≡/
conic /コニック/
conifer /コニファー/
conn /コン/
connect /コネクト/接続/
connecter /コネクタ/
connecticut /コネチカット;CT/
connection /コネクション/
connectionism /コネクショニズム/
connectionist /コネクショニスト/
connectionistmodel /コネクショニストモデル/
connectivity /コネクティビティ/
connector /コネクタ/コネクター/
connelly /コネリー/コナリー/コノリー/
conner /コナー/
connerie /コネリー/
connery /コネリー/
connie /コニー/
connor /コナー/
connotation /コノテーション/
conny /コニー/
conor /コナー/
conquistador /コンキスタドール/
conrad /コンラッド/
conrod /コンロッド;con-rod, connection rod/
cons /コンス/
consadole /コンサドーレ;[Jリーグ]札幌/
conscell /コンスセル/
consensus /コンセンサス/
consent /コンセント/
conserva /コンサバ;conservative/
conservative /コンサバティブ/コンサーバティブ/
conservatoire /コンセルヴァトワール/コンセルバトワール/
conservatory /コンセルヴァトーリ/
consider /コンシダー/
consistency /コンシステンシー/コンシステンシ/
consolation /コンソレーション/
console /コンソール/
consomme /コンソメ/
consommesoup /コンソメスープ;和製語(consomme(Fr) + soup(英))/
consort /コンソート/
consortium /コンソーシアム/
constable /コンスタブル/
constance /コンスタンス/
constant /コンスタント/コンスタン;(1767-1830)Benjamin Constant de Rebecque/
constantin /コンスタンティン/コンスタンチン/コンスタンタン/
constantine /コンスタンティン/
constantinople /コンスタンチノープル/
constantinus /コンスタンティヌス/
construct /コンストラクト/
construction /コンストラクション/
constructor /コンストラクタ/コンストラクター/構築子/
consul /コンサル/
consult /コンサルト/
consultant /コンサルタント/
consultation /コンサルテーション/
consulting /コンサルティング/
consume /コンシューム/
consumer /コンシューマ/コンシューマー/コンシュマー/
conta /コンタ/
contac /コンタック/
contact /コンタクト/
contactlens /コンタクトレンズ/
container /コンテナ/コンテナー/
containergarden /コンテナガーデン/
conte /コント/コンテ/
contemporary /コンテンポラリー/
content /コンテント/
contents /コンテンツ/
contest /コンテスト/
context /コンテキスト/コンテクスト/
contexte /コンテクスト;仏語/
contextmenu /コンテキストメニュー/コンテクストメニュー/
conti /コンティ/
continental /コンチネンタル/
contingency /コンティンジェンシー/
continuation /コンティニュエーション/継続/
continue /コンティニュー/
continuous /コンティニュアス/
contour /コンター/コンタ/
contra /コントラ/
contrabass /コントラバス/
contract /コントラクト/
contractbridge /コントラクトブリッジ/
contraction /コントラクション/
contralto /コントラルト/
contrast /コントラスト/
contredanse /コントルダンス/
contribution /コントリビューション/
control /コントロール/制御/
controlcenter /コントロールセンター/
controlcentre /コントロールセンター/
controler /コントローラ;※controLLer/
controlkey /コントロールキー/CONTROLキー/
controller /コントローラ/コントローラー/
controlpanel /コントロールパネル/
controltower /コントロールタワー/
conveni /コンビニ/
convenience /コンビニエンス/
conveniencestore /コンビニエンスストア/コンビニ/
convention /コンベンション/コンヴェンション/
conventional /コンベンショナル/コンヴェンショナル/
convergence /コンバージェンス/
conversation /カンバセーション/
conversion /コンバージョン/コンヴァージョン/変換/
convert /コンバート/コンヴァート/変換/
converter /コンバータ/コンバーター/
convertible /コンバーチブル/
convertor /コンバータ/
convex /コンベックス/
conveyer /コンベア/コンベアー/コンベヤ/コンベヤー/
conveyor /コンベア/コンベアー/コンベヤ/コンベヤー/
convolution /コンヴォリューション/
convolve /コンヴォルヴ/
convoy /コンボイ/
conway /コンウェイ/
cooder /クーダー/
cook /クック/コック/
cooker /クッカー/
cookie /クッキー/
cookiejar /クッキージャー/
cooking /クッキング/
cookingheater /クッキングヒーター/
cooky /クッキー/
cool /クール/
coolbiz /クールビズ;[新語]和製英語/
coolbox /クールボックス/
cooldown /クールダウン/
cooler /クーラー/
coolerbox /クーラーボックス/
cooley /クーリー/
coolidge /クーリッジ/
coolie /クーリー/
cooling /クーリング/
coolingoff /クーリングオフ/
coop /コープ/
cooper /クーパー/
cooperate /コーポレート/
cooperative /コーポラティブ/
coordinate /コーディネート/座標/コーディネイト/
coordination /コーディネーション/
coordinator /コーディネーター/コーディネータ/
cop /コップ/
copacabana /コパカバーナ/
copenhagen /コペンハーゲン/
copernicus /コペルニクス/
copier /コピア/
copland /コープランド/
copolymer /コポリマー/
coppelia /コッペリア/
copper /カッパー/
coppola /コッポラ/
coprocessor /コプロセッサ/
coprod /Ц;※これはキリル文字のtse/
copter /コプター;helicopter/
copula /コピュラ/
copy /コピー/
copyback /コピーバック/
copyband /コピーバンド;和製英語(cover band)/
copyguard /コピーガード/
copyleft /コピーレフト/
copymap /コピーマップ/
copyonce /コピーワンス/
copyonwrite /コピーオンライト/
copype /コピペ;copy and paste/
copyprotect /コピープロテクト/
copyright /コピーライト;略号は(C)/
copyservice /コピーサービス/
copywriter /コピーライター/
copywriting /コピーライティング/
coquette /コケット/
coquettish /コケティッシュ/
coquille /コキール/コキーユ/
cora /コーラ/コラ/
coral /コーラル/
coralie /コラリー/
corazon /コラソン/
corbusier /コルビュジエ;(1887-1965) Le Corbusier/
cord /コード/
cordelia /コーデリア/
cordial /コーディアル/
cordoba /コルドバ/
cordon /コルドン/
cordreel /コードリール;cord reel/
cords /コーズ/
cordula /コーデュラ/
corduroy /コーデュロイ/
core /コア/
coredump /コアダンプ/
corega /コレガ;www.corega.co.jp/
coreless /コアレス/
corelli /コレッリ/
coretime /コアタイム/
corfu /コルフ/
corgi /コーギー/
coriander /コリアンダー/
corin /コリン/
corinne /コリン/コリーヌ/コリンヌ/
corinth /コリント/
coriolis /コリオリ/
cork /コルク/
corkboard /コルクボード/
corkscrew /コルクスクリュー/
cormac /コーマック/
corn /コーン/
corncream /コーンクリーム/
cornedbeef /コンビーフ/
corneille /コルネイユ/コルネーユ/
cornelia /コーネリア/コルネリア/
cornelius /コーネリアス/コルネリウス/
cornell /コーネル/
corner /コーナー/┘/└/┐/┌/┓/┏/┛/┗/
cornering /コーナリング/コーナーリング/
cornerkick /コーナーキック/
cornet /コルネット/コロネ/コルネ;(Fr) (アイスなどの)コーン/
cornflake /コーンフレーク/
cornflakes /コーンフレーク/
cornflour /コーンフラワー/
cornish /コーニッシュ/
cornmeal /コーンミール/
cornpotage /コーンポタージュ/
corns /コーンズ/
cornsoup /コーンスープ/
cornstarch /コーンスターチ/
coro /コロ/
corolla /カローラ/
coromandel /コロマンデル/
corona /コロナ/
coronabeer /コロナビール/
coronado /コロナド/
corot /コロー/
corp /コープ;corporation/
corpo /コーポ;corporate house/
corporate /コーポレート/
corporategovernance /コーポレートガバナンス/
corporation /コーポレーション/
corporatism /コーポラティズム/
corpse /コープス/
corpus /コーパス/
correct /コレクト/正確な/
correction /コレクション;修正/
correlation /コリレーション/
correspondence /コレスポンデンス/コレスポンダンス/
correspondent /コレスポンデント/コレスポンダント/
corrida /コリーダ/
corrugate /コルゲート/
corsage /コサージュ/コサージ/
corse /コルス/
corset /コルセット/
corsica /コルシカ/
cortes /コルテス/
cortisol /コルチゾール/
cortisone /コルチゾン/コーチゾン/
cortot /コルトー/
corundum /コランダム/
corvette /コルベット/
cos /コサイン/コス/
cosecant /コセカント;余割/
cosine /コサイン/
cosme /コスメ;cosmetics/
cosmetic /コスメティック/コスメチック/
cosmetics /コスメティックス/
cosmic /コズミック/コスミック/
cosmo /コスモ/
cosmology /コスモロジー/
cosmopolitan /コスモポリタン/
cosmos /コスモス/
cosplay /コスプレ;<costume play (NB:英語化している)/
cosplayer /コスプレイヤー/
cossack /コサック;Казак/
cossackdance /コサックダンス/
cost /コスト/
costa /コスタ/
costadelsol /コスタデルソル;Costa del Sol/
costarica /コスタリカ;Costa Rica/
costdown /コストダウン;和製英語(cost-cutting)/
coste /コスト/
costello /コステロ/
costner /コスナー/
costperformance /コストパフォーマンス/
costume /コスチューム/
costumeplay /コスチュームプレイ/コスチュームプレー/コスプレ/
cota /コタ/
cotangent /コタンジェント;余接/
cote /コート/
cotedazur /コートダジュール;Cote d'Azur/
cotedivoire /コートジボワール;Cote d'Ivoire (.ci)/
cotes /コーツ/
cottage /コテージ/カッテージ/
cottagecheese /カッテージチーズ/
cotton /コットン/
coubertin /クーベルタン/
couch /カウチ/
couchpotato /カウチポテト/
coucou /クク/
could /クド/クッド/
couleur /クルール;(Fr)色/
coulis /クーリ/
coulomb /クーロン/
coulthard /クルサード/
coumarin /クマリン;C9H6O2/
counseling /カウンセリング/
counselor /カウンセラー/
count /カウント/
countdown /カウントダウン/
counter /カウンター/カウンタ/
counterattack /カウンターアタック/
counterculture /カウンターカルチャー/
counterkitchen /カウンターキッチン/
counterpart /カウンターパート/
counterpropagation /カウンタープロパゲーション/
counterpunch /カウンターパンチ/
countertable /カウンターテーブル/
countertenor /カウンターテナー/カウンターテノール/
country /カントリー/
countryclub /カントリークラブ/
countrymusic /カントリーミュージック/
countup /カウントアップ/
coupdetat /クーデター;(Fr)coup d'etat/
coupe /クーペ;仏語/クープ/
coupepain /コッペパン;和製仏語(pain coupe?)/
couperin /クープラン/
couple /カップル/
coupler /カプラ/カプラー/
coupling /カップリング/
coupon /クーポン/
courante /クーラント/
courbet /クールベ/
cource /コース;※course/
courier /クーリエ/
courreges /クレージュ/
cours /クール;仏語/
course /コース/
coursemenu /コースメニュー/
courseout /コースアウト;(和製英語)/
court /コート/
courteney /コートニー/
courthouse /コートハウス/
courtyard /コートヤード/
couscous /クスクス;(粉状パスタ)/
cousin /カズン/
couture /クチュール/
couturier /クチュリエ/
couverture /クーベルチュール/
cover /カバー/カヴァー/
coverage /カバレッジ/カバレージ/
coveralbum /カバーアルバム/
coverall /カバーオール/
covergirl /カバーガール/
coverillust /カバーイラスト;cover illustration/
covering /カバーリング/
coverstory /カバーストーリー/
coverup /カバーアップ/
coverversion /カバーバージョン/
cow /カウ/
cowbell /カウベル/
cowboy /カウボーイ/
cowen /コーエン/
cowgirl /カウガール/
cowper /カウパー/
cox /コックス/
coy /コイ/
coyote /コヨーテ/
cozy /コージー/
cps /CPS(Continuation-Passing Style)/
cpu /CPU/中央処理装置/
cr /CR/クロム/Chromium/
crack /クラック/
cracker /クラッカー/
cracking /クラッキング/
cradle /クレードル/クレイドル/
craft /クラフト/
craftman /クラフトマン;craftsman/
craftsman /クラフトマン/
craftwork /クラフトワーク/
craig /クレイグ/クレーグ/
cram /クラム/
cramer /クレーマー/クレイマー/
cranberry /クランベリー/
crane /クレーン/
crank /クランク/Cランク/Ｃランク/
crankin /クランクイン;和製英語/
crankup /クランクアップ;和製英語/
crap /クラップ/
crash /クラッシュ/
crashcymbal /クラッシュシンバル/
crate /クレート/
crater /クレーター/
crawford /クロフォード/
crawl /クロール/
crawler /クローラー/クローラ/
crawling /クローリング/
cray /クレイ/
crayon /クレヨン/
crazy /クレイジー/クレージー/
crea /クレア/
cream /クリーム/
creamcheese /クリームチーズ/
creamer /クリーマー/
creampain /クリームパン/
creamsoda /クリームソーダ/
creamsoup /クリームスープ/
creamstew /クリームシチュー/
creamy /クリーミー/
create /クリエイト/クリエート/
creatine /クレアチン/
creatinine /クレアチニン/
creation /クリエーション/クリエイション/
creative /クリエイティブ/クリエーティブ/クリエイティヴ/
creativity /クリエイティビティ/
creator /クリエイター/クリエーター/クリエータ/クリエイタ/
creature /クリーチャー/
credit /クレジット/
creditcard /クレジットカード/
credittitle /クレジットタイトル/
credo /クレド/
creek /クリーク/
creep /クリープ/
creepers /クリーパーズ/
creme /クレーム;仏語/
cremebrulee /クレームブリュレ;(Fr) creme brulee/
cremona /クレモナ/
creole /クレオール/
creosote /クレオソート/
crepe /クレープ/
cresc /クレッシェンド;次第に強く/crescendo/
crescendo /クレッシェンド/
crescent /クレセント/
cresol /クレゾール;C7H8O/
cresson /クレソン/
crest /クレスト/
cresta /クレスタ;[商標]トヨタ/
crested /クレステッド/
crete /クリート/
creutz /クロイツ/
crevasse /クレバス/クレヴァス/
crew /クルー/
crewneck /クルーネック/
crick /クリック/
cricket /クリケット/
crime /クライム/
crimea /クリミア/
criminal /クリミナル/
crimson /クリムゾン/
cripper /クリッパー/
crisis /クライシス/
crisp /クリスプ/
crispin /クリスピン/
crispy /クリスピー/
cristian /クリスティアン/
cristiano /クリスティアーノ/クリスチアーノ/
cristina /クリスティーナ/クリスチーナ/クリスチナ/
cristo /クリスト/
cristobal /クリストバル/
criterion /クライテリオン/
critic /クリティック/
critical /クリティカル/
criticalhit /クリティカルヒット/
criticalpath /クリティカルパス/
critique /クリティーク/クリティック/
croatia /クロアチア;.hr/
croche /クロッシュ/クローシュ/クロシュ/♪/
crocodile /クロコダイル/
crocop /クロコップ/
crocus /クロッカス/
croesus /クロイソス/
croissant /クロワッサン/
cromagnon /クロマニヨン/クロマニョン/
cromatie /クロマティ/
cromwell /クロムウェル/
cron /クーロン/
cronus /クロノス/
crop /クロップ/
cropped /クロップド/
croquembouche /クロカンブッシュ/
croquet /クロッケー/
croquette /コロッケ/クロケット/
croquis /クロッキー/
crosby /クロスビー/
cross /クロス/×/┼/╋/┿/╂/
crossball /クロスボール/
crossbar /クロスバー/
crossbow /クロスボウ/
crossbreed /クロスブリード/
crosscable /クロスケーブル;crossing cable/
crosscheck /クロスチェック/
crosscompile /クロスコンパイル/
crosscompiler /クロスコンパイラ/
crosscounter /クロスカウンター/
crosscountry /クロスカントリー;cross country/
crossfade /クロスフェード/
crossfire /クロスファイア/
crossing /クロッシング/
crosslicence /クロスライセンス/
crosslicense /クロスライセンス/
crossover /クロスオーバー/クロスオーヴァー/
crosspoint /クロスポイント;cross-point/
crosspost /クロスポスト/
crossroad /クロスロード/
crossstitch /クロスステッチ/
crosstalk /クロストーク/
crossword /クロスワード/
crosswordpuzzle /クロスワードパズル/
crostini /クロスティーニ/
croton /クロトン/
croute /クルート/
crouton /クルトン/
crow /クロー/
crowley /クロウリー/クローリー/
crown /クラウン/
crtdisplay /CRTディスプレイ/
crtmonitor /CRTモニタ/CRTモニター/
cru /クリュ/
cruise /クルーズ/
cruiser /クルーザー/
cruising /クルージング/
crunch /クランチ/
crusader /クルセイダー/
crusaders /クルセイダーズ/
crush /クラッシュ/
crusher /クラッシャー/
crusoe /クルーソー/
crust /クラスト/
crutch /クラッチ/
cruz /クルーズ/クルス/
cruzeiro /クルゼイロ/
cry /クライ/
crying /クライング/
cryo /クリオ;(接頭辞:低温)/クライオ/
cryostat /クライオスタット/
crypt /クリプト/
crypto /クリプト/
cryptococcus /クリプトコッカス/
cryptoxanthin /クリプトキサンチン/
crysknife /クリスナイフ/
crystal /クリスタル/水晶/
crystalglass /クリスタルガラス/クリスタルグラス/
cs /セシウム/Cesium/
csantenna /CSアンテナ/
csh /Cシェル/
cstuner /CSチューナー/CSチューナ/
csvfile /CSVファイル/
ct /Connecticut/コネチカット/コネティカット/
ctesiphon /クテシフォン/
cthulhu /クトゥルフ/
ctrlkey /CTRLキー/コントロールキー/
ctscan /CTスキャン/
ctype /Cタイプ/Ｃタイプ/
cu /銅/Copper/
cuba /キューバ;.cu/
cuban /キューバン/
cube /キューブ/
cubic /キュービック/
cubism /キュビズム/キュービズム/
cubisme /キュビスム/
cubs /カブス;[MLB]/
cuckoo /カッコウ/カッコー/
cue /キュー/
cuff /カフ/
cuffs /カフス/
cuffsbutton /カフスボタン/
cuica /クイーカ/
cuisine /キュイジーヌ/
cuit /キュイ;(Fr) 焼いた/
culotte /キュロット/
culotteskirt /キュロットスカート;culottes/
cult /カルト/
cultmovie /カルトムービー/
cultural /カルチュラル/
culture /カルチャー/カルチュア/
cultureschool /カルチャースクール/
cultureshock /カルチャーショック/
cum /カム/
cumene /クメン/
cumin /クミン/
cuminseed /クミンシード/
cummin /クミン/
cunni /クンニ;cunnilingus/
cunnilingus /クンニリングス/
cunning /カンニング/
cunt /カント/
cuomo /クオモ/
cuore /クオレ/
cup /カップ/コップ/∪/
cupboard /カップボード/
cupcake /カップケーキ/
cupid /キューピッド/
cupin /カップイン;cup in/
cupnoodle /カップヌードル/
cupola /キューポラ/
cupple /カップル;※couple?/
curacao /キュラソー/
curare /クラーレ/
curator /キュレーター/
curd /カード/
cure /キュア/
curie /キュリー/
curiosity /キュリオシティ/
curious /キュリアス/
curium /キュリウム;[元素]96,Cm/
curl /カール/
curler /カーラー/
curling /カーリング/
curly /カーリー/
curot /キュロット/
curran /カラン/
currant /カラント;すぐり/
currect /カレント/
currency /カレンシー/カレンシ/
current /カレント/
currentdirectory /カレントディレクトリ;pwd/
curriculum /カリキュラム/
curry /カレー/カリー/
currying /カリー化/
currypain /カレーパン/
currypowder /カレーパウダー/
curryrice /カレーライス/
curryroux /カレールー;NB:英語curry + 仏語roux/
currysauce /カレーソース/
currysoup /カレースープ/
curse /カース/
curses /カーセス/
cursor /カーソル/カーサ/
cursorkey /カーソルキー/
curt /クルト/
curtain /カーテン/
curtaincall /カーテンコール/
curtainrail /カーテンレール/
curtainwall /カーテンウォール/
curtis /カーティス/カーチス/
curve /カーブ/カーヴ/
curving /カービング/
cusco /クスコ/
cuscus /クスクス;有袋類/
cushion /クッション/
cusp /カスプ/
custard /カスタード/
custardcream /カスタードクリーム/
custer /カスター/
custom /カスタム/
customcar /カスタムカー/
customchip /カスタムチップ/
customer /カスタマー/カスタマ/
customercenter /カスタマーセンター/
customercentre /カスタマーセンター/
customerservice /カスタマーサービス/
customersupport /カスタマーサポート/
customisable /カスタマイザブル/
customisation /カスタマイゼーション/
customise /カスタマイズ/
customised /カスタマイズド/
customiser /カスタマイザ/
customizable /カスタマイザブル/
customization /カスタマイゼーション/
customize /カスタマイズ/カスタム化/
customized /カスタマイズド/
customizer /カスタマイザ/
custommade /カスタムメイド/カスタムメード/
cut /カット/
cutback /カットバック/
cutball /カットボール/
cute /キュート/
cutglass /カットガラス/カットグラス/
cuthbert /カスバート/
cuticle /キューティクル/クチクラ/
cutie /キューティー/キューティ/
cutin /カットイン;cut-in/クチン;[植物]/
cutlery /カトラリー/
cutlet /カツレツ/
cutoff /カットオフ/
cutout /カットアウト/
cutover /カットオーバー/
cutpants /カットパンツ/
cutsew /カットソー;cut and sewn/
cutter /カッター/
cutterknife /カッターナイフ;和製英語(utility knife)/
cutting /カッティング/
cuttingsheet /カッティングシート;[商標]/
cutup /カットアップ/
cuty /キューティー;※cutie?/
cuvee /キュヴェ;仏語/
cuzco /クスコ/
cyalume /サイリューム;[商標]OmniGlow社/
cyan /シアン/
cyanine /シアニン/
cyano /シアノ/
cyanocobalamin /シアノコバラミン/
cyanocobalamine /シアノコバラミン/
cyanosis /チアノーゼ/
cyber /サイバー/
cybernetic /サイバネティック/
cybernetics /サイバネティックス/サイバネティクス/
cyberpunk /サイバーパンク/
cyberspace /サイバースペース/
cyborg /サイボーグ/
cybozu /サイボウズ;cybozu.co.jp/
cyclamen /シクラメン/
cycle /サイクル/
cyclehit /サイクルヒット/
cyclic /サイクリック/
cyclin /サイクリン/
cycling /サイクリング/
cyclingroad /サイクリングロード/
cyclo /シクロ/サイクロ/
cycloid /サイクロイド/
cyclon /サイクロン/
cyclops /サイクロプス/
cyclotron /サイクロトロン/
cygne /シーニュ;(Fr) 白鳥/
cylindar /シリンダー;※cylinder/
cylinder /シリンダー/シリンダ/
cylinderhead /シリンダーヘッド/シリンダヘッド/
cyma /シーマ/
cymbal /シンバル/
cymbals /シンバル/
cymbidium /シンビジウム/
cyndy /シンディ/シンディー/
cynical /シニカル/
cynicism /シニシズム/
cynnamon /シナモン;※cinnamon/
cynthia /シンシア/
cyprus /キプロス;.cy/
cyrano /シラノ/
cyric /サイクロトロンＲＩ/
cyril /シリル/ツィリル/
cyrille /シリル/
cyrillic /а;a/б;be/в;ve/г;ge/д;de/е;je/ё;jo/ж;zhe/з;ze/и;i/й;i-kratkoje (j)/к;ka/л;el/м;em/н;en/о;o/п;pe/р;er/с;es/т;te/у;u/ф;ef/х;xa/ц;tse/ч;cha/ш;sha/щ;scha/ъ;znak (tvjordyj znak)/ы;y/ь;znak (xjaxkij znak)/э;e/ю;ju/я;ja/
cyrus /サイラス/キュロス/
cystein /システイン;Cys/
cystine /シスチン/
cytokine /サイトカイン/
cytosine /シトシン;C/
czar /ツァー/ツァーリ/
czech /チェコ;.cz/
czechslovakia /チェコスロバキア/チェコスロヴァキア/
czerny /ツェルニー/チェルニー/
d /δ;delta/∂;differential/ディー/デー/д;de (cyrillic)/
d# /Ｄ#1/
dB /デシベル/
da /↓/
dabadie /ダバディ/
dacapo /ダカーポ;da capo/ダ・カーポ/
dacca /ダッカ/
dachshund /ダックスフンド/ダックスフント/
dacquoise /ダックワーズ/ダコワーズ/
dad /ダッド/ダド/
dada /ダダ/
dadaisme /ダダイスム/
daddy /ダディ/ダディー/
daemon /デーモン/
daff /ダフ/
daffy /ダフィ/ダッフィ/ダフィー/
dag /ダグ/
dagger /ダガー/†/‡;ddagger/
dagmar /ダグマー/
dahl /ダール/
dahlia /ダリア/
daidalos /ダイダロス/
daiei /ダイエー;www.daiei.co.jp/
daily /デイリー/デーリー/
dailysports /デイリースポーツ;www.daily.co.jp/
daimler /ダイムラー/
daiquiri /ダイキリ/
daisy /デイジー/デージー/ディジー/Ｄａｉｓｙ/
daisychain /デイジーチェーン/
dakar /ダカール/
dal /ダール/
dalaiblama /ダライラマ/達頼喇嘛/
dalailama /ダライラマ/達頼喇嘛/
dale /デール/ディル/デイル/
dalembert /ダランベール;Jean Le Rond d'Alembert (1717-1783)/
dali /ダリ/
dallara /ダラーラ/
dallas /ダラス/
dalmatian /ダルメシアン/
dam /ダム/
damage /ダメージ/
damascus /ダマスカス/
dame /ダム;仏語/
damia /ダミア/
damian /ダミアン/
damiani /ダミアーニ/
damiano /ダミアーノ/
damien /ダミアン/
damon /デーモン/デイモン/ダモン/
damore /ダモーレ;(It.) d'amore/
damour /ダムール;(Fr) d'amour. 愛の/
damp /ダンプ/
damper /ダンパー/
dan /ダン/
dana /ダーナ/デーナ/ダナ/デナ/
danae /ダナエ/
danang /ダナン;Da-Nang,ベトナム/
dance /ダンス/
danceable /ダンサブル/
dancefloor /ダンスフロア/
dancegroup /ダンスグループ/
dancehall /ダンスホール/
dancemusic /ダンスミュージック/
danceparty /ダンスパーティー/ダンスパーティ/
dancer /ダンサー/
danceschool /ダンススクール/
danceteam /ダンスチーム/
dancing /ダンシング/
dandelion /ダンデライオン;たんぽぽ/
dandy /ダンディ/ダンディー/
dandyism /ダンディズム/
dane /デン/デーン/
danese /ダネーゼ/
dangaree /ダンガリー/
dangdut /ダンドゥット/
danger /デンジャー/
dangerous /デンジャラス/
dani /ダニ/
daniel /ダニエル/
daniela /ダニエラ/
daniele /ダニエル/ダニエーレ/
daniella /ダニエラ/
danielle /ダニエル/
danilo /ダニーロ/
danish /デニッシュ/ダニッシュ/
dank /ダンク/
danke /ダンケ/
dankshoot /ダンクシュート/
danner /ダナー/
danny /ダニー/
dans /ダン;仏語/
dante /ダンテ/
danube /ダニューブ/
dany /ダニー/
danzig /ダンチヒ/ダンツィヒ/
daphne /ダフネ/
daphnis /ダフニス/
darbukka /ダルブッカ/ダラブッカ/
darc /ダルク/
darcy /ダーシー/
daressalam /ダルエスサラーム;Dar es Salam/
dari /ダリ/
daria /ダリア/ダリヤ/
dario /ダリオ/
darius /ダリウス/ダライアス/
darjeeling /ダージリン/
dark /ダーク/
darkblue /ダークブルー/
darkbrown /ダークブラウン/
darkcolor /ダークカラー/
darkcolour /ダークカラー/
darkelf /ダークエルフ/
darkgray /ダークグレー/
darkgreen /ダークグリーン/
darkgrey /ダークグレー/
darkhorse /ダークホース/
darkmatter /ダークマター/
darkness /ダークネス/
darkred /ダークレッド/
darkside /ダークサイド/
darksuit /ダークスーツ/
darla /ダーラ/
darling /ダーリン/ダーリング/
darrel /ダレル/
darrell /ダレル/
darren /ダレン/
dart /ダート/
dartagnan /ダルタニャン/ダルタニアン/
darth /ダース/
darthvader /ダースベイダー/ダースベーダー/
darts /ダーツ/
darussalam /ダルエスサラーム/
darwin /ダーウィン/
darwinism /ダーウィニズム/
daryl /ダリル/
das /ダス/
dasa /ダサ/
dasein /ダーザイン/
dash /ダッシュ/―/
dashboard /ダッシュボード/
dashv /┤/
dassault /ダッソー/
data /データ/データー/
databank /データバンク/
database /データベース/
databasesoft /データベースソフト/
databasesystem /データベースシステム/データベース・システム/
databook /データブック/
datacenter /データセンター/データセンタ/
datacentre /データセンター/データセンタ/
datadisk /データディスク/
datafile /データファイル/
dataflow /データフロー/
dataglove /データグローブ/
datagram /データグラム/
datalink /データリンク/
datamining /データマイニング/
dataobject /データオブジェクト/
datapack /データパック/
dataserver /データサーバ/データサーバー/
dataset /データセット/
datasheet /データシート/
datashow /データショウ/
datasize /データサイズ/
datastore /データストア/
datatype /データタイプ/
date /デート/デイト/
datebase /データベース/
datecourse /デートコース/
dates /デーツ/
datespot /デートスポット/
datsun /ダットサン;[商標]日産/
datura /ダチュラ;朝鮮朝顔/
daudet /ドーデ/
daughter /ドーター/
daumier /ドーミエ/
daun /ダウン/
davao /ダバオ;フィリピン/
dave /デイブ/デイヴ/デーブ/デーヴ/ディヴ/
david /デビッド/デヴィッド/デイビッド/ダビデ/デービッド/デーヴィッド/ダヴィド/ダヴィッド/ダビド/デーヴィド/ダーフィット/ダビッド/
davide /ダビデ/ダヴィデ/
davidoff /ダビドフ;www.davidoff.com/
davidson /ダビッドソン/デビッドソン/
davinch /ダ・ビンチ;(1452-1519)Leonardo da Vinci/
davinci /ダヴィンチ/ダ・ヴィンチ/
davis /デイビス/デイヴィス/デービス/デビス/
daviscup /デビスカップ/
dawkins /ドーキンス/
dawn /ドーン/
dawson /ドーソン/
day /ディ/デイ/デー/
daycare /デイケア/
daycream /デイクリーム/
daydream /デイドリーム/
daygame /デーゲーム/デイゲーム/
dayhome /デイホーム/
daylight /デイライト/ディライト/
daypack /デイパック/
days /デイズ/
dayservice /デイサービス/
dayservicecenter /デイサービスセンター/
dayservicecentre /デイサービスセンター/
daytime /デイタイム/
daytona /デイトナ;米国・フロリダ/
daytrade /デイトレード/デイトレ/
daytrader /デイトレーダー/
db /データベース/デシベル;decibel/ドブニウム/Dubnium/
dbms /データベース管理システム;database management system/DBMS/
dbserver /データベースサーバ/DBサーバ/
dbsoft /データベースソフト/
dbsystem /データベースシステム/
dc /直流/District of Columbia/コロンビア/
dcbrand /ＤＣブランド/DCブランド/
dccard /DCカード;www.dccard.co.jp/
dcircle /◎/
dcup /Dカップ;17.5cm/Ｄカップ/
ddagger /‡/
ddb /演繹データベース;deductive database/文書データベース;document database/
ddrive /Dドライブ;D:/Ｄドライブ/
de /デ/ド/ドゥ/д;cyrillic/Delaware/デラウェア/
dead /デッド/
deadball /デッドボール;和製英語(hit by pitch)/
deadcopy /デッドコピー/
deadend /デッドエンド/
deadheat /デッドヒート/
deadlift /デッドリフト/
deadline /デッドライン/
deadlink /デッドリンク;404/
deadlock /デッドロック/
deadspace /デッドスペース/
deadstock /デッドストック/
deaf /デフ/
deal /ディール/
dealer /ディーラー/ディーラ/
dealing /ディーリング/
deallocate /デアロケイト/
deamon /デーモン/
dean /ディーン/
deanna /ディアナ/
dear /ディア/ディアー/
death /デス/
deathmarch /デスマーチ/
deathmask /デスマスク/
deathmatch /デスマッチ/
deathmetal /デスメタル/
deb /デブ/
debate /ディベート/
debbie /デビー/
debby /デビー/
debeers /デビアス;De Beers. www.debeers.com/
debian /デビアン/
debit /デビット/
debitcard /デビットカード/
debora /デボラ/
deborah /デボラ/
debra /デブラ/
debris /デブリ/
debroglie /ド・ブロイ;de Broglie/ドブロイ/
debt /デット/
debug /デバッグ/ディバッグ/
debugger /デバッガ/デバッガー/ディバッガ/
debugging /デバッギング/
debussy /ドビュッシー/
debut /デビュー/
debutalbum /デビューアルバム/
debutsingle /デビューシングル/
dec /DEC/
deca /デカ;[SI接頭語]da,10^1/
decade /ディケード/ディケイド/
decadence /デカダンス/
decadent /デカダン/
decal /デカール;decalcomania/
decalcomanie /デカルコマニー/
decalog /デカローグ;十戒/
decalogue /デカローグ;十戒/
decameron /デカメロン/
decane /デカン;C10H22/
decanter /デキャンタ/デカンタ/デキャンター/デカンター/
decare /デカール;1000m^2/
decay /ディケイ/
decca /デッカ/
deccan /デカン/
december /ディセンバー/
deci /デシ;[SI接頭語]d,10^-1/
decibel /デシベル;db/
decimal /デシマル/十進数/
decision /デシジョン/
deck /デッキ/デック/
deckbrush /デッキブラシ/
deckchair /デッキチェア/
decken /ゼッケン;(独語)/
decker /デッカ/デッカー/
deckshoes /デッキシューズ/
decode /デコード/復号化/
decoder /デコーダ/デコーダー/
decoding /デコーディング/
decollete /デコルテ/
deconvolution /デコンボリューション/
decor /デコール;(Fr)装飾/
decorate /デコレート/
decoration /デコレーション/
decorationcake /デコレーションケーキ;和製英語/
decorative /デコラティブ/デコレイティブ/
decoy /デコイ/
decrement /デクリメント/
decres /デクレッシェンド;次第に弱く/decrescendo/
decrescendo /デクレッシェンド/
dederot /ディドロ/
dee /ディー/
deep /ディープ/
deepblue /ディープブルー/
deepkiss /ディープキス/
deeplink /ディープリンク/
deeppurple /ディープパープル/
deepthroat /ディープスロート/
deet /ディート/
defacto /デファクト;de facto/
defactostandard /デファクトスタンダード;de facto standard/
defau /デフォ;default/
default /デフォルト/ディフォルト/省略/ディフォールト;<rare>/デファルト;<rare>/
defaultresourcefile /デフォルトリソースファイル/
defect /ディフェクト/
defence /ディフェンス/
defend /ディフェンド/
defender /ディフェンダー/
defending /ディフェンディング/
defendingchampion /ディフェンディングチャンピオン/
defense /ディフェンス/
deffenbacchia /ディフェンバキア/
define /デファイン/
definition /デフィニション/ディフィニション/
defla /デフレ;deflation/
deflation /デフレーション/デフレ/
deflator /デフレーター/デフレータ/
defoe /デフォー/
deformer /デフォルメ/
defrag /デフラグ;defragmentation/
degas /ドガ/
degaulle /ドゴール/ド・ゴール/
degrade /デグレード/
degree /ディグリー/°/℃;celsius/
deimos /ダイモス/デイモス/
deirdre /ディアドラ/
deja /デジャ/
dejavu /デジャヴ;(Fr) deja vu/デジャブ/デジャヴュ/デジャビュ/
dejeuner /デジュネ;(Fr)昼食/
dejohnette /ディジョネット/デジョネット/
del /デル/
delacroix /ドラクロワ/ドラクロア/
delaware /デラウェア;DE/
delay /ディレイ/ディレー/
delayed /ディレイド/
delayline /ディレイライン/
delegate /デリゲート/
delerue /ドルリュー/
delete /デリート/
deleuze /ドゥルーズ/
delft /デルフト/
delgado /デルガド/
delhi /デリー/
delia /デリア/
delibes /ドリーブ/
delica /デリカ/
delicacy /デリカシー/
delicate /デリケート/
delicatessen /デリカテッセン/
delicious /デリシャス/
delight /ディライト/
delikatessen /デリカテッセン;(独)/
delilah /デリラ/
delimiter /デリミタ/
delivery /デリバリー/
deliveryhealth /デリバリーヘルス/デリヘル/
delkey /DELキー/デリートキー/
dell /デル/
della /デラ/デッラ/
dellinger /デリンジャー/
delon /ドロン/
delos /デロス/
delphi /デルフィ/デルファイ/
delphine /デルフィーヌ/
delphinium /デルフィニウム/
delphoi /デルフォイ/
delpy /デルピー/
delta /δ/デルタ/
deltarule /δルール/
deluxe /デラックス/
dem /デム/
dema /デマ/
demacs /Ｄｅｍａｃｓ/
demagog /デマゴーグ/
demand /デマンド/
demel /デメル/
demerit /デメリット/
demeter /デメテル/
demi /デミ/ドゥミ;仏語/
demian /デミアン/
demiglace /デミグラス/ドミグラス/
demiglacesauce /デミグラスソース/ドミグラスソース/
demitasse /デミタス;demi-tasse/
demo /デモ;demonstration/デモ版/
democracy /デモクラシー/
demokritos /デモクリトス/
demon /デーモン/
demonbane /デモンベイン/
demonstration /デモンストレーション/
demonstrator /デモンストレーター/デモンストレータ/
demorgan /ド・モルガン;(1806-1871) Augustus de Morgan/ドモルガン;De Morgan/
demosthenes /デモステネス/
demotape /デモテープ/
demy /ドゥミ/デミー/
den /デン/
dendro /デンドロ/
dendrobium /デンドロビウム/
deneuve /ドヌーヴ/
denhaag /ハーグ;Den Haag/
denied /ディナイド/拒否された/
denier /デニール/
denim /デニム/
denimjacket /デニムジャケット/
denimpants /デニムパンツ/
denimskirt /デニムスカート/
denis /デニス/ドニ/ドゥニ/
denise /デニス/
deniz /デニス/
denmark /デンマーク;.dk/
dennett /デネット/
dennis /デニス/
dennys /デニーズ;Denny's/
denomi /デノミ;denomination/
denomination /デノミネーション/
denotation /デノテーション/
denotational /デノテーショナル/
denpasar /デンパサール;バリ島(インドネシア)/
dense /デンス/
density /デンシティ/
dent /デント/
dental /デンタル/
dentalcare /デンタルケア/
denver /デンヴァー/デンバー;コロラド(USA)/
denys /デニス/
deodorant /デオドラント/
deoxy /デオキシ/
deoxyribose /デオキシリボース/
depardieu /ドパルデュー/
depart /デパート/
department /デパートメント/デパート/
departure /デパーチャー/
depaysement /デペイズマン;仏語/
depend /ディペンド/
dependency /ディペンデンシ/
depo /デポ/
deposerver /デポサーバー/
deposit /デポジット/
depth /デプス/
dequeue /デキュー/
der /ダー/
derby /ダービー/
derek /デレク/デリク/デレック/
derick /デリック/デリク/
deringer /デリンジャー/
derivative /デリバティブ/
derived /デライブド/
derrick /デリック/デリク/
derrida /デリダ/
derringer /デリンジャー/
des /デ;仏語/デス/
desailly /デサイー/
desc /記述子;descriptor/
descartes /デカルト/
descente /デサント/
describe /ディスクライブ/
descripter /記述子;※descriptor/
description /ディスクリプション/
descriptor /ディスクリプタ/記述子/
desert /デザート/
deserteagle /デザートイーグル/
design /デザイン/
designer /デザイナー/デザイナ/
designers /デザイナーズ/
designersbrand /デザイナーズブランド/
designpattern /デザインパターン/
desir /デジール;仏語/
desire /デザイア/デザイアー/デジレ;仏語/
desiree /デジレ;仏語/
desk /デスク/
desklight /デスクライト/
desktop /デスクトップ/
desktoppc /デスクトップPC/デスクトップパソコン/
deskwork /デスクワーク/
desmond /デズモンド/
desmonde /デスモンド/
desnos /デスノス/
dessau /デッサウ/
dessert /デザート/
dessertwine /デザートワイン/
dessin /デッサン/
destination /デスティネーション/ディスティネーション/デスティネイション/
destiny /デスティニー/ディスティニー/
destroy /デストロイ/破壊する/
destroyer /デストロイヤー/破壊者/
destruction /デストラクション/
destructor /デストラクタ/ディストラクタ/消滅子/
det /行列式;determinant/
detach /デタッチ/
detail /ディテール/
detect /ディテクト/発見する/
detective /ディテクティブ/
detector /ディテクタ/ディテクター/
detente /デタント/
detonation /デトネーション/
detroit /デトロイト/
detune /デチューン/
deuce /デュース/ジュース/
deutsch /ドイツ/ドイツ語/ドイチュ/
deutsche /ドイチェ/
deutschegp /ドイツGP;[F1]/
deutschland /ドイツ;.de/
deux /ドゥ/ドゥー/
deuxmagots /ドゥマゴ;Les Deux Magots/
develop /ディベロップ/デベロップ/
developer /デベロッパー/ディベロッパー/デベロッパ/
development /デベロップメント/ディベロップメント/
device /デバイス/デヴァイス/
devicedriver /デバイスドライバ/デバイスドライバー/
deviceid /デバイスID/
devicemanager /デバイスマネージャ/デバイスマネージャー/
devil /デビル/
devilman /デビルマン/
devilrays /デビルレイズ;[MLB]Devil Rays/
devin /デヴィン/
devine /デヴァイン/ディバイン/
devon /デボン/デヴォン/
devora /デボラ/
dew /デュー/
dewey /デューイ/
dex /デックス/
dexter /デクスター/
dextrin /デキストリン/
dharan /ダーラン;サウジアラビア/
dharma /ダルマ;法/
dhcpc /DHCPクライアント/
dhcpclient /DHCPクライアント/
dhcps /DHCPサーバ/
dhcpserver /DHCPサーバ/
dhole /ドール/
di /ジ;2/ディ/
dia /ダイヤ/ダイア/◇;菱形/◆;菱形/
diablo /ディアブロ/
diabolo /ディアボロ/
diacritical /ダイアクリティカル/
diagnosis /ダイアグノーシス/
diagram /ダイアグラム/ダイヤグラム/
dial /ダイヤル/ダイアル/
dialer /ダイアラー/ダイヤラー/ダイヤラ/ダイアラ/
dialin /ダイヤルイン/ダイアルイン/
dialing /ダイアリング/
dialog /ダイアログ/ダイアローグ/
dialogbox /ダイアログボックス/
dialogue /ダイアログ/
dialq# /ダイヤルQ#0/ダイヤルＱ#1/
dialq2 /ダイヤルQ2/ダイヤルＱ２/
dialup /ダイアルアップ/ダイヤルアップ/
diamond /ダイヤモンド/ダイアモンド/◇;菱形/◆;菱形/ダイヤ/金剛石/
diamondbacks /ダイヤモンドバックス;[MLB]/
diamondcut /ダイヤモンドカット/
diamonddust /ダイヤモンドダスト/
diana /ダイアナ/ディアナ/ディアーナ/
diane /ダイアン/ディアヌ/
dianne /ダイアン/
diary /ダイアリー/ダイアリ/
diaspora /ディアスポラ;(ギリシア語)離散/
diastase /ジアスターゼ/
diatone /ダイアトーン/
diatonic /ダイアトニック/
diaz /ディアス/ディアズ/
dibromochloromethane /ジブロモクロロメタン;(CHBr2Cl) トリハロメタンの一種/
dic /ディック/辞書/
dicaprio /ディカプリオ;DiCaprio/
dice /ダイス/
dichloro /ジクロロ/
dichloroethylene /ジクロロエチレン;C2H2Cl2/
dichloromethane /ジクロロメタン/
dick /ディック/
dickens /ディケンズ/
dickie /ディッキー/
dickson /ディクソン/ディクスン/
dictionary /ディクショナリー/ディクショナリ/辞書/
did /ディド/
diderot /ディドロ/
didge /ディジュ;didgeridoo/
didgeridoo /ディジュリドゥ/ディジュリドゥー/ディジリドゥ/ディジェリドゥ/ディジェリドゥー/ディジリドゥー/
didier /ディディエ/
dido /ディド/
didot /ディド/
die /ダイ/ディー/
diecast /ダイキャスト;die-cast/ダイカスト/
diego /ディエゴ/
diehard /ダイハード/
dies /ダイス/
diesel /ディーゼル/
dieselcar /ディーゼルカー/
dieselengine /ディーゼルエンジン/
dieskau /ディースカウ/
diet /ダイエット/
dietary /ダイエタリー/
dieter /ディーター/
dietfood /ダイエットフード/
diethyl /ジエチル/
dietrich /ディートリッヒ/ディートリヒ/
dieu /デュー;(Fr)神/
diff /ディフ/
difference /ディファレンス/
different /ディファレント/
differential /ディファレンシャル/∂/デフ/
diffuse /ディフューズ/
diffusion /ディフュージョン/
dig /ディグ/
digest /ダイジェスト/
digger /ディガー/
digicame /デジカメ;digital camera/
digipak /デジパック;[商標]AGI/
digit /デジット/ディジット/
digital /デジタル/ディジタル/Digital/
digitalaudio /デジタルオーディオ/
digitalaudioplayer /デジタルオーディオプレーヤー;dap/デジタルオーディオプレイヤー/
digitalcamera /デジタルカメラ/デジカメ/
digitaldata /デジタルデータ/
digitaldivide /デジタルデバイド/デジタルディバイド/ディジタルデバイド/ディジタルディバイド/
digitalhivision /デジタルハイビジョン/
digitalis /ジギタリス/
digitalpiano /デジタルピアノ/
digitalprint /デジタルプリント/
digitalsound /デジタルサウンド/
digitalsurround /デジタルサラウンド/
digitaltv /デジタルテレビ/
digitalvideo /デジタルビデオ/
digitalzoom /デジタルズーム/
digitizer /デジタイザ/デジタイザー/
dignity /ディグニティ/
dihydro /ジヒドロ/
dijkstra /ダイクストラ/
dijon /ディジョン/
dike /ダイク/
dilation /ダイレーション/
dildo /ディルド/ディルドー/
dilemma /ジレンマ/
dilettante /ディレッタント/
dill /ディル/
dillon /ディロン/
dilly /ディリー/
dim /ディム/ディミヌエンド;次第に弱く/diminuendo/
dimaggio /ディマジオ;DiMaggio/
dimanche /ディマンシュ;(Fr) 日曜日/
dimbula /ディンブラ;紅茶/
dime /ダイム/
dimension /ディメンション/ディメンジョン/
dimethyl /ジメチル/
dimethylamine /ジメチルアミン/
dimethylether /ジメチルエーテル/
diminish /ディミニッシュ/
diminuendo /ディミヌエンド/
dimple /ディンプル/
dina /ダイナ/ディナ/
dinah /ダイナ/
dinar /ディナール/
dine /ダイン/
diner /ダイナー/ディネ;(Fr)夕食/
diners /ダイナース/ダイナーズ/
dinghy /ディンギー/
dingo /ディンゴ/
dining /ダイニング/
diningkitchen /ダイニングキッチン/
diningroom /ダイニングルーム/
diningset /ダイニングセット/
diningtable /ダイニングテーブル/
dinkie /ディンキー/
dinks /ディンクス/double income, no kids/
dinner /ディナー/
dinnershow /ディナーショー/
dinnertime /ディナータイム/
dino /ディーノ/ディノ/
diode /ダイオード/
diogenes /ディオゲネス/
diol /ジオール/
dion /ディオン/
dionne /ディオンヌ/
dionysos /ディオニュソス/ディオニソス/
dior /ディオール;www.dior.com/
diorama /ジオラマ/ディオラマ/
dios /ディオス/
dioxin /ダイオキシン/
dip /ディップ/
diphtheria /ジフテリア/
diplomacy /ディプロマシー/
diplomat /ディプロマット/
diplomate /ディプロマット/
diplomatic /ディプロマティック/
diplomatique /ディプロマティーク;仏語/
dipole /ダイポール/
dipswitch /ディップスイッチ/DIPスイッチ/
dir /ディレクトリ/ディレクトリー/
dirac /ディラック/ディラク/
direct /ダイレクト/
direction /ディレクション/
directive /ディレクティブ/
directlink /ダイレクトリンク;直リン/
directmail /ダイレクトメール/
director /ディレクター/
directory /ディレクトリ/ディレクトリー/ディレクトリィ/デイレクトリー/
dirichlet /ディリクレ/
dirk /ディルク/デリック/
dirt /ダート/
dirtcourse /ダートコース/
dirty /ダーティ/ダーティー/
dis /ディス/
disable /ディスエーブル/ディゼーブル/
disassemble /ディスアセンブル/
disassembler /ディスアセンブラ/
disaster /ディザスター/ディザスタ/
disc /ディスク/
discard /ディスカード/
discarray /ディスクアレイ/
discbrake /ディスクブレーキ/
discharge /ディスチャージ/
discjockey /ディスクジョッキー;DJ/
disclosure /ディスクロージャー/ディスクロージャ/
discman /ディスクマン/
disco /ディスコ/
discography /ディスコグラフィー/ディスコグラフィ/
discommunication /ディスコミュニケーション/
disconnect /ディスコネクト/
discount /ディスカウント/
discountshop /ディスカウントショップ/
discountstore /ディスカウントストア/
discours /ディスクール/
discourse /ディスコース/
discovery /ディスカバリー/
discrete /ディスクリート/
discreview /ディスクレビュー/
discrimination /ディスクリミネーション/
discriminator /ディスクリミネータ/
discunion /ディスクユニオン/
discuss /ディスカス/
discussion /ディスカッション/
dish /ディッシュ/
disk /ディスク/DISK/
diskaccess /ディスクアクセス/
diskarray /ディスクアレイ/
diskcase /ディスクケース/
diskdrive /ディスクドライブ/
diskette /ディスケット/
diskimage /ディスクイメージ/
diskjockey /ディスクジョッキー/
diskless /ディスクレス/
diskman /ディスクマン/
diskreview /ディスクレビュー/
diskspace /ディスクスペース/
disney /ディズニー/
disneyland /ディズニーランド/
disneyresort /ディズニーリゾート/
disneysea /ディズニーシー;DisneySea/
disorder /ディスオーダー/
dispatch /ディスパッチ/
dispatcher /ディスパッチャ/
dispencer /ディスペンサー/ディスペンサ/
dispenser /ディスペンサー/
displacement /ディスプレイスメント/
display /ディスプレイ/ディスプレー/
disposer /ディスポーザー/
distance /ディスタンス/
distemper /ジステンパー/
distortion /ディストーション/
distri /ディストリ;distribution (NB:英語ではdistro)/
distribution /ディストリビューション/
distributor /ディストリビューター/ディストリビュータ/
district /ディストリクト/
distro /ディストロ;(Linuxの)distribution/
dita /ディタ/
dither /ディザ/
dithering /ディザリング/
div /÷/
diva /ディーバ/ディーヴァ;歌姫/
dive /ダイブ/ダイヴ/
diver /ダイバー/
divergence /ダイバージェンス/
diversity /ダイバーシティ/ダイバシティ/
divertimento /ディヴェルティメント/ディベルティメント/
divide /デバイド/ディバイド/
divider /ディバイダー/デバイダー/
divine /ディバイン/ディヴァイン/デヴァイン/デバイン/
diving /ダイビング/ダイヴィング/
divingcatch /ダイビングキャッチ/
division /ディビジョン/ディヴィジョン/
divot /ディボット/
dixie /デキシー/ディキシー/ディクシー/
dixieland /デキシーランド/ディキシーランド/
dixielandjazz /デキシーランドジャズ/
dizzy /ディジー/
dj /ディスクジョッキー/
django /ジャンゴ/
djembe /ジャンベ/
djibouti /ジブチ;.dj/
djinni /ジン/
dma /DMA/Direct Memory Access/
dmitri /ドミトリー/
dmitrii /ドミトリー/
dmitry /ドミトリー/
dnepr /ドニエプル/
do /ドゥ/ド/
dob /ドブ/
doberman /ドーベルマン/
dobermann /ドーベルマン;(独語)/
doc /ドク;doctor/ドキュメント;document/
docetaxel /ドセタキセル/
dock /ドック/
docking /ドッキング/
docment /ドキュメント;※document/
docomo /ドコモ;www.nttdocomo.co.jp/DoCoMo/
doctor /ドクター/ドクトル/博士/医者/博士課程/
doctorcar /ドクターカー/
doctorcheck /ドクターチェック/
doctorcourse /ドクターコース/
doctorstop /ドクターストップ/
doctrine /ドクトリン/
document /ドキュメント/文書/
documentalist /ドキュメンタリスト/
documentary /ドキュメンタリー/
documentation /ドキュメンテーション/
dodge /ドッジ/
dodgeball /ドッジボール/
dodgers /ドジャース;[MLB]/
dodo /ドードー/
doek /ズック;(蘭語)/
does /ダズ/
dog /ドッグ/
dogfight /ドッグファイト/
dogfood /ドッグフード/
doggie /ドギー/
doggy /ドギー/
dogleg /ドッグレッグ/
dogma /ドグマ/
dogmatic /ドグマティック/ドグマチック/
dograce /ドッグレース/
dogshow /ドッグショー/
dogtag /ドッグタグ/
doha /ドーハ/
dohran /ドーラン/
doimoi /ドイモイ/
dolby /ドルビー/
dolbydigital /ドルビーデジタル;Dolby digital/
dolbysurround /ドルビーサラウンド/
dolce /ドルチェ;www.dolcegabbana.it/
dolcetto /ドルチェット/
dole /ドール/
dolittle /ドリトル/
doll /ドール/ドル/
dollar /ドル/ダラー/＄/
dolly /ドリー/
dolmen /ドルメン/
dolomite /ドロマイト/
dolores /ドロレス/
dolphin /ドルフィン/イルカ/
dolphy /ドルフィー/ドルフィ/
dom /ドム/
domain /ドメイン/ドメーン;<rare>/
domainname /ドメインネーム/ドメイン名/
domani /ドマーニ/
dome /ドーム/
domenica /ドメニカ/
domenico /ドメニコ/
domestic /ドメスティック/
domi /ドミ/
domina /ドミナ/
dominant /ドミナント/
domingo /ドミンゴ/
dominic /ドミニク/
dominica /ドミニカ;.dm/
dominik /ドミニク/
dominion /ドミニオン/
dominique /ドミニク/
domino /ドミノ/
domperi /ドンペリ;Dom Perignon/
domperignon /ドンペリニョン;Dom Perignon/ドンペリニヨン/ドンペリ/
don /ドン/
donald /ドナルド/
donaldduck /ドナルドダック;[商標]Disney/
donaldson /ドナルドソン/
donatello /ドナテッロ/ドナテロ/ドナテルロ/
donation /ドネーション;寄付/
donato /ドナート/
donau /ドナウ/
done /ダン/
donetsk /ドネツク/
dongle /ドングル/
doni /ドニ/
donizetti /ドニゼッティ/
donjuan /ドンファン;Don Juan/
donkey /ドンキー/
donna /ドナ/ドンナ/
donnie /ドニー/
donny /ドニー/
donor /ドナー/
donorcard /ドナーカード/
donovan /ドノヴァン/ドノバン/
donquijote /ドンキホーテ;Don Quijote/ドン・キホーテ/
donquixote /ドンキホーテ;(英語綴) Don Quixote/ドン・キホーテ/
dont /ドント;don't/
dontmind /ドンマイ;Don't mind/
donut /ドーナツ/ドーナッツ/
donuts /ドーナツ/ドーナッツ/
dooard /ドアーズ;紅茶/
dooley /ドーリー/
doom /ドゥーム/
door /ドア/ドアー/
doorbell /ドアベル/
doorchain /ドアチェーン/
doorchime /ドアチャイム/
doorknob /ドアノブ/
doorlock /ドアロック/
doorman /ドアマン/
doormirror /ドアミラー/
doorphone /ドアホン;和製英語(intercom)/
doors /ドアーズ/
doorstopper /ドアストッパー/
dopa /ドーパ;DihydrOxyPhenylAlanine/
dopamine /ドーパミン/ドパミン/
dope /ドープ/
doping /ドーピング;薬物使用/
doppelganger /ドッペルゲンガー/
doppler /ドップラー/ドップラ/
dor /ドール/
dora /ドラ/ドーラ/
doreen /ドリーン/
doremi /ドレミ/
doremifa /ドレミファ/
dorham /ドーハム/
doria /ドリア/ドーリア/
dorian /ドリアン;DEFGABCD/
doris /ドリス/ドーリス/
dormie /ドーミー/
dormitory /ドミトリー/
dorothy /ドロシー/
dorris /ドリス/
dortmund /ドルトムント/
dos /ドス/DOS/
dose /ドーズ/
dostoevskii /ドストエフスキー;Достоевский/ドストエフスキイ/
dostoevsky /ドストエフスキー/ドストエフスキイ/
dostoyevsky /ドストエフスキー/ドストエフスキイ/
dosv /(concat "DOS\057V")/
dot /ドット/./．/・/、;読点/，;comma/丶;「チュ」の字/…/・・・;中黒x3/
dotcom /ドットコム;.com/
dotfile /ドットファイル;.skk/
dotfont /ドットフォント/
dotpitch /ドットピッチ/
dots /ドッツ/…/‥/.../・・・;中黒x3/
dotted /ドッティド/
dotter /ドッター/
double /ダブル/
doublea /ダブルA/
doublebass /ダブルベース/
doublebed /ダブルベッド/
doublebind /ダブルバインド/
doublebooking /ダブルブッキング/
doubleclick /ダブルクリック/
doublecount /ダブルカウント/
doubledagger /‡;ddagger/
doubledecker /ダブルデッカー/
doubledribble /ダブルドリブル/
doubleeagle /ダブルイーグル/
doublefault /ダブルフォルト/ダブルフォールト/
doubleflat /ダブルフラット/
doubleheader /ダブルヘッダー/
doubleplay /ダブルプレー/ダブルプレイ/
doublepunch /ダブルパンチ/
doublequotation /ダブルクオーテーション;”/
doublequote /ダブルクォート/“;opening/”;closing/
doublereed /ダブルリード/
doubleroom /ダブルルーム/
doubles /ダブルス/
doubleschool /ダブルスクール/
doublescore /ダブルスコア/
doublesharp /ダブルシャープ/
doublesize /ダブルサイズ/
doublestandard /ダブルスタンダード/
doublesteal /ダブルスチール/
doubleu /ダブリュー/
doubleyew /ダブリュー/
doubleyou /ダブリュー/
doubling /ダブリング/
doubt /ダウト/
douce /ドゥース/
doug /ダグ/ダッグ/
dougal /ドゥーガル/
dough /ドウ/
doughnut /ドーナツ/ドーナッツ/
doughnuts /ドーナツ/ドーナッツ/
douglas /ダグラス/
douglass /ダグラス/
doulton /ドルトン/
doutor /ドトール/
doux /ドウ/
dove /ダブ/ダヴ/
dover /ドーバー/ドーヴァー/
dow /ダウ/
down /ダウン/↓/
downarrow /↓/
downbeat /ダウンビート/
downer /ダウナー/
downgrade /ダウングレード/
downhill /ダウンヒル/
downjacket /ダウンジャケット/
downlight /ダウンライト/
downlink /ダウンリンク/
download /ダウンロード/
downloader /ダウンローダ/ダウンローダー/
downsampling /ダウンサンプリング/
downside /ダウンサイド/
downsizing /ダウンサイジング/
downstream /ダウンストリーム/
downswing /ダウンスイング/
downto /↓/
downtown /ダウンタウン/
downvest /ダウンベスト/
dowsing /ダウジング/
doyle /ドイル/
dozen /ダース/ダズン/
dq /ドラクエ;[ゲーム]Dragon Quest/
drab /ドラブ;鳶色/
dracaena /ドラセナ/
drachma /ドラクマ/
dracula /ドラキュラ/
draft /ドラフト/
drafting /ドラフティング/
drag /ドラッグ/
draganddrop /ドラッグアンドドロップ/
dragee /ドラジェ/
dragging /ドラッギング/
dragon /ドラゴン/
dragonball /ドラゴンボール;[アニメ]/
dragonfruit /ドラゴンフルーツ/
dragonquest /ドラゴンクエスト;[ゲーム]Enix/ドラクエ/
dragons /ドラゴンズ/
dragonslayer /ドラゴンスレイヤー/
dragoon /ドラグーン;竜騎兵/
dragrace /ドラッグレース/
drain /ドレイン/ドレン/ドレン／ベント/
drak /ドラク/
drake /ドレーク/ドレイク/
drama /ドラマ/
dramatic /ドラマティック/ドラマチック/
dramaturgie /ドラマツルギー/
dramaturgy /ドラマツルギー/
drang /ドラング/
drank /Dランク/Ｄランク/
drape /ドレープ/
drastic /ドラスティック/
dravida /ドラヴィダ/ドラビダ/
draw /ドロー/
drawer /ドロワ/ドロアー/ドロワー/ドロア/
drawers /ズロース/
drawing /ドローイング/
dread /ドレッド/
dreadhair /ドレッドヘア/
dreadnought /ドレッドノート/
dream /ドリーム/
dreamcast /ドリームキャスト;[商標]SEGA/
dreamer /ドリーマー/
dreaming /ドリーミング/
dreamjumbo /ドリームジャンボ;宝くじ/
dreamland /ドリームランド/
dreams /ドリームス/ドリームズ/
dreamteam /ドリームチーム/
dreamy /ドリーミー/
drei /ドライ/
dresden /ドレスデン/
dress /ドレス/
dresscode /ドレスコード/
dresser /ドレッサー/
dressing /ドレッシング/
dressshirt /ドレスシャツ/
dressshirts /ドレスシャツ/
dressup /ドレスアップ/
dressy /ドレッシー/
drew /ドリュー/ドルー/ドゥルー/
drewell /ドリエル/
dreyfus /ドレフュス/
dribble /ドリブル/
drier /ドライヤー/
drift /ドリフト/
drifter /ドリフター/
drifters /ドリフターズ/
drill /ドリル/
driller /ドリラー/
drink /ドリンク/
drinkbar /ドリンクバー/
drinker /ドリンカー/
drip /ドリップ/
dripcoffee /ドリップコーヒー/
dripper /ドリッパー/
dripping /ドリッピング/
drive /ドライブ/ドライヴ/
drivebay /ドライブベイ/
drivecourse /ドライブコース/
drivein /ドライブイン/
driveletter /ドライブレター/
drivemap /ドライブマップ;和製英語(roadmap)/
driven /ドリブン/
driver /ドライバー/ドライバ/ドライヴァ/
driverset /ドライバーセット/
driveway /ドライブウェイ/ドライブウェー/
driving /ドライビング/ドライヴィング/
drocer /ドローサー/
droit /ドロワ/
dron /Ｄ論/
drone /ドローン/
drop /ドロップ/
dropgoal /ドロップゴール/
drophandle /ドロップハンドル/
dropin /ドロップイン/
dropkick /ドロップキック/
dropout /ドロップアウト/
drops /ドロップス/
dropshot /ドロップショット/
drpepper /ドクターペッパー;www.drpepper.com/Dr Pepper;"Dr"はドットなし/
druaga /ドルアーガ/
drucker /ドラッカー/
drug /ドラッグ/
drugstore /ドラッグストア/
druid /ドルイド/
drum /ドラム/
drumbrake /ドラムブレーキ/
drumhead /ドラムヘッド/
drummer /ドラマー/
drumming /ドラミング/
drumnbass /ドラムンベース;drum'n'bass/
drumroll /ドラムロール/
drums /ドラムス/
drumset /ドラムセット/
drumsolo /ドラムソロ/
drumstick /ドラムスティック/
drunk /ドランク/
drunker /ドランカー/
dry /ドライ/
dryad /ドリアード/ドライアド/
drycleaning /ドライクリーニング/
drycurry /ドライカレー;dried curry/
dryer /ドライヤー/
dryeye /ドライアイ/
dryflower /ドライフラワー;dried flower/
dryfood /ドライフード/
dryfruit /ドライフルーツ;dried fruits/
dryfruits /ドライフルーツ;dried fruits/
dryice /ドライアイス/
drymartini /ドライマティーニ/
drypoint /ドライポイント/
dryskin /ドライスキン/
drysuit /ドライスーツ/
drysuits /ドライスーツ/
drytype /ドライタイプ/
dryyeast /ドライイースト/
dsp /デジタル信号処理;digital signal processing/ディジタル信号処理/
dte /DTE/
dtmsoft /DTMソフト/
dtpsoft /DTPソフト/
dtype /Dタイプ/Ｄタイプ/
du /デュ/
dual /デュアル/
dualboot /デュアルブート/
dualdisplay /デュアルディスプレイ/
dualmode /デュアルモード/
dualsystem /デュアルシステム/
duane /デュアン/ドゥエイン/デュエイン/
dub /ダブ/
dubai /ドバイ;UAE/
dubbing /ダビング/
dubble /ダブル;?/
dublin /ダブリン/
duboeuf /デュブッフ/
dubois /デュボワ/
ducamp /デュカン/
ducasse /デュカス/
duchamp /デュシャン/
duck /ダック/ズック/
ducking /ダッキング/
ducru /デュクリュ/
duct /ダクト/
dud /ダッド/
dudley /ダドリー/ダッドリー/
due /デュー/
duel /デュエル/
duelist /デュエリスト/
dueprocess /デュープロセス/
duet /デュエット/
duetto /デュエット/
duff /ダフ/
duffel /ダッフル/
duffelcoat /ダッフルコート/
duffle /ダッフル/
dufflecoat /ダッフルコート/
dufy /デュフィ/
dugong /ジュゴン/
dugout /ダッグアウト/ダグアウト/
dukas /デュカス/
duke /デューク/
dulcie /ダルシー/
dulcimer /ダルシマー/
dulfer /ダルファー/
dull /ダル/
dumas /デュマ/
dumb /ダム/
dumbbell /ダンベル/
dumbo /ダンボ/
dumdum /ダムダム/
dummy /ダミー/
dummyhead /ダミーヘッド/
dump /ダンプ/
dumpcar /ダンプカー;和製英語(dump truck)/
dumper /ダンパー/
dumping /ダンピング/
dumpty /ダンプティ/ダンプティー/
dun /ダン/
dunan /デュナン/
dunaway /ダナウェイ/
duncan /ダンカン/
dundee /ダンディ/
dune /デューン/
dungarees /ドンゴロス/
dungeon /ダンジョン/
dungeons /ダンジョンズ/
dunhill /ダンヒル;www.dunhill.com/
dunk /ダンク/
dunkerque /ダンケルク/
dunlop /ダンロップ/
duo /デュオ/
duplex /デュプレックス/デュープレックス/デュプレクス/
duplicate /デュプリケート/デュプリケイト/デュープリケート/
dupont /デュポン;Du Pont de Nemours/
duralumin /ジュラルミン/
duran /デュラン/
durand /デュラン/
duras /デュラス/
duration /デュレーション/デュレイション/
durban /ダーバン;南ア/
durer /デューラー/
durga /ドゥルガー/
durian /ドリアン/
durkheim /デュルケム/デュルケーム/
dushanbe /ドゥシャンベ/
duskin /ダスキン;www.duskin.co.jp/
dusseldorf /デュッセルドルフ/
dust /ダスト/
dustbox /ダストボックス/
dustcover /ダストカバー/
duster /ダスター/
dustin /ダスティン/
dusty /ダスティ/ダスティー/
dutch /ダッチ/
dutchoven /ダッチオーブン/
dutchroll /ダッチロール/
dutchwife /ダッチワイフ/
dutoit /デュトワ/
duty /デューティー/デューティ/
dutyfree /デューティーフリー/デューティフリー/
dvdaudio /DVDオーディオ/
dvdbox /DVDボックス/
dvdcase /DVDケース/
dvddeck /DVDデッキ/
dvddrive /DVDドライブ/
dvdmulti /DVDマルチ/
dvdmultidrive /DVDマルチドライブ/
dvdplayer /DVDプレーヤー/DVDプレイヤー/
dvdrack /DVDラック/
dvdrecorder /DVDレコーダー/
dvdshop /DVDショップ/
dvdvideo /DVDビデオ/
dvdvideocamera /DVDビデオカメラ/
dvorak /ドヴォルザーク/ドボルザーク/ドヴォルジャーク/ドボルジャーク/
dwarf /ドワーフ/
dwight /ドワイト/
dy /ジスプロシウム/Dysprosium/
dyck /ダイク/
dying /ダイイング/
dyingmessage /ダイイングメッセージ/
dylan /ディラン/Ｄｙｌａｎ/Dylan/Dylan(Dynamic language)/
dyna /ダイナ/
dynabook /ダイナブック;[商標]東芝/
dynamic /ダイナミック/
dynamicrange /ダイナミックレンジ/
dynamics /ダイナミクス/ダイナミックス/
dynamism /ダイナミズム/
dynamite /ダイナマイト/
dynamo /ダイナモ/
dynasty /ダイナシティ/ダイナスティ/
dyne /ダイン;10^-5N/
dyquem /ディケム;d'Yquem/
dysprosium /ジスプロシウム;[元素]66,Dy/
dystrophy /ジストロフィー/ジストロフィ/
e /ε;epsilon/イー/э;cyrillic/エー;(独語)/ウー;(仏語)/
e+ /イープラス;eee.eplus.co.jp/
eaccess /イーアクセス;www.eaccess.net/
each /イッチ/
eagle /イーグル/
eagles /イーグルス/
ear /イヤー/イア/
earhook /イヤーフック/
earl /アール/
earlgrey /アールグレイ;Earl Grey/アールグレー/
early /アーリー/
earlyamerican /アーリーアメリカン/
earpad /イヤーパッド/
earphone /イヤホン/イヤフォン/イアフォン/
earring /イヤリング/イアリング/
earth /アース/
earthday /アースデイ;4.22/
earthquake /アースクエイク/
earthy /アーシー/
ease /イーズ/
easel /イーゼル/
eason /イーソン/
east /イースト/Ｅａｓｔ/
eastcoast /イーストコースト/
eastend /イーストエンド;East End, London/
easter /イースター/
easteregg /イースターエッグ/
eastern /イースタン/
easternleague /イースタンリーグ/
eastside /イーストサイド/
eastwood /イーストウッド/
easy /イージー/
easylistening /イージーリスニング/
easyorder /イージーオーダー/
easyrider /イージーライダー/
eat /イート/
eater /イーター/
eatin /イートイン;eat-in/
eau /オー;(Fr)水/
eaudecologne /オーデコロン;eau de Cologne/
eaudetoilette /オードトワレ;eau de toilette/
ebank /イーバンク;www.ebank.co.jp/
ebay /イーベイ;www.ebay.com/
ebola /エボラ/
ebonite /エボナイト/
ebony /エボニー/
ebro /エブロ/
ecaprolactam /ε-カプロラクタム/ε-caprolactam/
ecbatana /エクバタナ/
eccentric /エキセントリック/
echalote /エシャロット/
echelon /エシュロン;米国営の盗聴システム/
echinacea /エキナセア/エキナシア/
echo /エコー/
echoback /エコーバック/
eckart /エッカート/エッカルト/
eckert /エッカート/
eckhard /エックハルト/
eckhardt /エックハルト/
eclaire /エクレア/
eclipse /エクリプス/
eco /エコ/エーコ;(1932-) Umberto Eco/
ecobusiness /エコビジネス/
ecohouse /エコハウス/
ecole /エコール;仏語/
ecological /エコロジカル/
ecologist /エコロジスト/
ecology /エコロジー/
ecomark /エコマーク;ちきゅうにやさしい/
ecommerce /eコマース/Eコマース/
economic /エコノミック/
economical /エコノミカル/
economics /エコノミクス/エコノミックス/
economist /エコノミスト/
economy /エコノミー/
economyclass /エコノミークラス/
ecosystem /エコシステム/
ecrit /エクリ/
ecriture /エクリチュール/
ecstasy /エクスタシー/
ecuador /エクアドル;.ec/
ecup /Eカップ;20cm/Ｅカップ/
ed /エド/
eda /エダ/
edam /エダム/
edamcheese /エダムチーズ/
edbeta /ＥＤベータ/
edda /エッダ/
eddie /エディ/エディー/
eddy /エディ/エディー/
ede /イード/
edel /エーデル;(独語)高貴な/エデル/
edelweiss /エーデルワイス/
eden /エデン/
edgar /エドガー/
edgard /エドガー/
edge /エッジ/
edging /エッジング/
edible /エディブル/
edie /エディ/エディー/イーディ/
edinburgh /エディンバラ/エジンバラ;イギリス/
edison /エジソン/エディソン/
edit /エディット/エディト/編集/
edith /エディス/イーディス/
editing /エディティング/
edition /エディション/
editor /エディタ/エディター/
editorial /エディトリアル/
editors /エディターズ/
edmond /エドモンド/エドモン/
edmondo /エドモンド/
edmonton /エドモントン/
edmund /エドモンド/エドマンド/エドムント/
edna /エドナ/
edoard /エドゥアルド/エドアルド/
edoardo /エドアルド/
edouard /エドゥアール/エドワール/
edrive /Eドライブ;E:/Ｅドライブ/
edu /エドゥ/
eduard /エドゥアルド/エドアルド/エデュアルド/エドゥアルト/
eduardo /エドゥアルド/エドアルド/エデュアルド/
educatation /エデュケーション/
education /エデュケーション/エデュケイション/
educational /エデュケーショナル/
educator /エデュケーター/
edutainment /エデュテイメント;[新語]education + entertainment/エデュテインメント/
edward /エドワード/
edwin /エドウィン/
ee /η;eta/イー/
eel /イール/
eero /エーロ/
ef /ф;cyrillic/エフ/
eff /エフ/
effect /エフェクト/イフェクト/
effector /エフェクター/エフェクタ/イフェクタ/
effects /エフェクツ/
effort /エフォート/
egalite /エガリテ;(Fr)平等/
egg /エッグ/
eggman /エッグマン;Goo goo g'joob!/
egmont /エグモント/
ego /エゴ/
egoism /エゴイズム/
egoist /エゴイスト/
egoistic /エゴイスティック/
egon /エゴン/
egypt /エジプト;.eg/
egyptian /エジプシャン/
egyptianmau /エジプシャンマウ/
eichmann /アイヒマン/
eicosanoid /エイコサノイド/
eiffel /エッフェル/
eiger /アイガー/
eight /エイト/
eightball /エイトボール/
eightbeat /エイトビート/
eighteen /エイティーン/
eighth /エイス/
eighty /エイティ/
eileen /アイリーン/
ein /アイン/
einstein /アインシュタイン/
einsteinium /アインスタイニウム;[元素]99,Es/
eira /エイラ/
eire /エール/
eisenhower /アイゼンハワー/
eiswein /アイスヴァイン/
eizenshtein /エイゼンシュテイン/
eject /イジェクト/
ekaterina /エカテリーナ/エカチェリーナ/
el /エル/л;cyrillic/
elaine /エレイン/イレイン/
elan /エラン/
elastic /エラスティック/
elastin /エラスチン/
elba /エルバ/
elbe /エルベ/
elbow /エルボー/
elbowpad /エルボーパッド/
elda /エルダ/
elder /エルダー/
eldorado /エルドラド;El Dorado/
eleanor /エレナ/エレノア/エリノア/エレナー/エレアノール/
elearning /eラーニング;e-learning/
elec /エレキ/
elect /エレクト/
election /エレクション/
electone /エレクトーン/
electra /エレクトラ/
electric /エレクトリック/
electrical /エレクトリカル/
electricbass /エレクトリックベース/
electricguitar /エレクトリックギター/
electro /エレクトロ/
electroluminescence /エレクトロルミネッセンス;EL/エレクトロルミネセンス/
electron /エレクトロン/
electronic /エレクトロニック/
electronica /エレクトロニカ/
electronics /エレクトロニクス/
elegance /エレガンス/
elegant /エレガント/
elegante /エレガンテ/
elegie /エレジー/
elegy /エレジー/
elektra /エレクトラ/
element /エレメント/
elemental /エレメンタル/
elementary /エレメンタリー/
elements /エレメンツ/
elena /エレナ/エレーナ/
eleni /エレニ/
elenore /エレノア/エリノア/エリナー/
eleonora /エレオノーラ/
elephant /エレファント/
elescorial /エスコリアル;El Escorial/
elevation /エレベーション/
elevator /エレベーター/エレベータ/
elevatorgirl /エレベーターガール/
eleven /イレブン/
elf /エルフ/
elfin /エルフィン/
elgar /エルガー/
eli /エリ/
elia /エリア/
eliade /エリアーデ/
eliana /エリアナ/
elias /エリアス/イライアス/
elie /エリー/イリヤ/イリア/
elijah /エリヤ/
eliminator /エリミネーター/
elina /エリナ/エリーナ/
elinor /エリナ/エリノア/
elio /エリオ/
eliot /エリオット/
elis /エリス/
elisa /イライザ/エリザ/エリサ/
elisabeth /エリザベート/エリザベト/エリザベス/
elise /エリーゼ/エリース/エリーズ/エリス/
elisha /エリシャ/
elisp /EmacsLisp/Emacs Lisp/
elite /エリート/
elixir /エリクシール/エリキシル/
eliza /エリザ/イライザ/
elizabeth /エリザベス/
elk /エルク/Elk/
ella /エラ/
ellas /エラス/
elle /エル/
ellen /エレン/
ellery /エラリー/
elli /エリ/エリー/
ellie /エリー/
ellington /エリントン/
elliott /エリオット/
ellis /エリス/
ellison /エリソン/エリスン/
ellora /エローラ/
elly /エリー/
elma /エルマ/
elmer /エルマー/
elmo /エルモ/
elnino /エルニーニョ;El Nino/
elocution /エロキューション/
elodie /エロディ/
elohim /エロヒム/
eloise /エロイーズ/
eloy /エロア/エロイ/
elpaso /エルパソ;El Paso/
elric /エルリック/
elroy /エルロイ/
elsa /エルザ/エルサ/
elsalvador /エルサルバドル;El Salvador,sv,.sv/
else /エルス/
elsie /エルシー/エルセ/
elton /エルトン/
eltsyn /エリツィン/
eluard /エリュアール/
elvin /エルヴィン/
elvira /エルビラ/エルヴィラ/
elvis /エルヴィス/エルビス/
elysee /エリゼ/
em /м;cyrillic/エム/
ema /エマ/
emacs /Ｅｍａｃｓ/ｅｍａｃｓ/Emacs/イーマックス/Editing MACroS/
emacslisp /EmacsLisp/Emacs Lisp/
email /E-mail/Eメール/電子メール/電子メイル/
emailaddress /Eメールアドレス/E-mailアドレス/
emanuel /エマニュエル/エマニエル/エマヌエル/
emanuele /エマヌエーレ/
embassy /エンバシー/
embed /エンベッド/
embedded /エンベデッド/
emblem /エンブレム/
emboss /エンボス/
embouchure /アンブシュア/
embryo /エンブリオ/
emerald /エメラルド/
emergency /エマージェンシー/
emerging /エマージング/
emerson /エマーソン/エマソン/
emery /エメリ/エメリー/
emil /エミール/エミル/エーミール/
emile /エミール/
emilia /エミリア/エミーリア/
emiliano /エミリアーノ/
emilie /エミリー/
emilio /エミリオ/
emily /エミリ/エミリー/
emission /エミッション/
emitter /エミッタ/エミッター/
emma /エマ/エンマ/
emmanuel /エマヌエル/エマニュエル/
emmanuelle /エマニュエル/エマヌエル/
emmenthal /エメンタール/
emmerich /エメリッヒ/
emmet /エメット/
emmy /エミー/
emotion /エモーション/
emotional /エモーショナル/
emperor /エンペラー/
emphasis /エンファシス/強調/
empire /エンパイア/
emporium /エンポリアム/エンポリウム/
empower /エンパワー/
empowerment /エンパワーメント/
empty /エンプティ/エンプティー/
emu /エミュー;[鳥]/エミュ;emulator/
emulate /エミュレート/イミュレート/
emulation /エミュレーション/
emulator /エミュレータ/エミュレーター/イミュレータ;<rare>/イミュレイタ;<rare>/
emulsion /エマルジョン/
emurate /エミュレート;※emulate/
emurater /エミュレータ;※emulator/
en /エン/アン;仏語/エヌ/
enable /イネーブル/
enableware /イネーブルウェア/
enamel /エナメル/
enbug /エンバグ/
encapsulate /カプセル化/
encapsulation /エンカプセレーション/エンカプシュレーション/
encapsulator /エンカプスレータ/
enchainement /アンシェヌマン/
enchant /エンチャント/
enchante /アンシャンテ/
enclosure /エンクロージャー/エンクロージャ/
encode /エンコード/符号化/
encoder /エンコーダ/エンコーダー/
encoding /エンコーディング/
encore /アンコール/
encount /エンカウント/
encounter /エンカウンター/
encyclopedia /エンサイクロペディア/百科事典/
end /エンド/
ende /エンデ/
endeavour /エンデバー/
ender /エンダー/
endevor /エンデバー/
endian /エンディアン/
ending /エンディング/
endingroll /エンディングロール/
endingtheme /エンディングテーマ/
endive /エンダイブ/
endless /エンドレス/
endline /エンドライン/
endmark /エンドマーク/
endorphin /エンドルフィン/
endpoint /エンドポイント/
endtoend /エンドツーエンド/
enduser /エンドユーザー/エンドユーザ/
endymion /エンディミオン/
ene /エネ;energy/
enema /エネマ/
energisch /エネルギッシュ;(独語)/
energish /エネルギッシュ;※energisch?/
energy /エネルギー/エナジー/
enfant /アンファン/
engage /エンゲージ/アンガージュ;仏語/
engagement /アンガージュマン;仏語/エンゲージメント/
engagering /エンゲージリング/
engel /エンゲル/
engelbert /エンゲルベルト/エンゲルバート/
engelhardt /エンゲルハート/
engels /エンゲルス/エゲレス;(蘭語)/
engine /エンジン/
enginebrake /エンジンブレーキ/
engineer /エンジニア/
engineering /エンジニアリング/
enginekey /エンジンキー/
enginetrouble /エンジントラブル/
england /イングランド/イギリス/
englar /エングラー/
english /イングリッシュ/イギリス/英吉利/
englishhorn /イングリッシュホルン/
enhance /エンハンス/
enhanced /エンハンスド/エンハンスト/
enid /アニド/
enigma /エニグマ;謎/
enix /エニックス/
enja /エンヤ/
enjoy /エンジョイ/
enki /エンキ/
enkidu /エンキドゥ/
enlil /エンリル/
ennio /エンニオ/
ennis /エニス/
ennui /アンニュイ/
enoch /エノク/イノック/イーノック/
enola /エノラ/
enolagay /エノラゲイ;Enola Gay/エノラ・ゲイ/
enos /エノス/
enquete /アンケート/
enqueue /エンキュー/
enrich /エンリッチ/
enrico /エンリコ/
enrique /エンリケ/
ensemble /アンサンブル/
entailment /→/
entasis /エンタシス/
enter /エンター/
enterbrain /エンターブレイン;www.enterbrain.co.jp/
enterkey /エンターキー/ENTERキー/
enterprise /エンタープライズ/
entertainer /エンターテイナー/エンターティナー/
entertainment /エンターテイメント/エンターテインメント/エンタテインメント/エンタテイメント/エンターティメント/
enthalpy /エンタルピー/
entire /エンタイア/
entitle /エンタイトル/
entity /エンティティ/
entoutcas /アンツーカー;(Fr)en tout cas/
entrance /エントランス/
entrancehall /エントランスホール/
entrapment /エントラップメント/
entree /アントレ/
entremet /アントルメ/
entremets /アントルメ/
entrepreneur /アントレプレナー/
entropy /エントロピー/
entry /エントリー/エントリ/
entrymodel /エントリーモデル/
entrysheet /エントリーシート/
envelope /エンベロープ/
envy /エンヴィ/エンヴィー/
enzo /エンツォ/
eof /EOF/
eos /エオス/イーオス/
epee /エペ/
ephedrine /エフェドリン/
ephesos /エフェソス/エペソ/
ephesus /エペソ/エフェソス/
epi /エピ/
epic /エピック/
epicurean /エピキュリアン/
epigonen /エピゴーネン/
epigraph /エピグラフ/
epikuros /エピクロス/エピキュロス/
epilogue /エピローグ/
epiphanie /エピファニー;仏語/
epiphany /エピファニー/
epipolar /エピポーラ/
episode /エピソード/
episteme /エピステーメー/
epitaxy /エピタキシー/エピタキシ/
epitope /エピトープ/
eplus /イープラス;eee.eplus.co.jp/
epoch /エポック/
epochmaking /エポックメイキング/エポックメーキング/
epock /エポック;※epoch?/
epoque /エポック;仏語/
epoxy /エポキシ/
eprecord /EPレコード/
epsilon /ε/イプシロン/∋;include/∈/
epson /エプソン;www.epson.co.jp/
eq /＝/≡/
equal /イコール/＝/
equalise /イコライズ/
equaliser /イコライザー/イコライザ/
equality /イクアリティ/
equalize /イコライズ/
equalizer /イコライザー/イコライザ/
equity /エクイティ/エクイティー/
equiv /⇔/≡/
equivalent /⇔/≡/
er /р;cyrillic/エルビウム/Erbium/
era /エラ/イラ/イアラ/
erase /イレース/
eraser /イレイザー/イレーザー/イレーサー/イレイサー/
erasmus /エラスムス/
eratosthenes /エラトステネス/
erbium /エルビウム;[元素]68,Er/
erda /エルダ/
erebos /エレボス/
erebus /エレボス/
erect /エレクト/
erection /エレクション/
erector /エレクター/
eren /エレン/
erg /エルグ;10^-7J/
ergo /エルゴ/
ergode /エルゴード/
ergonomics /エルゴノミクス;人間工学/
ergosterol /エルゴステロール/
eria /エリア/
eric /エリック/
erica /エリカ/
erich /エーリッヒ/エーリヒ/
erick /エリック/
erie /エリー/
erik /エリック/エリク/エーリク/
erika /エリカ/
erikson /エリクソン/
eritrea /エリトリア;.er/
erlung /アーラン/
erma /エルマ/アーマ/
ermine /アーミン/
ermitazh /エルミタージュ/
ernest /アーネスト/エルネスト/
ernesto /エルネスト/
ernie /アーニー/
ernst /エルンスト/
ero /エロ/
eroanime /エロアニメ;erotic animation,和製英語(hentai)/
eroero /エロエロ/
erogro /エログロ;erotic and grotesque/
eroica /エロイカ/
eros /エロス/
erosite /エロサイト/
erotic /エロティック/エロチック/
erotica /エロチカ/
eroticism /エロティシズム/エロチシズム/
erotomania /エロトマニア/
erovideo /エロビデオ;和製英語(porn video)/
err /エラー/
errata /エラッタ/エラータ/
errol /エロール/
erroll /エロール/
error /エラー/エラーメッセージ/
errorcheck /エラーチェック/
errorcode /エラーコード/
errordialog /エラー・ダイアログ/
errorlog /エラーログ/
errormessage /エラーメッセージ/
errorsignal /エラーシグナル/
erwin /エルヴィン/アーウィン/
erythritol /エリスリトール/
erythromycin /エリスロマイシン/
es /エス/с;cyrillic/アインスタイニウム/Einsteinium/
esa /エサ/
esc /エスケープ/
escalate /エスカレート/
escalation /エスカレーション/
escalator /エスカレーター/エスカレータ/
escape /エスケープ/
escapekey /エスケープキー/
escapesequence /エスケープシーケンス/
escargot /エスカルゴ/
escher /エッシャー/
esckey /ESCキー/エスケープキー/
escort /エスコート/
escrow /エスクロー/
esfahan /イスファハン/エスファハン/
esher /エッシャー/
eskimo /エスキモー/
esmeralda /エスメラルダ/
esoteric /エソテリック/
esp /ESP/
espace /エスパス;(Fr)空間/エスパース/
espagnole /エスパニョール/
espana /エスパーニャ/
espanol /エスパニョール/
espanola /エスパニョーラ/
esper /エスパー/
esperance /エスペランス/
esperanto /エスペラント/
esperanza /エスペランサ/
espoir /エスポワール/
espressione /エスプレッシオーネ/
espressivo /エスプレッシーヴォ/
espresso /エスプレッソ;スペイン語/
espressocoffee /エスプレッソコーヒー/
espressomachine /エスプレッソマシン/エスプレッソマシーン/
esprit /エスプリ/
esquimau /エスキモー/
esquisse /エスキス;仏語/
essai /エセー;仏語/エッセイ/エッセー/
essay /エッセイ/エッセー/エッセィ/
essayist /エッセイスト/
esse /エッセ/
essen /エッセン/
essence /エッセンス/
essential /エッセンシャル/
essentialoil /エッセンシャルオイル;精油/
essex /エセックス/
establish /エスタブリッシュ/
establishment /エスタブリッシュメント/設立/
estate /エステート/
esteban /エステバン/
estella /エステラ/
estelle /エステル/
ester /エステル/エスター/
esterase /エステラーゼ/
esthe /エステ/
esther /エステル/エスター/
esthesalon /エステサロン;esthetic salon/
esthetic /エステティック/
estheticien /エステティシャン;仏語/
estheticsalon /エステティックサロン;esthetic salon/
esthetique /エステティック/
estima /エスティマ;[商標]トヨタ/
estonia /エストニア;.ee/
estradiol /エストラジオール/
estragon /エストラゴン/
estrogen /エストロゲン/
estron /エストロン/
eta /η/エータ/
etat /エタ;仏語/
etcetera /エトセトラ/
etch /エッチ/
etching /エッチング/
eternal /エターナル/
eternity /エタニティ/エタニティー/
ethan /エタン;C2H6/イーサン;人名/
ethane /エタン;C2H6/
ethanol /エタノール/
ethel /エセル/
ether /エーテル/イーサ/
etherboard /イーサボード/イーサーボード/
ethernet /イーサネット/
ethica /エチカ/
ethics /エシックス/
ethiopia /エチオピア;.et/エティオピア/
ethnic /エスニック/
ethnicity /エスニシティ/
ethno /エスノ/
ethos /エートス/エトス/
ethyl /エチル;-C2H5/
ethylalcohol /エチルアルコール/
ethylene /エチレン;C2H4/
ethylenediamine /エチレンジアミン/
ethylenegas /エチレンガス/
ethyleneglycol /エチレングリコール;C2H6O2/
eti /エティ/
etienne /エティエンヌ/
etiquette /エチケット/
etna /エトナ/
etoile /エトワール/
eton /イートン/
etrange /エトランゼ/エトランジェ/
etruria /エトルリア/
etta /エッタ/
ettore /エットレ/
etude /エチュード/
etype /Eタイプ/Ｅタイプ/
eu /ユウロピウム/Europium/
eucalyptus /ユーカリ/
euccode /EUCコード/
euclid /ユークリッド/
eudora /ユードラ/
eugen /オイゲン/
eugene /ユージン/ユージーン/ウジェーヌ;仏語/
eukleides /エウクレイデス/ユークリッド;euclid/
euler /オイラー/
eunice /ユーニス/
eunos /ユーノス/
euphonium /ユーフォニアム/
euphoria /ユーフォリア/
euphrates /ユーフラテス/
eurasia /ユーラシア/
eure /ウール/
eureka /ユリイカ/エウレカ/ユーレカ/
euripides /エウリピデス/
euro /ユーロ/
eurobeat /ユーロビート/
europa /エウロパ/ヨーロッパ/欧羅巴/欧州/歐州/歐羅巴/
europagp /ヨーロッパGP;[F1]/
europe /ヨーロッパ/エウロペ/欧州/欧羅巴/歐州/歐羅巴/
european /ヨーロピアン/
europium /ユーロピウム;[元素]63,Eu/
eurostar /ユーロスター/
eurus /ユーラス;東風/エウロス/
eurydike /エウリュディケ/
eva /エヴァ/エバ/
evaluate /エバリュエート/評価する/
evaluator /エバリュエータ/
evamilk /エバミルク;evaporated milk/
evangeline /エヴァンジェリン/
evangelion /エヴァンゲリオン;[アニメ]/
evangelist /エバンジェリスト/
evans /エヴァンス/エバンス/
evaporator /エバポレータ/エバポレーター/
eve /イブ/イヴ/エヴァ/
evelyn /エブリン/イヴリン/エヴリン/イブリン/イーヴリン/
even /イーブン/
evening /イブニング/
eveningdress /イブニングドレス/
evenpar /イーブンパー/
event /イベント/イヴェント/
eventdriven /イベントドリブン/
eventer /イベンター/
eventhandler /イベントハンドラ/
eventschedule /イベントスケジュール/
eventspace /イベントスペース/
ever /エバー/エヴァー/
everest /エベレスト/エヴェレスト/
evergreen /エバーグリーン/
everton /エヴァートン/
every /エブリ/エヴリ/
everybody /エブリバディ/
everyday /エブリデイ/エブリディ/エブリデー/
everyone /エブリワン/
evgeni /エフゲニー/
evgenii /エフゲニー/
evian /エビアン/エヴィアン/
evidence /エビデンス/
evil /エビル/
evolution /エボリューション/エヴォリューション/発展/
ew /─;罫線/━;太い罫線/
ewan /ユアン/
ewn /┴/┻;太/┷;横太/┸;縦太/
ews /┬/┳;太/┯;横太/┰;縦太/エンジニアリング・ワークステーション/ワークステーション/
ex /エクス/エキス/イクス/∃/エックス/
exa /エクサ;[SI接頭語]E,10^18/
excalibur /エクスカリバー/
exceed /エクシード/
excel /エクセル/
excelan /エクセラン;[企業名]/
excellence /エクセレンス/
excellent /エクセレント/
excentric /エキセントリック/
except /エクセプト/
exception /エクセプション/例外/
excess /エクセス/
exchange /エクスチェンジ/
excite /エキサイト/
exciting /エキサイティング/
exclamation /エクスクラメーション/感嘆符/！/
exclamationmark /エクスクラメーションマーク;！/
exclusive /エクスクルーシブ/
excursion /エクスカーション/
excuse /エクスキューズ/
exe /エグゼ/
exec /実行/
exective /エグゼクティブ;※executive/
execute /エグゼキュート/
executive /エグゼクティブ/エクゼクティブ/
exercise /エクササイズ/Ｅｘｅｒｃｉｓｅ/
exergy /エクセルギー/
exhibition /エキシビション/エキシビジョン;※「エキシビション」の方が忠実/エキジビション/エグジビション/
exist /イグジスト/∃/
exists /∃/
exit /イグジット/
exodus /エクソダス/
exon /エクソン/エキソン/
exorcist /エクソシスト/
exotic /エキゾチック/エキゾティック/
exp /エクスポネンシャル/
expand /エキスパンド/エクスパンド/イクスパンド/拡張/
expander /エキスパンダー/エクスパンダー/エキスパンダ/エクスパンダ/
expansion /エキスパンション/エクスパンション/
experience /エクスペリエンス/
experiment /エクスペリメント/
experimental /エクスペリメンタル/
expert /エキスパート/
expertsystem /エキスパートシステム/エキスパート・システム/
expiration /エクスパイレーション/
expire /エクスパイア/
explorer /エクスプローラ/エクスプローラー/
explosion /エクスプロージョン/
expo /エキスポ/エクスポ/
exponential /エクスポネンシャル/
export /エクスポート/エキスポート/
expose /エクスポーズ/
exposure /エクスポージャー/
express /エクスプレス/エキスプレス/
expression /エクスプレッション/イクスプレッション/式/
extend /エクステンド/
extended /エクステンデッド/
extender /エクステンダー/エクステンダ/
extension /エクステンション/
extent /エクステント/
extention /エクステンション/
exterior /エクステリア/
external /エクスターナル/
extra /エクストラ/エキストラ/
extract /エキス/
extravirgin /エクストラバージン/エクストラヴァージン/
extreme /エクストリーム/
exxon /エクソン/
eyck /アイク/
eye /アイ/
eyebank /アイバンク/
eyebrow /アイブロウ/アイブロー/
eyecatch /アイキャッチ;和製英語/
eyecolor /アイカラー/
eyecolour /アイカラー/
eyecontact /アイコンタクト/
eyeguard /アイガード/
eyeline /アイライン/
eyeliner /アイライナー/
eyemake /アイメイク;eye makeup/
eyemask /アイマスク/
eyes /アイズ/
eyeshadow /アイシャドウ/アイシャドー/
eyre /エア/
ezekiel /エゼキエル/
ezra /エズラ/
f /φ;phi/エフ/ф;ef (cyrillic)/フッ素/Flourine/フォルテ;強く/forte/周波数/
f#driver /F#0ドライバー/Ｆ#1ドライバー/
f#key /F#0キー/
f#race /F#0レース/Ｆ#1レース/
f#racer /F#0レーサー/Ｆ#1レーサー/
f1 /Ｆ１/１／ｆゆらぎ/
fa /ファ/
fabian /フェビアン/ファビアン/
fabien /ファビアン/
fabio /ファビオ/
fable /ファーブル;仏語/フェイブル/
fabless /ファブレス/
fabre /ファーブル/
fabric /ファブリック/
fabrice /ファブリス/
fabrizio /ファブリツィオ/
facade /ファサード/
face /フェイス/フェース/
facecare /フェイスケア/
faceline /フェイスライン/
facemark /フェイスマーク;:-)/
facet /ファセット/
facetowel /フェイスタオル/
facial /フェイシャル/
facilitator /ファシリテーター/ファシリテータ/
facility /ファシリティ/ファシリティー/
facom /ファコム/
facsimile /ファクシミリ/
fact /ファクト/
factbook /ファクトブック/
factor /ファクター/ファクタ/
factoring /ファクタリング/
factory /ファクトリー/ファクトリ/
fad /ファド/ファッド/
fade /フェード/フェイド/
fadein /フェードイン/
fadeout /フェードアウト/
fader /フェーダー/フェーダ/フェイダー/
fagotto /ファゴット/
fahd /ファハド/
fail /フェイル/失敗/フェール/
failover /フェイルオーバー/
failsafe /フェイルセーフ/フェールセーフ/
failure /フェイリュア/
faint /フェイント/
fair /フェア/フェアー/
fairbanks /フェアバンクス/
fairlady /フェアレディ/
fairway /フェアウェイ/
fairy /フェアリー/
fairyland /フェアリーランド/
fairytale /フェアリーテール/
faith /フェイス/
fake /フェイク/
fakefur /フェイクファー/
falcom /ファルコム;www.falcom.co.jp/
falcon /ファルコン/
falkland /フォークランド;.fk/
fall /フォール/
falla /ファリャ/
fallback /フォールバック/
falluja /ファルージャ;イラク/
false /フォルス/フォールス/誤/偽/
falsetto /ファルセット/
fame /フェイム/フェーム/Ｆａｍｅ/
fami /ファミ;family/
famicom /ファミコン/
famicon /ファミコン/
familia /ファミリア/
familiar /ファミリア/
family /ファミリー/ファミリ/
familyclub /ファミリークラブ/
familycomputer /ファミリーコンピュータ/ファミコン/
familymart /ファミリーマート;www.family.co.jp/
familyname /ファミリーネーム/
familyplan /ファミリープラン/
familyrestaurant /ファミリーレストラン/
famires /ファミレス;family restaurant/
famous /フェイマス/
fan /ファン/
fanatic /ファナティック/
fanclub /ファンクラブ/
fancy /ファンシー/
fancygoods /ファンシーグッズ/
fancyshop /ファンシーショップ/
fandango /ファンダンゴ/
fanfare /ファンファーレ/
fang /ファング/
fanheater /ファンヒーター/
fanin /ファンイン/
fanless /ファンレス/
fanletter /ファンレター/
fannie /ファニー/
fanny /ファニー/
fanout /ファンアウト/
fanservice /ファンサービス/
fansite /ファンサイト/
fanta /ファンタ/
fantasia /ファンタジア/
fantasic /ファンタジック/
fantasista /ファンタジスタ/
fantastic /ファンタスティック/
fantasy /ファンタジー/
fantasynovel /ファンタジーノベル/
farad /ファラッド/ファラド/
faraday /ファラデー/
farandole /ファランドール/
farce /ファルス/
fareast /ファーイースト;極東/
farewell /フェアウェル/
farfalle /ファルファッレ/
farina /ファリーナ/
farm /ファーム/
farmer /ファーマー/
farming /ファーミング/
farside /ファーサイド/
farther /ファーザー/
fascio /ファッショ;(イタリア語)/
fascism /ファシズム/
fascist /ファシスト/
fashion /ファッション/
fashionable /ファッショナブル/
fashionbrand /ファッションブランド/
fashiondesign /ファッションデザイン/
fashiondesigner /ファッションデザイナー/
fashioned /ファッションド/
fashionhealth /ファッションヘルス/
fashionhotel /ファッションホテル/
fashionleader /ファッションリーダー/
fashionmodel /ファッションモデル/
fashionsense /ファッションセンス/
fashionshop /ファッションショップ/
fashionshow /ファッションショー/
fast /ファースト/ファスト/
fastener /ファスナー/
fastfood /ファーストフード/ファストフード/
fat /ファット/
fatah /ファタハ/
fatal /フェイタル/ファタール;仏語/ファタル;仏語/
fate /フェイト/
father /ファーザー/ファザー/
fathercon /ファザコン;father complex/
fatherland /ファザーランド/
fathers /ファーザーズ/
fatima /ファティマ/ファーティマ/
fats /ファッツ/
fauchon /フォション;www.fauchon.fr/
faulkner /フォークナー/
fault /フォルト/フォールト/
faulttolerance /フォールトトレランス/
faulttolerancy /フォルトトレランシ/
faun /フォーン/
fauna /ファウナ/
faure /フォーレ/
faust /ファウスト/
fausto /ファウスト/
fauvism /フォービズム/フォーヴィズム/
fauvisme /フォーヴィスム/フォービスム/
favor /フェイバー/
favorite /フェイバリット/フェイヴァリット/
favour /フェイバー/
fax /ファックス/ファクス/ファクシミリ;facsimile/Ｆａｘ/FAX/
faxmodem /FAXモデム/ファックスモデム/
faxservice /FAXサービス/
fay /フェイ/
faye /フェイ/フェー/
fazzy /ファジィ;※fuzzy/
fb /フレームバッファ/
fcup /Fカップ;22.5cm/Ｆカップ/
fd /フロッピーディスク/FD/
fe /鉄/Iron/
fear /フィアー/フィア/
feasibility /フィージビリティ/
feather /フェザー/
feature /フィーチャー/フィーチャ/
featuring /フィーチャリング/
february /フェブラリー/
federal /フェデラル/
federico /フェデリコ/
fedora /フェドーラ;中折れ帽/フェドラ/
fee /フィー/
feed /フィード/
feedback /フィードバック/
feeder /フィーダー/フィーダ/
feedforward /フィードフォワード/
feel /フィール/
feeling /フィーリング/
feet /フィート/
feferman /フェファーマン/
fei /フェイ/
feint /フェイント/
feldman /フェルドマン/
felice /フェリーチェ/フェリス/
felicia /フェリシア/
feliciano /フェリシアーノ/
felipe /フェリペ/
felix /フェリス/フェリックス/フェリクス/
fella /フェラ/
fellatio /フェラチオ/
feller /フェラー/
fellini /フェリーニ/
fellow /フェロー/
fellowship /フェローシップ/
felt /フェルト/
feltpen /フェルトペン/
female /フィメール/♀/
femi /フェミ;feminism,feminist/
femina /フェミナ/
feminine /フェミニン/
feminism /フェミニズム/
feminist /フェミニスト/
femme /ファム/
femto /フェムト;[SI接頭語]f,10^-15/
fence /フェンス/
fencer /フェンサー/
fencing /フェンシング/
fender /フェンダー/
fenderrhodes /フェンダーローズ/
fendi /フェンディ;www.fendi.it/
fenelon /フェヌロン/
fennel /フェンネル;茴香/
fenollosa /フェノロサ/
fenrir /フェンリル/
fentanyl /フェンタニル/
fep /フロントエンドプロセッサ/
ferdinand /フェルディナンド/フェルディナント/フェルディナン/
ferdinando /フェルディナンド/
fergana /フェルガナ/
fergus /ファーガス/
ferguson /ファーガソン/
fermat /フェルマー/フェルマ/
fermata /フェルマータ/
fermi /フェルミ/
fermion /フェルミオン/フェルミ粒子/
fermium /フェルミウム;[元素]100,Fm/
fern /ファーン/
fernand /フェルナンド/フェルナン/
fernandes /フェルナンデス/
fernandez /フェルナンデス/
fernando /フェルナンド/
feroce /フェローチェ/
ferragamo /フェラガモ;www.salvatoreferragamo.it/
ferrara /フェラーラ;イタリア/
ferrari /フェラーリ/
ferre /フェレ/
ferreira /フェレイラ/
ferrer /フェレール/
ferret /フェレット/
ferretti /フェレッティ/
ferri /フェリ;(接頭辞) 鉄/
ferrite /フェライト/
ferry /フェリー/
fes /フェス/
fest /フェスト/
festa /フェスタ;(イタリア語)/
festiva /フェスティヴァ/
festival /フェスティバル/フェスティヴァル/
fetch /フェッチ/
feti /フェチ;fetishist/
fetish /フェティッシュ/
fetishism /フェティシズム/
fettuccine /フェットチーネ/
fettucine /フェットチーネ;=fettuccine/
feuerbach /フォイエルバッハ/
fever /フィーバー/
feynman /ファインマン/
fez /ファス/フェズ/
ff /font-family/フォルテッシモ;fより強く/fortessimo/
fff /フォルテッシシモ;ffより強く/fortessissimo/
fg /フォアグラウンド/
fiance /フィアンセ/
fiancee /フィアンセ/
fiat /フィアット/
fiber /ファイバー/ファイバ/
fiberscope /ファイバースコープ/
fibonacci /フィボナッチ/
fichte /フィヒテ/
fick /フィック/
fiction /フィクション/
fiddle /フィドル/
fiddler /フィドラー/
fidel /フィデル/
fidele /フィデル/
fidelio /フィデリオ/
fidelity /フィデリティ/
field /フィールド/
fielder /フィールダー/
fielderschoice /フィルダースチョイス;fielder's choice. 野選/
fieldgoal /フィールドゴール/
fielding /フィールディング/
fieldmap /フィールドマップ/
fieldnote /フィールドノート;field-note/
fields /フィールズ/
fieldwork /フィールドワーク;field-work/
fiesta /フィエスタ;(西語)/
fifteen /フィフティーン/
fifth /フィフス/
fifty /フィフティ/
figaro /フィガロ/
figeac /フィジャック/
fight /ファイト/
fighter /ファイター/
fighters /ファイターズ/
fighting /ファイティング/
fightingpose /ファイティングポーズ/
fightmoney /ファイトマネー/
figure /フィギュア/フィギュアー/
figureskate /フィギュアスケート/
fiji /フィジー;.fj/フィージー/
filament /フィラメント/
filaria /フィラリア/
file /ファイル/
fileformat /ファイルフォーマット/
filehandle /ファイルハンドル/
filemanager /ファイルマネージャ/ファイルマネージャー/
filemenu /ファイルメニュー/ファイル・メニュー/
filename /ファイルネーム/ファイル名/
filepointer /ファイルポインタ/
filer /ファイラー/ファイラ/
fileserver /ファイルサーバ/ファイルサーバー/
fileset /ファイルセット/
filesize /ファイルサイズ/
filesystem /ファイルシステム/
filet /ヒレ/フィレ/
filetype /ファイルタイプ/
filia /フィリア/
filing /ファイリング/
filip /フィリップ/
filippo /フィリッポ/
fill /フィル/
fille /フィーユ/
fillet /ヒレ/フィレット/
fillin /フィルイン/
filling /フィリング/
fillmore /フィルモア/
film /フィルム/フイルム/
filmcase /フィルムケース/
films /フィルムズ/
filmscanner /フィルムスキャナ/フィルムスキャナー/
filter /フィルター/フィルタ/
filterbank /フィルタバンク/
filtered /フィルタード/
filtering /フィルタリング/
fin /フィン/
fina /フィーナ/フィナ/
final /ファイナル/
finale /フィナーレ/
finalfantasy /ファイナルファンタジー;[ゲーム]Square/
finalise /ファイナライズ/
finalist /ファイナリスト/
finalize /ファイナライズ/
finallap /ファイナルラップ/
finance /ファイナンス/
financhier /フィナンシェ/
financial /ファイナンシャル/
financialplanner /ファイナンシャルプランナー;FP/
finch /フィンチ/
find /ファインド/
finder /ファインダー/ファインダ/
finding /ファインディング/
fine /ファイン/フィーネ/
fineart /ファインアート/
fineceramics /ファインセラミックス/
finechemical /ファインケミカル/
fineplay /ファインプレー/
finesse /フィネス/
finest /ファイネスト/
finetuning /ファインチューニング/
finger /フィンガー/
fingering /フィンガリング/
fingerprint /フィンガープリント/
finish /フィニッシュ/
finishing /フィニッシング/
fink /フィンク/
finland /フィンランド;.fi/
finlay /フィンレイ/
finn /フィン/
finnegan /フィネガン/
fiona /フィオナ/
fiore /フィオーレ/
fiorentina /フィオレンティーナ/
fiorentino /フィオレンティーノ/
fire /ファイア/ファイヤー/ファイアー/ファイヤ/
fireball /ファイアボール/ファイヤーボール/ファイアーボール/
firefox /ファイヤーフォックス/
fireman /ファイヤーマン/ファイアーマン/ファイアマン/
firenze /フィレンツェ/
firewall /ファイアウォール/ファイアーウォール/ファイヤーウォール/ファイヤウォール/
firm /ファーム/
firmware /ファームウェア/
first /ファースト/１ｓｔ/第1要素/
firstaid /ファーストエイド;first-aid/
firstalbum /ファーストアルバム/
firstbase /ファーストベース/
firstclass /ファーストクラス/ファースト・クラス/
firstcontact /ファーストコンタクト/
firstfly /ファーストフライ/
firstgoro /ファーストゴロ;和製語(grounder)/
firstimpression /ファーストインプレッション/
firstkiss /ファーストキス;first kiss/
firstlady /ファーストレディ/
firstmit /ファーストミット/
firstname /ファーストネーム/
fischer /フィッシャー/
fish /フィッシュ/
fisher /フィッシャー/
fisherman /フィッシャーマン;漁師/
fishing /フィッシング/
fisichella /フィジケラ/
fissler /フィスラー/
fist /フィスト/
fistfuck /フィストファック/
fit /フィット/
fitness /フィットネス/
fitnessclub /フィットネスクラブ/
fitter /フィッター/
fitting /フィッティング/
fitzgerald /フィッツジェラルド/
five /ファイブ/ファイヴ/
fix /フィックス/フィクス/修正/
fixed /フィクスト/
fixer /フィクサー/
fizz /フィズ/
fjord /フィヨルド/
fl /Florida/フロリダ/
flag /フラッグ/フラグ/
flagship /フラッグシップ/フラグシップ/
flail /フレイル/
flake /フレーク/
flam /フラム/
flamand /フラマン/
flambe /フランベ/
flamber /フランベ/
flame /フレーム/フレイム/
flamenco /フラメンコ/
flamingo /フラミンゴ/
flamm /フラム/
flamme /フラム;(Fr) 炎/
flan /フラン/
flanagan /フラナガン/
flanders /フランダース/
flandre /フランドル/
flange /フランジ/
flannel /フランネル/
flap /フラップ/
flapping /フラッピング/
flare /フレア/フレアー/
flareskirt /フレアスカート;flared skirt/フレアースカート/
flash /フラッシュ/
flashback /フラッシュバック/
flashmemory /フラッシュメモリ/フラッシュメモリー/
flask /フラスコ/
flat /フラット/♭/
flatbed /フラットベッド/
flatcable /フラットケーブル/
flatpanel /フラットパネル/
flatter /フラッタ/
flattop /フラットトップ/
flaubert /フローベール/フロベール/
flauto /フラウト/
flavan /フラバン/
flavanone /フラバノン/
flavin /フラビン/
flavone /フラボン/
flavonoid /フラボノイド/
flavonol /フラボノール/
flavor /フレーバー/フレイバー/フレイヴァー/Ｆｌａｖｏｒ/Flavor/
flavortea /フレーバーティー/
flax /フラックス/
fleamarket /フリーマーケット;蚤の市/
fleece /フリース/
fleet /フリート/
fleming /フレミング/
flesh /フレッシュ;肉/
fletcher /フレッチャー/
flets /フレッツ;flets.com/
fleur /フルール/
fleuret /フルーレ/
flex /フレックス/
flexible /フレキシブル/柔軟な/
flextime /フレックスタイム/
flick /フリック/
flicker /フリッカー/フリッカ/
flier /フライヤー/
flight /フライト/
flightattendant /フライトアテンダント/
flightsimulator /フライトシミュレータ/
flint /フリント/
flintstone /フリントストーン/
flip /フリップ/
flipflop /フリップフロップ/
flipper /フリッパー/
flippers /フリッパーズ/
flo /フロ/
float /フロート/浮動小数点数/
floating /フローティング/浮動小数点数/
flock /フロック;群れ/
flon /フロン/
flongas /フロンガス/
floor /フロア/フロアー/
flooring /フローリング/
floorlight /フロアライト/
floorplan /フロアプラン/
floorshift /フロアシフト/
floortam /フロアタム/
flop /フロップ/
floppy /フロッピー/フロッピィ/フロッピ/
floppydisk /フロッピーディスク/フロッピィディスク/
floppydiskdrive /フロッピーディスクドライブ;FDD/
flora /フローラ/
floral /フローラル/
flore /フロール/フローレ/
floreal /フロレアール/
florence /フローレンス/フロレンス/フロランス/フローランス/
florent /フローラン/
florentin /フロランタン;(Fr) フィレンツェの./
florentine /フロランティーヌ;(Fr) フィレンツェの./
flores /フローレス/フロレス/
floria /フローリア/
florian /フロリアン/フローリアン/
florida /フロリダ/
florist /フローリスト/
floss /フロス/
flour /フラワー;小麦粉/
flow /フロー/フロウ/
flowchart /フローチャート/フロウチャート;<rare>/
flower /フラワー/
flowerarrangement /フラワーアレンジメント/
flowerbox /フラワーボックス/
flowergift /フラワーギフト/
flowers /フラワーズ/
flowershop /フラワーショップ/
flowgraph /フローグラフ/
floyd /フロイド/
flugelhorn /フリューゲルホルン/フリューゲルホーン/
fluid /フルイド/
fluke /フロック;まぐれ/
fluorine /フローリン;F/
fluorite /フローライト;蛍石/フルオライト/
fluoro /フルオロ/フッ化/弗化/
fluorocarbon /フルオロカーボン/
flush /フラッシュ/
flute /フルート/
flutist /フルーティスト/
flutter /フラッター/フラッタ/
flux /フラックス/
fluxus /フルクサス/
fly /フライ/ハエ/
flyfishing /フライフィッシング;fly-fishing/
flying /フライング/
flying-pan /フライパン;※frying-pan?/
fm /フェルミウム/Fermium/エフエム;frequency modulation/
fmarinos /F・マリノス;[Jリーグ]横浜/
fmradio /FMラジオ/
foam /フォーム;泡/
foaming /フォーミング/
focaccia /フォカッチャ/
focus /フォーカス/
focusmode /フォーカスモード/
fodor /フォドー/
foehn /フェーン/
fog /フォグ/
foghorn /フォグホーン/
foglamp /フォグランプ/
foiegras /フォアグラ;foie gras/
foil /ホイル/フォイル/
fold /フォールド/
folder /フォルダ/フォルダー/
folding /フォールディング/
foley /フォーリー/フォリー/
folie /フォリー/
folio /フォリオ/
folk /フォーク/フォルク/
folkdance /フォークダンス/
folkduo /フォークデュオ/
folkguitar /フォークギター/
folklore /フォルクローレ;(西語)/フォークロア/
folksong /フォークソング/
follifollie /フォリフォリ;www.follifollie.com/
follow /フォロー/フォロウ/
follower /フォロワー/
followthrough /フォロースルー/
followup /フォローアップ/
folly /フォリー/
foma /フォーマ;[商標]NTT DoCoMo/
fond /フォンド/フォン;仏語/
fondant /フォンダン/
fonddeveau /フォンドボー;fond de veau/
fondu /フォンデュ/
fondue /フォンデュ/
fons /フォンス/
font /フォント/
fontaine /フォンテーヌ;(Fr)泉/
fontainebleau /フォンテーヌブロー/フォンテンブロー/
fontana /フォンタナ/
fontlist /フォントリスト/
fontpath /フォントパス/
fontserver /フォントサーバ/フォントサーバー/
fontset /フォントセット/
fontsize /フォントサイズ/
food /フード/
foodprocessor /フードプロセッサー/フードプロセッサ/
foods /フーズ/
fool /フール/
foolproof /フールプルーフ/
fools /フールズ/
foot /フット/
football /フットボール/
footbath /フットバス/
footer /フッタ/フッター/
footlight /フットライト/
footnote /¶/フットノート/
footpedal /フットペダル/
footprint /フットプリント/
footrest /フットレスト/
footware /フットウェア/
footwork /フットワーク/
for /フォア/
forall /∀/
forbes /フォーブス/
force /フォース/
forceout /フォースアウト/
forcus /フォーカス/
ford /フォード/
fore /フォア/
foreground /フォアグラウンド/
forehand /フォアハンド/
foreign /フォーリン/
foreman /フォアマン/フォーマン/
forest /フォレスト/
forestcat /フォレストキャット/
forester /フォレスター/
foret /フォレ;(Fr) 森/
forever /フォーエバー/フォーエヴァー/
fork /フォーク/
forkball /フォークボール/
forklift /フォークリフト/
form /フォーム/
formal /フォーマル/形式的/
formaldehyde /ホルムアルデヒド/
formaldress /フォーマルドレス/
formaline /ホルマリン/
formalism /フォルマリズム/フォーマリズム/
formalize /フォーマライズ/
formalwear /フォーマルウェア/
formamide /ホルムアミド/
forman /フォアマン/
formant /フォルマント/ホルマント/
format /フォーマット/形式/
formation /フォーメーション/
formatstring /フォーマットストリング/
formatter /フォーマッタ/
formatting /フォーマッティング/
forme /フォルム/
formfactor /フォームファクタ/
forming /フォーミング/
formula /フォーミュラ/論理式/
fort /フォート/
forte /フォルテ/
fortepiano /フォルテピアノ/
fortessimo /フォルテッシモ/
fortis /フォルティス/
fortran /フォートラン/
fortress /フォートレス/
fortune /フォーチュン/
fortunecookie /フォーチュンクッキー;What a pity, you cannot read it!/
fortworth /フォートワース/
forum /フォーラム/
forval /フォーバル/
forward /フォワード/
forwarder /フォワーダー/フォワーダ/フォーワーダ/
forwarding /フォワーディング/
forword /フォワード;※forward/
foster /フォスター/
foucault /フーコー/
foul /ファール/ファウル/
foulball /ファールボール/ファウルボール/
foulfly /ファールフライ/
foultip /ファールチップ/ファウルチップ/
found /ファウンド/
foundation /ファンデーション/ファウンデーション/
founder /ファウンダー/
foundry /ファウンドリ/
fountain /ファウンテン/
four /フォー/フォア/
fourball /フォアボール/
fourbeat /フォービート/
fourier /フーリエ/
fournier /フルニエ/
fourre /フーレ/
fourree /フーレ/
fourteen /フォーティーン/
fourth /フォース/
fourty /フォーティ/
fox /フォックス/
foxtrot /フォックストロット/
foxy /フォクシー/
foyer /ホワイエ/
fp /フォルテピアノ;強く、ただちに弱く/forte piano/
fr /フランシウム/Francium/
fractal /フラクタル/
fragile /フラジャイル/
fragment /フラグメント/
fragmentation /フラグメンテーション/
fragrance /フレグランス/フラグランス/
fraiche /フレーシュ;(Fr) <frais/
frais /フレ;(Fr) 新鮮な/
fraise /フライス/
framboise /フランボワーズ;(Fr)木苺/
frame /フレーム/フレイム/
framebuffer /フレームバッファ/
framedrum /フレームドラム/
framein /フレームイン/
frameless /フレームレス/
frameout /フレームアウト/
framerelay /フレームリレー/
framework /フレームワーク/
framing /フレーミング/
fran /フラン/
franc /フラン/フランク/
franca /フランカ/
francais /フランセ/
francaise /フランセーズ/
france /フランス;.fr/仏蘭西/佛蘭西/
francebed /フランスベッド;www.francebed.co.jp/
francegp /フランスGP;[F1]/
francepain /フランスパン;和製仏語(baguette)/
frances /フランシス/フランセス/
francesca /フランチェスカ/
francesco /フランチェスコ/
francewine /フランスワイン;vin francais/
franchise /フランチャイズ/
francine /フランシーヌ/
francis /フランシス/
francisco /フランシスコ/
francium /フランシウム;[元素]87,Fr/
franck /フランク/
franco /フランコ/
francois /フランソワ/
francoise /フランソワーズ/
frank /フランク/
franka /フランカ/
franken /フランケン/
frankenstein /フランケンシュタイン/
frankfurt /フランクフルト/
frankie /フランキー/
frankl /フランクル/
franklin /フランクリン/
franky /フランキー/
frannie /フラニー/
franny /フラニー/
frantz /フランツ/
franz /フランツ/
frappe /フラッペ/
fraser /フレイザー;豪州/フレーザー/
fraternite /フラテルニテ;(Fr)同胞愛/
frau /フラウ;(独語)女性/フロー/
fraulein /フロイライン;(独語)未婚女性/
frazer /フレイザー/フレーザー/
freak /フリーク/
freaks /フリークス/
freaky /フリーキー/
frebel /フレーベル/
fred /フレッド/
freda /フリーダ/
freddi /フレディ/フレディー/
freddie /フレディ/フレディー/
freddy /フレディ/フレディー/
frederic /フレデリック/
frederica /フレデリカ/
frederick /フレデリック/
free /フリー/
free-software /フリーソフトウェア/
freeaccess /フリーアクセス/
freeagent /フリーエージェント;FA/
freebatting /フリーバッティング/
freecell /フリーセル/
freeclimbing /フリークライミング/
freecup /フリーカップ;和製英語/
freed /フリード/
freedial /フリーダイヤル/フリーダイアル/
freedman /フリードマン/
freedom /フリーダム/
freefall /フリーフォール/
freehand /フリーハンド/
freejazz /フリージャズ/
freekick /フリーキック/
freelance /フリーランス/
freelancer /フリーランサー/
freelist /フリーリスト/
freemail /フリーメール/
freeman /フリーマン/
freemarket /フリーマーケット;自由市場(≠flea market)/
freemason /フリーメーソン/フリーメイソン/
freepage /フリーページ/
freepaper /フリーペーパー/
freepass /フリーパス/
freepath /フリーパス/
freeplan /フリープラン/
freeradical /フリーラジカル/
freerider /フリーライダー/
freerun /フリーラン/
freeschool /フリースクール/
freesex /フリーセックス;和製英語/
freesia /フリージア/
freesize /フリーサイズ;和製英語(one-size-fits-all)/
freesoft /フリーソフト/
freesoftware /フリーソフトウェア/フリーソフトウエア/
freespace /フリースペース/
freestyle /フリースタイル/
freetalk /フリートーク/
freeter /フリーター;和製英語(part-time)/
freethrow /フリースロー/
freetime /フリータイム/
freetown /フリータウン/
freeware /フリーウェア/
freeword /フリーワード;和製英語/
freewriter /フリーライター;和製英語(freelance writer)/
freeze /フリーズ/
freezedry /フリーズドライ/
freezer /フリーザー/
freezing /フリージング/
frege /フレーゲ/
frei /フライ/フレイ/
freiburg /フライブルク/
freight /フレート/フレイト/
freire /フレイレ/
french /フレンチ/フランス語/
frenchbulldog /フレンチブルドッグ/
frenchdressing /フレンチドレッシング/
frenchfry /フレンチフライ/
frenchhorn /フレンチホルン/
frenchkiss /フレンチキス/
frenchrestaurant /フレンチレストラン/
frenchtoast /フレンチトースト/
frequency /フリークエンシー/
frere /フレール;(Fr)兄弟/
fresco /フラスコ/フレスコ/Fresco/
fresh /フレッシュ/
freshjuice /フレッシュジュース/
freshman /フレッシュマン/
freshness /フレッシュネス/
fret /フレット/
fretless /フレットレス/
freud /フロイト/
freund /フロイント/
frey /フレイ/
fri /金/
friand /フリアン/
fricasse /フリカッセ/
friction /フリクション/
frida /フリーダ/
friday /フライデー/フライデイ/フライディ/
fried /フライド/フリード/
frieda /フリーダ/
friedchicken /フライドチキン/
friedel /フリーデル/
friedman /フリードマン/
friedpotato /フライドポテト;fried potatoes/
friedrich /フリードリヒ/フリードリッヒ/
friend /フレンド/
friendly /フレンドリー/フレンドリ/
friends /フレンズ/
friendship /フレンドシップ/
frigate /フリゲート/
fright /フライト/
frill /フリル/
fringe /フリンジ/
fripper /フリッパー/
frisbee /フリスビー/
frisky /フリスキー/
frit /フリット/
frite /フリット/
fritter /フリッター/
fritz /フリッツ/
frock /フロック/
frockcoat /フロックコート/
frodo /フロド/
frog /フロッグ/
frois /フロイス/
from /フロム/
fromage /フロマージュ;(Fr)チーズ/
fromentin /フロマンタン/
fromm /フロム/
front /フロント/
frontale /フロンターレ;[Jリーグ]川崎/
frontdoor /フロントドア/
frontend /フロントエンド/
frontglass /フロントガラス/
fronthook /フロントホック/
frontier /フロンティア/
frontlight /フロントライト/
frontline /フロントライン/
frontpage /フロントページ/
frontpanel /フロントパネル/
frontpocket /フロントポケット/
frontrow /フロントロー/
frontrunner /フロントランナー/
frontside /フロントサイド/
frost /フロスト/
frostglass /フロストガラス/
frottage /フロッタージュ/
frown /⌒/
frozen /フローズン/
fructose /フルクトース/
fruit /フルーツ/フルート/フリュイ;仏語/
fruitcake /フルーツケーキ/
fruitjelly /フルーツゼリー/
fruitjuice /フルーツジュース/
fruitparfait /フルーツパフェ/
fruitpunch /フルーツポンチ/
fruits /フルーツ/
fruitsbasket /フルーツバスケット/
fruitscake /フルーツケーキ;fruitcake/
fruitsjuice /フルーツジュース/
fruitsparfait /フルーツパフェ/
fruitsparlour /フルーツパーラー/
fruitswine /フルーツワイン/
fruitwine /フルーツワイン/
fruity /フルーティ/
frunze /フルンゼ/
frustration /フラストレーション/
fry /フライ/
frye /フライ/
fryer /フライヤー/
frypan /フライパン;fry pan/
fsf /Free Software Foundation/FSF/
ftp /FTP/
ftpserver /FTPサーバ/
ftpsite /FTPサイト/
ftype /Fタイプ/Ｆタイプ/
fuchsia /フクシア/
fuck /ファック/
fucker /ファッカー/
fuckin /ファッキン;fuckin'/
fucose /フコース/
fucus /フーカス/
fudge /ファッジ/
fuego /フエゴ/
fuel /フューエル/フュエル/
fuga /フーガ/
fuji /フジ/
fujifilm /富士フイルム;www.fujifilm.co.jp/富士写真フイルム/フジフイルム/
fujitsu /富士通/
fujitv /フジテレビ;www.fujitv.co.jp/
ful /フル/
fulbright /フルブライト/
fulda /フルダ/
fulfil /フルフィル/
fulfill /フルフィル/
full /フル/一杯/
full-time /フルタイム/
fullaccess /フルアクセス/
fullalbum /フルアルバム/
fullauto /フルオート;full-automatic/
fullback /フルバック/
fullbase /フルベース;和製英語(bases loaded)/
fullbrowser /フルブラウザ/
fullcast /フルキャスト/
fullcity /フルシティ/フルシティー/
fullcolor /フルカラー/
fullcolour /フルカラー/
fullcontents /フルコンテンツ/
fullcount /フルカウント/
fullcourse /フルコース/
fuller /フラー/
fullerene /フラーレン;C60/
fullface /フルフェイス;full-face/
fullhouse /フルハウス/
fullinstall /フルインストール/
fullkeyboard /フルキーボード/
fullmarathon /フルマラソン/
fullmark /フルマーク/
fullmember /フルメンバー/
fullmesh /フルメッシュ/
fullmetal /フルメタル/
fullmoon /フルムーン/
fullname /フルネーム/
fullnude /フルヌード/
fullpath /フルパス/
fullpitch /フルピッチ/
fullpower /フルパワー/
fullrange /フルレンジ/
fullscale /フルスケール/
fullscore /フルスコア/
fullscratch /フルスクラッチ/
fullscreen /フルスクリーン/
fullseason /フルシーズン/
fullset /フルセット/
fullshot /フルショット/
fullsize /フルサイズ/
fullswing /フルスイング/
fullthrottle /フルスロットル/
fulltime /フルタイム/
fulltower /フルタワー/
fullversion /フルバージョン/
fully /フリー/
fumble /ファンブル/ハンブル/
fume /ヒューム/フューム/
fun /ファン/
funafuti /フナフティ/
funckey /ファンクションキー/
function /ファンクション/機能/関数/
functional /ファンクショナル/汎関数/
functionkey /ファンクションキー/
fund /ファンド/
fundamental /ファンダメンタル/
fundamentalism /ファンダメンタリズム;原理主義/
fundamentalist /ファンダメンタリスト;原理主義者/
fundamentals /ファンダメンタルズ/
funeral /フューネラル/
fungi /フンギ/
funk /ファンク/
funky /ファンキー/
funny /ファニー/
fur /ファー/
furan /フラン/
furio /フリオ/
furlong /ハロン/ファーロング/
furniture /ファニチャー/ファーニチャー/
further /ファーザー/
furtwangler /フルトヴェングラー/
fusco /フスコ/
fuse /ヒューズ/フューズ/
fusion /フュージョン/
futsal /フットサル/
future /フューチャー/フューチャ/
fuzzy /ファジー/ファジィ/
fyodor /フョードル/
g /γ;gamma/ジー/г;ge (cyrillic)/ゲー;(独語)/
ga /ガリウム/Gallium/Georgia/ジョージア/
gabardine /ギャバジン/
gabby /ガビー/ギャビー/
gabin /ギャバン/
gabon /ガボン;.ga/
gaborone /ハボローネ/
gabriel /ガブリエル/
gabriela /ガブリエラ/
gabriella /ガブリエラ/
gabrielle /ガブリエル/
gaby /ガビー/ゲイビー/
gacchan /ガッチャン/
gad /ガッド/
gadd /ガッド/
gadget /ガジェット/
gadolinium /ガドリニウム;[元素]64,Gd/
gaea /ガイア/
gael /ゲール/
gaff /ギャフ/ガフ/
gag /ギャグ/
gagarin /ガガーリン/
gagsense /ギャグセンス/
gaia /ガイア/
gail /ゲイル/ゲール/
gaillard /ガイヤール/ガイヤルド/
gaillarde /ガイヤルド/
gain /ゲイン/
gainax /ガイナックス;www.gainax.co.jp/
gainsbourg /ゲンズブール/
gal /ギャル/ガル/
gala /ガラ;仏語/ガーラ/ゲイラ;(英)/ギャラ/
galaconcert /ガラコンサート/
galact /ガラクト;(接頭辞)乳/
galactic /ギャラクティック/
galactose /ガラクトース/
galapagos /ガラパゴス/
galatea /ガラテア/
galatia /ガラテヤ/ガラテア/
galaxy /ギャラクシー/
galbraith /ガルブレイス/
gale /ゲイル/ゲール/
galette /ガレット/
galia /ガリア/
galicia /ガリシア/
galilaia /ガリラヤ/
galilei /ガリレイ/
galileo /ガリレオ/
galina /ガリーナ/
gall /ギャル/
galleria /ガレリア;(イタリア語)/
gallery /ギャラリー/
galley /ゲラ/ガレー;-船/ギャレー/
galli /ガリ/
gallia /ガリア/
galliano /ガリアーノ/
gallimard /ガリマール/
gallium /ガリウム;[元素]31,Ga/
galliver /ガリバー/
gallo /ガロ/
gallon /ガロン/
gallop /ギャロップ/
galo /ガロ/
galois /ガロワ/
gals /ギャルズ/
gamay /ガメ/
gamba /ガンバ;[Jリーグ]大阪/
gambia /ガンビア;.gm/
gamble /ギャンブル/
gambler /ギャンブラー/
gambling /ギャンブリング/
game /ゲーム/
gamebalance /ゲームバランス/
gamebook /ゲームブック/
gameboy /ゲームボーイ;[商標]任天堂/
gameboyadvance /ゲームボーイアドバンス;[商標]任天堂/
gameboymicro /ゲームボーイミクロ;[商標]任天堂/
gamebusiness /ゲームビジネス/
gamecenter /ゲームセンター/
gamecorner /ゲームコーナー/
gamecube /ゲームキューブ;[商標]任天堂/
gamelan /ガムラン/
gamemachine /ゲームマシン/
gamemaker /ゲームメーカー/
gamemaster /ゲームマスター/
gamemusic /ゲームミュージック/
gameover /ゲームオーバー/
gamepad /ゲームパッド/
gameplay /ゲームプレイ/
gamer /ゲーマー/
gamers /ゲーマーズ/
games /ゲームズ/
gameset /ゲームセット/
gameshow /ゲームショウ/
gamesoft /ゲームソフト;game software/
gamest /ゲーメスト/
gamestart /ゲームスタート/
gametitle /ゲームタイトル/
gamewatch /ゲームウォッチ;[商標]任天堂/
gaming /ゲーミング/
gamma /γ/ガンマ/γ版/
gammon /ギャモン/
ganache /ガナッシュ/
gandalf /ガンダルフ/
gandhara /ガンダーラ/
gandhi /ガンジー/ガンディー/
ganesha /ガネーシャ/
gang /ギャング/
ganga /ガンガー/
ganges /ガンジス/
gangster /ギャングスター/
ganja /ガンジャ/
ganttchart /ガントチャート;Gantt chart/
ganymede /ガニメデ/
ganymedes /ガニュメデス/
ganza /ガンザ/
gap /ギャップ/
garage /ガレージ/ガラージ;(原音に近い表記)/
garagekit /ガレージキット/
garagesale /ガレージセール/
garam /ガラム/
garammasala /ガラムマサラ/
garbage /ガベージ/ガーベージ/ガーベッジ/
garcia /ガルシア/
garcon /ギャルソン/
gard /ガール/
garden /ガーデン/
gardener /ガードナー/
gardening /ガーデニング/
gardenparty /ガーデンパーティ/
gardenplace /ガーデンプレイス;www.gardenplace.co.jp/
gardner /ガードナー/
gareth /ギャレス/
garfield /ガーフィールド/
garfunkel /ガーファンクル/
gargantua /ガルガンチュア/
gargoyle /ガーゴイル/
garhard /ゲルハルト/
garibaldi /ガリバルディ/
garland /ガーランド/
garlic /ガーリック/
garlicbutter /ガーリックバター/
garlictoast /ガーリックトースト/
garment /ガーメント/
garner /ガーナー/
garnet /ガーネット/
garnier /ガルニエ/
garonne /ガロンヌ/
garr /ゲール/
garret /ギャレット/
garrett /ギャレット/
garrison /ギャリソン/
garry /ゲイリー/
garter /ガーター/
garterbelt /ガーターベルト/
garuda /ガルーダ/ガルダ/
gary /ゲイリー/ゲーリー/
gas /ガス/瓦斯/ガソリン/
gasbombe /ガスボンベ;(独語)/
gasburner /ガスバーナー/
gascogne /ガスコーニュ/
gasket /ガスケット/
gasmask /ガスマスク/
gasmeter /ガスメーター/
gasoline /ガソリン/
gasolineengine /ガソリンエンジン/
gasolinestand /ガソリンスタンド;和製英語(gas station)/
gaspard /ガスパール/ガスパル/
gasrange /ガスレンジ/
gasstove /ガスストーブ/
gastable /ガステーブル;和製英語/
gastank /ガスタンク/
gaston /ガストン/
gastronomie /ガストロノミー;仏語/
gastronomy /ガストロノミー/
gasturbine /ガスタービン/
gate /ゲート/
gatearray /ゲートアレイ/
gateau /ガトー/
gateauchocolat /ガトーショコラ/
gateball /ゲートボール/
gatecity /ゲートシティ;大崎/
gatekeeper /ゲートキーパー/
gates /ゲイツ/
gateway /ゲートウェイ/
gather /ギャザー/ギャザ/
gathering /ギャザリング/
gatsby /ギャツビー/
gatt /ガット;General Agreement on Tariffs and Trade/
gatti /ガッティ/
gattuso /ガットゥーゾ/
gauche /ゴーシュ/
gaucho /ガウチョ/
gaudi /ガウディ/
gaudy /ゴーディ/
gaufre /ゴーフル/
gaufrette /ゴーフレット/
gauge /ゲージ/
gauguin /ゴーギャン/ゴーガン/
gaul /ゴール/
gauloise /ゴロワーズ/
gaultier /ゴルチェ;www.jeanpaul-gaultier.com/
gauntlet /ガントレット/
gauss /ガウス/
gaussian /ガウシアン/
gautier /ゴーティエ/ゴーチェ/ゴーチエ/
gauze /ガーゼ/
gavin /ガビン/ギャビン/ギャヴィン/
gavotte /ガボット/ガヴォット/
gawein /ガウェイン/
gay /ゲイ/ガイ/
gaya /ガヤ/
gaybar /ゲイバー/
gaze /ガーゼ;(独語)/
gazelle /ガゼル/
gazette /ガゼット/
gazpacho /ガスパチョ/ガスパッチョ/ガスパーチョ/
gb /ＧＢｙｔｅ/
gc /ガーベッジ・コレクション/グラフィク・コンテキスト/
gcc /Gcc/
gcl /GCL/
gcup /Gカップ;25cm/Ｇカップ/
gd /ガドリニウム/Gadolinium/
ge /г;cyrillic/≧/ゲルマニウム/Germanium/
gear /ギア/ギヤ/
gearbox /ギアボックス/
gearchange /ギアチェンジ/
gecko /ゲッコー;ヤモリ/
ged /ゲド/
gee /ジー/
geek /ジーク/
geen /ジーン/
geena /ジーナ/
gefitinib /ゲフィチニブ;NB:通称Iressa/
gehennom /ゲヘナ/
gehry /ゲーリー/
geiger /ガイガー/
geigercounter /ガイガーカウンター/
geist /ガイスト/
gel /ジェル/ゲル/
gelande /ゲレンデ;(独語)/
gelatin /ゼラチン/
gelatine /ゼラチン/
gelato /ジェラート;(It)アイスクリーム/
gelee /ジュレ;(Fr) ゼリー/
gelette /ガレット/
geller /ゲラー/
gelly /ゲリー/
gelsomina /ジェルソミーナ/
gem /ジェム/
gema /ジェマ/
gemclip /ゼムクリップ/
gemeinschaft /ゲマインシャフト/
gemini /ジェミニ/
gemma /ジェンマ/ジェマ/
gender /ジェンダー/
genderfree /ジェンダーフリー;和製英語/
gene /ジーン/ジェネ/
genecon /ゼネコン;general contractor/
genepro /ゲネプロ;<Generalprobe/
general /ゼネラル/ジェネラル/
generalist /ゼネラリスト/ジェネラリスト/
generalmanager /ゼネラルマネージャー;GM/
generate /ジェネレート/
generation /ジェネレーション/
generationgap /ジェネレーションギャップ;generation gap/
generator /ジェネレータ/ジェネレーター/
generic /ジェネリック/
genesis /ジェネシス/
genet /ジュネ/
genetic /ジェネティック/
geneticalgorithms /ジェネティックアルゴリズム/
genetics /ジェネティクス/ジェネティックス/
geneticsystem /ジェネティックシステム/
geneve /ジュネーブ/ジュネーヴ/
genevieve /ジュヌヴィエーヴ/ジュヌビエーブ/
genghiskhan /ジンギスカン;Genghis Khan/成吉思汗/
genie /ジニー/ジェニー;仏語/
genius /ジーニアス/
genoa /ゼノア;genovaの英語読み/ジェノア/ジェノバ/ジェノヴァ/
genocide /ジェノサイド/
genoise /ジェノワーズ/
genom /ゲノム/
genome /ゲノム/
genova /ジェノバ/ジェノヴァ/
genre /ジャンル/
gentle /ジェントル/
gentleman /ジェントルマン/ゼントルマン/
gentlemen /ジェントルメン/
gently /ジェントリー/ジェントリィ/
gentzen /ゲンツェン/
geo /ジオ/
geoff /ジェフ/
geoffrey /ジェフリー/
geography /ジオグラフィ/ジオグラフィー/
geoid /ジオイド/
geometry /ジオメトリ/ジオメトリー/
geopotential /ジオポテンシャル/
georg /ゲオルク/ゲオルグ/
george /ジョージ/ジョルジュ/ゲオルゲ/
georgemason /ジョージ・メイソン大学/
georges /ジョルジュ/
georgetown /ジョージタウン/
georgette /ジョーゼット/
georgia /ジョージア/グルジア;.ge/
georgie /ジョルジ/ジョージー/
georgii /ゲオルギー/ゲオールギー/
georgina /ジョージナ/
geq /≧/
gera /ゲーラ/
gerald /ジェラルド/
geraldine /ジェラルディン/ジェラルダイン/
geraniol /ゲラニオール/
geranium /ゼラニウム/
gerard /ジェラルド/ジェラード/ジェラール/
gerardo /ヘラルド/ジェラルド/
gerbera /ガーベラ/
gerd /ゲルト/
gerda /ゲルダ/
gere /ギア/
gerhard /ゲルハルト/
geri /ジェリ/
gericault /ジェリコ/ジェリコー/
gerin /ゲラン/
germain /ジェルマン/
german /ジャーマン/ドイツ/ゲルマン/ヘルマン/
germane /ゲルマン/
germania /ゲルマニア/
germanium /ゲルマニウム;[元素]32,Ge/
germansuplex /ジャーマンスープレックス/
germany /ドイツ/
geronimo /ジェロニモ/
gerrard /ジェラード/
gerry /ジェリー/ゲリー/
gershwin /ガーシュイン/ガーシュウィン/
gertie /ガーティ/
gertrude /ガートルード/
gesellschaft /ゲゼルシャフト/
gestalt /ゲシュタルト/
gestapo /ゲシュタポ/
gesture /ジェスチャー/
gesturegame /ジェスチャーゲーム/
get /ゲット/得る/
getaway /ゲッタウェイ/
gethsemane /ゲッセマネ/
getmethod /GETメソッド/
gets /ゲッツ/
getter /ゲッター/ゲッタ/
getting /ゲッティング/
gettwo /ゲッツー/
gettysburg /ゲティスバーグ/
getz /ゲッツ/
gewalt /ゲバルト;(独語)暴力/
geyer /ガイヤー/
gfx /グラフィックス;graphics/
gfxboard /グラフィックボード;graphic board/
gfxcard /グラフィックカード;graphic card/
gfxdesign /グラフィックデザイン/
gfxdesigner /グラフィックデザイナー/
gg /≫/
ggtp /γGTP;γ-glutamyl transpeptitase/
ghana /ガーナ;.gh/
ghazza /ガザ/
ghee /ギー/
ghetto /ゲットー;(イタリア語)/
ghibli /ジブリ/
ghosn /ゴーン/
ghost /ゴースト/
ghosttown /ゴーストタウン/
ghostwriter /ゴーストライター/
giacometti /ジャコメッティ/
giacomo /ジャコモ/
gian /ジャン/
giancarlo /ジャンカルロ/
gianfranco /ジャンフランコ/
gianluca /ジャンルカ/
gianluigi /ジャンルイジ/ジャン・ルイジ/
gianna /ジャンナ/
giannini /ジャンニーニ/
giant /ジャイアント/
giantpanda /ジャイアントパンダ/
giants /ジャイアンツ/
gibberellin /ジベレリン/
gibbs /ギブス/
gibernau /ジベルナウ/
gibraltar /ジブラルタル;.gi/
gibson /ギブソン/ギブスン/
gid /グループID/
gide /ジッド/ジイド/ジード/
gideon /ギデオン/
gien /ジアン/
gifanimation /GIFアニメーション/
gifanime /GIFアニメ/
giffile /GIFファイル/
gift /ギフト/
giftbox /ギフトボックス/
giftcard /ギフトカード/
giftcorner /ギフトコーナー/
giftset /ギフトセット/
giftshop /ギフトショップ/
giftwrapping /ギフトラッピング/
gig /ギグ/
giga /ギガ;G,10^9/
gigabit /ギガビット/
gigabyte /ギガバイト/
gigabytes /ギガバイト/
gigantes /ギガンテス/
giger /ギーガー/
gigi /ジジ/
gigolo /ジゴロ/
gigue /ジグ/ジーグ/
gil /ジル/ギル/ヒル/
gila /ギラ/
gilardino /ジラルディーノ/
gilbert /ギルバート/ジルベール/
gilberto /ジルベルト/
gile /ガイル/
giles /ジャイルズ/
gilgamesh /ギルガメッシュ/ギルガメシュ/
gill /ジル/ギル/
gilles /ジル/
gillespie /ガレスピー/
gillette /ジレット/
gillian /ジリアン/ギリアン/
gillie /ギリー/
gilly /ギリー/
gilmour /ギルモア/
gilyak /ギリヤーク/
gimlet /ギムレット/
gimmick /ギミック/
gin /ジン/
gina /GINA(the Generic Interactive Application)/ジーナ/ジナ/
ginette /ジネット/
ginfizz /ジンフィズ/
ginger /ジンジャー/
gingerale /ジンジャーエール/ジンジャエール/
gingham /ギンガム/
ginghamcheck /ギンガムチェック/
ginn /ギン/
ginny /ジニー/
gino /ジーノ/ジノ/
ginsberg /ギンズバーグ/
gintonic /ジントニック;和製英語(gin and tonic)/
gioconda /ジョコンダ/
giocoso /ジョコーソ/
giordano /ジョルダーノ/
giorgio /ジョルジオ/ジョルジョ/
giotto /ジョット/ジオット/
giovanna /ジョヴァンナ/ジョバンナ/
giovanni /ジョヴァンニ/ジョバンニ/
gips /ギプス;(独語)/
giraffu /ジラフ;※giraffe?/
giraldo /ジラルド/
giraud /ジロー/
girdle /ガードル/
girl /ガール/
girlfriend /ガールフレンド/
girlish /ガーリッシュ/
girls /ガールズ/
girlscout /ガールスカウト/
girly /ガーリー/
girolamo /ジローラモ/
gironde /ジロンド/
gisele /ジゼル/
giselle /ジゼル/
gitanes /ジタン/
giulia /ジュリア/
giuliano /ジュリアーノ/
giulietta /ジュリエッタ/
giulini /ジュリーニ/
giuseppe /ジュゼッペ/
giveandtake /ギブアンドテイク;give-and-take/
given /ギブン/
givency /ジバンシー/
giveup /ギブアップ/
glace /グラッセ/
glad /グラッド/
gladiator /グラディエーター/
gladiolus /グラジオラス/
gladys /グラディス/
glaive /グレイブ/グレイヴ/
glamor /グラマー/
glamorous /グラマラス/
glamour /グラマー/
glamourous /グラマラス/
glare /グレア/
glasgow /グラスゴー/
glasnost /グラスノスチ/
glass /グラス/ガラス/硝子/
glassblock /ガラスブロック/
glassboat /グラスボート/
glasscase /ガラスケース/
glassfiber /グラスファイバー/
glassharp /グラスハープ/
glasslens /ガラスレンズ/
glasstable /ガラステーブル/
glasstop /ガラストップ/
glasswool /グラスウール/
glaze /グレイズ/グレーズ/
glazunov /グラズノフ/
glee /グリー/
gleeclub /グリークラブ/
glen /グレン/
glencheck /グレンチェック/
glenda /グレンダ/
glenn /グレン/
glia /グリア/
glico /グリコ;www.glico.co.jp/
glider /グライダー/
gliss /グリス;[音楽]/
glissade /グリセード/
glitch /グリッチ/
glitter /グリッター/
global /グローバル/
globaladdress /グローバルアドレス/
globaldatafile /グローバルデータファイル/
globalip /グローバルIP/
globalisation /グローバリゼーション/
globalism /グローバリズム/
globalization /グローバリゼーション/
globalmemory /グローバルメモリ/
globalstandard /グローバルスタンダード/
globalstd /グローバルスタンダード;global standard/
globe /グローブ/
globin /グロビン/
globulin /グロブリン/
glocal /グローカル/
glock /グロック/
glocken /グロッケン/
glockenspiel /グロッケンシュピール/
gloom /グルーム/
gloomy /グルーミー/
gloria /グロリア/グローリア/
glorious /グロリアス/グローリアス/
glory /グローリー/
glossary /グロッサリー/
glove /グローブ/グラブ/グローヴ/
glover /グローバ/グラバー/グローバー/
glow /グロー;白熱/グロウ/
glucan /グルカン/
gluck /グルック/
gluco /グルコ/
glucomannan /グルコマンナン/
glucosamine /グルコサミン/
glucose /グルコース/
glue /グルー/
gluhwein /グリューワイン/グリューヴァイン/
gluon /グルーオン/グルオン/
glutamine /グルタミン;Gln/
glutathion /グルタチオン/
gluten /グルテン/
glycan /グリカン/
glycerin /グリセリン/
glycerine /グリセリン/
glycerol /グリセロール/グリセリン;glycerin/
glyceryl /グリセリル/
glycine /グリシン;Gly/
glycogen /グリコーゲン/
glycol /グリコール/
glycoside /グリコシド/
glycyrrhizin /グリチルリチン/
glykogen /グリコーゲン;(独語)/
glykol /グリコール;(独語)/
glyme /グリム/
glyph /グリフ/
gmd /GMD(German National Research Center for Computer Science)/
gmen /Ｇメン/Gメン/
gmt /グリニッジ標準時/GMT/
gnome /ノーム/
gnosis /グノーシス/
gnossienne /グノシェンヌ/グノシエンヌ/
gnu /ヌー;[動物]/グヌー;GNU is not unix/グニュー/GNU/
gnus /ニューズ/Ｇｎｕｓ/ｇｎｕｓ/GNUS/Gnus/
go /ゴー/
goa /ゴア/
goal /ゴール/
goalarea /ゴールエリア/
goalin /ゴールイン;和製英語/
goalkeeper /ゴールキーパー/
goalkick /ゴールキック/
goalline /ゴールライン/
goalpost /ゴールポスト/
gobi /ゴビ/
goblet /ゴブレット/
goblin /ゴブリン/
gocart /ゴーカート/
god /ゴッド/ガッド/
godard /ゴダール/
goddamn /ガッデム/
goddard /ゴダード/ゴッダード/
godel /ゲーデル/
godfather /ゴッドファーザー/
godiva /ゴディバ/
godmother /ゴッドマザー/
godot /ゴドー/
godwin /ゴドウィン/
godzilla /ゴジラ/
goebbels /ゲッベルス/ゲッペルス;※ゲッ「ベ」ルスの方が正確/
goedel /ゲーデル/
goes /ゴーズ/
goethe /ゲーテ/
goggle /ゴーグル/
gogh /ゴッホ/
gogo /ゴーゴー/
gogol /ゴーゴリ/
going /ゴーイング/
golan /ゴラン/
gold /ゴールド/
goldberg /ゴールドバーグ/ゴルトベルク/ゴールドベルグ/
goldcard /ゴールドカード/
goldcoast /ゴールドコースト;Gold Coast, オーストラリア(ool)/
goldcollar /ゴールドカラー/
golddisk /ゴールドディスク/
golden /ゴールデン/
goldencross /ゴールデンクロス/
goldeneagles /ゴールデンイーグルス/
goldenglove /ゴールデングラブ;NB:MLBのは Gold Glove/
goldenretriever /ゴールデンレトリバー/ゴールデンレトリーバー/ゴールデンリトリバー/
goldentime /ゴールデンタイム/
goldenweek /ゴールデンウィーク/
goldglove /ゴールドグラブ;Gold Glove/
goldie /ゴールディ/
goldman /ゴールドマン/
goldrush /ゴールドラッシュ/
goldsmith /ゴールドスミス/
goldstone /ゴールドストーン/
golem /ゴーレム/
golf /ゴルフ/
golfbag /ゴルフバッグ/
golfball /ゴルフボール/
golfclub /ゴルフクラブ/
golfcourse /ゴルフコース/
golfer /ゴルファー/
golfgame /ゴルフゲーム/
golfresort /ゴルフリゾート/
golfshoes /ゴルフシューズ/
golfshop /ゴルフショップ/
golfware /ゴルフウェア/
golgotha /ゴルゴタ/
goliath /ゴリアテ/
golo /ゴーロ/
gom /ゴム;(蘭語)/
gomes /ゴメス/
gomez /ゴメス/
gommage /ゴマージュ/
gomorrha /ゴモラ/
goncourt /ゴンクール/
gondola /ゴンドラ/
gone /ゴーン/
gong /ゴング/
gonzales /ゴンザレス/
gonzalez /ゴンザレス/ゴンサレス/
gonzalo /ゴンサロ/
goo /グー;www.goo.ne.jp/
good /グッド/グー/
good-bye /グッド・バイ/
goodbye /グッバイ/グッドバイ/
gooddesign /グッドデザイン/
goodjob /グッジョブ/
goodluck /グッドラック/
goodman /グッドマン/
goodmorning /グッドモーニング/
goodnight /グッドナイト/グッナイ/グンナイ/
goods /グッズ/
goodtiming /グッドタイミング/
goodwill /グッドウィル/
goodwin /グッドウィン/
goody /グッディ/
goodyear /グッドイヤー;www.goodyear.com/グッドイアー;<rare>/
google /グーグル;www.google.com/
goose /グース/
gopher /ゴーファー/
goran /ゲラン/ゴラン/
gorbachev /ゴルバチョフ/
gordon /ゴードン/
gore /ゴア/
goretex /ゴアテックス;[商標]/
gorge /ゴルジュ/
gorgeous /ゴージャス/
gorgias /ゴルギアス/
gorgo /ゴルゴ;13/
gorgon /ゴルゴン/
gorgonzola /ゴルゴンゾーラ/
gorilla /ゴリラ/
gorkii /ゴーリキー/ゴーリキイ/
gosign /ゴーサイン/GOサイン/
gospel /ゴスペル/
gossip /ゴシップ/
gotama /ゴータマ/瞿曇/
goteborg /エーテボリ;スウェーデン/ヨーテボリ/イェーテボリ/イェテボリ/
goth /ゴート/
gothenburg /イェテボリ/
gothic /ゴシック/
gothiclolita /ゴシックロリータ/ゴスロリ/
gothloli /ゴスロリ;gothic lolita/
gottfried /ゴットフリート/
gottingen /ゲッティンゲン/
gouache /ガッシュ/グワッシュ/グアッシュ/
gouda /ゴーダ/
goudacheese /ゴーダチーズ/
gould /グールド/
gounod /グノー/
gourmand /グルマン/
gourmet /グルメ/
governance /ガバナンス/
government /ガバメント/
governor /ガバナー/
gown /ガウン/
goya /ゴヤ/
gpan /ジーパン;和製英語(jeans)/Ｇパン/Gパン/
gpl /GPL/
gpllicence /GPLライセンス;NB:general public licence licence/
gpllicense /GPLライセンス;NB:general public license license/
grab /グラブ/
grabber /グラバー/
grace /グレース/グレイス/
graceful /グレイスフル/グレースフル/
gracia /グラシア/
gracias /グラシアス;(西語)/
gracie /グレイシー/
gracious /グレイシャス/
gracq /グラック/
grad /グラード/グラッド/
gradation /グラデーション/
grade /グレード/グレイド/
gradedown /グレードダウン/
gradeup /グレードアップ/グレイドアップ/
gradient /グラディエント/
gradius /グラディウス;[ゲーム]コナミ/
graduate /グラデュエート/大学院生/
graf /グラフ/
graffiti /グラフィティ/
graham /グラハム/グレアム/
grain /グレン/グレイン/グレーン/
gram /グラム/
grammar /グラマー/
gramme /グラム/
grammy /グラミー/
grampus /グランパス;[Jリーグ]名古屋/
grampuseight /グランパスエイト;[Jリーグ]名古屋/
gramsci /グラムシ/
gran /グラン/
granada /グラナダ/
granados /グラナドス/
grand /グランド/グラン;仏語/
grandcanyon /グランドキャニオン;Grand Canyon/
grandcru /グランクリュ;grand cru/
granddesign /グランドデザイン/
grande /グランデ/
grandfinale /グランドフィナーレ/
grandhotel /グランドホテル/
grandi /グランディ/
grandioso /グランディオーソ/
grandmarnier /グランマルニエ;(Fr) grand marnier/
grandmaster /グランドマスター;grand master/
grandopen /グランドオープン/
grandopera /グランドオペラ/
grandpiano /グランドピアノ/
grandprix /グランプリ;grand prix/
grandslam /グランドスラム/
grandvin /グランヴァン/
grange /グランジェ/
granite /グラニット/グラニテ;(Fr)氷菓/
grant /グラント/
granular /グラニュラー/
granville /グランビル/グランヴィル/
grape /グレープ/
grapefruit /グレープフルーツ/
grapefruits /グレープフルーツ/
graph /グラフ/
graphic /グラフィック/グラフィク/
graphica /グラフィカ/
graphicaccelerator /グラフィックアクセラレータ/
graphical /グラフィカル/
graphicalinterface /グラフィカル・インターフェイス/
graphicboard /グラフィックボード/
graphiccard /グラフィックカード/
graphicdesign /グラフィックデザイン/
graphicdesigner /グラフィックデザイナー/
graphicer /グラフィッカー/
graphics /グラフィックス/グラフィクス/
graphite /グラファイト/
graphmatching /グラフマッチング/
graphy /グラフィ/グラフィー/
grappa /グラッパ/
grapple /グラップル/
grass /グラス/
grassbunker /グラスバンカー/
grasscourt /グラスコート/
grasshopper /グラスホッパー/
grassski /グラススキー/
gratin /グラタン/
grating /グレーチング/グレーティング/
grau /グラウ/
grave /グレイブ/グレイヴ/グラーヴ;仏語/グラーブ/グラーベ;(イタリア語)/
graves /グラーブ/
gravity /グラビティ/グラヴィティ/
gravure /グラビア/
gravureidol /グラビアアイドル/
gray /グレー/グレイ/
graycollar /グレーカラー/
grayhound /グレイハウンド/
grayout /グレーアウト/グレイアウト/
grayscale /グレースケール/グレイスケール/
grayzone /グレーゾーン/
graz /グラーツ/
graze /グレイズ/
grazia /グラツィア/
grazie /グラッチェ;(イタリア語)/
grazioso /グラツィオーソ/
grease /グリス/グリース/
great /グレート/グレイト/
greatbarrierreef /グレートバリアリーフ/
greatbritain /グレートブリテン;Great Britain/
greatdane /グレートデン/
greater /グレーター/グレイター/
greatest /グレーテスト/グレイテスト/
greco /グレコ/
grecoroman /グレコローマン/
gree /グリー;www.gree.jp/
greece /ギリシャ;.gr/ギリシア/グリース/
greeclub /グリークラブ;gree club/
greek /α;alpha/β;beta/γ;gamma/δ;delta/ε;epsilon/ζ;zeta/η;eta/θ;theta/ι;iota/κ;kappa/λ;lambda/μ;mu/ν;nu/ξ;xi/ο;omicron/π;pi/ρ;rho/σ;sigma/τ;tau/υ;upsilon/φ;phi/χ;chi/ψ;psi/ω;omega/グリーク/ギリシャ/
green /グリーン/
greenasparagus /グリーンアスパラガス/
greenbelt /グリーンベルト/
greenberet /グリーンベレー/
greencard /グリーンカード/
greene /グリーン/
greenfee /グリーンフィ/グリーンフィー/
greenhouse /グリーンハウス/
greenland /グリーンランド;.gl/
greenpeace /グリーンピース;www.greenpeace.org/
greenpeas /グリーンピース/
greenpepper /グリーンペッパー/
greenpia /グリーンピア/
greensleeves /グリーンスリーブス/グリーンスリーヴス/
greenspan /グリーンスパン/
greentea /グリーンティー/グリーンティ/
greenwich /グリニッジ/
greeting /グリーティング/
greetingcard /グリーティングカード/
greg /グレッグ/
gregor /グレゴール/
gregorio /グレゴリオ/
gregorius /グレゴリウス/
gregory /グレゴリー/
gremlin /グレムリン/
grenada /グレナダ;.gd/
grenade /グレネード/
grenier /グルニエ;(Fr)屋根裏部屋/
grenoble /グルノーブル/
grep /グレップ/
gresham /グレシャム/
gresia /ギリシャ;(<蘭語)/ギリシア/
greta /グレタ/
gretchen /グレートヒェン/グレッチェン/グレートヘン/
grete /グレーテ/
gretel /グレーテル/
grey /グレー/グレイ/
greycollar /グレーカラー/
greyhound /グレイハウンド/
greyout /グレーアウト/
greyscale /グレースケール/グレイスケール/
greyzone /グレーゾーン/
grid /グリッド/
griddle /グリドル/
grieg /グリーグ/
griffin /グリフィン/
griffis /グリフィス/
griffith /グリフィス/
griffon /グリフォン/
grill /グリル/
grillpan /グリルパン/
grim /グリム/
grimm /グリム/
grind /グラインド/
grinder /グラインダー/グラインダ/
griotte /グリオット/
grip /グリップ/
gripper /グリッパー/
grisaille /グリザイユ/
grissini /グリッシーニ/
grit /グリット/
gro /グロ;grotesque/
grocery /グローサリー/
groggy /グロッキー/
groom /グルーム/
groomer /グルーマー/
grooming /グルーミング/
groove /グルーヴ/グルーブ/
groovy /グルーヴィー/
gropius /グロピウス/
gross /グロス/
grossman /グロスマン/
grotesque /グロテスク/
ground /グランド/グラウンド/
grounder /グラウンダー/ゴロ/
grounding /グラウンディング/
groundzero /グラウンドゼロ;原爆の爆心/
group /グループ/
grouphome /グループホーム/
groupid /グループID/
grouping /グルーピング/
groupingeffect /グルーピング・エフェクト/
grouplesson /グループレッスン/
groupsounds /グループサウンズ/
groupware /グループウェア/
groupwork /グループワーク/
groupy /グルーピー/
grow /グロー;成長/グロウ/
growing /グローイング/
growl /グロール/
growth /グロース/グロウス/
grumman /グラマン/
grunge /グランジ/
grusin /グルーシン/
gruyere /グリュイエール/
gruziya /グルジア/
gryphon /グリフォン/
gs /ghostscript/
gspot /Ｇスポット;G-spot/Gスポット/
gt /＞/
gtype /Gタイプ/Ｇタイプ/
guadalajara /グアダラハラ/
guadalcanal /ガダルカナル/
guadeloupe /グアドループ;.gp/
guam /グアム;.gu/グァム/
guanidine /グアニジン/
guanine /グアニン;G/
guano /グアノ/
guanosine /グアノシン/
guantanamo /グアンタナモ;キューバ/
guarana /ガラナ/
guarantee /ギャランティー/ギャランティ/ギャラ/
guard /ガード/
guardian /ガーディアン/
guardman /ガードマン;和製英語(security guard)/
guardrail /ガードレール/
guatemala /グアテマラ;gt/グァテマラ/ガテマラ/
guattari /ガタリ/
guava /グァバ/グアバ/
guayaquil /グアヤキル;エクアドル(gye)/
gucci /グッチ;www.gucci.com/
guccio /グッチオ/
guerin /ゲラン/ゲリン/
guerlain /ゲラン;www.guerlain.com/
guernica /ゲルニカ/
guernsey /ガーンジー;.gg/
guerre /ゲール/
guerrilla /ゲリラ/
guess /ゲス/
guest /ゲスト/
guestbook /ゲストブック/
guesthouse /ゲストハウス/
guestroom /ゲストルーム/
guetre /ゲートル/
guevara /ゲバラ;Ernesto Che Guevara/
guggenheim /グッゲンハイム/
guglielmo /グリエルモ/
gui /グラフィカルユーザインターフェース/GUI/
guiana /ギアナ/
guidance /ガイダンス/
guide /ガイド/
guidebook /ガイドブック/
guideline /ガイドライン/
guidemap /ガイドマップ/
guidetour /ガイドツアー/
guideway /ガイドウェイ/
guido /グイド/ギド/グィード/
guild /ギルド/
guilder /ギルダー/
guile /ガイル/
guillaume /ギョーム/ギヨーム/
guillotine /ギロチン/
guilty /ギルティ/ギルティー/
guin /グイン/グウィン/グィン/
guinea /ギニア;.gn/
guineabissau /ギニアビサウ;Guinea-Bissau/
guinness /ギネス;www.guinness.ie/
guinnessbook /ギネスブック/
guiro /ギロ/
guitar /ギター/
guitaramp /ギターアンプ/
guitarist /ギタリスト/
guitarmagazine /ギターマガジン/
guitarsolo /ギターソロ/
guitarsynth /ギターシンセ/
gukbap /クッパ;(朝鮮語)/
gulda /グルダ/
gulf /ガルフ/
gull /ガル;かもめ/
gulose /グロース/
gum /ゴム/ガム/
gumband /ゴムバンド;rubber band/
gumbo /ガンボ;オクラ/
gumboat /ゴムボート/
gumhose /ゴムホース/
gumpacking /ゴムパッキン/
gumsyrup /ガムシロップ;gum syrup/
gumtape /ガムテープ;和製英語(packing tape)/
gun /ガン/
gundam /ガンダム;[アニメ]/
gunman /ガンマン/
gunnar /グンナー/
gunner /ガンナー/
gunter /ギュンター/
gunther /ギュンター/グンター/ガンサー/
guppy /グッピー/
gupta /グプタ/
gurkha /グルカ/
guru /グル/
gus /ガス/
gushose /ガスホース/
gust /ガスト;www.gust.co.jp/
gusta /グスタ/
gustaf /グスタフ/
gustav /グスタフ/
gustave /グスタフ/ギュスターヴ/ギュスターブ/
gusto /ガスト;英語/グスト;イタリア語)/ガストー/
gut /ガット/
gutenberg /グーテンベルク/グーテンベルグ/
gutguitar /ガットギター/
gutierrez /グティエレス/
guts /ガッツ/
gutspose /ガッツポーズ;和製英語/
gutter /ガーター/ガター/
guy /ガイ/ギー;仏語/ギイ/ギュイ/
guyana /ガイアナ;.gy/
gw /ゴールデンウィーク/ゲートウェイ/GateWay/
gwen /グエン/グウェン/
gym /ジム/
gymnasium /ギムナジウム/ジムナジウム/
gymnopedie /ジムノペディ/
gynt /ギュント/
gypsy /ジプシー/
gyro /ジャイロ/
gyroscope /ジャイロスコープ/
h /エッチ/エイチ/ハー;(独語)/水素/Hydrogen/
h# /平成#0年度/平成#0年/
h#.#.# /平成#0年#0月#0日/
haag /ハーグ/
haagendazs /ハーゲンダッツ;Haagen-Dazs/
haas /ハース/
habakkuk /ハバクク/
habanera /ハバネラ/
habanero /ハバネロ/
haber /ハーバー/
habermas /ハーバーマス/ハーバマス/
habit /ハビット/
habitat /ハビタット/
habitation /アビタシオン/
habitus /ハビトゥス/
habsburg /ハプスブルグ/
hachette /アシェット/
hack /ハック/
hacker /ハッカー/
hacking /ハッキング/
had /ハド/
hadamard /アダマール/
hades /ハデス/
hadley /ハドリー/ハドレー/
hadron /ハドロン/
hafnium /ハフニウム;[元素]72,Hf/
hagen /ハーゲン/
haggai /ハガイ/
hague /ヘーグ;the Hague, Holland/
hahn /ハーン/
hahnium /ハーニウム;[元素]105,Hn/
haines /ヘインズ/
haiphong /ハイフォン;ベトナム/
hair /ヘアー/ヘア/
hairaccessory /ヘアアクセサリー/
hairball /ヘアボール/
hairband /ヘアバンド/
hairbrush /ヘアブラシ/
haircare /ヘアケア/
haircolor /ヘアカラー/
haircolour /ヘアカラー/
haircut /ヘアカット/
hairdye /ヘアダイ/
hairgum /ヘアゴム/
hairline /ヘアライン/
hairmake /ヘアメイク/ヘアメーク/
hairnude /ヘアヌード;和製英語/
hairpiece /ヘアピース/
hairpin /ヘアピン/
hairpincurve /ヘアピンカーブ/
hairsalon /ヘアサロン/
hairspray /ヘアスプレー/
hairstyle /ヘアスタイル/ヘアースタイル/
hairtonic /ヘアトニック/
haiti /ハイチ;.ht/ハイティ/
hajj /ハッジ;[イスラム]巡礼/
haken /ハーケン/
hakenkreuz /ハーケンクロイツ/
hakkinen /ハッキネン/
hal /ハル/
halation /ハレーション/
halberd /ハルバード/
halcion /ハルシオン/
half /ハーフ/
halfback /ハーフバック/
halfbottle /ハーフボトル/
halfcoat /ハーフコート;和製英語(half-length coat)/
halfcourt /ハーフコート/
halfmarathon /ハーフマラソン/
halfmirror /ハーフミラー/
halfmoon /ハーフムーン/
halfpants /ハーフパンツ/
halfpitch /ハーフピッチ/
halfsize /ハーフサイズ/
halfsleeve /ハーフスリーブ/
halfswing /ハーフスイング/
halftime /ハーフタイム/
halftone /ハーフトーン/
halfway /ハーフウェイ/ハーフウェー/
hali /ハーリー/
haliburton /ハリバートン/
halifax /ハリファックス/
halim /ハリム;インドネシア(hlp)/
hall /ホール/
halle /ハレ/ハル/
hallelujah /ハレルヤ/
halley /ハレー/ハリー;Edmund Halley (1656-1742)/
halloween /ハロウィン/ハロウィーン/
hallstaff /ホールスタッフ/
halo /ハロー/ハロ/
halogen /ハロゲン/
halogenheater /ハロゲンヒーター/
halogenlamp /ハロゲンランプ/
halon /ハロン;CF3Brなど/
halothane /ハロセン/
halt /ホルト/
halter /ホルター/
halterneck /ホルターネック;halter-neck/
ham /ハム/
hamadan /ハマダーン/
hamam /ハマム/
hamann /ハーマン/ハマン/
hamas /ハマス/
hambacker /ハムバッカー/
hamburg /ハンバーグ/ハンブルク/ハンブルグ/
hamburger /ハンバーガー/
hamegg /ハムエッグ;和製英語(ham and eggs)/
hameln /ハーメルン;ドイツ/
hamilton /ハミルトン/
hamiltonian /ハミルトニアン/
hamlet /ハムレット/
hammer /ハンマー/ハンマ/
hammerhead /ハンマーヘッド/
hamming /ハミング/
hammock /ハンモック/
hammond /ハモンド/
hammondorgan /ハモンドオルガン/
hammurabi /ハンムラビ/ハムラビ/
hampshire /ハンプシャー/
hampton /ハンプトン/
hamsalad /ハムサラダ/
hamster /ハムスター/
hamza /ハムザ/
hana /ハナ/
hancock /ハンコック/
hand /ハンド/
handbag /ハンドバッグ/
handball /ハンドボール/
handbell /ハンドベル/
handbook /ハンドブック/
handbrake /ハンドブレーキ/
handclap /ハンドクラップ/
handcraft /ハンドクラフト/
handcream /ハンドクリーム/
handel /ヘンデル/
handgun /ハンドガン/
handheld /ハンドヘルド/
handi /ハンディ;handicap/ハンデ/ハンディー/
handicap /ハンディキャップ/
handkerchief /ハンカチーフ/ハンカチ/ハンケチ/
handle /ハンドル/
handlename /ハンドルネーム/
handler /ハンドラ/
handling /ハンドリング/
handmade /ハンドメイド/ハンドメード/
handoff /ハンドオフ/
handout /ハンドアウト/
handover /ハンドオーバー/
hands /ハンズ/
handsfree /ハンズフリー/
handshake /ハンドシェイク/
handsoap /ハンドソープ/
handsome /ハンサム/
handtowel /ハンドタオル;napkin/
handy /ハンディ/ハンディー/
handycam /ハンディカム;[商標]SONY. (<handy camera)/
hanes /ヘインズ/
hang /ハング/
hanger /ハンガー/
hanging /ハンギング/
hangingbasket /ハンギングバスケット/
hangman /ハングマン/
hangul /ハングル/
hangup /ハングアップ/
hank /ハンク/
hankel /ハンケル/
hanks /ハンクス/
hanna /ハンナ/
hannah /ハンナ/
hanne /ハンネ/
hannibal /ハンニバル/
hanning /ハニング/
hannon /ハノン/
hannover /ハノーバー;ドイツ/ハノーヴァー/
hanns /ハンス/
hanoch /エノク/
hanoi /ハノイ/
hans /ハンス/
hansa /ハンザ/
hanse /ハンザ;(独)/
hansel /ヘンゼル/
hansen /ハンセン/
hanson /ハンソン/
hanuman /ハヌマーン/ハヌマン/
happening /ハプニング/
happiness /ハピネス/ハッピネス/
happy /ハッピー/
happybirthday /ハッピーバースデー/ハッピーバースディ/
happyend /ハッピーエンド/
happymonday /ハッピーマンデー/
happytalking /ハッピートーキング/
harald /ハラルド/
haram /ハーレム/ハレム/
harappa /ハラッパ;パキスタン/ハラッパー/
harare /ハラレ/
harassment /ハラスメント/
harbor /ハーバー/
harbour /ハーバー/
hard /ハード/ハードウェア/
hardboiled /ハードボイルド/
hardbop /ハードバップ/
hardcase /ハードケース/
hardcoat /ハードコート/
hardcode /ハードコード/
hardcontact /ハードコンタクト;hard contact lens/
hardcontactlens /ハードコンタクトレンズ/
hardcopy /ハードコピー/
hardcore /ハードコア/
hardcover /ハードカバー/
harddisk /ハードディスク/
harddiskdrive /ハードディスクドライブ;HDD/
hardgay /ハードゲイ/
hardhit /ハードヒット/
hardhitter /ハードヒッター/
hardlanding /ハードランディング/
hardle /ハードル;※hurdle/
hardlens /ハードレンズ;hard lens/
hardlink /ハードリンク/
hardliquor /ハードリカー/
hardluck /ハードラック/
hardoff /ハードオフ;www.hardoff.co.jp/
hardrock /ハードロック/
hardschedule /ハードスケジュール;和製英語(tight schedule)/
hardsf /ハードSF/
hardsm /ハードSM/
hardtop /ハードトップ/
hardware /ハードウェア/ハードウエア/
hardwiring /ハードワイアリング/
hardy /ハーディー/ハーディ/
harem /ハーレム;英語綴り/ハレム/
hargreaves /ハーグリーブス/ハーグリーブズ/
harijan /ハリジャン/
harim /ハーレム/ハレム/
harlan /ハーラン/
harlem /ハーレム;NYの./
harlequin /ハーレクイン/
harley /ハーレー/ハーリー/ハーレイ/
harleydavidson /ハーレーダビッドソン;Harley-Davidson/
harmagedon /ハルマゲドン/
harmonia /ハルモニア/ハーモニア/
harmonic /ハーモニック/
harmonica /ハーモニカ/
harmonics /ハーモニクス/ハーモニックス/
harmonious /ハーモニアス/
harmonisation /ハーモナイゼーション/
harmonise /ハーモナイズ/
harmonium /ハルモニウム/
harmonization /ハーモナイゼーション/
harmonize /ハーモナイズ/
harmony /ハーモニー/
harness /ハーネス/
harnoncourt /アーノンクール/
harold /ハロルド/
harp /ハープ/
harper /ハーパー/
harpsichord /ハープシコード/
harpy /ハーピー/ハルピュイア/
harrier /ハリヤー/ハリアー/
harriet /ハリエット/
harris /ハリス/
harrison /ハリスン/ハリソン/
harrop /ハロップ/
harry /ハリー/
harrypotter /ハリーポッター;Harry Potter/
harte /ハート/
hartley /ハートレイ/ハートリー/ハートレー/
hartmann /ハルトマン/ハートマン/
hartree /ハートリー/
harty /ハーティ/ハーティー/
harvard /ハーバード/
harvest /ハーベスト/ハーヴェスト/
harvester /ハーベスター/ハーベスタ/
harvey /ハービー/ハーベイ/ハーヴェイ/ハーヴィー/
has /ハズ/
hash /ハッシュ/
hashed /ハッシュド/
hashedbeef /ハッシュドビーフ/
hashish /ハシシ/ハシシュ/
hashtable /ハッシュテーブル/
hassan /ハッサン/
haste /ヘイスト/
hat /ハット/
hatch /ハッチ/
hatchback /ハッチバック/
hatching /ハッチング/
hatckback /ハッチバック/
hate /ヘイト/
hathaway /ハサウェイ/ハザウェイ/
hattie /ハッティ/
hattrick /ハットトリック/
hauptmann /ハウプトマン/
hauser /ハウザー/
haut /オー;(Fr) 高い/
hautbrion /オーブリオン;Haut Brion/
hautecouture /オートクチュール;(Fr)haute couture/
hautmedoc /オーメドック;Haut Medoc/
havana /ハバナ/
have /ハブ/ハヴ/
haven /ヘイブン/ヘイヴン/
hawaii /ハワイ/
hawaiian /ハワイアン/
hawes /ホーズ/
hawk /ホーク/
hawking /ホーキング/
hawkins /ホーキンス/
hawks /ホークス/
hawley /ホーリー/
haws /ホーズ/
hayden /ハイデン/ヘイドン/
haydn /ハイドン/
haydon /ヘイドン/
hayek /ハイエク/
hayes /ヘイズ/
hayley /ヘイリー/
haynes /ヘインズ/ハイネス/
hazard /ハザード/
hazardlamp /ハザードランプ/
hazardmap /ハザードマップ/
hazel /ヘーゼル/ヘイゼル/
hazelnut /ヘーゼルナッツ/
hcup /Hカップ;27.5cm/Ｈカップ/
hd /ハードディスク/
hddrecorder /HDDレコーダー/
he /ヒー/ヘリウム/Helium/
head /ヘッド/
headbutt /ヘッドバット/
headcoach /ヘッドコーチ/
headdress /ヘッドドレス/
header /ヘッダ/ヘッダー/
headerfile /ヘッダファイル/ヘッダーファイル/
headgear /ヘッドギア/
headhunt /ヘッドハント/
headhunter /ヘッドハンター/
headhunting /ヘッドハンティング/
heading /ヘディング/ヘッディング/
headlamp /ヘッドランプ/
headlight /ヘッドライト/
headline /ヘッドライン/
headphone /ヘッドホン/ヘッドフォン/
headquarter /ヘッドクォーター/ヘッドクオーター/
headset /ヘッドセット/
headsliding /ヘッドスライディング;和製英語(headfirst sliding)/
heal /ヒール/
healer /ヒーラー/
healing /ヒーリング/
health /ヘルス/
healthcare /ヘルスケア/
healthcheck /ヘルスチェック/
healthmeter /ヘルスメーター;和製英語/
healthy /ヘルシー/
heap /ヒープ/
hear /ヒア/
hearing /ヒアリング/
hearn /ハーン/
heart /ハート/ハツ/
heartbeat /ハートビート/
heartbreak /ハートブレイク/
heartful /ハートフル/
hearth /ハース/
heartland /ハートランド/
heartmark /ハートマーク/
hearts /ハーツ/
hearty /ハーティー/ハーティ/
heat /ヒート/
heater /ヒーター/
heath /ヒース/
heather /ヘザー/
heathrow /ヒースロー;イギリス(lhr)/
heatisland /ヒートアイランド/
heatpipe /ヒートパイプ/
heatpump /ヒートポンプ/
heatsink /ヒートシンク/
heatup /ヒートアップ/
heaven /ヘブン/ヘヴン/
heavenly /ヘブンリー/
heavy /ヘビー/ヘヴィ/ヘヴィー/
heavyduty /ヘビーデューティー/
heavymetal /ヘビーメタル/ヘヴィメタル/ヘビメタ/ヘヴィメタ/
heavysmoker /ヘビースモーカー/
heavyuser /ヘビーユーザー/ヘビーユーザ/
hebe /ヘーベ/ヘベ/ヘーベー/
hebrew /ヘブライ/
heckel /ヘッケル/
hecta /ヘクタ;100/
hectare /ヘクタール;10000m^2/
hecto /ヘクト;[SI接頭語]h,10^2/
hectopascal /ヘクトパスカル;hPa/
hector /ヘクター/ヘクトル/ヘクトール/エクトル/
hedda /ヘッダ/
hedge /ヘッジ/
hedgefund /ヘッジファンド/
hedgehog /ヘッジホッグ/
hedi /エディ/
heel /ヒール/
hegel /ヘーゲル/
heide /ハイデ/
heidegger /ハイデガー/ハイデッガー/
heidelberg /ハイデルベルク/
heiden /ハイデン/
heidfeld /ハイドフェルド/
heidi /ハイジ/ハイディ/ヘイディ/
heifetz /ハイフェッツ/
height /ハイト/高さ/
heights /ハイツ/
heike /ハイケ/
heil /ハイル;(独語)万歳/
heim /ハイム/
heimat /ハイマート;(独語)故郷/
hein /ハイン/
heine /ハイネ/
heineken /ハイネケン/
heiner /ハイナー/
heinlein /ハインライン/
heinrich /ハインリッヒ/ハインリヒ/
heintz /ハインツ/
heinz /ハインツ/ハインズ/
heisenberg /ハイゼンベルク/ハイゼンベルグ/
helen /ヘレン/
helena /ヘレナ/エレナ/
helene /ヘレネ/エレーヌ/
helga /ヘルガ/
helguera /エルゲラ/
heli /ヘリ;helicopter/
helical /ヘリカル/
helichrisum /ヘリクリサム/
helicopter /ヘリコプター/
helio /ヘリオ/
heliopolis /ヘリオポリス/
helios /ヘリオス/
heliotrope /ヘリオトロープ/
heliport /ヘリポート/
helium /ヘリウム/
helix /ヘリックス/
hell /ヘル/
hella /ヘラ/
hellas /ヘラス/
hellcat /ヘルキャット/
hellenism /ヘレニズム/
hello /ハロー/
hellokitty /ハローキティ;[商標]sanrio/
hellopage /ハローページ/
hellowork /ハローワーク;和製英語(job centre)/
helm /ヘルム/
helmet /ヘルメット/
helmholtz /ヘルムホルツ/
helmut /ヘルムート/
helmuth /ヘルムート/
heloise /エロイーズ/
help /ヘルプ/
helpdesk /ヘルプデスク/
helper /ヘルパー/ヘルパ/
helpfile /ヘルプファイル/
helpsystem /ヘルプシステム/
helsinki /ヘルシンキ/
hematite /ヘマタイト/
heme /ヘム/
hemi /ヘミ/
hemingway /ヘミングウェイ/ヘミングウェー/
hemming /ヘミング/
hemoglobin /ヘモグロビン/
hemp /ヘンプ/
hen /ヘン/
hendel /ヘンデル/
henderson /ヘンダーソン/
hendricks /ヘンドリックス/ヘンドリクス/
hendrik /ヘンドリック/
hendrix /ヘンドリックス/ヘンドリクス/
henkel /ヘンケル/
henley /ヘンリー/
henleyneck /ヘンリーネック/
hennessy /ヘネシー/
henning /ヘニング/
henri /アンリ/ヘンリ/
henrietta /ヘンリエッタ/
henriette /アンリエット/ヘンリエッテ/
henrik /ヘンリク/ヘンリック/
henrique /エンリケ/
henry /ヘンリー/アンリ/ヘンリ/
heparin /ヘパリン/
hepburn /ヘップバーン/ヘプバーン/ヘボン/
hephaistos /ヘパイストス/ヘファイストス/
hepta /ヘプタ;7/
heptane /ヘプタン;C7H16/
her /ハー/
hera /ヘラ/
herakleitos /ヘラクレイトス/
herakles /ヘラクレス/
herald /ヘラルド/
herat /ヘラート/
herb /ハーブ/
herbal /ハーバル/
herbert /ヘルベルト/ハーバート/
herbie /ハービー/
herboil /ハーブオイル/
herbrand /エルブラン/
herbtea /ハーブティー/ハーブティ/
hercegovina /ヘルツェゴビナ/ヘルツェゴヴィナ/
hercule /エルキュール/
hercules /ヘラクレス/
here /ヒア/
heredocument /ヒアドキュメント/
herend /ヘレンド/
heritage /ヘリテージ/
herman /ヘルマン/エルマン/ハーマン/
hermann /ヘルマン/ハーマン/
hermes /エルメス/ヘルメス/ヘルメース/
hermione /ハーマイオニー/ヘルミオネ/
hermit /ハーミット/エルミット;?/
hermite /エルミート/
hernandez /ヘルナンデス/エルナンデス/
hernando /ヘルナンド/
hernia /ヘルニア/
hero /ヒーロー/
herod /ヘロデ/
herodes /ヘロデ/ヘロデス/
herodotos /ヘロドトス/
heroes /ヒーローズ/
heroic /ヒロイック/
heroin /ヘロイン/
heroine /ヒロイン/
herointerview /ヒーローインタビュー/
heroism /ヒロイズム/
heron /ヘロン/
herpes /ヘルペス/
herrmann /ハーマン/ヘルマン/
hers /ハーズ/
hershey /ハーシー/
hertha /ヘルタ/
hertz /ヘルツ/
herve /エルヴェ/
herzegovina /ヘルツェゴビナ/
herzog /ヘルツォーク/
hesiodos /ヘシオドス/
hesse /ヘッセ/
hessen /ヘッセン/
hestia /ヘスティア/
hetero /ヘテロ/ヘテロジニアス/
heterodyne /ヘテロダイン/
heterogeneous /ヘテロジニアス/
heterosexual /ヘテロセクシャル/ヘテロセクシュアル/
heuer /ホイヤー/
heuristic /ヒューリスティック/
heuristics /ヒューリスティクス/
hewlett /ヒューレット/
hewlettpackard /ヒューレットパッカード;www.hp.com/
hex /ヘックス/十六進数/
hexa /ヘキサ;6/ヘクサ/
hexagon /ヘキサゴン;六角形/
hexane /ヘキサン;C6H14/
hexard /ヘキサード;www.hexard.co.jp/
hey /ヘイ/
heyden /ハイデン/
heydon /ヘイドン/
hf /ハフニウム/Hafnium/
hg /水銀/Mercury/
hi /ハイ/Hawaii/ハワイ/
hi8 /Ｈｉ８/
hiace /ハイエース;[商標]トヨタ/
hiband /ＨｉＢａｎｄ/
hibernation /ハイバネーション/
hibiscus /ハイビスカス/
hickory /ヒッコリー/
hicks /ヒックス/
hidalgo /イダルゴ/
hidden /ヒドゥン/
hide /ハイド/非表示/
hiding /ハイディング/
hierarchie /ヒエラルヒー;(独語)/
hierarchy /ヒエラルキー/ハイアラーキー/
hieroglyph /ヒエログリフ/
hieronymus /ヒエロニムス/
hierro /イエロ/
hifi /ハイファイ;hi-fi/
higgins /ヒギンズ/
higgs /ヒッグス/
high /ハイ/
highball /ハイボール/
highcalorie /ハイカロリー/
highclass /ハイクラス/
highcost /ハイコスト/
highend /ハイエンド/
highgrade /ハイグレード/
highhat /ハイハット/
highheels /ハイヒール/
highjack /ハイジャック/
highjacker /ハイジャッカー/
highjump /ハイジャンプ/
highkey /ハイキー;high key/
highkick /ハイキック/
highland /ハイランド/
highleg /ハイレグ;high-leg/
highlevel /ハイレベル/
highlight /ハイライト/
highneck /ハイネック/
highness /ハイネス/
highnote /ハイノート/
highoc /ハイオク;high-octan/
highpace /ハイペース/
highpass /ハイパス/
highperformance /ハイパフォーマンス/
highpitch /ハイピッチ/
highpower /ハイパワー/
highquality /ハイクオリティ/
highreso /ハイレゾ;high resolution/
highreturn /ハイリターン/
highrisk /ハイリスク/
highschool /ハイスクール/
highscore /ハイスコア/
highseason /ハイシーズン/
highsense /ハイセンス/
highso /ハイソ;high society, high sox/
highsociety /ハイソサエティ/ハイソサエティー/ハイソ/
highsocks /ハイソックス/
highsox /ハイソックス;high socks/
highspec /ハイスペック/
highspeed /ハイスピード/
hightech /ハイテク;high technology/
hightechnology /ハイテクノロジー/
highteen /ハイティーン/
hightempo /ハイテンポ/
hightension /ハイテンション/
hightom /ハイタム/
hightone /ハイトーン/
hightouch /ハイタッチ/
highvision /ハイビジョン/
highway /ハイウェイ/ハイウェー/
highwaybus /ハイウェイバス/
highwaycard /ハイウェイカード/
hihat /ハイハット/
hiho /ハイホー/
hijack /ハイジャック/
hijacker /ハイジャッカー/
hijrah /ヒジュラ/
hike /ハイク/
hiker /ハイカー/
hiking /ハイキング/
hilaire /イレール/
hilary /ヒラリー/
hilbert /ヒルベルト/
hilda /ヒルダ/
hilde /ヒルデ/
hilevel /ハイレベル/
hilight /ハイライト/
hilite /ハイライト/
hill /ヒル/
hillary /ヒラリー/
hillbilly /ヒルビリー/
hillman /ヒルマン/
hills /ヒルズ/
hilltop /ヒルトップ/
hilton /ヒルトン/
him /ヒム/
himalaya /ヒマラヤ/
himalayan /ヒマラヤン;猫/
himmler /ヒムラー/
hindemith /ヒンデミット/
hindi /ヒンディ/ヒンディー/
hindu /ヒンズー/ヒンドゥー/ヒンドゥ/
hinge /ヒンジ/
hingis /ヒンギス/
hint /ヒント/
hip /ヒップ/
hiphop /ヒップホップ/
hipline /ヒップライン/
hipp /ヒップ/
hippie /ヒッピー/
hippocket /ヒップポケット/
hippocrates /ヒポクラテス/
hippokrates /ヒポクラテス/
hipsize /ヒップサイズ/
hipup /ヒップアップ;和製英語/
hiram /ハイラム/ヒラム/
hire /ハイヤー/ハイア/
hireso /ハイレゾ/
hirsch /ヒルシュ/
his /ヒズ/
hispania /イスパニア/
hispanic /ヒスパニック/
hiss /ヒス/
histamine /ヒスタミン/
histidine /ヒスチジン;His/
histogram /ヒストグラム/
histon /ヒストン/
history /ヒストリー/ヒストリ/
hit /ヒット/
hit&run /ヒットエンドラン;hit and run/
hitandrun /ヒットエンドラン/
hitch /ヒッチ/
hitchart /ヒットチャート/
hitchcock /ヒッチコック/
hitchhike /ヒッチハイク/
hitchhiker /ヒッチハイカー/
hitler /ヒトラー/ヒットラー/
hitman /ヒットマン/
hitnumber /ヒットナンバー/
hitom /ハイタム/
hitparade /ヒットパレード;hit parade/
hitpoint /ヒットポイント/
hits /ヒッツ/
hitsong /ヒットソング/
hitter /ヒッター/
hitting /ヒッティング/
hittite /ヒッタイト/
hivision /ハイビジョン/
hix /ヒックス/
hj /┐;vi式罫線入力/┓;太/
hjk /┤;vi式罫線入力/┫;太/┨;縦太/┥;横太/
hjkl /┼;vi式罫線入力/╋;太/┿;横太/╂;縦太/
hjl /┬;vi式罫線入力/┳;太/┯;横太/┰;縦太/
hk /┘;vi式罫線入力/┛;太/
hkl /┴;vi式罫線入力/┻;太/┷;横太/┸;縦太/
hl /─;vi式罫線入力/━;太/
ho /ホルミウム/Holmium/
hoare /ホーア/
hoax /ホークス/
hob /ホブ/
hobbes /ホッブズ/
hobbit /ホビット/Ｈｏｂｂｉｔ/
hobby /ホビー/
hobgoblin /ホブゴブリン/
hochiminh /ホーチミン;Ho Chi Minh/
hochst /ヘキスト/
hockey /ホッケー/
hodge /ホッジ/
hodges /ホッジス/
hoe /ホー/
hoffer /ホッファー/
hoffmann /ホフマン/
hofmann /ホフマン/
hofmannsthal /ホフマンスタール/
hog /ホッグ/
hogan /ホーガン/
hohl /ホール/
hoist /ホイスト/
hola /オラ/
holbein /ホルバイン/
hold /ホールド/
holden /ホールデン/
holder /ホルダー/ホルダ/
holderlin /ヘルダーリン/
holding /ホールディング/
holdings /ホールディングス/
hole /ホール/
holeinone /ホールインワン;hole-in-one/
holeout /ホールアウト/
holger /ホルガー/オルガー/
holi /ホーリー/
holiday /ホリデー/ホリデイ/ホリディ/
holland /オランダ/ホランド/
holly /ホーリー/ホリー/
hollywood /ハリウッド/
hollywoodstar /ハリウッドスター/
holm /ホルム/
holmes /ホームズ/
holmium /ホルミウム;[元素]67,Ho/
holocaust /ホロコースト/
hologram /ホログラム/
holographic /ホログラフィック/
holography /ホログラフィ/ホログラフィー/
holon /ホロン/
hols /ホルス/
holst /ホルスト/
holstein /ホルスタイン/
holster /ホルスター/
holy /ホーリー/
holyname /ホーリーネーム/
home /ホーム/
homebakery /ホームベーカリー;和製英語(home baking)/
homebase /ホームベース/
homecenter /ホームセンター;和製英語/
homecentre /ホームセンター;和製英語/
homeconcert /ホームコンサート/
homedir /ホームディレクトリ/
homedirectory /ホームディレクトリ/
homedoctor /ホームドクター;和製英語(family doctor)/
homedrama /ホームドラマ;和製英語(domestic drama)/
homegame /ホームゲーム/
homeground /ホームグラウンド/
homehelp /ホームヘルプ/
homehelper /ホームヘルパー/
homein /ホームイン/
homeland /ホームランド/
homeless /ホームレス/
homemade /ホームメイド/ホームメード/
homeoffice /ホームオフィス/
homeopathy /ホメオパシー/
homeostasis /ホメオスタシス/
homepage /ホームページ/
homepageaddress /ホームページアドレス/
homeparty /ホームパーティ/ホームパーティー/
homeplate /ホームプレート/
homeposition /ホームポジション/
homer /ホーマー/
homeroom /ホームルーム/
homeros /ホメロス/
homerun /ホームラン/
homesick /ホームシック/
homestay /ホームステイ/
homesteal /ホームスチール;和製英語(steal home)/
hometeam /ホームチーム/
hometheater /ホームシアター/
hometheatre /ホームシアター/
hometown /ホームタウン/
hometrade /ホームトレード/
homework /ホームワーク/
homing /ホーミング/
hommage /オマージュ;仏語/
homo /ホモ/
homocystein /ホモシステイン/
homology /ホモロジー/
homosapiens /ホモサピエンス/
homosexual /ホモセクシャル/ホモセクシュアル/ホモ/
homunculus /ホムンクルス/
homunkulus /ホムンクルス/
honda /ホンダ/
honduras /ホンジュラス;.hn/
honegger /オネゲル/
honest /アーネスト/オネスト/アネスト/
honesty /オネスティ/
honey /ハニー/
honeybee /ハニービー/
honeycomb /ハニカム/
honeymoon /ハネムーン/
honeypie /ハニーパイ/
honeypot /ハニーポット/
honfleur /オンフルール/
hongkong /ホンコン/香港/
honiara /ホニアラ/
honkytonk /ホンキートンク;honky-tonk/
honolulu /ホノルル/
honor /オナー/
honore /オノレ/
hood /フッド/
hook /フック/ホック/
hooke /フック;(1635-1703) Robert Hooke/
hooker /フッカー/
hooking /フッキング/
hooligan /フーリガン/
hoop /フープ/
hoover /フーバー/フーヴァー/
hop /ホップ/
hope /ホープ/
hopeful /ホープフル/
hopkin /ホプキン/
hopkins /ホプキンス/
hopper /ホッパー/
hopping /ホッピング/
hoppy /ホッピー/
hopstepjump /ホップステップジャンプ/
horace /ホレス/ホリス/
horatio /ホレイショ/ホレイショー/ホレーショー/
horece /ホレス/
horizon /ホライズン/
horizont /ホリゾント/
horizontal /ホリゾンタル/水平/水平方向/
hormon /ホルモン;(独語)/
hormone /ホルモン/
hormonebalance /ホルモンバランス/
horn /ホーン/ホルン/
hornet /ホーネット;雀蜂/
hornfels /ホルンフェルス/
horoscope /ホロスコープ/
horowitz /ホロヴィッツ/
horror /ホラー/
horsdoeuvre /オードブル;hors-d'oeuvre/
horse /ホース/
horseradish /ホースラディッシュ/
horst /ホルスト/
horus /ホルス/
hose /ホース/
hosea /ホセア/
hoshi /☆/★/
hospice /ホスピス/
hospital /ホスピタル/
hospitality /ホスピタリティ/ホスピタリティー/
host /ホスト/
hostaddress /ホストアドレス/
hostclub /ホストクラブ/
hostcomputer /ホストコンピュータ/
hostdata /ホストデータ/
hostel /ホステル/
hostess /ホステス/
hosting /ホスティング/
hostingservice /ホスティングサービス/
hostname /ホストネーム/ホスト名/
hostroute /ホストルート/
hot /ホット/
hotcake /ホットケーキ/
hotcakemix /ホットケーキミックス;和製英語(pancake mix)/
hotcarpet /ホットカーペット;和製英語(electric carpet)/
hotchkiss /ホッチキス;=stapler/
hotcoffee /ホットコーヒー/
hotcorner /ホットコーナー/
hotdog /ホットドッグ/
hotdrink /ホットドリンク/
hotel /ホテル/オテル;仏語/
hotelman /ホテルマン/
hotels /ホテルズ/
hotkey /ホットキー/
hotline /ホットライン/
hotlist /ホットリスト/
hotmail /ホットメール;MSN/
hotmilk /ホットミルク/
hotnews /ホットニュース/
hotpants /ホットパンツ/
hotplate /ホットプレート/ホット・プレート/
hotplug /ホットプラグ/
hotsalad /ホットサラダ/
hotsand /ホットサンド/
hotspot /ホットスポット/
hotswap /ホットスワップ/
hottentot /ホッテントット/
houdunit /ハウダニット/How done it?/
hough /ハフ/
hound /ハウンド/
hour /アワー/
hours /アワーズ/
house /ハウス/
housecleaning /ハウスクリーニング/
housedust /ハウスダスト/
household /ハウスホールド/
housekeeper /ハウスキーパー/
housekeeping /ハウスキーピング/
housemaker /ハウスメーカー/
housemannequin /ハウスマヌカン;和製語/
housemusic /ハウスミュージック/
housewine /ハウスワイン/
housing /ハウジング/
houston /ヒューストン/
hover /ホバー/フーバー;人名/
hovercraft /ホバークラフト/
hovering /ホバリング/
how /ハウ/
howard /ハワード/
howell /ハウエル/
howl /ハウル/
howling /ハウリング/
howlite /ハウライト/
howto /ハウツー/
hp /ヒューレット・パッカード;Hewlett-Packard/ホームページ;homepage/HP/
hpaddr /ホームページアドレス/HPアドレス/
hpaddress /ホームページアドレス/HPアドレス/
hpf /ハイパスフィルタ/
hr /ホルン/
hs /ハッシウム/Hassium/
htmlfile /HTMLファイル/
httpserver /HTTPサーバ/
hub /ハブ/
hubbard /ハバード/
hubble /ハッブル/
huber /フーバー/ユベール/
hubert /ユベール/ヒューバート/
huck /ハック/
huckleberry /ハックルベリー/
hudson /ハドソン/波怒村/
hue /フエ/色調/ユー/
huffman /ハフマン/
hug /ハグ/
huge /ヒュージ/
hugh /ヒュー/
hughes /ヒューズ/
hughie /ヒューイ/
hugo /ユゴー/ユーゴー/ヒューゴー/ヒューゴ/フーゴ/ウーゴ/
huguenot /ユグノー/
hugues /ユーグ/
huhhot /フフホト;中国/呼和浩特/
huizinga /ホイジンガ/
hula /フラ/
huladance /フラダンス/
hulagirl /フラガール/
hull /ハル/
hullnote /ハルノート;(1941)Hull Note/
human /ヒューマン/
humanerror /ヒューマンエラー/
humanism /ヒューマニズム/
humanisme /ユマニスム/
humanist /ヒューマニスト/
humaniste /ユマニスト/
humanite /ユマニテ;仏語/
humanity /ヒューマニティ/ヒューマニティー/
humanlike /ヒューマンライク/
humanoid /ヒューマノイド/
humanskill /ヒューマンスキル;和製英語/
humbert /アンベール/ハンバート/フンベルト/
humble /ハンブル/
humboldt /フンボルト/
hume /ヒューム/
hummel /フンメル/
hummer /ハマー;GM/
humming /ハミング/
hummingbird /ハミングバード/
humor /ユーモア/
humoresque /ユーモレスク/
humorous /ユーモラス/
humour /ユーモア/
humphrey /ハンフリー/
humpty /ハンプティ/ハンプティー/
humptydumpty /ハンプティダンプティ/
hundred /ハンドレッド/
hung /ハング/
hungarian /ハンガリアン/
hungary /ハンガリー;.hu/
hungarygp /ハンガリーGP;[F1]/
hungerstrike /ハンガーストライキ/ハンスト/
hungry /ハングリー/
hungup /ハングアップ/
hunk /ハンク/
hunt /ハント/
hunter /ハンター/
hunting /ハンティング/ハンチング;-帽/
huntingworld /ハンティングワールド;www.huntingworld.com/
huppert /ユペール/
hurd /Hurd/
hurdle /ハードル/
hurdygurdy /ハーディガーディ/
hurley /ハーレー/ハーリー/ハーレイ/
huron /ヒューロン/
hurrah /フレー/
hurricane /ハリケーン/
hurry /ハリー/
hus /ハズ/
husband /ハズバンド/
hush /ハッシュ/
husky /ハスキー/
huskyvioce /ハスキーボイス/
hussain /フセイン/
husserl /フッサール/
hustle /ハッスル/
hustler /ハスラー/
huston /ヒューストン;人名/
hut /ハット;小屋/
hutte /ヒュッテ/
huxley /ハクスリー/ハクスレー/ハックスレー/ハックスリ/
huygens /ホイヘンス/
huysmans /ユイスマンス/
hyacinth /ヒヤシンス/ヒアシンス/
hyades /ヒアデス/
hyaena /ハイエナ/
hyatt /ハイアット/
hybrid /ハイブリッド/
hybridcar /ハイブリッドカー/
hyde /ハイド/
hydepark /ハイドパーク;Hyde Park, London/
hyderabad /ハイデラバード/
hydra /ヒドラ/ヒュドラ/
hydrate /ハイドレート/
hydrazine /ヒドラジン;N2H4/
hydride /ハイドライド;水素化/
hydro /ハイドロ/ヒドロ/
hydrogen /ハイドロジェン;H/
hydroquinone /ハイドロキノン;C6H4(OH)2/ヒドロキノン/
hydroxy /ヒドロキシ;-OH/ハイドロキシ/
hymn /ヒム/
hyper /ハイパー/
hypercard /ハイパーカード/
hypercube /ハイパーキューブ/
hyperion /ハイペリオン/ヒペリオン/ヒュペリオン/
hyperlink /ハイパーリンク/
hypermedia /ハイパーメディア/
hypertext /ハイパーテキスト/
hyperthreading /ハイパースレッディング/
hyphen /ハイフン/‐/
hyphenation /ハイフネーション/
hypnosis /ヒプノシス/
hypnotherapy /ヒプノセラピー;催眠療法/
hypo /ハイポ/
hyrax /ハイラックス/
hysteresis /ヒステリシス/
hysteria /ヒステリー/
hysteric /ヒステリック/
hysterie /ヒステリー/
hyundai /ヒュンダイ;www.hyundai-motor.com/現代/
hz /ヘルツ/Ｈｚ/
i /ι;iota/アイ/и;cyrillic/ヨウ素/Iodine/私/
i'm /アイム/
i-kratkoje /й;cyrillic/
i/o /Ｉ／Ｏ/
ia /Iowa/アイオワ/
iain /イアン/
iam /アイアム;I am/アイ・アム/
ian /イアン/ヤン/
iappli /iアプリ/
ib /イヴ/
iban /イバン/
iberia /イベリア/
iberis /イベリス/
ibex /アイベックス/
ibm /インターナショナル・ビジネス・マシーンズ・コーポレーション/アイ・ビー・エム/
ibmpc /ＩＢＭ-ＰＣ/
ibn /イブン/
ibrahim /イブラヒム/
ibuprofen /イブプロフェン;C13H18O2/
icarus /イカルス;(英綴)/イカロス/
iccard /ICカード/
icchip /ICチップ/
ice /アイス/インサーキットエミュレーター;in-circuit emulator/氷/
icebar /アイスバー/
iceberg /アイスバーグ/
icebox /アイスボックス/
icecap /アイスキャップ/
icecoffee /アイスコーヒー/
icecream /アイスクリーム/
icecube /アイスキューブ/
icedance /アイスダンス/
icehockey /アイスホッケー/
iceland /アイスランド;.is/
icemilk /アイスミルク/
icenon /アイスノン;[商標]白元/
icepail /アイスペール/
icepick /アイスピック/
icerink /アイスリンク/
icetea /アイスティー/アイスティ/
icewine /アイスワイン/
ich /イッヒ/
icing /アイシング/
icon /アイコン/
iconic /アイコン化;?/
iconify /アイコニファイ/
ictag /ICタグ/
icup /Iカップ;30cm/Ｉカップ/
icy /アイシー/
id /イド;[精医]/アイディー/識別子/Idaho/アイダホ/
ida /イダ/アイダ/イーダ/
idaho /アイダホ;ID/
idcard /IDカード/
ide /アイド/
idea /アイデア/アイディア/イデア;ιδεα/
ideal /イデアル/アイデアル/
ideaman /アイデアマン/
idecable /IDEケーブル/
idecontroller /IDEコントローラ/
idedevice /IDEデバイス/
idedrive /IDEドライブ/
idee /イデー/
identifier /アイデンティファイア/識別子/
identify /アイデンティファイ/
identity /アイデンティティ/アイデンティティー/
ideologie /イデオロギー/
ideologue /イデオローグ/
ideology /イデオロギー/
idic /Ｉ-ｄｉｃ/
idiom /イディオム/
idiomatic /イディオマティック/
idiot /イディオット/
idle /アイドル/
idletime /アイドルタイム/
idling /アイドリング/
idol /アイドル/
idola /イドラ/
if /イフ/インターフェース/インタフェース/
iff /必要十分条件;if and only if/⊃⊂/<==>/
iglesias /イグレシアス/
igloo /イグルー/
ignacio /イグナチオ/イグナシオ/
ignite /イグナイト/
ignition /イグニッション/
ignitor /イグナイター/イグナイタ/
ignore /イグノア/
igor /イーゴリ/イゴール/イーゴル/
iguana /イグアナ/
iguanodon /イグアノドン/
iguazu /イグアス/
ihatov /イーハトーブ;(賢治)/イーハトーヴ/
ikaros /イカロス/イカルス/
ikra /イクラ;икра/
il /Illinois/イリノイ/イル/
ilia /イリヤ/
ilias /イリアス/イーリアス/
ill /イル/
illegal /イリーガル/
illich /イリイチ/
illinois /イリノイ/
illumination /イルミネーション/イリュミナシオン;仏語/イリュミネイション;<rare>/
illusion /イリュージョン/
illust /イラスト/
illustration /イラストレーション/
illustrator /イラストレーター/イラストレータ/
ilmari /イルマリ/
ilove /アイラブ;I love/アイ・ラブ・/
iloveyou /アイラブユー;I love you/
ilse /イルゼ/
ilya /イリヤ/イリア/
ilyich /イリイチ/
im /イン/
imac /iMac;[商標]アップル/アイマック/
image /イメージ/イマージュ;仏語/
imagealbum /イメージアルバム/
imagechange /イメージチェンジ;和製英語/
imagecharacter /イメージキャラクター/
imagedown /イメージダウン;和製英語/
imagefile /イメージファイル/
imagegirl /イメージガール/
imageillust /イメージイラスト/
imagemap /イメージマップ/
imagescanner /イメージスキャナ/
imagesensor /イメージセンサ/イメージセンサー/
imagesong /イメージソング/
imagetraining /イメージトレーニング/
imageup /イメージアップ;和製英語/
imagevideo /イメージビデオ/
imagewindow /イメージウィンドウ/イメージウインドー;<rare>/
imaginary /イマジナリー/
imagination /イマジネーション/
imaging /イメージング/
imago /イマーゴ/
imam /イマーム/イマム/
imbalance /インバランス/
imelda /イメルダ/
imidazole /イミダゾール/
imido /イミド/
imine /イミン/
imitation /イミテーション/
immanuel /イマニュエル/イマヌエル/
immigration /イミグレーション/
immoral /インモラル/
imode /iモード/
imp /インプ/⊃/
impact /インパクト/
impala /インパラ/
impedance /インピーダンス/
imperial /インペリアル/
imphal /インパール/
implant /インプラント/
implement /インプリメント/
implementation /インプリメンテーション/インプリメンテイション/
implementor /インプリメンタ/
implication /インプリケーション/⊃/
implied /⊂/
implies /→/⇒/⊃/ならば/
imply /⊃/→/
impo /インポ;impotenz/
import /インポート/
importer /インポーター/
impose /インポーズ/
impossible /インポッシブル/インポシブル/
impotence /インポテンス/
impotent /インポテンツ/
impotenz /インポテンツ;(独語)/
impre /インプレ;impression/
impress /インプレス/
impression /インプレッション/
impressive /インプレッシブ/
impreza /インプレッサ;[商標]スバル/
imprint /インプリント/
imprinting /インプリンティング/
impro /インプロ;improvisation/
impromptu /アンプロンプチュ/アンプロンプテュ/即興曲/
improvisation /インプロヴィゼーション/インプロビゼーション/インプロ/
improviser /インプロヴァイザー/インプロバイザー/
impulse /インパルス/
in /イン/∈/インチ/Indiana/インディアナ/インジウム/Indium/
ina /アイナ/
inactive /インアクティブ/
inari /イナリ/
inax /イナックス;www.inax.co.jp/
inbal /インバル/
inbound /インバウンド/
inc /Ｉｎｃ．/
incense /インセンス/
incentive /インセンティブ/
incest /インセスト/
inch /インチ/吋/
incident /インシデント/
incite /インサイト/
include /インクルード/∈/∋/
inclusion /インクルージョン/
inclusive /インクルーシブ/
income /インカム/
incomegain /インカムゲイン;income gain/
incourse /インコース;和製英語(inside)/
incredible /インクレディブル/
increment /インクリメント/
incremental /インクリメンタル/
incrementalsearch /インクリメンタルサーチ/
incubate /インキュベート/
incubation /インキュベーション/
incubator /インキュベータ/インキュベーター/
incubus /インキュバス/
inden /インデン/
indent /インデント/
indentation /インデンテーション/インデンテイション/字下げ/
independant /アンデパンダン;仏語/
independence /インデペンデンス/インディペンデンス/
independent /インディペンデント/
index /インデックス/インデクス/
indexation /インデクセーション/
indexer /インデクサ/インデクサー/
indexing /インデクシング/
indexmode /インデックスモード/
indi /インディ/インディー/
india /インディア/インド;.in/
indian /インディアン/
indiana /インディアナ;IN/
indianapolis /インディアナポリス/
indians /インディアンズ;[MLB]/
indica /インディカ/
indication /インディケーション/
indicator /インジケータ/インジケーター/インディケーター/インディケータ/
indicial /インディシャル/
indies /インディーズ/
indigo /インディゴ/
indigoblue /インディゴブルー/
indio /インディオ/
indirect /インダイレクト/
indium /インジウム;[元素]49,In/
individual /インディヴィジュアル/インディビジュアル/
indo /インド/印度/
indochina /インドシナ/
indole /インドール/
indomethacin /インドメタシン;C19H16ClNO4/
indonesia /インドネシア;.id/
indoor /インドア/
indra /インドラ/
inductance /インダクタンス/
induction /インダクション/帰納法/
indus /インダス/
industrial /インダストリアル/
industries /インダストリーズ/
industry /インダストリー/インダストリ/
indy /インディ/インディー/
ines /イネス/アイネス/
infant /インファント/
inferior /インフェリア/
inferno /インフェルノ/
infield /インフィールド/
infight /インファイト/
infinite /インフィニット/
infinity /インフィニティ/インフィニティー/∞/
infla /インフレ;inflation/
inflation /インフレーション/インフレ/
inflationary /インフレーショナリ/インフレ/
influence /インフルエンス/
influenza /インフルエンザ/
influenzavirus /インフルエンザウイルス/
info /インフォ/
inform /インフォーム/
informal /インフォーマル/
informant /インフォーマント/
informatic /インフォマティック/
informatics /インフォマティクス/インフォマティックス/
information /インフォメーション/情報/
informationcenter /インフォメーションセンター/
informationcentre /インフォメーションセンター/
informatique /アンフォルマティーク/
informed /インフォームド/
informedconsent /インフォームドコンセント/
informel /アンフォルメル/
informercial /インフォマーシャル;information + commercial/
infoseek /インフォシーク;www.infoseek.com/
infra /インフラ/
infrastructure /インフラストラクチャ/インフラストラクチャー/インフラ/
infusion /インフュージョン/
ing /イング/
inge /インゲ/
inglez /イギリス/
ingo /インゴ/
ingoal /インゴール/
ingot /インゴット/
ingram /イングラム/
ingrid /イングリッド/
inheritance /インヘリタンス/
inhigh /インハイ;[野球]和製英語(inside high)/
inhouse /インハウス/
iniesta /イニエスタ/
initial /イニシャル/
initialise /イニシャライズ/
initialize /イニシャライズ/
initiative /イニシアティブ/イニシアチブ/
initiator /イニシエータ/
injection /インジェクション/
injector /インジェクター/
ink /インク/インキ/
inka /インカ/
inkcartridge /インクカートリッジ/
inkjet /インクジェット/
inkjetprinter /インクジェットプリンタ/インクジェットプリンター/
inkribbon /インクリボン/
inlane /インレーン/
inlay /インレー/インレイ/
inline /インライン/
inlineframe /インラインフレーム/
inlineskate /インラインスケート/
inlining /インライニング/
inlow /インロー;[野球]和製英語(inside low)/
inn /イン/
inna /インナ/
inner /インナー/
innercity /インナーシティ/
innerspace /インナースペース/
innerwear /インナーウェア/
innerworld /インナーワールド/
innes /イネス/アイネス/イニス/
inning /イニング/
innocence /イノセンス/
innocent /イノセント/
innovation /イノベーション/
innovator /イノベーター/イノベータ/
innsbruck /インスブルック/
inode /iノード/ｉノード/
inositol /イノシトール/
inplay /インプレー;in play/インプレイ/
inprovisation /インプロヴァイゼィション;※improvisation?/
inpulse /インパルス/
input /インプット/入力/
inputmethod /インプットメソッド/
insect /インセクト/
insensitive /インセンシティブ/
insert /インサート/
insertion /インサーション/
inshallah /インシャラー/
inside /インサイド/
insideout /インサイドアウト/
insider /インサイダー/
insidework /インサイドワーク/
insight /インサイト/
insoft /インソフト/
insole /インソール/
inspection /インスペクション/
inspector /インスペクタ/インスペクター/
inspiration /インスピレーション/
inspire /インスパイア/
inst /インスト/
install /インストール/
installation /インスタレーション/インストレーション/
installer /インストーラ/インストーラー/
instance /インスタンス/
instant /インスタント/
instantcamera /インスタントカメラ/
instantcoffee /インスタントコーヒー/
instantiate /インスタンシエート/具体化/
institute /インスティテュート/インスティチュート/
institution /インスティテューション/
instore /インストア/
instorelive /インストアライブ/
instruction /インストラクション/
instructor /インストラクター/
instrument /インストゥルメント/インストルメント/インスツルメント/
instrumental /インストゥルメンタル/インストルメンタル/インスツルメンタル/
instruments /インスツルメンツ/
insufficient /不充分/不足/
insulation /インシュレーション/
insulator /インシュレーター/インシュレータ/
insulin /インスリン/インシュリン/
insulinoma /インスリノーマ/
insurance /インシュアランス/インシュランス/
int /∫/
integer /インテジャー/インテジャ/整数/
integra /インテグラ/
integral /インテグラル/∫/∬/
integrate /インテグレート/
integration /インテグレーション/
integrator /インテグレータ/インテグレーター/
integrin /インテグリン/
integrity /インテグリティ/完全/
intel /インテル/Intel/
intellectual /インテレクチュアル/
intelli /インテリ/
intelligence /インテリジェンス/
intelligent /インテリジェント/
intelligentsia /インテリゲンチャ/
intelligentzia /インテリゲンチャ/
intense /インテンス/
intensity /インテンシティ/
intensive /インテンシブ/
inter /インター/インタ/
interact /インタラクト/
interaction /インタラクション/インターアクション/
interactive /インタラクティブ/インタラクティヴ/
interactivity /インタラクティビティ/
interbank /インターバンク/
intercept /インターセプト/インタセプト/
interchange /インターチェンジ/
intercom /インターコム/
intercontinental /インターコンチネンタル/
interest /インタレスト/
interface /インターフェイス/インターフェース/インタフェース/インタフェイス/
interfaceboard /インターフェースボード/
interfere /インターフェア/
interferon /インターフェロン/
interhigh /インターハイ;和製英語(inter + high school)/
interior /インテリア/
interiorcoordinator /インテリアコーディネーター/
interiordesign /インテリアデザイン/
interiordesigner /インテリアデザイナー/
interiorshop /インテリアショップ/
interlace /インターレース/インタレース/
interlaken /インターラーケン/
interleave /インターリーブ/インタリーブ/
interleukin /インターロイキン/
interlock /インターロック/インタロック/
interlocking /インターロッキング/
interlude /インターリュード/インタリュード/
intermedia /インターメディア/
intermezzo /インテルメッツォ/
intermission /インターミッション/
intern /インターン/
internal /インターナル/
international /インターナショナル/
internet /インターネット/インタネット/Ｉｎｔｅｒｎｅｔ/
internetbanking /インターネットバンキング/
internetcafe /インターネットカフェ/
internetexplorer /インターネットエクスプローラー/インターネットエクスプローラ/
internetserver /インターネットサーバ/
internetwork /インターネットワーク/
internetworking /インターネットワーキング/
internoise /インターノイズ/
internship /インターンシップ/
interphone /インターホン/インターフォン/
interplay /インタープレイ/
interpol /インターポール;www.interpol.int/
interpret /インタープリト/
interpretation /インタープリテーション/
interpreter /インタプリタ/インタープリター/インタープリタ/インタープリータ;<rare>/
interpretive /インタプリティブ/
interrace /インターレース;※interlace/
interrupt /インタラプト/
interrupter /インタラプター/
intersection /∩/
intersex /インターセックス/
interval /インターバル/インタバル/
interview /インタビュー/インタビュ/インタヴュー/
interviewer /インタビュアー/インタヴュアー/
intimate /インティメイト/
into /イント/
intolerance /イントレランス/
intonation /イントネーション/
intra /イントラ/
intranet /イントラネット/
intrinsics /イントリンシックス/
intro /イントロ/
introduction /イントロダクション/導入/
inuit /イヌイット/
inulin /イヌリン/
invader /インベーダー/
invalid /インバリッド/誤った/無効な/
invalidate /インバリデート/
invalidation /インバリデーション/
invariant /インバリアント/インヴァリアント/
invention /インヴェンション/インベンション/
inventory /インベントリ/インベントリー/
inverse /インバース/インヴァース/
inversion /インバージョン/インヴァージョン/
invert /インバート/
inverter /インバータ/インバーター/
invest /インベスト/
investment /インベストメント/
invincible /インビンシブル/
invisible /インビジブル/
invitation /インビテーション/
invitational /インビテーショナル/インヴィテイショナル;<rare>/
invitro /インビトロ;in vitro/
invoice /インボイス/インヴォイス/
involvement /インボルブメント/
inzaghi /インザーギ/
io /イオ/Ｉ／Ｏ/入出力/(concat "I\057O")/
ioan /ヨアン/
iocard /イオカード/
iodine /アイオダイン/ヨード;Jod/
iodo /ヨード;(接中辞)/
iolite /アイオライト/
ion /イオン/アイオン/
iona /イオナ/アイオナ/
ionbeam /イオンビーム/
ione /イオネ/
ionesco /イヨネスコ/
ionia /イオニア/
ionian /イオニアン;CDEFGABC/アイオニアン/
ionicchannel /イオニック・チャンネル/
ioport /(concat "I\057Oポート")/
iosif /ヨシフ/
iota /ι/イオタ/
iowa /アイオワ/
ip /IPアドレス/IP/
ipaddress /IPアドレス/
ipanema /イパネマ/
ipmasquerade /IPマスカレード/
ipod /iPod;[商標]アップル/アイポッド;iPod/
ipphone /IPフォン/IP電話/
ipsum /イプサム;[商標]トヨタ/
ir /イリジウム/Iridium/
ira /アイラ/
irak /イラク;iq/
iran /イラン;.ir/
iraq /イラク;.iq/
ireland /アイルランド;.ie/
irene /アイリーン/イレーヌ/イレーネ/
iressa /イレッサ;=gefitinib/
iridium /イリジウム;[元素]77,Ir/
irina /イリーナ/
iris /アイリス/イリス/イーリス/
irish /アイリッシュ/
irkutsk /イルクーツク/
irma /イルマ/
iro /イロ/
iron /アイアン/アイロン/
ironie /イロニー/
ironman /アイアンマン/
ironside /アイアンサイド/
irony /アイロニー/
irq /IRQ/
irregular /イレギュラー/
irrumatio /イラマチオ/
irvin /アーヴィン/アービン/
irvine /アーヴィン/アービン/
irving /アーヴィング/
is /イズ/
isaac /アイザック/イサク/イザーク/
isabel /イザベル/イサベル/
isabella /イザベラ/
isabelle /イザベル/
isabus /ISAバス/
isaiah /イザヤ/
isbncode /ISBNコード;International Standard Book Number/ISBN番号/
iscariot /イスカリオテ;-のユダ/
iscariote /イスカリオテ/
isfahan /イスファハン;イラン/
ishtar /イシュタル/イシター/
isis /イシス/
iskandar /イスカンダル/
islam /イスラム/イスラーム/
islamabad /イスラマバード/
island /アイランド/
isle /アイル;島/
ism /イズム/
ismael /イスマエル/
isme /イスム;仏語/
iso /イソ/アイソ/ISO/
iso# /ISO#0/ＩＳＯ#1/
isodine /イソジン/
isoflavone /イソフラボン/
isoimage /ISOイメージ/
isola /イソラ/
isolation /アイソレーション/
isolator /アイソレータ/
isolde /イゾルデ/
isoleucin /イソロイシン;Ile/
isome /アイソメ;isometric/
isometric /アイソメトリック/
isoparametric /アイソパラメトリック/
isoprene /イソプレン/
isopropanol /イソプロパノール/
isopropyl /イソプロピル/
isotonic /アイソトニック/
isotope /アイソトープ/
isou /イズー/
isozyme /アイソザイム/
israel /イスラエル;.il/
issac /アイザック/
issue /イシュー/
ist /イスト/
istanbul /イスタンブール/
it /イット/アイティー/
it's /イッツ/
italia /イタリア;.it/伊太利亜/
italiagp /イタリアGP;[F1]/
italian /イタリアン/
italiana /イタリアーナ/
italiano /イタリアーノ/
italianrestaurant /イタリアンレストラン/
italiawine /イタリアワイン/
italic /イタリック/
italo /イタロ/
italy /イタリー/イタリア;.it/
itbubble /ITバブル/
itchy /イッチー/
itelie /イタリー;仏語/
item /アイテム/項目/
iteration /イテレーション/
iterative /逐次型/
iterator /イテレータ/
itriangle /▼/
its /イッツ/
itsystem /ITシステム/
iturn /Ｉターン/Iターン/
ivan /イワン/イヴァン/アイヴァン/イバン/
ivanhoe /アイヴァンホー/アイバンホー/
ives /アイヴズ/アイヴス/アイブス/
ivo /イヴォ/イボ/
ivory /アイボリー/アイヴォリー/
ivorywhite /アイボリーホワイト/
ivy /アイビー/アイヴィー/アイヴィ/
iybank /アイワイバンク;www.iy-bank.co.jp/
izmir /イズミル;トルコ/
j /ジェイ/ジェー/й;cyrillic(i-kratkoje)/
j2 /Ｊ２/
ja /ヤー;(独語)/я;cyrillic/
jab /ジャブ/
jabberwock /ジャバウォック/
jack /ジャック/ジャッキ/
jackal /ジャッカル/
jacke /ヤッケ/
jacker /ジャッカー/
jacket /ジャケット/
jackie /ジャッキー/
jackpot /ジャックポット/
jackrussell /ジャックラッセル;[犬]Jack Russell/
jackson /ジャクソン/
jaco /ジャコ/
jacob /ヤコブ/ジェイコブ/ジャコブ/ヤーコブ/ジェーコブ/
jacobi /ヤコビ/
jacobs /ジェイコブス/ジェイコブズ/
jacobsen /ヤコブセン/
jacobson /ヤコブソン/
jacquard /ジャカード/ジャガード/
jacqueline /ジャクリーン/ジャクリーヌ/
jacques /ジャック/
jacquiline /ジャクリーヌ/
jacuzzi /ジャグジー/ジャクージ/
jade /ジェイド/ジェード/
jaeger /イェーガー/
jael /ジェイル/ジェール/ヤエル/
jaggy /ジャギー/
jaguar /ジャガー/
jahn /ヤーン/
jahnn /ヤーン/
jail /ジェイル/
jaime /ハイメ/ジェイム/ジャイメ/ジェイミー/
jaipur /ジャイプール/
jair /ジェイル/ヤイル/
jaist /北陸先端大/ジャイスト/北陸先端科学技術大学院大学/JAIST/Japan Advanced Institute of Science and Technology/
jakarta /ジャカルタ/
jake /ジェイク/
jakob /ヤコブ/ジェイコブ/
jakobson /ヤコブソン/
jal /日本航空/日航/
jalapeno /ハラペーニョ/
jalousie /ジャロジー;(Fr)嫉妬。(窓の)ブラインド/ジャルジー/
jam /ジャム/
jamaica /ジャマイカ;.jm/
jamaican /ジャマイカン/
jamais /ジャメ/
jamal /ジャマール/ジャマル/
jambalaya /ジャンバラヤ/
jamband /ジャムバンド/
jamboree /ジャンボリー/
james /ジェームズ/ジェームス/ジェイムズ/ヤコブ/
jamie /ジェイミー/
jamila /ジャミラ/ジャミーラ/
jammes /ジャム/
jamming /ジャミング/
jammy /ジャミー/
jamsession /ジャムセッション/
jan /ジャン/ヤン/ヤーン/
jana /ヤナ/
janacek /ヤナーチェク/
jancode /JANコード;Japanese Article Number/
jane /ジェーン/
janet /ジャネット/
jani /ヤニ/
janice /ジャニス/
janie /ジェイニー/
janine /ジェニン/
janis /ジャニス/
janne /ヤンネ/
janos /ヤーノシュ/
jansen /ヤンセン/ジャンセン/
january /ジャニュアリー/
janus /ヤヌス;>january/
janusz /ヤヌス/ヤヌシュ/
jap /ジャップ/
japan /ジャパン/日本/
japancup /ジャパンカップ/
japanese /ジャパニーズ/
japanesque /ジャパネスク/
japon /ジャポン;仏語/
japonica /ジャポニカ/
japonisme /ジャポニスム/
jar /ジャー/
jardin /ジャルダン;(Fr)庭/
jared /ジャレド/ヤレド/
jargon /ジャーゴン/
jari /ヤリ/
jarno /ヤルノ/
jarpot /ジャーポット/
jarre /ジャール/
jarrett /ジャレット/
jarry /ジャリ/
jasdaq /ジャスダック;www.jasdaq.co.jp/
jasmin /ジャスミン;人名/
jasmine /ジャスミン/
jasminetea /ジャスミンティー/
jason /ジェイソン/
jasper /ジャスパー/碧玉/
jaspers /ヤスパース/
jasrac /ジャスラック/
jataka /ジャータカ/
jati /ジャーティ/
jaune /ジョーヌ;(Fr)黄色/
java /ジャワ/ジャバ/ジャヴァ/
javaapplet /JAVAアプレット/ジャバアプレット/
javanese /ジャバニーズ/
javascript /JAVAスクリプト/ジャバスクリプト/
javelin /ジャベリン/
jaw /ジョー/
jaws /ジョーズ/
jax /ジャックス/
jay /ジェイ/ジェー/
jaya /ジャヤ/
jazz /ジャズ/
jazzband /ジャズバンド/
jazzbar /ジャズバー/
jazzchorus /ジャズコーラス/
jazzclub /ジャズクラブ/
jazzdance /ジャズダンス/
jazzdrum /ジャズドラム/
jazzdrummer /ジャズドラマー/
jazzfes /ジャズフェス/
jazzfestival /ジャズフェスティバル/
jazzfunk /ジャズファンク/
jazzfusion /ジャズフュージョン/
jazzguitar /ジャズギター/
jazzlife /ジャズライフ/
jazzlive /ジャズライブ/
jazzman /ジャズマン/
jazzmen /ジャズメン/
jazzpiano /ジャズピアノ/
jazzrock /ジャズロック/
jazzsinger /ジャズシンガー/
jazzsong /ジャズソング/
jazzvocal /ジャズボーカル/
jazzy /ジャジー/
jbibtex /jBibTeX/
jcbcard /JCBカード;www.jcb.co.jp/
jcom /ジェイコム/
jcup /Jカップ;32.5cm/Ｊカップ/
je /е;cyrillic/ジュ/
jealous /ジェラス/
jealousy /ジェラシー/
jean /ジーン/ジャン/
jeanette /ジャネット/
jeanie /ジーニー/
jeanist /ジーニスト/
jeanne /ジャンヌ/
jeannedarc /ジャンヌダルク;(1412-1431) Jeanne d'Arc/
jeannette /ジャネット/
jeannie /ジニー/
jeans /ジーンズ/
jeddah /ジェッダ;サウジアラビア(jed)/
jedi /ジェダイ/
jeep /ジープ/
jef /ジェフ/
jeff /ジェフ/
jefferson /ジェファーソン/ジェファソン/
jeffery /ジェフリー/
jeffrey /ジェフリー/
jefunited /ジェフユナイテッド;[Jリーグ]市原・千葉/
jehovah /エホバ/
jekyll /ジキル/
jelly /ゼリー/ジェリー/
jellybeans /ジェリービーンズ/ゼリービーンズ/
jellyfish /ジェリーフィッシュ;くらげ/
jem /ジェム/
jena /イエナ/イェナ/
jenga /ジェンガ;[商標]/
jeni /ジェニ/
jenka /ジェンカ/
jenkins /ジェンキンス/ジェンキンズ/
jenna /ジェナ/ヤンナ/
jenner /ジェンナー/
jennie /ジェニー/ジェニィ/
jennifer /ジェニファー/
jennings /ジェニングス/
jenny /ジェニー/ジェニィ/
jens /ジェンス/イエンス/イェンス/
jensen /ジェンセン/ジャンセン/イェンセン/イエンセン/イェンゼン/
jenson /ジェンソン/
jeremiah /エレミヤ/ジェレマイア/
jeremie /ジェレミー/
jeremy /ジェレミー/
jerez /ヘレス/
jeri /ジェリ/
jericho /エリコ;パレスチナ/ジェリコ/
jerk /ジャーク/
jerky /ジャーキー/
jermaine /ジャーメイン/
jerome /ジェローム/
jeronimo /ジェロニモ/
jerry /ジェリー/
jersey /ジャージ/ジャージー/
jerusalem /エルサレム/イェルサレム/
jess /ジェス/
jesse /ジェシー/エッサイ/
jessica /ジェシカ/
jessie /ジェシー/
jesus /イエス/ジーザス/イエズス/ヘスス/
jesuschrist /イエスキリスト;Jesus Christ/イエス・キリスト/
jet /ジェット/
jetaime /ジュテーム;Je t'aime/
jetbath /ジェットバス;和製英語/
jetcoaster /ジェットコースター/
jete /ジュテ/
jetengine /ジェットエンジン/
jeter /ジーター/
jethro /ジェスロ/
jetro /ジェトロ;日本貿易振興会/
jetski /ジェットスキー/
jetstream /ジェットストリーム/
jeunesse /ジュネス/
jew /ジュー/ユダヤ/
jewel /ジュエル/
jewelcase /ジュエルケース/
jeweler /ジュエラー/
jewelry /ジュエリー/
jewelrybox /ジュエリーボックス/
jewelrycase /ジュエリーケース/
jewelryshop /ジュエリーショップ/
jibe /ジャイブ/
jig /ジグ/治具/
jigae /チゲ;(朝鮮語)/
jigsaw /ジグソー/
jigsawpuzzle /ジグソーパズル/
jihad /ジハード/
jil /ジル/
jill /ジル/
jim /ジム/
jimenez /ヒメネス/
jimi /ジミ/
jimmie /ジミー/
jimmy /ジミー/
jimny /ジムニー/
jingiskan /ジンギスカン;Genghis Khan?/
jingle /ジングル/
jinglebell /ジングルベル/
jinn /ジン/
jinx /ジンクス/
jis /ジス;Japanese Industrial Standard/
jis# /JIS#0/
jiscode /JISコード/
jismark /JISマーク/ジスマーク/
jitter /ジッタ/ジッター/
jitterbug /ジルバ/ジターバグ/ジッターバグ/ジタバグ/
jive /ジャイブ/ジャイヴ/
jk /│;vi式罫線入力/┃;太/
jkl /├;vi式罫線入力/┣;太/┠;縦太/┝;横太/
jl /┌;vi式罫線入力/┏;太/
jlatex /jLaTeX/
jleague /Jリーグ/Ｊリーグ/
jnic /日本ネットワークインフォメーションセンター;www.jnic.jp/
jo /ё;cyrillic/ジョー/
joachim /ヨアキム/ヨアヒム/
joan /ジョアン/ジョーン/
joanna /ジョアンナ/ジョアナ/
joanne /ジョアン/ジョアンヌ/
joao /ジョアン/
joaquin /ホアキン/
job /ジョブ/ヨブ/
jobim /ジョビン/
jobs /ジョブズ/ジョブス/
jocelyn /ジョセリン/
jockey /ジョッキー/
jod /ヨード;[元素]I (独語)/ヨート/
jodel /ヨーデル;(独語)/
jody /ジョディ/
joe /ジョー/
joel /ヨエル/ジョエル/
joelle /ジョエル/
jog /ジョグ/
jogger /ジョガー/
jogging /ジョギング/
joggingcourse /ジョギングコース/
joggingshoes /ジョギングシューズ/
jogjakarta /ジョグジャカルタ;インドネシア(jog)/
johan /ヨハン/
johann /ヨハン/
johanna /ヨハンナ/ヨハナ/
johannes /ヨハネ/ヨハネス/ヨハンネス/
johannesburg /ヨハネスブルグ;(jnb)南アフリカ/ヨハネスブルク/
johanson /ヨハンソン/
john /ジョン/ヨハネ/
johnlennon /ジョンレノン;(1940-1980)John Lennon/ジョン・レノン/
johnnie /ジョニー/
johnny /ジョニー/
johnnys /ジャニーズ;www.johnnys-net.jp/
johns /ジョーンズ/ジョンズ/
johnson /ジョンソン/
johorbahru /ジョホールバル;Johor Bahru,マレーシア(jhb)/
joie /ジョア/ジョワ/
join /ジョイン/
joint /ジョイント/
jointconcert /ジョイントコンサート/
jointlive /ジョイントライブ/
jointventure /ジョイントベンチャー/
jojo /ジョジョ/
jojoba /ホホバ/
joke /ジョーク/
joker /ジョーカー/
jolene /ジョリーン/
jolivet /ジョリヴェ/
jolly /ジョリー/
jon /ジョン/
jonah /ヨナ/
jonas /ジョナス/
jonathan /ジョナサン/ヨナタン/
jones /ジョーンズ/
joplin /ジョプリン/
jordan /ヨルダン;.jo/ジョルダン/ジョーダン/
jordi /ジョルディ/
jorg /ヨルグ/イェルク/
jorge /ホルヘ/ジョルジュ/ジョルジェ/ジョージ/
jose /ホセ/ジョゼ/
josef /ジョセフ/ジョゼフ/ヨーゼフ/ヨゼフ/ヨセフ/ジョーゼフ/
joseph /ヨセフ/ジョーゼフ/ヨーゼフ/ヨシフ/ジョセフ/
josephe /ジョセフ/
josephine /ジョセフィン/ジョゼフィーヌ;仏語/ジョセフィーヌ/
josephson /ジョセフソン/
josette /ジョゼット/
josh /ジョシュ/ジョッシュ/
joshua /ヨシュア/ジョシュア/
josie /ジョシー/
josquin /ジョスカン/
jota /ホタ/
joule /ジュール/
journal /ジャーナル/
journaling /ジャーナリング/
journalism /ジャーナリズム/
journalist /ジャーナリスト/
journalistic /ジャーナリスティック/
journey /ジャーニー/
joy /ジョイ/
joyce /ジョイス/
joyful /ジョイフル/
joypad /ジョイパッド/
joystick /ジョイスティック/
jpegfile /JPEGファイル/
jperiod /．/
jpgfile /JPGファイル/
jpop /Ｊポップ/Jポップ/J-POP/
jr /ジュニア/
jsbach /J.S.バッハ/J.S.Bach/ヨハンセバスチャンバッハ/ヨハン・セバスチャン・バッハ/
jsme /日本機械学会;Japan Society of Mechanical Engineers. www.jsme.or.jp/
jtex /jTeX/
ju /ю;cyrillic/
juan /ファン/ホアン/ジュアン/
juana /ファナ/
jubilee /ジュビリー/
jubilo /ジュビロ;[Jリーグ]磐田/
judah /ユダ;(ヤコブの子)/ジュダ/
judas /ユダ;(キリストを売った弟子)/ジューダス/
jude /ジュード/ユダ/
judea /ユダヤ/
judge /ジャッジ/
judgement /ジャッジメント/
judi /ジュディ/
judith /ジュディス/ユーディット/ジュディット/
judy /ジュディ/ジュディー/
jug /ジャグ/ジョッキ/
jugend /ユーゲント/
juggle /ジャッグル/
juggler /ジャグラー/
juggling /ジャグリング/
juha /ユハ/
juice /ジュース/
juicer /ジューサー/
juicy /ジューシー/
juillet /ジュイエ/
juin /ジュアン/
juke /ジューク/
jukebox /ジュークボックス/
jukka /ユッカ/
jule /ジュール/
jules /ジュール/
julia /ジュリア/ユリア/フリア/
julian /ジュリアン/フリアン/
julianna /ジュリアナ/
julianus /ユリアヌス/
julie /ジュリー/
julien /ジュリアン/
juliet /ジュリエット/
juliette /ジュリエット/
julio /フリオ/ジュリオ/
julius /ユリウス/ジュリアス/
july /ジュライ/
jumbo /ジャンボ/
jump /ジャンプ/
jumper /ジャンパー/ジャンパ/
jumperpin /ジャンパピン/ジャンパーピン/
jumperskirt /ジャンパースカート;和製英語(jumper)/
jumping /ジャンピング/
jumpsuit /ジャンプスーツ/
junction /ジャンクション/
june /ジューン/
junebride /ジューンブライド/
junet /JUNET/
jung /ユング/
jungfrau /ユングフラウ/
jungle /ジャングル/
junglebook /ジャングルブック;1894,Kipling/
junglegym /ジャングルジム/
junior /ジュニア/
junius /ジュニアス/
junk /ジャンク/
junker /ユンカー/ユンケル;(独語)/
junkfood /ジャンクフード/
junkie /ジャンキー/
junkmail /ジャンクメール/
junky /ジャンキー/
juno /ジュノー/ユノ/ユーノ/ユーノー/
jupiter /ジュピター/ユピテル/
jupon /ズボン;仏語/
juponpresser /ズボンプレッサー;和製語(trouser press)/
jura /ジュラ/
jurassic /ジュラシック/
jurgen /ユルゲン/
juri /ユリ/ユーリ/
jus /Ｊｕｓ/ＪＵＳ/
jusco /ジャスコ/
jussi /ユッシ/
just /ジャスト/ジュス/
juste /ジュスト;仏語/
justfit /ジャストフィット/
justice /ジャスティス/
justification /ジャスティフィケーション/
justify /ジャスティファイ/
justin /ジャスティン/
justine /ジュスティーヌ/ジャスティン/
justmeet /ジャストミート;和製英語/
justsystem /ジャストシステム/
jute /ジュート/
juvenile /ジュブナイル/ジュヴナイル/
jv /共同企業体;joint venture/
jwave /Ｊ−ＷＡＶＥ/
k /κ;kappa/ケイ/ケー/к;ka (cyrillic)/キロ/カリウム/Potassium/χ;※(kh) chi/
ka /к;cyrillic/
kaaba /カーバ/
kaas /カース/
kabaddi /カバディ/
kabah /カーバ/
kabalevskii /カバレフスキー/
kabalevsky /カバレフスキー/
kabbala /カバラ/
kabul /カブール/
kadenz /カデンツ/
kaffein /カフェイン;(独語)/
kafka /カフカ/
kahla /カーラ/
kahler /カーラー/
kahlua /カルーア/カルア/
kahluamilk /カルアミルク/カルーアミルク/
kai /χ/カイ/
kailas /カイラス/
kain /ケイン/
kaiser /カイザー/カイゼル/
kaj /カイ/
kalahari /カラハリ/
kalanchoe /カランコエ/
kalashnikov /カラシニコフ/
kalbi /カルビ;(朝鮮語)/
kale /ケール/
kaleidoscope /カレイドスコープ/
kalevala /カレワラ/
kali /カーリー/
kalimantan /カリマンタン/
kalimba /カリンバ/
kaliope /カリオペ/
kalium /カリウム;[元素]19,K/
kaliumion /カリウムイオン;potassium ion/
kalk /カルキ;(独語)/
kalle /カレ/
kallisto /カリスト/
kalman /カルマン/
kalmia /カルミア/
kama /カーマ/
kamasutra /カーマスートラ/
kamchatka /カムチャッカ/カムチャツカ/
kamen /カーメン/
kamiokande /カミオカンデ;KAMIOKA Nucleon Decay Experiment/
kampala /カンパラ/
kampher /カンフル;(蘭語)/
kamuy /カムイ;(アイヌ語)神/
kana /カナ/
kanamycin /カナマイシン/
kandahar /カンダハル/
kandinsky /カンディンスキー/
kandy /キャンディ;紅茶/
kangaroo /カンガルー/
kangfu /カンフー/功夫/
kanon /カノン/
kansas /カンザス;KS/
kansascity /カンザスシティ/カンザスシティー/
kant /カント/
kantele /カンテレ/
kantor /カントル/
kaolin /カオリン/
kaolinite /カオリナイト/
kapo /カポ/
kappa /κ/カッパ/
kapsel /カプセル;(独語)/
kara /〜/
karaat /カラット;(蘭語)/
karachi /カラチ;パキスタン/
karajan /カラヤン/
karamazov /カラマーゾフ/
karaoke /カラオケ/
karaokebox /カラオケボックス/
karat /カラット/
karbala /カルバラ;イラク/
karel /カレル/
karelia /カレリア/
karen /カレン/
karenina /カレーニナ/
kari /カリ/
karin /カリン/カーリン/
karl /カール/カルル/
karlheinz /カールハインツ/
karlsruhe /カールスルーエ/
karma /カルマ/
karmen /カーメン/カルメン/
karna /カーナ/カルナ/
karrer /カーラー/
karst /カルスト/
karte /カルテ;(独語)/
kartell /カルテル;(独語)/
karzai /カルザイ/
kasein /カゼイン/
kashmir /カシミール/カシミヤ/カシミア/
kaspar /カスパー/カスパル/
kasper /カスパー/
kassovitz /カソヴィッツ/
kastner /ケストナー/
katalase /カタラーゼ/
katar /カタール;.qa/
kate /ケイト/ケート/
katerina /カテリーナ/カテリナ/
katharine /キャサリン/
katharsis /カタルシス/
kathe /ケーテ/
katherina /カテリーナ/カテリナ/
katherine /キャサリン/
katheter /カテーテル;(蘭語)/
kathleen /キャスリーン/キャスリン/キャサリン/
katholiek /カトリック;(蘭語)/
kathryn /キャスリン/
kathusha /カチューシャ;(日本語)/
kathy /キャシー/キャッシー/
kati /カティ/
katie /ケイティー/
kation /カチオン;(独語)/
katmandu /カトマンズ/
katrin /カトリン/カトリーン/
katrina /カトリーナ/
katyusha /カチューシャ/
kauai /カウアイ/
kaufman /カウフマン/
kaufmann /カウフマン/
kaus /カウス/
kavkaz /カフカス/
kawai /カワイ/
kaxgar /カシュガル;中国/
kay /ケー/ケイ/
kayak /カヤック/
kazakh /カザフ/
kazakhstan /カザフスタン;.kz/
kazan /カザン/
kazoo /カズー/
kb /キーボード/キロバイト/
kbbutz /キブツ/
kbyte /キロバイト/
kcl /KCL/
kcup /Kカップ/Ｋカップ/
kean /キーン/
keaton /キートン/
keats /キーツ/
kebab /ケバブ/カバブ/
kechak /ケチャ/
keema /キーマ/
keemun /キーマン/
keen /キーン/
keene /キーン/
keep /キープ/
keepalive /キープアライブ/
keeper /キーパー/
keeping /キーピング/
kefir /ケフィア/
keita /ケイタ/
keith /キース/
keller /ケラー/
kellogg /ケロッグ/
kelly /ケリー/
keloid /ケロイド/
kelvin /ケルビン/
kemp /ケンプ/
kempff /ケンプ/
ken /ケン;Kenneth/
kenaf /ケナフ/
kendall /ケンドール/
kennedy /ケネディ/
kennel /ケンネル/ケネル/
kenneth /ケネス/
kenny /ケニー/
kent /ケント/
kentauros /ケンタウロス/
kentucky /ケンタッキー/
kenwood /ケンウッド/Ｋｅｎｗｏｏｄ/
kenya /ケニア;.ke/ケニヤ/
kepheus /ケフェウス/
kepler /ケプラー/
keratin /ケラチン/
kerberos /ケルベロス/
keris /クリス/
kern /カーン/ケルン/
kernel /カーネル/
kerner /ケルナー/
kernighan /カーニハン/
kerning /カーニング/
kerosene /ケロシン/
kerouac /ケルアック/
kerr /カー/カール/ケア/ケル/
kerry /ケリー/
kessel /ケッセル/
kessler /ケスラー/
ketamine /ケタミン;C13H16ClNO・HCl/
ketchup /ケチャップ/
ketone /ケトン/
kettle /ケトル/
ketty /ケティ/
kevin /ケビン/ケヴィン/
kevlar /ケブラー/
kewpie /キューピー/
key /キー/キイ/ケイ/
keyassign /キーアサイン/
keybind /キーバインド/
keybinding /キーバインディング/
keyboard /キーボード/
keyboardist /キーボーディスト/
keyboardmacro /キーボードマクロ/
keycase /キーケース/
keycode /キーコード/
keyconcept /キーコンセプト/
keyholder /キーホルダー/
keyling /キーリング;豪州/
keylock /キーロック/
keylogger /キーロガー/
keyman /キーマン/
keymap /キーマップ/
keynes /ケインズ/
keynesian /ケインジアン/
keynote /キーノート/
keypad /キーパッド/
keyperson /キーパーソン/
keyphrase /キーフレーズ/
keypitch /キーピッチ/
keypoint /キーポイント;key point/
keypuncher /キーパンチャー/
keyring /キーリング/
keysequence /キーシーケンス/
keystation /キーステーション/
keystone /キーストーン/
keystroke /キーストローク/
keytop /キートップ/
keytouch /キータッチ/
keyword /キーワード/
keywordsearch /キーワードサーチ/
kfc /ケンタッキーフライドチキン/
kg /キログラム/Ｋｇ/
kh /χ;chi/х;xa (cyrillic)/
khabarovsk /ハバロフスク/
khachaturyan /ハチャトゥリアン/
khaki /カーキ/
khan /カン/カーン/ハン/ハーン/汗/
kharakhorum /カラコルム/
khartoum /ハルツーム/
khmer /クメール/
khoisan /コイサン/
khomeini /ホメイニ/
khoomei /ホーメイ/
khoomii /ホーミー/
khorosho /ハラショー;(露語)/
khrushchev /フルシチョフ/
khubilai /フビライ/忽必烈/忽比烈/
khufu /クフ/
kick /キック/
kickback /キックバック/
kickboard /キックボード/
kickboxer /キックボクサー/
kickboxing /キックボクシング/
kicker /キッカー/
kickin /キックイン/
kickoff /キックオフ/
kicks /キックス/
kickstart /キックスタート;kick-start/
kid /キッド/
kidd /キッド/
kidnap /キッドナップ/
kidney /キドニー/
kids /キッズ/
kidsroom /キッズルーム;託児室/
kiefer /キーファー/
kieffer /キーファー/
kiel /キール/
kier /キア/
kiev /キエフ/
kigali /キガリ/
kiki /キキ/
kilauea /キラウエア/
kilia /キリア/
kilimanjaro /キリマンジャロ/
kill /キル/
killer /キラー/
killers /キラーズ/
killing /キリング/
kilmer /キルマー/
kiln /キルン/窯/
kilo /キロ;K,10^3/
kilobyte /キロバイト/
kilobytes /キロバイト/
kilocalorie /キロカロリー/
kilogram /キログラム/
kiloliter /キロリットル/
kilolitre /キロリットル/
kilometer /キロメートル/
kilometre /キロメートル/
kilowatt /キロワット/
kilt /キルト/
kim /キム/金/
kimberley /キンバリー/
kimberly /キンバリー/
kimchi /キムチ;(朝鮮語) kimch'i/
kimi /キミ/
kin /キン/
kina /キナ/
kinase /キナーゼ/
kind /カインド/
kinder /キンダー/
kinema /キネマ;kinematograph/
kinesiology /キネシオロジー/
kinetic /キネティック/
kinetin /カイネチン/キネチン/
king /キング/
kingdom /キングダム/
kingkong /キングコング/
kingof /キング・オブ・/キングオブ/
kingrecord /キングレコード/
kings /キングス/キングズ/
kingsalmon /キングサーモン/
kingsize /キングサイズ/
kingston /キングストン/
kingstown /キングスタウン/
kinine /キニーネ/
kinsey /キンゼイ/
kinshasa /キンシャサ;コンゴ民主共和国/
kinski /キンスキー/
kiosk /キオスク/キヨスク/
kipling /キプリング/キップリング/
kir /キール/
kira /キラ/
kirby /カービィ/カービー/
kirchhoff /キルヒホッフ/
kirgistan /キルギスタン/
kirgiz /キルギス/
kiribati /キリバス;.ki/
kirinbeer /キリンビール/
kirk /カーク/
kirkland /カークランド/
kirsch /キルシュ/
kirsten /キルステン/
kirsty /カースティ/
kishinyov /キシニョフ/
kiska /キスカ/
kiss /キス/キッス/×××/
kissin /キーシン/
kissinger /キッシンジャー/
kissmark /キスマーク;和製英語(lovebite)/
kissscene /キスシーン/
kit /キット/
kitchen /キッチン/
kitchencounter /キッチンカウンター/
kitchenette /キチネット/
kitchenknife /キッチンナイフ/
kitchenpaper /キッチンペーパー/
kitchenscale /キッチンスケール/
kitchensink /キッチンシンク/
kitchentimer /キッチンタイマー/
kitchenware /キッチンウェア/
kite /カイト/
kithara /キタラ/
kitkat /キットカット;[商標]/
kitsch /キッチュ;(独語)/
kittel /キッテル/
kitto /キット/
kitty /キティ/キティー/
kittyhawk /キティホーク;Kitty Hawk, USA/
kiwi /キウイ/キウィ/
kk /株式会社/（株）/
kkbestsellers /KKベストセラーズ;www.kk-bestsellers.com/
kl /└;vi式罫線入力/┗;太/キロリットル/
klar /クラール/
klara /クララ/クラーラ/
klaus /クラウス/
klavichord /クラヴィコード;(独語)/クラビコード/
klavier /クラヴィーア/クラヴィア/
klaxon /クラクション/
klee /クレー/
kleene /クリーネ/
kleiber /クライバー/
klein /クライン/
klemperer /クレンペラー/
klezmer /クレズマー/
klien /クリエン/
klimt /クリムト/
klose /クローゼ/
kluger /クルーガー/
klum /クラム/
km /Ｋｍ/
kmc /京大マイコンクラブ/
knack /ナック/
knapsack /ナップザック/ナップサック/
knee /ニー/
kneedrop /ニードロップ/
kneel /ニール/
kneepad /ニーパッド/
kneesocks /ニーソックス/
kneesox /ニーソックス;knee socks/
knife /ナイフ/
knight /ナイト/
knights /ナイツ/
knit /ニット/
knitcap /ニットキャップ/
knitshirt /ニットシャツ/
knitting /ニッティング/
knob /ノブ/
knock /ノック/
knockdown /ノックダウン/
knocker /ノッカー/
knocking /ノッキング/
knockout /ノックアウト/
knomeini /ホメイニ/
knot /ノット/節/
knotting /ノッティング/
know /ノウ/
knowhow /ノウハウ/
knowledge /ナレッジ/
known /ノーン/ノウン/
knuckle /ナックル/
knut /クヌート/
knuth /クヌース/
ko /ＫｎｏｃｋＯｕｔ/
koala /コアラ/
koblenz /コブレンツ/
kobold /コボルド/
koch /コッホ/
kochel /ケッヘル/
kocher /コッヘル/
kodak /コダック;www.kodak.com/
kodaly /コダーイ;(1882-1967)Kodaly Zoltan/
koehler /ケーラー/
kohl /コール/
kohler /ケーラー/コーラー/
kohlrabi /コールラビ/
kok /コック;(蘭語)/
kokand /コーカンド/
koks /コークス;(独語)/
kolchizin /コルヒチン/
kolkata /コルカタ/
kolkhoz /コルホーズ/
kollagen /コラーゲン;(独語)/
kolmogorov /コルモゴロフ/
koln /ケルン/
kolossai /コロサイ/
kolsch /ケルシュ/
kombinat /コンビナート;(露語)/
kome /※/
komi /コミ/
kommentar /コンメンタール/
komodo /コモド;インドネシア/
komododragon /コモドドラゴン;Komodo dragon/
kona /コナ/
kondom /コンドーム;(独語)/
kondratieff /コンドラチェフ/
kong /コング/
konica /コニカ;www.konicaminolta.jp/
konide /コニーデ/
konitz /コニッツ/
konrad /コンラッド/コンラート/
konstantin /コンスタンティン/
konstanz /コンスタンツ/
konzern /コンツェルン/
konzert /コンツェルト/
koran /コーラン/クルアーン/
korea /コリア/
korean /コリアン/
korg /コルグ/
koror /コロール/
korsakov /コルサコフ/
kosma /コスマ/
kosmos /コスモス;ギリシア語/
kosovo /コソボ/コソヴォ/
kotakinabalu /コタキナバル;マレーシア/
kouglof /クグロフ/
koumiss /クミス/
kr /クリプトン/Krypton/
kraan /カラン;(蘭語)/
kraepelin /クレペリン/
kraken /クラーケン/
krakow /クラクフ/
kramer /クレーマー/クレイマー/
kranke /クランケ/
krasnoyarsk /クラスノヤルスク/
kraus /クラウス/
krause /クラウゼ/
krauss /クラウス/
kreapelin /クレペリン/
kreis /クライス;(独語)領分/
kreisler /クライスラー/
kremer /クレーメル/
kremlin /クレムリン/
kreta /クレタ/
kretschmer /クレッチマー/
kreutzer /クロイツェル/クロイツァー/
kreuz /クロイツ/
kripke /クリプキ/クリプケ/
kris /クリス/
krishna /クリシュナ/
kriss /クリス/
kristel /クリステル/
kristeva /クリステヴァ/
kristian /クリスチャン/クリスティアン/
kristiania /クリスチャニア/
kristin /クリスティン/
kristina /クリスティーナ/クリスティナ/
kronecker /クロネッカー/
kroneckerdelta /クロネッカーのデルタ/
kronos /クロノス/
krsna /クリシュナ/
kruger /クルーガー/
krugman /クルーグマン/
krym /クリム/
krypton /クリプトン;[元素]36,Kr/
ks /Kansas/カンサス/カンザス/
ksatriya /クシャトリア/クシャトリヤ/
kterm /KTerm/
kualalumpur /クアラルンプール;Kuala Lumpur/
kuantan /クアンタン;マレーシア(kua)/
kubelik /クーベリック/
kubota /クボタ/
kubrick /キューブリック/
kuchen /クーヘン;(独) 菓子/
kugel /クーゲル/
kuhn /クーン/
kuijken /クイケン/
kuiper /カイパー/
kuli /クーリー/
kumiss /クミス/
kundera /クンデラ/
kunlun /クンルン/
kunst /クンスト;(独語)芸術/
kunz /クンツ/
kurd /クルド/
kurhaus /クアハウス/
kurt /カート/クルト/
kurz /クルツ/
kuwait /クウェート;.kw/
ky /Kentucky/ケンタッキー/
kypros /キプロス/
kyrgyzstan /キルギス;.kg/
kyrie /キリエ/
l /λ;lambda/エル/л;el (cyrillic)/リットル/
la /ラ/Lanthanum/ランタン/Louisiana/ルイジアナ/
lab /ラボ/研究室/
laban /ラバン/
label /ラベル/レーベル/
labelgate /レーベルゲート/
labelgatecd /レーベルゲートCD/
labeling /ラベリング/ラベル付け/
labelwidget /ラベル・ウィジット/
labia /ラビア/
labo /ラボ;laboratory/
labor /レイバー/レーバー/
laboratories /ラボラトリーズ/
laboratory /ラボラトリー/ラボラトリ/
labour /レイバー/レーバー/
labrador /ラブラドル/ラブラドール/
labradorretriever /ラブラドールレトリバー;Labrador retriever/
labyrinth /ラビリンス/
lacan /ラカン/
lace /レース/
lacecurtain /レースカーテン/
lacey /レイシー/
lack /ラック/
laclos /ラクロ/
lacoste /ラコステ/
lacquer /ラッカー/
lacroix /ラクロワ/
lacrosse /ラクロス/
lact /ラクト/
lactam /ラクタム/
lactice /ラクトアイス;和製英語(lacto + ice)/
lacto /ラクト/
lactoice /ラクトアイス;和製英語(lacto + ice)/
lactone /ラクトン/
lacy /レイシー/
lad /ラッド/
ladder /ラダー;梯子/
laden /ラディン/
ladies /レディース/レディス/
ladiescomic /レディースコミック/
ladle /レードル/
lado /ラド/
ladon /ラドン/
lady /レディ/レディー/
ladyborden /レディーボーデン;[商標]ロッテ/レディボーデン/
ladyfirst /レディーファースト;ladies first/レディファースト/
laetitia /レティシア/
lafaro /ラファロ;LaFaro/
lafayette /ラファイエット;La Fayette/
lafcadio /ラフカディオ/
lafite /ラフィット/
lafont /ラフォン/
lafontaine /ラ・フォンテーヌ;La Fontaine/ラフォンテーヌ/
laforet /ラフォーレ;(Fr) la foret/
laforgue /ラフォルグ/
lafrance /ラフランス;(日本産の洋梨)/
lag /ラグ/
lage /ラーゲ;(独語)/
lager /ラガー/ラーゲリ;(露)лагерь/
lagerbeer /ラガービール/
lagerfeld /ラガーフェルド/
lago /ラーゴ/
lagoon /ラグーン/
lagos /ラゴス/
lagrange /ラグランジュ/ラグランジェ/
lagrangian /ラグランジアン/
lagtime /ラグタイム;lag time/
lahore /ラホール/
lai /レイ/
laila /レイラ/ライラ/
laine /レーヌ;(Fr)羊毛/レーン/
laing /レイン/
lair /レア/
laisserfaire /レッセフェール;laisser faire/
laissezfaire /レッセフェール;laissez faire/
lake /レイク/レーク/
lakeside /レイクサイド/レークサイド/
lakshmi /ラクシュミ/ラクシュミー/
lala /ララ/
lalala /ラララ/
lally /ラリー/
lama /ラマ/
lamancha /ラマンチャ;La Mancha/ラ・マンチャ/
lamarck /ラマルク/
lamarseillaise /ラ・マルセイエーズ;La Marseillaise (フランス国歌)/
lamaze /ラマーズ/
lamb /ラム/
lambada /ランバダ/
lambchop /ラムチョップ;lamb chop/
lambda /λ/ラムダ/λ-算法/
lambert /ランバート/ランベール/ランベルト/
lamborghini /ランボルギーニ;www.lamborghini.com/
lambrusco /ランブルスコ/
lame /ラメ/レイム/
laminate /ラミネート/
lamp /ランプ/
lampshade /ランプシェード/
lamy /ラミー/
lan /LAN/
lana /ラナ/ラーナ/
lanboard /LANボード/
lancable /LANケーブル/
lancard /LANカード/
lancashire /ランカシャー/
lancaster /ランカスター/
lance /ランス/
lancelot /ランスロット/ランスロ/ラーンスロット/
lancer /ランサー/
lancet /ランセット/
lancia /ランチア;www.lancia.com/
land /ランド/∧/
landcruiser /ランドクルーザー/
landing /ランディング/
landmark /ランドマーク/
landmarktower /ランドマークタワー;横浜/
lando /ランド/
landrover /ランドローバー/
landsat /ランドサット/
landscape /ランドスケープ/
landy /ランディ/
lane /レーン/
lang /ラング/
langage /ランガージュ/
langerhans /ランゲルハンス/
langkawi /ランカウイ;マレーシア(lgk)/
langley /ラングレー/
langsam /ラングザーム/ラングザム/
language /ランゲージ/
langue /ラング/
languedechat /ラングドシャ;langue de chat/
languedoc /ラングドック;Langue d'Oc/
lanina /ラニーニャ;La Nina/
lantana /ランタナ/
lantern /ランタン/
lanthanoid /ランタノイド/
lanthanum /ランタン;[元素]57,La/
lanza /ランツァ/
laocoon /ラオコーン;英語綴り/
laokoon /ラオコーン/
laon /ラン/
laos /ラオス;.la/
laox /ラオックス;www.laox.co.jp/
lap /ラップ/
lapaz /ラパス;La Paz/
lapis /ラピス;石/
lapislazuli /ラピスラズリ;lapis lazuli/
laplace /ラプラス/
laplacian /ラプラシアン/
lapland /ラップランド/
laplata /ラプラタ;La Plata/
lapp /ラップ/
lapping /ラッピング/
laptime /ラップタイム/
laptop /ラップトップ/
laputa /ラピュタ/
lara /ララ/ラーラ/
larc /ラルク;l'arc. (Fr)弓/
lard /ラード/
large /ラージ/
largehill /ラージヒル/
largesize /ラージサイズ/
larghetto /ラルゲット/
largo /ラルゴ/
lariat /ラリアット/ラリアート/
lark /ラーク/
larmen /ラーメン;?/
laroche /ラロッシュ/
larousse /ラルース/
larry /ラリー/ラリイ/ラリィ/
lars /ラーズ/ラルス/
larsen /ラーセン/ラルセン/
las /ラス/
lasagna /ラザニア/ラザーニャ/
lasalle /ラサール/ラ・サール/
lascaux /ラスコー/
laser /レーザー/レーザ/
laserbeam /レーザービーム/
laserdisc /レーザーディスク/
laserdisk /レーザーディスク/
laserpointer /レーザーポインター/レーザーポインタ/レーザポインタ/
laserprinter /レーザープリンタ/レーザープリンター/レーザプリンタ/
laserwriter /レーザーライタ/ＬａｓｅｒＷｒｉｔｅｒ/
lasse /ラッセ/
lassen /ラッセン/
lassi /ラッシー;インド風飲むヨーグルト/
last /ラスト/
lastboss /ラスボス/
lastdance /ラストダンス/
lastname /ラストネーム/
lastnumber /ラストナンバー/
lastorder /ラストオーダー/
lastresort /ラストリゾート;last resort. 最後の拠り所/
lastscene /ラストシーン/
lastspurt /ラストスパート/
lasvegas /ラスベガス/
laswell /ラズウェル/
latch /ラッチ/
late /レイト/レート/
latency /レイテンシ/レイテンシー/
lateral /ラテラル/
lateshow /レイトショー/
latex /ラテックス;ゴム/ラテフ;LaTeX/ＬａＴｅＸ/ＬAＴEＸ/LaTeX/\LaTeX/
latin /ラテン/
latin# /Latin-#0/
latinamerica /ラテンアメリカ/
latour /ラトゥール/
lattice /ラティス/ラチス/
latvia /ラトビア;.lv/ラトヴィア/
lauan /ラワン/
laud /ロード/
lauda /ラウダ/
laude /ロード/
laue /ラウエ/
laugh /ラフ/
laughing /ラフィング/ラーフィング/
launcer /ランチャー/ランチャ/
launch /ランチ/
launcher /ランチャー/ランチャ/
launder /ロンダ/
laundering /ロンダリング/
laundry /ランドリー/
laura /ローラ/ラウラ/
laure /ロール/
laurel /ローレル/
lauren /ローレン/
laurence /ローレンス/ロレンス/ローランス/
laurencin /ローランサン/
laurent /ロラン/ローラン/
laurie /ローリー/
laurier /ローリエ/
lauro /ラウロ/
lausanne /ローザンヌ/
laut /ラウト/
lautreamont /ロートレアモン/
lautrec /ロートレック;(1864-1901)Henri de Toulouse-Lautrec/
lavender /ラベンダー/ラヴェンダー/
law /ロー/
lawn /ローン;芝/
lawntennis /ローンテニス/
lawrence /ローレンス/ロレンス/
lawrencium /ローレンシウム;[元素]103,Lr/
lawschool /ロースクール/
lawson /ローソン/Ｌａｗｓｏｎ/
lawsonticket /ローソンチケット;www2.lawsonticket.com/
lay /レイ/
laydock /レイドック/
layer /レイヤー/レイヤ/
layered /レイヤード/
layman /レイマン/
laymantype /レイマン型/
layoff /レイオフ/
layout /レイアウト/
layoutsystem /レイアウトシステム/
laytracing /レイトレーシング;※ray tracing/
lazare /ラザール/
lazaro /ラザロ/
lazarus /ラザロ/ラザルス/ラザラス/
lazer /レーザー/レーザ/
lazerbeam /レーザービーム;※laserbeam/
lazy /レイジー/
lbp /レーザビームプリンタ/
lcd /液晶;liquid crystal display/
ld /LD/
ldots /.../
le /ル;仏語/≦/
lea /レア/
lead /リード/
leader /リーダー/リーダ/
leaderalbum /リーダーアルバム/
leadership /リーダーシップ/
leadguitar /リードギター/
leading /リーディング/
leadoff /リードオフ/
leadoffman /リードオフマン/
leadtime /リードタイム;所要時間/
leadvocal /リードボーカル/
leaf /リーフ/
leaflet /リーフレット/
leafpie /リーフパイ/
league /リーグ/
leaguer /リーガー/
leah /リア/レア/
leak /リーク/
lean /リーン/
learn /ラーン/
learner /ラーナー/
learning /ラーニング/学習/
lease /リース/
leasing /リーシング/
leather /レザー/
leathercraft /レザークラフト/
leave /リーブ/
leaves /リーブス/リーヴス/リーブズ/
leaving /リービング/
lebanon /レバノン;.lb/
lebesgue /ルベーグ/
leblanc /ルブラン/
lechatelier /ルシャトリエ;Henry Louis Le Chatelier (1850-1936)/
lecithin /レシチン/
leconte /ルコント/
lector /レクター/
lecture /レクチャー/レクチャ/
leda /レダ/
ledlight /LEDライト/
ledoux /ルドゥー/
lee /リー/李/
leeds /リーズ/
leek /リーキ/リーク;ねぎ/
lees /リース/
lefevre /ルフェーブル/
left /レフト/←/左/
leftarrow /←/
leftfly /レフトフライ/
leftover /レフトオーバー/
lefty /レフティ/レフティー/
leg /レッグ/
legacy /レガシー/レガシィ/
legal /リーガル/
legato /レガート/
legend /レジェンド/
legendary /レジェンダリー/
legendre /ルジャンドル/
legends /レジェンズ/
leger /レジェ/
leggiero /レッジェーロ/レジェーロ/
leghorn /レグホーン/
legiondhonneur /レジオンドヌール;Legion d'honneur/
legionella /レジオネラ/
lego /レゴ/
legrand /ルグラン;le Grand/
legwarmer /レッグウォーマー/
lehar /レハール/
lehavre /ルアーブル;Le Havre/
lehman /リーマン/レーマン/
lehmann /レーマン/
leibniz /ライプニッツ/
leica /ライカ/
leiden /ライデン/
leier /ライアー/ライエル/
leigh /レイ/
leila /レイラ/リーラ/
leipzig /ライプチヒ/ライプツィヒ/
leisure /レジャー/
leisureland /レジャーランド;和製英語/
leisuresports /レジャースポーツ/
leitmotiv /ライトモチーフ/
leloup /ルルー/
lem /レム/
lema /レマ/
lemaire /ルメール/
lemans /ルマン;Le Mans/
lemma /レンマ/Lemma/補題/
lemming /レミング/
lemon /レモン/檸檬/
lemonade /レモネード/ラムネ;NB:lemonadeの訛り/
lemonbalm /レモンバーム/
lemonde /ルモンド;Le Monde. lemonde.fr/ル・モンド/
lemongrass /レモングラス/
lemonpeel /レモンピール;lemon peel/
lemonpie /レモンパイ/
lemonsour /レモンサワー/
lemonsquash /レモンスカッシュ/
lemontea /レモンティー/
lemonyellow /レモンイエロー/
len /レン/
lena /レナ/レイナ/レーナ/リーナ/
lender /レンダー;貸し手/
length /レングス/
lenin /レーニン/
leningrad /レニングラード;現・Sankt-Peterburg/
lennie /レニー/
lennon /レノン/
lenny /レニー/
lenore /レノア/
lenovo /レノボ/聯想;[企業名]www.lenovo.com/
lenox /レノックス/
lens /レンズ/
lenscase /レンズケース/
lenscover /レンズカバー/
lense /レンズ/
lenshood /レンズフード;lens hood/
lento /レント/
lenz /レンツ/
leo /レオ/
leon /レオン/
leona /レオナ/
leonard /レオナルド/レナード/レオナール/
leonardo /レオナルド/
leonardodavinci /レオナルドダヴィンチ;(1452-1519) Leonardo da Vinci/レオナルド・ダ・ヴィンチ/
leone /レオーネ/
leonhard /レオンハルト/
leonhardt /レオンハルト/
leonhart /レオンハルト/
leoni /レオーニ/
leonid /レオニード/
leonor /レオノール/
leonora /レオノーラ/
leonore /レオノール/レオノーレ/
leopalace /レオパレス;[企業名]/
leopold /レオポルド/レオポルト/
leopoldo /レオポルド/
leotard /レオタード/
leoville /レオヴィル/
leprechaun /レプラコーン/
lepton /レプトン/
leq /≦/
leroux /ルルー/
leroy /リロイ;LeRoy/ルロイ/ルロワ/
les /レ/
lesbian /レズビアン/レズ/
lesbos /レスボス/
lescault /レスコー/
lescaut /レスコー/
lesley /レズリー/レスリー/
leslie /レスリー/レズリー/
lesmiserables /レミゼラブル;Les Miserables,1862,Hugo/レ・ミゼラブル/
lesotho /レソト;.ls/
lespaul /レスポール;Les Paul/
less /レス/
lesser /レッサー/
lesserpanda /レッサーパンダ/
lessig /レッシグ/
lessing /レッシング/
lesson /レッスン/
lester /レスター/
let /レット/
lethal /リーサル/
leto /レト/
lets /レッツ;let's/
letsgo /レッツゴー/
letter /レター/レッテル;(蘭語) NB:label(En)/手紙/
letterhead /レターヘッド/
lettering /レタリング/
letteropener /レターオープナー/
letterset /レターセット/
lettie /レティ/
lettuce /レタス/
lettucesalad /レタスサラダ/
letty /レティ/
leucin /ロイシン;Leu/
leukotriene /ロイコトリエン;LT/
lev /レフ/
levan /レヴァン/
level /レベル/レヴェル/
leveldown /レベルダウン/
levelup /レベルアップ/
lever /レバー/
leverage /レバレッジ/
levi /レビ/レヴィ/
leviathan /リヴァイアサン/リバイアサン/レヴィアタン/
levin /レビン/レヴィン/
levinas /レヴィナス/
levine /レヴィン/レヴァイン/
levis /リーバイス;[商標]Levi's/
levistrauss /レヴィ=ストロース;Claude Levi-Strauss/
levit /レビ/
levy /リービ/レヴィ/レビ/レビー/レヴィー/
lew /ルー/リュー/
lewie /ルーイ/
lewin /レビン/レヴィン/ルウィン/リューイン/
lewis /ルイス/
lex /レックス;法/レクス/
lexical /レキシカル/
lexicon /レキシコン/
lexington /レキシントン/
lexus /レクサス;[商標]トヨタ/
leyte /レイテ/
lf /ロジカル・フレームワーク/
lhasa /ラサ/拉薩/
lhotse /ローツェ/
li /リチウム/Lithium/
lia /リア/
liaison /リエゾン/
liam /リアム/リーアム/
liane /リアーヌ/
liar /Ｌｉａｒ/
lib /ライブラリ/ライブラリー/リブ/
libby /リビー/
libera /リベラ/
liberal /リベラル/
liberalism /リベラリズム/
liberalist /リベラリスト/
liberation /リベレーション/リベラシオン;仏語/
liberia /リベリア;.lr/
libero /リベロ/
libertarian /リバタリアン/
libertarianism /リバタリアニズム/
liberte /リベルテ;(Fr)自由/
liberty /リバティ/リバティー/
libido /リビドー/
libra /リブラ;天秤座/リーブラ/
librarian /ライブラリアン/
library /ライブラリ/ライブラリー/
libre /リーブル;(Fr)自由な/
libro /リブロ/
libya /リビア;.ly/
licence /ライセンス/
licencekey /ライセンスキー/
license /ライセンス/
licensee /ライセンシー/
licensekey /ライセンスキー/
licenser /ライセンサー/
licensing /ライセンシング/
lich /リッチ/
lichtenstein /リキテンシュタイン/リキテンスタイン/
lick /リック/
lid /リッド/
lida /リーダ/リダ/
liddell /リデル/
liddi /リディ/
liddy /リディ/
lidia /リディア/
lidocaine /リドカイン/
liebe /リーベ;(独) 愛/
liechtenstein /リヒテンシュタイン;.li/
lied /リート/
lieder /リーダー/
liege /リエージュ/
liesa /リーザ/
liese /リーゼ/
lieu /リュー;(Fr)場所/
life /ライフ/
lifeboat /ライフボート/
lifecycle /ライフサイクル/
lifegame /ライフゲーム/
lifeguard /ライフガード/
lifehistory /ライフヒストリー/
lifejacket /ライフジャケット/
lifeline /ライフライン/
lifeplan /ライフプラン/
lifesaver /ライフセーバー/
lifesaving /ライフセービング/
lifescience /ライフサイエンス/
lifeservice /ライフサービス/
lifestage /ライフステージ/
lifestyle /ライフスタイル/
lifetime /ライフタイム/
lifework /ライフワーク/
lift /リフト/
lifter /リフター/
lifting /リフティング/
liftup /リフトアップ/
light /ライト/
lightbeige /ライトベージュ/
lightblue /ライトブルー/
lightbrown /ライトブラウン/
lighter /ライター/
lightgray /ライトグレー/
lightgreen /ライトグリーン/
lightgrey /ライトグレー/
lighthouse /ライトハウス/
lighting /ライティング/
lightmiddle /ライトミドル/
lightning /ライトニング/
lightnovel /ライトノベル/
lightup /ライトアップ/
lightvan /ライトバン/
lightyellow /ライトイエロー/
lignan /リグナン/
lignin /リグニン/
lihue /リフエ;lih/
like /ライク/
likud /リクード/
lil /リル/
lila /リラ/
lilac /リラ/ライラック/
lilas /リラ/
lili /リリー/リリ/
lilia /リリア/
lilian /リリアン/
liliane /リリアン/
lilienthal /リリエンタール/
lille /リール/
lilli /リリ/リリー/
lillian /リリアン/
lillie /リリー/
lilliput /リリパット/
lilly /リリー/
lilongwe /リロングウェ/
lily /リリー/リリィ/
lima /リマ/
liman /リマン/
limbo /リンボー/リンボ/
limbodance /リンボーダンス;limbo/
lime /ライム/
limegreen /ライムグリーン/
limelight /ライムライト/
limit /リミット/
limitcycle /リミットサイクル/
limited /リミテッド/
limiter /リミッター/リミッタ/
limoges /リモージュ/
limoncello /リモンチェッロ/
limonen /リモネン/
limousine /リムジン/
limousinebus /リムジンバス/
lin /リン/
lina /リナ/リーナ/
lincoln /リンカーン/
linda /リンダ/
lindberg /リンドバーグ;(ポピュラーバンド名)/
lindbergh /リンドバーグ;(1902-1974) Charles Augustus Lindbergh 飛行家/
linden /リンデン/
lindgren /リンドグレーン/
lindie /リンディ/リンディー/
lindsay /リンゼイ/リンジー/
lindsey /リンゼイ/リンジー/
lindy /リンディ/
line /ライン/￣/＿/リーネ;(独語人名)/リヌ/
lineage /リネージュ;[ゲーム]www.lineage.com/
linear /リニア/
linearmotor /リニアモーター/
linearmotorcar /リニアモーターカー/
lineback /ラインバック;linebacker/
linebacker /ラインバッカー/
linedance /ラインダンス/
linefeed /ラインフィード/
linein /ラインイン/
linen /リネン/
lineout /ラインアウト/
liner /ライナー/
linernote /ライナーノート/
linernotes /ライナーノーツ/
lineset /ラインセット/
linet /リネット/
lineup /ラインナップ/ラインアップ/
ling /リング/リン/
linga /リンガ/
linger /リンガー/
lingerie /ランジェリー/
lingerieshop /ランジェリーショップ/
lingua /リンガ;(Lat) 言語/
linguafranca /リンガフランカ/
lingual /リンガル/
lining /ライニング/
link /リンク/
linkage /リンケージ/
linkbanner /リンクバナー/
linked /リンクト/
linker /リンカ/リンカー/
linkfield /リンクフィールド/
linkfree /リンクフリー;当然/
linkpage /リンクページ/
linkpolicy /リンクポリシー/
links /リンクス/
linksite /リンクサイト/
linn /リン/
linne /リンネ/
linnea /リネア/
linnet /リネット/
lino /リノ/
linoleum /リノリウム/
linsey /リンゼイ/
lint /リント/
linus /ライナス/リーナス/リヌス/
linux /リナックス/ライナックス/リヌクス/リヌックス/リーヌックス/Linux/
linz /リンツ/
lion /ライオン/
lionel /ライオネル/リオネル/
lioness /ライオネス/
lions /ライオンズ/
lionsclub /ライオンズクラブ;www.lionsclub.org/
lionsmansion /ライオンズマンション;[商標]大京/
lip /リップ/
lipase /リパーゼ/
lipbrush /リップブラシ/
lipcream /リップクリーム/
lipline /リップライン/
lipliner /リップライナー/
lipo /リポ/
lippi /リッピ/
lips /リップス/
lipservice /リップサービス/
lipslur /リップスラー/
lipstick /リップスティック/
lipton /リプトン;www.lipton.com/
liqueur /リキュール/
liquid /リキッド/
liquor /リカー/
lira /リラ/
lirica /リリカ/
lirico /リリコ/
lisa /リサ/リザ/リーザ/ライザ/
lisbon /リスボン/
lisle /ライル/リール/
lisleadam /リラダン;(1838-1889) Auguste de Villiers de L'Isle-Adam/
lisp /リスプ/Ｌｉｓｐ/Lisp/
lisper /Ｌｉｓｐｅｒ/ｌｉｓｐｅｒ/
lissa /リサ/
list /リスト/
listbox /リストボックス/
listen /リッスン/
listener /リスナー/リスナ/
listening /リスニング/
listing /リスティング/
listup /リストアップ/
liszt /リスト/
lit /リット/
litchi /ライチ/
lite /ライト/Ｌｉｔｅ/
liter /リットル/リッター/リター/
literacy /リテラシー/リテラシ/
literal /リテラル/
lithium /リチウム/
lithiumion /リチウムイオン;lithium-ion/
lithograph /リトグラフ/
lithography /リソグラフィ/リソグラフィー/
lithuania /リトアニア;.lt/
litmus /リトマス/
litre /リットル/リッタ/
littbarski /リトバルスキー/
litter /リットル/リッター/リター/
little /リトル/
littleleague /リトルリーグ/
littre /リトレ/
live /ライブ/ライヴ/
livealbum /ライブアルバム/
livecamera /ライブカメラ/
livecd /ライブCD/
livechat /ライブチャット/
livedoor /ライブドア;livedoor.com/
livedvd /ライブDVD/
liveevent /ライブイベント/
livehouse /ライブハウス/ライヴハウス/
livelock /ライブロック/
lively /ライブリー/
liver /レバー/
liverecording /ライブレコーディング/
livereport /ライブレポート/
liverpaste /レバーペースト/
liverpool /リバプール/リヴァプール/
lives /ライブス/
liveschedule /ライブスケジュール/
liveshow /ライブショー/
liveticket /ライブチケット/
livetour /ライブツアー/
liveunderthesky /ライヴ・アンダー・ザ・スカイ/
livevideo /ライブビデオ/
living /リビング/
livingdead /リビングデッド/
livingroom /リビングルーム/
livingstone /リビングストン/リヴィングストン/
livingtable /リビングテーブル/
livre /リーブル/リーヴル/£/
liz /リズ/
liza /リザ/ライザ/
lizard /リザード/
lizardman /リザードマン/
lizzie /リジー;Elizabeth/
lizzy /リジー;Elizabeth/
ljubljana /リュブリャーナ/
ll /≪/
lladro /リヤドロ/
llama /ラマ/リャマ/
lloyd /ロイド/
llsize /LLサイズ/ＬＬサイズ/
lm /ロードモジュール/
lmenthol /l-メントール/
load /ロード/
loadable /ローダブル/
loadbalancer /ロードバランサー/ロードバランサ/
loader /ローダー/ローダ/
loading /ローディング/
loadmodule /ロードモジュール/
loady /ローディ/
loafer /ローファー/
loafers /ローファー/
loam /ローム/
loan /ローン/
loancard /ローンカード/
lob /ロブ/
lobbing /ロビング/
lobby /ロビー/
lobbying /ロビイング/
lobbyist /ロビイスト/
lobelia /ロベリア/
lobo /ロボ/
lobotomy /ロボトミー/
lobster /ロブスター/
local /ローカル/局所/
localaddress /ローカルアドレス/
localarea /ローカルエリア/
locale /ロケール/ロカール/
localhost /ローカルホスト/
localip /ローカルIP/
localisation /ローカリゼーション/ローカライゼーション/
localise /ローカライズ/
localism /ローカリズム/
locality /ローカリティ/
localization /ローカリゼーション/ローカライゼーション/
localize /ローカライズ/
localminima /ローカルミニマ/局所的最良解/
localnews /ローカルニュース/
localrule /ローカルルール/
localtime /ローカルタイム/
locate /ロケート/
location /ロケーション/
locator /ロケータ/
lock /ロック/施錠/
locke /ロック/
locker /ロッカー/
lockerroom /ロッカールーム/
lockfile /ロックファイル/
lockheed /ロッキード/
lockin /ロックイン;lock-in/
locking /ロッキング/
lockmode /ロックモード/
lockon /ロックオン;lock-on/
lockout /ロックアウト/
loco /ロコ/
locomoco /ロコモコ;(ハワイ語)/
locomotion /ロコモーション/
locrian /ロクリアン;BCDEFGAB/
locus /ローカス/
lode /ロード/
lodge /ロッジ/
loeb /ローブ/
loewe /ロエベ;www.loewe.com/
loft /ロフト/Ｌｏｆｔ/
loftbed /ロフトベッド/
log /ログ/
logan /ローガン/
logdata /ログデータ/
logfile /ログファイル/
logger /ロガー/
logging /ロギング/ログィング;<rare>/
loghouse /ログハウス/
logic /ロジック/⊃;superset/∧;and/∨;or/¬;not/∀;all/∃;exist/論理/
logical /ロジカル/
logicool /ロジクール;www.logicool.co.jp/
logicprogramming /ロジック・プログラミング/
login /ログイン/
loginid /ログインID/
logistic /ロジスティック/ロジスティク/
logistics /ロジスティクス/ロジスティックス/
logit /ロジット/
logitech /ロジテック;www.logitech.com/
logo /ロゴ/
logoff /ログオフ/
logomark /ロゴマーク;和製英語(logo)/
logon /ログオン/
logos /ロゴス/
logotype /ロゴタイプ/
logout /ログアウト/
logue /ローグ/
logy /ロジー/
lohengrin /ローエングリン/
loire /ロワール/ロアール/
lois /ロイス/
loki /ロキ/
lola /ローラ/
loli /ロリ;Lolita, lolicon/
lolicon /ロリコン;Lolita complex, pedophilia/
lolita /ロリータ/
lollipop /ロリポップ/
lolo /ロロ/
lombardi /ロンバルディ/
lombardia /ロンバルディア/
lombok /ロンボク/ロンボック/
lome /ロメ/
london /ロンドン/
londonboots /ロンドンブーツ;和製英語(platform shoes)/
londonderry /ロンドンデリー/
lone /ローン/
lonely /ロンリー/ロンリィ/
lonewolf /ローンウルフ;lone wolf/
long /ロング/
longbeach /ロングビーチ/
longboard /ロングボード/
longboots /ロングブーツ/
longcoat /ロングコート/
longdress /ロングドレス/
longfellow /ロングフェロー/
longhair /ロングヘア/ロングヘアー/
longhit /ロングヒット;和製英語(extra-base)/
longhole /ロングホール;par-5/
longine /ロンジン/
longiron /ロングアイアン;2-4/
longisland /ロングアイランド/
longneck /ロングネック/
longo /ロンゴ/
longpass /ロングパス/
longputt /ロングパット/
longrun /ロングラン/
longseller /ロングセラー/
longshoot /ロングシュート/
longshot /ロングショット/
longsize /ロングサイズ/
longskirt /ロングスカート/
longsleeve /ロングスリーブ/
longstay /ロングステイ/
longsword /ロングソード/
longtime /ロングタイム/
longueville /ロングヴィル/
longversion /ロングバージョン/
longword /ロングワード/
lonnie /ロニー/
lonny /ロニー/
lonsdale /ロンズデール/
look /ルック/
lookahead /ルックアヘッド/
looking /ルッキング/
looks /ルックス/
lookup /ルックアップ/
loom /ルーム/
loop /ループ/
loopback /ループバック/
loose /ルース/ルーズ;NB:日本式発音/
looseleaf /ルーズリーフ/
loosesocks /ルーズソックス/
loosesox /ルーズソックス;loose socks/
lopez /ロペス/
lor /∨/
lora /ローラ/
lorca /ロルカ/
lord /ロード/
lore /ロア/
loreal /ロレアル;l'Oreal/
lorelei /ローレライ/
loren /ローレン/
lorena /ロリーナ/
lorentz /ローレンツ/
lorenz /ローレンツ/
lorenzo /ロレンツォ/ロレンソ/
loretta /ロレッタ/
lorin /ローリン/
loris /ロリス/
lorna /ローナ/
lorraine /ロレーヌ/ロレイン/
lorry /ローリー/
los /ロス/ロス・アンゼルス;los Angeles NB:losは単なる冠詞/
losalamos /ロスアラモス/ロス・アラモス/
losangeles /ロサンゼルス/ロサンジェルス/ロスアンゼルス/ロスアンジェルス/
lose /ルーズ/
loser /ルーザー/
loss /ロス/
losstime /ロスタイム;和製英語(extra time)/
lost /ロスト/
lostvirgin /ロストバージン;和製英語/
lot /ロット/ロト;[聖書]/
lothar /ローター/
loti /ロティ/
lotion /ローション/
lotnumber /ロットナンバー/
lotta /ロッタ/
lotte /ロッテ/
lotteria /ロッテリア/
lottie /ロッティ/
lotto /ロト/ロット/
lotus /ロータス/
lou /ルー/
loud /ラウド/
loudness /ラウドネス/
loudspeaker /ラウドスピーカー/ラウドスピーカ/
louis /ルイ/ルイス/
louisa /ルイザ/ルイーザ/
louise /ルイーズ/ルイズ/
louisiana /ルイジアナ;LA/
louison /ルイゾン/
louisvuitton /ルイヴィトン/ルイ・ヴィトン/
loukas /ルカ/
loulou /ルル/
lounge /ラウンジ/
loura /ローラ/
loussier /ルーシェ/
louver /ルーバー/
louvre /ルーブル;-美術館/ルーヴル/
love /ラブ/ラヴ/
lovecall /ラブコール/
lovecome /ラブコメ;love comedy/
lovecomedy /ラブコメディ/ラブコメディー/ラブコメ/
lovecraft /ラヴクラフト/ラブクラフト/
lovedoll /ラブドール/
lovegoods /ラブグッズ/
loveho /ラブホ/
lovehotel /ラブホテル/ラヴホテル/
lovejuice /ラブジュース/
loveletter /ラブレター/ラヴレター/
lovelove /ラブラブ;和製英語(lovey-dovey)/
lovely /ラブリー/
lover /ラバー/ラヴァー/
loveromance /ラブロマンス;love and romance/
lovers /ラヴァーズ/ラバーズ/
lovescene /ラブシーン/
lovesong /ラブソング;love song/
lovestory /ラブストーリー/ラブ・ストーリー/
loving /ラビング/ラヴィング/
low /ロー/ロウ/
lowangle /ローアングル/
lowblow /ローブロー/
lowcalorie /ローカロリー/
lowcost /ローコスト/
lowell /ローウェル/
lowend /ローエンド/
lowfat /ローファット/
lowheel /ローヒール/
lowkick /ローキック/
lowlevel /ローレベル/
lowpass /ローパス/
lowprice /ロープライス/
lowprofile /ロープロファイル/
lowrise /ローライズ;low-rise/
lowrisk /ローリスク/ロウリスク/
lowry /ローリー/ロウリー/
lowspec /ロースペック/
lowtech /ローテク;low technology/
lowteen /ローティーン/
lowtension /ローテンション/
lowtom /ロータム/
lox /ロックス/
loy /ロイ/
loyalty /ローヤリティ;忠誠/
loyola /ロヨラ/
lp /LP/
lpc /LPC/
lpf /ローパスフィルタ;lowpass filter/
lpgas /LPガス/
lprecord /LPレコード/
lr /ローレンシウム/Lawrencium/
lse /最小2乗法;Least Squares Estimation/
lsize /Lサイズ/Ｌサイズ/
lt /＜/
lu /ルテチウム/Lutetium/ルー/
lua /ルア/
luana /ルアナ/
luanda /ルアンダ/
lubeck /リューベック/
luc /リュック/
luca /ルカ/ルーカ/ルッカ/
lucas /ルーカス/
luce /ルース/ルス/リュス/
luchino /ルキノ/
lucia /ルシア/ルチア/ルーシア/
lucian /ルシアン/
luciano /ルチアーノ/ルチャーノ/
lucid /ルーシッド/Ｌｕｃｉｄ/Lucid/
lucie /ルーシー/
lucien /ルシアン/リュシアン/
lucifer /ルシファー/
lucile /ルシル/
lucille /ルシル/ルシール/
lucinda /ルシンダ/
lucio /ルチオ/ルーチョ/ルシオ/
luck /ラック/
lucky /ラッキー/Ｌｕｃｋｙ/
lucky7 /ラッキーセブン/
luckyseven /ラッキーセブン/
luckystrike /ラッキーストライク/
luckyzone /ラッキーゾーン/
lucretia /ルクレチア/
lucrezia /ルクレツィア/
lucy /ルーシー/
ludens /ルーデンス;(Lat.) 遊ぶ/
ludmilla /リュドミラ/
ludo /ルード;(It)仮面劇/
ludwig /ルートヴィヒ/
lufthansa /ルフトハンザ;www.lufthansa.de/
lug /ラグ/
luge /リュージュ/
luger /ルガー/ルーガー/
luggage /ラゲージ/
luigi /ルイージ/ルイジ/
luis /ルイ/ルイス/
luisa /ルイーザ/
luise /ルイーゼ/
lukacs /ルカーチ/
lukas /ルーカス/
luke /ルカ/ルーク/
lukes /ルークス/
lula /ルーラ/
lullaby /ララバイ/
lulu /ルル/リュリュ/
lumbini /ルンビニ/ルンビニー/
lumen /ルーメン/
lumi /ルミ/
lumiere /リュミエール/ルミエール/
lumine /ルミネ/
luminescence /ルミネッセンス/ルミネセンス/
luminous /ルミナス/
lump /ランプ/
lumpen /ルンペン/
lun /Logical Unit Number/
luna /ルナ/Ｌｕｎａ/ＬＵＮＡ/
lunar /ルナー/
lunatic /ルナティック/
lunch /ランチ/
lunchbox /ランチボックス/
luncheon /ランチョン/
luncheonmat /ランチョンマット/
lunchset /ランチセット/
lunchtime /ランチタイム/
lune /ルーン/リューヌ;仏語/
lung /ラング/
lupe /ルーペ/
lupin /ルパン/
lupine /ルピナス/
lupinus /ルピナス/
luque /ルケ/
lure /ルアー/
lurefishing /ルアーフィッシング/
lust /ラスト/ルスト;(独語)欲望/
lute /リュート/
lutecium /ルテチウム;[元素]71,Lu/
lutetium /ルテチウム;[元素]71,Lu/
luther /ルター/ルーテル/ルーサー/
lutz /ルッツ/
luv /ラブ;=love/
lux /ルクス/
luxembourg /ルクセンブルク;.lu/ルクセンブルグ/リュクサンブール/
luxemburg /ルクセンブルク/
luxor /ルクソール;エジプト/
luxury /ラグジュアリー/
luzern /ルツェルン/
luzon /ルソン/
ly /リー;(接尾辞)/リィ/
lyall /ライアル/
lycaon /リカオン/
lycee /リセ/
lycopene /リコピン/
lycoris /リコリス/
lydia /リディア/
lydian /リディアン;FGABCDEF/
lyle /ライル/
lymph /リンパ/
lympha /リンパ/
lynch /リンチ/
lyndon /リンドン/
lynette /リネット/
lynn /リン/
lynne /リン/
lynx /リンクス/
lyon /リヨン/
lyotard /リオタール/
lyric /リリック/
lyrical /リリカル/
lys /リス/
lysine /リジン;Lys/
lysosome /リソソーム/
lysozym /リゾチーム/
m /μ;mu/エム/メートル/
m# /Ｍ#1/
m17n /multilingualization/多言語化/
ma /マ/Massachusetts/マサチューセッツ/
maar /マール/
maas /マース/マーズ/
maastricht /マーストリヒト/
maazel /マゼール/
mab /マブ/
mabel /メイベル/メーベル/
mac /マック/Ｍａｃ/マッキントッシュ/Macintosh/Ｍａｃｉｎｔｏｓｈ/マク/
macadamia /マカダミア/マカデミア/
macadamianuts /マカダミアナッツ/
macaddress /MACアドレス/
macaron /マカロン/
macaroni /マカロニ/
macaronigratin /マカロニグラタン/
macaroniwestern /マカロニウエスタン/マカロニウェスタン/
macaroon /マカロン/
macarthur /マッカーサー;MacArthur/
macau /マカオ;.mo/
macbeth /マクベス/
macdonald /マクドナルド;MacDonald/
mace /メイス/
macedonia /マケドニア;.mk/マチェドニア;(イタリア語)/
macfarlane /マクファーレン/
macguffin /マクガフィン/
mach /マッハ/マッハ数/Ｍａｃｈ/Mach/
machiavelli /マキャベリ/マキアヴェッリ/マキアヴェリ/マキアベリ/
machiavellism /マキャベリズム/マキアヴェリズム/
machine /マシン/マシーン/計算機/ミシン;sawing machine/
machinegun /マシンガン/
machineguntalk /マシンガントーク/
machinepower /マシンパワー/
machineroom /マシンルーム/
machinery /マシナリー/
machinevision /マシンビジョン/マシン・ビジョン/
machining /マシニング/
macho /マッチョ/
machupicchu /マチュピチュ;Machu Picchu,Peru/
macintosh /マッキントッシュ/
mackenzie /マッケンジー/
maclaine /マクレーン/マクリーン/
maclean /マクレーン/マクリーン/
macpherson /マクファーソン/
macro /マクロ/
macrobiotic /マクロビオティック/
macrolens /マクロレンズ/
macromedia /マクロメディア;www.macromedia.com/
macromodel /マクロモデル;macro-model/
macrophage /マクロファージ/
macross /マクロス/
macrovirus /マクロウイルス/マクロウィルス/
mad /マッド/
madagascar /マダガスカル;.mg/
madam /マダム/
madame /マダム/
made /メイド/メード/
madein /メイドイン;made in ~/メイド・イン・/
madeinjapan /メイドインジャパン/メイド・イン・ジャパン/made in Japan/日本製/
madeira /マデイラ/
madeleine /マドレーヌ/
madeline /マドリン/マデリン/
mademoiselle /マドモアゼル/マドモワゼル/
madness /マッドネス/
madonna /マドンナ/
madras /マドラス/
madrid /マドリッド/マドリード/
madrigal /マドリガル/
madrigale /マドリガーレ/
madscientist /マッドサイエンティスト/
mae /メイ/
maestoso /マエストーソ/
maestra /マエストラ/
maestro /マエストロ/
maetel /メーテル;また一つ星が消えるよ/
maeterlinck /メーテルリンク/メーテルランク/
mafia /マフィア/
mag /マグニチュード;magnitude/マグ/
maga /マガ;magazine/
magagine /マガジン;※magazine/
magali /マガリ/
magazine /マガジン/
magazinehouse /マガジンハウス;www.magazine.co.jp/
magazinerack /マガジンラック/
magazines /マガジンズ/
magda /マグダ/
magdala /マグダラ;-のマリア/
magdalena /マグダレーナ/マグダレナ/
mage /メイジ/
magellan /マゼラン/
magenta /マゼンタ/
maggie /マギー/
maggy /マギー/
maghreb /マグレブ/
magic /マジック/
magical /マジカル/
magicgate /マジックゲート/
magichand /マジックハンド/
magician /マジシャン/
magicmirror /マジックミラー/
magicmushroom /マジックマッシュルーム/
magicnumber /マジックナンバー/
magictape /マジックテープ;和製英語(velcro)/
magik /マジック;magic/
magma /マグマ/
magnacarta /マグナカルタ;Magna Carta/
magnesia /マグネシア;MgO,苦土/
magnesium /マグネシウム;[元素]12,Mg/
magnesiumion /マグネシウムイオン;magnesium ion/
magnet /マグネット/
magnetic /マグネティック/マグネチック/
magnetite /マグネタイト/
magnificat /マニフィカト/
magnitude /マグニチュード/
magnum /マグナム/
magnus /マグナス/マグヌス/
magritte /マグリット/
maguire /マグワイア/
magyar /マジャール;ハンガリー/
magzine /マガジン;※magazine/
mahabharata /マハーバーラタ/
mahalanobis /マハラノビス/
maharaja /マハラジャ/
mahdi /マフディ;[イスラム]救世主/マフディー/
mahjong /マージャン/
mahler /マーラー/
mahogany /マホガニー/
maia /マイア/
maid /メイド/メード/
maiden /メイデン/
maier /マイヤー/
maigret /メグレ/
maija /マイヤ/
maik /マイク/
mail /メール/メイル/手紙/〒/
mailaccount /メールアカウント/
mailaddress /メールアドレス/
mailbomb /メールボム;mail bomb/
mailbox /メールボックス/
mailcheck /メールチェック/
mailclient /メールクライアント/
mailer /メーラー/メーラ/メイラ/メイラー/
mailfilter /メールフィルタ/
mailfiltering /メールフィルタリング/
mailform /メールフォーム/
mailfriend /メールフレンド/
mailheader /メールヘッダ/
mailing /メーリング/メイリング/
mailing-list /メイリングリスト/
mailinglist /メーリングリスト/メイリングリスト/
maillist /メールリスト/メイルリスト/
maillol /マイヨール/
maillot /マイヨ/
maillotjaune /マイヨジョーヌ/
mailmaga /メルマガ;e-mail magazine/
mailmagazine /メールマガジン;e-mail magazine/
mailnews /メールニュース/
mailorder /メールオーダー/
mailpassword /メールパスワード/
mailreader /メールリーダー/
mailserver /メールサーバー/メールサーバ/メイルサーバ/
mailservice /メールサービス/
mailsoft /メールソフト;e-mail client/
mailsystem /メールシステム/
main /メイン/メーン/マイン/
mainbank /メインバンク/メーンバンク/
mainboard /メインボード/
maincast /メインキャスト/
maincontents /メインコンテンツ/
maindish /メインディッシュ/
maine /メーン;ME/
mainecoon /メインクーン/
mainevent /メインイベント/
mainframe /メインフレーム/
maingate /メインゲート/
mainmachine /メインマシン/
mainmemory /メインメモリ/
mainmenu /メインメニュー/
mainpage /メインページ/
mainroutine /メインルーチン/
mainsite /メインサイト/
mainstage /メインステージ/
mainstand /メインスタンド/
mainstream /メインストリーム/
mainstreet /メインストリート/
maintainance /メンテナンス/
maintainancefree /メンテナンスフリー/
maintainer /メンテナ/メンテナー/
maintarget /メインターゲット/
mainte /メンテ;maintenance/
maintenance /メンテナンス/メインテナンス/
maintheme /メインテーマ/
maintitle /メインタイトル/
mainvocal /メインボーカル/
mainwindow /メインウィンドウ/メインウインドー/メーンウインドー;<rare>/
mainz /マインツ/
maira /マイラ/
maiskii /マイスキー/
maison /メゾン/
maisonette /メゾネット/
maitai /マイタイ;mai tai/
maitre /メートル/
maj /マイ/
majesta /マジェスタ/
majesty /マジェスティ/マジェスティー/
majong /麻雀;mah-jong?/
major /メジャー/メージャー/メイジャー/メージャ/
majorca /マジョルカ;(英語風表記) =mallorca/
majordebut /メジャーデビュー;和製英語/
majority /マジョリティ/マジョリティー/
majorlabel /メジャーレーベル/
majorleague /メジャーリーグ/
majorleaguer /メジャーリーガー/
majormode /メジャーモード/
majorversion /メジャーバージョン/
majuro /マジュロ/
make /メイク/メーク/
makedonia /マケドニア/
makefile /makeファイル/メイクファイル/メークファイル/Makefile/
makelele /マケレレ/
makelove /メイクラブ;skk: don't know how to make love. Stop/
maker /メーカー/メーカ/メイカー/
makerbrand /メーカーブランド/
makeup /メイクアップ/メークアップ/メーキャップ/メイキャップ/
makeupartist /メイクアップアーティスト;美容師/
makgeoolri /マッコリ;(朝鮮語)/
makgoli /マッコリ;(朝鮮語)/
making /メイキング/メーキング/
maksim /マクシム/
mal /マル/モール/マール/
malabo /マラボ/
malacca /マラッカ/
malachi /マラキ/マラカイ/
malachite /マラカイト/
malaga /マラガ;スペイン/
malaguena /マラゲーニャ/
malai /マレー/
malaria /マラリア/
malawi /マラウイ;.mw/マラウィ/
malay /マレー/
malaysia /マレーシア;.my/
malaysiagp /マレーシアGP;[F1]/
malcom /マルコム/
maldini /マルディーニ/
maldives /モルディブ;.mv/モルジブ/
maldoror /マルドロール/
male /メール/♂/マーレ/
mali /マリ;.ml/
malia /マリア/
malibu /マリブ/
malik /マリク/
malinowski /マリノフスキー/
mall /モール/
mallarme /マラルメ/
malle /マル/
mallet /マレット/
mallorca /マジョルカ/
mallow /マロー/マロウ/
malory /マロリー/
malraux /マルロー/
malt /モルト/
malta /マルタ;.mt/
maltese /マルチーズ/
malthus /マルサス/
maltitol /マルチトール/
maltose /マルトース/
maltwhiskey /モルトウイスキー/モルトウィスキー/
malware /マルウェア/
mama /ママ/
maman /ママン/
mambo /マンボ/
mamluk /マムルーク/
mamma /マンマ/
mammoth /マンモス/
mammy /マミー/
man /マン/♂/マニュアル/
man-machine /マン-マシン/
mana /マナ/
manage /マネージ/
managed /マネージド/
management /マネジメント/マネージメント/
manager /マネージャー/マネージャ/マネジャー/マネジャ/
managing /マネージング/
managua /マナグア/
manama /マナーマ/
manas /マナス/
manatee /マナティ/マナティー/
manaus /マナウス/
mance /マンス/
manchester /マンチェスター/
mancini /マンシーニ/マンチーニ/
mancur /マンサー/
mandala /マンダラ/曼荼羅;mandala/曼陀羅/
mandalay /マンダレー/
mandarin /マンダリン/
mandela /マンデラ/
mandelbrot /マンデルブロ/マンデルブロー/マンデルブロート/
mandelin /マンデリン/
mandiargues /マンディアルグ/
mandola /マンドラ/マンドーラ/
mandolin /マンドリン/
mandoline /マンドリン/
mandolino /マンドリーノ/
mandom /マンダム;www.mandom.co.jp/
mandrake /マンドレイク/マンドレーク/
mandrill /マンドリル/
mandy /マンディ/マンディー/
manet /マネ/
maneuver /マヌーバー/マヌーヴァー/
manfred /マンフレッド/
manga /マンガ/
mangan /マンガン;Mn/
manganese /マンガン;[元素]25,Mn/
mangatic /マンガチック;和製英語/
mango /マンゴー/マンゴ/
mangold /マンゴールド/
mangosteen /マンゴスチン/
mangrove /マングローブ/
manhattan /マンハッタン/
manhole /マンホール/
mania /マニア/
maniac /マニアック/
manicure /マニキュア/
maniera /マニエラ;(It)様式/
manierisme /マニエリスム/
manifest /マニフェスト/
manifesto /マニフェスト;政権公約/
manila /マニラ/
manipulate /マニピュレイト/
manipulation /マニピュレーション/
manipulator /マニピュレータ/マニピュレーター/
mann /マン/
manna /マナ/マンナ/
mannan /マンナン/
mannequin /マネキン/マヌカン/
manner /マナー/
mannerism /マンネリズム/マンネリ/
mannermode /マナーモード/
mannheim /マンハイム/
mannish /マニッシュ/
mannose /マンノース/
manns /マンス/
manolo /マノロ/
manon /マノン/
manpower /マンパワー/
manque /マンケ/
mansard /マンサード/
mansell /マンセル/
mansfield /マンスフィールド/
manshon /マンション;※mansion/
mansion /マンション/
manson /マンソン/
manta /マンタ/
manteau /マント/
mantelpiece /マントルピース/
manticore /マンティコア/
mantis /マンティス/
mantle /マントル/
mantoman /マンツーマン/
mantra /マントラ/
manu /マヌ/
manual /マニュアル/
manualpage /マニュアルページ/
manuel /マヌエル/マニュエル/マニエル/
manuela /マヌエラ/マニュエラ/
manufacture /マニュファクチュア/マニュファクチャー/
manuscript /マニュスクリプト/
manx /マンクス/
many /メニー/メニ/
manya /マーニャ/
map /マップ/写像/
mapentry /マップエントリ/
maple /メイプル/メープル/
maplesyrup /メープルシロップ/メイプルシロップ/
mapped /マップド/
mapping /マッピング/
mapplethorpe /メイプルソープ/
mappy /マッピー;[ゲーム]ナムコ/
maputo /マプート/
mara /マラ/
maracas /マラカス/
marais /マレー/
maraschino /マラスキーノ/
marathon /マラソン/マラトン/
marathoncourse /マラソンコース/
marble /マーブル/
marbling /マーブリング/
marc /マルク/マーク/
marca /マルカ/
marceau /マルソー/
marcel /マルセル/マーセル/
marcela /マルセラ/マルチェラ/
marcelino /マルセリーノ/
marcelle /マルセル/
marcello /マルチェロ/マルチェッロ/
marcelo /マルセロ/
march /マーチ/
marchand /マルシャン/
marche /マルシェ;仏語/マルシュ;(Fr)歩み/
marching /マーチング/
marchingband /マーチングバンド/
marcia /マーシャ/マルシア/
marcica /マーシカ/
marcie /マーシー/
marco /マルコ/マーコ/
marconi /マルコーニ/
marcopolo /マルコポーロ;Marco Polo/
marcos /マルコス/
marcus /マルコ/マーカス/マルクス;(ローマ皇帝)/
marcy /マーシー/
marek /マレック/マレク/
maresca /マレスカ/
margaret /マーガレット/
margarete /マルガレーテ/
margarine /マーガリン/
margarita /マルガリータ/
margaux /マルゴー/マルゴ/
marge /マージ/
margery /マージェリー/
margherita /マルゲリータ/
margie /マージー/
margin /マージン/
marginal /マージナル/
margo /マーゴ/
margot /マルゴ/マーゴット/
margrit /マルグリット/
marguerite /マーガレット/マルグリット/
margueritte /マルグリット/
mari /マリ;(Fr)夫/マリー/
maria /マリア/
mariage /マリアージュ;仏語/
mariah /マライア/
marian /マリアン/
mariana /マリアナ;.mp/
mariane /マリアン/
marianna /マリアンナ/
marianne /マリアン/マリアンヌ/マリアンネ/
mariano /マリアーノ/マリアノ/
marie /マリー/マリエ;(Fr)花婿/
mariee /マリエ;(Fr)花嫁/
mariel /マリエル/
marielle /マリエル/
marienbad /マリエンバート/マリエンバード/
marier /マリエ;(Fr)結婚する/
marietta /マリエッタ/
marigold /マリーゴールド/マリゴールド/
marihuana /マリファナ/
marija /マリヤ/
marijuana /マリファナ/
marika /マリカ/
marilla /マリラ/
marilyn /マリリン/
marimba /マリンバ/
marin /マリン/
marina /マリーナ/マリナ/
marine /マリン/マリーン/マリネ/
marineblue /マリンブルー/
marinera /マリネラ/
mariners /マリナーズ;[MLB]/
marines /マリーンズ/
marinesnow /マリンスノー/
marinesport /マリンスポーツ/
marinesports /マリンスポーツ/
marini /マリーニ/
marino /マリノ/マリーノ/
marinos /マリノス;[Jリーグ]横浜/
marinovski /マリノフスキー/
mario /マリオ/
marion /マリオン/
marionette /マリオネット/
maris /マリス/
marisa /マリサ/
marius /マリウス/
marjoram /マージョラム/
marjorie /マージョリー/
mark /マーク/マルク/
marker /マーカー/マーカ/
market /マーケット/
marketer /マーケッター/
marketing /マーケティング/
marketplace /マーケットプレイス/
marking /マーキング/
marko /マルコ/
markos /マルコス/
markov /マルコフ/マルコフ過程/マルコフ遷移/
markovmodel /マルコフモデル;Markov model/
marks /マークス/
marksheet /マークシート/
markup /マークアップ/
markus /マルクス/マーカス/
marl /マール/
marlboro /マルボロ/マールボロ/
marlene /マレーネ/マルレーン/
marley /マーリー/マーレイ/
marlin /マーリン/
marlins /マーリンズ;[MLB]/
marlon /マーロン/
marlowe /マーロウ/
marmalade /マーマレード/
marmelo /マルメロ;(ポルトガル語)/
marmoset /マーモセット/
marmot /モルモット;(蘭語) guinea pig/マーモット/
marne /マルヌ/
marnier /マルニエ/
maro /マロー/マロ/
maroon /マルーン/
marot /マロ/
marquee /マーキー/
marquez /マルケス/
marquis /マルキ/
marquise /マルキーズ/
marrakesh /マラケシュ;モロッコ/
marriage /マリッジ/
marriagering /マリッジリング/
marric /マリック/
marriott /マリオット/
marriotte /マリオット/
marron /マロン/
marronglace /マロングラッセ;marron glace/
marronnier /マロニエ/
marry /マリー/
mars /マーズ/マルス/
marsalis /マルサリス/
marseillaise /マルセイエーズ/
marseille /マルセイユ/マルセーユ/
marsh /マーシュ/
marsha /マーシャ/
marshal /マーシャル/
marshaling /マーシャリング/
marshall /マーシャル;.mh/
marshmallow /マシュマロ/
mart /マート/マー/
marta /マルタ/マータ/
marteau /マルトー/
martha /マーサ/マルタ/
marthe /マルト/
marti /マルティ/マーティ/マーティー/
martial /マーシャル/
martialarts /マーシャルアーツ/
martin /マーチン/マーティン/マルタン/マルティン/マルチン/
martina /マルチナ/マルティナ/
martine /マルティーヌ/
martinet /マルティネ/
martinez /マルティネス/マルチネス/
martini /マティーニ/マルティーニ/マルティニ/
martinique /マルティニク;.mq/
martinlof /マーティンレーフ/
martino /マルティーノ/マルチーノ/
marton /マートン/
marty /マルティ/マーティ/マーティー/
maru /●/○/〇;漢数字のゼロ/◎/
marvel /マーベル/マーヴェル/
marvellous /マーベラス/
marvelous /マーベラス/
marvin /マービン/マーヴィン/メルビン/
marx /マルクス/
marxism /マルキシズム/
mary /マリー/メリー/メアリー/メアリ/
maryann /メリーアン/メアリーアン/
maryland /メリーランド/
marypoppins /メリーポピンズ;Mary Poppins/
marzipan /マジパン/マルツィパン/
mas /マッツ/
masala /マサラ;(Hindi)香辛料/
mascara /マスカラ/
mascarpone /マスカルポーネ/
mascot /マスコット/
mascotcharacter /マスコットキャラクター/
maser /メーザー;microwave amplification by stimulated emission of radiation/メーザ/
maserati /マセラティ;www.maserati.it/
maseru /マセル/
mash /マッシュ/
masha /マーシャ/
mashpotato /マッシュポテト;mashed potato/
mask /マスク/仮面/
masked /マスクド/マスクト/
maskedspector /マスクトスペクトル/
maskee /マスキー/マスキ/
masker /マスカ/マスカー/
masking /マスキング/
maskingtape /マスキングテープ/
maslow /マズロー/
maso /マゾ;masochist,masochism/
masoch /マゾッホ/マゾ/ザッヘル＝マゾッホ/
masochism /マゾヒズム/被虐趣味/嗜虐的趣味/被虐淫乱症/
masochist /マゾヒスト/被虐趣味者/嗜虐的趣味者/
mason /メイスン/メーソン/
masqat /マスカット/
masquerade /マスカレード/
mass /マス/マッス;[美術]/
massa /マッサ/
massachusetts /マサチューセッツ;MA/
massage /マッサージ/
massagechair /マッサージチェア/
massageoil /マッサージオイル/
massager /マッサージャー/
masscommunication /マスコミュニケーション/
masscomp /マスコンプ/
masse /マッス;(仏語)/マッセ;(独語)/
massenet /マスネ/
massgame /マスゲーム;和製英語/
massimo /マッシモ;(It)最大/
massive /マッシヴ/マッシブ/
massmedia /マスメディア/
masspro /マスプロ;mass production/
mast /マスト/
master /マスター/マスタ/修士/
mastercard /マスターカード;www.mastercard.com/MasterCard/
mastercourse /マスターコース/
masterdata /マスターデータ/マスタデータ/
mastering /マスタリング/
masterkey /マスターキー/
masterpiece /マスターピース/
masterplan /マスタープラン/
masters /マスターズ/
mastertape /マスターテープ/
mastroianni /マストロヤンニ/
masturbation /マスターベーション/
mat /マット/
mata /マータ/マタ/
matador /マタドール/
match /マッチ/
matchbox /マッチボックス/
matching /マッチング/
matchplay /マッチプレー/
matchpoint /マッチポイント/
matchppomp /マッチポンプ;和製語/
matchppump /マッチポンプ;和製語/
mate /メイト/マテ/マテ茶/
mateo /マテオ/
materazzi /マテラッツィ/
material /マテリアル/
maternity /マタニティ/マタニティー/
mates /メイツ/
mateus /マテウス/
math /マス/±;+-/×;x/÷;div/∞;infinity,oo/∝;proportional/∴;therefore/∵;because/⇒;=>/⇔;equiv,<=>/∀;all/∃;exist/∂;d,partial/Δ;Delta/∇;nabla/√;root,sqrt/∫;integral/∬;integral/≡;equiv/∽;similar/≒;=:,approx/≠;neq,!=/≦;<=/≧;>=/≪;<</≫;>>/∈;include/∋;include/⊆;subseteq/⊇;superseteq/⊂;subset/⊃;superset/∪;sum/∩;cap/∧;and/∨;or/¬;not/∠;angle/⌒;arc,frown/⊥;vertical/
mathew /マシュー/
mathias /マティアス/マサイアス/
mathieu /マシュー/マチュー/
mathilda /マチルダ/
mathilde /マチルド/
matias /マティアス/マチアス/
matic /マチック/マティック/
matiere /マチエール/
matilda /マチルダ/
matinee /マチネ/
matisse /マチス/マティス/
mato /マト/
matreshka /マトリョーシカ/
matrix /マトリックス/マトリクス/行列/
matroid /マトロイド/
mats /マッツ/
matt /マット/
mattaeus /マタイ/
matteo /マッテオ/
matter /マター/
matterhorn /マッターホルン/
mattew /マシュー/
matthaus /マテウス/
matthew /マタイ/マシュー/
matthews /マシューズ/
matthias /マティアス/
matti /マッティ/
mattie /マッティ/
mattress /マットレス/
matty /マティ/マッティ/
mau /マウ/
maud /モード;Who was that Maud person anyway?/
maude /モード/
maugham /モーム/
maui /マウイ/
maul /モール/
maunakea /マウナケア/
maunaloa /マウナロア/
maupassant /モーパッサン/
maureen /モーリン/モーリーン/
mauri /マウリ/
mauriat /モーリア/
maurice /モーリス/
mauritania /モーリタニア;.mr/
mauritius /モーリシャス;.mu/
maurizio /マウリツィオ/
mauro /マウロ/モーロ/
maus /マウス/
mauss /モース/
mauve /モーブ/
maverick /マーベリック;一匹狼/
mavis /メイビス/メイヴィス/
max /マックス/最大/
maxell /マクセル/
maxi /マキシ/
maxim /マキシム/マクシム/
maxime /マクシム/
maximilian /マクシミリアン/
maximin /マキシミン/マクシミン/
maximo /マキシモ/
maximum /マキシマム/最大/最大値/
maxisingle /マキシシングル/
maxwell /マクスウェル/マックスウェル/
may /メイ/メー/
maya /マヤ/マーヤ/マーヤー/
maybe /メイビー/
mayday /メーデー/
mayer /マイヤー/メイヤー/マイエル/マイアー/メイア/マイア/
mayfield /メイフィールド/
mayflower /メイフラワー/
maynard /メイナード/
mayne /メイン/
mayo /メイヨ/
mayol /マイヨール/
mayonnaise /マヨネーズ/
mayor /メイヤー;市長/
mayotte /マヨット;.yt/
mayqueen /メークイン/メイクイーン/メイクイン/
mazarin /マザラン/
mazda /マツダ/
maze /メイズ/
mazurka /マズルカ/
mazza /マッツァ/
mb /メガバイト/
mbabane /ムババネ/
mbira /ムビラ/
mbps /Ｍｂｐｓ/
mc /マック;人名の一部(McDonald,McCartney)/マク/
mcafee /マカフィー/
mccallum /マッカラム/
mccarran /マッカラン;McCarran/
mccarthy /マッカーシー/ＭｃＣａｒｔｈｙ/McCarthy/
mccartney /マッカートニー;McCartney/
mccollum /マッカラム/マッコーラム/
mccoy /マッコイ;McCoy/
mcculloch /マッカロー/
mcdonald /マクドナルド;McDonald/
mcenroe /マッケンロー;McEnroe/
mcentire /マッケンタイア;McEntire/
mcfarlane /マクファーレン;McFarlane/
mcgrawhill /マグロウヒル/
mcguffin /マクガフィン/
mcgwire /マグワイア;McGwire/
mckee /マッキー;McKee/
mckinley /マッキンリー/マッキンレー/
mclain /マクレーン/マクリーン/
mclaren /マクラーレン;McLaren/
mclaughlin /マクラフリン;McLaughlin/
mclean /マクリーン;McLean/マクレーン/
mcluhan /マクルーハン;McLuhan/
mcmahon /マクマホン/
mcneil /マクニール;McNeil/
mcpherson /マクファーソン/
mcqueen /マックイーン/
mcrae /マクレー;McRae/マクリー/
md /ミニディスク/Mendelevium/メンデレビウム/Maryland/メリーランド/
mdplayer /MDプレーヤー/
mdrecorder /MDレコーダー/
me /ミー/Maine/メイン/メーン/
mead /ミード/
meadow /メドウ;牧草地/
meal /ミール/
mean /ミーン/
meaning /ミーニング/
measure /メジャー/
measurecup /メジャーカップ/
measuring /メジャリング/
meat /ミート/
meatball /ミートボール/
meatloaf /ミートローフ/
meatpie /ミートパイ/
meatsauce /ミートソース/
mecab /MeCab/和布蕪/
mecca /メッカ/
mecenat /メセナ;仏語/
mecha /メカ/
mechanic /メカニック/
mechanical /メカニカル/
mechanics /メカニクス/メカニックス/
mechanism /メカニズム/
mechatronics /メカトロニクス/
meche /メッシュ/
meda /メダ/
medal /メダル/
medalist /メダリスト/
medallion /メダリオン/
medallist /メダリスト/
medan /メダン/
medea /メディア/メデア/
medi /メディ/
media /メディア/ミーディア/
mediacase /メディアケース/
mediacenter /メディアセンター/
mediacentre /メディアセンター/
mediafactory /メディアファクトリー;www.mediafactory.co.jp/
medialiteracy /メディアリテラシー/
mediamix /メディアミックス/
mediaplayer /メディアプレイヤー/
medias /メリヤス/
mediaservice /メディアサービス/
mediator /メディエータ/
mediaworks /メディアワークス;www.mediaworks.co.jp/
medic /メディック/
medical /メディカル/
medicalcheck /メディカルチェック;和製英語/
medication /メディケーション/
medici /メディチ/
medicine /メディシン/
medicis /メディシス/
medico /メディコ/
medina /メジナ/メディナ/
meditation /メディテーション/
medium /ミディアム/
medley /メドレー/
medoc /メドック/
medusa /メデューサ/メドゥーサ/メドゥサ/
meerkat /ミーアキャット/
meet /ミート/
meeting /ミーティング/会議/
meets /ミーツ/
meg /メグ/
mega /メガ;M,10^6/
megabank /メガバンク/
megabit /メガビット/
megabyte /メガバイト/
megabytes /メガバイト/
megadeath /メガデス/
megademo /メガデモ/
megadrive /メガドライブ/
megafloat /メガフロート/
megalopolis /メガロポリス/
megan /メーガン/
megaphone /メガホン/
megastore /メガストア/
megaton /メガトン/
mehmet /メフメト/
meier /メイヤー/
meissen /マイセン/
meissner /マイスナー/
meister /マイスター/
meistersinger /マイスタージンガー/
meitec /メイテック;www.meitec.co.jp/
mekong /メコン/
mel /メル/
melamine /メラミン/
melancholia /メランコリア/
melancholic /メランコリック/
melancholy /メランコリー/
melancolie /メランコリー;仏語/
melandri /メランドリ/
melanesia /メラネシア/
melanie /メラニー/メラニ/
melanin /メラニン/
melatonin /メラトニン/
melba /メルバ/
melbourne /メルボルン/
melby /メルビー/
melchior /メルキオール/メルキオル/
melco /メルコ/
melinda /メリンダ/
melisande /メリザンド/
melissa /メリッサ/メリサ/
mell /メル/
mello /メロ/
mellon /メロン/
mellow /メロウ/メロー/
melo /メロ/
melocore /メロコア;melodic core/
melodia /メロディア/
melodic /メロディック/
melodie /メロディー;仏語/メロディ/
melodion /メロディオン/
melodious /メロディアス/
melodius /メロディアス;※melodious?/
melodrama /メロドラマ/
melody /メロディ/メロディー/
melodyline /メロディーライン/メロディライン/
melon /メロン/ムロン;ブドウの品種/
melonpain /メロンパン/
melrose /メルローズ/
melt /メルト/
meltdown /メルトダウン/
melville /メルヴィル/メルビル/
melvin /メルヴィン/メルビン/
melvyn /メルヴィン/
member /メンバー/メンバ/
memberlist /メンバーリスト/
members /メンバーズ/
memberscard /メンバーズカード/
membersclub /メンバーズクラブ/
membership /メンバーシップ/メンバシップ/
membrane /メンブレン/
meme /ミーム/メーム/
memfis /メンフィス/
memo /メモ/
memomemo /メモメモ/
memorandum /メモランダム/メモ/
memorial /メモリアル/
memories /メモリーズ/
memory /メモリ/メモリー/
memoryaccess /メモリアクセス/
memorycard /メモリーカード/メモリカード/
memorychip /メモリチップ/
memoryleak /メモリリーク/
memorymapped /メモリマップド/
memoryset /メモリセット/
memoryslot /メモリースロット/メモリスロット/
memorystick /メモリースティック/
memphis /メンフィス/
men /メン/
mena /メナ/
menado /メナド/
menam /メナム/
menard /メナード/
mendel /メンデル/
mendeleev /メンデレーエフ/
mendelevium /メンデレビウム;[元素]101,Md/
mendelssohn /メンデルスゾーン/
mendieta /メンディエタ/
mendoza /メンドーサ/
menger /メンガー/
meniere /メニエール/
meno /メノ;(It)もっと/
mens /メンズ;men's/メンス;Menstruation/
mensfashion /メンズファッション/
mensshop /メンズショップ/
ment /メント;(接尾辞)/
mental /メンタル/
mentalcare /メンタルケア/
mentalhealth /メンタルヘルス/
mentalism /メンタリズム/
mentality /メンタリティ/メンタリティー/
mentaltraining /メンタルトレーニング/
menthol /メントール/メンソール/薄荷脳/
mentor /メンター/
menu /メニュー/ムニュ;(Fr) 定食/
menubar /メニューバー/メニュー・バー/
menuett /メヌエット/
menulist /メニューリスト/
mephist /メフィスト;mephistopheles/
mephistopheles /メフィストフェレス/
mer /メール;(Fr)海/
mercado /メルカド/
mercaptan /メルカプタン/
mercator /メルカトル/
mercedes /メルセデス/
mercedesbenz /メルセデスベンツ/
merchandise /マーチャンダイズ/
merchandiser /マーチャンダイザー/
merchandising /マーチャンダイジング/
merchant /マーチャント/
merchen /メルヘン;(独語)/メルヒェン/
merchentic /メルヘンチック;和製語(独語merchen + tic)/
merci /メルシー/メルシィ/
mercian /メルシャン;www.mercian.co.jp/
merck /メルク/
mercurius /メルクリウス/
mercury /マーキュリー/メルクリウス/
mercy /マーシー/
mere /メア/メール;(Fr)母/
meredith /メレディス/
merengue /メレンゲ/
merge /マージ/
mericlone /メリクロン/
merida /メリダ/
merimee /メリメ/
meringue /メレンゲ/
merit /メリット/
meritocracy /メリトクラシー/
merits /メリッツ/
merkel /メルケル/
merkl /メルクル/
merkmal /メルクマール/
merle /マール/メルル/
merleau /メルロー/メルロ/
merleauponty /メルロ=ポンティ/メルロポンティ/
merlin /マーリン/メルラン/
merlot /メルロー/メルロ/
merluza /メルルーサ/
mermaid /マーメイド/
merrell /メレル/
merrick /メリック/
merrill /メリル/
merrit /メリット/
merrow /メロウ;[ケルト神話]/
merry /メリー/
merrychristmas /メリークリスマス/
merrygoround /メリーゴーランド;merry-go-round/メリーゴーラウンド/
merryxmas /メリークリスマス/
mersenne /メルセンヌ/
merveille /メルヴェイユ/メルヴェーユ/
meryl /メリル/
mes /メ;仏語/
mescaline /メスカリン/
mesh /メッシュ/
meso /メソ/
meson /メソン/中間子/
mesopotamia /メソポタミア/
mess /メス/
messa /メッサ/
message /メッセージ/
messagebox /メッセージボックス/
messagecard /メッセージカード;note card/
messageid /メッセージＩｄ/
messaging /メッセージング/
messanger /メッセンジャー/メッセンジャ/
messangers /メッセンジャーズ/
messe /メッセ/
messerschmitt /メッサーシュミット/
messiaen /メシアン/
messiah /メシア/メサイア/
messier /メシエ/
messina /メッシーナ/
messy /メッシー/
mesto /メスト/
meta /メタ/メータ/
metabolic /メタボリック/
metadata /メタデータ/
metafiction /メタフィクション/
metafont /メタフォント/
metal /メタル/
metalband /メタルバンド/
metalcable /メタルケーブル/
metalevel /メタレベル/
metalframe /メタルフレーム/
metalic /メタリック/
metaliccolor /メタリックカラー/
metaliccolour /メタリックカラー/
metaljacket /メタルジャケット/
metallic /メタリック/
metallica /メタリカ/
metallicblue /メタリックブルー/
metalogue /メタローグ;[出版社名]www.metalogue.co.jp/
metalpercussion /メタルパーカッション/
metaltape /メタルテープ/
metamorphose /メタモルフォーゼ/
metaphor /メタファー/
metasearch /メタサーチ/
metasequoia /メタセコイア/
meteo /メテオ/
meteor /メテオ/メテオール/
meter /メートル/メーター/メータ/
methan /メタン;(独語)/
methane /メタン;CH4/
methanegas /メタンガス/
methanehydrate /メタンハイドレート/
methanol /メタノール/
metheny /メセニー/
methionine /メチオニン;Met/
metho /メト;methyl/
method /メソッド/
methodist /メソジスト/
methodology /メソドロジ/
methoxy /メトキシ/
methyl /メチル;-CH3/
methylalcohol /メチルアルコール/
methylamine /メチルアミン/
methylbenzene /メチルベンゼン;=toluene/
methylene /メチレン/
methylether /メチルエーテル/
metier /メチエ/
metonymy /メトニミー/
metric /メトリック/
metrics /メトリックス/メトリクス/
metro /メトロ/
metronom /メトロノーム;(独語)/
metronome /メトロノーム/
metropolis /メトロポリス/
metropolitan /メトロポリタン/
metry /メトリー/メトリ/
mets /メッツ;[MLB]/
metz /メス/
meunier /ムニエ/
meuniere /ムニエル/
meursault /ムルソー/
mexican /メキシカン/
mexico /メキシコ;.mx/メヒコ;(西語読み)/
mexicocity /メキシコシティ;メキシコ(mex)/メキシコシティー/
mexp /M式/
meyer /マイヤー/
mezzo /メゾ;(イタリア語)/
mezzoforte /メゾフォルテ;mezzo forte/
mezzopiano /メゾピアノ;mezzo piano/
mezzosoprano /メゾソプラノ/
mezzotint /メゾチント/
mf /MetaFont/メゾフォルテ;やや強く/mezzo forte/
mg /マグネシウム/Magnesium/ミリグラム/
mhz /ＭＨｚ/
mi /Michigan/ミシガン/ミ/
mia /ミーア/ミア/
miami /マイアミ/
mic /マイク;microphone/
mica /マイカ;雲母/
micah /ミカ/
miccoli /ミッコリ/
mice /マイス/
micelle /ミセル/
michael /マイケル/ミカエル/ミヒャエル/ミッシェル/ミハエル/
michaela /ミカエラ/
michaux /ミショー/
michel /ミシェル/ミッシェル/マイケル/ミチェル/
michelangelo /ミケランジェロ/
michele /ミケーレ;(イタリア語)/ミシェル;仏語/ミッシェル;仏語/
michelet /ミシュレ/
michelin /ミシュラン/
michelle /ミシェル/ミッシェル/
michigan /ミシガン/
mick /ミック/
mickey /ミッキー/
mickeymouse /ミッキーマウス;[商標]Disney/
micky /ミッキー/
micom /マイコン/
micro /マイクロ/ミクロ/μ/
microbus /マイクロバス/
microchip /マイクロチップ/
microcomputer /マイクロコンピュータ/
microcosmos /ミクロコスモス/
microfiber /マイクロファイバー/
microfilm /マイクロフィルム/
microgram /μg/マイクログラム/
microgramme /μg/マイクログラム/
microkernel /マイクロカーネル/
microlens /マイクロレンズ/
micromachine /マイクロマシン/
micrometer /μm/マイクロメートル/マイクロメータ/マイクロメーター/
micrometre /μm/マイクロメートル/
micromini /マイクロミニ/
micromouse /マイクロマウス/
micron /ミクロン/
micronesia /ミクロネシア;.fm/
microphone /マイクロフォン/マイクロホン/
microprocessor /マイクロプロセッサ/
microscope /マイクロスコープ/
microsecond /マイクロセカンド/マイクロ秒/
microsoft /マイクロソフト;www.microsoft.com/
microsome /ミクロソーム/ミクロゾーム/
microsystems /マイクロシステムズ/
microtower /マイクロタワー/
microwave /マイクロウェーブ/
mid /ミッド/
midas /ミダス/
midcentury /ミッドセンチュリー/
middle /ミドル/
middleage /ミドルエイジ/
middleclass /ミドルクラス/
middlehole /ミドルホール;par-4/
middleiron /ミドルアイアン;5-7/
middlename /ミドルネーム/
middlerange /ミドルレンジ/
middleshoot /ミドルシュート/
middletempo /ミドルテンポ/
middletower /ミドルタワー/
middleware /ミドルウェア/ミドルウエア/
midfield /ミッドフィールド/
midfielder /ミッドフィールダー/ミッドフィルダー/
midgard /ミッドガルド/
midi /ミディ/
midnight /ミッドナイト/
midrange /ミッドレンジ/
midship /ミッドシップ/
midtown /ミッドタウン/
midway /ミッドウェー/ミッドウェイ;イリノイ(USA)(mdw)/
miffy /ミッフィー/
mig /ミグ/
might /マイト/
mighty /マイティ/
mignon /ミニョン/ミニヨン/
migrate /マイグレート/移送/マイグレイト/
migration /マイグレーション/移送/マイグレイション/
miguel /ミゲル/
mihaela /ミハイル/
mihail /ミハイル/
mihrab /ミフラーブ/
mika /ミカ/
mikael /ミカエル/
mike /マイク/ミケ/
mikey /マイキー/
mikhail /ミハイル/ミハエル/
mikihouse /ミキハウス;www.mikihouse.co.jp/
mikko /ミッコ/
mikonos /ミコノス/
mil /ミル/
mila /ミラ/
milage /マイレッジ/
milan /ミラン/
milano /ミラノ/
mild /マイルド/
mildred /ミルドレッド/
mildseven /マイルドセブン/
mile /マイル/
mileage /マイレージ/マイレッジ/
milena /ミレナ/ミレーナ/
miler /マイラー/
miles /マイルス/マイルズ/
milestone /マイルストーン/
milhaud /ミヨー/
military /ミリタリー/
milk /ミルク/
milka /ミルカ/
milkchoco /ミルクチョコ/
milkchocolate /ミルクチョコレート/
milkcocoa /ミルクココア/
milkcoffee /ミルクコーヒー/
milkpan /ミルクパン;(鍋)milk pan/
milkpot /ミルクポット/
milkshake /ミルクセーキ/
milktea /ミルクティー/ミルクティ/
milky /ミルキー/
mill /ミル/
milla /ミラ/
millan /ミラン/
mille /ミル/
millecrepe /ミルクレープ;mille crepe/
millefeuille /ミルフィーユ;mille-feuille/
millenium /ミレニアム/
miller /ミラー/
millet /ミレー/
milli /ミリ/
millibar /ミリバール;=hectopascal/
millie /ミリー/
milligram /ミリグラム/
milligramme /ミリグラム/
millikan /ミリカン/
milliliter /ミリリットル/
millilitre /ミリリットル/
millimeter /ミリメートル/
millimetre /ミリメートル/
million /ミリオン;1,000,000/
millionaire /ミリオネア/
millionseller /ミリオンセラー/
millisecond /ミリセカンド/ミリ秒/
milly /ミリー/
milner /ミルナー/
milo /ミロ/
milon /ミロン/
milonga /ミロンガ/
milos /ミロシュ/ミロス/
milt /ミルト/
milton /ミルトン/
milwaukee /ミルウォーキー;USA/
mimd /MIMD/
mime /マイム/ミーム/
mimesis /ミメーシス/ミメシス/
mimi /ミミ/
mimic /ミミック/
mimosa /ミモザ/
min /ミン/ミニマム/
mina /ミナ/
minardi /ミナルディ/
minaret /ミナレット/
minas /ミナス/
mince /ミンチ/
mind /マインド/
mindanao /ミンダナオ;フィリピン/
mindcontrol /マインドコントロール/
mine /マイン/ミーネ;(独語人名)/
minebea /ミネベア;www.minebea.co.jp/
miner /マイナー/
mineral /ミネラル/
mineralwater /ミネラルウォーター/
minerva /ミネルヴァ/ミネルバ/
minestrone /ミネストローネ/
minette /ミネット/
mingus /ミンガス/
mini /ミニ/
minialbum /ミニアルバム/
miniature /ミニチュア/
miniaturedachs /ミニチュアダックス;miniature dachshund/
miniaturedachshund /ミニチュアダックスフンド/ミニチュアダックスフント/
minibottle /ミニボトル/
minibuffer /ミニバッファ/
minibus /ミニバス/
minicar /ミニカー/
minicom /ミニコン/
minicompo /ミニコンポ;minicomponent stereo/
minicomputer /ミニコンピュータ/ミニコン/
minidisc /ミニディスク;MD/
minidisk /ミニディスク/
minigame /ミニゲーム/
minijack /ミニジャック/
minilive /ミニライブ/
minimal /ミニマル/
minimalism /ミニマリズム/
minimalist /ミニマリスト/
minimalmusic /ミニマルミュージック/
minimini /ミニミニ/
minimum /ミニマム/最小/最小値/
mining /マイニング/
minion /ミニオン/
minisize /ミニサイズ/
miniskirt /ミニスカート/
minister /ミニスター/
ministop /ミニストップ;www.ministop.co.jp/
minitower /ミニタワー/
minivan /ミニバン/
mink /ミンク/
minkowski /ミンコフスキー/
minna /ミンナ/
minneapolis /ミネアポリス/
minnesota /ミネソタ;MN/
minnie /ミニー/
minolta /ミノルタ;www.konicaminolta.jp/
minor /マイナー/マイナ/
minorchange /マイナーチェンジ/
minority /マイノリティ/マイノリティー/
minorleague /マイナーリーグ/
minormode /マイナーモード/
minorversion /マイナーバージョン/
minos /ミノス/
minotaur /ミノタウロス/ミノトール/
minotauros /ミノタウロス/
minovsky /ミノフスキー/
minsk /ミンスク/
minstrel /ミンストレル/
mint /ミント/
mintgreen /ミントグリーン/
minton /ミントン/
minuet /メヌエット/
minus /マイナス/−;minus/
minusdriver /マイナスドライバー;和製英語(flat screwdriver)/
minusimage /マイナスイメージ;和製英語(negative image)/
minusion /マイナスイオン;和製英語(negative ion)/
minute /ミニット/′/
minutes /ミニッツ/
minutia /マニューシャ/
mips /MIPS/
mira /ミラ/
mirabel /ミラベル/
mirabelle /ミラベル/
miracle /ミラクル/
miraclefruit /ミラクルフルーツ/
miraclefruits /ミラクルフルーツ/
mirage /ミラージュ/
miranda /ミランダ/
mireille /ミレイユ/ミレーユ/
miri /ミリ/
miriam /ミリアム/
mirko /ミルコ/
miro /ミロ/
miron /ミロン/
miroslav /ミロスラフ/
mirra /ミイラ;(ポルトガル語)/
mirror /ミラー/
mirrorball /ミラーボール/
mirroring /ミラーリング/
mirrorsite /ミラーサイト/
mis /ミス/
miscast /ミスキャスト/
miserable /ミゼラブル/
misha /ミーシャ/
misjudge /ミスジャッジ/
mismatch /ミスマッチ/
mispri /ミスプリ;misprint/
misprint /ミスプリント/
miss /ミス/
missa /ミサ/
missanga /ミサンガ/
misshit /ミスヒット/
missile /ミサイル/
missing /ミッシング/
missinglink /ミッシングリンク/
mission /ミッション/
missioncritical /ミッションクリティカル/
missionschool /ミッションスクール/
mississippi /ミシシッピ;MS/
missouri /ミズーリ;MO/
misspell /ミススペル/
misspicking /ミスピッキング/
misstouch /ミスタッチ/
misstype /ミスタイプ/
mist /ミスト/
mistake /ミステイク/
mister /ミスター/
misterdonut /ミスタードーナツ;www.misterdonut.co.jp/
misterioso /ミステリオーソ/
mistery /ミステリー;※mystery/
mistral /ミストラル/
mistress /ミストレス/
misty /ミスティ/ミスティー/
mit /MIT/ミット/
mitchell /ミッチェル/
mithra /ミスラ/ミトラ/
mithril /ミスリル/
mitochondria /ミトコンドリア/
mitomycin /マイトマイシン/
mitra /ミトラ/
mitt /ミット/
mitten /ミトン/
mitterrand /ミッテラン/
mitya /ミーチャ/
mix /ミックス/ミクス/
mixer /ミキサー/ミキサ/
mixi /ミクシィ;mixi.jp/
mixing /ミキシング/
mixjuice /ミックスジュース/
mixnuts /ミックスナッツ/
mixolydian /ミクソリディアン;GABCDEFG/
mixture /ミクスチャー/ミクスチャ/ミクスチュア/
mjollnir /ミョルニル/ミョルニール/
ml /メーリングリスト/メイリングリスト/
mlsize /MLサイズ/ＭＬサイズ/
mm /ミリメートル/
mmi /マン・マシン・インタフェース/
mn /マンガン/Manganese/ミネソタ/Minnesota/
mnemonic /ニーモニック/
mnemosyne /ムネモシュネ/
mo /Molybdenum/モリブデン/光磁気ディスク/Missouri/ミズーリ/MO/
moai /モアイ/
moan /モーン/
moanin /モーニン;moanin'/
moaning /モーニング;うめき/
mob /モブ/
mobile /モバイル/モービル/モビル/モビール/
mobilenote /モバイルノート/
mobilepage /モバイルページ/
mobileservice /モバイルサービス/
mobilesuit /モビルスーツ/
mobility /モビリティ/
mobit /モビット;[企業名]消費者金融。www.mobit.ne.jp/
mobius /メビウス/
moblog /モブログ/
mobscene /モブシーン/
moby /モービー/
moccasin /モカシン/
moccus /モックス/
mocha /モカ/
mock /モック/
mocking /モッキング/
mockingbird /モッキンバード/モッキングバード/
mockup /モックアップ/
moco /モコ/
modal /モーダル/
modality /モダリティ/
modalshift /モーダルシフト/
mode /モード/
mode-line /モードライン/
model /モデル/
modelcar /モデルカー/
modelcase /モデルケース/
modelchange /モデルチェンジ/
modelcourse /モデルコース/
modeler /モデラー/モデラ/
modeless /モードレス/
modelgun /モデルガン/
modelhouse /モデルハウス/
modeline /モードライン/
modeling /モデリング/
modelling /モデリング/
modelnumber /モデルナンバー/
modelroom /モデルルーム/
modem /モデム/
modemcard /モデムカード/
modemrental /モデムレンタル/
modena /モデナ/
moderate /モデレート/モデラート;※moderato(It.)?/モデレイト/
moderato /モデラート/
moderator /モデレータ/モデレーター/
modern /モダン/
modernart /モダンアート/
modernballet /モダンバレエ/
moderndance /モダンダンス/
moderne /モデルヌ;仏語/
modernism /モダニズム/モダニスム/
modernite /モデルニテ;(Fr) 現代性/
modernjazz /モダンジャズ/
moderno /モデルノ;(イタリア語)/
modest /モデスト/
modifier /モディファイア/
modify /モディファイ/
modigliani /モジリアーニ/
modisk /MOディスク/
modrive /MOドライブ/
modular /モジュラー/モジュラ/
modularity /モジュラリティ/
modularjack /モジュラージャック/
modulation /モジュレーション/
module /モジュール/モデュール/
moduler /モジュラー;※modular/
modulo /モデューロ/モジュロ/
moebius /メビウス/
mogadishu /モガディシュ/
mogol /モール;(ポルトガル語)/
mogul /モーグル/
mohair /モヘア/モヘヤ/
mohammad /モハメド/ムハンマド/モハマド/
mohawk /モホーク/
mohenjodaro /モヘンジョダロ;Mohenjo-Daro/モヘンジョ・ダロ/
mohican /モヒカン/
mohr /モーア/
mohs /モース/
moi /モワ/
moira /モイラ/
moire /モアレ/
moist /モイスト/
moisture /モイスチャー/
mojito /モヒート/
mol /モル/
mola /モラ/モーラ/
mold /モールド/
moldau /モルダウ/
moldova /モルドバ;.md/モルドヴァ/
mole /モール/モル/
molecular /モレキュラー/
moleskin /モールスキン/
moley /モーリー/
moliere /モリエール/
molina /モリーナ/
moll /モール/モル/
mollis /モリス/
molly /モーリー/モリー/
molokai /モロカイ/
molto /モルト;(It)非常に/
molybden /モリブデン;Mo/
molybdenum /モリブデン;[元素]42,Mo/
mom /マム/
mombasa /モンバサ/
moment /モーメント/
moments /モーメンツ/
momentum /モメンタム/モーメント/モーメンタム/モーメント項/
mommy /マミー/
momo /モモ/
momos /モモス/
mompou /モンポウ/
mon /モン/月/
monaco /モナコ/
monacogp /モナコGP;[F1]/
monad /モナド/
monaghan /モナハン/
monarch /モナーク/
monaural /モノラル/
monday /マンデー/マンディ/マンデイ/マンディー/月曜日/
monde /モンド/
mondriaan /モンドリアン/
mondrian /モンドリアン;(英語綴り)=Mondriaan/
monet /モネ/
monetarism /マネタリズム/
monetary /マネタリー/
money /マネー/
moneygame /マネーゲーム/
moneylaundering /マネーロンダリング/
moneysupply /マネーサプライ/
mongol /モンゴル/
mongolia /モンゴリア;.mn/
mongolian /モンゴリアン/
mongoloid /モンゴロイド/
mongoose /マングース/
monica /モニカ/
monika /モニカ/
monique /モニク/
monitor /モニター/モニタ/
monitorcable /モニターケーブル/モニタケーブル/
monitoring /モニタリング/
monitormode /モニタモード/
monk /モンク/
monkey /モンキー/
monnalisa /モナリザ;Monna Lisa/
mono /モノ/モノクロ;monochrome/
monochro /モノクロ;monochrome/
monochrome /モノクローム/モノクロ/
monoculture /モノカルチャー/
monod /モノ/
monoethyl /モノエチル/
monogram /モノグラム/
monograph /モノグラフ/
monoid /モノイド/
monolith /モノリス/
monolithic /モノリシック/
monolog /モノローグ/
monologue /モノローグ/
monomania /モノマニア/
monomer /モノマー/単量体/
monomethyl /モノメチル/
monopole /モノポール/
monopoly /モノポリー/
monorail /モノレール/
monotone /モノトーン/
monotype /モノタイプ/
monroe /モンロー/
monsieur /ムッシュー/ムッシュウ/
monsoon /モンスーン/
monster /モンスター/
monsters /モンスターズ/
montage /モンタージュ/
montague /モンタギュー/
montaigne /モンテーニュ/
montana /モンタナ;MT/
montand /モンタン/
montblanc /モンブラン;Mont Blanc/
monte /モンテ/モント/モンティ/
montecarlo /モンテカルロ;Monte-Carlo/モンテカルロ法/
montecristo /モンテクリスト;Monte Cristo/モンテ=クリスト/
montee /モンテ/
montella /モンテッラ/
montenegro /モンテネグロ/
monterey /モントレー;USA/
monterosa /モンテローザ;Monte Rosa/
montes /モンテス/
montesquieu /モンテスキュー/
montessori /モンテッソーリ/
monteverdi /モンテヴェルディ/
montevideo /モンテビデオ/
montgomery /モンゴメリー/モンゴメリ/モントゴメリー;地名/
month /マンス/
monthly /マンスリー/
monti /モンティ/
montmartre /モンマルトル;18区/
montoya /モントーヤ/
montparnasse /モンパルナス;15区/
montpellier /モンペリエ/
montreal /モントリオール/
montreux /モントルー;スイス/
montrose /モンローズ;Mont Rose/
montserrat /モントセラト;.ms/
monty /モンティ/
montylymansion /マンスリーマンション/
monument /モニュメント/
monumental /モニュメンタル/
mood /ムード/
moodmaker /ムードメーカー/
moody /ムーディー/ムーディ/
moodys /ムーディーズ;Moody's. www.moodys.com/
moog /モーグ/ムーグ/
mook /ムック/
moomin /ムーミン/
moon /ムーン/
moonlight /ムーンライト/
moonriver /ムーンリバー/
moonsault /ムーンサルト/
moonstone /ムーンストーン/
moor /ムーア/
moorcock /ムアコック/
moore /ムーア/
moose /ムース/
mop /モップ/MOP/
mora /モーラ/モラ/
moraine /モレーン/
moral /モラル/
morale /モラル/モラール/
morales /モラレス/
moralhazard /モラルハザード/
moralism /モラリズム/
moralist /モラリスト/
moraliste /モラリスト/
moran /モラン/モーラン/
morandi /モランディ/
moratorium /モラトリアム/
moravia /モラヴィア/
mordor /モルドール/
more /モア/モレ/
moreau /モロー/
morel /モレル/
morell /モレル/
morelle /モレル/
morello /モレロ/
moreno /モレノ/
moretti /モレッティ/
morgan /モーガン/モルガン/
morganite /モルガナイト/
morgue /モルグ/
mori /モーリ/
morientes /モリエンテス/
morin /モラン/モーリン/モリン/
morison /モリソン/
moritz /モーリッツ/モリッツ/
morley /モーリー/
mormon /モルモン/
mornin /モーニン;mornin'/
morning /モーニング/
morningcall /モーニングコール;和製英語(wake-up call)/
morningset /モーニングセット/
morningstar /モーニングスター/
moro /モロ/
morocco /モロッコ/
moroco /モロッコ;.ma/
moroni /モロニ/
morozov /モロゾフ/
morph /モーフ/モーフィング/
morphine /モルヒネ/
morphing /モーフィング/
morrell /モレル/
morricone /モリコーネ/
morrigan /モリガン/
morris /モーリス/モリス/
morrison /モリソン/
morrow /モロー/モロウ/
morse /モース/モールス/
mort /モール;(Fr)死/
mortal /モータル/
mortar /モルタル/
mortgage /モーゲージ/
morton /モートン/
mos /モス/
mosa /モサ/
mosaic /モザイク/
mosburger /モスバーガー;www.mos.co.jp/
moscato /モスカート/
moscow /モスクワ/モスコー/
mosel /モーゼル/
moses /モーセ/モーゼ/モーゼス/
mosh /モッシュ/
moskowmule /モスコミュール/
moskva /モスクワ/
moslem /モスレム/
mosque /モスク/
mosquito /モスキート/
moss /モス/
mossad /モサド/
mossgreen /モスグリーン/
mosso /モッソ/
most /モスト/
mosul /モスル;イラク/
mot /モ;(Fr)語/
motedio /モンテディオ;[Jリーグ]山形/
motel /モーテル/
motet /モテット/
mother /マザー/
motherbo /マザボ;motherboard/
motherboard /マザーボード/
mothercon /マザコン;mother complex/
mothergoose /マザーグース;Mother Goose/
mothers /マザーズ/
mothership /マザーシップ/
mothra /モスラ/
motif /モチーフ/モティーフ/Ｍｏｔｉｆ/Motif/
motion /モーション/
motioncapture /モーションキャプチャー/モーションキャプチャ/
motionfeedback /モーションフィードバック/
motionpicture /モーションピクチャー/
motivation /モチベーション/
moto /モート/
motocross /モトクロス/
motor /モーター/モータ/
motorboat /モーターボート/
motorcar /モーターカー/
motorcycle /モーターサイクル/
motorisation /モータリゼーション/
motorization /モータリゼーション/
motorola /モトローラ/Motorola/
motors /モータース/モーターズ/
motorshow /モーターショー/
motorsport /モータースポーツ/
motorsports /モータースポーツ/
motown /モータウン/
motrola /モトローラ;※motorola?/
motta /モッタ/
motto /モットー/
moule /ムール/
moulinrouge /ムーランルージュ/
moulis /ムリス/
mound /マウンド/
mount /マウント/
mountain /マウンテン/
mountainbike /マウンテンバイク/
mounter /マウンタ/
mounting /マウンティング/
mountposition /マウントポジション/
mouse /マウス/
mousebutton /マウスボタン/
mousecursor /マウスカーソル/
mousepad /マウスパッド/
mousepointer /マウスポインタ/マウスポインター/
mousewheel /マウスホイール/
moussaka /ムサカ;Μουσακασ/
mousse /ムース/
mouth /マウス/
mouthpiece /マウスピース/
mouton /ムートン/
move /ムーブ/ムーヴ/
movement /ムーブメント/ムーヴメント/
mover /ムーバ/ムーバー/
movie /ムービー/ムーヴィー/
moving /ムービング/
moya /モヤ/
mozambique /モザンビーク;.mz/
mozart /モーツァルト/モーツアルト/
mozilla /モジラ/
mozzarella /モッツァレラ/モツァレラ/
mp /メゾピアノ;やや弱く/mezzo piano/
mp#file /MP#0ファイル/
mp#player /MP#0プレーヤー/MP#0プレイヤー/
mp3player /MP3プレーヤー/MP3プレイヤー/
mr /Ｍｒ．/ミスター;Mr./
mrdonut /ミスタードーナツ;www.misterdonut.co.jp/
mrna /ｍ-ＲＮＡ/
mrs /ミセス;Mrs./
ms /ミズ;Ms./ミリ秒/ミリセカンド/ミリセコンド/Mississippi/ミシシッピ/マイクロソフト/
ms-dos /MS-DOS/
msdos /MS-DOS/ＭＳ−ＤＯＳ/
msec /ミリセカンド/millisecond/ミリ秒/
msize /Mサイズ/Ｍサイズ/
mt /マウント/マイトネリウム/Meitnerium/Montana/モンタナ/
mu /μ/ミュー/ミュウ/ムー/ムウ/
muaythai /ムエタイ/
much /マッチ/
mucha /ミュシャ/
mud /マッド/
muddler /マドラー/
mueller /ミュラー/ミューラー/ミュレル/
muff /マフ/
muffin /マフィン/
muffler /マフラー/
mug /マグ/
mugcup /マグカップ;和製英語(mug)/
mughal /ムガール/ムガル/
muguet /ミュゲ;(Fr)鈴蘭/
muhammad /モハメド/ムハンマド/マホメット/
mujahadeen /ムジャヒディン/
mujahideen /ムジャヒディン/ムジャヒディーン/
mule /ミュール/Mule/
muleta /ムレタ/
muller /ミュラー/ミューラー/マラー/
multi /マルチ/
multiagent /マルチエージェント/マルチエイジェント/
multiboot /マルチブート/
multibyte /マルチバイト/
multicast /マルチキャスト/
multichip /マルチチップ/
multicomputer /マルチコンピュータ/
multicore /マルチコア/
multidrive /マルチドライブ/
multihome /マルチホーム/
multilevel /マルチレベル/
multilingual /マルチリンガル/
multimedia /マルチメディア/
multimodal /マルチモーダル/
multipart /マルチパート/
multipath /マルチパス/
multiplayer /マルチプレイヤー/
multiple /マルチプル/
multiplex /マルチプレックス/
multiplexer /マルチプレクサ/
multiplexor /マルチプレクサ/
multiplier /マルチプライヤ/
multipost /マルチポスト/
multiprocessor /マルチプロセッサ/
multirate /マルチレート/
multiscan /マルチスキャン/
multiserver /マルチサーバ/
multiset /マルチセット/
multitalker /マルチトーカ/
multitalkernoise /マルチトーカノイズ/
multitask /マルチタスク/
multithread /マルチスレッド/
multitrack /マルチトラック/
multiuser /マルチユーザー/マルチユーザ/
multiwindow /マルチウィンドウ/
mulukhiya /モロヘイヤ/
mumbai /ムンバイ;インド/
mummy /マミー;ミイラ/
munch /ムンク/ミュンシュ/
munchen /ミュンヘン/
munchkin /マンチキン/マンチカン/
munich /ミュンヘン/
munson /マンソン/
muon /ミューオン/
murano /ムラーノ/ムラノ/
murcia /ムルシア/
murder /マーダー/
murdoch /マードック/
muriel /ミュリエル/
murphy /マーフィー/マーフィ/
murray /マレー;オーストラリア/マーレイ/マレイ/
musa /ムーサ/
musai /ムーサイ/
muscadet /ミュスカデ/
muscarine /ムスカリン/
muscat /マスカット/ミュスカ;仏語/
muscle /マッスル/
muse /ミューズ/
musee /ミュゼ;(Fr)美術館/
musette /ミュゼット/
musharraf /ムシャラフ/
mushroom /マッシュルーム/
music /ミュージック/♪;quaver/♯;sharp/♭;flat/∫;※積分記号(integral)/∬;※二重積分記号/
musica /ムジカ/
musical /ミュージカル/
musicbox /ミュージックボックス/
musician /ミュージシャン/
musicschool /ミュージックスクール/
musicvideo /ミュージックビデオ/
musik /ムジーク;(独語)音楽/
musium /ミュージアム/
musket /マスケット/
muslim /ムスリム/
muslin /モスリン/
musorgskii /ムソルグスキー/
musset /ミュッセ/
mussolini /ムッソリーニ/
must /マスト/
mustafa /ムスタファ/
mustang /ムスタング/
mustapha /ムスタファ/
mustard /マスタード/
mustardgas /マスタードガス/
mustardsauce /マスタードソース/
mutable /ミュータブル/
mutant /ミュータント/
mute /ミュート/
mutex /ミューテックス/
muti /ムーティ/
mutt /マット;犬/
mutter /ムター/ムッター/
mutton /マトン/
mutual /ミューチュアル/
mw /ミドルウエア/
mxtv /MXテレビ;www.mxtv.co.jp/
my /マイ/
myanmar /ミャンマー;.mm/
myboom /マイブーム;和製英語/
mycar /マイカー/
mycenae /ミケーネ/ミュケナイ/
mycenai /ミケーネ/ミュケナイ/
mycin /マイシン/
mycomputer /マイコンピュータ/
mycotoxin /マイコトキシン/
myelin /ミエリン/
myers /マイヤーズ/
myhome /マイホーム/
mylene /ミレーヌ/
myline /マイライン/
myoglobin /ミオグロビン/
myosin /ミオシン/
mypace /マイペース/
mypage /マイページ/
myra /マイラ/
myriam /ミリアム/
myroom /マイルーム/
myrrh /ミルラ/マー/
myrrha /ミルラ/
myrte /ミルテ/
myrtle /マートル/
myself /マイセルフ/
mysterious /ミステリアス/
mystery /ミステリー/ミステリ/
mysterycircle /ミステリーサークル/
mysterytour /ミステリーツアー/
mythology /ミソロジー/
mythos /ミトス/ミュトス/
mytyl /ミチル/
myway /マイウェイ/
n /ν;nu/エヌ/н;en (cyrillic)/窒素/Nitrogen/
na /ナトリウム/Sodium/
naan /ナン/ナーン/
nabisco /ナビスコ/
nabla /∇;ベクトル微分/
nabokov /ナボコフ/
nacelle /ナセル/
nacht /ナハト/
nachtmusik /ナハトムジーク/
nack /ナック/
nadal /ナダル/
nadar /ナダール/
nadia /ナディア/
nadine /ナディーン/ナディーヌ/
nadja /ナジャ/
naga /ナーガ/
nagoyadome /ナゴヤドーム/名古屋ドーム/
nahum /ナホム/
naiad /ナイアード/
nail /ネイル/
nailart /ネイルアート/
nailcare /ネイルケア/
nailchip /ネイルチップ;和製英語(artificial nail)/
nailcolor /ネイルカラー/
nailcolour /ネイルカラー/
nailenamel /ネイルエナメル/
nailsalon /ネイルサロン/
nairobi /ナイロビ/
naive /ナイーブ/
najaf /ナジャフ;イラク/
naked /ネイキッド/
nakhodka /ナホトカ/
namaste /ナマステ/
namco /ナムコ;www.namco.co.jp/
name /ネーム/名/名称/名前/
nameplate /ネームプレート/
nameserver /ネームサーバ/ネームサーバー/
namespace /ネームスペース/
namevalue /ネームヴァリュー/ネームバリュー/
nami /〜/
namibia /ナミビア;.na/
naming /ネーミング/
namingrights /ネーミングライツ/
namingsense /ネーミングセンス/
namplaa /ナンプラー/
namul /ナムル;(朝鮮語)/
nan /ナン/
nana /ナナ/
nanao /ナナオ/
nance /ナンス/
nancy /ナンシー/
nanette /ナネット/
nannette /ナネット/
nanni /ナンニ/
nanny /ナニー/
nano /ナノ;[SI接頭語]n,10^-9/
nanometer /ナノメートル/
nanometre /ナノメートル/
nanoscale /ナノスケール/
nanosleep /ナノスリープ/
nanotech /ナノテク;nanotechnology/
nanotechnology /ナノテクノロジー/
nanotube /ナノチューブ/
nantes /ナント/
naomi /ナオミ;(聖書人名)/
nap /ナップ/
napalm /ナパーム/
naphtha /ナフサ/ナフタ/
naphthalene /ナフタレン;C10H8/ナフタリン/
naphthol /ナフトール/
napkin /ナプキン/ナフキン;転訛/
napoleon /ナポレオン/
napoli /ナポリ/
napolitan /ナポリタン/
nappage /ナパージュ/
napster /ナップスター;www.napster.com/
narcism /ナルシズム/
narciso /ナルシソ/
narcisse /ナルシス/
narcissism /ナルシシズム/
narcissist /ナルシシスト/
narcist /ナルシスト/
narcistic /ナルシスティック/
narcolepsy /ナルコレプシー/
narkissos /ナルキッソス/
narod /ナロード;(露語)人民/
narration /ナレーション/
narrative /ナラティブ/ナラティヴ/
narrator /ナレーター/
narrow /ナロー/
narrowband /ナローバンド/
nasa /NASA/
nasdaq /ナスダック/
nash /ナッシュ/
nasha /ナーシャ/
nashville /ナッシュヴィル/ナッシュビル;テネシー(USA)/
nassau /ナッソー/
nasser /ナセル/
nastassja /ナスターシャ/
nasturtium /ナスタチウム;キンレンカ/
nasty /ナスティー/ナスティ/
nat /ナット/
nata /ナタ/
natacha /ナターシャ/
natadecoco /ナタデココ;nata de coco/
natalia /ナタリア/
natalie /ナタリー/
natasha /ナターシャ/
nate /ネイト/
nathalie /ナタリー/
nathan /ネイサン/ナタン/ナータン/
nathaniel /ナサニエル/
nation /ネーション/ネイション/ナシオン;仏語/
national /ナショナル/
nationalism /ナショナリズム/
nationalist /ナショナリスト/
nationality /ナショナリティ/ナショナリティー/
nationalleague /ナショナルリーグ/
nationals /ナショナルズ;[MLB]/
native /ネイティブ/ネイティヴ/ネーティブ/
nativespeaker /ネイティブスピーカー/
natrium /ナトリウム;[元素]11,Na/
natriumion /ナトリウムイオン;sodium ion/
natriumlamp /ナトリウムランプ;sodium lamp/
natural /ナチュラル/
naturalcheese /ナチュラルチーズ/
naturalhigh /ナチュラルハイ/
naturalist /ナチュラリスト/
nature /ネイチャー/ナチュール;仏語/Ｎａｔｕｒｅ/
nauru /ナウル/
nausicaa /ナウシカ/
naut /ノート/
nautilus /ノーチラス/
navajo /ナバホ/ナヴァホ/
navarro /ナバロ/ナヴァロ/ナバーロ/
navel /ネーブル/
navi /ナビ/Ｎａｖｉ/ナヴィ/
navier /ナビア/
navigate /ナビゲート/
navigation /ナビゲーション/
navigationbar /ナビゲーションバー/
navigator /ナビゲーター/ナビゲータ/
navy /ネイビー/
navyblue /ネイビーブルー/
nay /ネイ/ナーイ/
nazar /ナザール/
nazare /ナザレ/
nazareth /ナザレ/ナザレス/
nazca /ナスカ;ペルー/
nazgul /ナズグル/
nazi /ナチ/
nazis /ナチス/
nazisdeutsch /ナチスドイツ/
nazism /ナチズム/
nb /ニオブ/Niobium/
nc /North Carolina/ノースカロライナ/
nd /North Dakota/ノースダコタ/ネオジム/Neodymium/
ne /≠/ネオン/Neon/Nebraska/ネブラスカ/└/┗;太/
neal /ニール/
neale /ニール/
neanderthal /ネアンデルタール/
near /ニア/
nearlyequal /≒/
nearmiss /ニアミス/
neat /ニート/
nebbiolo /ネッビオーロ/
nebraska /ネブラスカ;NE/
nebula /ネビュラ/
nec /日本電気/NEC/
neck /ネック/
neckar /ネッカー/
necker /ネッカー/
neckerchief /ネッカチーフ/
necklace /ネックレス/
neckline /ネックライン/
neckstrap /ネックストラップ/
necktie /ネクタイ/
necktiepin /ネクタイピン;和製英語(tiepin)/
necro /ネクロ/
necromancer /ネクロマンサー/
necrophilia /ネクロフィリア/
necropolis /ネクロポリス/
necrosis /ネクローシス/
nectar /ネクター/ネクタル/
nectarine /ネクタリン/
nector /ネクター/
ned /ネッド/
nederland /ネーデルラント/
need /ニード/
needle /ニードル/
needs /ニーズ/
neel /ニール/
neenah /ニーナ/
neeson /ニーソン/
neet /ニート;Not in Education, Employment or Training/
neg /¬/
nega /ネガ;negative/
negafilm /ネガフィルム;negative film/
negativa /ネガティブ/ネガティヴ/
negative /ネガティブ/ネガティヴ/
neglect /ネグレクト/
neglige /ネグリジェ/
negligee /ネグリジェ;英語綴り/
nego /ネゴ;negotiation/
negotiate /ネゴシエート/
negotiation /ネゴシエーション/
negotiator /ネゴシエーター/
negri /ネグリ/
negrito /ネグリト/
negro /ニグロ/ネグロ/
negroid /ネグロイド/
nehemiah /ネヘミヤ/
nehru /ネルー/
neige /ネージュ;(Fr)雪/
neighbor /ネイバー/
neil /ニール/
neill /ニール/
nein /ナイン;(独語)/
nejd /ネジド/
nektar /ネクタル/
nel /ネル/
nell /ネル/
nella /ネッラ/
nelldrip /ネルドリップ/
nelli /ネッリ/ネリー/ネリ/
nellie /ネリー/
nello /ネロ/
nelly /ネリー/
nelson /ネルソン/
nemacs /ＮＥｍａｃｓ/Ｎｅｍａｃｓ/ｎｅｍａｃｓ/NEmacs/
nematic /ネマティック/
nemesis /ネメシス/
nemo /ネモ/
nemophila /ネモフィラ/
neo /ネオ/
neoclassic /ネオクラシック/
neocon /ネオコン;<neo-conservative/
neodymium /ネオジム;[元素]60,Nd/ネオジミウム/
neogeo /ネオジオ;[商標]SNK/
neoliberalism /ネオリベラリズム/
neon /ネオン/
neonazi /ネオナチ/
neonsign /ネオンサイン/
neontetra /ネオンテトラ/
neoprene /ネオプレン;=chloroplene gum/
neoteny /ネオテニー/
nepal /ネパール;.np/
nepenthes /ネペンテス;ウツボカズラ/
nephrite /ネフライト/
nephrose /ネフローゼ/
nephrosis /ネフローゼ/
nephthys /ネフティス/
nepoch /NEpoch/
neptune /ネプチューン/
neptunium /ネプツニウム;[元素]93,Np/
neq /≠/
nereid /ネレイド/
nereides /ネレイデス/
nereis /ネレイス/
nereus /ネレウス/
nergal /ネルガル/
neri /ネリ/
nero /ネロ/
nerval /ネルヴァル;(1808-55) Gerard de Nerval/
nervous /ナーバス/
nescafe /ネスカフェ;[商標]Neslet/
ness /ネス/
nessie /ネッシー/
nest /ネスト/
nesta /ネスタ/
nesting /ネスティング/
nestle /ネスレ/ネッスル/
nestor /ネストール/ネスター/ネストル/
net /ネット/ネットワーク/
netauction /ネットオークション/
netbank /ネットバンク/
netbanking /ネットバンキング/
netbiz /ネットビジネス/
netbusiness /ネットビジネス/
netcafe /ネットカフェ/
netdatabase /ネットデータベース/
netgame /ネットゲーム/
nethack /ネットハック/
netherland /ネーデルランド/ネーデルラント/ネザーランド/
netherlands /オランダ;.nl/
netidol /ネットアイドル/
netin /ネットイン;和製英語/
netiquette /ネチケット;network etiquette/
netizen /ネチズン/
netlist /ネットリスト/
netmanner /ネットマナー;和製英語(netiquette)/
netmask /ネットマスク/
netnews /ネットニュース/
netone /ネットワン/
netplay /ネットプレイ/ネットプレー/
netradio /ネットラジオ/
netscape /ネットスケープ/
netshop /ネットショップ/
netshopping /ネットショッピング/
netstore /ネットストア/
netsurfing /ネットサーフィン/
netta /ネッタ/
nettalk /ＮＥＴｔａｌｋ/
nettopology /ネット・トポロジー/
nettv /ネットテレビ/
netware /ネットウェア/NetWare/
network /ネットワーク/アメリカネットワーク;net,.net/
networkaddress /ネットワークアドレス/
networkadmin /ネットワークアドミン/
networkcable /ネットワークケーブル/
networkcard /ネットワークカード/
networkcomputer /ネットワークコンピュータ/
networker /ネットワーカー/
networking /ネットワーキング/
networks /ネットワークス/
networksystem /ネットワークシステム/
neue /ノイエ;(独)/
neuf /ヌフ;(Fr) 新しい/
neumann /ノイマン/ノイマン型/
neural /ニューラル/Ｎｅｕｒａｌ/
neuralnet /ニューラルネット/ＮｅｕｒａｌＮｅｔ/
neuralnetwork /ニューラルネットワーク/
neuralware /ＮｅｕｒａｌＷａｒｅ/
neuro /ニューロ/
neurocomputer /ニューロコンピュータ/
neurocomputing /ニューロコンピューティング/
neuroethology /ニューロエソロジー/
neuromancer /ニューロマンサー/
neuron /ニューロン/
neuroscience /ニューロサイエンス/
neurose /ノイローゼ;(独語)/
neutral /ニュートラル/
neutrino /ニュートリノ/
neuve /ヌーヴ;(Fr) <neuf/
neva /ネヴァ/ネバ/
nevada /ネバダ;NV/
never /ネバー/ネヴァー/
nevergiveup /ネバーギブアップ/ネヴァーギブアップ/
neverland /ネバーランド/ネヴァーランド/
nevermind /ネバーマインド/ネバーマイン/
neville /ネビル/
new /ニュー/
newage /ニューエイジ/ニューエージ/
newalbum /ニューアルバム/
newark /ニューアーク;ニュージャージー(USA)/
newcaledonia /ニューカレドニア;New Caledonia/
newcastle /ニューカッスル/ニューキャッスル/ニューキャッスル大学/
newcomer /ニューカマー/
newdelhi /ニューデリー;New Delhi/
neweconomy /ニューエコノミー/
newell /ニューウェル/
newengland /ニューイングランド;New England, Australia/
newface /ニューフェイス/ニューフェース/
newfoundland /ニューファンドランド/
newfrontier /ニューフロンティア/
newguinea /ニューギニア;New Guinea/
newhalf /ニューハーフ;和製英語/
newhampshire /ニューハンプシャー;NH/
newjersey /ニュージャージー;NJ/Ｎｅｗ−Ｊｅｒｓｅｙ/
newman /ニューマン/
newmedia /ニューメディア/
newmexico /ニューメキシコ;NM/ニューメキシコ州立大学/
newmodel /ニューモデル/
newmusic /ニューミュージック/
newohtani /ニューオータニ/
neworleans /ニューオリンズ/ニューオーリンズ/
newrelease /ニューリリース/
news /ニュース/ニューズ/ＮｅＷＳ/
newscaster /ニュースキャスター/
newsfeed /ニュースフィード/
newsflash /ニュースフラッシュ/
newsgroup /ニュースグループ/
newsletter /ニュースレター/ニューズレター/
newsouthwales /ニューサウスウェールズ/
newspaper /ニュースペーパー/
newsreader /ニュースリーダー/
newsrelease /ニュースリリース/
newsserver /ニュースサーバ/ニュースサーバー/
newssite /ニュースサイト/
newssource /ニュースソース/
newsspool /ニューススプール/
newsstation /ニュースステーション;番組名/
newssystem /ニュースシステム/
newsweek /ニューズウィーク;www.newsweek.com/
newt /ニュート;イモリ/
newtech /ニューテック/
newton /ニュートン/
newtown /ニュータウン/
newtype /ニュータイプ/
newversion /ニューバージョン/
newwave /ニューウェーブ/ニューウェーヴ/
newworld /ニューワールド/
newyear /ニューイヤー/
newyork /ニューヨーク/紐育/
newyorkcity /ニューヨークシティ/
newyorker /ニューヨーカー;New Yorker/
newyorktimes /ニューヨークタイムズ;New York Times. www.nytimes.com/ニューヨーク・タイムズ/
newzealand /ニュージーランド;(.nz) New Zealand/
next /ネクスト/ＮｅＸＴ/NeXT/
nexus /ネクサス/
ng /ニュースグループ/
ngram /N-gram/
ngword /NGワード/
nh /New Hampshire/ニューハンプシャー/
nhkhall /NHKホール/
nhkradio /NHKラジオ/
ni /∋/ニッケル/Nickel/
niacin /ナイアシン/
niagara /ナイアガラ/
niamey /ニアメ/
nias /ナイアス/
nib /ニブ/
nibble /ニブル/
nibelung /ニーベルング/
nic /The Network Information Center/
nicad /ニッカド;nickel-cadmium/
nicaragua /ニカラグア;.ni/
nicd /NiCd/ニッカド;nickel-cadmium/
nice /ナイス/ニース/
nicebody /ナイスバディ/ナイスボディ/
nicecatch /ナイスキャッチ/
niceguy /ナイスガイ/
nicemiddle /ナイスミドル/
niceshot /ナイスショット/
niche /ニッチ/
nicholas /ニコラス/
nicholls /ニコルズ/ニコルス/
nichols /ニコルズ/ニコルス/
nicholson /ニコルソン/
nichrome /ニクロム/
nick /ニック/
nickel /ニッケル/
nicklaus /ニクラウス/
nickname /ニックネーム/
nicky /ニッキー/
nico /ニコ/
nicol /ニコル/
nicola /ニコラ/
nicolai /ニコライ/
nicolas /ニコラス/ニコラ;仏語/
nicolaus /ニコラウス/
nicole /ニコル/ニコール/
nicolet /ニコレ/
nicoletta /ニコレッタ/
nicolette /ニコレット/
nicollet /ニコレ/
nicolo /ニコロ/
nicorette /ニコレット;[商標]/
nicos /ニコス;www.nicos.co.jp/
nicosia /ニコシア/
nicotine /ニコチン/
niedersachsen /ニーダーザクセン/
niels /ニールス/
nielsen /ニールセン/
nietzsche /ニーチェ/
nif /Ｎｉｆｔｙ/
nifty /ニフティ/Ｎｉｆｔｙ/ＮＩＦＴＹ/
niftyserve /ニフティサーブ/
nigel /ナイジェル/
niger /ニジェール;.ne/
nigeria /ナイジェリア;.ng/
nigger /ニガー/
night /ナイト/
nightcap /ナイトキャップ/
nightcare /ナイトケア/
nightclub /ナイトクラブ/
nightcream /ナイトクリーム/
nighter /ナイター/
nightgame /ナイトゲーム/
nightgown /ナイトガウン/
nightingale /ナイチンゲール/
nightlife /ナイトライフ/
nightly /ナイトリー/
nightmare /ナイトメア/ナイトメアー/
nights /ナイツ/
nightspot /ナイトスポット/
nighttable /ナイトテーブル/
nighttime /ナイトタイム/
nighty /ナイティ/ナイティー/
nihil /ニヒル/
nihilism /ニヒリズム/
nihilist /ニヒリスト/
nihon /ニホン/
nihontv /日本テレビ;www.ntv.co.jp/
nijinsky /ニジンスキー/
nike /ナイキ/ニケ/
niki /ニキ/
nikita /ニキータ/
nikka /ニッカ/
nikki /ニキ/ニッキー/
niklas /ニクラス/
niko /ニコ/
nikola /ニコラ/
nikolai /ニコライ/
nikolaus /ニコラウス/
nikolay /ニコライ/
nikoli /ニコリ/
nikon /ニコン;www.nikon.co.jp/
nikos /ニコス/
niku /ニク/
nil /ニル/空リスト/ニール/
nile /ナイル/
nilgiri /ニルギリ;紅茶/
nils /ニルス/
nilson /ニルソン/
nilsson /ニルソン/
nim /ニム/
nimes /ニーム/
nin /ニン/
nina /ニーナ/ニナ/
ninaricci /ニナリッチ;www.ninaricci.fr/ニナ・リッチ/
nine /ナイン/
nineball /ナインボール/
nineteen /ナインティーン/
nineth /ナインス;※ninth/
ninety /ナインティ/
nino /ニーノ/
nintendo /ニンテンドー/
nintendods /ニンテンドーDS;[商標]/
ninth /ナインス/
niob /ニオブ;Nb/
niobe /ニオベ/
niobium /ニオブ;[元素]41,Nb(Cb)/
nip /ニップ/
nipper /ニッパー/
nipple /ニップル/
nippon /ニッポン/
nipponia /ニッポニア/
nir /ニール/
nirvana /ニルヴァーナ/ニルバーナ/
nissan /ニッサン/
nite /ナイト;=night/
nitrile /ニトリル/
nitro /ニトロ/
nitrobenzene /ニトロベンゼン/
nitrocellulose /ニトロセルロース/
nitrogen /ナイトロジェン;N/
nitroglycerine /ニトログリセリン/
nitrosamine /ニトロソアミン/
niue /ニウエ;.nu/
niven /ニーヴン/
nix /ニックス/
nixon /ニクソン/
nizhinskii /ニジンスキー/
nj /New Jersey/ニュージャージー/
nji /n次/
njigen /ｎ次元/
nko /ｎ個/
nm /ナノメートル;nanometre/New Mexico/ニューメキシコ/
no /ノー/Ｎｏ．/ＮＯ/No./ナンバー/番号/ノーベリウム/Nobelium/
no# /ナンバー#0/ナンバー#1/
no.# /ナンバー#0/ナンバー#1/
no1 /Ｎｏ．１/
noaa /ノア/
noah /ノア/
noam /ノーム/
nob /ノブ/
nobel /ノーベル/
nobelium /ノーベリウム;[元素]102,No/
noble /ノーブル/
noblesseoblige /ノブレスオブリッジ/
nobody /ノーバディ/ノーボディ/
nobound /ノーバウンド/
nobra /ノーブラ;braless/
nobrand /ノーブランド/
nocheck /ノーチェック;unchecked/
nocomment /ノーコメント/
nocount /ノーカウント/
nocturne /ノクターン/夜想曲/
nocut /ノーカット;和製英語(uncut)/
node /ノード/節点/
noel /ノエル;(Fr)クリスマス/Ｎｏёｌ/
noelle /ノエル/
nogame /ノーゲーム/
nogoal /ノーゴール/
noguard /ノーガード/
nohit /ノーヒット/
nohitnorun /ノーヒットノーラン;no-hitter/
noir /ノワール;(Fr)黒/ノアール/
noire /ノワール;(Fr)黒/ノアール/
noiret /ノワレ/
noise /ノイズ/
noiselevel /ノイズレベル/
noisereduction /ノイズリダクション/
noisette /ノワゼット/ノアゼット/
noisiness /ノイジネス/
noisy /ノイジー/ノイズィ/
nokia /ノキア;www.nokia.com/
nolan /ノーラン/
noloan /ノーローン;和製英語/
nomad /ノマド/
nomade /ノマド/
nomadic /ノマディック/
nomake /ノーメイク;和製英語/
nomark /ノーマーク;和製英語(unmarked)/
nomat /ノーマット;和製英語/
nombre /ノンブル/
nominal /ノミナル/
nominate /ノミネート/
nomore /ノーモア/
nomos /ノモス/
non /ノン/
nona /ノナ;9/ノーナ/
nonadult /ノンアダルト/
nonalcohol /ノンアルコール;nonalcoholic/
nonbank /ノンバンク/
noncalorie /ノンカロリー;和製英語(noncaloric)/
noncareer /ノンキャリア/
nonchalant /ノンシャラン/
nonecktie /ノーネクタイ;和製英語(tieless)/
nonet /ノネット/
nonfiction /ノンフィクション/
nonframe /ノンフレーム/
nongenre /ノンジャンル/
nonie /ノーニ/
nonlinear /ノンリニア/
nonmaskable /ノンマスカブル/
nonno /ノンノ;(アイヌ語)花/
nonoil /ノンオイル/
nonpro /ノンプロ;non-professional/
nonsection /ノンセクション/
nonsense /ナンセンス/ナンセンス！/
nonstop /ノンストップ/
nonsugar /ノンシュガー;sugar-free/
nonverbal /ノンバーバル/
noodle /ヌードル/
noon /ヌーン/
noout /ノーアウト/
nopan /ノーパン;pantyless/
noproblem /ノープロブレム/
nor /ノア/not or/ノル;(接頭辞)正-/
nora /ノラ/ノーラ/
noradrenalin /ノルアドレナリン/
noradrenaline /ノルアドレナリン/
norah /ノラ/ノーラ/
norbert /ノルベルト/ノーバート/
nordic /ノルディック/
nordicski /ノルディックスキー/
nordrheinwestfalen /ノルトラインヴェストファーレン/
noreturn /ノーリターン/
norfolk /ノーフォーク;.nf/
noriega /ノリエガ/
norisk /ノーリスク/
norm /ノルム/
norma /ノルマ/ノーマ/
normal /ノーマル/ノルマル;(独語)/正常/
normalhill /ノーマルヒル/
normalisation /ノーマライゼーション/
normalise /ノーマライズ/
normalization /ノーマライゼーション/
normalize /ノーマライズ/
normalmode /ノーマルモード/
norman /ノーマン/ノルマン/
normand /ノルマン/
normandie /ノルマンディー/ノルマンディ/
norn /ノルン/
norris /ノリス/
north /ノース/
northcarolina /ノースカロライナ;NC/
northdakota /ノースダコタ;ND/
northeast /ノースイースト/
northern /ノーザン/
northpole /ノースポール;north pole/
northrop /ノースロップ/
northwest /ノースウエスト/ノースウェスト/
northwestern /ノースウェスタン/
northwesternuniv /ノースウェスタン大学/
norton /ノートン/
norun /ノーラン/
norway /ノルウェー;.no/ノルウェイ/諾威/
nose /ノーズ/
nosferatu /ノスフェラトゥ/
noside /ノーサイド/
nosleeve /ノースリーブ/ノースリーヴ/
nostalgia /ノスタルジー/ノスタルジア/
nostalgic /ノスタルジック/
nostradamus /ノストラダムス/
not /ノット/¬/〜/
notation /ノーテーション/ノウテイション/
notch /ノッチ/
notchfilter /ノッチフィルタ/
note /ノート/
notebook /ノートブック/
notepad /ノートパッド/
notepasocom /ノートパソコン;notebook computer/
notepc /ノートPC/ノートパソコン/
noteq /≠/
notequal /≠/
notes /ノーツ/
nothing /ナッシング/
notice /ノーティス/
notify /ノーティファイ/
notime /ノータイム/
notouch /ノータッチ/
notre /ノートル;仏語/
notredame /ノートルダム/
nottingham /ノッティンガム/
notus /ノトス;南風/ノータス/
nouakchott /ヌアクショット/
nougat /ヌガー/
noumea /ヌメア/ヌーメア/
nouveau /ヌーヴォー/ヌーボー/
nouvelle /ヌーベル/ヌーヴェル/
nouvellevague /ヌーベルバーグ;nouvelle vague/ヌーヴェルヴァーグ/
nova /ノバ/ノヴァ/ノーヴァ/
novalis /ノヴァーリス/
novel /ノベル/ノヴェル/
novelgame /ノベルゲーム/
novelisation /ノベライゼーション/
novelise /ノベライズ/
novelization /ノベライゼーション/
novelize /ノベライズ/
novels /ノベルズ/ノベルス/
novelty /ノベルティ/ノベルティー/
noveltygoods /ノベルティグッズ/ノベルティーグッズ/
november /ノベンバー/
novice /ノービス/
novo /ノボ/
novosibirsk /ノボシビルスク/ノヴォシビルスク/
now /ナウ/
nowait /ノーウェイト/ノーウエイト/
nox /ノックス/窒素酸化物/
nozzle /ノズル/
np /ネプツニウム/Neptunium/
nqueen /Ｎクィーン/
nroff /エヌロフ/
nrzi /NRZI/
ns /│;罫線/┃;太い罫線/
nse /├/┣;太/┠;縦太/┝;横太/
nsew /┼/╋;太/┿;横太/╂;縦太/
nsw /┤/┫;太/┨;縦太/┥;横太/
nten /Ｎ点/
ntt /NTT/
nttdocomo /NTTドコモ;www.nttdocomo.co.jp/
ntv /日本テレビ/
nu /ν/ニュー/
nuance /ニュアンス/
nubia /ヌビア/
nuclear /ニュークリア/
nucleoside /ヌクレオシド/
nucleotide /ヌクレオチド;NB:nucleosideのリン酸エステル/
nude /ヌード/
nudemodel /ヌードモデル/
nudist /ヌーディスト/
nugget /ナゲット/
nukualofa /ヌクアロファ/
null /ヌル/ナル/NULL/
nullpointer /ヌルポインタ/
number /ナンバー/ナンバ/番号/＃/
numberdisplay /ナンバーディスプレイ/
numbering /ナンバリング/
numberone /ナンバーワン/
numberplate /ナンバープレート/
numbers /ナンバーズ/
numbertwo /ナンバーツー/
numeric /ニューメリック/
numerics /ニューメリックス/
nunez /ヌニェス/
nurnberg /ニュルンベルク/
nurse /ナース/
nursecall /ナースコール/
nursery /ナーサリー/
nursestation /ナースステーション/
nursing /ナーシング/
nut /ナット/
nutmeg /ナツメグ/
nutria /ヌートリア/
nutrition /ニュートリション/
nuts /ナッツ/
nuwaraeliya /ヌワラエリヤ;Nuwara Eliya,紅茶/
nv /Nevada/ネバダ/
nw /┘;罫線/┛;太い罫線/
ny /New York/ニューヨーク/Ｎ.Ｙ./
nydow /NYダウ/
nylon /ナイロン/
nymph /ニンフ/
nymphet /ニンフェット/
nymphomania /ニンフォマニア/
nyquist /ナイキスト/
nytimes /ニューヨークタイムズ;www.nytimes.com/ニューヨーク・タイムズ/
nyu /ν/
nyx /ニクス/ニュクス/
nz /ニュージーランド/
o /ο;omicron/○;記号のマル/о;cyrillic/オー/酸素/Oxygen/ω;※(oo) omega/
oacleaner /OAクリーナー/
oahu /オアフ/
oak /オーク/
oakland /オークランド;USA/
oakley /オークリー/オークレー/
oakridge /オークリッジ/
oaks /オークス/
oar /オール/
oasis /オアシス/
oat /オート/オート麦/
oatmeal /オートミール/
oats /オーツ/
oaxaca /オアハカ/
ob /オビ/
obadiah /オバデヤ/
obbligato /オブリガート/
obelisk /オベリスク/
oberon /オベロン/
obi /オビ/
obj /オブジェクト;object/
object /オブジェクト/
objectcode /オブジェクトコード/
objectoriented /オブジェクトオリエンテッド/
objectshikou /オブジェクト指向/
objet /オブジェ/
oblaat /オブラート;(蘭語)/
oblate /オブラート;(独語)/
oboe /オーボエ/
observation /オブザベーション/
observer /オブザーバー/オブザーバ/
obsession /オブセッション/
obsidian /オブシディアン/
obstruction /オブストラクション/
oc /∝;proportion/
ocalina /オカリナ;※ocarina/
ocarina /オカリナ/
occam /オッカム/
occlusion /オクルージョン/
occult /オカルト/
occupation /オキュペーション/職業/
occurrence /オカレンス/
ocean /オーシャン/
oceanblue /オーシャンブルー/
oceania /オセアニア/
oceanus /オケアノス/
ocelot /オセロット/
ochoa /オチョア/
ochs /オークス/オクス/
ocicat /オシキャット/
ockham /オッカム/
oconnor /オコナー;O'Conner/
ocrsoft /OCRソフト/
octa /オクタ;8/
octagon /オクタゴン;八角形/
octan /オクタン/
octane /オクタン;C8H18/
octave /オクターブ/オクターヴ/
octavia /オクタヴィア/オクタビア/
octavio /オクタビオ/
octet /オクテット/
octo /オクト;8/
october /オクトーバー/
octopus /オクトパス/
odalisk /オダリスク/
odalisque /オダリスク/
oday /オデイ;O'Day/
odd /オッド/
odds /オッズ/
ode /オード/
odense /オーデンセ/
odeon /オデオン/
odessa /オデッサ/
odette /オデット/
odin /オーディン/
odometer /オドメーター/
odysseia /オデュッセイア/
odysseus /オデュッセウス/
odyssey /オデッセイ/オデュッセイア/
oedipus /オイディプス/
of /オブ/オヴ/
off /オフ/
offbeat /オフビート/
offcom /オフコン;office computer/
offenbach /オッフェンバック/
offence /オフェンス/
offense /オフェンス/
offer /オファー/
office /オフィス/
office-computer /オフコン/
officecomputer /オフィスコンピュータ/オフコン/
officehour /オフィスアワー/
officelady /オフィスレディ/
officelove /オフィスラブ/
officer /オフィサー/
officesoft /オフィスソフト/
officesuite /オフィススイート/
officework /オフィスワーク/
officeworker /オフィスワーカー/
official /オフィシャル/
officialhomepage /オフィシャルホームページ/
officialhp /オフィシャルホームページ/
officialpage /オフィシャルページ/
officialsite /オフィシャルサイト/
offline /オフライン/
offpeak /オフピーク/
offrec /オフレコ/
offreco /オフレコ/
offroad /オフロード/
offroader /オフローダー/
offscreen /オフスクリーン/
offseason /オフシーズン/
offset /オフセット/
offshore /オフショア/
offshot /オフショット/
offshoulder /オフショルダー/
offside /オフサイド/
offsidetrap /オフサイドトラップ/
offsite /オフサイト/
offspring /オフスプリング/
offtime /オフタイム/
offtopic /オフトピック;off-topic/
offwhite /オフホワイト/
ogata /Ｏ型/
ogier /オジェ/
ogre /オーガ/オウガ/
oh /オー/Ohio/オハイオ/
ohara /オハラ;O'Hara/
ohhisse /オーエス;(Fr) oh hisse/
ohio /オハイオ;OH/
ohm /オーム/Ω/
oidipous /オイディプス/
oidipus /オイディプス/
oil /オイル/
oilfence /オイルフェンス/
oilheater /オイルヒーター/
oillighter /オイルライター;oil lighter/
oilmassage /オイルマッサージ/
oilmoney /オイルマネー/
oilpot /オイルポット/
oilsand /オイルサンド/
oilsardine /オイルサーディン/
oilskin /オイルスキン/
oily /オイリー/
ok /オッケー/オーケー/オーケイ/オッケイ/Ｏ.Ｋ./Oklahoma/オクラホマ/承知しました./大丈夫/
okapi /オカピ/
okeanos /オケアノス/
okhotsk /オホーツク/
oklahoma /オクラホマ;OK/
okra /オクラ/
olaf /オラフ/
olanda /オランダ/和蘭/
old /オールド/
oldenburg /オルデンブルグ/
oldfashion /オールドファッション/
oldies /オールディーズ/
oldmiss /オールドミス;和製英語(old maid)/
oldtype /オールドタイプ/
ole /オーレ/
oleg /オレグ/
oleo /オレオ/
olga /オルガ/オリガ/
oligo /オリゴ/
oligomer /オリゴマー/
olin /オーリン/
olive /オリーブ/オリーヴ/
olivegreen /オリーブグリーン/
oliveoil /オリーブオイル/
oliver /オリバー/オリヴァー/
olivia /オリビア/オリヴィア/
olivier /オリヴィエ/オリビエ/
olmeca /オルメカ/
ologun /オロゴン/
olympas /オリンパス/
olympia /オリンピア/
olympiad /オリンピアード/オリンピック;?/
olympic /オリンピック/
olympos /オリンポス/オリュンポス/
olympus /オリンパス/オリュンポス/
om /オウム/オーム/
omaha /オマハ/
omalley /オマリー;O'Malley/
oman /オマーン;.om/
ombra /オンブラ/
ombudsman /オンブズマン/
omega /ω/オメガ/
omelet /オムレツ/
omelette /オムレツ/オムレット/
omen /オーメン/
omicron /ο/オミクロン/
omit /オミット/
omni /オムニ/
omnibus /オムニバス/
omnis /オムニス/
omrice /オムライス;日本料理(omelette-rice)/
omron /オムロン;[企業名]www.omron.co.jp/立石電機;[企業名]/OMRON;[企業名]/
on /オン/
onahole /オナホール/
onair /オンエア/オンエアー/
onan /オナン/
onanie /オナニー/
onanist /オナニスト/
onapet /オナペット/
onbeat /オンビート/
onboard /オンボード/
once /ワンス/
oncemore /ワンスモア;once more/
onchip /オンチップ/
oncidium /オンシジウム/
ondemand /オンデマンド/
ondine /オンディーヌ;=undine/
one /ワン/
one-to-one /一対一/
onebound /ワンバウンド;和製英語(one-hopper)/
onebox /ワンボックス/
oneboxcar /ワンボックスカー/
onechip /ワンチップ/
oneclick /ワンクリック/
onecoin /ワンコイン/
onecup /ワンカップ;[商標]大関 (言い換え語:カップ酒)/
onecushion /ワンクッション;和製英語。「-置く」/
onedrink /ワンドリンク/
oneill /オニール;O'Neill/
onekey /ワンキー/
oneman /ワンマン/
onemanlive /ワンマンライブ/
onemanshow /ワンマンショー;one-man show/
onemore /ワンモア;one more/
onenight /ワンナイト/
oneout /ワンアウト/ワンナウト/
onepattern /ワンパターン/
onephrase /ワンフレーズ/
onepi /ワンピ;one-piece/
onepiece /ワンピース/ワンピ/
onepoint /ワンポイント/
onepointadvice /ワンポイントアドバイス/
onepush /ワンプッシュ/
onerank /ワンランク/
oneroom /ワンルーム/
oneroommansion /ワンルームマンション/
onescene /ワンシーン;one scene/
oneset /ワンセット/
oneshot /ワンショット/
oneshoulder /ワンショルダー/
oneside /ワンサイド/
onesidegame /ワンサイドゲーム/
onesize /ワンサイズ/
onestep /ワンステップ/
onestop /ワンストップ/
onetempo /ワンテンポ;和製語/
onetime /ワンタイム/
onetop /ワントップ/
onetouch /ワンタッチ/
onetwo /ワンツー/
oneway /ワンウェイ/ワンウェー/
onion /オニオン/
onionslice /オニオンスライス/
online /オンライン/
onlineauction /オンラインオークション/
onlinebanking /オンラインバンキング/
onlinecasino /オンラインカジノ/
onlinegame /オンラインゲーム/
onlinehelp /オンラインヘルプ/
onlinemagazine /オンラインマガジン/
onlinemanual /オンラインマニュアル/
onlineservice /オンラインサービス/
onlineshop /オンラインショップ/
onlineshopping /オンラインショッピング/
onlinesignup /オンラインサインアップ/
onlinesoft /オンラインソフト/
onlinestore /オンラインストア/
onlinesystem /オンラインシステム/
onlinetrade /オンライントレード/
only /オンリー/
onlyone /オンリーワン/
onoff /オン・オフ/オンオフ/
onomatopee /オノマトペ;仏語/
onomatopoeia /オノマトペ/
onon /オノン/
onparade /オンパレード;on parade/
onpu /♪/
onroad /オンロード/
onscreen /オンスクリーン/
onseason /オンシーズン;和製英語/
onsite /オンサイト/
onstage /オンステージ/
ontario /オンタリオ/
ontek /オンテック/
onthefly /オンザフライ;on-the-fly/
ontherock /オンザロック;on the rocks/
ontherocks /オンザロック;on the rocks/
ontime /オンタイム/
ontologie /オントロギー;存在論/オントロジー;仏語/
ontology /オントロジー;存在論/
onward /オンワード/
onyx /オニキス/
oo /∞;infinity/ω;omega/○○;まるまる/Object-Oriented/オブジェクト指向/
oodb /オブジェクト指向データベース/
oodl /OODL/
oolong /ウーロン/烏龍/
oolongtea /ウーロン茶/
oop /オブジェクト指向プログラミング/
ooparts /オーパーツ;out of place artifacts/
oopl /OOPL/
ooze /ウーズ/
opal /オパール/蛋白石/
ope /オペ;operation/
opecode /オペコード/
opel /オペル;www.opel.com/
open /オープン/開/
openair /オープンエア/
opencafe /オープンカフェ;和製語/
opencampus /オープンキャンパス/
opencar /オープンカー/
openend /オープンエンド/
opener /オープナー/
opengolf /オープンゴルフ/
openheart /オープンハート/
openhouse /オープンハウス/
opening /オープニング/
openingtheme /オープニングテーマ/
openjaw /オープンジョー/
openkitchen /オープンキッチン/
openlab /オープンラボ;openlab.jp/
openlook /ＯｐｅｎＬｏｏｋ/
openoffice /オープンオフィス;www.openoffice.org/
openprice /オープンプライス/オープン価格/
openreel /オープンリール/
openschool /オープンスクール/
opensource /オープンソース/
openspace /オープンスペース/
opensystem /オープンシステム/
openwindow /OpenWindow/
openwindows /ＯｐｅｎＷｉｎｄｏｗｓ/
opera /オペラ/歌劇/
operability /オペラビリティ/
operacity /オペラシティ;www.operacity.jp/
operaglass /オペラグラス;opera glasses/
operaglasses /オペラグラス/
operahouse /オペラハウス/
operand /オペランド/
operant /オペラント/
operate /オペレート/
operating /オペレーティング/
operatingsystem /オペレーティングシステム/
operation /オペレーション/操作/
operational /オペレーショナル/
operations /オペレーションズ/
operationsresearch /オペレーションズリサーチ;OR/オペレーションズ・リサーチ/オペレーションズ リサーチ/
operationsreserch /オペレーションズリサーチ;OR/
operator /オペレーター/オペレータ/演算子/
operetta /オペレッタ/
operon /オペロン/
ophelia /オフィーリア/オフェーリア/
opinion /オピニオン/
opinionleader /オピニオンリーダー/
opioid /オピオイド/
opium /オピウム/
oppenheimer /オッペンハイマー/
opportunity /オポチュニティ/オポチュニティー/
opt /オプト/
optical /オプティカル/
opticalflow /オプティカルフロー/
opticalmouse /オプティカルマウス/
optima /オプティマ/
optimal /オプティマル/
optimism /オプティミズム/
optimist /オプティミスト/
optimize /オプティマイズ/最適化/
optimizer /オプティマイザ/
optimum /オプティマム/
optin /オプトイン;opt-in/
option /オプション/
optional /オプショナル/
optionbutton /オプション・ボタン/
optionmenu /オプションメニュー/
options /オプションズ/
opto /オプト/
optout /オプトアウト;opt-out/
opus /オーパス/オプス/
or /オア/∨/∪/または/Oregon/オレゴン/
oracle /オラクル/
oral /オーラル/
oralsex /オーラルセックス/
orange /オレンジ/
orangecuracao /オレンジキュラソー/
orangejuice /オレンジジュース/
orangepeel /オレンジピール/
orangepekoe /オレンジペコ/オレンジペコー/
orangutan /オランウータン/
oratorio /オラトリオ/聖譚曲/
orb /オーブ/
orbis /オービス;ねずみとり/
orbit /オービット/
orbital /オービタル/
orbiter /オービター/
orc /オーク/
orca /オルカ/
orch /オケ;orchestra/
orchard /オーチャード/
orchardhall /オーチャードホール/
orche /オケ/
orchestra /オーケストラ/
orchestrapit /オーケストラピット/
orchestration /オーケストレーション/
orchid /オーキッド/
order /オーダー/オーダ/
ordermade /オーダーメイド/オーダーメード/
ordersheet /オーダーシート/
orderstop /オーダーストップ/
ordinary /オーディナリー/
ordos /オルドス/
oread /オレアード/
oregano /オレガノ/
oregon /オレゴン/
oreilly /オライリー;O'Reilly. www.oreilly.com/
oreillyjapan /オライリージャパン;[出版社名]www.oreilly.co.jp/O'Reilly Japan/
oreo /オレオ/
orestes /オレステス/
org /オルグ/
orga /オルガ/
organ /オルガン/オーガン/
organdie /オーガンジー/
organelle /オルガネラ/
organic /オーガニック/
organisation /オーガニゼーション/
organise /オーガナイズ/
organiser /オーガナイザー/
organism /オルガニズム/
organist /オルガニスト/
organization /オーガニゼーション/
organize /オーガナイズ/
organizer /オーガナイザー/オーガナイザ/
orgasm /オーガズム/オルガズム/オルガスム/
orgasme /オルガスム;仏語/オーガスム/
orgasmus /オルガスムス/
orgel /オルゴール;(蘭語)/
orgy /オージー/
orico /オリコ;www.orico.co.jp/
oricon /オリコン;www.oricon.co.jp/
orient /オリエント/
oriental /オリエンタル/
orientalism /オリエンタリズム/
orientation /オリエンテーション/オリエンテイション/
oriented /オリエンテッド/
orienteering /オリエンテーリング/
orifice /オリフィス/
origin /オリジン/
original /オリジナル/
originalalbum /オリジナルアルバム/
originalbrand /オリジナルブランド/
originalgoods /オリジナルグッズ/
originality /オリジナリティ/オリジナリティー/
originalprint /オリジナルプリント/
originalversion /オリジナルバージョン/
origo /オリゴ/
oring /Oリング;O-ring/Ｏリング/
orinoco /オリノコ/
oriol /オリオール/
orioles /オリオールズ;[MLB]/
orion /オリオン/
orix /オリックス/
orlando /オーランド/オルランド/
orleans /オルレアン/
orly /オルリー;フランス(ory)/
ornament /オーナメント/
ornella /オルネラ/
ornette /オーネット/
orourke /オルーク;O'Rourke/
orphan /オーファン/
orphee /オルフェ/
orpheus /オルフェウス/
orquesta /オルケスタ;(西語)/
orsay /オルセー/
orso /オルソ/
orson /オーソン/オルソン/
ortega /オルテガ/
ortho /オルト/オルソ/オーソ/
orthodox /オーソドックス/
ortiz /オルティス/
orvieto /オルヴィエート/
orwell /オーウェル/
oryza /オリザ;稲/
os /オペレーティングシステム/オペレーティング・システム/オスミウム/Osmian/基本ソフトウェア/OS/オペレイティング・システム;<rare>/
os9 /ＯＳ９/
osama /オサマ/
osborn /オズボーン/
osborne /オズボーン/
oscar /オスカー/オスカル/
oscillator /オシレーター/オシレータ/
oscillo /オシロ/
oscilloscope /オシロスコープ/
osciloscope /オシロスコープ;※oscilloscope/
osf /OSF/
osiris /オシリス/
oskar /オスカル/
oslo /オスロ/
osman /オスマン/
osmium /オスミウム;[元素]76,Os/
osmo /オスモ/
ossian /オシアン/
osteria /オステリア/
ostrich /オーストリッチ/オストリッチ/
osullivan /オサリバン;O'Sullivan/オサリヴァン/
oswald /オズワルド/
otacky /オタッキー/
otfried /オトフリート/
othello /オセロ/
other /アザー/その他/
otis /オーティス/
ottawa /オタワ/
otto /オットー/オット/
ottoman /オットマン/
ouch /アウチ/
oui /ウィ;(仏語)/ウィー;(仏語)/
ounce /オンス/
our /アワ/
ouroboros /ウロボロス/
ours /アワーズ/
out /アウト/
outboxing /アウトボクシング/
outbreak /アウトブレイク/
outcourse /アウトコース;和製英語(outside)/
outdoor /アウトドア/
outdoorlife /アウトドアライフ/
outer /アウター/
outerspace /アウタースペース/
outerwear /アウターウェア/
outfit /アウトフィット/
outlane /アウトレーン/
outlaw /アウトロー/
outlet /アウトレット/
outline /アウトライン/
outlinefont /アウトラインフォント/
outlook /アウトルック/
outlow /アウトロー;[野球]和製英語(outside low)/
outof /アウト・オブ・/アウトオブ/
outplacement /アウトプレースメント/
output /アウトプット/出力/
outside /アウトサイド/
outsider /アウトサイダー/
outsource /アウトソース/
outsourcing /アウトソーシング/
oval /オーバル/楕円/
ovation /オベーション/オヴェイション/
oven /オーブン/
ovenrange /オーブンレンジ;和製英語/
oventoaster /オーブントースター;和製英語(toaster oven)/
over /オーバー/オーバ/オーヴァー/
overall /オーバーオール/
overblouse /オーバーブラウス/
overbooking /オーバーブッキング/
overcharge /オーバーチャージ/
overclock /オーバークロック/
overcoat /オーバーコート/
overcomplete /オーバコンプリート/
overdoctor /オーバードクター/
overdrive /オーバードライブ/
overdubbing /オーバーダビング/オーヴァーダビング/
overflow /オーバーフロー/
overhaul /オーバーホール/
overhead /オーバーヘッド/オーバヘッド/
overkill /オーバーキル/
overknee /オーバーニー/
overlap /オーバーラップ/オーバラップ/
overlay /オーバーレイ/オーバレイ/
overline /オーバーライン;~/
overload /オーバーロード/
overloading /オーバーローディング/
overnight /オーバーナイト/
overpar /オーバーパー/
override /オーバーライド/
overrun /オーバーラン/
overseas /オーバーシーズ/
overskirt /オーバースカート/
overspec /オーバースペック/
overstay /オーバーステイ/
overtake /オーバーテイク/
overtime /オーバータイム/
overtop /オーバートップ/
overture /オーバーチュア/
overview /オーバービュー/
overwork /オーバーワーク/
overwrap /オーバーラップ/
overwrite /オーバーライト/オーバライト/
owen /オーウェン/オーエン/オウエン/
own /オウン/
owner /オーナー/オーナ/オウナー/
ownerchef /オーナーシェフ/
ownership /オーナーシップ/
owngoal /オウンゴール/
oxford /オックスフォード/
oxidant /オキシダント/
oxidase /オキシダーゼ/
oxide /オキサイド/オキシド/
oxine /オキシン/
oxo /オキソ/
oxy /オキシ/オキソ/
oxydol /オキシドール/
oxygen /オキシジェン/酸素/
oxygen-destroyer /オキシジェン・デストロイヤー/水中酸素破壊剤/
oxytocin /オキシトシン/
oyster /オイスター/
oystersauce /オイスターソース/
oz /オズ/
ozon /オゾン/
ozone /オゾン/
ozonehole /オゾンホール/
p /π;pi/ピー/п;pe (cyrillic)/リン/燐/Phosphorus/ピアノ;弱く/piano/
pa /プロトアクチニウム/Protactinium/ペンシルバニア/Pennsylvania/ペンシルベニア/
pablo /パブロ/
paca /パカ/
pace /ペース/
pacedown /ペースダウン/
pacemaker /ペースメーカー/ペースメーカ/
paceup /ペースアップ/
pachelbel /パッヘルベル/
pachinker /パチンカー/
pachinko /パチンコ/
pachislot /パチスロ;<pachinko + slot machine/
pacific /パシフィック/
pacifica /パシフィカ;(西)/
pacificleague /パシフィックリーグ/
pacifico /パシフィコ;(西)/
pack /パック/
package /パッケージ/
packagedesign /パッケージデザイン/
packagesoft /パッケージソフト/
packagetour /パッケージツアー/
packaging /パッケージング/
packard /パッカード/
packer /パッカー/
packet /パケット/
packetfilter /パケットフィルタ/
packetfiltering /パケットフィルタリング/
packing /パッキング/パッキン;蛇口の-/
packtour /パックツアー;package tour/
paclitaxel /パクリタキセル/
pacman /パックマン;[ゲーム]ナムコ/
paco /パコ/
pad /パッド/パット/
padang /パダン;インドネシア(pdg)/
padding /パディング/パッディング/
paddle /パドル/
paddling /パドリング/
paddock /パドック/
paddy /パディ/
padova /パドヴァ/
padre /バテレン/
padres /パドレス;[MLB]/
padstack /パッドスタック/
paella /パエリア/
pagan /パガン/
pagani /パガーニ/
paganini /パガニーニ/
page /ページ/ペイジ/頁/パージュ/
pageant /ページェント/
pagefault /ページフォールト/
pagein /ページイン/
pageone /ページワン/
pageout /ページアウト/
pageprinter /ページプリンタ/ページプリンター/
pager /ページャー/ページャ/
pagerank /ページランク/
pagesize /ページサイズ/
pagetable /ページテーブル/
pagetop /ページトップ/
paging /ページング/
pagingdaemon /ページングデーモン/
pagoda /パゴダ/
paid /ペイド/
pail /ペール/
pain /ペイン/パン;仏語/
paine /ペイン/
paint /ペイント/ペンキ;NB:蘭語pek/
painter /ペインター/
painting /ペインティング/
pair /ペア/ペアー/
pairglass /ペアガラス;和製英語(double glass)/
pairing /ペアリング/
pairlook /ペアルック/
pairring /ペアリング;和製英語(matching rings)/
pairticket /ペアチケット;和製英語(pair of tickets)/
pairwise /ペアワイズ/
paisa /パイサ/
pajamas /パジャマ/
pajero /パジェロ;[商標]三菱自動車/
pakistan /パキスタン;.pk/
pal /パル/
pala /パーラ/
palabora /パラボーラ;www.palabora.com(?) (NB:放物線はparabola/
palace /パレス/
palacios /パラシオス/
palais /パレ/
palau /パラオ;.pw/パラウ/
pale /ペール/ペイル/
paleague /パリーグ/パ・リーグ/パシフィックリーグ/
palembang /パレンバン/
paleo /パレオ;(接頭辞:古)/
palermo /パレルモ/
palestine /パレスチナ;.ps/パレスティナ/
palet /パレ;(Fr)円盤/
palette /パレット/
paletteknife /パレットナイフ/
pali /パーリ/
palikir /パリキール/
pall /ポール/パール/
palladium /パラジウム;[元素]46,Pd/
pallas /パラス/
pallet /パレット/
palm /パーム/
palma /パルマ/
palmer /パーマー/パルマー/パルメ/
palmier /パルミエ;(Fr) 棕櫚/
palmitin /パルミチン/
palmrest /パームレスト/
palmtop /パームトップ/
palmtree /パームツリー;palm tree,椰子の木/
palmyra /パルミラ;シリア/
palo /パロ/
paloma /パロマ/
palomar /パロマ/
palos /パロス/
palpal /パルパル/
pam /パン/パム/
pamela /パメラ/
pamir /パミール/パミル/
pampa /パンパ/
pampas /パンパス/
pampers /パンパース;[商標]P&G/
pamph /パンフ/
pamphlet /パンフレット/
pan /パン/
pana /パナ/パーナ/
panama /パナマ;.pa/
pancake /パンケーキ/
pancetta /パンチェッタ/
pancras /パンクラス/
panda /パンダ/
pandeiro /パンデイロ/
pandeiros /パンデイロ/
pandora /パンドラ/パンドーラー/
pane /ペイン/ペーン/パーネ;(It) パン/
panel /パネル/
paneldiscussion /パネルディスカッション/
paneler /パネラー/
panelheater /パネルヒーター/
panelist /パネリスト/
panflet /パンフレット;※pamphlet/
panflute /パンフルート/
pangaea /パンゲア/
panic /パニック/
panini /パニーニ;<panino/
panino /パニーノ/
panis /パニス/
panku /パンク;?/
pannacotta /パンナコッタ;(It) panna cotta/
pannier /パニエ/
panning /パニング/パンニング/
panopticon /パノプティコン/
panorama /パノラマ/
panoramic /パノラミック/
panpipe /パンパイプ/
panpot /パンポット/
pansto /パンスト;panty stocking/
pansy /パンジー/
pant /パント/
pantagruel /パンタグリュエル/
pantalon /パンタロン/
pantheon /パンテオン/
panther /パンサー/
pantie /パンティ/パンティー/
pantograph /パンタグラフ/
pantomime /パントマイム/
pantry /パントリー/
pants /パンツ/
pantslook /パンツルック/
pantssuit /パンツスーツ;※pantsuit/
pantsuit /パンツスーツ/
panty /パンティ/パンティー/
pantystocking /パンティストッキング/パンスト/
pantzer /パンツァー/
panza /パンサ/
paola /パオラ/
paolo /パオロ/
papa /パパ/
papageno /パパゲーノ/
paparazzi /パパラッチ/
papaya /パパイヤ/パパイア/
papeete /パペーテ;タヒチ/
paper /ペーパー/論文/
paperback /ペーパーバック/
papercraft /ペーパークラフト/
paperdrip /ペーパードリップ/
paperdriver /ペーパードライバー;和製英語/
paperholder /ペーパーホルダー/
paperjam /ペーパージャム/
paperknife /ペーパーナイフ/
paperless /ペーパーレス/
papermoon /ペーパームーン/
papertest /ペーパーテスト;和製英語/
paperweight /ペーパーウェイト/
papi /パピ/
papier /パピエ;(Fr)紙/
papillon /パピヨン/
paprika /パプリカ/
papua /パプア/
papuanewguinea /パプアニューギニア;Papua New Guinea/
par /パー/
para /パラ/
parabola /パラボラ/
parabolaantenna /パラボラアンテナ/
parachute /パラシュート/
parada /パラダ/
parade /パレード/
paradigm /パラダイム/
paradigmshift /パラダイムシフト/パラダイム・シフト/
paradise /パラダイス/
paradiso /パラディソ/
paradox /パラドックス/パラドクス/
paraffin /パラフィン/
paraglider /パラグライダー/
paragon /パラゴン/
paragraph /パラグラフ/¶/
paraguay /パラグアイ;.py/
paraiso /パライソ/
parallel /パラレル/‖/
parallelport /パラレルポート/
parallelturn /パラレルターン/
parallelworld /パラレルワールド/
paralympic /パラリンピック/
paramaribo /パラマリボ/
paramedic /パラメディック/
paramedical /パラメディカル/
parameter /パラメータ/パラメーター/パラメタ/パラメター/引数/
parameterfile /パラメーターファイル/
parameterization /パラメタリゼーション/
parameterized /パラメタライズド/
parametric /パラメトリック/
paramount /パラマウント/
parano /パラノ;paranoia/
paranoia /パラノイア/偏執狂/偏執病/
paranoid /パラノイド/
parapara /パラパラ/
paraphrase /パラフレーズ/
parasite /パラサイト/
parasol /パラソル/
parathion /パラチオン/
parco /パルコ/
parcolation /パーコレーション/
parcolator /パーコレーター/
pardon /パードン/
pare /パレ/
paredes /パレデス/
parent /ペアレント/
parenthesis /（/）/
parents /ペアレンツ/
pareto /パレート/
parfait /パフェ/パルフェ/
paris /パリ/パリス/
parisbrest /パリブレスト;paris-brest (お菓子)/
parisien /パリジャン/
parisiennne /パリジェンヌ/
parity /パリティ/パリティー/
paritybit /パリティビット/
park /パーク/
parka /パーカ/パーカー/
parker /パーカー/
parkhotel /パークホテル/
parking /パーキング/
parkingarea /パーキングエリア/
parkingmeter /パーキングメーター/パーキングメータ/
parkinson /パーキンソン/
parliament /パーラメント/
parlor /パーラー/
parlour /パーラー/
parme /パルム/
parmenides /パルメニデス/
parmesan /パルメザン/
parmigiano /パルミジャーノ/
parnasse /パルナス/
parnassos /パルナッソス/パルナソス/
parnassus /パルナッソス;(英語綴り)/
parnell /パーネル/
paro /パロ/
parody /パロディ/パロディー/
parole /パロール/
paroxetine /パロキセチン/
parque /パルク/
parrot /パロット/
parry /パリー/パリィ/
parrying /パリング/
parse /パース/パーズ/
parsec /パーセク/
parser /パーザ/パーザー/
parsifal /パルシファル/パルジファル/
parsing /パージング/
parsley /パセリ/
parsons /パーソンズ/
part /パート/
part# /パート#1/
parthenon /パルテノン/
partial /パーシャル/∂/
particle /パーティクル/
particleboard /パーティクルボード/
partisan /パルチザン/
partita /パルティータ/
partition /パーティション/パーテーション;esp.間仕切り/
partitioning /パーティショニング/
partner /パートナー/パートナ/
partners /パートナーズ/
partnership /パートナーシップ/
parts /パーツ/
parttime /パートタイム/
parttimer /パートタイマー/
party /パーティ/パーティー/
partygoods /パーティグッズ/
partyroom /パーティールーム/パーティルーム/
parvati /パールヴァティ/パールヴァティー/
pas /パ/
pasadena /パサデナ/
pascal /パスカル/
pascale /パスカル/
pascual /パスカル/
pasdedeux /パドドゥ;pas de deux/
pashtun /パシュトゥーン/
pasocom /パソコン/パーソナルコンピュータ/
pasocomsoft /パソコンソフト;PC software/
pasocon /パソコン/
pasolini /パゾリーニ/
pasona /パソナ;www.pasona.co.jp/
pass /パス/
passage /パッセージ/パサージュ;仏語/パッサージュ/
passball /パスボール;和製英語(passed ball)/
passcase /パスケース/
passcode /パスコード/
passenger /パッセンジャー/
passepied /パスピエ/
passing /パッシング/
passion /パッション/
passionata /パッショナータ/
passionato /パッショナート/
passionflower /パッションフラワー;時計草/
passionfruit /パッションフルーツ/
passionfruits /パッションフルーツ/
passive /パッシブ/
passphrase /パスフレーズ/
passport /パスポート/
passwd /パスワード/
password /パスワード/
passwordfile /パスワードファイル/
past /パスト/
pasta /パスタ/
pastamachine /パスタマシーン/パスタマシン/
pastapot /パスタポット/
pastasauce /パスタソース/
paste /ペースト/貼り付け/
pastel /パステル/
pastelblue /パステルブルー/
pastelcolor /パステルカラー/
pastelcolour /パステルカラー/
pastelpink /パステルピンク/
pasteur /パスツール/パストゥール/
pastiche /パスティーシュ/パスティッシュ/パスティシュ/
pastime /パスタイム/
pastis /パスティス/
pastor /パストール/
pastoral /パストラル/
pastorale /パストラル/パストラーレ;(イタリア語)/
pastral /パストラル;※pastoral?/
pastrius /パストリアス/
pastry /ペストリー/
pat /パット/
patagonia /パタゴニア/
pataliputra /パータリプトラ/
patcar /パトカー;patrol car/
patch /パッチ/
patchfile /パッチファイル/
patchkit /パッチキット/
patchrelease /パッチリリース/
patchtest /パッチテスト/
patchwork /パッチワーク/
pate /パテ/
patent /パテント/
paternalism /パターナリズム/
path /パス/
pathetic /パセティック/
pathos /ペーソス/パトス/ペイソス/
pathway /パスウェイ/
pathy /パシー/
patient /ペイシェント/
patio /パティオ/
patisserie /パティスリー;(Fr)ケーキ屋/
patissier /パティシエ/
patissiere /パティシエール;(Fr)ケーキ職人/
patlabor /パトレイバー;[アニメ]/
patlight /パトライト;[商標]/
patrice /パトリス/
patricia /パトリシア/
patrick /パトリック/
patriot /パトリオット/
patrol /パトロール/
patrolcar /パトロールカー/パトカー/
patron /パトロン/
patsy /パッツィ/
pattern /パターン/パタン/
patterner /パタンナー;和製英語(pattern maker)/
patternfile /パターンファイル/
patternmatch /パターンマッチ/
patternmatching /パターンマッチング/パターン・マッチング/
patternrecognition /パターン認識/
patterson /パターソン/
patti /パティ/
patty /パティ/パティー/
pau /ポー/
pauch /パウチ/
pauillac /ポイヤック/
paul /ポール/パウロ/パウル/
paula /ポーラ/パウラ/
paule /ポール/
paulette /ポーレット/
pauli /パウリ/
pauline /ポーリン/ポーリーヌ/
pauling /ポーリング/
paulo /パウロ/ポーロ/
paulos /パウロ/
paulus /パウルス/
pause /ポーズ/
pavane /パヴァーヌ/
pavarotti /パヴァロッティ/パバロッティ/
pavel /パヴェル/パベル/パーヴェル/
pavilion /パビリオン/
pavillon /パヴィヨン;仏語/
pavlov /パブロフ/パヴロフ/
pawn /ポーン/
pax /パックス;(latin) 平和/パクス/パークス/
paxil /パキシル/
pay /ペイ/
paycheck /ペイチェック/
payload /ペイロード/
payment /ペイメント/
payoff /ペイオフ/
paz /パス/
pb /鉛/Lead/
pc /パソコン/パーソナルコンピュータ/PC/
pc98 /ＰＣ９８/
pcat /ＰＣ／ＡＴ/
pccamera /PCカメラ/
pccard /PCカード/
pccase /PCケース/
pcdesk /パソコンデスク/PCデスク/
pcengine /PCエンジン;[商標]NEC/
pcgame /PCゲーム/パソコンゲーム/
pcibus /PCIバス/
pcicard /PCIカード/
pcidevice /PCIデバイス/
pcislot /PCIスロット/
pcl /PCL/PCL(Portable Common Loops)/
pcmaker /PCメーカー/パソコンメーカー/PCメーカ/パソコンメーカ/
pcmodel /ＰＣモデル/
pcode /Pコード;チケットぴあ/
pcrack /パソコンラック/PCラック/
pcshop /PCショップ/パソコンショップ/
pcsite /PCサイト/
pcsoft /PCソフト/パソコンソフト/
pd /パラジウム/Palladium/
pdffile /PDFファイル/
pdp# /PDP-#0/
pds /パブリックドメインソフト/パブリックドメーンソフトウエア/
pe /п;cyrillic/プロセッシングエレメント/
peace /ピース/
peaceboat /ピースボート;www.peaceboat.org/
peaceful /ピースフル/
peacesign /ピースサイン/
peach /ピーチ/
peacock /ピーコック/
peak /ピーク/
peakout /ピークアウト/
peaks /ピークス/
peaky /ピーキー/
peano /ペアノ/
peanut /ピーナッツ/ピーナツ/
peanutbutter /ピーナッツバター/ピーナツバター/
peanuts /ピーナッツ/ピーナツ/
peanutsbutter /ピーナッツバター/ピーナツバター/
pear /ペア;洋梨/
pearl /パール/真珠/
pearlcolor /パールカラー/
pearlcolour /パールカラー/
pearlharbor /パールハーバー;Pearl Harbor/
pearlite /パーライト/
pearlwhite /パールホワイト/
pearson /ピアソン/
peau /ポー/
pecan /ペカン/ピーカン/
pecannuts /ピーカンナッツ/
peccary /ペッカリー/
peche /ペシェ;(Fr) 罪/ペーシュ;(Fr) 桃/
pecker /ペッカー/
pectin /ペクチン/
pectine /ペクチン/
ped /ペド/
pedal /ペダル/
pedaling /ペダリング/
pedantic /ペダンティック/
pedantry /ペダントリー/
pedicure /ペディキュア/
pediment /ペディメント/
pedo /ペド/
pedophilia /ペドフィリア/
pedro /ペドロ/
pedrosa /ペドロサ/
pee /ピー/
peek /ピーク/
peel /ピール/
peeler /ピーラー/
peeling /ピーリング/
peephole /ピープホール/
peer /ピア/ペール;Peer Gynt/
peergynt /ペールギュント/ペール・ギュント/
peerreview /ピアレビュー/
peertopeer /ピアツーピア/
peg /ペグ/
pegasos /ペガソス/
pegasus /ペガサス/
peggy /ペギー/
pek /ペンキ;(蘭語)/
peking /ペキン/北京/
pekingduck /北京ダック/ペキンダック/
pekingese /ペキニーズ/
pekoe /ペコ/ペコー/
pel /ペル/
peleg /ペレグ/
peleus /ペレウス/
pelican /ペリカン/
pellagra /ペラグラ/
pelleas /ペレアス/
pellet /ペレット/
peloponnesos /ペロポネソス/
pembroke /ペンブローク/
pen /ペン/
pena /ペーニャ/
penalty /ペナルティ/ペナルティー/
penaltyarea /ペナルティーエリア/
penaltykick /ペナルティーキック;PK/
penang /ペナン/
pencase /ペンケース/
pence /ペンス/
pencil /ペンシル/
penclub /ペンクラブ;www.pen.org/
pendant /ペンダント/
pendanthead /ペンダントヘッド/
pendanttop /ペンダントトップ/
pending /ペンディング/
pendulum /ペンデュラム/
pene /ペネ/
penelope /ペネロペ/
penetration /ペネトレーション/
penfriend /ペンフレンド/
penguin /ペンギン/
penicillin /ペニシリン/
peninsula /ペニンシュラ/
penis /ペニス/
penlight /ペンライト/
penname /ペンネーム/
pennant /ペナント/
pennantrace /ペナントレース/
penne /ペンネ/
pennsylvania /ペンシルバニア/ペンシルベニア;PA/
penny /ペニー/
penpal /ペンパル/
penrose /ペンローズ/
pensee /パンセ/
pension /ペンション/
penstand /ペンスタンド/
penta /ペンタ;5/
pentablet /ペンタブレット/
pentagon /ペンタゴン/
pentane /ペンタン/
pentatonic /ペンタトニック/
pentax /ペンタックス;www.pentax.co.jp/
pentecost /ペンテコステ/
penthouse /ペントハウス/
pentium /ペンティアム/Pentium/
pentouch /ペンタッチ/
pentyl /ペンチル/
people /ピープル/
peoria /ピオリア;Illinois, USA/
pep /ペップ/
pepe /ペペ/
pepee /ペペ;仏語/
pepper /ペッパー/ペパー/
peppermill /ペッパーミル/
peppermint /ペパーミント/
pepperoncino /ペペロンチーノ/
pepsi /ペプシ;www.pepsi.com/
pepsico /ペプシコ;www.pepsico.com/
pepsicola /ペプシコーラ;Pepsi-Cola/
pepsin /ペプシン/
peptidase /ペプチダーゼ/
peptide /ペプチド/
peptideglycan /ペプチドグリカン/
peptidehormone /ペプチドホルモン;peptide hormone/
peptone /ペプトン/
per /ペール/パー/ペア/
percent /パーセント/％/
percentage /パーセンテージ/
perception /パーセプション/
perceptron /パーセプトロン/
perceval /パーシバル/パーシヴァル/
percival /パーシバル/
percuss /パーカス/
percussion /パーカッション/
percussionist /パーカッショニスト/
percussive /パーカッシブ/パーカッシヴ/
percy /パーシー/
pere /ペール;(Fr)父/
perestroika /ペレストロイカ/
perez /ペレス/
perfect /パーフェクト/
perfectv /パーフェクTV/
perform /パフォーム/
performance /パフォーマンス/パーフォーマンス/
performer /パフォーマー/
performing /パフォーミング/
perfume /パフューム/パルファン;仏語/
pergamon /ペルガモン/
pergola /パーゴラ/
peri /ペリ/
peridot /ペリドット/
perier /ペリエ/
periere /ペリエール/
perignon /ペリニョン/ペリニヨン/
period /ピリオド/Ｐｅｒｉｏｄ/．/
periodic /ピリオディック/
peripheral /ペリフェラル/
perkin /パーキン/
perkins /パーキンス/パーキンズ/
perl /パール/Ｐｅｒｌ/Perl/
perla /パーラ/
perlscript /Perlスクリプト/perlスクリプト/
perm /パーマ;permanent/
perma /パーマ/
permanent /パーマネント/
permil /‰/パーミル/
permill /‰/パーミル/
permission /パーミッション/
perno /ペルノ/
pero /ペロ/
peron /ペロン/
peroxo /ペルオキソ/
peroxy /ペルオキシ/
perp /┴/
perpignan /ペルピニャン/
perrault /ペロー/
perrin /ペラン/
perrine /ペリーヌ/
perrot /ペロー/
perry /ペリー/
persephone /ペルセポネ/ペルセフォネ/
persepolis /ペルセポリス/
perseus /ペルセウス/
persia /ペルシャ/ペルシア/
persistent /パーシステント/永続/
persocom /パソコン/
person /パーソン/
persona /ペルソナ/
personal /パーソナル/
personal-computer /パソコン/
personalcomputer /パーソナルコンピュータ/パーソナルコンピューター/
personalise /パーソナライズ/
personality /パーソナリティ/パーソナリティー/
personalize /パーソナライズ/
personalmedia /パーソナルメディア/
personnel /パーソネル/
perspective /パースペクティブ/
perth /パース/
perto /ペトロ/
peru /ペルー;.pe/
pescatore /ペスカトーレ/
peseta /ペセタ/
peshawar /ペシャワール;パキスタン/
pesrsonal /パーソナル/
pessac /ペサック/
pessary /ペッサリー/
pessimism /ペシミズム/
pessimist /ペシミスト/
pest /ペスト/
pet /ペット/
peta /ペタ;P,10^15/
petal /ペタル/
petanque /ペタンク/
petbottle /ペットボトル/PETボトル/
pete /ピート/
peter /ピーター/ペーター/ペテロ/ピョートル/ペテル/
peterburg /ペテルブルグ/
peterpan /ピーターパン;Peter Pan/
peterrabbit /ピーターラビット/
petersen /ペーターゼン/
peterson /ピーターソン/
petfood /ペットフード/
petgoods /ペットグッズ/
pethotel /ペットホテル/
petit /プチ/プティ/
petite /プティット/
petitgateau /プチガトー/プティガトー/
petitknife /ペティナイフ/
petittomato /プチトマト;和製英語(petite tomate?)/
petra /ペトラ/
petrarca /ペトラルカ/
petri /ペトリ/
petros /ペテロ/
petrouchka /ペトルーシュカ/
petrucciani /ペトルチアーニ/
petrus /ペトリュス/
pets /ペッツ/
petshop /ペットショップ/
petsitter /ペットシッター/
petticoat /ペチコート/
petting /ペッティング/
petty /ペティ/ペティー/
petunia /ペチュニア/
petz /ペッツ/
peugeot /プジョー/
pex /ペックス/
peyote /ペヨーテ/
pfalz /ファルツ/
pfartz /プファルツ/
pfizer /ファイザー/
ph /φ;phi/
phage /ファージ/
phalaenopsis /ファレノプシス/
phallus /ファルス/
phantasm /ファンタズム/
phantasma /ファンタズマ/
phantom /ファントム/
pharaoh /ファラオ/
pharisee /パリサイ/
pharma /ファーマ/
pharmacy /ファーマシー/
pharming /ファーミング/
phase /フェーズ/フェイズ/
phasing /フェージング/フェイズィング;<rare>/
phenol /フェノール/
phenolphthalein /フェノールフタレイン/
phenoxy /フェノキシ/
phenoxyethanol /フェノキシエタノール/
phenyl /フェニル;C6H5-/フェニール/
phenylalanine /フェニルアラニン;Phe/
pheromone /フェロモン/
phi /φ/ファイ/
phil /フィル/
philadelphia /フィラデルフィア/
phile /フィル;仏語/ファイル;英語/
philemon /フィレモン/ピレモン/
philharmonia /フィルハーモニア/
philharmonic /フィルハーモニック/
philharmonie /フィルハーモニー/
philharmony /フィルハーモニー/
philia /フィリア/
philip /フィリップ/
philipp /フィリップ/
philippa /フィリッパ/フィリパ/
philippe /フィリップ/
philippi /ピリピ/
philippine /フィリピン/フィリピーヌ/
philippinepub /フィリピンパブ/
philippines /フィリピン;.ph/比律賓/
philips /フィリップス/
phillies /フィリーズ;[MLB]/
phillips /フィリップス/
phillis /フィリス/
philly /フィリー/
philo /フィロ/
philology /フィロロジー/
philopon /ヒロポン/
philosophy /フィロソフィー/
phishing /フィッシング/
phmeter /pHメーター/pHメータ/
phnompenh /プノンペン;Phnom Penh/
pho /フォー;ベトナム料理/
phobia /フォビア/
phobos /フォボス/
phoebe /フィービー/フェーベ/
phoenicia /フェニキア/
phoenix /フェニックス/
phon /フォン/
phone /フォン/ホン/
phono /フォノ;(接頭辞:音)/
phonon /フォノン/
phononics /フォノニクス/
phony /フォニー/
phosgen /ホスゲン/
phosgene /ホスゲン/
phosphor /フォスファー;P/
photo /フォト/
photoalbum /フォトアルバム/
photocd /フォトCD/
photocontest /フォトコンテスト/
photocoupler /フォトカプラ/
photoframe /フォトフレーム/
photogallery /フォトギャラリー/
photogenic /フォトジェニック/
photograph /フォトグラフ/
photographer /フォトグラファー/
photography /フォトグラフィー/フォトグラフィ/
photolog /フォトログ/
photomask /フォトマスク/
photon /フォトン/
photoretouch /フォトレタッチ/
photoshop /フォトショップ/
photostand /フォトスタンド;和製英語/
phrase /フレーズ/
phrasing /フレージング/フレイジング/
phrygian /フリジアン;EFGABCDE/
phthalein /フタレイン/
phuket /プーケット/
phyllis /フィリス/
physical /フィジカル/
physics /フィジックス/
physis /ピュシス/
pi /π/パイ/
pia /ピア/ぴあ;www.pia.co.jp/
piacere /ピアチェーレ/
piaf /ピアフ/
pianica /ピアニカ/
pianism /ピアニズム/
pianissimo /ピアニッシモ/
pianist /ピアニスト/
piano /ピアノ/
pianocover /ピアノカバー/
pianoforte /ピアノフォルテ/
pianosolo /ピアノソロ/
pianosonata /ピアノソナタ/
pianotrio /ピアノトリオ/
piazza /ピアッツァ;(It)広場/ピアザ/
piazzolla /ピアソラ/
pica /パイカ/
picador /ピカドール/
picard /ピカード/ピカール/
picaresque /ピカレスク/
picasso /ピカソ/
piccadilly /ピカデリー/
piccata /ピカタ/
piccoli /ピッコリ/
piccolo /ピッコロ/
pichon /ピション/
pick /ピック/
pickel /ピッケル/
picker /ピッカー/
picket /ピケ/ピケット/
picking /ピッキング/
pickles /ピクルス/
pickup /ピックアップ/
picmicom /PICマイコン/
picnic /ピクニック/
pico /ピコ;[SI接頭語]p,10^-12/
picot /ピコ/
pictogram /ピクトグラム/
picture /ピクチャー/ピクチャ/
picturecard /ピクチャーカード/ピクチャカード/
picturelabel /ピクチャーレーベル/
pid /プロセスID/
pidgin /ピジン/
pie /パイ/
piece /ピース/
pieces /ピーシーズ/
piedra /ピエドラ/
piemonte /ピエモンテ;イタリア/
pier /ピア/ピアー/ピエル/
pierce /ピアス;和製英語/
piercer /ピアッサー/
piercing /ピアッシング/ピアシング/
piero /ピエロ/
pierre /ピエール/
pierrecardin /ピエールカルダン;Pierre Cardin. www.pierrecardin.com/
pierrot /ピエロ/
piers /ピアス/
pieta /ピエタ/
pietro /ピエトロ/
piezo /ピエゾ;圧電/
pig /ピッグ/
pigeon /ピジョン/
piggy /ピギー/
pigma /ピグマ/
pigmy /ピグミー/
pilaf /ピラフ/
pilar /ピラール/
pilatus /ピラト/
pile /パイル/
piledriver /パイルドライバー/
pilgrim /ピルグリム/
pill /ピル/
pillar /ピラー/
pillow /ピロー/
pillowcase /ピローケース;枕カバー/
pilot /パイロット/
pilotis /ピロティ/ピロティー/
pilotlamp /パイロットランプ/
piment /ピーマン;仏語/
pin /ピン/
pinbadge /ピンバッジ/
pinball /ピンボール/
pincet /ピンセット;(蘭語) NB:forceps(En)/
pinch /ピンチ/
pincher /ペンチ/ピンチャー/
pinchhitter /ピンチヒッター/
pinchrunner /ピンチランナー/
pindaros /ピンダロス/
pine /パイン/
pineapple /パイナップル/
pineau /ピノー/
pines /パインズ/
ping /ピン/ピング/
pingpong /ピンポン/
pingu /ピングー/
pinheel /ピンヒール/
pinhole /ピンホール/
pinholecamera /ピンホールカメラ/
pinjack /ピンジャック/
pink /ピンク/
pinkerton /ピンカートン/
pinklady /ピンクレディー/ピンクレディ/
pinknoise /ピンクノイズ/
pinkpanther /ピンクパンサー/
pinkrotor /ピンクローター/
pinksalon /ピンクサロン/ピンサロ/
pinky /ピンキー/
pinnacle /ピナクル/
pinnock /ピノック/
pino /ピノ/
pinocchio /ピノキオ/
pinochet /ピノチェト/
pinot /ピノ/
pinotnoir /ピノノワール;pinot noir/
pinpoint /ピンポイント/
pinscher /ピンシャー/
pinstripe /ピンストライプ/
pint /ピント/パイント/
pinto /ピント/
pinup /ピンナップ/
pinyin /ピンイン/
pio /ピオ/
pion /パイオン/
pioneer /パイオニア/
piotr /ピョートル/
pipe /パイプ/
pipecut /パイプカット;和製英語(vasectomy)/
pipeline /パイプライン/
pipeorgan /パイプオルガン/
piper /パイパー/
pipette /ピペット/
piping /パイピング/
pippi /ピッピ;Pippi Langkous/
pippin /ピピン/
pique /ピケ/
piranha /ピラニア/
pirarucu /ピラルク/
pirates /パイレーツ;[MLB]/
pirlo /ピルロ/
pirouette /ピルエット/
pirozhki /ピロシキ/
pisa /ピサ/
pisces /ピスケス;魚座/
piss /ピス/
pissarro /ピサロ/
pistachio /ピスタチオ/
pistol /ピストル/
piston /ピストン/
pit /ピット/
pita /ピタ;中東のパン/
pitapain /ピタパン;pita bread/
pitch /ピッチ/
pitcher /ピッチャー/
pitcherfly /ピッチャーフライ/
pitchergoro /ピッチャーゴロ;和製語(grounder)/
pitching /ピッチング/
pitchingwedge /ピッチングウェッジ/
pitcrew /ピットクルー/
pitfall /ピットフォール/
pitin /ピットイン;和製英語(pit stop)/
pitinn /ピットイン;www.pit-inn.com/ＰｉｔＩｎｎ/
pitstop /ピットストップ/
pittsburgh /ピッツバーグ;USA/
pius /ピウス/ピアス/
pivot /ピボット/
pixel /ピクセル/
pixer /ピクサー/
pixmap /ピックスマップ/
pixus /ピクサス;[商標]Canon/
pixy /ピクシー/
pizarro /ピサロ/
pizza /ピザ/ピッツァ/ピッツア/
pizzala /ピザーラ;www.pizza-la.co.jp/
pizzeria /ピッツェリア/
pizzicato /ピチカート/
pla /プラ;plastic/
placard /プラカード/
placase /プラケース;plastic case/
place /プレイス/プレース/プラース/
placebo /プラシーボ/プラセボ/
placid /プラシッド/
placido /プラシド/
plain /プレーン/プレイン/
plaintext /プレーンテキスト/
plaisir /プレジール;(Fr)快楽/
plala /ぷらら;www.plala.or.jp/
plamo /プラモ;plamodel/
plamodel /プラモデル;plastic model/
plan /プラン/
planaria /プラナリア/
planck /プランク/
plane /プレーン/
planet /プラネット/
planetarium /プラネタリウム/
planetary /プラネタリー/
planets /プラネッツ/
planing /プレーニング/プランニング;※plaNNing/
plank /プランク/
plankton /プランクトン/
planner /プランナー/プランナ/
planning /プランニング/
plant /プラント/
plantation /プランテーション/
planter /プランター/
plants /プランツ/
plaque /プラーク/
plasma /プラズマ/
plasmadisplay /プラズマディスプレイ/
plasmatv /プラズマテレビ/
plasmid /プラスミド/
plassey /プラッシー/
plaster /プラスター/
plasterboard /プラスターボード/
plastic /プラスチック/プラスティック/
plasticlens /プラスチックレンズ/
plastics /プラスチックス/
platanus /プラタナス/
plate /プレート/
plateau /プラトー/
platetectonics /プレートテクトニクス/
platform /プラットフォーム/プラットホーム/
plathome /ぷらっとホーム;www.plathome.co.jp NB:駅のはplatform/
platina /プラチナ/
platini /プラティニ/
platinum /プラチナ/
plato /プラトン/
platon /プラトン/
platonic /プラトニック/
platonism /プラトニズム/
platoon /プラトン/プラトーン/
platt /プラット/
platter /プラッタ/プラッター/
play /プレイ/プレー/
playback /プレイバック/プレーバック/
playball /プレイボール/プレーボール/
playboy /プレイボーイ/
player /プレーヤー/プレイヤー/プレーヤ/プレイヤ/
players /プレイヤーズ/
playgirl /プレイガール/
playguide /プレイガイド;和製英語(ticket agency)/
playing /プレイング/プレーイング/
playlist /プレイリスト/
playmate /プレイメイト/
playmode /プレイモード/
playoff /プレーオフ/プレイオフ/
playroom /プレイルーム/
plays /プレイズ/
playspot /プレイスポット/
playstation /プレイステーション;[商標]Sony/プレステ/
playstyle /プレイスタイル/
plaza /プラザ/プラーザ/プラサ/
plazahotel /プラザホテル/
please /プリーズ/
pleasure /プレジャー/
pleats /プリーツ/
pleatsskirt /プリーツスカート/
pleiade /プレイアード/
pleiades /プレアデス/プレイアデス/
plein /プレーン/プレイン/
pletnev /プレトニョフ/
plind /プリンディ;?/
plinius /プリニウス/
plot /プロット/
plotinos /プロティノス/
plototype /プロトタイプ/
plotter /プロッタ/プロッター/
plough /プラウ/
plow /プラウ/
plug /プラグ/
plugandplay /プラグアンドプレイ/
plugin /プラグイン/
plum /プラム/
plumeria /プルメリア/
plumi /±/
plus /プラス/＋/
plusalpha /プラスα/プラスアルファ/+α/＋α/
plusdriver /プラスドライバー;和製英語(Phillips-head screwdriver)/
plusion /プラスイオン;和製英語(positive ion)/
plusminus /プラスマイナス/±/
plusone /プラスワン/
plutarch /プルターク/プルタルコス/
plutarchos /プルタルコス/
pluthermal /プルサーマル;和製英語(plutonium + thermal)/
pluto /プルート/
pluton /プルトン/
plutonium /プルトニウム;[元素]94,Pu/
plymouth /プリマス/
pm /±/プロメチウム/Promethium/
po /ポロニウム/Polonium/ポー/
poachedegg /ポーチドエッグ/
pochette /ポシェット/
pocket /ポケット/
pocketbell /ポケットベル/ポケベル/
pocketmoney /ポケットマネー/
pocketmonster /ポケットモンスター/
pocketreference /ポケットリファレンス/
pocketsize /ポケットサイズ/
pockettissue /ポケットティッシュ/
pocky /ポッキー/
poco /ポコ/
pocoapoco /ポコアポコ;poco a poco/ポコ・ア・ポコ/
pod /ポッド/
podcast /ポッドキャスト/
podcasting /ポッドキャスティング/
podium /ポディウム/
poe /ポー/
poem /ポエム/
poeme /ポエム;仏語/
poertyreading /ポエトリーリーディング/
poesie /ポエジー/
poet /ポエット/ポエト/
poete /ポエット;(Fr)詩人/ポエト/
poetic /ポエティック/
poetry /ポエトリー/
poile /ポワール/
poincare /ポアンカレ/
poinsettia /ポインセチア/
point /ポイント/ポワン;仏語/ポアン;仏語/・/点/
pointcard /ポイントカード/
pointer /ポインタ/ポインター/
pointing /ポインティング/
pointingdevice /ポインティングデバイス/
points /ポインツ/
pointservice /ポイントサービス/
pointsystem /ポイントシステム/
pointup /ポイントアップ/
poire /ポワール;(Fr) 洋梨/ポアール/
poirot /ポワロ/
poison /ポイズン/
poisonpill /ポイズンピル/
poisson /ポアソン/
poitiers /ポワティエ/
pokemon /ポケモン;pocketmonster/
poker /ポーカー/
pokerface /ポーカーフェイス/
pokhara /ポカラ/
pola /ポーラ/
poland /ポーランド;.pl/
polanski /ポランスキー/
polanyi /ポランニー/
polar /ポーラー/
polaris /ポラリス/
polaroid /ポラロイド/
polaroidcamera /ポラロイドカメラ/
polder /ポルダー/
pole /ポール/
polenta /ポレンタ/
polepole /ポレポレ/
poleposition /ポールポジション/
police /ポリス/
policeman /ポリスマン/
policy /ポリシー/ポリシ/
polimeralloy /ポリマーアロイ;polimer alloy/
poling /ポーリング/
polio /ポリオ/
polis /ポリス/
polish /ポリッシュ/ポーランド;?/
polisher /ポリッシャー/
political /ポリティカル/
politician /ポリティシャン/
politics /ポリティクス/ポリティックス/
polka /ポルカ/
poll /ポール/
polling /ポーリング/
pollini /ポリーニ/
pollux /ポルックス/
polly /ポリー/
pollyanna /ポリアンナ/
polo /ポロ/ポーロ/
polonaise /ポロネーズ/
polonium /ポロニウム;[元素]84,Po/
poloshirt /ポロシャツ/
poloshirts /ポロシャツ/
poltergeist /ポルターガイスト/
poly /ポリ/
polyamide /ポリアミド/
polybucket /ポリバケツ;polyethylene bucket/
polycarbonate /ポリカーボネート/
polydextrose /ポリデキストロース/
polydor /ポリドール/
polyester /ポリエステル/
polyethylene /ポリエチレン/
polyethyleneglycol /ポリエチレングリコール/
polygon /ポリゴン/
polygraph /ポリグラフ/
polyline /ポリライン/
polymer /ポリマー/重合体/
polymerase /ポリメラーゼ/
polymorphic /ポリモルフィック/多相型/
polymorphism /ポリモーフィズム/ポリモルフィズム/
polynesia /ポリネシア;.pf/
polynesian /ポリネシアン/
polyp /ポリープ/ポリプ/
polyphonic /ポリフォニック/
polyphony /ポリフォニー/
polypropylene /ポリプロピレン/
polyrhythm /ポリリズム/
polysilane /ポリシラン/
polystar /ポリスター/
polystyrene /ポリスチレン/
polytank /ポリタンク;和製英語(polybottle)/
polyurethane /ポリウレタン/
polyvinyl /ポリビニル/
pomade /ポマード/
pomato /ポマト;<potato + tomato/
pomeranian /ポメラニアン;犬/
pomerol /ポムロール/
pomodoro /ポモドーロ;(It)トマト/
pomp /ポンプ;(蘭語)/
pompeii /ポンペイ/
pompidou /ポンピドゥー/ポンピドゥ/ポンピドー/
poncho /ポンチョ/
pond /£/ポンド/
pong /ポン/
pons /ポンス/
ponte /ポンテ/
ponti /ポンティ/
pontiac /ポンティアック/
pontneuf /ポンヌフ;Pont-Neuf/
ponty /ポンティ/
pony /ポニー/
ponycanyon /ポニーキャニオン;www.ponycanyon.co.jp/
ponytail /ポニーテール/
poo /Parallel Object-Oriented/
poodle /プードル/
pooh /プー/
pool /プール/Parallel Object-Oriented Language/
poolside /プールサイド/
poor /プア/
pop /ポップ/
popart /ポップアート/
popband /ポップバンド/
popcorn /ポップコーン/
popculture /ポップカルチャー/
pope /ポープ;法王/
popeye /ポパイ/
popfly /ポップフライ/
poplar /ポプラ/
poplin /ポプリン/
popmusic /ポップミュージック/
popp /ポップ/
popper /ポッパー/ポパー/
poppins /ポピンズ/
poppy /ポピー/
pops /ポップス/
popsong /ポップソング/
popular /ポピュラー/
popularmusic /ポピュラーミュージック/
popularscience /ポピュラーサイエンス/
popularsong /ポピュラーソング/
populism /ポピュリズム/
populist /ポピュリスト/
popup /ポップアップ/
popupmenu /ポップアップメニュー/ポップアップ・メニュー/
popupwindow /ポップアップウィンドウ/
porcelain /ポーセリン/ポーセレン/
porch /ポーチ/
porcini /ポルチーニ/
pork /ポーク/
porkchop /ポークチョップ/
porkcurry /ポークカレー/
porno /ポルノ/
pornography /ポルノグラフィ/ポルノグラフィー/
pororoca /ポロロッカ/
porphyrin /ポルフィリン/
porsche /ポルシェ/
port /ポート/
portability /ポータビリティ/
portable /ポータブル/
portableaudio /ポータブルオーディオ/
portableplayer /ポータブルプレーヤー/
portal /ポータル/
portalsite /ポータルサイト/
portamento /ポルタメント/
portasound /ポータサウンド/
portatone /ポータトーン/
porter /ポーター/
portfolio /ポートフォリオ/
porting /ポーティング/
portio /ポルチオ/
portion /ポーション/
portland /ポートランド/
portlouis /ポートルイス;Port Louis/
portmoresby /ポートモレスビー;Port Moresby/
porto /ポルト/
portrait /ポートレート/ポートレイト/
ports /ポーツ/
portsaid /ポートサイド/
portscan /ポートスキャン/
portside /ポートサイド/
portsmouth /ポーツマス/
portugal /ポルトガル;.pt/葡萄牙/
portulaca /ポーチュラカ/
portvila /ポートヴィラ;Port-Vila/
portwine /ポートワイン/
pose /ポーズ/
poseidon /ポセイドン/
posi /ポジ;positive/
posifilm /ポジフィルム;positive film/
posing /ポージング/
position /ポジション/
positioning /ポジショニング/
positive /ポジティブ/ポジティヴ/
posix /POSIX/
possum /ポッサム/
possystem /POSシステム/
post /ポスト/〒/
postal /ポスタル/
postcard /ポストカード/
postcolonial /ポストコロニアル/
postdoc /ポストドク/
postdoctor /ポストドクター/ポスドク/
poster /ポスター/ポスタ/
postercolor /ポスターカラー/
postercolour /ポスターカラー/
postersession /ポスターセッション/
postharvest /ポストハーベスト/
posting /ポスティング/
postit /ポストイット;[商標]3M/ポウストイット;<rare>/
postman /ポストマン/
postmaster /ポストマスター/ポストマスタ/
postmethod /POSTメソッド/
postmodern /ポストモダン/
postpet /ポストペット/
postprocess /ポストプロセス/
postscript /ポストスクリプト/
postseason /ポストシーズン/
pot /ポット/
potage /ポタージュ/
potala /ポタラ;チベット・ラサ/
potassium /カリウム;[元素]19,K/ポタシウム;=Kalium/ポタジウム/
potato /ポテト/
potatochip /ポテトチップ/
potatochips /ポテトチップス/
potatofry /ポテトフライ;和製英語(fried potatoes)/
potatosalad /ポテトサラダ/
potaufeu /ポトフ;pot-au-feu/
potemkin /ポチョムキン/
potente /ポテンテ/
potential /ポテンシャル/
potentiometer /ポテンショメータ/
pothos /ポトス/
potion /ポーション/
potlatch /ポトラッチ/
potomac /ポトマック/
potpourri /ポプリ;(Fr) pot-pourri/
potsdam /ポツダム/
potter /ポッター/
pottery /ポタリー/ポッタリー/
pouch /ポーチ/パウチ/
poudre /プードル;(Fr) 粉/
poulain /プラン/
poulenc /プーランク/
pound /ポンド/パウンド/£/
poundcake /パウンドケーキ/
poussin /プーサン/プッサン/
powder /パウダー/
powderroom /パウダールーム/
powdersnow /パウダースノー/
powderspray /パウダースプレー/
powdery /パウダリー/
powell /パウエル/
power /パワー/
poweramp /パワーアンプ/
powerbalance /パワーバランス/
powerbomb /パワーボム/
powerbook /パワーブック/
powercable /パワーケーブル/
powerdown /パワーダウン/
powered /パワード/
powerful /パワフル/
powergame /パワーゲーム/
poweroff /パワーオフ/
poweron /パワーオン/
powerpoint /パワーポイント;[商標]Microsoft/
powers /パワーズ/
powershovel /パワーショベル/
powerspector /パワースペクトル/
powersteer /パワステ/
powersteering /パワーステアリング/パワステ/
powerstone /パワーストーン/
powerup /パワーアップ/
poweruser /パワーユーザー/パワーユーザ/
powerwindow /パワーウィンドウ/
pp /ピアニッシモ;pより弱く/pianissimo/
ppp /ピアニッシッシモ;ppより弱く/pianississimo/
pr /プラセオジム/Praseodymium/
practical /プラクティカル/
practice /プラクティス/
prada /プラダ;www.prada.it/
prado /プラド/
pragma /プラグマ/
pragmatic /プラグマティック/
prague /プラハ/
praha /プラハ/
praia /プライア/
prairie /プレーリー/
prairiedog /プレーリードッグ/
praise /プレイズ/
praline /プラリネ/プラリーヌ/
pralinee /プラリネ/
praseodymium /プラセオジミウム;[元素]59,Pr/
prasma /プラズマ/
prat /プラット/
pratt /プラット/
pravda /プラウダ/
pray /プレイ/
prayer /プレイヤ;祈る人/プレア;祈り/
pre /プリ/プレ/
prealocate /プリアロケート/
preamble /プリアンブル/
preamp /プリアンプ/
precious /プレシャス/
precision /プレシジョン/
precut /プレカット/
predator /プレデター/
predicate /プレディケート/プレディケイト/述語/
predump /プリダンプ/
preemmptive /プリエンプティブ/
preemption /プリエンプション/
preemptive /プリエンプティブ/
preevent /プレイベント/
prefab /プレハブ/
preference /プリファレンス/プレファレンス/
prefetch /プリフェッチ/
prefix /プレフィックス/プリフィクス/プレフィクス/
preinstall /プリインストール/プレインストール/
preload /プリロード/プレロード/
prelocate /プリロケート/
prelude /プレリュード/
premainamp /プリメインアンプ;pre-main amp/
premier /プルミエ;(Fr)第一/プレミア/
premiere /プルミエール/プレミア/
premium /プレミアム/プレミア/
preopen /プレオープン/
prepaid /プリペイド/
prepaidcard /プリペイドカード/
preparat /プレパラート;(独語)/
preprint /プレプリント/
preprocessor /プリプロセッサ/
prerelease /プレリリース/
preseason /プレシーズン/
presen /プレゼン;presentation/
presence /プレゼンス/
present /プレゼント/
presentation /プレゼンテーション/プレゼンテイション/
presenter /プレゼンター/
presents /プレゼンツ/
preserve /プリザーブ/
preserved /プリザーブド/
preservedflower /プリザーブドフラワー/
preset /プリセット/
president /プレジデント/
presidential /プレジデンシャル/
presley /プレスリー/
press /プレス/
presser /プレッサー/
pressing /プレッシング/
pressrelease /プレスリリース/
pressroom /プレスルーム/
presssheet /プレスシート;和製英語/
pressure /プレッシャー/
prestige /プレステージ/プレスティッジ/
presto /プレスト/
preston /プレストン/
pretaporte /プレタポルテ;(Fr)pret-a-porter/
pretoria /プレトリア/
pretty /プリティ/プリティー/
prettyprint /プリティプリント/
pretzel /プレッツェル/
preussen /プロイセン/
prevert /プレヴェール/
preview /プレビュー/プレヴュー/
previewer /プレビュアー/プレビューア/プレヴュア/
previn /プレヴィン/
prevost /プレヴォー/プレヴォ/
pri /プリ/
price /プライス/
pricedown /プライスダウン/
priceless /プライスレス/
pricing /プライシング/
prick /プリック/
pride /プライド/
priest /プリースト/
prieto /プリエト/
prima /プリマ/
primadonna /プリマドンナ;prima donna/
primal /プライマル/
primary /プライマリ/プライマリー/
primavera /プリマベーラ;(It)春/プリマヴェーラ/
prime /プライム/
primer /プライマー/プリマー/
primera /プリメーラ/
primerate /プライムレート/
primetime /プライムタイム/
priming /プライミング/
primitive /プリミティブ/プリミティヴ/
primo /プリモ/
primrose /プリムローズ;桜草/
primula /プリムラ/
prince /プリンス/
princehotel /プリンスホテル/
princess /プリンセス/
princeton /プリンストン/
principal /プリンシパル/
principia /プリンキピア/
pringles /プリングルス/
print /プリント/
printable /プリンタブル/
printemps /プランタン;(Fr)春/
printer /プリンタ/プリンター/
printerbuffer /プリンタバッファ/
printercable /プリンタケーブル/
printerdriver /プリンタドライバ/
printerserver /プリンタサーバ/
printing /プリンティング/
printout /プリントアウト/
printserver /プリントサーバ/
printtshirt /プリントTシャツ/プリントＴシャツ/
printtshirts /プリントTシャツ/プリントＴシャツ/
prion /プリオン/
priori /プライオリ/
priority /プライオリティ/
priscilla /プリシラ/プリスキラ/
prism /プリズム/
prison /プリズン/
prisoner /プリズナー/
prius /プリウス;[商標]トヨタ/
privacy /プライバシー/プライヴァシー/
privacypolicy /プライバシーポリシー/
private /プライベート/
privateaddress /プライベートアドレス/
privatebrand /プライベートブランド/
privateip /プライベートIP/
privatelesson /プライベートレッスン/
prix /プリ;(Fr)賞/
prize /プライズ/
pro /プロ/
proama /プロアマ;proam/
probe /プローブ/
probing /プロービング/
problem /プロブレム/
proc /プロシジャ/
procaine /プロカイン/
procedural /プロシジュアル/プロシージャル/
procedure /プロシージャ/プロシジャ/手続き/
procedurecall /プロシジャ・コール/プロシジャコール/
proceeding /プロシーディング/プロスィーディング;<rare>/
proceedings /プロシーディングス/
process /プロセス/処理/
processcheese /プロセスチーズ/
processid /プロセスID/
processing /プロセッシング/
processor /プロセッサ/プロセッサー/
processorset /プロセッサセット/
procter /プロクター/
procyon /プロキオン/
produce /プロデュース/
producer /プロデューサー/
product /プロダクト/
production /プロダクション/
products /プロダクツ/
prof /プロフ;profile,professor/
profession /プロフェッション/
professional /プロフェッショナル/
professionalism /プロフェッショナリズム/
professor /プロフェッサー/
profile /プロフィール/プロファイル/
profiler /プロファイラ/
profiling /プロファイリング/
profit /プロフィット/利潤/
prog /プログラム/
progesteron /プロゲステロン/
progesterone /プロゲステロン/
progolf /プロゴルフ/
progolfer /プロゴルファー;pro golfer/
program /プログラム/算譜/
programable /プログラマブル/
programcounter /プログラムカウンタ;PC/
programer /プログラマ/プログラマー/
programers /プログラマーズ/
programfile /プログラムファイル/
programing /プログラミング/
programmability /プログラマビリティ/
programmable /プログラマブル/
programme /プログラム/
programmer /プログラマ/プログラマー/
programmers /プログラマーズ/
programming /プログラミング/
progre /プログレ;progressive (music|rock)/
progress /プログレス/進行/
progression /プログレッション/
progressive /プログレッシブ/プログレッシヴ/
progressiverock /プログレッシブロック/
project /プロジェクト/
projecter /プロジェクタ/
projection /プロジェクション/
projectleader /プロジェクトリーダー/
projectmanager /プロジェクトマネージャー/プロジェクトマネージャ/プロマネ/
projector /プロジェクター/プロジェクタ/
projectteam /プロジェクトチーム/
projet /プロジェ;仏語/
prokofiev /プロコフィエフ/
prolactin /プロラクチン/
proleague /プロリーグ;professional league/
proletariat /プロレタリア/プロレタリアート/
proline /プロリン;Pro/
prolog /プロログ/Ｐｒｏｌｏｇ/
prologue /プロローグ/
promenade /プロムナード/
prometheus /プロメテウス/
promethium /プロメチウム;[元素]61,Pm/
prominence /プロミネンス/
promiscuous /プロミスカス/
promo /プロモ;promotion/
promodel /プロモデル/
promote /プロモート/
promoter /プロモーター/
promotion /プロモーション/
promotionvideo /プロモーションビデオ/
prompt /プロンプト/
prompter /プロンプター/
pronto /プロント/
proof /プルーフ/証明/
prop /プロップ/
propaganda /プロパガンダ/
propagation /プロパゲーション/
propan /プロパン;(独語)/
propane /プロパン;C3H8/
propanegas /プロパンガス/
propanol /プロパノール/
propeller /プロペラ/
proper /プロパー/
property /プロパティ/プロパティー/
prophecy /プロフェシー/
prophet /プロフェット/
propion /プロピオン/
propolis /プロポリス/
proportion /プロポーション/∝/
proportional /プロポーショナル/∝/
proportionalfont /プロポーショナルフォント/
proposal /プロポーザル/
propose /プロポーズ/
proprietary /プロプライエタリ/
propto /∝/
propyl /プロピル;CH3CH2CH2-/
propylene /プロピレン/
proscenium /プロセニアム/
prosecco /プロセッコ/
proserpina /プロセルピナ/
proshop /プロショップ;pro shop/
prosper /プロスパー/
prost /プロスト/
prostaglandin /プロスタグランジン;PG/
protactinium /プロトアクチニウム;[元素]91,Pa/
protagoras /プロタゴラス/
protea /プロテア/
protease /プロテアーゼ/
protect /プロテクト/
protected /プロテクテッド/
protection /プロテクション/
protector /プロテクター/プロテクタ/
protein /プロテイン/タンパク質/
proteo /プロテオ/
proteoglycan /プロテオグリカン/
proteon /プロテオン/Ｐｒｏｔｅｏｎ/
protest /プロテスト/
protestant /プロテスタント/
protestantism /プロテスタンティズム/
proteus /プロテウス/
proto /プロト/
protocol /プロトコル/
protocolstack /プロトコルスタック/
proton /プロトン/
prototype /プロトタイプ/
prototyping /プロトタイピング/
proust /プルースト/
provence /プロヴァンス/プロバンス/
proves /├/┣/
provia /プロビア/
provider /プロバイダー/プロバイダ/
provitamin /プロビタミン/
provitamina /プロビタミンA;caroteneなど/
prowres /プロレス/
prowrestler /プロレスラー;professional wrestler/
prowrestling /プロレスリング;professional wrestling/
proxy /プロキシ/プロクシ/
proxyserver /プロキシサーバ/プロクシサーバ/
pruisen /プロイセン/
prussia /プロシア/
ps /ψ;psi/ＰＳ．/Ｐ．Ｓ．/ＰｏｓｔＳｃｒｉｐｔ/ポストスクリプト/PS./PostScript/プロセス/
ps/# /ＰＳ／#1/
psalm /サーム/
pseudo /シュード/
psi /ψ/プサイ/プシー/
psilocybin /シロシビン/サイロシビン/
psych /サイク/
psyche /プシュケ/プシュケー/プシケ/サイケ;<psychedelic/
psychedelic /サイケデリック/
psychic /サイキック/
psycho /サイコ/
psychodrama /サイコドラマ/
psychokinesis /サイコキネシス/
psychological /サイコロジカル/
psychology /サイコロジー/
psychopath /サイコパス/
psychotherapy /サイコセラピー/
psyllium /サイリウム;オオバコ/
psys /サイズ/PSY・S/
pt /白金/Platinum/
pteranodon /プテラノドン/
ptex /pTeX/
ptile /Pタイル;plastic tile/
ptolemaios /プトレマイオス/
ptr /ポインタ/
pu /プルトニウム/Plutonium/
pub /パブ/
public /パブリック/
publication /パブリケーション/パブリケイション/
publiccomment /パブリックコメント/
publicdomain /パブリックドメイン/
publicinvolvement /パブリックインボルブメント/
publicity /パブリシティ/公告/宣伝/
publicschool /パブリックスクール/
publicspace /パブリックスペース/
publish /パブリッシュ/
publisher /パブリッシャー/
publishing /パブリッシング/
pucci /プッチ/
puccini /プッチーニ/
puck /パック/
pudding /プリン/プディング/
pueraria /プエラリア/
puerta /プエルタ/
puerto /プエルト/
puertorico /プエルトリコ;.pr/
puff /パフ/
puffy /パフィー/パフィ/
pug /パグ/
puis /ピュイ;(Fr) それから/
puit /ピュイ;(Fr) 井戸/
puli /プーリー;犬/
pulitzer /ピュリッツァー/ピューリッツァー/
pull /プル/
pulldown /プルダウン/
pulldownmenu /プルダウンメニュー/
pulley /プーリー/プリー/
pulling /プリング/
pullover /プルオーバー/
pulltab /プルタブ/
pulltop /プルトップ/
pullup /プルアップ/
pulp /パルプ/
pulpfiction /パルプフィクション/
pulsar /パルサー/
pulse /パルス/
puma /ピューマ/
pump /ポンプ/
pumping /パンピング/
pumpkin /パンプキン/南瓜/
pumpkinpie /パンプキンパイ/
pumps /パンプス/
punc /パンク;puncture/
punch /パンチ/ポンチ;フルーツ-/
punchcard /パンチカード/
puncher /パンチャー/
punching /パンチング/
punchingball /パンチングボール/パンチボール/
punchout /パンチアウト/
punchperm /パンチパーマ;和製英語/
punchperma /パンチパーマ;和製英語/
puncture /パンク/
punjab /パンジャブ/
punk /パンク/
punkrock /パンクロック/
punt /パント/
pup /パップ/パプ/
puppet /パペット/
puppy /パピー/
purana /プラーナ/
purcell /パーセル/
pure /ピュア/
puree /ピューレ/ピュレ/
puremalt /ピュアモルト/
purewhite /ピュアホワイト/
purge /パージ/
purify /ピューリファイ/
purine /プリン/
purist /ピュアリスト/
puritan /ピューリタン/
purple /パープル/
purser /パーサ/パーサー/
push /プッシュ/
pushbutton /プッシュボタン/
pushing /プッシング/
pushkin /プーシキン/
pushphone /プッシュホン/
pushup /プッシュアップ/
pussy /プッシー/
put /プット/
putin /プーチン/
putt /パット/
putter /パター/
puttgolf /パットゴルフ/
putting /パッティング/
puyol /プジョール/
puzzle /パズル/
puzzlegame /パズルゲーム/
pygmalion /ピグマリオン/
pygmy /ピグミー/
pyjamas /パジャマ/
pylon /パイロン/
pylori /ピロリ/
pynchon /ピンチョン/
pyotr /ピョートル/
pyramid /ピラミッド/
pyramidal /ピラミダル/
pyran /ピラン/
pyrene /ピレン/
pyrenees /ピレネー/ピレネーズ;犬/
pyrethroid /ピレスロイド/
pyrex /パイレックス/
pyridine /ピリジン;C5H5N/
pyridinium /ピリジニウム/
pyridoxine /ピリドキシン/
pyrimidine /ピリミジン/
pyrine /ピリン/
pyrone /ピロン/
pyrrole /ピロール/
pyrrolin /ピロリン/
pyrroline /ピロリン/
pythagoras /ピタゴラス/
python /パイソン/
q /キュー/¶/
q&a /Ｑ＆Ａ/
qa /Ｑ＆Ａ/
qaddafi /カダフィ/
qanat /カナート/
qanun /カーヌーン/
qasba /カスバ/
qatar /カタール;.qa/
qazan /カザン/
qccircle /QCサークル;quality-control circle/
qibla /キブラ/
qic /QIC/
qomolangma /チョモランマ/珠穆朗瑪/
qrcode /QRコード;quick response code/
quadrille /カドリーユ/カドリール/
quaker /クエーカー/
qualia /クオリア/
qualify /クオリファイ/
qualite /カリテ;(Fr) 質/
quality /クオリティ/クオリティー/
quantas /カンタス/
quantifier /コンティファイア/
quantize /クォンタイズ/
quantum /カンタム;量子/
quark /クォーク/クオーク/
quarter /クォーター/クオーター/
quarterback /クォーターバック/
quartet /カルテット/
quartette /カルテット/
quartetto /カルテット/
quartier /カルティエ/カルチェ/カルチエ/
quartz /クオーツ/
quasar /クエーサー/
quate /クウェート;Kuwait?/
quatro /クアトロ/
quattro /クアトロ/
quaver /♪/
que /ク/ケ/
quebec /ケベック/
queen /クイーン/クィーン/
queens /クイーンズ/
queensize /クイーンサイズ/
queensland /クイーンズランド;豪州/
quel /ケル;仏語/
quena /ケーナ/
queneau /クノー/
quentin /クエンティン/クェンティン/カンタン/
query /クエリ/クエリー/問合せ/キュエリ;<rare>,原音からも遠い/
quesaisje /クセジュ;Que sais-je?/
queserasera /ケセラセラ;(西語)que sera sera/
quesnay /ケネー/
quest /クエスト/
questa /クエスタ/
question /クエスチョン/？/質問/
questionmark /クエスチョンマーク;？/
questo /クエスト/
quetzalcoatl /ケツァルコアトル/
queue /キュー/
queueing /キューイング/
quiche /キッシュ/
quick /クイック/クィック/
quickreference /クイックリファレンス/
quicksort /クイックソート/
quickstart /クイックスタート/
quicktime /クイックタイム/
quickturn /クイックターン;和製英語(flip turn)/
quijada /キハーダ/
quijote /キホーテ;Don Quijote/
quilt /キルト/
quilting /キルティング/
quin /クイン/
quincy /クインシー/
quine /クワイン/キーン/
quinn /クイン/
quinone /キノン/
quint /クイント/
quintet /クインテット/
quintetto /クインテット;(イタリア語)/
quinto /クイント/
quinton /クイントン/
quit /クイット/
quito /キト/
quixote /キホーテ;(英語綴) Don Quixote/
quiz /クイズ/
quo /クオ;ラテン語/
quocard /QUOカード;www.quocard.com/クオカード/
quolia /クオリア/
quot /クウォート/
quota /クォータ/クオータ/
quotation /クォーテーション/クオーテーション/
quote /クォート/クオート/クウォート/クォウト/“;opening/”;closing/‘;opening/’;closing/『』/
quran /クルアーン;Qur'an/コーラン/
r /ρ;rho/アール/р;er (cyrillic)/
r&b /リズム・アンド・ブルース/
r&d /Ｒ＆Ｄ/
ra /ラジウム/Radium/ラー/
rabat /ラバト/
rabaul /ラバウル/
rabbi /ラビ/
rabbit /ラビット/
rabelais /ラブレー/
rabi /ラビ/
raccoon /ラクーン;あらいぐま/
race /レース/
racecar /レースカー/
racequeen /レースクイーン;和製英語/レースクィーン/
racer /レーサー/
rachel /レイチェル/レーチェル/ラケル/
racine /ラシーヌ/
racing /レーシング/
racingcar /レーシングカー/
racingteam /レーシングチーム/
racism /レイシズム/
rack /ラック/
racket /ラケット/
rackmount /ラックマウント/
rackmounted /ラックマウント/
racoon /ラクーン;あらいぐま/
rada /ラーダ/レーダ/ラダ/
radar /レーダー/
radarsite /レーダーサイト/
radcliffe /ラドクリフ/
radetzky /ラデツキー/
radial /ラジアル/
radialtire /ラジアルタイヤ/
radian /ラジアン/
radiator /ラジエーター/ラジエータ/ラジエター/ラジエタ/
radical /ラジカル/ラディカル/
radicase /ラジカセ;radio-casette/
radicon /ラジコン;radio control/
radio /ラジオ/ラヂオ/レイディオ/
radio-casette /ラジカセ/
radiobotton /ラジオボタン/
radiobox /ラジオボックス/
radiobutton /ラジオボタン/
radiocasette /ラジオカセット/ラジカセ/
radiocm /ラジオCM/
radiodrama /ラジオドラマ/
radioname /ラジオネーム/
radiosity /ラジオシティ/
radish /ラディッシュ/
radium /ラジウム;[元素]88,Ra/
radon /ラドン;[元素]86,Rn/
raf /ラフ/
rafael /ラファエル/
rafe /レイフ/
raffaello /ラファエロ/
raffles /ラッフルズ/
rafflesia /ラフレシア/
raft /ラフト/
rafting /ラフティング/
raga /ラーガ/
ragdoll /ラグドール/
rage /レイジ/
raggae /レゲエ;※reggae?/
ragmat /ラグマット/
ragna /ラグナ/
ragnarok /ラグナロク;[北欧神話]神々の運命/
ragout /ラグー/
ragtime /ラグタイム/
rahmen /ラーメン;[建築]/
raid /レイド/
raiders /レイダース/
raikkonen /ライコネン/
rail /レール/レイル/
railgun /レールガン/
railroad /レイルロード/レールロード/
railway /レイルウェイ/レールウェイ/
raimonda /ライモンダ/
rain /レイン/
rainbow /レインボー/
rainbowbridge /レインボーブリッジ/
raincoat /レインコート/
rainer /ライナー/
rainey /レイニー/
rainier /レーニア/
rainmaker /レインメーカー/
raintire /レインタイヤ/
rainwear /レインウェア/
rainy /レイニー/
raise /レイズ/
raisin /レーズン/レザン;仏語/
raising /レイジング/
raison /レゾン;仏語/
raisondetre /レゾンデートル;(Fr) raison d'etre. 存在理由/レーゾンデートル/
raja /ラージャ/
rakel /ラケル/
rakhmaninov /ラフマニノフ/
rakko /ラッコ;(アイヌ語)/
ralf /ラルフ/
rally /ラリー/
ralph /ラルフ/
ralphlauren /ラルフローレン;Ralph Lauren/
ram /ラム/RAM/
rama /ラーマ/
ramadan /ラマダン/ラマダーン/
ramallah /ラマラ/
ramayana /ラーマーヤナ/
rambert /ランベール/
ramble /ランブル/
ramdisk /RAMディスク/
rameau /ラモー/
rami /ラミ/
ramirez /ラミレス/
ramjet /ラムジェット/
ramon /ラモン/
ramona /ラモーナ/
ramos /ラモス/
ramp /ランプ/
ramsay /ラムゼイ/ラムゼー/
ramses /ラムセス/
rana /ラナ/
randal /ランダル/
randall /ランダル/ランドール/
randolph /ランドルフ/
random /ランダム/
randomaccess /ランダムアクセス/
randomhouse /ランダムハウス;Random House/
randomize /ランダマイズ/
randomized /ランダマイズド/
randomjump /ランダムジャンプ/
randomwalk /ランダムウォーク/
randy /ランディ/ランディー/
range /レンジ/範囲/
rangehood /レンジフード;和製英語/
ranger /レンジャー/
rangers /レンジャーズ;[MLB]/
rangoon /ラングーン/
ranieri /ラニエリ/
rank /ランク/
rankdown /ランクダウン/
ranke /ランケ/
ranker /ランカー/
rankin /ランクイン;rank-in,和製英語/
ranking /ランキング/
rankup /ランクアップ/
ransel /ランドセル/
ranunculus /ラナンキュラス/
raoul /ラウール/ラウル/
rap /ラップ/
rape /レイプ/
raper /レイパー/
raphael /ラファエル/
rapid /ラピッド/
rapier /レイピア/
rapoport /ラパポート/
rapper /ラッパー/
rapport /ラポール;(Fr)関係/ラポート/
rapsodie /ラプソディ;仏語/ラプソディー/
rare /レア/
rarecase /レアケース/
rarecheese /レアチーズ;和製英語/
rarecheesecake /レアチーズケーキ;和製英語/
raregoods /レアグッズ/
rareitem /レアアイテム/
raremetal /レアメタル/
rascal /ラスカル/
rash /ラッシュ/
raskolnikov /ラスコーリニコフ/
raspberry /ラズベリー;キイチゴ/
rasputin /ラスプーチン/
rast /ラスト/
raster /ラスター/ラスタ/
rasterfile /ラスターファイル/
rat /ラット/
ratatouille /ラタトゥイユ/ラタトゥーユ/
ratchet /ラチェット/
rate /レート/
rather /ラザー/
rating /レーティング/
ratio /レシオ/
ration /レーション/
rattle /ラトル/
rau /ラウ/
raul /ラウル/
raum /ラウム;[商標]トヨタ/
rave /レイブ/レイヴ/
ravel /ラベル/ラヴェル/
raven /レイブン/レイヴン;Quoth the raven, 'Nevermore.'/
ravenna /ラヴェンナ/
ravioli /ラビオリ/
raw /ロー/
rawls /ロールズ/
ray /レイ/
rayban /レイバン;Ray-Ban. www.rayban.com/
rayleigh /レイリー/レーリー/
raymond /レイモンド/レーモン/レーモンド/レイモン/
raynaud /レイノー/
rayon /レーヨン/
raysol /レイソル;[Jリーグ]柏/
raytracing /レイトレーシング/
rb /ルビジウム/Rubidium/
rcs /RCS/
rdb /リレーショナルデータベース/関係データベース/
re /リ/レニウム/Rhenium/レ/
reach /リーチ/
reachable /リーチャブル/
reacitivate /リアクティベート/
reactance /リアクタンス/
reaction /リアクション/
reactivation /リアクティベーション/
reactive /リアクティブ/
reactor /リアクター/
read /リード/レッド;p,pp/
readable /リーダブル/
reader /リーダー/リーダ/
readers /リーダーズ/
readiness /レディネス/
reading /リーディング/
readings /リーディングス/
readme /README/
readonly /リードオンリー/
ready /レディ/
readymade /レディメイド/
reagan /レーガン/
real /リアル/レアル/
realism /リアリズム/
realisme /レアリスム/
realist /リアリスト/
realiste /レアリスト/
realistic /リアリスティック/
reality /リアリティ/リアリティー/
reallife /リアルライフ/
really /リアリー/
realmode /リアルモード/
realmoney /リアルマネー/
realplayer /リアルプレイヤー;www.real.com/リアルプレーヤー/
realtime /リアルタイム/
realtimesystem /リアルタイムシステム/
realworld /リアルワールド/
ream /リーム/
reamer /リーマー/
rear /リア/リヤ/
rearcar /リヤカー/
rearglass /リアガラス/
rearseat /リアシート/
rearwindow /リアウィンドウ/
reason /リーズン/
reasonable /リーズナブル/
reasoning /リーズニング/
reassemble /リアセンブル/
rebate /リベート/
rebecca /レベッカ/リベカ/
rebirth /リバース/
reboot /リブート/
rebound /リバウンド/
rebuild /リビルド/
recall /リコール/
receipt /レシート/
receive /レシーブ/
receiver /レシーバー/レシーバ/リシーバ;<rare>/
reception /レセプション/
receptor /レセプター/レセプタ/
recession /リセッション/
recette /ルセット;(Fr) レシピ/
recharge /リチャージ/
recipe /レシピ/
recipient /レシピエント;⇔donor/
recit /レシ;仏語/
recital /リサイタル/
recitativo /レチタティーヴォ/
reclam /レクラム/
reclining /リクライニング/
recliningchair /リクライニングチェア/
recliningseat /リクライニングシート/
recognition /リコグニション/認識/
recoil /リコイル/
recommen /レコメン;recommend(ed)/
recommend /リコメンド/
recompile /リコンパイル/
reconfirm /リコンファーム/
reconquista /レコンキスタ/
record /レコード/
recorder /レコーダー/レコーダ/リコーダー/
recording /レコーディング/
recordplayer /レコードプレーヤー/
records /レコーズ/
recordshop /レコードショップ/
recordya /レコード屋/
recoreco /レコレコ/
recover /リカバー/
recovery /リカバリー/リカバリ/レカバリ;<rare>/
recoverycd /リカバリCD/リカバリーCD/
recoverydisk /リカバリディスク/リカバリーディスク/
recreation /レクリエーション/
recruit /リクルート/
recruiter /リクルーター/
recruitment /リクルートメント/
rector /レクター/
recursion /リカージョン/
recursive /リカーシブ/再帰的/
recycle /リサイクル/
recycleshop /リサイクルショップ/
red /レッド/
redbull /レッドブル/
redcard /レッドカード/
redd /レッド/
redeye /レッドアイ/
redford /レッドフォード/
redhat /レッドハット/
redial /リダイアル/
redirect /リダイレクト/
redirection /リダイレクション/
redisplay /リディスプレイ/
redmond /レドモンド/
redo /リドゥ/
redon /ルドン/
redondo /レドンド/
redouble /リダブル/
redpepper /レッドペッパー/
redpurge /レッドパージ;red purge, 赤狩り/
redribbon /レッドリボン/
reds /レッズ/
redsox /レッドソックス;[MLB]Red Sox/
reduce /リデュース/
reducer /レデューサー/レデューサ/
reduction /リダクション/
redundant /リダンダント/
redzeppelin /レッドツェッペリン/
redzone /レッドゾーン/
reed /リード/
reef /リーフ/
reel /リール/
reengineering /リエンジニアリング/
reentrant /リエントラント/
reese /リーズ/
reeves /リーブス/リーヴス/リーブズ/
ref /レフ;reflex/
refactoring /リファクタリング/
refer /リファー/
referee /レフェリー/
refereestop /レフェリーストップ/
reference /リファレンス/レファレンス/参考文献/参照型/
referencer /リファレンサ/
referer /リファラ/リファラー/
refile /リファイル/リフィル;refill?/
refill /リフィル/
refinance /リファイナンス/
refine /リファイン/
reflation /リフレーション/
reflection /リフレクション/
reflective /リフレクティブ/
reflector /リフレクター/反射鏡/
reflex /リフレックス/レフレックス/
reflexion /リフレクション;=reflection/
reform /リフォーム/
refrain /リフレイン/ルフラン;仏語/
refresh /リフレッシュ/リフレシュ/
refreshrate /リフレッシュレート/
refund /リファンド/
refuse /リフューズ/拒否/
reg /レッグ/
regain /リゲイン/
regan /リーガン/
regatta /レガッタ/
regent /リーゼント/
regexp /正規表現/
reggae /レゲエ/
reggiano /レッジャーノ/
reggie /レジー/
reggio /レッジョ/
regi /レジ;<register/
regime /レジーム/
regina /レジーナ/レジナ/
reginald /レジナルド/
region /リージョン/
regional /リージョナル/
regionalism /リージョナリズム/
regioncode /リージョンコード/
regionfree /リージョンフリー/
regis /レジス/
regist /レジスト/
register /レジスタ/レジスター/レジ/
registrar /レジストラ/
registration /レジストレーション/
registry /レジストリ/レジストリー/
regnier /レニエ/
regression /リグレッション/
regret /リグレット/
regular /レギュラー/
regularcoffee /レギュラーコーヒー/
regulargasoline /レギュラーガソリン/
regularmember /レギュラーメンバー/
regularseason /レギュラーシーズン/
regularsize /レギュラーサイズ/
regulation /レギュレーション/
regulator /レギュレータ/レギュレーター/
rehabili /リハビリ;<rehabilitation/
rehabilitation /リハビリテーション/リハビリ/機能回復訓練/
reharsal /リハーサル;※rehearsal/
rehearsal /リハーサル/
reich /ライヒ/
reign /レイン/
reilly /ライリー/
reims /ランス/
reina /レイナ/
reincarnation /リインカーネーション/
reine /レーヌ;(Fr)王妃/
reiner /ライナー/
reinhard /ラインハルト/
reinhardt /ラインハルト/ラインハート/
reinhold /ラインホルト/
reino /レイノ/
reinstall /リインストール/
reis /ライス/レー/
reischauer /ライシャワー/
reissue /リイシュー/
reject /リジェクト/
relation /リレーション/
relational /リレーショナル/
relationaldatabase /リレーショナルデータベース/
relationaldb /リレーショナルデータベース/
relations /リレーションズ/
relationship /リレーションシップ/
relative /リラティブ/レラティブ/
relax /リラックス/
relaxation /リラクゼーション/
relaxing /リラクシング/
relay /リレー/
release /リリース/
relief /レリーフ;浮き彫り/リリーフ;救済/
religion /レリジョン/
reload /リロード/
relocatable /リロケータブル/
relocate /リロケート/
relocation /リロケーション/
rem /レム/
remain /リメイン/
remake /リメイク/リメーク/
remark /リマーク/
remaster /リマスター/
remastering /リマスタリング/
rembrandt /レンブラント/
remedy /レメディ/レメディー/
remember /リメンバー/
remi /レミ/
remind /リマインド/
reminder /リマインダー/リマインダ/
remix /リミックス/
remocon /リモコン/
remodel /リモデル/
remodeling /リモデリング/
remon /レモン/
remote /リモート/
remoteaccess /リモートアクセス/
remotehost /リモートホスト/
removable /リムーバブル/
remove /リムーブ/
remover /リムーバー/リムーバ/
remus /レムス/
remy /レミー/レミ/
ren /レン/
rena /レナ/リナ/
renaissance /ルネッサンス/ルネサンス/
rename /リネーム/
renard /ルナール/
renat /レナート/
renata /レナータ/
renate /レナーテ/
renato /レナート/
renaud /ルノー/
renault /ルノー/
render /レンダー/レンダ/
renderer /レンダラー/レンダラ/
rendering /レンダリング/
rendez-vous /ランデヴー/
rendezvous /ランデブー;(Fr)Rendez-vous/ランデヴー/
rendition /レンディション/
rene /ルネ/レネ/
renee /レニー/ルネ/レネ/
renew /リニュー/
renewal /リニューアル/
renewalopen /リニューアルオープン;和製英語/
renie /ルニエ/
renn /レン/
rennes /レンヌ/
rennie /レニー/
renny /レニー/
reno /Ｒｅｎｏ/
renoir /ルノワール/ルノアール/
renovation /リノベーション/
renown /レナウン/
rent /レント/
renta /レンタ/
rentacar /レンタカー;rent-a-car/
rentacycle /レンタサイクル;和製英語/
rental /レンタル/
rentalbbs /レンタルBBS/
rentalcd /レンタルCD/
rentalcgi /レンタルCGI/
rentalchat /レンタルチャット/
rentaldvd /レンタルDVD/
rentalease /レンタリース;和製英語(rental + lease)/
rentalserver /レンタルサーバ/レンタルサーバー/
rentalservice /レンタルサービス/
rentalshop /レンタルショップ/
rentalspace /レンタルスペース/
rentalstudio /レンタルスタジオ/
rentalvideo /レンタルビデオ/
renton /レントン/
renumber /リナンバー/レナンバ;<rare>/
repair /リペア/リペアー/
repeat /リピート/々/
repeater /リピーター/リピータ/
repertory /レパートリー/
replace /リプレース/
replacement /リプレースメント/
replay /リプレイ/
replica /レプリカ/
replication /レプリケーション/
replique /レプリーク/
reply /リプライ/返事/返信/
repo /ルポ;reportage/レポ;report/
report /レポート/リポート/
reportage /ルポルタージュ/
reporter /レポーター/リポーター/
reporting /レポーティング/
repository /リポジトリ/レポジトリ/
repost /リポスト/
repowriter /ルポライター;和製英語(reporter)/
reprint /リプリント/
reprise /リプリーズ/
republic /リパブリック/
request /リクエスト/要求/
requiem /レクイエム/
rerun /リラン/
res /レス;response/
rescan /リスキャン/
rescue /レスキュー/
research /リサーチ/
researcher /リサーチャー/
reserpine /レセルピン/
reserva /レゼルヴァ;(西語)/レゼルバ/
reservation /リザベーション/
reserve /リザーブ/レゼルブ;仏語/レザーブ/
reserved /リザーブド/
reserver /リザーバー/リザーバ/
reset /リセット/
resetbutton /リセットボタン/
resetswitch /リセットスイッチ/
residence /レジデンス/
residencial /レジデンシャル/
resident /レジデント/
resign /リザイン/
resin /レジン/
resist /レジスト/
resistance /レジスタンス/
resize /リサイズ/
reslie /レスリー/
resnais /レネ/
resolution /レゾリューション/リゾリューション/
resolve /リゾルブ/
resolver /リゾルバ/レゾルバ/
resonance /レゾナンス/
resonant /レゾナント/
resort /リゾート/
resorthotel /リゾートホテル/
resortmansion /リゾートマンション/
resource /リソース/
resourcefile /リソースファイル/
resourcemanager /リソースマネージャ/
respect /リスペクト/
respighi /レスピーギ/
responce /レスポンス;※response/
response /レスポンス/リスポンス/
ressentiment /ルサンチマン/
rest /レスト/
restart /リスタート/
restaurant /レストラン/
resthouse /レストハウス/
restore /リストア/
restroom /レストルーム/
result /リザルト/
resume /レジュメ;要約/レジューム;再開/リジューム/
retail /リテール/リテイル/
retainer /リテイナー/
retake /リテイク/
reti /レティ/
retinoid /レチノイド/
retinol /レチノール/
retire /リタイア/リタイヤ/
retirement /リタイアメント/
retort /レトルト/
retortcurry /レトルトカレー/
retortpouch /レトルトパウチ/
retouch /レタッチ/
retract /リトラクト/レトラクト/
retreat /リトリート/
retrieval /リトリーバル/検索/
retrieve /リトリーブ/
retriever /レトリバー/レトリーバー/リトリバー/リトリーバー/
retro /レトロ/
retrogame /レトロゲーム/
retrovirus /レトロウイルス/
retry /リトライ/
return /リターン/復帰/
returnable /リターナブル/
returnkey /リターンキー/RETURNキー/
returnmatch /リターンマッチ/
returns /リターンズ/
retyi /レティ/
reuben /ルーベン/
reunion /レユニオン;.re/
reusable /リユーザブル/
reuse /リユース/
reuter /ロイター/
reuters /ロイター;www.reuters.com/
reve /レーブ;(Fr)夢/レーヴ/
revenge /リベンジ/
revenger /リベンジャー/
reversal /リバーサル/
reversalfilm /リバーサルフィルム/
reverse /リバース/
reverseengineering /リバースエンジニアリング/
reversible /リバーシブル/
reves /リーブス/リーヴス/リーブズ/
review /レビュー/レヴュー/リビュー/リヴュー/
reviewer /レビュアー/レビューアー/レビューア/
revise /リバイズ/リヴァイズ/
revision /リビジョン/
revival /リバイバル/リヴァイヴァル/
revo /リボ;revolving/
revolution /レボリューション/
revolver /リボルバー/
revolving /リボルビング/
reward /リワード/
rewrite /リライト/
rex /レックス;王/
rey /レイ/
reyes /レジェス/
reykjavik /レイキャヴィク/レイキャビク;アイスランド(rek)/
reynard /レイナード/
reynaud /レイノー/
reynold /レイノルド/
reynolds /レイノルズ/
rezept /レセプト;(独)/
rf /ラザホージウム/Rutherfordium/
rh /ロジウム/Rhodium/
rhapsody /ラプソディ/ラプソディー/
rhea /レア/
rhein /ライン/レイン/
rheingau /ラインガウ/
rheinhessen /ラインヘッセン/
rheinland /ラインラント/
rhenium /レニウム;[元素]75,Re/
rheology /レオロジー/
rhetoric /レトリック/
rheumati /リウマチ;rheumatism/リューマチ/
rheumatisch /リウマチ;(蘭語)/リューマチ/
rheumatism /リウマチ/リューマチ/
rhinestone /ラインストーン/
rhizome /リゾーム/
rho /ρ/ロー/
rhoda /ローダ/
rhodan /ローダン/ロダン/
rhode /ロード/
rhodeisland /ロードアイランド;RI/
rhodes /ロウズ/ローズ/
rhodesia /ローデシア/
rhodium /ロジウム;[元素]45,Rh/
rhodopsin /ロドプシン/
rhodos /ロードス/ロドス/
rhone /ローヌ/
rhubarb /ルバーブ/
rhumba /ルンバ/
rhyme /ライム/
rhys /リス/
rhythm /リズム/
rhythmbox /リズムボックス/
rhythmic /リズミック/
rhythmical /リズミカル/
rhythmpattern /リズムパターン/
rhythmsection /リズムセクション/
rhythmtrack /リズムトラック/
ri /Rhode Island/ロードアイランド/
ria /リア/
rian /ライアン/
rias /リアス/
rib /リブ/
ribbon /リボン/
ribera /リベラ/
ribo /リボ;ribonucleic/
riboflavin /リボフラビン;V.B2/
ribose /リボース/
ribosome /リボソーム/
ribozyme /リボザイム/
ribroast /リブロース/
ribsteak /リブステーキ/
rica /リカ/
ricard /リカール/
ricardo /リカード/リカルド/
riccardo /リカルド/リッカルド/
ricci /リッチ/
rice /ライス/
ricecurry /ライスカレー/
ricepaper /ライスペーパー/
ricercare /リチェルカーレ/
rich /リッチ/リッシュ/リッヒ/
richard /リチャード/リヒャルト/リシャール/リカルド/
richards /リチャーズ/
richardson /リチャードソン/
riche /リシェ/
richelieu /リシュリュー/
richie /リッチー/リチー/
richman /リッチマン/
richmedia /リッチメディア/
richmond /リッチモンド/
richter /リヒター/リクター/リヒテル/
richtext /リッチテキスト/
ricin /リシン/
rick /リック/
ricken /リッケン/
rickettsia /リケッチア/
rickey /リッキー/
ricky /リッキー/
ricoeur /リクール/
ricoh /リコー;www.ricoh.co.jp/
ricotta /リコッタ/
riddell /リデル/
riddle /リドル/
ride /ライド/
rideau /リドー/
ridecymbal /ライドシンバル/
rider /ライダー/
riders /ライダーズ/ライダース/
ridge /リッジ/
ridgeway /リッジウェイ/
ridgway /リッジウェイ/
riding /ライディング/
riec /東北大学電気通信研究所;www.riec.tohoku.ac.jp/電気通信研究所/東北大通研/
riedel /リーデル/
riemann /リーマン/
rien /リアン/リエン/
riesling /リースリング/
riesman /リースマン/
riff /リフ;refrain/
rifle /ライフル/
riga /リガ/
rigatoni /リガトーニ/
right /ライト/→/右/
rightarrow /→/
rightfly /ライトフライ/
righthand /ライトハンド/
rightover /ライトオーバー;和製英語/
rights /ライツ/
rigid /リジッド/
rigoletto /リゴレット/
rihanna /リアーナ/
rika /リカ/
rikki /リッキー/
riku /リク/
rilke /リルケ/
rim /リム/
rimbaud /ランボー/
rime /ライム/
rimnet /リムネット;www.rim.or.jp/
rims /数理解析研究所;www.kurims.kyoto-u.ac.jp/京都大学数理解析研究所/
rimshot /リムショット/
rimskii /リムスキー/
rina /リーナ/リナ/
ring /リング/
ringer /リンガー/リンゲル/
ringing /リンギング/
ringo /リンゴ/
ringout /リングアウト/
rings /リングス/
ringside /リングサイド/
rink /リンク;{7,900,000}/
rinne /リンネ/
rinse /リンス/
rio /リオ/
riodejaneiro /リオデジャネイロ;Rio de Janeiro/
riogrande /リオグランデ;Rio Grande/
rioja /リオハ;スペイン/
rion /リオン/
riot /ライオット/
rip /リップ/
ripper /リッパー/
ripping /リッピング/
ripple /リップル/リプル/
risc /リスク/RISC/
rise /ライズ/
riser /ライザー/ライザ/
risercard /ライザーカード/ライザカード/
rising /ライジング/
risingsun /ライジングサン;Rising Sun(=Japan)/
risk /リスク/
riskfactor /リスクファクター/
riskhedge /リスクヘッジ/
riskmanagement /リスクマネージメント/
risky /リスキー/
risotto /リゾット/
risperidone /リスペリドン/
risto /リスト/
ristorante /リストランテ;(イタリア語)/
rit /リット/
rita /リタ/リータ/
ritardando /リタルダンド/
ritchie /リッチー/リチー/
ritenour /リトナー/
ritt /リット/
ritz /リッツ/
riva /リーバ/
rival /ライバル/ライヴァル/
rivas /リバス/
rive /リヴ/リブ/
river /リバー/リヴァー/
rivera /リベラ/リヴェラ/
riverfront /リバーフロント/
rivers /リバーズ/
riverside /リバーサイド/リヴァーサイド/
rivet /リベット/
riviera /リビエラ;イタリア/リヴィエラ/
riviere /リビエール/リヴィエール/
riyadh /リヤド/
riz /リズ/
rizotto /リゾット;※risotto/
rlogin /リモートログイン/
rms /Richard M. Stallman/リチャード・Ｍ・ストールマン/
rn /ラドン/Radon/
ro-maji /ローマ字/
roach /ローチ/
road /ロード/
roadbike /ロードバイク/
roadgame /ロードゲーム/
roadmap /ロードマップ/
roadmovie /ロードムービー/
roadpricing /ロードプライシング/
roadrace /ロードレース/
roadracer /ロードレーサー/
roadshow /ロードショー/ロードショウ/
roadster /ロードスター/
roadwork /ロードワーク/
roam /ローム/
roaming /ローミング/
roar /ロアー/ロア/
roast /ロースト/
roastbeef /ローストビーフ/
roastchicken /ローストチキン/
roaster /ロースター/
roastpork /ローストポーク/
rob /ロブ/
robber /ロバー/
robbie /ロビー/
robbins /ロビンス/
robby /ロビー/
robe /ローブ/
robert /ロバート/ロベルト/ロベール/
roberta /ロベルタ/ロバータ/
roberto /ロベルト/
roberts /ロバーツ/
robertson /ロバートソン/
robespierre /ロベスピエール/
robin /ロビン/ロバン/
robinhood /ロビンフッド;Robin Hood/
robinson /ロビンソン/
robo /ロボ/
robocup /ロボカップ;www.robocup.or.jp/
robot /ロボット/
robotanime /ロボットアニメ/
robotarm /ロボットアーム/
robotics /ロボティックス/ロボティクス/
robson /ロブソン/
robust /ロバスト/
roby /ロビー/
robyn /ロビン/
rocca /ロッカ/
roche /ロッシュ/
rochefort /ロシュフォール/
rochelle /ロシェル/
roches /ロッシュ/
rochester /ロチェスター/
rock /ロック/
rock'n /ロックン/
rockabilly /ロカビリー/
rockband /ロックバンド/
rockclimbing /ロッククライミング/
rockcrystal /ロッククリスタル/
rockefeller /ロックフェラー/
rocker /ロッカー/
rocket /ロケット/
rocketengine /ロケットエンジン/
rocketlauncher /ロケットランチャー/
rockets /ロケッツ/
rockfill /ロックフィル/
rockguitar /ロックギター/
rockice /ロックアイス/
rockies /ロッキーズ;[MLB]/
rocking /ロッキング/
rockingchair /ロッキングチェア/
rocknroll /ロックンロール;rock'n'roll/
rockridge /ロックリッジ/
rocks /ロックス/
rockwell /ロックウェル/
rockwool /ロックウール/
rocky /ロッキー/
rococo /ロココ/
rod /ロッド/
roddy /ロディ/
rode /ローデ/
roden /ローデン/
rodeo /ロデオ/
roderick /ロデリック/
rodger /ロジャー/
rodgers /ロジャース/ロジャーズ/
rodin /ロダン/
rodney /ロドニー/
rodolfo /ロドルフォ/
rodrigo /ロドリゴ/ロドリーゴ/
rodriguez /ロドリゲス/
roentgen /レントゲン/
roger /ロジャー/ロジェ;仏語/ラジャー;了解!/
rogers /ロジャース/ロジャーズ/
roget /ロジェ/
rogue /ローグ;@/
rohan /ローハン/ロアン/ロハン/
rohmer /ロメール/
rojas /ロハス/
rojo /ロホ/
roland /ローランド/ロラン/ローラン/
role /ロール/
roleplay /ロールプレイ/
roleplaying /ロールプレイング/
roleplayinggame /ロールプレイングゲーム/
rolex /ロレックス;www.rolex.com/
rolf /ロルフ/
roll /ロール/
rollback /ロールバック/
rollcabbage /ロールキャベツ;rolled cabbage/
rollcake /ロールケーキ;rolled cake/
roller /ローラー/
rollerball /ローラーボール/
rollerblade /ローラーブレード;[商標] NB:言い換え語"inline skate"/
rollercoaster /ローラーコースター/
rollerskate /ローラースケート/
rollin /ローリン/
rolling /ローリング/
rollingstones /ローリングストーンズ/
rollins /ロリンズ/
rollo /ロロ/
rollover /ロールオーバー/
rollpain /ロールパン/
rollpaper /ロールペーパー/
rollscreen /ロールスクリーン/
rollsroyce /ロールスロイス;Rolls-Royce/
rollup /ロールアップ/
rolly /ローリー/
rom /ロム/ROM/
roma /ローマ/羅馬/ロマ;=Gypsy/
romaclub /ローマクラブ;Club of Rome. www.clubofrome.org/
romain /ロマン/
romaji /ローマ字/
roman /ロマン/ローマン/ローマ字/
romana /ロマーナ/
romance /ロマンス/
romancecar /ロマンスカー/
romancegray /ロマンスグレー/
romancegrey /ロマンスグレー/
romancing /ロマンシング/
romancingstone /ロマンシングストーン/
romane /ロマーヌ/
romanesque /ロマネスク/
romania /ルーマニア;.ro/
romano /ロマノ/ロマーノ/
romanov /ロマノフ/
romantic /ロマンチック/ロマンティック/
romanticism /ロマンティシズム/ロマンチシズム/
romantist /ロマンチスト/ロマンティスト/
rome /ローマ/
romeo /ロミオ/
romero /ロメロ/
rommel /ロンメル/
romper /ロンパー/
rompers /ロンパース/
romulus /ロムルス/
romy /ロミー/
ron /ロン/
ronald /ロナルド/ロナウド/
ronde /ロンド/輪舞/
rondeau /ロンドー/
rondo /ロンド/
ronnie /ロニー/
ronny /ロニー/
ronsard /ロンサール/
rontgen /レントゲン/
roof /ルーフ/
roofgarden /ルーフガーデン/
roofrack /ルーフラック/
rooftop /ルーフトップ/
rook /ルーク/
rookie /ルーキー/
rooky /ルーキー/
room /ルーム/
roomcharge /ルームチャージ/
rooming /ルーミング/
roomlamp /ルームランプ/
roomlight /ルームライト/
roommate /ルームメイト/ルームメート/
roomnumber /ルームナンバー/
roomservice /ルームサービス/
roomshare /ルームシェア/
roop /ループ/
roosevelt /ルーズベルト/ルーズヴェルト/
root /ルート/√/根/
rootbeer /ルートビア/
rootdirectory /ルートディレクトリ/
roots /ルーツ/
rope /ロープ/
roper /ローパー/
ropeway /ロープウェイ/ロープウェー/
ropework /ロープワーク/
roquefort /ロックフォール/
roquentin /ロカンタン/
roro /ロロ/
rorschach /ロールシャッハ/
rorschachtest /ロールシャッハテスト/
rory /ローリー/
ros /ロス/
rosa /ローザ/ロサ/
rosado /ロサード/
rosalia /ロザリア/
rosalie /ロザリー/
rosalind /ロザリンド/
rosamunde /ロザムンデ/
rosanna /ロザンナ/
rosanne /ロザン/ロザンヌ/
rosario /ロザリオ/
rosch /ロッシュ/
rose /ローズ/ロゼ;仏語/ローゼ/
roseau /ロゾー/
rosegarden /ローズガーデン/
rosehip /ローズヒップ/
rosemary /ローズマリー/
rosenthal /ローゼンタール/
rosepink /ローズピンク/
rosered /ローズレッド/
rosetta /ロゼッタ/
rosette /ロゼット/ローゼット/
rosewine /ロゼワイン/
rosewood /ローズウッド/
rosie /ロージー/
rosin /ロジン/ロージン/
rosinante /ロシナンテ/
rosinbag /ロージンバッグ/ロジンバッグ/
ross /ロス/
rossby /ロスビー/
rossbywave /ロスビー波/
rossellini /ロッセリーニ/
rosser /ロッサー/
rossi /ロッシ/
rossignol /ロシニョール/
rossini /ロッシーニ/
rossiya /ロシア;Росий/
rosso /ロッソ/
rostand /ロスタン/
rostow /ロストウ/
rostropovich /ロストロポーヴィチ/ロストロポーヴィッチ/
rosy /ロージー/
rot /ロット/
rota /ロータ/
rotary /ロータリー/
rotaryclub /ロータリークラブ/
rotaryengine /ロータリーエンジン/
rotate /ローテート/
rotation /ローテーション/
rothenburg /ローテンブルク;Rothenburg ob der Tauber/
rothman /ロスマン/
rothmans /ロスマンズ/
rothschild /ロートシルト/
roti /ロティ/ロティー/
rotondo /ロトンド/
rotor /ローター/ロータ/
rotring /ロットリング;www.rotring.de/
rotta /ロッタ/
rotterdam /ロッテルダム/
roty /ロティ/
rouault /ルオー/
rouble /ルーブル;(貨幣単位)/
rouen /ルーアン/
rouge /ルージュ/
rough /ラフ/
roughplay /ラフプレー/ラフプレイ/
roughsketch /ラフスケッチ/
roulette /ルーレット/
round /ラウンド/
roundrobin /ラウンドロビン/
roundtrip /ラウンドトリップ/
roundup /ラウンドアップ/
rousseau /ルソー/
roussel /ルーセル/
route /ルート/
routemap /ルートマップ/
router /ルータ/ルーター/
routerid /ルータID/
routes /ルーツ/
routesales /ルートセールス/
routine /ルーチン/ルーティン/
routinework /ルーチンワーク/
routing /ルーティング/
routingtable /ルーティングテーブル/
roux /ルー/
rover /ローバー/
row /ロウ/
rowing /ローイング/
rowland /ローランド/
rox /ロックス/
roxy /ロキシー/
roy /ロイ/
royal /ロイヤル/ローヤル/ロワイヤル/ロワイアル/
royalalbert /ロイヤルアルバート/
royalcopenhagen /ロイヤルコペンハーゲン/
royalhotel /ロイヤルホテル/
royaljelly /ローヤルゼリー/ロイヤルゼリー/
royalpark /ロイヤルパーク/
royals /ロイヤルズ;[MLB]/
royalty /ロイヤリティー/ロイヤリティ/ロイヤルティ/ロイヤルティー/ローヤリティ/
roza /ローザ/
rs232c /ＲＳ−２３２Ｃ/
rssreader /RSSリーダー/RSSリーダ/
ru /ルテニウム/Ruthenium/
rubaiyat /ルバイヤート/
rubalkhali /ルブアルハリ;Rub Al Khali/
rubato /ルバート/
rubber /ラバー/
rubbersole /ラバーソール/
rubbersoul /ラバーソウル;Beatles/
rubble /ラブル/
ruben /ルーベン/
rubens /ルーベンス/
rubicon /ルビコン/
rubidium /ルビジウム;[元素]37,Rb/
rubik /ルービック/
rubikcube /ルービックキューブ;Rubik cube/
rubinstein /ルビンスタイン/ルビンシュタイン/ルービンシュタイン/
rubio /ルビオ/
ruby /ルビー/ルビ/紅玉/
rubyscript /rubyスクリプト/Rubyスクリプト/
ruck /ラック/リュック/
rucker /ラッカー/
rucksack /リュックサック/
rucola /ルッコラ/
rudbeckia /ルドベキア/
rudder /ラダー;舵/
rude /ルード/
rudi /ルーディ/ルディ/
rudiment /ルーディメント/
rudiments /ルーディメンツ/
rudolf /ルドルフ/
rudolph /ルドルフ/
rudy /ルディ/ルーディ/
rue /ルー/
ruff /ラフ/
rufino /ルフィーノ/
rufus /ルーファス/ルフス/
rug /ラグ/
rugby /ラグビー/
rugbyball /ラグビーボール/
rugger /ラガー/
ruggero /ルッジェーロ/
ruggiero /ルッジェーロ/
ruhr /ルール/
ruhuna /ルフナ;紅茶/
ruin /ルイン/ルーイン/
ruiz /ルイス/
rule /ルール/規則/
rulebook /ルールブック/
ruled /ルールド/
ruler /ルーラ/ルーラー/
ruleset /ルールセット/
rum /ラム/
rumania /ルーマニア/
rumba /ルンバ/
rumble /ランブル/Ｒｕｍｂｌｅ/
rumcoke /ラムコーク/
rummy /ラミー/
rumor /ルーマー/
rumour /ルーマー/
rump /ランプ/
rumraisIn /ラムレーズン/
run /ラン/
rundown /ランダウン/
rune /ルーン/
runlength /ランレングス/
runner /ランナー/
runners /ランナーズ/
runnershigh /ランナーズハイ;runner's high/
running /ランニング/
runningcost /ランニングコスト/
runninghigh /ランニングハイ/
runninghomerun /ランニングホームラン/
runningshirt /ランニングシャツ/
runningshirts /ランニングシャツ/
runtime /ランタイム/
rupee /ルピー/
rupert /ルパート/
rupiah /ルピア/
rural /ルーラル/
rush /ラッシュ/
rusher /ラッシャー/
rushhour /ラッシュアワー/
rusk /ラスク/
ruslan /ルスラン/
russ /ラス/ルス/
russe /リュス/ルッセ/リュッス/
russel /ラッセル/
russell /ラッセル/
russia /ロシア;.ru/露西亜/魯西亜/а;→cyrillic/б/в/г/д/е/ё/ж/з/и/к/й/м/н/л/п/с/о/р/т/у/ш/ф/х/ч/ц/ь/щ/я/ъ/ы/э/ю/
russian /ロシアン/ルシアン/ロシア語/
russianblue /ロシアンブルー/
russianroulette /ロシアンルーレット/
rust /ラスト/
rusticana /ルスティカーナ/
rusty /ラスティ/
rute /ルーテ/
ruth /ルツ/ルース/ルート/ルス/
ruthenium /ルチニウム;[元素]44,Ru/
rutherford /ラザフォード/
rutherfordium /ラザホージウム;[元素]104,Rf/
rutile /ルチル/
rutin /ルチン/
ruwer /ルワー/ルーヴァー/
rwanda /ルワンダ;.rw/
ryan /ライアン/
rye /ライ/
rythmique /リトミック;仏語/
s /σ;sigma/エス/с;es (cyrillic)/硫黄/Sulfur/秒/
s# /昭和#0年/
saab /サーブ/
saal /ザール;(独語)ホール/
saar /ザール/
saara /サーラ/
saarland /ザールラント/
sabado /サバト;(ポルトガル語)/
sabao /シャボン;(ポルトガル語)/
sabatini /サバティーニ/
sabbat /サバト;(蘭語)/
sabbath /サバス/サバト;(英語)/
sabbatical /サバティカル/
saber /サーベル/セイバー/
sabia /サビア/
sabina /サビーナ/
sabine /サビーヌ/ザビーネ/セービン/
sable /セーブル/サブレ/
sabot /サボ/
sabotage /サボタージュ/
sabre /サーベル/サーブル/
sabrina /サブリナ/
sachsen /ザクセン/
sack /サック/ザック/
sacrament /サクラメント/
sacramento /サクラメント/
sacrifice /サクリファイス/
sad /サッド/サド/
saddam /サダム/
saddle /サドル/
sade /サド/サド侯爵/Marquis de Sade/Donation Alphonse Francois de Sade/
sadism /サディズム/加虐趣味/嗜虐的趣味/加虐淫乱症/
sadist /サディスト/加虐趣味者/嗜虐的趣味者/
sadomaso /サドマゾ;sado-maso/
saens /サーンス/
safari /サファリ/
safaripark /サファリパーク/
safe /セーフ/
safeguard /セーフガード/
safemode /セーフモード/
safety /セーフティ/セーフティー/セイフティ/セイフティー/
safetybunt /セーフティバント;和製英語/セーフティーバント/
safetynet /セーフティネット/セーフティーネット/
safflower /サフラワー/
saffraan /サフラン;(蘭語)/
saffron /サフラン/
saga /サガ/サーガ/
sagan /サガン/
sage /セージ/
sagittarius /サジタリウス/
sagnier /サニエ/
sagrada /サグラダ/
sagradafamilia /サグラダファミリア;Sagrada Familia/
sahara /サハラ;.eh/
sahel /サヘル/
saibaba /サイババ/
said /サイード/セッド;<say/
sail /セール/
sailer /セイラー;帆船/ザイラー;(人名)/
sailing /セーリング/セイリング/
sailor /セーラー/
sailorcollar /セーラーカラー/
saint /セイント/セント/サン/
saintbernard /セントバーナード/
sainte /サント;仏語/
saintemilion /サンテミリオン;Saint-Emilion/
saintestephe /サンテステフ;Saint-Estephe/
saintexupery /サンテグジュペリ;Saint-Exupery/サン＝テグジュペリ/
saintgermain /サンジェルマン;Saint-Germain/
sainthelena /セントヘレナ;Saint Helena/
sainthonore /サントノーレ;(Fr) saint-honore/サントノレ/
saintjohns /セントジョーンズ;Saint Johns/
saintjulien /サンジュリアン;Saint-Julien/
saintlaurent /サンローラン/
saintlawrence /セントローレンス;Saint Lawrence/
saintlouis /セントルイス/サンルイ/
saintlucia /セントルシア;Saint Lucia (.lc)/
saintmarc /サンマルク;(Fr) Saint-Marc/
saintmichel /サンミッシェル;(Fr) Saint-Michel/
saintmoritz /サンモリッツ/
saintpaul /セントポール;Saint Paul/
saintpaulia /セントポーリア/
saintsaens /サンサーンス/サン=サーンス/
saintsebastien /サンセバスチャン;Saint Sebastien (ケーキ)/
sainttropez /サントロペ/
sainz /サインツ/
saipan /サイパン/
saison /セゾン/
sakari /サカリ/
sakha /サハ/
sakhalin /サハリン/
saki /サキ/
saku /サク/
sal /サル/
sala /サラ/サーラ/
salad /サラダ/
saladbar /サラダバー/
saladbowl /サラダボウル/サラダボール/
saladdressing /サラダドレッシング/
saladin /サラディン/サラディーン/
saladoil /サラダオイル/
salam /サラーム/
salamanca /サラマンカ/
salamander /サラマンダー/サラマンダ/サラマンドラ/
salami /サラミ/
salamis /サラミス/
salary /サラリー/
salaryman /サラリーマン/
salat /サラート/
sale /セール/
salem /セーラム;USA/セイラム/
salerno /サレルノ/
sales /セールス/
saleslady /セールスレディ/
salesman /セールスマン/
salespoint /セールスポイント/
salestalk /セールストーク;sales talk/
salgado /サルガド/
salicyl /サリチル/
salieri /サリエリ/
salim /サリム/
salinas /サリナス/
salinger /サリンジャー/
sallie /サリー/
sally /サリー/
salmon /サーモン/サルモン/
salmonella /サルモネラ/
salmonpink /サーモンピンク/
salome /サロメ/
salomon /サロモン/
salon /サロン/
salonconcert /サロンコンサート/
salonika /サロニカ/
saloon /サルーン/
salopette /サロペット/
salsa /サルサ/
salsasauce /サルサソース/
salt /ソルト/
saltlake /ソルトレイク;Salt Lake/ソルトレーク/
saltlakecity /ソルトレイクシティー;Salt Lake City, Utah, USA/ソルトレークシティー/ソルトレイクシティ/ソルトレークシティ/
salto /サルト/
salty /ソルティー/ソルティ/
saltydog /ソルティードッグ/ソルティドッグ/
salut /サリュー;仏語/
salute /サリュート/
salvador /サルバドール/サルバドル/サルヴァドール/
salvage /サルベージ/
salvatore /サルバトーレ/サルヴァトーレ/
salvia /サルビア/
salz /ザルツ/
salzburg /ザルツブルク/ザルツブルグ;※「ク」の方が正確/
sam /サム/
samantha /サマンサ/
samaranch /サマランチ/
samaria /サマリア/
samarium /サマリウム;[元素]62,Sm/
samarkand /サマルカンド/
samawah /サマワ;イラク/サマーワ/
samba /サンバ/
sambawhistle /サンバホイッスル/
sambo /サンボ/
same /セイム/
samen /ザーメン;(独)/
sami /サミ/サミー/
sammy /サミー/
samoa /サモア;.ws, (米領).as/
samosa /サモサ/
samovar /サモワール/
sample /サンプル/
samplecode /サンプルコード/
sampleprogram /サンプルプログラム/
sampler /サンプラー/
sampling /サンプリング/
samplingrate /サンプリングレート/
samsa /ザムザ/
samson /サムソン/
samsung /サムスン;(三星) www.samsung.com/三星/
samu /サム/
samuel /サミュエル/サムエル/
samuelson /サミュエルソン/サムエルソン/
samurnori /サムルノリ;(韓国語) sa mur nor i/
samy /サミー/
san /サン/
san-francisco /サンフランシスコ/
sana /サヌア/サナ/サーナ/
sanantonio /サンアントニオ;San Antonio/
sanatorium /サナトリウム/
sanborn /サンボーン/
sanchez /サンチェス/
sancho /サンチョ/
sanction /サンクション/
sanctuary /サンクチュアリ/サンクチュアリー/
sanctus /サンクトゥス/
sand /サンド/
sanda /サンダ/
sandakan /サンダカン/
sandal /サンダル/
sandalwood /サンダルウッド/
sandbag /サンドバッグ/
sandbeige /サンドベージュ/
sandbox /サンドボックス/
sander /サンダー/
sanders /サンダース/
sandiego /サンディエゴ;San Diego/サン・ディエゴ/
sandor /サンダー/
sandpaper /サンドペーパー/
sandra /サンドラ/
sandro /サンドロ/
sandwedge /サンドウェッジ/
sandwich /サンドイッチ/サンドウィッチ/
sandwitch /サンドイッチ;※sandwich/
sandy /サンディ/サンディー/
sanfrancisco /サンフランシスコ;San Francisco/サン・フランシスコ/
sanfrecce /サンフレッチェ;[Jリーグ]広島/
sanga /サンガ;[Jリーグ]京都/
sangiovese /サンジョヴェーゼ/
sangria /サングリア/
sani /サニ/
sanitary /サニタリー/
sanjose /サンノゼ/サンホセ;San Jose/
sanjuan /サンファン;San Juan/
sankaku /△/▲/
sankt /サンクト/
sanktpeterburg /サンクトペテルブルグ;Sankt-Peterburg/
sanmarino /サンマリノ;San Marino (.sm)/
sanmarinogp /サンマリノGP;[F1]San Marino/
sanpietro /サンピエトロ;San Pietro/
sanremo /サンレモ/
sanrio /サンリオ;www.sanrio.co.jp/
sans /サン/
sansalvador /サンサルバドル;San Salvador/
sanserif /サンセリフ;=sans serif/
sanskrit /サンスクリット/
sansserif /サンセリフ/
santa /サンタ/
santabarbara /サンタバーバラ;Santa Barbara/
santaclaus /サンタクロース;Santa Claus/
santacruz /サンタ・クルーズ/サンタクルーズ;Santa Cruz, ボリビア(vvi)/
santafe /サンタフェ;Santa Fe/
santafedebogota /サンタフェデボゴタ;Santa Fe de Bogota/
santamaria /サンタマリア;Santa Maria/
santamarta /サンタマルタ;Santa Marta, Colombia/
santamonica /サンタモニカ;Santa Monica/
santana /サンタナ/
sante /サンテ/
santi /サンティ/
santiago /サンチアゴ/サンティアゴ/サンチャゴ/
santodomingo /サントドミンゴ;Santo Domingo/
santorini /サントリーニ/
santoro /サントロ/
santos /サントス/
sanyo /サンヨー/
sanz /サンス/
saopaulo /サンパウロ;Sao Paulo, Brasil/
sap /SAP/サップ/
saphire /サファイア/青玉/
sapiens /サピエンス;ラテン語/
sapir /サピア/
saponin /サポニン/
sapp /サップ/
sapphire /サファイア/サファイヤ/
sapphireblue /サファイアブルー/
sappho /サッフォー/
sapporobeer /サッポロビール/
sara /サラ/セイラ/ザーラ/
saraband /サラバンド/
saraca /サラサ/
saracen /サラセン/
sarah /サラ/サラー/
sarai /サライ/
sarajevo /サラエボ/サラエヴォ/
sarangi /サーランギ/サランギ/
saranwrap /サランラップ;[商標]旭化成/
sarasate /サラサーテ/
sarasvati /サラスヴァティ/サラスヴァティー/
saratoga /サラトガ/
sarde /サルド/
sardegna /サルデーニャ/
sardes /サルデス/
sardine /サーディン/
sari /サリー/サリ/
sarin /サリン/
sarod /サロード/サロッド/
sartre /サルトル/
saruman /サルマン/
sasa /ササ/
sasan /ササン/
sash /サッシ/
sasha /サーシャ/
sasi /SASI/Shugart Associates System Interface;Shugart社開発のシステムインターフェイス/
sassoon /サスーン/
sat /土/
satan /サタン/
satchmo /サッチモ;=Louis Armstrong/
satellite /サテライト/
satelliteoffice /サテライトオフィス/
sati /サティ/サティー/
satie /サティ/
satijn /サテン;(ポルトガル語)/
satin /サテン/
satisfaction /サティスファクション/
saturation /サチュレーション/彩度/
saturday /サタデー/サタデイ/サタディ/
saturn /サターン/
satyros /サテュロス/
sauber /ザウバー/
sauce /ソース/
saucer /ソーサー/
saudade /サウダージ;(葡語) 哀愁/
saudi /サウジ/サウディ/
saudiarabia /サウジアラビア;Saudi Arabia (.sa)/サウディアラビア/
sauerkraut /ザワークラウト/
saul /サウル/ソール/
sauna /サウナ/
sauron /サウロン/
sausage /ソーセージ/
saussure /ソシュール/
saute /ソテー/
sauter /ソテー/
sauterne /ソーテルヌ/
sauvage /ソバージュ/
sauvignon /ソーヴィニヨン/ソーヴィニョン/
savanna /サバンナ/
savarin /サバラン/サヴァラン/
save /セーブ/
savedata /セーブデータ/
saveon /セーブオン;www.saveon.co.jp/
savepoint /セーブポイント;和製英語(saves)/
saver /セーバー/セイバー/セイヴァー/セーバ/
saving /セービング/
saviola /サビオラ/
savoia /サヴォイア/
savon /サボン;(Fr)石鹸/サヴォン/
savoy /サヴォイ/
saw /ソー/
sawallisch /サヴァリッシュ/
sawing /ソーイング/
sawyer /ソーヤ/
sax /サックス/
saxophone /サクソフォン/サキソフォン/
say /セイ/
sayonara /サヨナラ/
sayonarahit /サヨナラヒット/
sayonarahomerun /サヨナラホームラン;sayonara homerun/
sayonarahr /サヨナラホームラン;sayonara homerun/
saz /サズ/
sb /アンチモン/Antimony/
sc /スカンジウム/Scandium/サウスカロライナ/South Carolina/
scala /スカラ;-座(Teatro alla Scala)/
scalability /スケーラビリティ/スケイラビリティ/
scalable /スケーラブル/スケイラブル/
scalar /スカラ/スカラー/スケーラ/
scale /スケール/スケイル/
scaledown /スケールダウン;scale-down/
scalemerit /スケールメリット/
scaleout /スケールアウト/
scaler /スケーラ/スケーラー/スカラー;※scalar?/
scaleup /スケールアップ/
scalewindow /スケールウインドー/
scaling /スケーリング/
scalingfactor /スケーリングファクター/
scalp /スカルプ/
scan /スキャン/
scandal /スキャンダル/
scandalous /スキャンダラス/
scandinavia /スカンジナビア/
scandinavian /スカンジナビアン/
scandium /スカンジウム;[元素]21,Sc/
scanline /スキャンライン/
scanner /スキャナ/スキャナー/
scanning /スキャニング/
scanties /スキャンティ/スキャンティー/
scanty /スキャンティ/
scape /スケープ/
scapegoat /スケープゴート/
scar /スカー/
scarborough /スカボロー/
scare /スケア/
scarf /スカーフ/
scarface /スカーフェイス/スカーフェース/
scarlatti /スカルラッティ/
scarlet /スカーレット/
scat /スキャット/
scatolo /スカトロ;scatology/
scatology /スカトロジー/スカトロ/
scatterometer /スキャトロメーター/
scavenger /スカベンジャー/
scena /シェーナ/
scenario /シナリオ/
scenariowriter /シナリオライター/
scene /シーン/
scenery /シナリー/
scha /щ;cyrillic/
schanze /シャンツェ/
schedule /スケジュール/
scheduler /スケジューラ/スケジューラー/
scheduling /スケジューリング/
scheffe /シェッフェ/
scheherazade /シェエラザード/シェヘラザード/
schelling /シェリング/
schema /スキーマ/シェーマ;(独)/
schemata /スキーマタ/
schematic /スケマティック/
scheme /スキーム/Scheme/
schere /シェーレ/
scherzando /スケルツァンド/
scherzo /スケルツォ/
schiff /シフ/
schiheil /シーハイル;Schi Heil/
schiller /シラー/
schilling /シリング/
schilt /シュルト/シルト/
schizo /スキゾ;schizophrenia/
schlaf /シュラフ;(独語)Schlafsack/
schlegel /シュレーゲル/
schliemann /シュリーマン/
schmid /シュミット/
schmidt /シュミット/
schmitt /シュミット/
schnabel /シュナーベル/
schneider /シュナイダー/
schnorchel /シュノーケル;(独語)/
scholar /スカラ/スカラー/
scholarship /スカラシップ/
scholl /ショル/
schon /シェーン/
schonberg /シェーンベルク/
school /スクール/
schoolboy /スクールボーイ/
schoolbus /スクールバス/
schoolgirl /スクールガール/
schooling /スクーリング/
schoolmate /スクールメイト/スクールメート/
schoolzone /スクールゾーン/
schop /スコップ;(蘭語)/
schopenhauer /ショーペンハウアー/ショーペンハウエル/
schottky /ショットキー/
schroder /シュローダー/
schrodinger /シュレディンガー/シュレーディンガー/
schroeder /シュレーダー/シュローダー/
schubert /シューベルト/
schulz /シュルツ/
schumacher /シューマッハ/シューマッハー/
schuman /シューマン/
schumann /シューマン/
schumpeter /シュンペーター/
schwab /シュワブ/
schwann /シュワン/
schwartz /シュワルツ/シュヴァルツ/
schwarz /シュワルツ/シュヴァルツ/シュバルツ/
schwarzenegger /シュワルツェネッガー/シュワルツネッガー/
schwarzschild /シュヴァルツシルト/シュバルツシルト/シュワルツシルト/
schwarzwald /シュバルツバルト/シュヴァルツヴァルト/
schweitzer /シュバイツァー/シュヴァイツァー/シュバイツアー/
science /サイエンス/
scientific /サイエンティフィック/
scientist /サイエンティスト/
scimitar /シミター/
scintillation /シンチレーション/
scissor /シザー/
scitech /サイテック;sci-tech, science and technology/
sclereid /スクレレイド/
scola /スコラ/
scone /スコーン/
scoop /スクープ/スコップ;schop/
scooter /スクーター/
scope /スコープ/
scorch /スコーチ/
score /スコア/
scoreboard /スコアボード/
scorebook /スコアブック/
scorecard /スコアカード/
scorer /スコアラー/
scoria /スコリア/
scoring /スコアリング/
scorpio /スコーピオ;蠍座/
scorpion /スコーピオン/
scort /スコート/
scot /スコット/
scotch /スコッチ/Ｓｃｏｔｃｈ/
scotchwhiskey /スコッチウイスキー/
scotland /スコットランド/
scott /スコット/
scottish /スコティッシュ/
scottishfold /スコティッシュフォールド/
scotty /スコッティ/
scout /スカウト/
scouter /スカウター/
scoutman /スカウトマン;和製英語(recruiter)/
scramble /スクランブル/
scrambledegg /スクランブルエッグ/
scrambleegg /スクランブルエッグ;scrambled egg/
scrap /スクラップ/
scrap&build /スクラップ＆ビルド/
scrapbook /スクラップブック/
scraper /スクレーパー/スクレーパ/スケッパー;scraperの訛音?/
scrapie /スクレイピー/
scratch /スクラッチ/
scream /スクリーム/
screaming /スクリーミング/
screen /スクリーン/
screening /スクリーニング/
screensaver /スクリーンセーバー;screen saver/スクリーンセーバ/スクリーンセイバー/
screenshot /スクリーンショット/
screentone /スクリーントーン/
screw /スクリュー/スクリユー;<rare>/
screwball /スクリューボール/
screwdriver /スクリュードライバー/
scriabin /スクリャービン/
scrimmage /スクリメージ/
script /スクリプト/
scripter /スクリプター/スクリプタ/
scripting /スクリプティング/
scroll /スクロール/
scrollback /スクロールバック/
scrollbar /スクロールバー/
scrolledwindow /スクロール・ウィンドー/
scrub /スクラブ/
scrum /スクラム/
scsi /スカジー/SCSI/Small Computer System Interface/
scsiboard /SCSIボード/
scsicard /SCSIカード/
scsidevice /SCSIデバイス/
scsidrive /SCSIドライブ/
scsiinterface /SCSIインターフェイス;NB:Small Computer System Interface interface/SCSIインターフェース/
scuba /スキューバ/スクーバ/
scubadiving /スキューバダイビング/
scull /スカル/
sculpture /スカルプチャー/
scum /スカム/
sd /標準偏差;Standard Deviation/South Dakota/サウスダコタ/
sds /システムデザインサービス/
se /セレン/Selenium/┌;罫線/┏;太い罫線/
sea /シー/
seabass /シーバス;sea bass/
seafood /シーフード/
seafoodsalad /シーフードサラダ/
seagull /シーガル/
seajack /シージャック/
seal /シール/
sealer /シーラー/
sealing /シーリング/
seam /シーム/
seamless /シームレス/
seamonkey /シーモンキー/
sean /ショーン/
seaparadise /シーパラダイス;www.seaparadise.co.jp/
search /サーチ/探索/
searchengine /サーチエンジン/
searcher /サーチャー/サーチャ/
searchlight /サーチライト/
searle /サール/
seas /シーズ/
seaside /シーサイド/
season /シーズン/
seasoning /シーズニング/
seasonoff /シーズンオフ;和製英語(off-season)/
seat /シート/
seatbelt /シートベルト/
seating /シーティング/
seatknock /シートノック;和製英語/
seattle /シアトル/
seaworld /シーワールド/
sebastian /セバスチャン/セバスティアン/
sebastiano /セバスティアーノ/
sebastien /セバスチャン/セバスチアン/
sec /セック/
secant /セカント;正割/
seco /セコ/
secom /セコム;www.secom.co.jp/
second /セカンド/セコンド/″/秒/
secondary /セカンダリ/セカンダリー/
secondbase /セカンドベース/
secondclass /セカンドクラス/
secondfly /セカンドフライ/
secondgoro /セカンドゴロ;和製語(grounder)/
secondhouse /セカンドハウス/
secondlife /セカンドライフ/
secondopinion /セカンドオピニオン/
secret /シークレット/
secretary /セクレタリー/
secretservice /シークレットサービス/
sect /セクト/
section /セクション/§/
sectionalism /セクショナリズム/
sectionning /セクショニング/
sector /セクター/セクタ/
secure /セキュア/
security /セキュリティ/セキュリティー/
securityhole /セキュリティホール/
securitylevel /セキュリティレベル/セキュリティーレベル/
securitypolicy /セキュリティポリシー/セキュリティーポリシー/
sedan /セダン/
see /シー/
seed /シード/
seeds /シーズ/
seek /シーク/
seeker /シーカ/シーカー/
seektime /シークタイム/
seen /シーン/
seesaw /シーソー/
seesawgame /シーソーゲーム/
seethrough /シースルー/
sega /セガ/
segasaturn /セガサターン;[商標]/
segesta /セジェスタ/
segment /セグメント/
segmentation /セグメンテーション/
segovia /セゴビア/
segway /セグウェイ/
seidel /ザイデル/
seiko /セイコー/
seil /ザイル/
sein /ザイン;(独語)/
seine /セーヌ/
seismic /サイスミック/
select /セレクト/
selecter /セレクタ/
selection /セレクション/
selector /セレクター/セレクタ/
selectshop /セレクトショップ;和製英語/
selene /セレネ/セレーネ/
selenite /セレナイト/
selenium /セレニウム;[元素]34,Se/セレン;[元素]34,Se/
seleno /セレノ/
seles /セレス/セレシュ/
self /セルフ/Self/
selfcare /セルフケア/
selfcheck /セルフチェック/
selfcontrol /セルフコントロール/
selfcover /セルフカバー/
selfesthe /セルフエステ/
selfhelp /セルフヘルプ;self-help/
selfimage /セルフイメージ;self-image/
selfish /セルフィッシュ/
selfportrait /セルフポートレート/
selfpower /セルフパワー/
selfservice /セルフサービス/
selfstand /セルフスタンド/
selftimer /セルフタイマー/
selim /セリム/
selina /セリーナ/
seljuk /セルジューク/
sell /セル/
seller /セラー/
sellers /セラーズ/
selling /セリング/セーリング/
sellotape /セロテープ;[商標]/
sellvideo /セルビデオ;⇔レンタルビデオ/
selma /セルマ/
selmer /セルマー/
selva /セルバ/
semantic /セマンティック/
semantics /セマンティクス/意味/
semaphore /セマフォ/セマフォー/
semblance /センブランス/
semen /ザーメン/
semester /セメスター/
semi /ゼミ;seminar/セミ;-プロ/セミナー/
semiauto /セミオート;semi-automatic/
semicolon /セミコロン/
semiconductor /セミコンダクタ;半導体/セミコンダクター/
semicustom /セミカスタム/
semidouble /セミダブル/
semifinal /セミファイナル/
semihard /セミハード/
semillon /セミヨン/
semilong /セミロング;和製英語/
seminaire /セミネール/
seminar /セミナー/ゼミナール;(独語)/セミナ/ゼミ/
seminor /セミナー/
seminorm /セミノルム/
seminude /セミヌード/
semiorder /セミオーダー;和製英語/
semipro /セミプロ;semi-professional/
semisweet /セミスイート/
semmy /セーム/セミー/
semophore /セマフォ/
semplice /センプリーチェ/
sen /セン/
send /センド/
sender /センダ/センダー/
seneca /セネカ/
senegal /セネガル;.sn/
senior /シニア/
senna /セナ/センナ;[植物]/
senor /セニョール;(西語)/
senorita /セニョリータ;(西語)/
sens /サンス;仏語/センス/
sensation /センセーション/
sensational /センセーショナル/
sense /センス/
sensible /センシブル/
sensing /センシング/
sensitive /センシティブ/センシティヴ/
sensor /センサー/センサ/
sensual /センシュアル/
sent /セント/
sentence /センテンス/
sentiment /センチメント/
sentimental /センチメンタル/
sentimento /センチメント;(イタリア語)/
sentinel /センチネル/
seoul /ソウル/
separate /セパレート/
separates /セパレーツ/
separation /セパレーション/
separator /セパレータ/セパレーター/
sepatakraw /セパタクロー/
sepia /セピア/
september /セプテンバー/
septet /セプテット/
sequence /シーケンス/シークエンス/シークェンス/
sequencer /シーケンサー/シーケンサ/
sequencial /シーケンシャル/
sequent /シークエント/シーケント/
sequential /シーケンシャル/
sequoia /セコイア/
sera /セラ/
serafin /セラフィン/
seraphim /セラフィム;熾天使/
serbia /セルビア/
serena /セレナ/
serenade /セレナーデ/セレナード/
serenata /セレナータ/
serendipity /セレンディピティー/
serge /サージ/セルジュ/
sergeant /サージェント/
sergei /セルゲイ/
sergi /セルジ/
sergio /セルジオ/セルヒオ/セルジョ/
serial /シリアル/
serialise /シリアライズ/
serialize /シリアライズ/
serialnumber /シリアルナンバー/
serialport /シリアルポート/
serie /セリエ;(イタリア語)/セリー;仏語/
seriea /セリエA/
series /シリーズ/
serif /セリフ/
serine /セリン;Ser/
serio /セリオ;(イタリア語)/
serious /シリアス/
sermon /サーモン;説教/
serna /セルナ/
serotonin /セロトニン/
serpent /サーペント/
serra /セラ/セーラ/
servant /サーバント/
serve /サーブ/
server /サーバー/サーバ/サーヴァ/
serverdown /サーバーダウン/サーバダウン/
servermachine /サーバマシン/サーバーマシン/
serverrack /サーバーラック/サーバラック/
serverroom /サーバルーム/
service /サービス/サーヴィス/
serviceace /サービスエース/
servicearea /サービスエリア/
servicecenter /サービスセンター/
servicecentre /サービスセンター/
servicecounter /サービスカウンター/
serviceguide /サービスガイド/
serviceline /サービスライン/
servicelist /サービスリスト/
serviceman /サービスマン/
serviceprovider /サービスプロバイダ/
servicer /サービサー;債権管理回収業/
servicestation /サービスステーション/
servlet /サーブレット/
servo /サーボ/
sesame /セサミ/
sesamestreet /セサミストリート;(番組名) Sesame Street/
session /セッション/
sessionid /セッションID/
sessions /セッションズ/
set /セット/集合/
setback /セットバック/
sete /セテ/
seth /セト;(エジプト神話)/セツ;(聖書)/セス/
setlist /セットリスト/
setmenu /セットメニュー/
setminus /＼;LaTeX/
seton /シートン/
setplay /セットプレー/
setpoint /セットポイント/
setposition /セットポジション/
setservice /ネットサービス/
setter /セッター/
setting /セッティング/
setup /セットアップ/
setupper /セットアッパー/
seurat /スーラ/
seven /セブン/セヴン/
sevenbridge /セブンブリッジ/
seveneleven /セブンイレブン;www.sej.co.jp/
sevenstar /セブンスター/
seventeen /セブンティーン/セヴンティーン/
seventh /セブンス/
seventy /セブンティ/
severe /シビア/
sevilla /セビリア/セビーリャ/
sevres /セーブル/セーヴル/
sewing /ソーイング/
sewn /ソーン/
sex /セックス/Ｓ−ｅｘｐｒｅｓｓｉｏｎ/Ｓ式/
sexappeal /セックスアピール/
sexaroid /セクサロイド/
sexe /セクス;仏語/
sexfriend /セックスフレンド/セフレ/
sexless /セックスレス/
sexlife /セックスライフ/
sexology /セクソロジー/
sexp /S式/
sexscene /セックスシーン/
sextet /セクステット/
sexual /セクシャル/セクシュアル/性的/
sexualharassment /セクシャルハラスメント/セクハラ/
sexualis /セクスアリス;ラテン語/
sexuality /セクシュアリティ/セクシャリティ/セクシュアリティー/セクシャリティー/
sexy /セクシー/セクシィ/
seychelles /セイシェル;.sc/セーシェル/
seyfext /セイファート/
sf /スフォルツァンド;その音を特に強く/sforzando/
sfmagazine /SFマガジン;早川書房/
sforzando /スフォルツァンド/
sfz /スフォルツァンド;その音を特に強く/sforzando/
sg /シーボーギウム/Seaborgium/シリコン・グラフィックス/
sgi /シリコングラフィックス/
sgml /SGML/
sh /ш;sh (cyrillic)/Bシェル/
sha /ш;cyrillic/
shaba /シャバ/
shade /シェード/
shading /シェーディング/
shadow /シャドウ/シャドー/
shadowboxing /シャドーボクシング/シャドウボクシング/
shadowing /シャドーイング/シャドウイング/
shadowmask /シャドウマスク/シャドーマスク/
shaft /シャフト/
shaggy /シャギー/
shah /シャー/
shahrazad /シェエラザード/シェヘラザード/シェラザード/
shake /シェイク/
shakehand /シェイクハンド/シェークハンド/
shaker /シェーカー/シェイカー/
shakespeare /シェイクスピア/シェークスピア/
shakti /シャクティ/
shallow /シャロー/シャロウ/
shaman /シャーマン/
shamanism /シャーマニズム/
shambala /シャンバラ/
shampoo /シャンプー/
shampoodresser /シャンプードレッサー/
shampoohat /シャンプーハット/
shamrock /シャムロック/
shandy /シャンディ/シャンディー/
shane /シェーン/
shanghai /シャンハイ/上海/
shanghi /シャンハイ;※shanghai?/上海;※shanghai?/
shangrila /シャングリラ;Shangri-la/
shank /シャンク/
shannon /シャノン/
shanon /シャノン/
shanti /シャンティ;(ヒンディ語) 平和/
shanty /シャンティ/シャンティー/
shape /シェイプ/シェープ/
shaper /シェイパー/シェーパー/
shapeup /シェイプアップ/
shaping /シェイピング/
sharapova /シャラポワ/
share /シェア/
shared /シェアード/シェアド/
shareware /シェアウェア/
sharia /シャリア/シャリーア/
sharing /シェアリング/
shark /シャーク/
sharon /シャロン/
sharp /シャープ/♯;音楽記号のシャープ/＃;number/
sharpener /シャープナー/
sharpness /シャープネス/
sharppen /シャープペン;和製英語(mechanical pencil)/シャーペン/
sharppencil /シャープペンシル;和製英語(mechanical pencil)/シャーペン/
shattle /シャトル;※shuttle?/
shave /シェイブ/
shaver /シェーバー/
shaving /シェービング/
shavingcream /シェービングクリーム/
shawl /ショール/
she /シー/
shear /シアー/シャー/
shearing /シアリング/
sheat /シート/
sheba /シバ/
sheena /シーナ/
sheep /シープ/
sheepdog /シープドッグ/
sheet /シート/
sheetfeeder /シートフィーダ/シートフィーダー/
sheeting /シーティング/
sheets /シーツ/
sheffield /シェフィールド/
sheila /シーラ/シェイラ/シェーラ/
shekele /シェケレ/
sheldon /シェルダン/
shelf /シェルフ/
shell /シェル/
shelley /シェリー/
shellscript /シェルスクリプト/
shelter /シェルター/
shemale /シーメール/
shena /シーナ/
shepherd /シェパード/
sheraton /シェラトン/
sherbet /シャーベット/
sheriff /シェリフ/
sherlock /シャーロック/
sherpa /シェルパ/
sherry /シェリー/
sheryl /シェリル/
shiah /シーア/
shield /シールド/
shields /シールズ/
shift /シフト/
shiftchange /シフトチェンジ/
shifter /シフター/
shiftjis /シフトＪＩＳ/シフトJIS/
shiftkey /SHIFTキー/シフトキー/シフト・キー/
shiftlever /シフトレバー/
shihtzu /シーズー;shih tzu/
shikaku /□/■/
shilling /シリング/
shime /〆/
shin /シン/
shine /シャイン/
shingle /シングル/
shinguard /シンガード;すねあて/
shining /シャイニング/
shiny /シャイニー/
ship /シップ/
shipper /シッパー/
shipping /シッピング/
shiraz /シーラーズ/
shire /シャー/シャイア/
shirley /シャーリー/
shirring /シャーリング/
shirt /シャツ/
shirts /シャツ/
shishkebab /シシカバブ;shish kebab/
shit /シット/
shiva /シバ/
shoah /ショアー/
shock /ショック/
shocker /ショッカー/
shocking /ショッキング/
shockingpink /ショッキングピンク/
shockwave /ショックウェーブ/
shoe /シュー/
shoebox /シューボックス/
shoes /シューズ/
shoesbox /シューズボックス/
sholokhov /ショーロホフ/
shone /ショーン/
shoot /シュート/
shootball /シュートボール/
shootdown /シュートダウン/
shooter /シューター/
shooting /シューティング/
shootinggame /シューティングゲーム/
shootingstar /シューティングスター/
shop /ショップ/
shopbrand /ショップブランド/
shoppage /ショップページ/
shopper /ショッパー/
shopping /ショッピング/
shoppingbag /ショッピングバッグ/
shoppingcart /ショッピングカート/
shoppingcenter /ショッピングセンター/
shoppingmall /ショッピングモール/
shoppingplaza /ショッピングプラザ/
shoppingsite /ショッピングサイト/
shore /ショア/
short /ショート/
shortboard /ショートボード/
shortbound /ショートバウンド/
shortcake /ショートケーキ/
shortcut /ショートカット/
shortcutkey /ショートカットキー/
shortening /ショートニング/
shorter /ショーター/
shortfly /ショートフライ/
shortgoro /ショートゴロ;和製語(grounder)/
shorthair /ショートヘア/ショートヘアー/
shorthand /ショートハンド/
shorthole /ショートホール;par-3/
shortiron /ショートアイアン;8-/
shortpants /ショートパンツ/
shortpass /ショートパス/
shorts /ショーツ/
shortscale /ショートスケール/
shortshort /ショートショート;short-short/
shortsize /ショートサイズ/
shortsleeve /ショートスリーブ/
shortstay /ショートステイ/
shortstop /ショートストップ/
shortsword /ショートソード/
shorttrack /ショートトラック/
shorty /ショーティ/
shostakovich /ショスタコーヴィチ/
shot /ショット/
shotbar /ショットバー/
shotglass /ショットグラス/
shotgun /ショットガン/
should /シュド/シュッド/
shoulder /ショルダー/
shoulderbag /ショルダーバッグ/
shoulderstrap /ショルダーストラップ;肩紐/
shout /シャウト/
shovel /ショベル/シャベル/
shovelcar /ショベルカー/
show /ショー/ショウ/
showbusiness /ショービジネス/
showcase /ショーケース/ショウケース/
shower /シャワー/
showercurtain /シャワーカーテン/
showerhead /シャワーヘッド/
showerroom /シャワールーム/
showerscene /シャワーシーン/
showertoilet /シャワートイレ;和製英語/
showroom /ショールーム/ショウルーム/
showtime /ショウタイム/ショータイム/
showup /ショーアップ/ショウアップ/
showwindow /ショーウィンドウ/ショーウィンドー/ショウウィンドウ/
shredder /シュレッダー/シュレッダ/
shrimp /シュリンプ/
shrink /シュリンク/
shroedinger /シュレーディンガー/
shsh /щ;scha (cyrillic)/
shuffle /シャッフル/シャフル/
shuffling /シャッフリング/
shura /シューラ/
shut /シャット/
shutdown /シャットダウン/
shutout /シャットアウト/
shutter /シャッター/シヤッター;NB:企業名「三和-,東洋-,文化-」/
shutterbutton /シャッターボタン/
shutterchance /シャッターチャンス;和製英語/
shuttle /シャトル/
shuttlebus /シャトルバス/
shuttlecock /シャトルコック;バドミントンの羽根/
shy /シャイ/
shylock /シャイロック/
si /ケイ素/珪素/Silicon/シ/サイ/
siam /シャム/サイアム/
siamese /サイアミーズ/
sian /シアン/
sibelius /シベリウス/
siberia /シベリア/
siberian /シベリアン/サイベリアン/
siberianhusky /シベリアンハスキー/
sibip /シビップ/
sice /計測自動制御学会;Society of Instrument and Control Engineers. www.sice.or.jp/
sicilia /シチリア/
siciliana /シチリアーナ/
siciliano /シチリアーノ/
sicilien /シシリアン/
sicilienne /シシリエンヌ/
sick /シック/
sickhouse /シックハウス;和製英語/
sicp /ＳＩＣＰ(Structure and Interpretation of Computer Programs)/
sid /シド/セッションID/
siddhartha /シッダールタ/悉達多/
side /サイド/
sidearm /サイドアーム/
sideback /サイドバック/
sidebag /サイドバッグ/
sidebar /サイドバー/
sideboard /サイドボード/
sidebrake /サイドブレーキ/
sidebusiness /サイドビジネス/
sidecar /サイドカー/
sidedish /サイドディッシュ/
sidedoor /サイドドア/
sideline /サイドライン/
sideman /サイドマン/
sidemen /サイドメン/
sidemirror /サイドミラー/
sideout /サイドアウト/
sidepanel /サイドパネル/
sidepocket /サイドポケット/
sider /サイダー/
sidestep /サイドステップ/
sidetable /サイドテーブル/
sidethrow /サイドスロー;和製英語(sidearm)/
sidewalk /サイドウォーク/
sidewinder /サイドワインダー/
siding /サイディング/
sidney /シドニー/
siebold /シーボルト/
sieg /ジーク/ジーグ/
siegfried /ジークフリート/
siegmund /ジークムント/
siemens /シーメンス/ジーメンス/シーメンズ/ジーメンズ/
siemreap /シエムリアプ;Siem Reap, カンボジア(rep)/
siena /シエナ/
sienna /シエナ/
sierra /シエラ/シェラ/
sierracup /シェラカップ/
sierraleone /シエラレオネ;(Sierra Leone) .sl/シエラレオーネ/
sierranevada /シエラネバダ;Sierra Nevada/シェラネバダ/
siesta /シエスタ/
sieve /シーブ/
sievert /シーベルト/
sift /シフト/
sig /シグ/
sight /サイト/
sigma /σ/シグマ/
sigmarion /シグマリオン;[商標]NTT DoCoMo/
sigmoid /シグモイド/シグモイド関数/
sigmund /ジグムント/ジークムント/シグムンド/
sign /サイン/署名/
signal /シグナル/
signalhandler /シグナルハンドラ/
signaling /シグナリング/
signalling /シグナリング/
signature /シグネチャー/シグネチャ/シグニチャ/シグネイチャー/シグナチャー/
signball /サインボール/
signe /シーニュ/
signifiant /シニフィアン/
signifie /シニフィエ/
signin /サインイン;sign in/
signon /サインオン/
signori /シニョーリ/
signout /サインアウト;sign out/
signpen /サインペン;和製英語(felt pen)/
signplay /サインプレー;和製英語/
signup /サインアップ/
sihanouk /シアヌーク/
sikh /シーク/
sikkim /シッキム/
silane /シラン;SiH4/
silas /サイラス/
sildenafil /シルデナフィル;=viagra/
silence /サイレンス/
silencer /サイレンサー/
silent /サイレント/
silhouette /シルエット/
silica /シリカ/
silicagel /シリカゲル;silica gel/
silicon /シリコン/
silicone /シリコーン/
silicongum /シリコンゴム/
siliconvalley /シリコンバレー/
silk /シルク/
silkhat /シルクハット/
silkroad /シルクロード/
silkscreen /シルクスクリーン/
silky /シルキー/
sillitoe /シリトー/
silly /シリー/
silo /サイロ/
silt /シルト/
silva /シルヴァ/シルバ/
silver /シルバー/シルヴァー/
silverfox /シルバーフォックス/
silvergray /シルバーグレー/シルバーグレイ/
silvergrey /シルバーグレー/シルバーグレイ/
silverseat /シルバーシート/
silverstone /シルバーストーン/
silvester /シルベスター/シルベスタ/シルヴェスター/シルヴェスタ/
silvia /シルヴィア/シルビア/
silvio /シルヴィオ/
silvousplait /シルブプレ;S'il vous plait/
sim /シム/〜/
sima /シーマ/
simbox /シミュレーション・ボックス/
simcity /シムシティ;[ゲーム]/
simeon /シメオン/
simeone /シメオネ/
similar /∽/
simla /シムラ/
simm /ジム/
simmel /ジンメル/
simmonds /シモンズ/
simmons /シモンズ/
simms /シムズ/
simon /サイモン/シモン/
simonds /シモンズ/
simone /シモーヌ/シモーネ;(イタリア語)/
simonetta /シモネッタ/
simons /シモンズ/
simple /シンプル/
simplelife /シンプルライフ;和製英語/
simplex /シンプレックス/
simpson /シンプソン/
sims /シムズ/
simul /サイマル;simultaneous/
simulacre /シミュラークル;仏語/
simulate /シミュレート/シミュレイト/
simulation /シミュレーション/シミュレイション/
simulationgame /シミュレーションゲーム/
simulator /シミュレーター/シミュレータ/シミュレイタ;<rare>/
sin /サイン/シン;罪悪/
sina /シーナ/
sinai /シナイ/
sinatra /シナトラ/
since /シンス/
sindbad /シンドバッド/
sine /サイン/
sinecurve /サインカーブ/
sing /シング/
singapore /シンガポール;.sg/
singapura /シンガプーラ/
singer /シンガー/
singers /シンガーズ/
singersongwriter /シンガーソングライター/
singing /シンギング/
single /シングル/
singlebed /シングルベッド/
singleclick /シングルクリック/
singlecut /シングルカット/
singlehit /シングルヒット;和製英語(single)/
singlelife /シングルライフ;和製英語/
singlemother /シングルマザー/
singlequote /シングルクォート/‘;opening/’;closing/
singleroom /シングルルーム/
singles /シングルス/シングルズ/
singlesize /シングルサイズ/
singletask /シングルタスク/
singleton /シングルトン/
singleuser /シングルユーザー/シングルユーザ/
singspiel /ジングシュピール/
sinker /シンカー/
sinopoli /シノーポリ/
sinusoid /サイン曲線/
sion /シオン/
sip /シップ/
siphon /サイフォン/サイホン/
sippo /シッポ/
sir /サー/
siracusa /シラクサ/
siren /サイレン/セイレーン/シレン/
sirius /シリウス/
sirloin /サーロイン/
sirloinsteak /サーロインステーキ/
sirocco /シロッコ/
sisley /シスレー/
sistema /システマ/
sister /シスター/
sisters /シスターズ/
sistine /システィーナ/システィナ/
sisyphus /シジフォス/
sitar /シタール/
site /サイト/
sitelicence /サイトライセンス/
sitelicense /サイトライセンス/
sitemap /サイトマップ/
sitepolicy /サイトポリシー/
sitetop /サイトトップ/
sitter /シッター/
sitting /シッティング/
situation /シチュエーション/
siva /シヴァ/シバ/
sivuch /セイウチ;(露語)сивуч/
six /シックス/
sixnine /シックスナイン/
sixteen /シックスティーン/
sixth /シックスス/
sixty /シックスティ/シクスティ/
size /サイズ/
sizedown /サイズダウン;和製英語/
sizefree /サイズフリー;和製英語(one-size-fits-all)/
sizeup /サイズアップ;和製英語/
sizing /サイジング/
sizzle /シズル/
ska /スカ/
skate /スケート/
skateboard /スケートボード/スケボー/
skater /スケーター/
skaterink /スケートリンク;skating rink/
skaters /スケーターズ/
skating /スケーティング/
skatole /スカトール/
skeet /スキート/
skeleton /スケルトン/
skelton /スケルトン/
sketch /スケッチ/
sketchbook /スケッチブック/
skew /スキュー/
ski /スキー/
skid /スキッド/
skier /スキーヤー/
skill /スキル/
skillet /スキレット/
skillful /スキルフル/
skillup /スキルアップ;和製英語(upskill)/
skim /スキム/
skimmer /スキマー/
skimmilk /スキムミルク/
skimming /スキミング/
skin /スキン/
skincare /スキンケア/
skincream /スキンクリーム/
skindiving /スキンダイビング;素潜り/
skinhead /スキンヘッド/
skinlotion /スキンローション/
skinning /スキニング/
skins /スキンズ/
skinship /スキンシップ/
skip /スキップ/
skipper /スキッパー/
skiresort /スキーリゾート/
skirt /スカート/
skit /スキット/
skiware /スキーウェア/
skk /SKK/Simple Kana to Kanji conversion program/
skolem /スコーレム/
skopje /スコピエ/
skryabin /スクリャービン/
skull /スカル/
skunk /スカンク/スコンク;ボロ負け/
sky /スカイ/
skyblue /スカイブルー/
skydiver /スカイダイバー/
skydiving /スカイダイビング/
skylark /スカイラーク;ひばり/すかいらーく;www.skylark.co.jp/すかいら〜く/
skylight /スカイライト/
skyline /スカイライン/
skylla /スキュラ/
skymark /スカイマーク;www.skymark.co.jp/
skyperfectv /スカイパーフェクTV;www.skyperfectv.co.jp/SKY PerfecTV!/スカパー/
skythai /スキタイ/
skywalk /スカイウォーク/
skywalker /スカイウォーカー/
slab /スラブ/
slack /スラック/
slacks /スラックス/
slag /スラグ/
slalom /スラローム/
slam /スラム/
slamdunk /スラムダンク/
slammer /スラマー/
slang /スラング/
slapstick /スラップスティック/
slash /スラッシュ/／/
slashdot /スラッシュドット;slashdot.org/スラド/
slate /スレート/
slategray /スレートグレー/
slategrey /スレートグレー/
slaughter /スローター/
slav /スラヴ/スラブ/
slave /スレーブ/スレイブ/
slax /スラックス/
slay /スレイ/
slayer /スレイヤー/
slayers /スレイヤーズ/
sleep /スリープ/
sleeper /スリーパー/
sleeping /スリーピング/
sleepingbag /スリーピングバッグ/
sleeve /スリーブ/スリーヴ/
sleeveless /スリーブレス/
sleeves /スリーブス/スリーヴス/
sleigh /スレー/
slender /スレンダー/
slice /スライス/
slicealmond /スライスアーモンド/
slicecheese /スライスチーズ/
slicer /スライサー/スライサ/
slicing /スライシング/
slicker /スリッカー/
slide /スライド/
slideglass /スライドガラス/スライドグラス/
slider /スライダー/
sliderail /スライドレール/
slidermemory /スライダーメモリ/
slideshow /スライドショー/
sliding /スライディング/
slim /スリム/
slimane /スリマン/
slimcase /スリムケース/
slime /スライム/
slimming /スリミング/
slimsize /スリムサイズ/
slimtype /スリムタイプ/
slimup /スリムアップ/
sling /スリング/
slingshot /スリングショット/
slip /スリップ/
slipon /スリップオン;slip-on/スリッポン/
slipper /スリッパ/
slipstream /スリップストリーム/
slit /スリット/
slitdrum /スリットドラム/
sloan /スローン/
sloane /スローン/
slogan /スローガン/
slone /スローン/
slope /スロープ/
slot /スロット/
slotmachine /スロットマシン/スロットマシーン/
slotter /スロッター/
slovak /スロバキア;.sk/
slovakia /スロバキア/スロヴァキア/
slovenia /スロベニア;.si/
slovenija /スロヴェニア/
slow /スロー/スロウ/
slowball /スローボール/
slowcurve /スローカーブ/
slowdance /スローダンス/
slowdown /スローダウン/
slowfood /スローフード;slow food/
slowlife /スローライフ;slow life/
slowly /スローリー/
slowmotion /スローモーション/
slowness /スローネス/
slowpace /スローペース/
slowstep /スローステップ/
slowtempo /スローテンポ/
sludge /スラッジ/
slug /スラッグ/
slugger /スラッガー/
slum /スラム/
slump /スランプ/
slur /スラー/
sly /スライ/
sm /サマリウム/Samarium/
smack /スマック/
small /スモール/
smallsize /スモールサイズ/
smalltalk /Smalltalk/Ｓｍａｌｌｔａｌｋ/SmallTalk/
smap /スマップ/
smart /スマート/
smartball /スマートボール/
smartcard /スマートカード/
smartmedia /スマートメディア/
smash /スマッシュ/
smasher /スマッシャー/
smashhit /スマッシュヒット/
smclub /SMクラブ/
smeagol /スメアゴル/
smell /スメル/
smetana /スメタナ/
smile /スマイル/
smiley /スマイリー;顔文字 :-)/
smirnoff /スミルノフ/スミノフ/
smirnov /スミルノフ/
smith /スミス/
smithsonian /スミソニアン/
smog /スモッグ/
smoke /スモーク/
smokecheese /スモークチーズ/
smokedsalmon /スモークサーモン;smoked salmon/
smoker /スモーカー/
smokesalmon /スモークサーモン;smoked salmon/
smokin /スモーキン;smokin'/
smoking /スモーキング/
smoky /スモーキー/
smooth /スムーズ/スムース/
smoother /スムーサー/
smoothing /スムージング/
smplay /SMプレイ/
sn /スズ/錫/Tin/
snack /スナック/
snake /スネーク/
snakehead /スネークヘッド;蛇頭/
snap /スナップ/
snapbutton /スナップボタン/
snappy /スナッピー/
snapshot /スナップショット/
snare /スネア/
snaredrum /スネアドラム/
snatch /スナッチ/
snatcher /スナッチャー/
snd /サウンド;sound/
sndboard /サウンドボード/
sneak /スニーク/
sneaker /スニーカー/
snell /スネル/
sniff /スニフ/スニッフ/
sniffer /スニファ/スニファー/
snipe /スナイプ/
sniper /スナイパー/
snob /スノッブ/
snobbism /スノビズム/
snobo /スノボ;snowboard/
snoop /スヌープ/
snooping /スヌーピング/
snoopy /スヌーピー/
snooze /スヌーズ/
snore /スノア/
snorkel /シュノーケル/スノーケル/
snorkeling /シュノーケリング/スノーケリング/
snort /スノート/
snow /スノー/
snowball /スノーボール/
snowbird /スノーバード/
snowboard /スノーボード/
snowboarder /スノーボーダー/
snowboat /スノーボート/
snowdrop /スノードロップ/
snowshoe /スノーシュー/
snowtire /スノータイヤ/
snowwhite /スノーホワイト/
snufkin /スナフキン/
so /ソ/ソー/ソウ/
soap /ソープ/
soapland /ソープランド/
soapopera /ソープオペラ/
soarer /ソアラ/
soave /ソアーヴェ/
soccer /サッカー/
soccerball /サッカーボール/
soccerclub /サッカークラブ/
soccerteam /サッカーチーム/
sochi /ソチ/
social /ソーシャル/ソシアル/ソーシアル/
socialdance /ソシアルダンス/ソーシャルダンス/
socialengineering /ソーシャルエンジニアリング/
socialnetwork /ソーシャルネットワーク/
socialnetworking /ソーシャルネットワーキング/
socialworker /ソーシャルワーカー/
societe /ソシエテ/
society /ソサエティ/ソサエティー/
socio /ソシオ/
sociometry /ソシオメトリー/
socket /ソケット/
socks /ソックス/
socrates /ソクラテス/
soda /ソーダ/
sodium /ソディウム;Na/ナトリウム;[元素]11,Na/ソジウム/
sodom /ソドム/
sodomy /ソドミー/
sofa /ソファ/ソファー/
sofabed /ソファベッド/ソファーベッド/
sofia /ソフィア/
sofmap /ソフマップ;www.sofmap.com/
soft /ソフト/ソフトウェア/
softball /ソフトボール/
softbank /ソフトバンク;www.softbank.co.jp/
softcase /ソフトケース/
softcontact /ソフトコンタクト;soft contact lens/
softcontactlens /ソフトコンタクトレンズ/
softcream /ソフトクリーム;和製英語/
softdrink /ソフトドリンク/
softether /ソフトイーサ/
softfocus /ソフトフォーカス/
softhouse /ソフトハウス;和製英語/
softlanding /ソフトランディング/
softlens /ソフトレンズ;soft lens/
softly /ソフトリー/
softsm /ソフトSM/
softsynthe /ソフトシンセ;software synthesizer/
softtennis /ソフトテニス/
softtouch /ソフトタッチ/
software /ソフトウェア/ソフトウエア/
softwarestack /ソフトウェア・スタック/
softwear /ソフトウェア;※software?/
soho /ソーホー/
soir /ソワール;(Fr)夕/
soiree /ソワレ/
sol /ソル/ゾル/ソ/
solanin /ソラニン/
solar /ソーラー/
solarbattery /ソーラーバッテリー/
solarcar /ソーラーカー/
solarhouse /ソーラーハウス/
solaris /ソラリス/Ｓｏｌａｒｉｓ/Solaris/
solarisation /ソラリゼーション/
solarization /ソラリゼーション/
solarpanel /ソーラーパネル/
solarpoewr /ソーラーパワー/
solarsystem /ソーラーシステム/
sold /ソールド/ソルド/
soldier /ソルジャー/
soldiers /ソルジャーズ/
soldout /ソールドアウト/
sole /ソール/ソウル/
soleil /ソレイユ/
solemnis /ソレムニス/
solenoid /ソレノイド/
solfege /ソルフェージュ/
solid /ソリッド/
solidstate /ソリッドステート;solid-state/
solingen /ゾーリンゲン/
solist /ソリスト/
solitaire /ソリティア/
soliton /ソリトン/
solitude /ソリチュード/
sollers /ソレルス/
solo /ソロ/
soloalbum /ソロアルバム/
soloist /ソリスト/
sololive /ソロライブ/
solomon /ソロモン;.sb/
solon /ソロン/
solti /ショルティ/
solution /ソリューション/
solutions /ソリューションズ/
solver /ソルバー/ソルバ/
solzhenitsyn /ソルジェニーツィン/ソルジェニツィン/
soma /ソーマ/
somali /ソマリ/
somalia /ソマリア;.so/
soman /ソマン;(神経ガス)/
sombrero /ソンブレロ/
some /サム/ゾーム;ribosome,lysosome/
someday /サムデイ/サムディ/
somersault /サマーソルト/
somerset /サマセット/
something /サムシング/
sometime /サムタイム/
sommelier /ソムリエ/
sommelierknife /ソムリエナイフ/
sommer /ソマー/
son /サン/ソン;仏語/
sonar /ソナー/
sonata /ソナタ/
sonatine /ソナチネ/
sonde /ゾンデ/
sonet /ソネット;www.so-net.ne.jp/
song /ソング/
songbook /ソングブック/
songs /ソングス/
songwriter /ソングライター/
sonia /ソニア/ソーニャ/
sonic /ソニック/
sonicboom /ソニックブーム/
sonnet /ソネット/
sonny /ソニー/
sono /ソノ;(接頭辞:音)/
sonogram /ソノグラム/
sonority /ソノリティ/
sonosheet /ソノシート;和製英語(sound sheet)/
sontag /ソンタグ/
sony /ソニー/
sonya /ソーニャ/
sonymusic /ソニーミュージック;www.sonymusic.co.jp/
sonynews /ＳＯＮＹ ＮＥＷＳ/
sonyplaza /ソニープラザ;www.sonyplaza.com/
sonyrecord /ソニーレコード/
soon /スーン/
sophia /ソフィア/
sophie /ソフィー/ソフィ/ゾフィー;(独語)/
sophist /ソフィスト/
sophisticate /ソフィスティケート/
sophokles /ソポクレス/ソフォクレス/
sophy /ソフィー/
sopranino /ソプラニーノ/
soprano /ソプラノ/
sopranorecorder /ソプラノリコーダー/
sopranosax /ソプラノサックス/
sor /ソル/
sorbet /ソルベ;(Fr) シャーベット/
sorbit /ソルビット/
sorbitol /ソルビトール/
sorbonne /ソルボンヌ/
sorcerer /ソーサラー/
sorel /ソレル/
soriano /ソリアーノ/
sorkin /ソーキン/
sorrento /ソレント/
sorrow /ソロー/ソロウ/
sorry /ソーリー/
sort /ソート/
sorting /ソーティング/
sortstest /スポーツテスト/
sosa /ソーサ/
sostenuto /ソステヌート/
sotec /ソーテック;www.sotec.co.jp/
sothebys /サザビーズ;Sotheby's. www.sothebys.com/
soto /ソト/
souffle /スフレ/
soul /ソウル/
soulful /ソウルフル/
soulmusic /ソウルミュージック/
sound /サウンド/
soundboard /サウンドボード/
soundcard /サウンドカード/
soundchip /サウンドチップ/
sounddevice /サウンドデバイス/
sounddriver /サウンドドライバ/
soundeffect /サウンドエフェクト/
sounding /サウンディング/
soundnovel /サウンドノベル/
sounds /サウンズ/
soundscape /サウンドスケープ/
soundtrack /サウンドトラック/
soup /スープ/
soupcurry /スープカレー/
soupstock /スープストック/
sour /サワー/
source /ソース/
sourcecode /ソースコード/
sourcefile /ソースファイル/
sourcenext /ソースネクスト;www.sourcenext.com/
sourceprogram /ソースプログラム/
sourcream /サワークリーム/
sousaphone /スーザフォン/
south /サウス/
southampton /サウサンプトン/サザンプトン/
southcarolina /サウスカロライナ;SC/
southdakota /サウスダコタ;SD/
southeast /サウスイースト/
southern /サザン/
southerncross /サザンクロス/
southpaw /サウスポー/
southwest /サウスウエスト/サウスウェスト/
souvenir /スーベニア/スーベニール/スブニール;仏語/スーブニール;仏語/スヴニール/
sovet /ソビエト;совет/
soviet /ソビエト/ソヴィエト/ソ連/
sovkhoz /ソフホーズ/
sow /ソー/ソウ/
sox /ソックス;=socks/
soy /ソイ/
soyuz /ソユーズ/
sp /　;全角スペース/
spa /スパ/
spaak /スパーク/
space /スペース/　;全角スペース/□/スペイス/
spacebar /スペースバー/
spacecolony /スペースコロニー/
spacecraft /スペースクラフト/
spaceinvader /スペースインベーダー;[ゲーム]タイトー/
spacekey /スペースキー/SPACEキー/
spaceopera /スペースオペラ/
spacer /スペーサー/
spaceship /スペースシップ/
spaceshuttle /スペースシャトル/
spacing /スペーシング/
spade /スペード/スペイド/
spaghetti /スパゲティ/スパゲッティ/スパゲティー/スパゲッティー/
spain /スペイン;.es/Ｓｐａｉｎ/西班牙/
spaingp /スペインGP;[F1]/
spam /スパム/
spammail /スパムメール/
spammer /スパマー/
span /スパン/
spandex /スパンデックス/
spangle /スパンコール/スパングル/
spaniel /スパニエル/
spanish /スパニッシュ/スペイン語/
spank /スパンク/
spanking /スパンキング/
spanner /スパナ/
spanning /スパニング/
spar /スパー/
sparc /スパーク/Sparc/
spare /スペア/
sparekey /スペアキー/
sparemint /スペアミント/
sparerib /スペアリブ/
spareribs /スペアリブ/
sparetire /スペアタイヤ/
spark /スパーク/
sparkle /スパークル/
sparkling /スパークリング/
sparklingwine /スパークリングワイン/
sparring /スパーリング/
sparse /スパース/
sparta /スパルタ/
spasiba /スパシーバ;(露語)Спасибо/
spat /スパット/
spats /スパッツ/
spatter /スパッタ/
spattering /スパッタリング/
spatula /スパチュラ/スパテラ/
spaulding /スポルディング/
speak /スピーク/
speaker /スピーカー/スピーカ/
speaking /スピーキング/
spear /スピア/スピアー/
spearmint /スペアミント/
spec /スペック/仕様/
special /スペシャル/
specialguest /スペシャルゲスト/
specialist /スペシャリスト/
speciality /スペシャリティ/スペシャリティー/
specific /スペシフィック/
specification /スペシフィケーション/
specifier /スペシファイア/指示子/
spectacle /スペクタクル/
specter /スペクター/
spector /スペクトル/スペクター/
spectral /スペクトラル/スペクトル;spectre?/
spectre /スペクトル;仏語/
spectrogram /スペクトログラム/
spectrometer /スペクトロメータ;分光計/スペクトロメーター/
spectrum /スペクトラム/スペクトル/
speech /スピーチ/
speed /スピード/
speedball /スピードボール/
speeddown /スピードダウン;和製英語(slow-down)/
speedgun /スピードガン/
speedmeter /スピードメーター/
speedskate /スピードスケート/
speedtest /スピードテスト/
speedup /スピードアップ/
speedway /スピードウェイ/
speedy /スピーディー/スピーディ/
spell /スペル/
spellcheck /スペルチェック/
spellchecker /スペルチェッカー;spelling checker/スペルチェッカ/
spelling /スペリング/
spellmiss /スペルミス;和製英語(misspell)/
spelunker /スペランカー/
spencer /スペンサー/
spenser /スペンサー/
sperma /スペルマ/
sphere /スフィア/スフェア/
sphinx /スフィンクス/
sphynx /スフィンクス;猫/
spica /スピカ/
spice /スパイス/
spicy /スパイシー/
spider /スパイダー/
spider-man /スパイダーマン/
spiderman /スパイダーマン;正しくは"Spider-man"と綴る/
spiegel /シュピーゲル/
spielberg /スピルバーグ/
spike /スパイク/
spiker /スパイカー/
spiketire /スパイクタイヤ/
spill /スピル/
spillover /スピルオーバー/
spin /スピン/
spindle /スピンドル/
spine /スパイン/
spinel /スピネル/
spinet /スピネット/
spinglass /スピングラス/
spinics /スピニクス/
spinlock /スピンロック/
spinner /スピナー/
spinoff /スピンオフ;spin-off/
spinout /スピンアウト/
spinoza /スピノザ/
spiral /スパイラル/
spirit /スピリット/
spirits /スピリッツ/
spiritual /スピリチュアル/
spiritualism /スピリチュアリズム/
spiro /スピロ/
spirochaeta /スピロヘータ/
spirytus /スピリタス;アルコール96度のウォッカ/
spit /スピット/
spitfire /スピットファイア/
spitz /スピッツ;犬/
splash /スプラッシュ/
splatter /スプラッター/スプラッタ/
splay /スプレー;※spRay?/
splice /スプライス/
spline /スプライン/
split /スプリット/
splitter /スプリッタ/スプリッター/
splus /Splus/
spock /スポック/
spode /スポード/
spoil /スポイル/
spoiler /スポイラー/
spoke /スポーク/
spokesman /スポークスマン/
spokesperson /スポークスパーソン/
sponge /スポンジ/
spongecake /スポンジケーキ/
sponsor /スポンサー/
sponsored /スポンサード/
sponsorship /スポンサーシップ/
spoofing /スプーフィング/
spool /スプール/
spooler /スプーラ/
spoon /スプーン/
spore /スポア/
sport /スポーツ/
sportcaster /スポーツキャスター/
sports /スポーツ/スポーツ新聞/
sportsbag /スポーツバッグ/
sportscar /スポーツカー/
sportscaster /スポーツキャスター/
sportscenter /スポーツセンター/
sportsclub /スポーツクラブ/
sportsdrink /スポーツドリンク/
sportsfair /スポーツフェアー/
sportsgym /スポーツジム/
sportskite /スポーツカイト/
sportsman /スポーツマン/
sportsmanship /スポーツマンシップ/
sportsshop /スポーツショップ/
sportswear /スポーツウェア/
sporty /スポーティ/スポーティー/
spot /スポット/スパット;ボウリングの-/
spotlight /スポットライト/
spotter /スポッター/
sprawl /スプロール/
spray /スプレー/
spread /スプレッド/
spreadsheet /スプレッドシート/
sprechchor /シュプレヒコール/
sprecord /SPレコード/
sprice /スプライス;※splice?/
spriggan /スプリガン/
spring /スプリング/
springboard /スプリングボード/
springer /スプリンガー/
springs /スプリングス/
sprinkler /スプリンクラー/
sprint /スプリント/
sprinter /スプリンター/
sprite /スプライト/
sprout /スプラウト/
spuit /スポイト;(蘭語)/
spulse /エスパルス;[Jリーグ](S-pulse) 清水/
spumante /スプマンテ/
spumoni /スプモーニ/
spur /シュプール/スパー/
spurt /スパート/
sputnik /スプートニク/
spy /スパイ/
spyware /スパイウェア/
sq /□/■/
sqrt /√/
squalane /スクワラン;C30H62/
squalene /スクワレン;C30H50/スクアレン/
squall /スコール/
square /スクウェア/スクエア/スクェア/■/□/
squaredance /スクエアダンス/
squareenix /スクウェアエニックス;www.square-enix.com/スクウェア・エニックス/SQUARE ENIX/
squash /スカッシュ/
squashing /スカッシング関数/
squat /スクワット/
squeeze /スクイーズ/スクイズ/
sr /ストロンチウム/Strontium/ステラジアン;立方角の単位,SI基本単位/
sra /Software Research Associate,Inc./
src /ソース/
srcfile /ソースファイル/
srijayawardenepurakotte /スリジャヤワルダナプラコッテ;Sri Jayawardenepura Kotte (スリランカの首都)/
srilanka /スリランカ;.lk/
srinagar /スリナガル;インド(sxr)/
ss /§/
sseki /Ｓ席/
ssize /Sサイズ/Ｓサイズ/
sssize /SSサイズ/ＳＳサイズ/
st /サン;St. (saint)/
stab /スタブ/
stabatmater /スターバトマーテル/
stabiliser /スタビライザー/スタビライザ/
stability /スタビリティ/
stabilizer /スタビライザー/スタビライザ/
stable /ステーブル/
staccato /スタッカート/
stack /スタック/
stackable /スタッカブル/
stackframe /スタックフレーム/
stacking /スタッキング/
stackobject /スタック・オブジェクト/
stackpointer /スタック・ポインタ/
stacy /ステイシー/
stadium /スタジアム/
stadiumjumper /スタジアムジャンパー/スタジャン/
stael /スタール/
staff /スタッフ/
stafford /スタッフォード/スタフォード/
staffroll /スタッフロール/
stage /ステージ/
stagflation /スタグフレーション/
staging /ステージング/
stained /ステンド/
stainedglass /ステンドグラス/
staines /ステイン/ステインズ/
stainless /ステンレス/
stainlesssteel /ステンレススチール/ステンレススティール/
stair /ステア/
stake /ステーク/ステーキ;※steak?/
stakeholder /ステークホルダー/
stakes /ステークス/
stale /ステイル/
stalin /スターリン/
stalingrad /スターリングラード;現Volgograd/
stalk /ストーク/
stalker /ストーカー/
stalking /ストーキング/
stall /ストール/
stallman /ストールマン/
stallon /スタローン/
stamen /スタメン;<和製英語 starting member/
stamina /スタミナ/
stamp /スタンプ/
stamper /スタンパー/
stamping /スタンピング/
stamprally /スタンプラリー;和製英語/
stan /スタン/
stance /スタンス/
stand /スタンド/
standalone /スタンドアロン/スタンドアローン/
standard /スタンダード/標準/
standardnumber /スタンダードナンバー/
standards /スタンダーズ/
standby /スタンバイ/スタンドバイ/
standcollar /スタンドカラー/
standing /スタンディング/
standingovation /スタンディングオベーション/
standoff /スタンドオフ/
standplay /スタンドプレー;和製英語(grandstand)/スタンドプレイ/
standup /スタンドアップ/スタンダップ/
stanford /スタンフォード/スタンフォード大学/
stanislav /スタニスラフ/
stanislaw /スタニスワフ/スタニスラフ/
stanley /スタンリー/スタンレー/スタンリ/
stanza /スタンザ/
staple /ステープル/
stapler /ステープラー/
star /スター/★/☆/＊/STAR/
starboard /スターボード/
starbucks /スターバックス;www.starbucks.com/
starch /スターチ/
stardom /スターダム/
stardust /スターダスト/
starfruit /スターフルーツ/
starfruits /スターフルーツ/
stark /スターク/
starlight /スターライト/
starocean /スターオーシャン/
starr /スター/
starruby /スタールビー/
stars /スターズ/
starship /スターシップ/
start /スタート/
startbit /スタートビット/
startbutton /スタートボタン/
startdash /スタートダッシュ;和製英語/
starter /スターター/スタータ/
starterkit /スターターキット/スタータキット/
starting /スターティング/
startinggrid /スターティンググリッド/
startingmember /スターティングメンバー;和製英語(starting lineup)/
startline /スタートライン/
startmenu /スタートメニュー/
startpage /スタートページ/
startrek /スタートレック/
startup /スタートアップ/
starwars /スターウォーズ/
stat /スタット/
state /ステート/ステイト/
stateful /ステートフル/
statefull /ステートフル;※stateful?/
stateless /ステートレス/
statement /ステートメント/ステイトメント/文/
states /ステイツ/ステーツ/
static /スタティック/静的/
statice /スターチス/
staticlink /スタティックリンク/
statics /スタティックス/
statin /スタチン/
station /ステーション/ステイション/
stationary /ステーショナリー;静止した/
stationery /ステーショナリー/
stationwagon /ステーションワゴン/
status /ステータス/ステイタス/
statusbar /ステータスバー/
statussymbol /ステータスシンボル/
stay /ステイ/スティ/
stayer /ステイヤー/
stdin /標準入力/
stdout /標準出力/
steady /ステディ/
steak /ステーキ/
steal /スチール/スティール/
stealth /ステルス/
steam /スチーム/
steambath /スチームバス/
steamer /スチーマー/
stearin /ステアリン/
steed /スティード/
steel /スチール/スティール/
steeldrum /スチールドラム/スティールドラム/
steelguitar /スチールギター/スティールギター/
steelpan /スティールパン/スチールパン/
steelpipe /スチールパイプ/
steely /スティーリー/
steer /ステア/
steering /ステアリング/
stefan /ステファン/シュテファン/
stefania /ステファニア/
stefanie /ステファニー/
stefano /ステファノ/
stegosaurus /ステゴサウルス/
stein /シュタイン/
steiner /シュタイナー/スタイナー/
steinway /スタインウェイ/
steivie /スティービー/
stella /ステラ/
stello /ステロ/
stem /ステム/シュテム/
stemilion /サンテミリオン;Saint-Emilion/
sten /ステン/
stencil /ステンシル/
stendhal /スタンダール/
stent /ステント/
step /ステップ/ステップ応答/ステップ関数/
stephan /シュテファン/ステファン/スティーブン/
stephane /ステファン/ステファーヌ/
stephanie /ステファニー/
stephanos /ステファノ/
stephen /ステファン/シュテファン/スティーブン/スティーヴン;(英)/ステパノ/
steppe /ステップ/
stepper /ステッパー/
stepping /ステッピング/
steps /ステップス/
stepsize /ステップサイズ/
stepup /ステップアップ/
steradian /ステラジアン;sr/
stereo /ステレオ/
stereogram /ステレオグラム/
stereosound /ステレオサウンド/
stereotype /ステレオタイプ/
sterling /スターリング/スターリン/
sterne /スターン/
steroid /ステロイド/
steroidhormone /ステロイドホルモン;steroid hormone/
sterol /ステロール/
stestephe /サンテステフ;Saint-Estephe/
steve /スティーブ/スティーヴ/
steven /スティーブン/スティーヴン/
stevenson /スティーブンソン/スティーヴンソン/スティーヴンスン/スチーブンソン/
stevia /ステビア/
stevie /スティービー/スティーヴィー/
stew /シチュー/
steward /スチュワード/
stewardess /スチュワーデス/
stewart /スチュワート/
stibium /アンチモン;[元素]51,Sb/
stick /スティック/ステッキ/スティク/
sticker /ステッカー/
sticks /スティックス/
stieglitz /スティグリッツ/スティーグリッツ/
stiffness /スチフネス/
stiglitz /スティグリッツ/
stiletto /スティレット/
still /スティル/スチル/スチール/
stillcamera /スチルカメラ/
stina /スティーナ/
sting /スティング/
stingray /スティングレイ/スティングレー/
stirling /スターリング/
stitch /ステッチ/スティッチ/
stjulien /サンジュリアン;Saint-Julien/
stk /STk/
stlouis /セントルイス;St.Louis/
stoa /ストア/
stock /ストック/
stocker /ストッカー/
stockhausen /シュトックハウゼン/
stockholm /ストックホルム/
stocking /ストッキング/
stockings /ストッキング/
stockoption /ストックオプション/
stockyard /ストックヤード/
stoic /ストイック/
stoke /ストーク/
stokes /ストークス/
stole /ストール/
stollen /シュトーレン;(独)クリスマスケーキ/シュトレン/
stolon /ストロン/
stomach /ストマック/
stone /ストーン/
stonecircle /ストーンサークル/
stonehenge /ストーンヘンジ/
stones /ストーンズ/
stool /スツール/
stop /ストップ/
stopbit /ストップビット/
stopmotion /ストップモーション/
stopper /ストッパー/
stopwatch /ストップウォッチ/
stopword /ストップワード/
storage /ストレージ/ストーレジ;<rare>/
storagedevice /ストレージデバイス/
storagemedia /ストレージメディア/
store /ストア/ストアー/
stored /ストアド/
storethrough /ストアスルー/
storey /ストーリー/ストーリィ/
stories /ストーリーズ/
storm /ストーム/シュトルム;人名/
stormbringer /ストームブリンガー/
storming /ストーミング/
stormy /ストーミー/
story /ストーリー/ストーリ/
storyteller /ストーリーテラー/
storytelling /ストーリーテリング/
stout /スタウト/
stove /ストーブ/ストーヴ/
stoveleague /ストーブリーグ/
stradivari /ストラディバリ/ストラディヴァリ/
stradivarius /ストラディバリウス/ストラディヴァリウス/
straight /ストレート/ストレイト/
straightcable /ストレートケーブル/
straighthair /ストレートヘア/
straightjuice /ストレートジュース/
straightperm /ストレートパーマ/
straightperma /ストレートパーマ/
strainer /ストレーナー/ストレーナ/
strange /ストレンジ/
stranger /ストレンジャー/
strap /ストラップ/
strapless /ストラップレス/
strasbourg /ストラスブール/
strategist /ストラテジスト;戦略家/
strategy /ストラテジー/ストラテジ/
stratos /ストラトス/
strauss /シュトラウス/ストロース/
stravinsky /ストラヴィンスキー/ストラビンスキー/
straw /ストロー/
strawberry /ストロベリー/
strawberryjam /ストロベリージャム/
stray /ストレイ/
straysheep /ストレイシープ/
streak /ストリーク/
streaking /ストリーキング/
stream /ストリーム/
streamer /ストリーマー/ストリーマ/
streaming /ストリーミング/
street /ストリート/
streetchildren /ストリートチルドレン/
streetfashion /ストリートファッション/
streetfighter /ストリートファイター/
streetlive /ストリートライブ/
streetmusician /ストリートミュージシャン/
strelitzia /ストレリチア/
strength /ストレングス/
streptomycin /ストレプトマイシン/
stress /ストレス/
stressor /ストレッサー/
stretch /ストレッチ/
stretcher /ストレッチャー/
stretching /ストレッチング/
strict /ストリクト/
stride /ストライド/
strider /ストライダー/
strike /ストライク/ストライキ/
striker /ストライカー/
strikezone /ストライクゾーン/
strindberg /ストリンドベリ/
string /ストリング/文字列/
strings /ストリングス/
strip /ストリップ/
stripe /ストライプ/
stripes /ストライプス/
striping /ストライピング/
stripper /ストリッパー/
stripping /ストリッピング/
stripshow /ストリップショー/
strobe /ストローブ/
strobo /ストロボ/
stroganoff /ストロガノフ/
stroke /ストローク/
strokeplay /ストロークプレー/
stromatolite /ストロマトライト/
strong /ストロング/
strontium /ストロンチウム;[元素]38,Sr/
struckout /ストラックアウト/
struct /ストラクト/構造体/
structure /ストラクチャ/ストラクチャー/
strut /ストラット/
strychnine /ストリキニーネ/
stuart /スチュアート/スチュワート/
stub /スタブ/
stucco /スタッコ/
stuck /スタック/
stud /スタッド/
student /スチューデント/
studies /スタディーズ/
studio /スタジオ/ステュディオ;仏語/
studioghibli /スタジオジブリ;Studio Ghibli/
studiolive /スタジオライブ/
studiomusician /スタジオミュージシャン/
studium /スタジアム/
studless /スタッドレス/
studlesstire /スタッドレスタイヤ/
study /スタディー/スタディ/
stuff /スタッフ/
stuffed /スタッフド/
stun /スタン/
stungun /スタンガン/
stunt /スタント/
stuntman /スタントマン/
sturges /スタージェス/
sturm /シュトルム/
stuttgart /シュツットガルト/シュトゥットガルト/
sty /スタイル/
style /スタイル/
stylebook /スタイルブック/
styleguide /スタイルガイド/
stylesheet /スタイルシート/
styling /スタイリング/
stylish /スタイリッシュ/
stylist /スタイリスト/
stylus /スタイラス/
styluspen /スタイラスペン/
styrene /スチレン;C8H8/
styrol /スチロール/
styx /スティクス/ステュクス/
su /スーパーユーザ/スーパユーザ/
suarez /スアレス/
sub /サブ/部分/
subaddress /サブアドレス/
subbag /サブバッグ/
subblock /サブブロック/
subcategory /サブカテゴリ/サブカテゴリー/
subclass /サブクラス/
subcul /サブカル;subculture/
subculture /サブカルチャー/
subdirectory /サブディレクトリ/
subdomain /サブドメイン/サブドメーン;<rare>/
subdominant /サブドミナント/
subfolder /サブフォルダ/
subgoal /サブゴール/
subgraph /サブグラフ/
subgroup /サブグループ/
subheader /サブヘッダ/
subject /サブジェクト/
subleader /サブリーダー/
sublime /サブライム/
subliminal /サブリミナル/
submachine /サブマシン/
submap /サブマップ/
submarine /サブマリン/
submaster /サブマスター/
submenu /サブメニュー/
submission /サブミッション/
submit /サブミット/
submodel /サブモデル/
subnet /サブネット/
subnetmask /サブネットマスク/
subnetting /サブネッティング/
subnetwork /サブネットワーク/
subnote /サブノート/
subpattern /サブパターン/
subprocess /サブプロセス/
subprogram /サブプログラム/
subroutine /サブルーチン/
subscribe /サブスクライブ/
subscript /サブスクリプト/
subscription /サブスクリプション/
subset /サブセット/⊂/
subseteq /⊆/
subshell /サブシェル/
subsite /サブサイト/
substitute /置換/
subsystem /サブシステム/
subtheme /サブテーマ/
subtitle /サブタイトル/
subtraction /サブトラクション/
subtype /サブタイプ/
subunit /サブユニット/
suburban /サバーバン/
suburbia /サバービア/
subway /サブウェイ/
succeed /サクシード/
success /サクセス/
succession /サクセション/
successstory /サクセスストーリー/
succubus /サキュバス/
such /サッチ/
suck /サック/
sucker /サッカー/
sucralose /スクラロース/
sucre /スクレ/シュクル;(Fr) 砂糖/
sucrer /シュクレ;仏語/
sucrose /スクロース/サッカロース/
sudan /スーダン;.sd/
sudden /サドン/
suddendeath /サドンデス/
sudra /スードラ/シュードラ/
sue /スー/シュー/スウ/スゥ/
suede /スエード/
suesan /スーザン;※susan?/
suez /スエズ/
suffix /サフィックス/拡張子/添字/
sufi /スーフィー/スーフィ/
sufism /スーフィズム/
sug /サン・ユーザ・グループ/
sugar /シュガー/
sugarcraft /シュガークラフト;sugar craft/
sugarmilk /シュガーミルク/
sugarpot /シュガーポット/
suggest /サジェスト/
suggestion /サジェスチョン/
suharto /スハルト/
suica /スイカ/
suicide /スーサイド/
suisse /スイス/
suit /スーツ/スート/
suitcase /スーツケース/
suite /スイート/スート;カードの-/スィーツ/
suiteroom /スイートルーム/
suits /スーツ/
suitscase /スーツケース/
suleyman /スレイマン/
sulfa /サルファ/
sulfate /サルフェート/
sulfide /サルファイド;硫化/スルフィド/
sulfite /サルファイト;亜硫酸/
sulfone /スルホン/
sulfoxide /スルホキシド/
sulfur /サルファ;S/サルファー/
sullivan /サリヴァン/サリバン/
sully /シュリ/シュリー/
sulphate /サルフェート;硫酸/
sulphide /サルファイド;硫化/スルフィド/
sulphite /サルファイト;亜硫酸/
sulphur /サルファ;S/サルファー/
sultan /サルタン/スルタン/スルターン/
sum /サム/∪/スム;ラテン語/
sumatra /スマトラ/
sumer /シュメール/
summarize /サマライズ/
summary /サマリー/サマリ/
summer /サマー/
summercamp /サマーキャンプ/
summersale /サマーセール/
summertime /サマータイム/
summit /サミット/
sun /サン/日/Ｓｕｎ/ｓｕｎ/Sun/ＳＵＮ/
sun3 /Ｓｕｎ３/
sun4 /Ｓｕｎ４/
sundae /サンデー/
sundance /サンダンス/
sunday /サンデー/サンディ/サンディー/サンデイ/
sundeck /サンデッキ/
sundress /サンドレス/
sune /スネ/
sunflower /サンフラワー/
sunglass /サングラス/
sunglasses /サングラス/
sunkist /サンキスト;www.sunkist.com/
sunkus /サンクス;www.sankus.co.jp/
sunlight /サンライト/
sunmusic /サン・ミュージック/
sunna /スンナ;[イスラム]慣習法/
sunnet /ＳｕｎＮｅｔ/
sunni /スンニ/スンニー/
sunny /サニー/
sunnylettuce /サニーレタス/
sunnyside /サニーサイド/
sunoil /サンオイル/
sunos /ＳｕｎＯＳ/SunOS/
sunrise /サンライズ/
sunroof /サンルーフ/
sunroom /サンルーム/
sunset /サンセット/
sunshine /サンシャイン/
sunstar /サンスター;www.sunstar.com/
suntory /サントリー;www.suntory.co.jp/
suntoryhall /サントリーホール/
sunview /ＳｕｎＶｉｅｗ/
sunvisor /サンバイザー/
suomi /スオミ;フィンランド/
super /スーパー/スーパ/
superascii /ＳｕｐｅｒＡｓｃｉｉ/
superball /スーパーボール;和製英語/
superbowl /スーパーボウル/スーパーボール/
supercar /スーパーカー/
superclass /スーパークラス/スーパクラス/
supercom /スパコン;super computer/
supercomputer /スーパーコンピュータ/スーパーコンピューター/
superdry /スーパードライ;[商標]アサヒビール/
superfine /スーパーファイン/
superhero /スーパーヒーロー/
superimpose /スーパーインポーズ/
superior /スーペリア/スペリオール/スペリオル/
superiore /スペリオーレ/
superkamiokande /スーパーカミオカンデ/
superman /スーパーマン/
supermarket /スーパーマーケット/
supermodel /スーパーモデル/
supermulti /スーパーマルチ/
superoption /スーパーオプション/
superpower /スーパーパワー/
superrealism /スーパーリアリズム/
superrich /スーパーリッチ/
superscalar /スーパースケーラ/スーパスカラ/スーパースカラ/スーパースカラー/スーパースケーラー/
superscaler /スーパースケーラ;※scalar/
superset /⊃/スーパーセット/
superseteq /⊇/
supersize /スーパーサイズ/
superstar /スーパースター/
superuser /スーパーユーザー/スーパーユーザ/スーパユーザ/
supervielle /シュペルヴィエル/
supervisor /スーパバイザ/
superwoofer /スーパーウーファー/
suplex /スープレックス/
suppe /スッペ/
supper /サパー/
supple /サプリ;supplement/
supplement /サプリメント/
supplier /サプライヤー/サプライヤ/サプライア/
supplies /サプライズ/
supply /サプライ/
supplychain /サプライチェーン/
supplyside /サプライサイド/
suppocen /サポセン;supportcenter/
support /サポート/
supportcenter /サポートセンター/サポセン/
supportcentre /サポートセンター/サポセン/
supporter /サポーター/
supportmember /サポートメンバー/
supportpage /サポートページ/
suppress /サプレス/
supra /スープラ/
supremacy /スプレマシー/
supreme /シュープリーム/シュプリーム/
supset /⊃/
supseteq /⊇/
suq /スーク/
sur /シュール;仏語/サー/
surabaya /スラバヤ/
surcharge /サーチャージ/
surdo /スルド/
sure /シュア/
surf /サーフ/
surface /サーフェス/サーフェイス/サーフィス/
surfboard /サーフボード/
surfer /サーファー/
surfing /サーフィン/
surinam /スリナム/
suriname /スリナム;.sr/
surpass /サーパス/
surplus /サープラス/
surprise /サプライズ/
surrealisme /シュールレアリスム/
surrealiste /シュールレアリスト/
surrender /サレンダー/
surrogate /サロゲート/
surround /サラウンド/
surroundspeaker /サラウンドスピーカー/
surveillance /サーベイランス/
survey /サーベイ/
surveyor /サーベイヤー/
survival /サバイバル/
survivalgame /サバイバルゲーム/
survivalknife /サバイバルナイフ/
survive /サヴァイヴ/サバイブ/
survivor /サバイバー/
susa /スーサ/
susan /スーザン/
susanna /スザンナ/
susannah /スザンナ/
susanne /スザンヌ/
susceptance /サセプタンス/
susie /スージー/
suspend /サスペンド/
suspended /サスペンデッド/
suspender /サスペンダー/
suspense /サスペンス/
suspension /サスペンション/
sussex /サセックス/
sustain /サステイン/
sustainable /サステイナブル/サステナブル/
sutherland /サザーランド/
sutra /スートラ/
suva /スヴァ/
suzanne /スザンヌ/シュザンヌ/
suzdal /スーズダリ/
suzie /スージー/
suzy /スージー/
sven /スヴェン/スベン/
svetlana /スベトラーナ/
svyatoslav /スヴャトスラフ/
sw /┐;罫線/┓;太い罫線/
swallow /スワロー/
swallows /スワローズ/
swamp /スワンプ/
swan /スワン/
swanee /スワニー/
swap /スワップ/
swapfile /スワップファイル/
swapout /スワップアウト/
swapper /スワッパ/
swapping /スワッピング/
swarovski /スワロフスキー/
swatch /スウォッチ;www.swatch.com/
sway /スウェー/スウェイ/
swaziland /スワジランド/
sweat /スウェット/
sweater /セーター/
sweatshirt /スウェットシャツ/
sweatshirts /スウェットシャツ/
sweden /スウェーデン;.se/スエーデン/
sweep /スイープ/スウィープ/
sweeper /スイーパー/
sweet /スイート/スウィート/
sweetcorn /スイートコーン/
sweetheart /スウィートハート/スイートハート/
sweethome /スイートホーム/スウィートホーム/
sweetie /スウィーティー/
sweetpea /スイートピー;sweet pea/
sweetpotato /スイートポテト/スウィートポテト/
sweets /スイーツ/スウィーツ/
sweetspot /スイートスポット/スウィートスポット/
swell /スウェル/
swift /スイフト/スウィフト/
swim /スイム/
swimmer /スイマー/
swimming /スイミング/スウィミング/スィミング/
swimmingpool /スイミングプール/
swimmingschool /スイミングスクール/
swimwear /スイムウェア/
swing /スイング/スウィング/
swingby /スイングバイ/
swingjazz /スウィングジャズ/スイングジャズ/
swingout /スウィングアウト/スイングアウト/
swingy /スウィンギー/スインギー/
swiss /スイス/瑞西/
switch /スイッチ/スィッチ/
switcher /スイッチャー/
switchhitter /スイッチヒッター/
switching /スイッチング/
switchinghub /スイッチングハブ/
switchoff /スイッチオフ/
switchon /スイッチオン/
switzerland /スイス;.ch/
swizzling /シズリング/
sword /ソード/
swordfish /ソードフィッシュ/
syan /シアン/
sybil /シビル/
sybilla /シビラ/
sydney /シドニー/
syllable /シラブル/
syllabus /シラバス/
sylph /シルフ/
sylpheed /シルフィード/
sylvain /シルヴァン/シルバン/
sylvester /シルヴェスター/
sylvia /シルビア/シルヴィア/
sylvie /シルヴィ/シルヴィー/
symantec /シマンテック/
symbol /シンボル/
symbolcolor /シンボルカラー/
symbolcolour /シンボルカラー/
symbolic /シンボリック/
symbolic-link /シンボリック・リンク/
symboliclink /シンボリックリンク/シンボリック・リンク/
symbolise /シンボライズ/
symbolism /シンボリズム/
symbolisme /サンボリスム;象徴派/
symbolize /シンボライズ/
symbolmark /シンボルマーク/
symlink /シンボリックリンク/
symmetric /シンメトリック/
symmetrical /シンメトリカル/
symmetry /シンメトリー/
symonds /シモンズ/
symons /シモンズ/
sympa /シンパ/
sympathy /シンパシー/
symphonia /シンフォニア/
symphonic /シンフォニック/
symphony /シンフォニー/
sympo /シンポ/
symposium /シンポジウム/
synagogue /シナゴーグ/
synaps /シナプス;※synapse/
synapse /シナプス/
sync /シンク/
synch /シンク/
synchro /シンクロ;synchronise(d)/
synchronise /シンクロナイズ/
synchronised /シンクロナイズド/
synchronize /シンクロナイズ/
synchronized /シンクロナイズド/
synchronizing /シンクロナイジング/
synchronous /シンクロナス/
synchrotron /シンクロトロン/
syncopation /シンコペーション/
syndicate /シンジケート/
syndrome /シンドローム/
synergy /シナジー/
synonym /シノニム/
synopsis /シノプシス/
syntactic /シンタクティック/
syntax /シンタックス/シンタクス/
synth /シンセ/
synthe /シンセ/
synthese /ジンテーゼ/
synthesize /シンセサイズ/
synthesizer /シンセサイザー/シンセサイザ/
syphon /サイフォン/サイホン/
syrah /シラー/
syren /サイレン/セイレーン/セイレン/
syria /シリア;.sy/
syringe /シリンジ/
syrinx /シリンクス/シュリンクス/
syrup /シロップ/
sys /シス/
sysad /シスアド/システムアドミニストレータ;※abbrev/
syslab /シスラボ/
sysop /シスオペ;system operator/
system /システム/
system5 /システム５/
systemadministrator /システムアドミニストレータ/
systematic /システマティック/
systembath /システムバス/
systembus /システムバス/
systemcall /システムコール/
systemclock /システムクロック/
systemdisk /システムディスク/
systemdown /システムダウン/
systemengineer /システムエンジニア;SE/
systemengineering /システムエンジニアリング/
systemerror /システムエラー/
systemfile /システムファイル/
systemkitchen /システムキッチン;和製英語/
systems /システムズ/
systemtest /システムテスト/
systollic /シストリック/
systollicarray /シストリックアレイ/
sysv /ＳｙｓＶ/
szymanowski /シマノフスキ/シマノフスキー/
t /τ;tau/ティー/т;te (cyrillic)/〒;zip/├;罫線/┬/┤/┴/┣/┳/┫/┻/┠/┯/┨/┷/┝/┰/┥/┸/
t-shirt /Ｔシャツ/
ta /タンタル/Tantalum/
taart /タルト;(蘭語)/
tab /タブ/
tabacco /タバコ/
tabaco /タバコ/
tabasco /タバスコ/
tabbrowser /タブブラウザ/
tabitha /タバサ/
tabkey /TABキー/タブキー/
tabl /タブル/
tabla /タブラ/
tablature /タブラチュア/
table /テーブル/表/ターブル;仏語/
tableau /タブロー/
tableaux /タブロー/
tablecloth /テーブルクロス/
tablegame /テーブルゲーム/
tablemanner /テーブルマナー/
tablet /タブレット/
tabletalk /テーブルトーク/
tabletennis /テーブルテニス/
tabletop /テーブルトップ/
tabletpc /タブレットPC/
tablette /タブレット;仏語/
tableware /テーブルウェア/
tablewine /テーブルワイン/
tabloid /タブロイド/
taboo /タブー/
tabor /テーバー/
tabriz /タブリーズ/
tabu /タブー;(ポリネシア語)/
tabun /タブン;(神経ガス)/
tac /TAC/
tachometer /タコメーター/タコメータ/
tachyon /タキオン/
tack /タック/
tackle /タックル/
tacoma /タコマ/
tacos /タコス/
tactic /タクティック/
tactical /タクティカル/
tactics /タクティクス/
tadzhik /タジク/
tadzhikistan /タジキスタン/
taekwondo /テコンドー/
tafeta /タフタ/
taffy /タフィー/タフィ/トフィー/
tag /タグ/タッグ/Ｔａｇ/
tagalog /タガログ/
tagheuer /タグホイヤー;www.tagheuer.com/タグ・ホイヤー/
tagliatelle /タリアテッレ/
tagliolini /タリオリーニ/
tagmatch /タッグマッチ/
tagore /タゴール/
tahiti /タヒチ/
taiga /タイガ;(露語)тайга/
tail /テイル/テール/
tailend /テールエンド/
taillamp /テールランプ/
tailor /テーラー/テイラー/
tailored /テーラード/
tailormade /テーラーメイド/テーラーメード/
tailsoup /テールスープ/
taine /テーヌ/
tains /テインズ/TAINS/
taito /タイトー;www.taito.co.jp/タイト/
taiwan /タイワン/台湾/
tajikistan /タジキスタン;.tj/
tajmahal /タージマハル;Taj Mahal/
tajo /タホ/
take /テイク/
takeback /テイクバック/テークバック/
takeoff /テイクオフ/
takeout /テイクアウト;take-out/
taklamakan /タクラマカン;Takla Makan/タクラマカン砂漠/
takt /タクト/
tal /タル/
tala /ターラ/
talas /タラス/
talc /タルク/
tale /テイル/テール/
talent /タレント/
tales /テイルズ/
taliban /タリバン/タリバーン/
talisman /タリスマン/
talk /トーク/
talker /トーカ/
talkevent /トークイベント/
talkie /トーキー/
talking /トーキング/
talkingdrum /トーキングドラム/
talklive /トークライブ/
talkshow /トークショー/トークショウ/
tall /トール/
tallcase /トールケース/
tallinn /タリン/
tallis /タリス/
talmud /タルムード/
talon /タロン/
tam /タム/
tamar /タマル/
tamara /タマラ/タマーラ/
tamarin /タマリン/
tamarind /タマリンド/
tambora /タンボラ/
tambourine /タンバリン/
tambura /タンブーラ/
tami /タミ/
tamiflu /タミフル;抗インフルエンザ薬/
tamil /タミル/
tammy /タミー/
tampa /タンパ/
tampere /タンペレ/
tampon /タンポン/
tamtam /タムタム/
tan /タン/
tanbur /タンブール/
tandem /タンデム/
tandoori /タンドリー/
tandoorichicken /タンドリーチキン/
tanga /タンガ/
tangent /タンジェント/
tangerine /タンジェリン/
tango /タンゴ/
tangor /タンゴール/
tangram /タングラム/
tania /タニア/
tank /タンク/
tanker /タンカー/
tankini /タンキニ;tanktop + bikini/
tanklorry /タンクローリー/
tanktop /タンクトップ/
tannat /タナ/
tannhauser /タンホイザー/
tannin /タンニン/
tano /タノ/
tanqueray /タンカレー/
tantal /タンタル;Ta/
tantalos /タンタロス/
tantalum /タンタル;[元素]73,Ta/
tanto /タント;(It)たくさん/
tantra /タントラ/
tanya /ターニャ/タニア/
tanzania /タンザニア;.tz/
tanzanite /タンザナイト/
tap /タップ/
tapdance /タップダンス/
tapdancer /タップダンサー/
tape /テープ/テイプ/
tapecut /テープカット/
tapedrive /テープドライブ/
taperecorder /テープレコーダー/テープレコーダ/
tapestry /タペストリー/タペストリ/タピストリー/タピストリ/
tapia /タピア/
taping /テーピング/
tapio /タピオ/
tapioca /タピオカ/
tapper /タッパー;[商標]www.tapperware.com/タッパ/
tapperware /タッパーウェア;[商標]www.tapperware.com/
tapping /タッピング/
tar /タール/
tara /タラ/
tarantella /タランテラ/
tarantino /タランティーノ/
tarantula /タランチュラ/
taras /タラス/
tarawa /タラワ/
target /ターゲット/
targeting /ターゲティング/ターゲッティング/
tariff /タリフ/
tarim /タリム/
tarkovskii /タルコフスキー/
tarot /タロット/
tarotcard /タロットカード/
tart /タルト/トルテ/
tartan /タータン/
tartancheck /タータンチェック/
tartar /タルタル/
tartaresauce /タルタルソース/
tartaresteak /タルタルステーキ/
tartaros /タルタロス/
tartarsauce /タルタルソース/
tartarsteak /タルタルステーキ/
tarte /タルト/
tartelette /タルトレット/
taru /タル/
tarzan /ターザン/
tasha /ターシャ/
tashkent /タシケント/
task /タスク/
taskbar /タスクバー/
taskforce /タスクフォース/
tasking /タスキング/
taskmanager /タスクマネージャ/タスクマネージャー/
tasman /タスマン/
tasmania /タスマニア/
tasmanian /タスマニアン/
tasse /タス;(Fr) 茶碗/
tassel /タッセル/
taste /テイスト/ティスト/テースト/
tasting /テイスティング/
tasty /テイスティ/
tatar /タタール/
tatarstan /タタルスタン/
tate /テート/テイト/│;罫線/┃;太い罫線/
tatiana /タチアナ/
tatoo /タトゥー/タトゥ/
tatum /テイタム/テータム/
tatyana /タチアナ/
tau /τ/タウ/
taurine /タウリン/
taurus /トーラス;牡牛座/タウラス/
taut /タウト/
tautology /トートロジー/
tautou /トトゥ/
taverna /タベルナ/タヴェルナ/
tax /タックス/
taxane /タキサン/
taxanswer /タックスアンサー;www.taxanser.nta.go.jp/
taxhaven /タックスヘイブン/
taxi /タクシー/
taxy /タクシー/
taxydriver /タクシードライバー/
taylor /テイラー/
tb /テルビウム/Terbium/
tback /Ｔバック/Tバック/ティーバック/
tbilisi /トビリシ/
tc /テクネチウム/Technetium/
tchad /チャド/
tchaikovsky /チャイコフスキー/
tcode /T-Code/Tコード/
tcp /ＴＣＰ／ＩＰ/TCP/
tcpip /ＴＣＰ／ＩＰ/
te /т;cyrillic/テルル/Tellurium/
tea /ティー/ティ/テア/
teabag /ティーバッグ/
teacher /ティーチャー/
teaching /ティーチング/
teacup /ティーカップ/
teak /チーク/
team /チーム/
teamcolor /チームカラー/
teamcolour /チームカラー/
teamer /チーマー/
teamleader /チームリーダー/
teammate /チームメイト/チームメート/
teamplay /チームプレー/チームプレイ/
teamwork /チームワーク/
teaparty /ティーパーティー/
teapot /ティーポット/
tear /ティア/ティアー/
teardrop /ティアドロップ/
tearoom /ティールーム/
tears /ティアーズ/
teaserver /ティーサーバー/
teaset /ティーセット/
teaspoon /ティースプーン/
teatime /ティータイム/
teatro /テアトロ/
tech /テック/テク;technology/
technetium /テクネチウム;[元素]43,Tc/
technic /テクニック/
technica /テクニカ/
technical /テクニカル/
technicalengineer /テクニカルエンジニア/
technicalsupport /テクニカルサポート/
technician /テクニシャン/
technique /テクニック/
techno /テクノ/
technocrat /テクノクラート/
technologies /テクノロジーズ/
technology /テクノロジー/テクノロジ/
technopolis /テクノポリス/
technopop /テクノポップ;techno-pop/
technosterss /テクノストレス/
technostress /テクノストレス;techno-stress/
tectonics /テクトニクス/
ted /テッド/
tedd /テッド/
teddy /テディ/
teddybear /テディベア/
tee /ティー/
teen /ティーン/
teenage /ティーンエイジ/
teenager /ティーンエイジャー/ティーンエージャー/
teens /ティーンズ/
teeshot /ティーショット/
teeth /ティース/
teeup /ティーアップ/
teflon /テフロン/
tegucigalpa /テグシガルパ/
teheran /テヘラン/
tehran /テヘラン/
tektro /テクトロ/
tel /テル/電話/電話番号/Ｔｅｌ/TEL/
telaviv /テルアビブ;イスラエル(tlv)/
tele /テレ/
teleca /テレカ;telephone card/
telecom /テレコム/
telecommunication /テレコミュニケーション/
telekinesis /テレキネシス/
telemann /テレマン/
telemark /テレマーク/
telemarker /テレマーカー/
telemeter /テレメータ/テレメーター/
telemetry /テレメトリ/テレメトリー/
telepath /テレパス/
telepathy /テレパシー/
telephone /テレホン/テレフォン/
telephonecard /テレホンカード/テレフォンカード/
telephoneservice /テレホンサービス/テレフォンサービス/
telephony /テレフォニー/
teleport /テレポート/
telescope /テレスコープ/
telescopic /テレスコピック/
telesis /テレシス/
teletype /テレタイプ/
televi /テレビ;television/
televicamera /テレビカメラ/
televigame /テレビゲーム/
television /テレビジョン/テレビ/
telework /テレワーク/
telex /テレックス/
tell /テール/テル/
teller /テラー/
telling /テリング/
tellurium /テルル;[元素]52,Te/
telly /テリー/
telnet /テルネット/
telomere /テロメア/
telop /テロップ/
tema /テーマ;?/
temp /テンプ/テンポラリ/temporary/
tempera /テンペラ/
tempering /テンパリング/
tempest /テンペスト/
templa /テンプレ/
template /テンプレート/テンプレイト/
temple /テンプル/
templete /テンプレート;※template/
tempo /テンポ/
temporal /テンポラル/
temporary /テンポラリ/テンポラリー/
tempranillo /テンプラニーリョ/
ten /テン/・/
tenant /テナント/
tender /テンダー/
tenkey /テンキー/
tenn /テン/
tennessee /テネシー;TN/
tennis /テニス/
tennisball /テニスボール/
tenniscircle /テニスサークル/
tennisclub /テニスクラブ/
tenniscourt /テニスコート/
tennisracket /テニスラケット/
tennisshoes /テニスシューズ/
tenniswear /テニスウェア/
tennyson /テニスン/テニソン/
tenochtitlan /テノチティトラン/
tenor /テナー/テノール/
tenorsax /テナーサックス/
tense /テンス/
tenshan /テンシャン/
tension /テンション/
tensor /テンソル/
tent /テント/
tentative /テンタティブ/試験的/
tenten /…/・・・;中黒x3/
tenth /テンス/
tenuto /テヌート/
teo /テオ/
tequila /テキーラ/
tera /テラ;[SI接頭語]T,10^12/
terabyte /テラバイト/
terabytes /テラバイト/
terbium /テレビウム;[元素]65,Tb/
tercel /ターセル;[商標]トヨタ/
terence /テレンス/
teresa /テレサ/
term /ターム/用語/
terminal /ターミナル/端末/
terminaladapter /ターミナルアダプタ/ターミナルアダプター/
terminalcare /ターミナルケア/
terminalemulator /ターミナルエミュレータ/
terminate /ターミネート/ターミネイト/
termination /ターミネーション/
terminator /ターミネーター/ターミネータ/ターミネイタ/
tero /テロ/
terpen /テルペン/
terpene /テルペン/
terpenoid /テルペノイド/
terra /テラ/
terrace /テラス/
terracehouse /テラスハウス/
terracotta /テラコッタ/
terraforming /テラフォーミング/
terrain /テレイン/
terrarium /テラリウム/
terrence /テレンス/
terrier /テリア;犬/
terrine /テリーヌ/
territory /テリトリー/
terror /テロ/テラー/テロル/
terrorism /テロリズム/
terrorist /テロリスト/
terry /テリー/
tess /テス/
tessa /テッサ/
test /テスト/試験/
testarossa /テスタロッサ;[商標]Ferrari/
testcase /テストケース/
testdata /テストデータ/
testdriver /テストドライバー/
tester /テスター/テスタ/
testing /テスティング/
testmail /テストメール/
testosterone /テストステロン/
testpattern /テストパターン/
testrun /テストラン/
testset /テストセット/
tethering /テザリング/
tetra /テトラ;4/
tetrachloroethylene /テトラクロロエチレン;C2Cl4/
tetris /テトリス/
tetrodotoxin /テトロドトキシン;フグ毒/
tex /テフ/テックス/テック/ＴｅＸ/ＴEＸ/TeX/\TeX/
texas /テキサス/
texel /テクセル/
texinfo /Texinfo/
text /テキスト/テクスト/文字列/教科書/
textarea /テキストエリア/
textbook /テキストブック/
textbox /テキストボックス/
textdata /テキストデータ/
texte /テクスト;仏語/
texteditor /テキストエディタ/
textfield /テキストフィールド/
textfile /テキストファイル/
textile /テキスタイル/
textual /テクスチュアル/
texture /テクスチャ/テクスチャー/テキスチャ;<rare>/
textwidget /テキスト・ウィジット/
th /θ;theta/トリウム/Thorium/ス;(接尾辞)fifth,length/
thai /タイ/
thaibaht /タイバーツ/
thailand /タイランド;.th/タイ/
thais /タイス/
thalassa /タラサ/
thalassotherapie /タラソテラピー/
thales /タレス/タレース/
thalia /タリア/
thalidomide /サリドマイド/
thallium /タリウム;[元素]81,Tl/
thames /テムズ/テームズ/
than /ザン/
thanatos /タナトス/
thank /サンク/
thanks /サンクス/
thanksgiving /サンクスギビング;感謝祭/
thankyou /サンキュー/
thar /タール/
that /ザット/
that's /ザッツ/
thatcher /サッチャー/
thats /ザッツ;that's/
the /ザ/ジ/
thea /テア/
theater /シアター/
theatre /テアトル/シアター/
thebai /テーバイ/テバイ/テーベ/
thebes /テーベ/
thebestten /ザ・ベストテン/
thehague /ヘーグ;the Hague/
theirs /ゼアーズ/
thelma /セルマ/テルマ/
thelonious /セロニアス/
them /ゼム/
thema /テーマ;(独)/
theme /テーマ/
themepark /テーマパーク/
themesong /テーマソング/
themis /テミス/
then /ゼン/
theo /テオ/セオ/
theobromine /テオブロミン/
theodor /テオドール/シオドア/テオドル/
theodore /テオドール/セオドア/シオドア/
theophil /テオフィル/
theophile /テオフィル/
theophylline /テオフィリン/
theory /セオリー/
theos /テオス;神(θεοσ)/
therapist /セラピスト/テラピスト/
therapy /セラピー/テラピー/
there /ゼア/
therefore /∴/
theremin /テルミン/
theresa /テレサ/テリーサ/
therese /テレーズ/テレーゼ/
theresia /テレジア/
thermal /サーマル/
thermidor /テルミドール/
thermo /サーモ/
thermograph /サーモグラフ/
thermography /サーモグラフィー/サーモグラフィ/
thermometer /サーモメーター/
thermostat /サーモスタット/
theron /セロン/
thesaurus /シソーラス/
these /テーゼ/
theseus /テセウス/
thessalia /テッサリア/
thessalonica /テサロニケ/テサロニカ/
thessaloniki /テサロニケ/テサロニキ/
theta /θ/シータ/
thetelevision /ザ・テレビジョン/
thetis /テティス/
they /ゼイ/
thiamin /チアミン;V.B1/
thiamine /チアミン;V.B1/
thibaud /ティボー/チボー/
thibault /チボー/
thick /シック/
thief /シーフ/
thierry /ティエリ/
thigh /サイ/
thimphu /ティンプー/
thin /シン/
thing /シング/
think /シンク/
thinking /シンキング/
thinktank /シンクタンク/
thinner /シンナー/
thio /チオ/
thiol /チオール/
thiophene /チオフェン/
third /サード/３ｒｄ/第3要素/
thirdbase /サードベース/
thirdfly /サードフライ/
thirdgoro /サードゴロ;和製語(grounder)/
thirdparty /サードパーティ/サードパーティー/
thirteen /サーティーン/
thirty /サーティ/
this /ジス/ディス/
thistle /シスル;あざみ/
thom /トム/
thoma /トーマ/
thomas /トーマス/トマス/トマ/トーマ/
thomascook /トーマスクック/
thompson /トンプソン/
thomson /トムソン/トムスン/
thong /トング/
thor /トール/
thoreau /ソロー/
thorium /トリウム;[元素]90,Th/
thorn /ソーン;茨/
thoroughbred /サラブレッド/
thorpe /ソープ/
thoth /トート/トト/
thought /ソート/
thousand /サウザンド/
thracia /トラキア/
thrashing /スラッシング/
thread /スレッド/
threading /スレッディング/
threadsafe /スレッドセーフ/
three /スリー/
threebase /スリーベース;triple/
threef /スリーエフ;www.three-f.co.jp/
threeout /スリーアウト/
threepiece /スリーピース/
threerun /スリーラン/
threeseason /スリーシーズン;three-season/
threesize /スリーサイズ;和製英語(mesurements) NB:バスト・ウエスト・ヒップ/
threonine /スレオニン;Thr/トレオニン;=スレオニン/
threshold /スレッシュホールド/閾値/
thriling /スリリング/
thrill /スリル/
thriller /スリラー/
thrilling /スリリング/
throat /スロート/
thromboxane /トロンボキサン;TX/
throne /スローン/
throttle /スロットル/
through /スルー/
throughpass /スルーパス;和製英語/
throughput /スループット/
throw /スロー/
throwin /スローイン;throw-in/
throwing /スローイング/
thru /スルー/
thu /木/
thule /トゥーレ/
thulium /ツリウム;[元素]69,Tm/
thumb /サム/
thumbhole /サムホール/
thumbing /サミング/
thumbnail /サムネイル/サムネール/
thumbturn /サムターン;和製英語/
thunder /サンダー/
thunderbird /サンダーバード/
thunderbolt /サンダーボルト/
thuram /テュラム/
thuringen /チューリンゲン/
thursday /サーズデイ/サーズデー/サーズディ/
thurston /サーストン/
thyme /タイム/
thymine /チミン;T/
thymol /チモール/
thyristor /サイリスタ/
thyroxin /サイロキシン/
thyroxine /チロキシン/
ti /チタン/Titanium/テキサスインスツルメンツ/
tia /ティア/
tiago /ティアゴ/
tiamat /ティアマット/
tiananmen /天安門/
tiara /ティアラ/
tiber /タイバー/
tiberius /ティベリウス/
tibet /チベット/
tibetan /チベタン/
tic /チック/
tick /チック/ティック/
ticket /チケット/切符/
ticketless /チケットレス/
ticketpia /チケットぴあ;t.pia.co.jp/
ticketshop /チケットショップ/
ticktack /チクタク;tick-tack/チックタック/
tie /タイ/
tiebreak /タイブレーク/
tiepin /タイピン/
tieup /タイアップ/
tifanny /ティファニー/
tiff /ティフ/
tiffany /ティファニー/
tiffin /ティフィン/
tiger /タイガー/
tigers /タイガース/
tight /タイト/
tights /タイツ/
tightskirt /タイトスカート/
tignes /ティーニュ/
tigris /チグリス/ティグリス/
tijuana /ティファナ/
tilapia /ティラピア/テラピア/
tilda /チルダ/ティルダ/
tilde /チルダ/〜/ティルデ/ティルド/
tile /タイル/
tiling /タイリング/
till /ティル/
tilly /ティリー/
tilt /ティルト/
tim /ティム/
timbales /ティンバレス/
timber /ティンバー/
timbre /タンブル/
time /タイム/時間/
timeattack /タイムアタック/
timecapsule /タイムカプセル/
timecard /タイムカード/
timekeeper /タイムキーパー/
timelag /タイムラグ/
timelimit /タイムリミット/
timeline /タイムライン/
timely /タイムリー/
timelyhit /タイムリーヒット/
timemachine /タイムマシン/タイムマシーン/
timeout /タイムアウト/
timeover /タイムオーバー;和製英語(out of time)/
timer /タイマー/タイマ/
timerace /タイムレース/
timerecorder /タイムレコーダー/
times /タイムス/タイムズ/×/
timesale /タイムセール/
timescale /タイムスケール/
timeschedule /タイムスケジュール/
timeserver /タイムサーバ/タイムサーバー/
timeservice /タイムサービス/
timeshift /タイムシフト/
timeslip /タイムスリップ/
timespan /タイムスパン/
timessquare /タイムズスクエア/
timestamp /タイムスタンプ/
timetable /タイムテーブル/
timetravel /タイムトラベル/
timetrial /タイムトライアル/
timetunnel /タイムトンネル/
timeup /タイムアップ;和製英語(time's up)/
timezone /タイムゾーン/
timing /タイミング/
timm /ティム/
timmons /ティモンズ/
timo /ティモ/
timor /チモール/ティモール/
timothy /ティモシー/チモシー/テモテ/ティモテ/
timpani /ティンパニ/ティンパニー/
timur /ティムール/チムール/
tin /ティン;Sn/
tina /ティナ/ティーナ/
tinkerbell /ティンカーベル/
tinkle /ティンクル/
tino /ティノ/
tinpanalley /ティンパンアレイ;Tin-Pan Alley/
tint /ティント/
tinto /ティント/
tiny /タイニー/
tip /チップ/ティップ/
tips /ティップス/
tiramisu /ティラミス/
tirana /チラナ/ティラナ;アルバニア(tia)/
tire /タイヤ/タイア/
tirechain /タイヤチェーン/
tiresize /タイヤサイズ/
tirol /チロル/
tirolean /チロリアン/
tissue /ティッシュ/
tissuecase /ティッシュケース/
tissuepaper /ティッシュペーパー;和製英語/
tit /ティット/
titan /チタン/タイタン/Ｔｉｔａｎ/
titania /チタニア/
titanic /タイタニック/
titanium /チタニウム/チタン;[元素]22,Ti/
title /タイトル/
titlebar /タイトルバー/
titlematch /タイトルマッチ/
titlepage /タイトルページ/
titlerole /タイトルロール/
tito /チトー/
titus /テトス/タイタス/
tivoli /チボリ/
tiziano /ティツィアーノ/
tk80 /ＴＫ８０/
tl /タリウム/Thalium/
tm /ツリウム/Thulium/
tn /Tennessee/テネシー/
to /トゥ/ツー/→/
toad /トード/
toast /トースト/
toaster /トースター/トースタ/
tobacco /タバコ/
tobias /トビアス/トバイアス/トビト/
toby /トビー/
toccata /トッカータ/
tochka /トーチカ/
toco /トコ/
tocopherol /トコフェロール;V.E/
tocotrienol /トコトリエノール/
tocqueville /トクヴィル/
tod /トッド/トート;(独) 死/
today /トゥデイ/トゥディ/トゥデー/
toe /トゥ/トウ/トー/
toeic /トーイック;Test of English for International Communication/TOEIC/
toeplitz /テプリッツ/
toeshoes /トウシューズ/トゥシューズ/
together /トゥギャザー/
toggle /トグル/
togglebutton /トグルボタン/
toggleswitch /トグルスイッチ/
togo /トーゴ;.tg/
tohoku /東北/東北大学/東北地方/
toi /トワ/
toile /トイレ;toilet/
toilet /トイレット/トイレ/
toiletmat /トイレマット;bathroom mat/
toiletpaper /トイレットペーパー/
toiletry /トイレタリー/
tokaj /トカイ/
tokarev /トカレフ/
tokay /トカイ/
tokelau /トケラウ;.tk/
token /トークン/
tokenring /トークンリング/
tokhara /トカラ/トハラ/吐火羅/都貨邏/
tokio /トキオ/
tokyo /トーキョー/東京/
tokyodome /東京ドーム/
toledo /トレド/
tolerance /トレランス/
tolerant /トレラント/
tolkien /トールキン/
tolley /トリー/
tolstoi /トルストイ/
toluene /トルエン/
tom /トム/タム/
toma /トーマ/
tomahawk /トマホーク/
tomas /トマス/
tomato /トマト/
tomatojuice /トマトジュース/
tomatoketchup /トマトケチャップ/
tomatopuree /トマトピューレ/
tomatosalad /トマトサラダ/
tomatosauce /トマトソース/
tomcat /トムキャット;F-14/
tomei /トメイ/
tomi /トミ/
tommy /トミー/
tomorrow /トゥモロー/
tomtom /タムタム/トムトム/
tomy /トミー/
ton /トン/噸/瓲/
tonal /トーナル/
tonality /トーナリティ/
tondo /トンド/
tone /トーン/
tonedown /トーンダウン/
toner /トナー/
tonercartridge /トナーカートリッジ/
tong /トング/
tonga /トンガ;.to/
tongue /タング/タン/
tonguestew /タンシチュー/
tonguing /タンギング/
toni /トニー/トーニ/トニ/
tonic /トニック/
tonicwater /トニックウォーター;tonic/
tonight /トゥナイト/
tonino /トニーノ/
tonio /トニオ/
tonny /トニー/
tony /トニー/
tonya /トーニャ/
too /ツー/トゥー/
tool /ツール/
toolbar /ツールバー/
toolbox /ツールボックス/
toolkit /ツールキット/
tools /ツールス/ツールズ/
tooltip /ツールチップ/
tooth /トゥース/
top /トップ/上/
top# /トップ#0/トップ#1/
top10 /トップテン/
topaz /トパーズ/
topbatter /トップバッター/
topbust /トップバスト;top bust/
topclass /トップクラス;top class/
topdomain /トップドメイン/
topdown /トップダウン/
tope /トープ/
topgear /トップギア/
topgun /トップガン/
topia /トピア/
topic /トピック/
topics /トピックス/
topix /トピックス;東証株価指数/
toplady /トップレディ/
topleader /トップリーダー/
topleague /トップリーグ/
topless /トップレス/
toplevel /トップレベル/
toplight /トップライト/
topline /トップライン/
topmenu /トップメニュー/
topmodel /トップモデル/
topnote /トップノート/
topo /トポ/
topography /トポグラフィー/トポグラフィ/
topological /トポロジカル/
topology /トポロジー/トポロジ/
topos /トポス/
toppage /トップページ/
toppan /トッパン/
toppe /トッピー/
topping /トッピング/
topplayer /トッププレイヤー/トッププレーヤー/
toppro /トッププロ/
toprank /トップランク/
toprope /トップロープ/
toprunner /トップランナー/
tops /トップス/
topsales /トップセールス/
topsecret /トップシークレット/
topspin /トップスピン/
topstar /トップスター/
topten /トップテン/
toptime /トップタイム;和製英語/
tor /トール/
toradja /トラジャ/
torah /トーラー/トラー/トーラ/
toraja /トラジャ/
toraji /トラジ/
torch /トーチ/
toreador /トレアドール/
toredomin /トレドミン/
torerant /トレラント;※tolerant?/
torino /トリノ/
torn /トーン/
tornado /トルネード/
toronto /トロント/トロント大学/
torque /トルク/
torr /トル;=mmHg/
torre /トーレ/
torrent /トレント/
torres /トーレス/
torrey /トリー/トーリー/
torricelli /トリチェリ/
torrie /トリー/
torso /トルソー/
torsten /トルステン/
torte /トルテ;(独語)/
tortilla /トルティーヤ/トルティージャ/
tortoise /トータス/
torus /トーラス/
torvalds /トーバルズ/
tory /トリー/トーリー/
tosca /トスカ/
toscana /トスカーナ/トスカナ/
toscanini /トスカニーニ/
tosh /トッシュ/
toss /トス/
tossbatting /トスバッティング/
tostem /トステム;www.tostem.co.jp/
total /トータル/
totalcoordinate /トータルコーディネート/
totebag /トートバッグ/
totem /トーテム/
totempole /トーテムポール/
totipotent /トティポテント/
toto /トト/
totocalcio /トトカルチョ/
totti /トッティ/
touch /タッチ/
touchdown /タッチダウン/
touchline /タッチライン/
touchout /タッチアウト;和製英語(tag out)/
touchpanel /タッチパネル/
touchpen /タッチペン;和製英語/
touchsensor /タッチセンサー/
touchtype /タッチタイプ/
touchtyping /タッチタイピング/
touchup /タッチアップ;touch-up/
tough /タフ/
toughguy /タフガイ/
toughness /タフネス/
toulon /ツーロン/トゥーロン/
toulouse /トゥールーズ/ツールーズ/
tour /ツアー/
tourbus /ツアーバス;tour bus/
tourconductor /ツアーコンダクター/
tourdefrance /ツールドフランス;le Tour de France/
tourguide /ツアーガイド/
touring /ツーリング/
tourism /ツーリズム/
tourist /ツーリスト/
tourmarine /トルマリン/
tournament /トーナメント/
tournier /トゥルニエ/
tours /ツール/トゥール/ツアーズ/
toussaint /トゥーサン/
tove /トーベ/
toward /トワード/トゥワード/
towel /タオル/
towelhanger /タオルハンガー/
towelket /タオルケット;和製英語(towel+blanket)/
tower /タワー/
towering /タワーリング/
towermansion /タワーマンション/
towerrecord /タワーレコード;www.towerrecords.com/
towers /タワーズ/
town /タウン/
townes /タウンズ/
townhall /タウンホール/
townmeeting /タウンミーティング/
townpage /タウンページ;itp.ne.jp/
towns /タウンズ/
townsville /タウンズビル/
toxin /トキシン/
toy /トイ/
toynbee /トインビー/
toyopet /トヨペット/
toyota /トヨタ;www.toyota.co.jp/
toypiano /トイピアノ/
toypoodle /トイプードル/
toys /トイズ/
toyshop /トイショップ/
toysrus /トイザらス/トイザラス/
trace /トレース/トレイス/
traceability /トレーサビリティ/トレーサビリティー/
tracer /トレーサ/トレーサー/
tracey /トレイシー/トレーシー/
tracing /トレーシング/
tracingpaper /トレーシングペーパー/
track /トラック/
trackback /トラックバック/
trackball /トラックボール/
trackdown /トラックダウン/
tracker /トラッカー/
tracking /トラッキング/
trackpad /トラックパッド/
traction /トラクション/
tractor /トラクター/トラクタ/
tracy /トレイシー/トレーシー/
trad /トラッド/
trade /トレード/
trade-off /トレードオフ/
tradecenter /トレードセンター/
tradecentre /トレードセンター/
trademark /トレードマーク;TM/
tradeoff /トレードオフ/
trader /トレーダー/
trading /トレーディング/
tradingcard /トレーディングカード/
tradition /トラディション/
traditional /トラディショナル/
trafalgar /トラファルガー/
traffic /トラフィック/トラヒック/
tragedy /トラジェディ/
tragic /トラジック/
trail /トレイル/トレール/
trailer /トレーラー/
trailerhouse /トレーラーハウス/
train /トレイン/
trainee /トレーニー/トレイニー/
trainer /トレーナー/トレーナ/トレイナー/トレイナ;<rare>/
training /トレーニング/
trainingmachine /トレーニングマシン/トレーニングマシーン/
trainingwear /トレーニングウェア/
tram /トラム/
tramp /トランプ/
trampoline /トランポリン/
trance /トランス/
tranceiver /トランシーバ;※transceiver/トランシーバー;※transceiver/
trancy /トランシー/
tranquilizer /トランキライザー/トランキライザ/
trans /トランス/
transaction /トランザクション/
transactional /トランザクショナル/
transceiver /トランシーバー/トランシーバ/
transcript /トランスクリプト/
transcription /トランスクリプション/
transducer /トランスジューサ/
transfer /トランスファー/転送/
transform /トランスフォーム/
transformer /トランスフォーマー/
transgender /トランスジェンダー/
transgenic /トランスジェニック;遺伝子組換え/
transient /トランジェント/
transistor /トランジスタ/トランジスター/
transit /トランジット/
transition /トランジション/
translate /トランスレート/
translater /トランスレータ/
translation /トランスレーション/
translator /トランスレータ/トランスレーター/
transmission /トランスミッション/
transmit /転送/
transmitter /トランスミッター/トランスミッタ/
transnational /トランスナショナル/
transparent /トランスペアレント/透過/
transpersonal /トランスパーソナル/
transport /トランスポート/
transpose /トランスポーズ/
transputer /トランスピュータ/
transsexual /トランスセクシャル/
transversal /トランスバーサル/
transylvania /トランシルヴァニア/
trap /トラップ/タラップ;(蘭語)/
trapping /トラッピング/
trappists /トラピスト/
trash /トラッシュ/
trattoria /トラットリア/
trauma /トラウマ/
traumerei /トロイメライ/
travail /トラバーユ/
travel /トラベル/トラヴェル/
traveler /トラベラー/
travelers /トラベラーズ/
travelerscheck /トラベラーズチェック;traveler's check, TC/
traveling /トラベリング/
traveller /トラベラー/
travellers /トラベラーズ/
travelling /トラベリング/
travers /トラバース/
traverse /トラバース/
traverso /トラヴェルソ/
traviata /トラヴィアータ;椿姫/
travolta /トラボルタ/
trawl /トロール/
tray /トレー/トレイ/
tread /トレッド/
treadmill /トレッドミル/
treasure /トレジャー/
treasury /トレジャリー/
treat /トリート/
treatment /トリートメント/
trebbiano /トレッビアーノ/
treble /トレブル/
tree /ツリー/
trehalose /トレハロース/
trek /トレック/
trekker /トレッカー/
trekking /トレッキング/
trema /¨/
tremolo /トレモロ/
trench /トレンチ/
trenchcoat /トレンチコート/
trend /トレンド/
trendmicro /トレンドマイクロ/
trendo /トレンド;trend?/
trendy /トレンディ/トレンディー/
trento /トレント/
tres /トレ/トレス/
tresbien /トレビアン/
trevi /トレビ/トレヴィ/
trevise /トレビス/
trezeguet /トレゼゲ/
tri /トリ;3/
triad /トライアド/
trial /トライアル/
trialkit /トライアルキット/
triangle /トライアングル/△/▲/▽/▼/
triathlete /トライアスリート/
triathlon /トライアスロン/
triazolam /トリアゾラム/
tribal /トライバル/
tribe /トライブ/
tribune /トリビューン/
tribute /トリビュート/
trichloro /トリクロロ/
trichloroethylene /トリクロロエチレン/
trichomonas /トリコモナス/
tricia /トリシア/
trick /トリック/
trickart /トリックアート/
tricks /トリックス/
trickster /トリックスター/
tricky /トリッキー/
triclosan /トリクロサン/
tricolore /トリコロール/
trident /トライデント/
trie /トライ;<reTRIEval/
triennale /トリエンナーレ/
trieste /トリエステ/
triffid /トリフィド/
trigger /トリガー/トリガ/
triglyceride /トリグリセリド/
trigonelline /トリゴネリン/
trigraph /三連文字/
trihalomethane /トリハロメタン;THM/
trilemma /トリレンマ/
trill /トリル/
trim /トリム/
trimethylamine /トリメチルアミン/
trimmer /トリマー/
trimming /トリミング/
trine /トリーネ/トライン/
trinidad /トリニダード;Cuba/
trinitron /トリニトロン/
trinitrotoluene /トリニトロトルエン;TNT/
trinity /トリニティ;三位一体/トリニティー/
trino /トリノ/
trio /トリオ/
trip /トリップ/
tripeptide /ポリペプチド/
triple /トリプル/
triplea /トリプルA/トリプルＡ/
tripleplay /トリプルプレー/トリプルプレイ/
tripleroom /トリプルルーム/
triplet /トリプレット/
tripod /トライポッド/トリポッド/
tripoli /トリポリ/
tripper /トリッパー/
tripping /トリッピング/
tris /トリス/
tristan /トリスタン/
triste /トリスト/
tristram /トリストラム/
tritech /トライテック/
triton /トリトン/
triumph /トライアンフ;勝利/トリンプ;(独語) www.triumph.com/
trivia /トリビア/トリヴィア/
trivial /トリビアル/
trix /トリックス/
troche /トローチ/
troff /ティーロフ/
troia /トロイア/
troika /トロイカ/
trois /トロワ/
troll /トロール/トロル/
trolley /トロリー/
trolling /トローリング/
trombone /トロンボーン/
trompeloeil /トロンプルイユ;trompe-l'oeil/
tron /トロン/
trondheim /トロンヘイム/
troop /トループ/
trophy /トロフィー/トロフィ/
tropical /トロピカル/
tropicalfruit /トロピカルフルーツ/
tropicalfruits /トロピカルフルーツ/
tropicana /トロピカーナ/
troppo /トロッポ/
trotsky /トロツキー/
troubadour /トルバドゥール/トゥルバドゥール/
trouble /トラブル/
troublemaker /トラブルメーカー/
troubleshoot /トラブルシュート/
troubleshooting /トラブルシューティング/
trough /トラフ/
troussier /トルシエ/
trout /トラウト/
troy /トロイ/
troyounce /トロイオンス;31.1035g/
truck /トラック/
trucker /トラッカー/
true /トゥルー/正/
truetype /ＴｒｕｅＴｙｐｅ/
truffaut /トリュフォー/
truffe /トリュフ/
truffle /トリュフ;(英語綴り)/
trulli /トゥルーリ/
truman /トルーマン/トゥルーマン/
trump /トランプ/
trumpet /トランペット/
trumpeter /トランペッター/
trumpoline /トランポリン;※trampoline/
trunk /トランク/
trunkroom /トランクルーム/
trunks /トランクス/
truss /トラス/
trussardi /トラサルディ/
trust /トラスト/
truth /トゥルース/
try /トライ/
try&error /トライ＆エラー/
tryout /トライアウト/
trypsin /トリプシン/
tryptophan /トリプトファン;Trp/
ts /ц;tse (cyrillic)/
tsar /ツァー/ツァーリ/
tse /ц;cyrillic/
tshirt /Ｔシャツ/Tシャツ/ティーシャツ/
tshirts /Ｔシャツ/Tシャツ/ティーシャツ/
tu /テュ/
tuba /チューバ/
tube /チューブ/
tubeless /チューブレス/
tuberkulin /ツベルクリン/
tubetop /チューブトップ/
tubular /チューブラー/チューブラ/
tubularbell /チューブラベル/チューブラーベル/
tuck /タック/
tucker /タッカー/
tuckin /タックイン/
tucking /タッキング/
tuckseal /タックシール/
tucson /ツーソン/トゥーソン/
tue /火/
tuesday /チューズデイ/チューズデー/チューズディ/チューズディー/
tuft /タフト;房/
tug /タグ/
tugboat /タグボート/
tugjump /タグジャンプ/
tuka /ツーカー;www.tu-ka.co.jp/
tulip /チューリップ/
tull /タル/
tulle /チュール/
tullelace /チュールレース/
tumble /タンブル/
tumbler /タンブラー/
tumi /トゥミ;www.tumi.com/
tuna /ツナ/
tunakai /トナカイ;(アイヌ語)/
tunasalad /ツナサラダ/
tundra /ツンドラ/
tune /チューン/
tuner /チューナー/チューナ/
tuneup /チューンナップ/チューンアップ/
tungsten /タングステン;[元素]74,W/
tungus /ツングース/
tunic /チュニック/
tuning /チューニング/テューニング;<rare>/
tunis /チュニス/
tunisia /チュニジア;.tn/
tunnel /トンネル/
tunneling /トンネリング/トネリング/
tuple /タプル/
tupper /タッパー/
tupple /タプル;?/
turban /ターバン/
turbine /タービン/
turbo /ターボ/
turbocharger /ターボチャージャー/
turboengine /ターボエンジン/
turbolighter /ターボライター;和製英語/
turbolinux /ターボリナックス;www.turbolinux.com/
turco /トルコ/
turcogp /トルコGP;[F1]/
turf /ターフ/
turfan /トルファン;中国/
turgenev /ツルゲーネフ/
turing /チューリング/テューリング/
turingmachine /チューリングマシン/
turingtest /チューリングテスト/
turk /トルコ/土耳古/
turkestan /トルキスタン/
turkey /トルコ;.tr/ターキー/
turkmen /トルクメン/
turkmenistan /トルクメニスタン;.tm/
turmeric /ターメリック/
turn /ターン/
turnaround /ターンアラウンド/
turner /ターナー/
turning /ターニング/
turningmachine /チューリングマシン/
turningpoint /ターニングポイント/
turnover /ターンオーバー/
turnpike /ターンパイク/
turnstile /├/┣/ターンスタイル/
turntable /ターンテーブル/
turquoise /ターコイズ/
turquoiseblue /ターコイズブルー/
turtle /タートル/
turtleneck /タートルネック/
tuscan /タスカン/
tuscana /トスカナ/
tutankhamen /ツタンカーメン;Tut Ankh Amen/
tutor /チューター/チュータ/
tutorial /チュートリアル/
tutti /トゥッティ/
tutu /チュチュ/
tuvalu /ツバル;.tv/トゥ;tv/
tuxedo /タキシード/
tv /テレビ/テレビジョン/
tvanime /TVアニメ/テレビアニメ/ＴＶアニメ/
tvantenna /テレビアンテナ/
tvasahi /テレビ朝日;www.tv-asahi.co.jp/
tvboard /テレビボード/
tvcamera /テレビカメラ/
tvcm /テレビCM/
tvdrama /TVドラマ/テレビドラマ/ＴＶドラマ/
tvgame /テレビゲーム/TVゲーム/ＴＶゲーム/
tvmonitor /テレビモニター/テレビモニタ/TVモニター/TVモニタ/
tvnews /テレビニュース/TVニュース/ＴＶニュース/
tvseries /テレビシリーズ/
tvshopping /テレビショッピング/TVショッピング/
tvtokyo /テレビ東京;www.tv-tokyo.co.jp/
tvtuner /テレビチューナー/テレビチューナ/
twain /トウェイン/トウェーン/
tweed /ツイード/
tweeter /ツイーター/ツィーター/
twei /ツヴァイ/
twelve /トウェルブ/トゥウェルブ/
twenty /トウェンティ/
twilight /トワイライト/
twill /ツイル/
twin /ツイン/
twin-peaks /ツイン・ピークス/
twinbed /ツインベッド/
twinbee /ツインビー;[ゲーム]コナミ/
twincam /ツインカム/
twindrum /ツインドラム/
twining /トワイニング/
twinkle /トゥインクル/ツインクル/
twinpeaks /ツインピークス/
twinroom /ツインルーム/
twins /ツインズ/
twintail /ツインテール/
twist /ツイスト/
twisted /ツイステッド/
twister /ツイスター/
twistpair /ツイストペア;twisted-pair/
twistpaircable /ツイストペアケーブル;twisted-pair cable/
two /ツー/
twobase /ツーベース;double/
twobass /ツーバス/
twobeat /ツービート/
twobyfour /ツーバイフォー/
twoout /ツーアウト/
twopiece /ツーピース/
twoplatoons /ツープラトン/
tworun /ツーラン/
twoshot /ツーショット/
twostep /ツーステップ/
twotone /ツートン;two-tone/ツートーン/
twotonecolor /ツートンカラー;two-tone/
twotonecolour /ツートンカラー;two-tone/
twotop /ツートップ/
twoway /ツーウェイ/
tx /Texas/テキサス/
txtfile /TXTファイル/テキストファイル/
tyler /タイラー/
tylor /タイラー/
tyltyl /チルチル/
tyndall /チンダル/
tyner /タイナー/
type /タイプ/型/
typea /タイプA/タイプＡ/
typeb /タイプB/タイプＢ/
typec /タイプC/タイプＣ/
typemiss /タイプミス/
typesetter /タイプセッタ/
typewriter /タイプライター/タイプライタ/
typhoon /タイフーン/
typhus /チフス/
typical /ティピカル/
typing /タイピング/
typist /タイピスト/
typo /タイポ/
typographer /タイポグラファ/
typography /タイポグラフィ/タイポグラフィー/
tyr /チュール/
tyrannosaurus /ティラノサウルス/
tyre /タイヤ/
tyrosine /チロシン;Tyr/
tyson /タイソン/
tzara /ツァラ/
tzone /Ｔゾーン/Tゾーン/
u /υ;upsilon/ユー/у;cyrillic/ウラン/Uranium/
ubiquitous /ユビキタス/ユービキタス/
uboat /Ｕボート/Uボート/ユーボート/
ud /ウード/
ufa /ウファ/
ufocatcher /UFOキャッチャー;[商標]SEGA/
uganda /ウガンダ;.ug/
ugly /アグリー/
ugo /ウーゴ/
ui /ユーザーインターフェース/ユーザインターフェース/
uid /ユーザーID/ユーザID/
uif /ユーザ・インタフェース/
uighur /ウイグル/
uk /イギリス/
ukraina /ウクライナ/
ukraine /ウクライナ;.ua/
ukulele /ウクレレ/
ulanbator /ウランバートル/
ulanude /ウランウデ/
ulf /ウルフ/
ulla /ウラ/ウッラ/
ulm /ウルム/
ulrich /ウルリヒ/ウルリッヒ/
ultima /ウルティマ/
ultimate /アルティメット/
ultra /ウルトラ/
ultrac /ウルトラC;和製語/ウルトラＣ/
ultralight /ウルトラライト/
ultraman /ウルトラマン/
ultramarine /ウルトラマリン;群青色/
ulysses /ユリシーズ/
um /UNIX Magazine/
umar /オマル/ウマル/
umayyads /ウマイヤ/
umberto /ウンベルト/
umbrella /アンブレラ/
umbria /ウンブリア/
umlaut /¨/ウムラウト/
umma /ウンマ/
umount /アンマウント/
umpire /アンパイア/
un /アン/
una /ウナ/ウーナ/
unakite /ユナカイト/
unbalance /アンバランス/
unbelievable /アンビリーバボー/アンビリーバブル/
unberbar /アンダーバー;_/
unbundle /アンバンドル/
uncle /アンクル/
und /ウント/
undead /アンデッド/
under /アンダー/
underbust /アンダーバスト;under bust/
undercoat /アンダーコート/
undercover /アンダーカバー/
underflow /アンダーフロー/
underfull /アンダーフル/
underground /アンダーグラウンド/アンダーグランド/アングラ/
underhair /アンダーヘア/
underline /アンダーライン/
underpar /アンダーパー/
underrun /アンダーラン/
underscore /アンダースコア/
undershirt /アンダーシャツ/
undershirts /アンダーシャツ/
understand /アンダースタンド/
underwater /アンダーウォーター/
underwear /アンダーウェア/
underworld /アンダーワールド/
undine /ウンディーネ/
undo /アンドゥ/
undulation /アンジュレーション/
uneck /Ｕネック/Uネック/
unesco /ユネスコ;www.unesco.org/
unfair /アンフェア/
unformat /アンフォーマット/
ungaro /ウンガロ/
unhappy /アンハッピー/
uni /ユニ/
unicast /ユニキャスト/
unicef /ユニセフ;www.unicef.org/
unicode /ユニコード/
unicorn /ユニコーン/
unifiable /ユニファイアブル/
unification /ユニフィケーション/
unifier /ユニファイア/
uniform /ユニフォーム/ユニホーム/
unify /ユニファイ/単一化/
unilateralism /ユニラテラリズム/
unimaga /ユニマガ/UNIX Magazine/
uninstall /アンインストール/
uninstaller /アンインストーラ/アンインストーラー/
union /ユニオン/∪/共用体/共有体/
uniprocessor /ユニプロセッサ/
uniq /ユニーク/
uniqlo /ユニクロ;www.uniqlo.com/
unique /ユニーク/
uniquinone /ユビキノン/
unisex /ユニセックス/
unisol /ユニソル/
unison /ユニゾン/
unisys /ユニシス;www.unisys.com/
unit /ユニット/単位/
unitary /ユニタリ/
unitbath /ユニットバス;和製英語(prefabricated bath)/
unite /ユニテ;仏語/
united /ユナイテッド/
unity /ユニティ/ユニティー/
universal /ユニバーサル/
universaldesign /ユニバーサルデザイン/
universalservice /ユニバーサルサービス/
universalstudio /ユニバーサルスタジオ;www.universalstudios.com/
universe /ユニバース/ユニヴァース/
universiade /ユニバーシアード/
university /ユニバーシティ/
unix /ユニックス/UNIX/
unixfair /ＵＮＩＸフェアー/
unixmagazine /ＵＮＩＸマガジン/
unknown /アンノウン/アンノーン/
unlimited /アンリミテッド/
unlink /アンリンク/
unload /アンロード/
unlock /アンロック/
unlucky /アンラッキー/
unmap /アンマップ/
unmount /アンマウント/
uno /ウノ/ウーノ/
unofficial /アンオフィシャル/
unparse /アンパーズ/
unparser /アンパーザ/アンパーザー/
unplayable /アンプレアブル/アンプレヤブル/
unplugged /アンプラグド/
unreal /アンリアル/
unrecognized /識別不能/
unrolling /アンローリング/
untied /アンタイド/
until /アンティル/
untouchable /アンタッチャブル/
up /アップ/↑/
upanisad /ウパニシャッド/
uparrow /↑/
upbeat /アップビート/
upcall /アップコール/
updata /アップデータ;[新語]/
update /アップデート/アップデイト/
updater /アップデータ/
updike /アップダイク/
updown /アップダウン/
upfront /アップフロント/
upgrade /アップグレード/
uplight /アップライト/
uplightpiano /アップライトピアノ/
uplink /アップリンク/
upload /アップロード/
uploader /アップローダー/アップローダ/
upon /アポン/
upper /アッパー/
uppercut /アッパーカット/
uppermiddle /アッパーミドル/
uppsala /ウプサラ/
upright /アップライト/
uprightpiano /アップライトピアノ/
upset /アップセット/
upside /アップサイド/
upsilon /υ/ユプシロン/
upstream /アップストリーム/
uptempo /アップテンポ/
uptime /アップタイム/
uptown /アップタウン/
upward /アップワード/
ur /ウル/
ura /ウラー/
uracil /ウラシル;U/
ural /ウラル/
uran /ウラン;U/
uranium /ウラニウム;U/ウラン;[元素]92,U/
uranos /ウラノス/
uranus /ウラヌス/
urban /アーバン/
urbanlife /アーバンライフ/
urdu /ウルドゥ/ウルドゥー/
urea /ユリア;尿素/
urethan /ウレタン/
urethane /ウレタン/
urgent /アージェント/
uribe /ウリベ/
uriel /ウリエル/
urs /ウルス/
ursula /ウルスラ/アーシュラ/
uruguay /ウルグアイ;.uy/
us /アス/
usability /ユーザビリティ/
usama /ウサマ/
usasu /ウシャス/
usbbus /USBバス;NB:Universal Serial Bus bus/
usbcable /USBケーブル/
usbcard /USBカード/
usbdevice /USBデバイス/
usbdrive /USBドライブ/
usbhub /USBハブ/
usbkeyboard /USBキーボード/
usbmemory /USBメモリ/USBメモリー/
usbmouse /USBマウス/
use /ユーズ;[動詞]/ユース;[名詞]/
usecase /ユースケース/
used /ユーズド/
user /ユーザー/ユーザ/USER/
useraccount /ユーザーアカウント/ユーザアカウント/
useragent /ユーザエージェント/ユーザーエージェント/
userfriendly /ユーザーフレンドリー/ユーザフレンドリー/ユーザフレンドリ/
usergroup /ユーザーグループ/ユーザグループ/
userguide /ユーザガイド/
userid /ユーザーID/ユーザID/ユーザid/
userinterface /ユーザーインターフェース/ユーザインタフェース/
usermanual /ユーザーマニュアル/ユーザマニュアル/
usermode /ユーザモード/
users /ユーザーズ/
usersguide /ユーザーズガイド/
userside /ユーザーサイド/ユーザサイド/
usersmanual /ユーザーズマニュアル/
usersupport /ユーザーサポート/ユーザサポート/
usher /アッシャー/
usr /ユーザ;user/ユーザー/
usual /ユージュアル/
ut /Utah/ユタ/
utah /ユタ;UT/
utility /ユーティリティ/ユーティリティー/
utilitysoft /ユーティリティソフト/
utnet /UTnet/
utopia /ユートピア/
utpcable /UTPケーブル/
utrecht /ユトレヒト/
utrillo /ユトリロ/
uturn /Ｕターン/Uターン/
uu /UNIX USER/
uub /ウンウンビウム/Ununbium/
uucp /UUCP/
uuh /ウンウンヘキシウム/Ununhexium/
uun /ウンウンニリウム/Ununnilium/
uuo /ウンウンオクチウム/Ununoctium/
uuq /ウンウンクアジウム/Ununquadium/
uuu /ウンウンウニウム/Unununium/
uva /ウバ/ウヴァ/
uvcut /UVカット/
uwe /ウーヴェ/
uzbek /ウズベク/
uzbekistan /ウズベキスタン;.uz/
v /ブイ/ヴイ/в;ve (cyrillic)/∨;or/↓/バナジウム/Vanadium/
va /ビオラ/Virginia/ヴァージニア/バージニア/
vacance /バカンス/ヴァカンス/
vacation /バケーション/ヴァケーション/
vaccine /ワクチン/
vaccinesoft /ワクチンソフト/
vacuum /バキューム/
vacuumcar /バキュームカー/
vader /ベイダー/ベーダー/ヴェイダー/
vadim /ヴァディム/ワディム/
vaduz /ファドーツ/
vagabond /バガボンド/
vagina /ヴァギナ/ワギナ/バギナ/
vague /ヴァーグ/バーグ/
vaio /バイオ;[商標]SONY/ヴァイオ/
vaisya /バイシャ/ヴァイシャ/
vakzin /ワクチン;(独語)/
val /ヴァル/バル/
valdes /バルデス/
vale /ヴェール/
valencia /バレンシア/
valentine /バレンタイン/ヴァレンタイン/
valentineday /バレンタインデー;2.14/
valentino /バレンチノ;www.valentino.it/ヴァレンティノ/ヴァレンチノ/ヴァレンティーノ/
valeria /ヴァレリア/
valerie /ヴァレリー/バレリー/
valeron /バレロン/
valery /ヴァレリー/ワレリー/
valetudo /バーリトゥード;vale tudo/
valeur /バルール/ヴァルール/
valhalla /ヴァルハラ/
valiant /バリアント;勇壮/ヴァリアント/
valid /ヴァリッド/バリッド/恒真/
validation /バリデーション/
valine /バリン;Val/
valken /ヴァルケン/
valkyrie /ワルキューレ/ヴァルキューレ/ヴァルキリー/
valletta /ヴァレッタ/
valley /バレー/
valli /ヴァリ/
valse /ヴァルス;(Fr)ワルツ/
value /バリュー/ヴァリュー/値/Ｖａｌｕｅ/
valuechain /バリューチェーン/
valve /バルブ/ヴァルヴ/
valvu /バルブ/
vamp /バンプ/ヴァンプ/
vampire /ヴァンパイア/バンパイア/バンパイヤ/ヴァンパイヤ/
van /ファン;van der Waals/ヴァン;van Gogh/バン/
vanadium /バナジウム;[元素]23,V/
vanallen /バンアレン;Van Allen/ヴァンアレン/バン・アレン/ヴァン・アレン/
vancomycin /バンコマイシン/
vancouver /バンクーバー/
vanda /バンダ/ヴァンダ/
vanderbilt /ヴァンダービルト/バンダービルト/
vanderwaals /ファンデルワールス;Johannes Diderik van der Waals (1837-1923)/
vandyck /ファンダイク;van Dyck/
vanessa /ヴァネッサ/
vangelis /ヴァンゲリス/
vanguard /バンガード/ヴァンガード/
vanilla /バニラ/ヴァニラ/
vanillabeans /バニラビーンズ/ヴァニラビーンズ/
vanillaessence /バニラエッセンス/
vanillaice /バニラアイス/
vanille /ヴァニーユ;(Fr) バニラ/バニーユ/
vanuatu /バヌアツ;.vu/
vanvogt /ヴァン=ヴォークト/
vanya /ワーニャ/
varaha /ヴァラーハ/
varanasi /ヴァラナシ/バラナシ;インド(vns)/
varela /バレラ/
varese /ヴァレーズ/
vargas /ヴァルガス/
variable /バリアブル/ヴァリアブル/変数/
variant /バリアント;異本/ヴァリアント/
variation /バリエーション/ヴァリエーション/
variety /バラエティー/バラエティ/ヴァラエティ/ヴァリエティ;<rare>/
varig /ヴァリグ/
varna /ヴァルナ/
varnish /ワニス/ニス/
vartan /バルタン/
vasallo /バサロ/
vasco /バスコ/ヴァスコ/
vascodagama /バスコダガマ;(1469?-1524) Vasco da Gama/ヴァスコダガマ/
vaseline /ワセリン/ヴァセリン/
vasquez /バスケス/
vat /バット/
vatican /バチカン;.va/ヴァチカン/ヴァティカン/
vaucher /バウチャー/
vaudeville /ヴォードヴィル/ボードビル/
vaudevillian /ボードビリアン/
vaughan /ヴォーン/ボーン/
vault /ボールト/ヴォールト/
vax /VAX/
vazquez /バスケス/
vc /チェロ/ビレッジセンター/Ｖｃ/
vcine /Ｖシネ;video + cinema/Vシネ/
vcinema /Ｖシネマ;video + cinema/Vシネマ/
vdash /├/
vdots /：;全角のコロン/
ve /в;cyrillic/
vector /ベクター/ベクトル/ベクタ/
vectorchi /ベクトル値/
veda /ヴェーダ/
vee /∨/ブイ/ヴィー/
vega /ベガ/ヴェガ/
vegas /ベガス;Las Vegas/
vegetable /ベジタブル/
vegetarian /ベジタリアン/
vehicle /ビークル/ヴィークル/
veil /ベール/ヴェール/
veinna /ウインナー/
vela /ベラ/ヴェラ/
velazquez /ベラスケス/
vella /ベラ/ヴェラ/
velma /ヴェルマ/
veloce /ヴェローチェ/
velocity /ベロシティ/ヴェロシティ/
velvet /ベルベット/ヴェルヴェット/
vendemiaire /ヴァンデミエール/
vender /ベンダー/ベンダ/
vendor /ベンダー/ベンダ/ヴェンダー/
veneer /ベニヤ/ベニア/
venetian /ベネチアン/ヴェネチアン/ヴェネツィアン/ベネシャン/
venezia /ヴェネチア/ヴェネツィア/ベネチア/ベネツィア/
venezuela /ベネズエラ;.ve/
venice /ベニス/ヴェニス/
venn /ベン/ヴェン/
venom /ヴェノム/ベノム/
vent /ベント/
venta /ベンタ/
venter /ベンター/
ventilation /ベンチレーション/
ventilator /ベンチレーター/
ventri /ベンチュリ/
venture /ベンチャー/ベンチャ/
venturebusiness /ベンチャービジネス/
venturecapital /ベンチャーキャピタル/
ventures /ベンチャーズ/
venus /ヴィーナス/ウェヌス/
venusline /ビーナスライン;信州の観光道路。www.venus-line.net/
vera /ベラ/ヴェラ/
verandah /ベランダ/
verbal /バーバル/
verbena /バーベナ/
verbose /バーボス/冗長な/
verde /ベルデ;(西語)緑/ヴェルデ/
verdi /ヴェルディ/ベルディ/
verdun /ベルダン/ヴェルダン/
verdy /ヴェルディ;[Jリーグ]東京/
vergilius /ウェルギリウス/ヴェルギリウス/
veridian /ビリジアン/
verify /ベリファイ/
verisign /ベリサイン;www.verisign.com/VeriSign/
verlaine /ヴェルレーヌ/ベルレーヌ/
vermeer /フェルメール/
vermiculite /バーミキュライト;蛭石/
vermilion /バーミリオン/
vermillion /バーミリオン/ヴァーミリオン/
vermont /バーモント;VT/
vermouth /ベルモット/
vernacular /ヴァナキュラー/バナキュラー/
verne /ヴェルヌ/
vernier /バーニア/
vernon /ヴァーノン/バーノン/
verona /ヴェローナ/ベローナ/ベロナ/ヴェロナ/
veronica /ヴェロニカ/ベロニカ/
veronique /ヴェロニク/ベロニク/
verra /ベラ/ヴェラ/
verre /ヴェール;(Fr)ガラス/
versace /ヴェルサーチ;ww.versace.com/ベルサーチ/
versailles /ベルサイユ/ヴェルサイユ/
verse /ヴァース;歌詞/
version /バージョン/ヴァージョン/版/
version-up /バージョンアップ/
versionup /バージョンアップ/ヴァージョンアップ/
versus /バーサス/ヴァーサス/
vert /ヴェール;(Fr)緑/
vertical /バーティカル/ヴァーティカル/⊥/垂直/垂直方向/
verve /ヴァーヴ/
very /ベリー/ベリィ/
vespa /ベスパ/
vessel /ベッセル/
vest /ベスト/
vesta /ベスタ/ヴェスタ/
vesuvio /ベスビオ/ヴェスヴィオ/
vet /ヘット;(蘭語)牛脂/
veteran /ベテラン/ヴェテラン/
vgoal /Ｖゴール;victory + goal/Vゴール/
vhll /VHLL(Very High Level Language)/
vi /ヴィ/
via /ビア/ヴィア/バイア/ヴァイア/
viagra /バイアグラ/
vian /ヴィアン/
vib /バイブ;vibrator/ヴァイブ/
vibraphone /ビブラフォン/ヴィブラフォン/
vibraslap /ビブラスラップ/ヴィブラスラップ/
vibration /バイブレーション/
vibrato /ビブラート/ヴィブラート/
vibrator /バイブレーター/バイブレータ/
vic /ビック/
vice /ヴァイス/
vicente /ビセンテ/
vichy /ヴィシー/
vichyssoise /ビシソワーズ/ヴィシソワーズ/
vicious /ヴィシャス/ビシャス/
vick /ヴィック/
vicki /ヴィッキー/
vicky /ビッキー/ヴィッキー/
victoire /ヴィクトワール/
victor /ビクター/ヴィクター/ヴィクトル/ビクトル/ヴィクトール/ ビクトール/
victoria /ビクトリア/ヴィクトリア/
victorian /ヴィクトリアン/ビクトリアン/
victory /ビクトリー/ヴィクトリー/
vidal /ヴィダル/ビダル/
vidalsassoon /ヴィダルサスーン;www.vidalsassoon.com/
video /ビデオ/ヴィデオ/
videocable /ビデオケーブル/
videocamera /ビデオカメラ/
videocapture /ビデオキャプチャ/ビデオキャプチャー/
videocard /ビデオカード/
videocasette /ビデオカセット/
videocd /ビデオCD/
videochat /ビデオチャット/
videochip /ビデオチップ/
videoclip /ビデオクリップ/
videodeck /ビデオデッキ/
videogame /ビデオゲーム/
videoletter /ビデオレター/
videomemory /ビデオメモリ/
videomessage /ビデオメッセージ/
videorecorder /ビデオレコーダー/
videorental /ビデオレンタル/
videoresearch /ビデオリサーチ;www.videor.co.jp/
videoshop /ビデオショップ/
videotape /ビデオテープ/
videotex /ビデオテックス/
vie /ヴィ;仏語/ヴィー/
vieil /ヴィエイユ/
vieille /ヴィエイユ/
vienna /ウィンナー/ウィンナ/
viennoiserie /ヴィエノワズリー;(Fr) 菓子パン類/
vientiane /ヴィエンチャン/ビエンチャン;ラオス(vte)/
vieri /ヴィエリ/
vietnam /ベトナム;.vn/ヴェトナム/ヴィエトナム/
vieux /ヴュー/
view /ビュー/Ｖｉｅｗ/ヴュー/
viewer /ビューア/ビューアー/ビューワ/ビューワー/
viewhotel /ビューホテル/
viewing /ビューイング/
viewpoint /ビューポイント/
viewport /ビューポート/
vigny /ヴィニー/ビニー/
vigor /ビガー/
vihara /ビハーラ/ヴィハーラ/
viking /バイキング/ヴァイキング/
viktor /ヴィクトル/ヴィクトール/
viktoria /ヴィクトリア/
vila /ビラ/
villa /ビラ/ヴィラ/ビジャ/
village /ビレッジ/ヴィレッジ/ヴィラージュ;仏語/
villeneuve /ビルヌーブ/ヴィルヌーヴ/
villeroy /ビレロイ/
villon /ヴィヨン/
vilnyus /ヴィリニュス/
vin /ヴァン;(Fr) ワイン/
vina /ヴィーナ/
vinaigrette /ビネグレット/ヴィネグレット/
vince /ビンス/ヴィンス/
vincent /ヴィンセント/ビンセント/ヴァンサン/
vincenzo /ヴィンチェンツォ/
vinci /ヴィンチ/ビンチ/
vine /ヴァイン/バイン/
vinegar /ビネガー/ヴィネガー/
vinnie /ヴィニー/ビニー/
vinny /ヴィニー/ビニー/
vinson /ヴィンソン/ビンソン/
vintage /ヴィンテージ/ビンテージ/
vinyl /ビニール/ビニル/
vinylalcohol /ビニルアルコール/
vinylcover /ビニールカバー/
vinylhouse /ビニールハウス;和製英語(plastic greenhouse)/
vinylidene /ビニリデン/
vinylsheet /ビニールシート/
vinyltape /ビニールテープ/
viola /ビオラ/ヴィオラ/
violation /バイオレーション/
violence /バイオレンス/
violent /バイオレント/
violet /バイオレット/ヴァイオレット/
violetta /ヴィオレッタ/
violin /ヴァイオリン/バイオリン/
violinist /ヴァイオリニスト/バイオリニスト/
violinsonata /ヴァイオリンソナタ/バイオリンソナタ/
violon /ヴィオロン;(Fr)バイオリン/
viper /バイパー/ヴァイパー/
virgin /バージン/ヴァージン/
virginia /バージニア;VA/ヴァージニア/
virginie /ヴィルジニー/
virginoil /バージンオイル/
virginroad /バージンロード;和製英語/
virgo /バーゴ;乙女座/ヴァーゴ/バルゴ/ビルゴ/
viridian /ビリジアン/
virtual /バーチャル/ヴァーチャル/仮想/
virtualdomain /バーチャルドメイン/
virtualhost /バーチャルホスト/
virtualmachine /バーチャルマシン/
virtualmall /バーチャルモール/
virtualpet /バーチャルペット/
virtualreality /バーチャルリアリティ/
virtuoso /ヴィルトゥオーゾ/ヴィルトゥオーソ/
virus /ウイルス/ウィルス/ビールス/ヴィールス/
virusbuster /ウイルスバスター/ウィルスバスター/
viruscheck /ウイルスチェック/ウィルスチェック/
virusmail /ウイルスメール/ウィルスメール/
virusscan /ウイルススキャン/ウィルススキャン/
virussoft /ウイルスソフト/
vis /ビス/
visa /ビザ/ヴィザ/
visacard /VISAカード;www.visa.com/ビザカード/
visconti /ビスコンティ/ヴィスコンティ/
vision /ビジョン/ヴィジョン/視覚/
visionary /ビジョナリー/
visit /ビジット/ヴィジット/
visitor /ビジター/
visnu /ヴィシュヌ/
visor /バイザー/
vissel /ヴィッセル;[Jリーグ]神戸/
vista /ビスタ/ヴィスタ/
visual /ビジュアル/ヴィジュアル/
visualisation /ビジュアライゼーション/
visualise /ビジュアライズ/
visualization /ビジュアライゼーション/
visualize /ビジュアライズ/
vita /ヰタ;ラテン語/ヴィタ/
vital /バイタル/
vitality /バイタリティ/バイタリティー/ヴァイタリティ/
vitamin /ビタミン/
vitamina /ビタミンA/ビタミンＡ/
vitamina# /ビタミンA#0/ビタミンＡ#0/
vitaminb /ビタミンB/ビタミンＢ/
vitaminb# /ビタミンB#0/ビタミンＢ#0/
vitaminc /ビタミンC/ビタミンＣ/
vitamind /ビタミンD/ビタミンＤ/
vitamind# /ビタミンD#0/
vitamine /ビタミン/ビタミンE/ビタミンＥ/
vitamink /ビタミンK/ビタミンＫ/
vitesse /ヴィテス;(Fr)速度/
vittorio /ヴィットーリオ/ヴィットリオ/
vitz /ヴィッツ;[商標]トヨタ/
viv /ヴィヴ/
viva /ビバ;(It)万歳/ヴィヴァ/
vivace /ヴィヴァーチェ/ビバーチェ/
vivaldi /ヴィヴァルディ/ビバルディ/
vivant /ヴィヴァン;仏語/
vivarium /ビバリウム/
vive /ビブ;(Fr)万歳/ヴィヴ/
vivian /ビビアン/ヴィヴィアン/
vivid /ビビッド/ヴィヴィッド/
vividcolor /ビビッドカラー/
vividcolour /ビビッドカラー/
vivien /ヴィヴィアン/
vivo /ヴィーヴォ/ビーボ/
vjebeta /VJE-β/
vlad /ブラッド/ブラド/ヴラド;Vlad was here!/
vladimir /ウラジミール/ウラジーミル/ウラディミール/ヴラディミール/
vladivostok /ウラジオストク;ロシア(vvo)/ウラジオストック;ロシア/
vleague /Vリーグ/Ｖリーグ/
vltava /ヴルタヴァ/
vn /ヴァイオリン/
vneck /Ｖネック/Vネック/ブイネック/
vocabulary /ボキャブラリー/ボキャブラリ/語彙/ヴォキャブラリ;<rare>/ヴォキャブラリィ;<rare>/
vocal /ボーカル/ヴォーカル/
vocalise /ヴォカリーズ/ヴォーカリーズ/
vocalist /ヴォーカリスト/ボーカリスト/
voce /ヴォーチェ/
vocoder /ボコーダー/ボコーダ/
vodafone /ボーダフォン;www.vodafone.jp/
vodka /ウォッカ/
vogue /ヴォーグ/ボーグ/
voice /ボイス/ヴォイス/
voicechat /ボイスチャット/
voicemail /ボイスメール/
voicepercussion /ボイスパーカッション/
voicerecorder /ボイスレコーダー/
voices /ヴォイセズ/
voicetraining /ボイストレーニング/
voicing /ボイシング/ヴォイシング/
void /ボイド/ヴォイド/
volante /ボランチ/
volga /ボルガ/ヴォルガ/
volk /フォルク;(独語)/
volker /フォルカー/
volkl /Ｖｏｌｋｌ/
volkswagen /フォルクスワーゲン/
volley /バレー/ボレー/
volleyball /バレーボール/
volt /ボルト/
volta /ボルタ/ヴォルタ/
voltage /ボルテージ/
voltaire /ヴォルテール/ボルテール/
volume /ボリューム/ヴォリューム/
volumeup /ボリュームアップ/
voluntary /ボランタリー/
volunteer /ボランティア/
volvo /ボルボ/
volvox /ボルボックス/
von /フォン/
vongole /ボンゴレ/
vonnegut /ヴォネガット/
vonneumann /フォンノイマン;von Neumann/フォン・ノイマン/
voodoo /ブードゥー/ヴードゥー/
vorpal /ボーパル/ヴォーパル/
vortex /ボルテックス/ヴォルテックス/
vostok /ボストーク/ヴォストーク/
vote /ボート/
voyager /ボイジャー/
vr /バーチャルリアリティ;virtual reality/バーチャルリアリティー/
vs /versus/バーサス/ｖｓ．/
vsign /Ｖサイン/Vサイン;(^-^)v/
vt /Vermont/バーモント/ヴァーモント/
vuitton /ヴィトン;www.vuitton.com/
vulcan /バルカン/
vulnerability /ヴァルネラビリティ/
vulunteer /ボランティア/
vzone /Ｖゾーン/Vゾーン/
w /ダブリュー/タングステン/Tungsten/
wa /Washington/ワシントン/
wa-pro /ワープロ/
wacoal /ワコール;www.wacoal.co.jp/
wafer /ウェハ/ウエハー/ウェハー/ウェーハ/ウエーハ/ウェファ/
wafers /ウエハース/
waffle /ワッフル/
wagen /ワーゲン/
wagner /ワーグナー/ワグナー/ヴァーグナー/ワグネル/
wagon /ワゴン/
wagonsale /ワゴンセール/
waikiki /ワイキキ/
wais /ウェイズ/
waist /ウエスト/ウェスト/
waistbag /ウエストバッグ;和製英語/ウェストバッグ/
waistline /ウエストライン/
waistpouch /ウエストポーチ;和製英語(belt bag)/
waistsize /ウエストサイズ/
wait /ウェイト/ウエイト/
waiter /ウェイター/
waiting /ウェイティング/
waitress /ウェイトレス/
waits /ウェイツ/
waiver /ウェーバー/
wake /ウェイク/
wakeboard /ウェイクボード/
wakeup /ウェイクアップ/
walden /ウォールデン/
waldo /ウォルド/ワルド/ウォルドー/
waldstein /ワルトシュタイン/
wales /ウェールズ/
walk /ウォーク/
walker /ウォーカー/
walkin /ウォークイン/
walkincloset /ウォークインクローゼット;walk-in closet/
walking /ウォーキング/
walkingshoes /ウォーキングシューズ/
walkman /ウォークマン;[商標]SONY/
walkrally /ウォークラリー/
walkthrough /ウォークスルー/
walkure /ワルキューレ/ヴァルキューレ/
wall /ウォール/
wallaby /ワラビ/ワラビー/
wallace /ウォーレス/ウォレス/
wallet /ウォレット/
wallstreet /ウォールストリート/ウォール街/
wally /ウォーリー/
walmart /ウォルマート;www.walmart.com/
walnut /ウォルナット;胡桃/
walnuts /ウォールナッツ/ウォルナッツ/
walras /ワルラス/
walsh /ウォルッシュ/
walt /ウォルト/
walter /ウォルター/ワルター/ヴァルター/
walther /ワルター/ワルサー/ヴァルター/ウォルター/バルター/
waltherp# /ワルサーP#0/
waltz /ワルツ/
wand /ワンド/
wanda /ワンダ/ヴァンダ/
wander /ワンダー/
wanderer /ワンダラー/
wandering /ワンダリング/
wandervogel /ワンダーフォーゲル;(独語)/
wanernmusic /ワーナーミュージック;wmg.com/
wangel /ワンゲル;Wandervogel(?)/
wannabe /ワナビー/
want /ウォント/
wanted /ウォンテッド/
wants /ウォンツ/
wappen /ワッペン;(独語)/
war /ウォー/
ward /ワード/
wardrobe /ワードローブ/
ware /ウェア/ウエア/Ｗａｒｅ/
warehouse /ウェアハウス/ウエアハウス/
waren /ワーレン/
warhol /ウォーホル/
warlock /ウォーロック/
warlord /ウォーロード/
warm /ウォーム/
warmbiz /ウォームビズ;[新語]和製英語/
warmer /ウォーマー/
warming /ウォーミング/
warmingup /ウォーミングアップ/
warmup /ウォームアップ/
warn /ワーン/ウォーン/
warner /ワーナー/
warning /ワーニング/ウォーニング/警告/
warp /ワープ/
warrant /ワラント/
warren /ウォーレン/
warrior /ウォーリア/ウォーリアー/ウォリアー/
warriors /ウォーリアーズ/ウォリアーズ/
wars /ウォーズ/
warship /ウォーシップ/
warszawa /ワルシャワ;ポーランド/
was /ワズ/ウォズ/
wash /ウォッシュ/
washable /ウォッシャブル/
washer /ワッシャー/ウォッシャー/ワッシャ/
washing /ウォッシング/
washington /ワシントン/
washingtondc /ワシントンＤＣ/ワシントンDC/
washingtonhotel /ワシントンホテル/
washlet /ウォシュレット;和製英語/ワォシュレット;<rare>/
wasp /ワスプ/
waste /ウェイスト/
wat /ワット/
watch /ウォッチ/
watchdog /ウォッチドッグ/
watching /ウォッチング/
water /ウォーター/
waterbed /ウォーターベッド/
waterbottle /ウォーターボトル/
watercooler /ウォータークーラー/
waterfall /ウォーターフォール/ウォータフォール/
waterfront /ウォーターフロント/
watergarden /ウォーターガーデン/
watergate /ウォーターゲート/
waterhazard /ウォーターハザード/
waterjet /ウォータージェット/
waterloo /ワーテルロー/ウォータールー/
watermark /ウォーターマーク;透かし/
waterproof /ウォータープルーフ/
watersport /ウォータースポーツ/
watersports /ウォータースポーツ/
watkins /ワトキンス/
watson /ワトソン/ワトスン/
watt /ワット/
watts /ワッツ/
wave /ウェーブ/ウエーブ/ウェイブ/ウェイヴ/波/
wavefront /ウェーブフロント/
wavelet /ウェーブレット/
wavfile /WAVファイル/
wavy /ウェービー/
wax /ワックス/
way /ウェイ/ウェー/ウエイ/
wayne /ウェイン/ウエイン/
ways /ウェイズ/
we /ウィ/ウィー/
weak /ウィーク/
weakpoint /ウィークポイント/
wealth /ウェルス/
weapon /ウェポン/ウエポン/
wear /ウェア/ウエア/
weather /ウェザー/ウエザー/
weatherreport /ウェザーリポート/
web /ウェブ/
webbrowser /WEBブラウザ/ウェブブラウザ/
webcomic /Webコミック/ウェブコミック/
webdesign /ウェブデザイン/
webdesigner /ウェブデザイナー/
webdirectory /ウェブディレクトリ/
webdrama /Webドラマ/ウェブドラマ/
weber /ウェーバー/ウェバー/ヴェーバー/ウェーバ/
webern /ウェーベルン/
weblog /ウェブログ;blog/
webmagazine /WEBマガジン/ウェブマガジン/
webmail /ウェブメール/
webmaster /ウェブマスター/
webmoney /ウェブマネー/
webpage /ウェブページ/Webページ/
webradio /Webラジオ/ウェブラジオ/
webring /ウェブリング/
webserver /Webサーバ/ウェブサーバ/ウェブサーバー/webサーバ/
webservice /Webサービス/ウェブサービス/webサービス/
website /Webサイト/ウェブサイト/webサイト/
webster /ウェブスター/ウエブスター/
wed /水/
wedding /ウェディング/ウエディング/
weddingbell /ウェディングベル/ウエディングベル/
weddingcake /ウェディングケーキ/
weddingdress /ウェディングドレス/ウエディングドレス/
wedeln /ウェーデルン/
wedge /∧/ウェッジ/
wedgewood /ウェッジウッド/
wedgwood /ウェッジウッド/
wednesday /ウェンズデー/ウェンズデイ/ウェンズディ/
weed /ウィード/
week /ウィーク/ウイーク/
weekday /ウィークデー/ウィークデイ/
weekend /ウィークエンド/
weekly /ウィークリー/ウイークリー/
weeklymansion /ウィークリーマンション/
weeks /ウィークス/
wegner /ウェグナー/ウェゲナー/
weight /ウェイト/ウェート/
weightlifting /ウェイトリフティング/
weighttraining /ウェイトトレーニング/
weil /ヴェイユ/
weimar /ワイマール/
wein /ウェイン/ウエイン/ヴァイン;(独語)ワイン/
weird /ウィアード/
weisman /ワイズマン/ワイスマン/
weiss /ヴァイス/
weissman /ワイスマン/
welcome /ウェルカム/ウエルカム/
welfare /ウェルフェア/
well /ウェル/ウェール/
well-done /ウェルダン/
wellcity /ウェルシティ;厚生年金会館/
welldone /ウェルダン/
weller /ウェラー/
welles /ウェルズ/
wellington /ウェリントン/
wellness /ウェルネス/ウエルネス/
wells /ウェルズ/
welsh /ウェルシュ/
welter /ウェルター/
wenders /ヴェンダース/
wendy /ウェンディ/ウェンディー/
went /ウェント/
wentz /ウエンツ/ウェンツ/
were /ワー/
werner /ワーナー/ウェルナー/ベルナー/ヴェルナー/
wernicke /ウェルニッケ/
wes /ウェス/ウエス/
wesley /ウェスリー/
wessex /ウェセックス/
wesson /ウェッソン/
west /ウエスト/
westcoast /ウエストコースト;西海岸/ウェストコースト/
westend /ウエストエンド/
western /ウエスタン/ウェスタン/
westernleague /ウエスタンリーグ/
westminster /ウェストミンスター/ウエストミンスター/
westphalia /ウェストファリア/ウエストファリア/
westside /ウェストサイド/ウエストサイド/
westvirginia /ウェストバージニア;WV/ウエストバージニア;WV/
wet /ウェット/ウエット/
wetsuit /ウェットスーツ/
wetsuits /ウェットスーツ/
wettype /ウェットタイプ/
weyl /ワイル/
wg /ワーキンググループ/
whale /ホエール/
what /ホワット/
what's /ホワッツ/
whats /ホワッツ;what's/
wheat /フィート;小麦/
wheel /ホイール/
wheelbase /ホイールベース/
wheelclick /ホイールクリック/
wheeler /ホイーラー/
wheelie /ウィリー/ウイリー/
wheelmouse /ホイールマウス/
where /ホエア/ウェア/
whey /ホエー;乳清/ホエイ/
which /フィッチ/
while /ワイル/ホワイル/ファイル/
whip /ホイップ/
whipcream /ホイップクリーム/
whipper /ホイッパー/
whisker /ウィスカー/ウイスカー/
whiskey /ウイスキー/ウィスキー/ウヰスキー/
whisky /ウイスキー/ウィスキー/
whisper /ウィスパー/
whistle /ホイッスル/
white /ホワイト/
whiteasparagus /ホワイトアスパラガス/
whiteband /ホワイトバンド;www.whiteband.org/
whiteboard /ホワイトボード/
whitebox /ホワイトボックス/
whitechoco /ホワイトチョコ/
whitechocolate /ホワイトチョコレート/
whitechristmas /ホワイトクリスマス;white Christmas/
whitecollar /ホワイトカラー/
whitecuracao /ホワイトキュラソー/
whiteday /ホワイトデー/ホワイトデイ/
whitehole /ホワイトホール/
whitehouse /ホワイトハウス/
whiteknight /ホワイトナイト/
whitelist /ホワイトリスト/
whitening /ホワイトニング/
whitenoise /ホワイトノイズ/
whiteopal /ホワイトオパール/
whiteout /ホワイトアウト/
whitepapper /ホワイトペッパー/
whitepearl /ホワイトパール/
whiterum /ホワイトラム/
whitesauce /ホワイトソース/
whitesox /ホワイトソックス;[MLB]White Sox/
whitexmas /ホワイトクリスマス;white Christmas/
whitman /ホイットマン/
whitney /ホイットニー/
who /フー/
whodunit /フーダニット;推理小説/Who done it?/
whole /ホール/
wholesale /ホールセール/
wholesaler /ホールセラー/
wholetomato /ホールトマト/
whom /フム/
whose /フーズ/
why /ホワイ/
whydunit /ホワイダニット/Why done it?/
wi /Wisconsin/ウィスコンシン/
wicky /ウィッキー/
wide /ワイド/WIDE/
wideangle /ワイドアングル/
widearea /ワイドエリア/
widescreen /ワイドスクリーン/
wideshow /ワイドショー/ワイドショウ/
widesize /ワイドサイズ/
widespan /ワイドスパン/
widetv /ワイドテレビ/
widget /ウィジェット/ウィジット/Widget/
widow /ウィドウ/ウィドー/
width /幅/
wie /ヴィー;(独語)/
wien /ウィーン/
wiener /ウインナー/ウィンナー/ウィナー/ウィンナ/ウインナ/ウィーナー/
wienphil /ウィーンフィル;Wiener Philharmoniker/
wiese /ヴィーゼ/
wiest /ウィースト/
wife /ワイフ/
wig /ウィッグ/
wiki /ウィキ/
wikipedia /ウィキペディア;wikipedia.org/
wilbur /ウィルバー/
wild /ワイルド/
wildcard /ワイルドカード/
wildcat /ワイルドキャット/
wilde /ワイルド/
wilder /ワイルダー/
wilderness /ウィルダネス/
wildflower /ワイルドフラワー/
wildlife /ワイルドライフ/
wildpitch /ワイルドピッチ/
wildrice /ワイルドライス;マコモ/
wildstrawberry /ワイルドストロベリー/
wiley /ウィリー/ワイリー;人名/
wilfred /ウィルフレッド/
wilhelm /ヴィルヘルム/ウィルヘルム/
wilkins /ウィルキンズ/
wilkinson /ウィルキンソン/
will /ウィル/
willcom /ウィルコム;www.willcom-inc.com/
willem /ウィレム/
william /ウィリアム/ウイリアム/
williams /ウィリアムズ/ウイリアムズ/ウィリアムス/ウイリアムス/
williamson /ウィリアムソン/ウィリアムスン/
willie /ウィリー/
willis /ウィリス/ウイリス/
willow /ウィロー/
willy /ウィリー/ウイリー/
wilm /ヴィルム/
wilma /ウィルマ/
wilson /ウィルソン/ウイルソン/ウィルスン/
wim /ヴィム/
wimbledon /ウィンブルドン/ウインブルドン/
win /ウィン/ウイン/
winch /ウインチ/ウィンチ/
winchester /ウィンチェスター/
wind /ウインド/ウィンド/
windbreaker /ウインドブレーカー/ウィンドブレーカー/
windchime /ウインドチャイム/ウィンドチャイム/
windham /ウィンダム/ウインダム/
windhoek /ウィントフック/
winding /ワインディング/
windmill /ウィンドミル/
windom /ウィンダム/ウインダム/
window /ウィンドウ/ウインドウ/ウインドー/
windowing /ウインドウィング/
windowmanager /ウィンドウマネージャ/
windows /ウィンドウズ/ウインドウズ/Windows/
windowsystem /ウィンドウシステム/
windsor /ウィンザー;UK/
windsurfing /ウインドサーフィン/ウィンドサーフィン/
windup /ワインドアップ/
windy /ウィンディ/ウィンディー/ウインディ/ウインディー/
wine /ワイン/
winebar /ワインバー/
winecellar /ワインセラー/
winecooler /ワインクーラー/
wineglass /ワイングラス/
wineopener /ワインオープナー/
winered /ワインレッド/
winery /ワイナリー/
winevinegar /ワインビネガー/
wing /ウイング/ウィング/
wings /ウィングス/
wink /ウインク/ウィンク/Ｗｉｎｋ/
winker /ウインカー/ウィンカー/
winner /ウィナー/ウイナー/
winners /ウィナーズ/
winnie /ウィニー/
winning /ウイニング/ウィニング/
winningball /ウイニングボール/
winningrun /ウイニングラン/ウィニングラン/
winnipeg /ウィニペグ/
winny /ウィニー/
wins /ウィンズ/ウインズ/
winston /ウィンストン/ウインストン/
winter /ウィンター/ウインター/
winterp /WINTERP(Widget Interpreter)/
wintersports /ウィンタースポーツ/
wipe /ワイプ/
wipeout /ワイプアウト/
wiper /ワイパー/
wire /ワイヤー/ワイヤ/ワイア/ワイアー/
wirebrush /ワイヤーブラシ/
wirecable /ワイヤーケーブル/
wired /ワイヤード/
wiredor /ワイヤードオア/
wireframe /ワイヤーフレーム/ワイヤフレーム/
wireless /ワイヤレス/
wirelessmouse /ワイヤレスマウス/
wirelock /ワイヤーロック/
wirerope /ワイヤーロープ/ワイヤロープ/
wirewrapping /ワイヤラッピング/
wiring /ワイヤリング/
wisconsin /ウィスコンシン;WI/
wisdom /ウィズダム/
wise /ワイズ/
wiseman /ワイズマン/
wish /ウィッシュ/
wishbone /ウィッシュボーン/
wisp /ウィスプ/
wit /ウィット/
witch /ウィッチ/
with /ウィズ/ウイズ/
wither /ウィザー/
witherspoon /ウィザースプーン/
within /ウィズイン/
without /ウィズアウト/
witness /ウィットネス/
wittgenstein /ウィトゲンシュタイン/
witty /ウィッティ/
witz /ウィッツ/
wizard /ウィザード/
wizardry /ウィザードリィ/ウイザードリィ/
wm /ウィンドウマネージャー/
wnn /Ｗｎｎ/WNN/
wolf /ウルフ/ヴォルフ/
wolfe /ウルフ/
wolff /ウォルフ/ウルフ/ボルフ/
wolfgang /ヴォルフガング/ウォルフガング/
wolfram /タングステン;[元素]74,W/ウォルフラム/ヴォルフラム/
wolframium /タングステン;[元素]74,W/
wolter /ウォルター/
woman /ウーマン/
womanlib /ウーマンリブ;women's liberation/
womans /ウーマンズ;woman's/
womb /ウーム/
wombat /ウォンバット/
women /ウィメン/ウィミン/
womens /ウィメンズ;women's/
won /ウォン/ウオン/
wonder /ワンダー/
wonderful /ワンダフル/
wonderland /ワンダーランド/
wonderswan /ワンダースワン;[商標]バンダイ/
wont /ウォント;won't/
wood /ウッド/
woodbass /ウッドベース/
woodblock /ウッドブロック/
woodcraft /ウッドクラフト/
wooddeck /ウッドデッキ/
woodfence /ウッドフェンス/
woodpecker /ウッドペッカー/
woods /ウッズ/
woodshole /ウッズホール/
woodstock /ウッドストック/
woodward /ウッドワード/
woody /ウディ/ウッディ/ウッディー/ウディー/
woofer /ウーファー/ウーハー/ウーファ/
woogie /ウギ/
wool /ウール/
woolf /ウルフ/
woolly /ウーリー/
woolmark /ウールマーク/
wooly /ウーリー/
worcester /ウスター/ウースター/
word /ワード/
word-processor /ワードプロセッサ/ワープロ/ワードプロセッサー/
wordpad /ワードパッド/
wordprocessor /ワードプロセッサ/ワードプロセッサー/
words /ワーズ/
wordsworth /ワーズワース/
work /ワーク/
workaholic /ワーカホリック/
workarea /ワークエリア/
workaround /ワークアラウンド/
workbench /ワークベンチ/
workbook /ワークブック/
worker /ワーカー/
workflow /ワークフロー/
workgroup /ワークグループ/
working /ワーキング/
workinggroup /ワーキンググループ/
workingholiday /ワーキングホリデー/
workingmother /ワーキングマザー/
workingset /ワーキングセット/
workload /ワークロード/
workman /ワークマン/
workout /ワークアウト/
workroom /ワークルーム/
works /ワークス/
worksharing /ワークシェアリング/
worksheet /ワークシート/
workshop /ワークショップ/
workspace /ワークスペース/
workstation /ワークステーション/
workstyle /ワークスタイル/
world /ワールド/
worldcup /ワールドカップ;World Cup/
worldmusic /ワールドミュージック/
worlds /ワールズ/
worldseries /ワールドシリーズ/
worldtour /ワールドツアー/
worldwide /ワールドワイド/
worm /ワーム/
wormhole /ワームホール/
worpro /ワープロ/
worprosoft /ワープロソフト;word processor software/
worry /ウォーリー/
worse /ワース/
worship /ワーシップ/
worst /ワースト/
worst# /ワースト#0/ワースト#1/
worstone /ワーストワン/
worth /ワース/
would /ウド/ウッド/
wow /ワウ/
wowow /WOWOW/
wp /ワープロ/
wraith /レイス/
wrap /ラップ/
wrapper /ラッパー/ラッパ/
wrapping /ラッピング/
wreath /リース;花輪/
wrecker /レッカー/
wren /レン/
wrench /レンチ/
wrestler /レスラー/
wrestling /レスリング/
wright /ライト/
wrinkle /リンクル/
wrist /リスト/
wristband /リストバンド/
wristcut /リストカット;和製英語/
wristwatch /リストウォッチ/
write /ライト/書き込み/
writeonly /ライトオンリー/
writeprotect /ライトプロテクト/
writer /ライター/ライタ/
writing /ライティング/
writingdesk /ライティングデスク/
wrong /ロング/
ws /ワークステーション/WS/
wurzburg /ヴュルツブルク/ブルツブルク/
wv /West Virginia/ウェストヴァージニア/ウェストバージニア/ウエストバージニア/
wy /Wyoming/ワイオミング/ワイ/
wyatt /ワイアット/
wyler /ワイラー/
wyn /ウィン/
wyndham /ウィンダム/ウインダム/
wynn /ウィン/
wynne /ウィン/
wynton /ウィントン/ウイントン/
wyoming /ワイオミング;WY/
wyvern /ワイバーン/
x /エックス/エクス/×;バツ/ξ;xi/х;xa (cyrillic)/
x# /Ｘ#1/X#0/
x#r# /Ｘ#1Ｒ#1/
xa /х;cyrillic/
xan /ザン/
xanthan /キサンタン/
xanthangum /キサンタンガム/
xanthine /キサンチン/
xanthippe /クサンチッペ/クサンティッペ/
xanthos /クサントス/
xavier /ザビエル/ハビエル/クザヴィエ/
xc /XConsortium/
xday /Ｘデー;和製英語(D-day)/Ｘデイ/Xデー/Xデイ/
xe /キセノン/Xenon/
xenakis /クセナキス/
xenon /キセノン;[元素]54,Xe/
xenophon /クセノフォン/
xeon /ジオン/
xerography /ゼログラフィ/
xerox /ゼロックス/
xevious /ゼビウス;[ゲーム]ナムコ/
xi /ξ/クシー/クサイ/
xjiku /X軸/Ｘ軸/
xlib /Xlib/
xlisp /ＸＬｉｓｐ/XLisp/
xlsize /XLサイズ/ＸＬサイズ/
xmas /クリスマス;christmas/
xmascake /クリスマスケーキ/
xmascard /クリスマスカード/
xmascarol /クリスマスキャロル/
xmaseve /クリスマスイブ/クリスマスイヴ/
xmasparty /クリスマスパーティー/クリスマスパーティ/
xmaspresent /クリスマスプレゼント/
xmassale /クリスマスセール/
xmassong /クリスマスソング/
xmastree /クリスマスツリー;Christmas tree/
xpost /クロスポスト;crosspost/
xps /XPS(eXpansion Passing Style)/
xsen /X線/Ｘ線/エックス線/
xssize /XSサイズ/ＸＳサイズ/
xtc /エクスタシー/
xterminal /Ｘ端末/
xview /Ｘｖｉｅｗ/
xwindow /Ｘウィンドウ/
xx /××/
xylene /キシレン;C6H4(CH3)2/
xylitol /キシリトール/
xylo /キシロ/
xylocaine /キシロカイン/
xylophone /シロフォン/シロホン/
xylose /キシロース/
y /υ;upsilon/ワイ/й;cyrillic(i-kratkoje)/ы;cyrillic/イットリウム/Yttrium/
y# /#0円/
ya /←/→/↑/↓/ヤー/
yacht /ヨット/
yachtharbor /ヨットハーバー/
yachtharbour /ヨットハーバー/
yachtman /ヨットマン/
yachtrace /ヨットレース/
yachtsman /ヨットマン/
yah /ヤー/
yahoo /ヤフー;www.yahoo.com/Yahoo!/
yahooauction /ヤフーオークション;auctions.yahoo.co.jp/Yahoo!オークション/
yahoobb /Yahoo! BB/
yahweh /ヤハウェ/
yajirushi /→/←/↑/↓/
yak /ヤク/
yakult /ヤクルト/
yakutsk /ヤクーツク/
yale /エール/イェール/イエール/
yalta /ヤルタ/
yamaha /ヤマハ/
yamoussoukro /ヤムスクロ/
yan /ヤン/
yana /ヤナ/
yang /ヤン/
yangon /ヤンゴン/
yank /ヤンク/
yankee /ヤンキー/
yankees /ヤンキース;[MLB]/
yann /ヤン/
yaounde /ヤウンデ/
yaplog /ヤプログ;www.yaplog.jp/
yapoo /ヤプー/
yard /ヤード/
yarder /ヤーダ/
yarn /ヤーン/
yb /イッテルビウム/Ytterbium/
ydan /Ｙ談/
ye /е;cyrillic/
yea /イェイ/イエイ/イェー/イエー/イェア/
yeah /イェー/イエー/イェア/イェイ/イエイ/
year /イヤー/
years /イヤーズ/
yeast /イースト/
yeastfood /イーストフード/
yeats /イエーツ/イェーツ/イエイツ/
yellow /イエロー/イェロー/
yellowcab /イエローキャブ/
yellowcard /イエローカード/
yellowgreen /イエローグリーン/
yellowknife /イエローナイフ;カナダ(yzf)/
yellowpage /イエローページ/
yellowstone /イエローストーン/
yemen /イエメン;.ye/
yen /￥/円/
yenisei /エニセイ/
yepes /イエペス/
yerevan /エレヴァン/
yes /イエス/
yesman /イエスマン/
yessir /イエッサー;Yes, Sir!/
yesterday /イエスタデイ/イエスタディ/
yeti /イエティ/
yevgeny /エフゲニー/
yew /ユー/
yeye /イエイエ;ye-ye/
yggdrasil /ユグドラシル;[北欧神話]世界樹/イグドラシル/
yhwh /ヤハウェ/ヤーウェ/ヤーヴェ/エホバ/
yiddish /イディッシュ/
yield /イールド/
yjiku /Y軸/Ｙ軸/
yo /ё;cyrillic/
yocto /ヨクト;[SI接頭語]y,10^-24/
yoda /ヨーダ/
yodel /ヨーデル/
yoga /ヨガ/ヨーガ/
yogurt /ヨーグルト/
yoho /ヤッホー;yo-ho/
yoke /ヨーク/
yoko /─;罫線/━;太い罫線/
yolanda /ヨランダ/
yoni /ヨニ/
yoohoo /ヤッホー;yoo-hoo/
york /ヨーク/
yorkie /ヨーキー/
yorkshire /ヨークシャー/ヨークシャ/
yorkshireterrier /ヨークシャーテリア/ヨークシャテリア/
yorktown /ヨークタウン/
yosemite /ヨセミテ/
yotta /ヨタ;[SI接頭語]Y,10^24/
you /ユー/
young /ヤング/
youngadult /ヤングアダルト;young adult/
youngjump /ヤングジャンプ;集英社/
youngmagazine /ヤングマガジン;講談社/
youngsunday /ヤングサンデー;小学館/
your /ユア/
yours /ユアーズ/
yourself /ユアセルフ/
youth /ユース/
youthful /ユースフル/
youthhostel /ユースホステル/
yoyo /ヨーヨー/
ys /イース/
yshirt /ワイシャツ;和製英語(white shirt)/Ｙシャツ/Yシャツ/
yshirts /ワイシャツ;和製英語(white shirt)/Ｙシャツ/Yシャツ/
ytterbium /イッテルビウム;[元素]70,Yb/
yttrium /イットリウム;[元素]39,Y/
yu /ы;y (cyrillic)/
yucca /ユッカ/
yugo /ユーゴ/
yugoslavia /ユーゴスラビア;.yu/ユーゴスラヴィア/
yukar /ユーカラ;(アイヌ語)/ユカラ/
yukatan /ユカタン/
yukhoe /ユッケ;(朝鮮語)/
yul /ユル/
yulian /ユリアン/
yumin /ユーミン/
yuri /ユーリ/
yury /ユーリー/
yuzhnosakhalinsk /ユジノサハリンスク;Yuzhno-Sakhalinsk/
yves /イブ/イヴ/
yvessaintlaurent /イブサンローラン;Yves Saint Laurent/
yvette /イヴェット/イベット/
yvonne /イボンヌ/イヴォンヌ/
z /ζ;zeta/ゼット/з;ze (cyrillic)/
zabadak /ザバダック;誰にも知られず消えてゆく強さ/
zack /ザック/
zagreb /ザグレブ/
zaire /ザイール;.zr (現コンゴ .cd)/
zak /ザック/
zambezi /ザンベジ/
zambia /ザンビア/
zambrotta /ザンブロッタ/
zamenhof /ザメンホフ;(1859-1917) Esperantoの創案者/
zamora /サモラ/
zampona /サンポーニャ/
zanetti /ザネッティ/
zanzibar /ザンジバル/
zap /ザップ/
zapper /ザッパー/
zapping /ザッピング/
zaragoza /サラゴサ/
zarathustra /ツァラトゥストラ/
zardas /チャルダッシュ/
zaurus /ザウルス/
zaza /ザザ/
zazie /ザジ/
zbuffer /Zバッファ;Z-buffer/
ze /з;cyrillic/
zeal /ジール/
zebra /ゼブラ/
zechariah /ゼカリヤ/
zed /ゼット/ゼッド/
zee /ジー/ゼー/ゼット/
zeeman /ゼーマン/
zeit /ツァイト;(独語)時間/
zelda /ゼルダ/
zele /ゼール;(Fr)熱意/
zemi /ゼミ;semi?/
zener /ツェナー/
zenith /ゼニス/
zeno /ゼノ/
zenobia /ゼノビア/
zenon /ゼノン/
zeolite /ゼオライト/
zephaniah /ゼパニヤ/
zepher /ゼファー/
zephyr /ゼファー/ゼフィール/
zephyros /ゼフィロス;西風/
zeppelin /ツェッペリン/
zepto /ゼプト;[SI接頭語]z,10^-21/
zermatt /ツェルマット/
zero /ゼロ/〇/零/
zerobase /ゼロベース/
zeroemission /ゼロエミッション/
zerometre /ゼロメートル;sea level/
zerosum /ゼロサム;zero-sum/
zerosumgame /ゼロサムゲーム;zero-sum game/
zeste /ゼスト;(Fr) 柑橘類の皮/
zeta /ζ/ゼータ/
zetta /ゼタ;[SI接頭語]Z,10^21/
zeus /ゼウス/
zexy /ゼクシィ;[雑誌名]zexy.net/
zgundam /Zガンダム;[アニメ]ゼータガンダム/Ζガンダム;(ギリシア文字のZeta)/
zh /←/ж;zhe (cyrillic)/
zhe /ж;cyrillic/
zhivago /ジバゴ/
zico /ジーコ/
zidane /ジダン/
ziegler /ツィーグラー/
zigeuner /ツィゴイネル;(独語)ジプシー/
zigeunerweisen /ツィゴイネルワイゼン/チゴイネルワイゼン/
ziggy /Ｚｉｇｇｙ/
zigzag /ジグザグ/
zimbabwe /ジンバブエ;.zw/
zimbalon /ツィンバロン/
zimmerman /ツィンマーマン/
zina /ジナ/
zinc /ジンク;Zn/
zinedine /ジネディーヌ/
zinfandel /ジンファンデル/
zion /シオン;=Jerusalem/ジオン/ザイオン/
zionism /シオニズム/
zionist /シオニスト/
zip /ジップ/〒/
zipangu /ジパング/
zipfile /ZIPファイル/
ziplock /ジップロック/
zipper /ジッパー/
zippo /ジッポ;www.zippo.com/ジッポー/
zircon /ジルコン/
zirconia /ジルコニア/
zirconium /ジルコニウム;[元素]40,Zr/
zirkon /ジルコン/
zither /ツィター/シタール/
zizek /ジジェク/
zizi /ジジ/
zj /↓/
zjiku /Z軸/Ｚ軸/
zk /↑/
zl /→/
zn /亜鉛/Zinc/
znak /ъ;cyrillic (tvjordyj znak)/ь;cyrillic (xjaxkij znak)/
zodiac /ゾディアック/
zoe /ゾーイ/ゾエ/
zoff /ゾフ/
zola /ゾラ/
zoltan /ゾルタン/
zombie /ゾンビ/
zone /ゾーン/
zonedefence /ゾーンディフェンス/
zoning /ゾーニング/
zoo /ズー/
zoom /ズーム/
zoomin /ズームイン/
zooming /ズーミング/
zoomlens /ズームレンズ/
zoomout /ズームアウト/
zoot /ズート/
zoroaster /ゾロアスター/
zr /ジルコニウム/Zirconium/
zubrowka /ズブロッカ;(ポーランドのウォッカ)/
zucchini /ズッキーニ/
zuccotto /ズコット/
zurich /チューリッヒ/チューリヒ/
zyanose /チアノーゼ;(独語)/
zyklus /チクルス/ツィクルス/
{ /｛/
| /｜;pipe/│;罫線/┃;太い罫線/‖/
|- /├/┣/
|| /‖/
} /｝/
~ /〜/¬/￣/
ー /〜/
「 /『/【/〔/［/
」 /』/】/〕/］/
あ /亜/吾;私/彼;=吾/阿;阿呆/婀;婀娜っぽい/痾;宿痾/唖;聾唖/亞;「亜」の旧字(人名用漢字)/椏;また/娃;美女/哇/襾/安;?/明;?/嗚;?/
あ> /亜;亜熱帯,亜低木,亜硝酸/
あーくとう /アーク灯/
あーくほうでん /アーク放電/
あーくようせつ /アーク溶接;arc welding/
あーくろ /アーク炉/
あーけーどがい /アーケード街/
あーさーおう /アーサー王;Arthur King/
あーさーおうでんせつ /アーサー王伝説;roman arthurien/
あーすせん /アース線/
あーちがた /アーチ型/
あーちきょう /アーチ橋/
あーとし /アート紙/
あーとてん /アート展/
あーべるぐん /アーベル群/
あーりあじん /アーリア人;aryan/
ああ /嗚呼/噫/唖唖;カラスの声/あゝ/
あい /愛/相/藍/間/合/亜衣;人名/哀;悲哀/埃;(ほこり)塵埃/挨;挨拶/曖;曖昧/瞹;「曖」の異体字/靉/噫;ああ/欸/隘;狭隘/娃/藹;和気藹々/阨;≒隘/穢;(慣用音)/姶;姶良町/会;?/饗;?/
あい> /相;相まみえる,相勤める,相和す/愛;愛猫,愛バイク,愛労連(愛媛)/
あいあい /藹々;和気-/靄々/相合/藹藹/靄靄/
あいあいがさ /相合傘/相合い傘/
あいいく /愛育/
あいいそ /相磯/
あいいちろう /愛一郎/
あいいろ /藍色/
あいいん /愛飲/合印/
あいうえおじゅん /アイウエオ順/あいうえお順/
あいうち /相打ち/相討ち/相撃ち/
あいうら /相浦/
あいえ /藍絵/
あいえき /愛液/
あいえん /愛煙/
あいえんか /愛煙家/
あいえんきえん /合縁奇縁/
あいおい /相生/
あいか /哀歌/
あいかぎ /合鍵/合い鍵/
あいかた /相方/合方/
あいかわ /相川/愛川/鮎川/合川/
あいかわらず /相変わらず/
あいかん /哀感;pathos.「-漂う」/哀歓;pools of sorrow, waves of joy.「-を共にする」/
あいが /相賀/
あいがみ /間紙/藍紙/
あいがも /合鴨/間鴨;=合鴨/
あいがん /愛玩/哀願/
あいがんけん /愛玩犬/
あいがんどうぶつ /愛玩動物/
あいき /愛機/
あいきどう /合気道/
あいきゃく /相客/
あいきゅう /哀泣/
あいきょう /愛嬌/愛敬;=愛嬌/愛郷;-心/
あいきょうげん /間狂言/
あいぎ /合着/間着/
あいぎょう /愛敬;†愛され敬われる/愛楽;†愛し、求める/
あいぎん /愛吟/
あいくち /匕首/合口/合い口/
あいぐま /藍隈/
あいけい /愛敬/
あいけん /愛犬/
あいけんか /愛犬家/
あいこ /愛子/藍子/愛顧/アイ子/
あいこう /愛好/愛甲;地名/愛校/
あいこういしだ /愛甲石田/
あいこうか /愛好家/
あいこうかい /愛好会/
あいこうしゃ /愛好者/
あいこうしん /愛校心/
あいこうだいめいでん /愛工大名電/
あいこうぼん /愛好本/
あいこく /愛国/哀哭/
あいこくしん /愛国心/
あいことば /合言葉/合い言葉/
あいこんか /アイコン化/
あいご /愛護/愛語/
あいごま /合駒/合い駒/
あいさい /愛妻/
あいさいか /愛妻家/
あいさいごう /愛妻号/
あいさいべんとう /愛妻弁当/
あいさつ /挨拶/
あいさつご /挨拶語;Hello Bonjour 初めまして/
あいさつじょう /挨拶状/
あいさつまわり /挨拶回り/
あいさわ /相沢/
あいざわ /相沢/相澤/会沢/
あいし /哀史/間紙/哀詩/愛子/
あいしーかーど /ＩＣカード/ICカード/
あいしーたぐ /ＩＣタグ/ICタグ/
あいしかた /愛し方/
あいしゃ /愛車/愛社/
あいしゃせいしん /愛社精神/
あいしゅう /哀愁/愛執/
あいしょ /愛書/
あいしょう /相性/愛称/愛唱;†好んでうたう。「-歌集」/愛妾/哀傷/愛誦;†好んで口ずさむ。「ヴェルレーヌを-する」/合性/
あいしょううらない /相性占い/
あいしょうか /愛唱歌/
あいしょうきょく /愛唱曲/
あいしょうしんだん /相性診断/
あいしょうひょう /相性表/
あいしょうめい /愛称名/
あいしょうもんだい /相性問題/
あいしょか /愛書家/
あいしんかくら /愛新覚羅/愛新覺羅;旧字/
あいしんせいき /アイシン精機/
あいじ /愛児/
あいじゃく /愛著/
あいじょう /愛情/愛嬢/哀情/
あいじょうひょうげん /愛情表現/
あいじん /愛人/
あいすみちょう /愛住町/
あいず /合図/相図;=合図/会津;※仮名遣い「あいづ」/
あいずだい /会津大;※仮名遣い「あいづ」/
あいずだいがく /会津大学;※仮名遣い「あいづ」/
あいずばんだいさん /会津磐梯山;※仮名遣い「あいづ」/
あいずみ /藍住/
あいせき /相席/愛惜;大切にする/哀惜;悲しむ/合席/
あいせつ /哀切/
あいぜつ /哀絶/
あいぜん /愛染/
あいぜんみょうおう /愛染明王/
あいそ /愛想/哀訴/相磯/相曽/愛相/
あいそう /愛想/
あいそく /愛息/
あいそづかし /愛想尽かし/
あいそよく /愛想良く/
あいそわらい /愛想笑い/
あいそん /愛孫/
あいぞう /愛憎/愛蔵/
あいぞうげき /愛憎劇/
あいぞうばん /愛蔵版/
あいぞめ /藍染め/
あいたい /相対/靉靆/
あいたいばいばい /相対売買/
あいたしゅぎ /愛他主義;altruisme/
あいだ /間/相田/愛田/藍田/会田/合田/英田/
あいだい /愛大/
あいだがら /間柄/
あいだじゅう /間中/
あいだちょう /英田町/
あいち /愛知/相知/
あいちいかだいがく /愛知医科大学/
あいちいだい /愛知医大/
あいちかんじょうてつどう /愛知環状鉄道/
あいちがくせんだい /愛知学泉大/
あいちがくせんだいがく /愛知学泉大学/
あいちきょういくだい /愛知教育大/
あいちきょういくだいがく /愛知教育大学/
あいちきんろうかいかん /愛知勤労会館/
あいちぎんこう /愛知銀行/
あいちけん /愛知県/
あいちけんけい /愛知県警/
あいちけんじん /愛知県人/
あいちけんない /愛知県内/
あいちこうぎょうだいがく /愛知工業大学/
あいちこうじょう /愛知工場/
あいちこうせいねんきん /愛知厚生年金/
あいちこうだい /愛知工大/
あいちばんぱく /愛知万博;‖2005/
あいちべん /愛知弁/
あいちみと /愛知御津/
あいちゃく /愛着/合着;?/
あいちょう /愛聴/愛鳥/哀調/愛重/
あいちょうしゅうかん /愛鳥週間;bird week. 5.10-16/
あいちょうばん /愛聴盤/
あいつ /彼奴/
あいつぎ /相次/
あいづ /会津/
あいづき /相築/
あいづじょう /会津城/
あいづたかだ /会津高田/
あいづたじま /会津田島/
あいづだい /会津大/
あいづだいがく /会津大学/
あいづち /相槌/相づち/相鎚;=相槌/
あいづてつどう /会津鉄道/
あいづのうしょ /会津農書/
あいづばんだいさん /会津磐梯山/
あいづま /逢妻/
あいづわかまつ /会津若松/
あいづわかまつし /会津若松市/
あいて /相手/
あいてかた /相手方/
あいてがた /相手方/
あいてがわ /相手側/
あいてきぎょう /相手企業/
あいてきゅうだん /相手球団/
あいてきょく /相手局/
あいてぎんこう /相手銀行/
あいてこく /相手国/
あいてさき /相手先/
あいてしだい /相手次第/
あいてしゃりょう /相手車両/
あいてじんない /相手陣内/
あいてせいふ /相手政府/
あいてせんしゅ /相手選手/
あいてだしゃ /相手打者/
あいてとうしゅ /相手投手/
あいてやく /相手役/
あいてりきし /相手力士/
あいでぃーかーど /IDカード/
あいとう /哀悼/
あいどお /間遠/
あいどく /愛読/
あいどくしゃ /愛読者/
あいどくしょ /愛読書/
あいなかば /相半ば/
あいなめ /鮎魚女/鮎並/
あいにく /生憎/
あいぬご /アイヌ語;アイヌの言語。一部地名などに残る。/
あいぬみんぞく /アイヌ民族/
あいねずみ /藍鼠/
あいの /愛野/
あいのえき /愛野駅/
あいのこ /間の子/合いの子/
あいのす /愛の巣/
あいのちょう /愛野町/
あいのて /間の手/合いの手/合の手/
あいのみなこ /愛野美奈子/
あいのむち /愛の鞭/
あいのり /相乗り/
あいは /愛葉;名/
あいはら /相原/粟飯原/愛原/藍原;姓/合原/
あいはん /合判/相判/
あいば /愛馬/相羽/饗場/相庭/相場;姓/
あいばじょうほう /愛馬情報/
あいばら /相原/合原/
あいびき /逢引/逢い引き/合挽き/合挽/合い引き/
あいびょう /愛猫/
あいびょうか /愛猫家/
あいぴーあどれす /IPアドレス/
あいぴーでんわ /ＩＰ電話/IP電話/
あいふ /合符;手荷物合符/
あいふく /間服/合服/
あいふだ /合札/
あいぶ /愛撫/
あいべ /相部/
あいべつ /愛別/哀別/
あいべつりく /愛別離苦;愛する者との死別の苦しみ/
あいべや /相部屋/
あいぼ /愛慕/
あいぼう /相棒/
あいぼし /相星;[相撲]勝敗(星)数が同じ/
あいぼれ /相惚れ/
あいま /合間/合い間/
あいまあいま /合間合間/
あいまい /曖昧/
あいまいせい /曖昧性/
あいまいもこ /曖昧模糊/
あいまいやど /曖昧宿/
あいまって /相俟って/
あいみ /愛美/亜衣実/
あいみたがい /相身互い/
あいみつもり /合い見積もり;(concat "http:\057\057abc.trans.jp\057glossary\057aimitsu.htm")/
あいみるちゃ /藍海松茶/
あいもち /相持ち/
あいもと /相本/
あいもん /合文/
あいやく /相役/
あいやぐら /相矢倉;[将棋]/
あいやど /相宿/
あいやぶし /あいや節/
あいやま /相山/
あいよう /愛用/
あいようき /愛用機/
あいようしゃ /愛用者/
あいよく /愛欲/愛慾;=愛欲/
あいよし /相吉/
あいよつ /相四つ;[相撲]/
あいら /姶良;地名/吾平/
あいらく /哀楽/
あいり /愛里;名/
あいりん /愛輪/
あいるらんど /愛蘭/
あいれん /愛恋/哀憐;憐れむ/愛憐;愛し憐れむ/
あいろ /隘路/文色/
あいろんだい /アイロン台/
あいわ /哀話/
あいんすたいにうむ /Es/Einsteinium/
あう /央/奥/桜/奧;「奥」の旧字(人名用漢字)/媼;老女/櫻;「桜」の旧字(人名用漢字)/
あうすとろばいれやか /Austrobaileyaceae/
あうん /阿吽/
あえ /阿江/
あえぎ /喘ぎ/
あえぎごえ /喘ぎ声/
あえて /敢えて/
あえば /饗庭/
あえもの /和え物/韲え物/
あえり /愛絵理/
あえん /亜鉛/Zn/Zinc/
あえんか /亜鉛華/
あお /青/蒼/碧/
あお> /青;青ペン,青鉛筆,青線/
あおあお /青々/青青/蒼蒼/蒼々/
あおあざ /青痣/青アザ/
あおあらし /青嵐/
あおい /葵/青井/碧/
あおいきといき /青息吐息/
あおいけ /青池/
あおいし /青石/
あおいっしょく /青一色/
あおいとり /青い鳥;L'Oiseau Bleu, 1909, Maeterlinck/
あおいのうえ /葵上/葵の上;[源氏物語]/
あおいはな /青い花;Heinrich von Ofterdingen,1802,Garshin/
あおいまつり /葵祭/
あおいめ /青い目/
あおいもく /アオイ目/Malvales/
あおいもん /葵紋/
あおいろ /青色/
あおいろしんこく /青色申告/
あおうなばら /青海原/
あおうま /白馬;† NB:「あを」は本来白灰色/青馬;†/
あおうみがめ /青海亀/
あおえ /青江/青絵/
あおえきしょう /青液晶/
あおおに /青鬼/
あおかち /青褐/
あおかび /青黴/青カビ/青かび/
あおかん /青姦;[卑]/青かん/
あおがい /青貝/
あおがえる /青蛙/
あおがき /青垣/
あおがく /青学/青山学院大学;※abbrev/
あおがくだい /青学大/
あおがしま /青ヶ島/
あおがり /青刈り/
あおき /青木/
あおきいさお /青木功;人名/
あおきいろ /青黄色/
あおきがはら /青木ヶ原/
あおきこ /青木湖/
あおきこんよう /青木昆陽;人名/
あおきっぷ /青切符/
あおきばし /青木橋/
あおきん /青金/
あおぎいろ /青黄色/
あおぎり /青桐/榮;「栄」の旧字(人名用漢字)/
あおくさ /青草/
あおくび /青首/
あおくびだいこん /青首大根/
あおけいとう /青系統/
あおげ /青毛/
あおこーなー /青コーナー/
あおさ /石蓴/
あおさぎ /青鷺/
あおさび /青錆/
あおさぶらい /青侍/
あおざかな /青魚/
あおざむらい /青侍/
あおしお /青潮/
あおしか /青鹿/
あおしま /青島/青嶋/
あおしんごう /青信号/
あおじ /青地/
あおじそ /青紫蘇/青ジソ/
あおじゃしん /青写真/
あおじる /青汁/
あおすじ /青筋/
あおせざかな /青背魚/
あおせん /青線;赤線の外のモグリ/
あおそ /青麻/青苧/
あおぞら /青空/蒼空/
あおぞらいちば /青空市場/
あおぞらきょうしつ /青空教室/
あおぞらちゅうしゃ /青空駐車/
あおぞらぶんこ /青空文庫;電子テキストを多く集めたサイト。www.aozora.gr.jp/
あおた /青田/
あおたがい /青田買い/
あおたがり /青田刈り/青田刈/
あおたけ /青竹/
あおたん /青短;花札で青色の短冊の札および役/青痰/青丹;あおに?/
あおだいしょう /青大将/
あおだけ /青竹/
あおだけいろ /青竹色/
あおだけふみ /青竹踏み/
あおだたみ /青畳/
あおだち /青立ち/
あおだま /青玉/
あおち /青地/
あおちゃ /青茶;(jincha)烏龍茶など/
あおてんじょう /青天井/
あおでんわ /青電話/
あおと /青砥/青戸/
あおとうがらし /青唐辛子/
あおどうしん /青道心/
あおな /青菜;-に塩/
あおなし /青梨/
あおに /青二/青丹/
あおにさい /青二才/
あおにび /青鈍/
あおぬま /青沼/
あおね /青嶺/
あおねおんせん /青根温泉/
あおねぎ /青葱/青ネギ/
あおねこ /青猫/
あおの /青野/
あおのはら /青野原/
あおのり /青海苔/
あおはた /青旗/
あおば /青葉/
あおばえ /青蠅/
あおばかい /青葉会/
あおばきねんかいかん /青葉記念会館/
あおばく /青葉区/
あおばしょう /青葉賞/
あおばじょう /青葉城/
あおばじょうし /青葉城址/
あおばずく /青葉木菟/
あおばだい /青葉台/
あおばだいえき /青葉台駅/
あおばどおり /青葉通/
あおばばし /青葉橋/
あおばやま /青葉山/
あおばん /青版/青盤/
あおひげ /青髭/青髯;Barbe-Bleue, Perrault.妻殺し/
あおひょう /青票/
あおびかり /青光り/
あおびょうし /青表紙/青標紙;1840-41,大野広城/
あおぶさ /青房/
あおほん /青本/
あおぼうず /青坊主/
あおまめ /青豆/
あおみ /青み/青身;青魚の身/
あおみどり /青緑/
あおみどりいろ /青緑色/
あおみどりけい /青緑系/
あおみどろ /青味泥/水綿/
あおむぎ /青麦/
あおむけ /仰向け/
あおむし /青虫/
あおむらさき /青紫/
あおむらさきいろ /青紫色/
あおめ /青眼/
あおもじ /青文字/
あおもと /青本/
あおもの /青物/
あおものよこちょうえき /青物横丁駅/
あおもり /青森/
あおもりうんてんじょ /青森運転所/
あおもりえき /青森駅/
あおもりけん /青森県/
あおもりけんじん /青森県人/
あおもりし /青森市/
あおもりはこだてかん /青森函館間/
あおもりはつ /青森発/
あおもりべん /青森弁/
あおもん /青門/
あおや /青谷/青屋/
あおやき /青焼き;blueprint/青焼/
あおやぎ /青柳/
あおやなぎ /青柳/
あおやま /青山/
あおやまいっちょうめ /青山一丁目/
あおやまえんけいげきじょう /青山円形劇場/
あおやまがくいん /青山学院/
あおやまがくいんだい /青山学院大/
あおやまがくいんだいがく /青山学院大学/
あおやません /青山線/
あおやまちょう /青山町/
あおやまほうめん /青山方面/
あおやまぼち /青山墓地/
あおり /煽り/
あおりもんく /煽り文句/
あおんそく /亜音速/
あか /赤/垢/亜科;[生物]subfamily/閼伽;[仏教](argha) 仏前に供える水/淦;船底の水/絳;真紅/
あか> /赤;赤ペン,赤狩り,赤線/
あかあお /赤青/
あかあおみどり /赤青緑/
あかあか /赤々/明々/
あかあざ /赤痣/
あかあり /赤蟻/
あかい /赤井/
あかいえか /赤家蚊/
あかいがわ /赤井川/
あかいくつ /赤い靴/
あかいけ /赤池/
あかいけえき /赤池駅/
あかいし /赤石/
あかいしさんみゃく /赤石山脈/
あかいしだけ /赤石岳/
あかいっしょく /赤一色/
あかいでんき /赤井電機;[企業名]/
あかいぬ /赤犬/
あかいはね /赤い羽根/
あかいろ /赤色/
あかいわ /赤岩/赤磐/
あかいわえき /赤岩駅/
あかいわぐん /赤磐郡/
あかいわし /赤鰯/
あかうお /赤魚/
あかうま /赤馬/
あかうみがめ /赤海亀/
あかえ /赤絵/
あかえそ /赤狗母魚/
あかえだ /赤枝/
あかえび /赤海老/赤蝦/
あかえぼし /赤烏帽子;亭主の好きな-/
あかえんぴつ /赤鉛筆/
あかお /赤尾/
あかおか /赤岡/
あかおすぎ /赤尾杉/
あかおに /赤鬼/
あかおまな /赤御魚/
あかかげ /赤影/
あかかぶ /赤蕪;-の漬物/
あかがい /赤貝/
あかがしら /赤頭/
あかがね /銅/
あかがねいろ /銅色/
あかがみ /赤紙/
あかがり /赤狩り/赤狩/
あかがわ /赤川/
あかきっぷ /赤切符/
あかきゃべつ /赤キャベツ;red cabbage/
あかぎ /赤城/赤木/
あかぎいろ /赤黄色/
あかぎこうげん /赤城高原/
あかぎさん /赤城山/
あかぎちょう /赤城町/
あかぎつね /赤狐/
あかぎぬ /赤衣/
あかぎやま /赤城山/
あかぎれ /皸/皹/
あかくら /赤倉/
あかくろ /赤黒/
あかぐつ /赤靴;海魚/
あかぐま /赤熊/
あかぐみ /紅組;紅白歌合戦の-/赤組;運動会の-/
あかけいとう /赤系統/
あかげ /赤毛/
あかげら /赤啄木鳥/
あかげわしゅ /褐毛和種/
あかこーなー /赤コーナー/
あかこほん /赤小本/
あかご /赤子/赤児/
あかごめ /赤米/
あかさか /赤坂/
あかさかえき /赤坂駅/
あかさかほんしゃ /赤坂本社/
あかさかみつけ /赤坂見附/赤坂見付;※「赤坂見附」が正式/
あかさかみつけえき /赤坂見附駅/
あかさかみつけてん /赤坂見附店/
あかさかりきゅう /赤坂離宮/
あかさき /赤崎/赤碕/
あかさび /赤錆/
あかざ /藜/
あかざか /アカザ科/
あかざかな /赤魚/
あかざき /赤崎/
あかざとう /赤砂糖/
あかざわ /赤沢/赤澤/
あかざん /赤残/
あかし /明石/証/灯/證/赤司/証し/絳し/
あかしお /赤潮/
あかしかいきょう /明石海峡/
あかしかいきょうおおはし /明石海峡大橋/
あかしがわ /明石側/
あかしこう /明石港/
あかしし /明石市/
あかしな /明科/
あかしば /赤芝/
あかしま /暴/
あかしや /明石家/
あかしやき /明石焼/
あかしろ /赤白/
あかしんごう /赤信号/
あかしんぶん /赤新聞/
あかじ /赤字/赤地/
あかじかくご /赤字覚悟/
あかじがく /赤字額/
あかじく /赤字区/
あかじけっさん /赤字決算/
あかじこくさい /赤字国債/
あかじそ /赤紫蘇/
あかじはば /赤字幅/
あかじろせん /赤字路線/
あかすいしょう /赤水晶/
あかすり /垢擦り/
あかず /赤酢;紫蘇入り梅酢/
あかずきん /赤頭巾/
あかずのま /開かずの間/
あかせがわ /赤瀬川/
あかせがわげんぺい /赤瀬川原平/
あかせん /赤線/
あかぞめえもん /赤染衛門;やすらはで 寝なましものを さ夜ふけて かたぶくまでの 月をみしかな/
あかたにせん /赤谷線/
あかたん /赤短;花札で赤色の短冊の札および役/赤丹/
あかだし /赤出し/
あかだな /閼伽棚/
あかだま /赤玉/
あかだまつち /赤玉土;[園芸]関東ロームの土/
あかちゃ /赤茶/
あかちゃいろ /赤茶色/
あかちゃん /赤ちゃん/
あかちゃんよう /赤ちゃん用/
あかちょうちん /赤提灯/
あかちん /赤チン/
あかっぱじ /赤っ恥/
あかつか /赤塚/
あかつかふじお /赤塚不二夫/
あかつき /暁/垢付き/閼伽坏/曉;「暁」の旧字(人名用漢字)/
あかつきがた /暁方/
あかつきづくよ /暁月夜/
あかつきやみ /暁闇/
あかつち /赤土/赭/赭土/
あかつつみ /赤堤/
あかつめくさ /赤詰草/
あかてん /赤点/
あかでみーしょう /アカデミー賞;[映画]Academy Award/
あかでん /赤電/
あかでんわ /赤電話/
あかとうがらし /赤唐辛子/
あかとき /暁/
あかときづくよ /暁月夜/
あかとんぼ /赤蜻蛉/赤とんぼ/
あかどう /赤胴/
あかどまり /赤泊/
あかな /赤名/
あかなす /赤茄子/
あかに /赤丹/
あかにし /赤螺/
あかにんじゃ /赤忍者/
あかぬけ /垢抜け/
あかぬま /赤沼/
あかね /茜/朱子/
あかねいろ /茜色/
あかねか /アカネ科/Rubiaceae/
あかねぐも /茜雲/
あかねこ /赤猫/
あかねさす /茜さす/
あかねもく /アカネ目/Rubiales/
あかのたにん /赤の他人/
あかのひろば /赤の広場;モスクワの-/
あかはじ /赤恥/
あかはた /赤旗/旃/
あかはだ /赤膚/赤肌/
あかはだか /赤裸/
あかはな /赤鼻/
あかはに /赤埴/
あかはね /赤羽/
あかはら /赤腹/
あかばこ /赤箱/
あかばな /赤花/
あかばね /赤羽/赤羽根/
あかばねえき /赤羽駅/
あかばねせん /赤羽線/
あかばん /赤盤/
あかひげ /赤髭;鳥/
あかひと /赤人/
あかひら /赤平/
あかびょうし /赤表紙/
あかびら /赤平/
あかぴーまん /赤ピーマン/
あかふく /赤福/
あかふくほんてん /赤福本店/
あかふくもち /赤福餅/
あかふじ /赤富士;富嶽三十六景/
あかふじょう /赤不浄/
あかふだ /赤札/
あかぶさ /赤房/
あかぺん /赤ペン/
あかほ /赤穂/
あかほり /赤堀/
あかほん /赤本/
あかぼう /赤帽/
あかぼし /赤星/明星/
あかぼり /赤堀/
あかま /赤間/
あかまい /赤米/
あかまえき /赤間駅/
あかまじんぐう /赤間神宮/
あかまつ /赤松/
あかまど /赤窓/
あかまる /赤丸/
あかまるきゅうじょうしょう /赤丸急上昇/
あかまるじょうしょうちゅう /赤丸上昇中/
あかまんぼう /赤翻車魚/
あかまんま /赤飯/
あかみ /赤身/赤み/
あかみず /赤水/閼伽水;仏に供える水/
あかみそ /赤味噌/赤みそ/
あかみどり /赤緑/
あかみどりいろ /赤緑色/
あかむし /赤虫/
あかむらさき /赤紫/
あかむらさきいろ /赤紫色/
あかめ /赤目/
あかめいも /赤芽芋/
あかめがしわ /赤芽柏/
あかめぐち /赤目口/
あかもん /赤門/
あかゆ /赤湯/
あかゆき /赤雪/
あから /赤ら/
あからがお /赤ら顔/
あからく /赤楽/
あからしま /暴/
あからんぷ /赤ランプ;red light/
あかり /明かり/灯り/灯/明り/燈;「灯」の旧字(人名用漢字)/
あかりとり /明かり取り/明り取り/
あかりまど /明かり窓/明り窓/
あかるみ /明るみ/
あかれんが /赤煉瓦/赤レンガ/
あかわいん /赤ワイン/
あかん /阿寒/
あかんこ /阿寒湖/
あかんたい /亜寒帯/
あかんちょう /阿寒町/
あかんぼう /赤ん坊/
あがおか /阿賀岡/
あがた /県/
あがつま /吾妻/我妻/
あがない /贖い/贖/
あがの /阿賀野/
あがのがわ /阿賀野川/
あがほ /英賀保/
あがり /上がり/上り/
あがりかた /上がり方/
あがりかまち /上がり框/
あがりがまち /上がり框/
あがりさがり /上がり下がり/
あがりしょう /上がり性/
あがりた /揚田/
あがりだか /上がり高/
あがりば /上がり場/
あがりめ /上がり目/
あがりゆ /上がり湯/
あがわ /阿川/吾川/
あき /秋/安芸/空/空き/亜希/亜紀/亜季/亜樹/光/明/章/晶/昭/暁/晃/亮/哲/彰/朗/顕/彬/安岐/璋/晄;「晃」の異体字(人名用漢字)/晶紀/穐;「秋」の異体字/龝/晢/晰/朖/
あき> /空き;(vacant) -部屋,-スロット/
あきあかね /秋茜/
あきあき /飽き飽き/厭き厭き/
あきあじ /秋味/
あきいこう /秋以降/
あきう /秋保/
あきうみ /明生/
あきえ /明恵/章江/秋江/昭江/秋絵/晃枝/亜紀恵/
あきお /昭夫/明夫/昭雄/章夫/昭男/明男/明雄/彰夫/暁生/秋夫/秋男/秋雄/晶夫/亜希夫/晃夫/明央/彬生/
あきおか /秋岡/
あきおみ /明臣/
あきかず /彰一/
あきかぜ /秋風/
あきかわ /秋川/
あきかわけいこく /秋川渓谷/
あきかん /空き缶/空缶/空き罐/
あきがせ /秋ケ瀬/
あきがわ /秋川/
あきぎり /秋霧/
あきく /安芸区/
あきぐち /秋口/
あきぐん /安芸郡/
あきけいば /秋競馬/
あきげしき /秋景色/
あきこ /亜希子/晶子/明子/晃子/亜紀子/章子/昭子/暁子/彰子/顕子/朗子/亜季子/亜樹子/朱子/亜以子;?/
あきごう /秋号/
あきごえ /秋肥/
あきごろ /秋頃/
あきさと /穐里/
あきさば /秋鯖/
あきさめ /秋雨/
あきさめぜんせん /秋雨前線;秋の長雨をもたらす/
あきさわ /秋澤/
あきざくら /秋桜/
あきしぐれ /秋時雨/
あきしつ /空き室/
あきしの /秋篠/
あきしのでら /秋篠寺/
あきしののみや /秋篠宮/
あきしま /昭島/安芸島/
あきしまし /昭島市/
あきしょう /飽き性/
あきしょせん /秋初戦/
あきじかん /空き時間/空時間/
あきす /空き巣/空巣/
あきすえ /秋末/
あきすねらい /空き巣狙い/空巣狙い/
あきせき /空き席/
あきぞら /秋空/
あきた /秋田/飽田;地名,熊本/
あきたいぬ /秋田犬/
あきたえき /秋田駅/
あきたぎんこう /秋田銀行/
あきたけん /秋田県/秋田犬/
あきたこまち /秋田小町/
あきたし /秋田市/
あきたしょてん /秋田書店;[出版社名]www.akitashoten.co.jp/
あきたじんく /秋田甚句;[民謡]「キタカサイサイ」/
あきただい /秋田大/
あきただいがく /秋田大学/
あきたに /秋谷/
あきたべん /秋田弁/
あきだい /秋大/
あきち /空き地/空地/
あきつ /秋津/蜻蛉/安芸津/
あきつぐ /明二/
あきつしま /秋津島/
あきづき /秋月/
あきづきでんし /秋月電子/
あきと /彰人/
あきとし /彰俊/明敏/晃年/秋利/
あきとも /秋友/
あきな /明菜/
あきない /商い/
あきないぐち /商い口/
あきなが /秋永/
あきなぎ /秋奈祇/
あきなす /秋茄子/
あきなり /秋成/章成/
あきなる /秋成/
あきの /秋野/昭乃/
あきのこえ /秋の声;-を聞く/
あきのそら /秋の空;変わりやすいもの。「女心と-」/
あきのひ /秋の日/
あきのよ /秋の夜/
あきのよのながものがたり /秋夜長物語/
あきのり /明徳/明憲/昭憲/昭則/明紀/昭徳/彰則/晃紀/晧則/
あきは /秋葉/
あきはさん /秋葉山/
あきはばら /秋葉原/
あきはばらえき /秋葉原駅/
あきはばらかかく /秋葉原価格/
あきば /秋葉/秋場/秋庭/
あきばけい /アキバ系;[新語]秋葉原系/
あきばこ /空箱/
あきばしょ /秋場所/
あきばれ /秋晴れ/秋晴/
あきひこ /明彦/昭彦/彰彦/秋彦/暁彦/晶彦/祥彦/
あきひさ /彰久/顕尚/
あきひで /彰英/
あきひと /昭仁/明仁/祥仁/
あきひろ /明宏/昭宏/明弘/彰宏/章宏/昭博/晃弘/章弘/明広/明浩/章博/昭弘/明大/昭浩/章裕/章浩/明裕/晃宏/晃広/章広/暁宏/彰広/哲裕/碩宏/
あきびえ /秋冷え/
あきびより /秋日和/
あきびん /空瓶/空ビン/
あきふく /秋服/
あきふみ /明文/章文/晶文/
あきふゆ /秋冬/
あきぶもん /空部門/
あきべや /空き部屋/空部屋/
あきほ /明穂/秋穂/秋保/
あきま /秋間/空き間/
あきまき /秋蒔き;[園芸]autumn sowing/
あきまつり /秋祭り/秋祭/
あきまで /秋迄/
あきまる /秋丸/
あきみ /秋生/
あきみず /秋水/
あきみち /明倫/
あきみつ /彬光/章充/
あきむら /秋村/
あきめ /秋芽/
あきめくら /明き盲/
あきもと /秋元/秋本/
あきもの /秋物/
あきものがたり /秋物語/
あきもよう /秋模様/
あきや /空家/空き家/空き屋/空屋/明き家/
あきやさい /秋野菜/
あきやしき /空屋敷/
あきやす /彰康/
あきやすみ /秋休み/
あきやま /秋山/
あきゅーせいでん /阿Ｑ正伝;(1921)魯迅/
あきゅう /秋保/
あきゅうせい /亜急性/
あきゆき /昭如/
あきょう /阿膠/阿嬌/
あきよ /明代/晃代/
あきようりょう /空き容量/空容量/
あきよし /秋吉/昭義/明良/昭良/明吉/彰芳/
あきよしくみこ /秋吉久美子/
あきよしだい /秋吉台/
あきよしどう /秋芳洞/
あきら /光/明/章/輝/晶/陽/昭/晃/彰/暁/亮/聡/朗/啓/鑑/旭/顕/亨/彬/洸/日明/曉;「暁」の旧字(人名用漢字)/晧/顯;「顕」の旧字(人名用漢字)/滉/璋/晄;「晃」の異体字(人名用漢字)/昜/朖/
あきらか /明らか/明か;(非正則)/曠/昿/
あきらめ /諦め/
あきらめがお /諦め顔/
あきりすと /空きリスト/
あきりょういき /空領域/
あきれ /呆れ/
あきれがお /呆れ顔/あきれ顔/
あきれすけん /アキレス腱/
あきんど /商人/
あきんどやど /商人宿/
あぎ /阿木/亜木/阿魏/吾君/顎/
あぎと /顎/鰓/顎門/
あぎなし /顎無し/
あぎに /阿耆尼/
あぎょう /ア行/あ行/
あく /悪/灰汁/握;握力/幄;天幕/渥;(厚い)/阿久;人名/軛;くびき/齷;齷齪/堊;つち/惡;「悪」の旧字(人名用漢字)/空/
あくあらい /灰汁洗い/
あくい /悪意/阿久井/
あくいん /悪因/
あくいんあっか /悪因悪果;悪い原因に伴う悪い結果/
あくいんしょう /悪印象/
あくうかん /亜空間/
あくうん /悪運/
あくえいきょう /悪影響/
あくえき /悪疫/
あくえきしつ /悪液質;癌腫等の末期の衰弱状態/
あくえん /悪縁/
あくかんきょう /悪環境/
あくかんじょう /悪感情/
あくぎ /悪戯/
あくぎゃく /悪逆/悪虐/
あくぎゃくむどう /悪逆無道/
あくぎょう /悪行/悪業/
あくげんた /悪源太/
あくこうか /悪効果/
あくごう /悪業/
あくさい /悪妻/悪才/
あくさく /齷齪/
あくざいりょう /悪材料/
あくしつ /悪質/悪疾/
あくしつか /悪質化/
あくしゃ /幄舎/
あくしゅ /握手/悪手/悪趣;[仏教]/
あくしゅう /悪臭;stink/悪習;vice/
あくしゅうぼうしほう /悪臭防止法/
あくしゅかい /握手会/
あくしゅけん /握手券/
あくしゅみ /悪趣味/
あくしょ /悪書;bad book/悪所/
あくしょう /悪性/
あくしょついほう /悪書追放/
あくしん /悪心/
あくじ /悪事/
あくじき /悪食/
あくじせんり /悪事千里/
あくじゅんかん /悪循環/
あくじょ /悪女/
あくじょう /悪尉/
あくじょうけん /悪条件/
あくじょうけんか /悪条件下/
あくせい /悪性/悪政;misrule/悪声;bad voice/
あくせいか /悪性化/
あくせいこくしょくしゅ /悪性黒色腫/
あくせいしゅよう /悪性腫瘍/
あくせいど /悪性度/
あくせいりんぱしゅ /悪性リンパ腫/
あくせく /齷齪/
あくせすかいせき /アクセス解析/
あくせすけん /アクセス権;[電算]permission/
あくせすじょうきょう /アクセス状況/
あくせすすう /アクセス数/
あくせん /悪銭/悪戦/
あくせんくとう /悪戦苦闘/
あくせんと /accent;その音を特に強く/
あくせんときごう /アクセント記号/
あくぜい /悪税/
あくそう /悪相/悪僧/
あくそうきゅう /悪送球;[野球]/
あくた /芥/
あくたい /悪態/
あくたがわ /芥川/
あくたがわしょう /芥川賞/
あくたがわしょうこうほ /芥川賞候補/
あくたがわやすし /芥川也寸志/
あくたがわりゅうのすけ /芥川龍之介/
あくたれ /悪たれ/
あくたろう /悪太郎;いたずらっ子/
あくだいかん /悪代官/
あくだま /悪玉/
あくだまか /悪玉化;「コレステロールの-」「旧体制の-」/
あくだまきん /悪玉菌;⇔善玉菌/
あくだまこれすてろーる /悪玉コレステロール/
あくち /悪血/
あくちしき /悪知識/
あくちにうむ /Ac/Actinium/
あくちにうむけいれつ /アクチニウム系列;4n+3系列/
あくつ /阿久津/圷/
あくてん /悪天/
あくてんこう /悪天候/
あくてんこうじ /悪天候時/
あくと /踵/悪徒/
あくとう /悪党/悪投/
あくとく /悪徳/
あくとくしょうにん /悪徳商人/
あくとくしょうほう /悪徳商法/
あくとくふどうさんや /悪徳不動産屋/
あくどう /悪童/悪道/
あくなき /飽くなき/
あくにち /悪日/
あくにん /悪人/
あくにんしょうき /悪人正機/
あくにんしょうきせつ /悪人正機説/
あくぬき /灰汁抜き/
あくね /阿久根/
あくねん /悪念/
あくねんぴ /悪燃費/
あくのはな /悪の華;Les Fleurs du Mal,1857-61,Baudelaire/
あくはつとほ /握髪吐哺/
あくば /悪罵/
あくひつ /悪筆/
あくひょう /悪評/
あくひょうばん /悪評判/
あくび /欠伸/悪日/欠/
あくびょう /悪病/
あくびょうどう /悪平等/
あくふ /握斧;handaxe/
あくふう /悪風/
あくぶん /悪文/
あくへい /悪弊/
あくへき /悪癖/
あくへん /悪変/
あくほう /悪法/悪報/
あくぼくとうせん /悪木盗泉/
あくま /悪魔/
あくまがったい /悪魔合体/
あくまじょう /悪魔城/
あくますうはい /悪魔崇拝/
あくまてき /悪魔的/
あくまで /飽く迄/
あくまばらい /悪魔払い;?/
あくみ /飽海/
あくみょう /悪名/
あくむ /悪夢/
あくめい /悪名/
あくもん /悪問/
あくやく /悪役/
あくゆう /悪友/阿久悠/
あくよう /悪用/
あくようかのう /悪用可能/
あくらつ /悪辣/
あくりゅう /悪竜/
あくりょう /悪霊/
あくりょうたいさん /悪霊退散/
あくりょく /握力/
あくりょくけい /握力計/
あくりるえのぐ /アクリル絵の具;acrylic paint/アクリル絵具/
あくりるじゅし /アクリル樹脂/
あくりるせい /アクリル製/
あくる /明くる/
あくるあさ /明くる朝/
あくるひ /明くる日/
あくれい /悪例/
あくろ /悪路/
あぐい /阿久比/安居院/安食/
あぐさ /阿草/
あぐに /粟国/
あぐら /胡座/胡坐/胡床/趺坐;NB:「ふざ」とも/
あぐらなべ /安愚楽鍋;仮名垣魯文/
あぐり /亜久里/
あぐん /亜群/
あけ /朱/明け/暁/曉;「暁」の旧字(人名用漢字)/明/
あけお /暁生/
あけがた /明け方/
あけがらす /明烏/
あけくれ /明け暮れ/
あけこ /朱子/
あけしめ /開け閉め/
あけすけ /明け透け;point-blank. 「-に言う」/
あけたて /開け閉て/
あけち /明智/
あけちこごろう /明智小五郎/
あけちたんてい /明智探偵/
あけちみつひで /明智光秀/
あけっぴろげ /開けっ広げ/
あけに /明荷;[相撲]/
あけの /明野/
あけのみょうじょう /明けの明星;the evening star (金星)/
あけはま /明浜/
あけび /木通/通草/
あけびか /アケビ科/Lardizabalaceae/
あけぼの /曙/
あけぼのいろ /曙色/
あけぼのばし /曙橋/
あけみ /明美/朱美/暁美/朱実/明海/明珠/
あけわたし /明け渡し/
あげ /上げ/揚げ/揚/上/安芸/
あげあし /揚げ足;-を取る/上げ足/上足/挙げ足/揚足/挙足/
あげあしとり /揚げ足取り/
あげあぶら /揚げ油/
あげいた /上げ板/
あげお /上尾/
あげおえき /上尾駅/
あげおし /上尾市/
あげおろし /上げ下ろし;布団の-/
あげかじ /上げ舵/
あげがし /揚げ菓子/
あげぎょうざ /揚げ餃子/揚餃子/
あげく /挙句/挙げ句/揚げ句;=挙げ句/揚句;=挙(げ)句/上げ句;?/
あげくだし /上げ下し/
あげくのはて /挙句の果て/挙げ句の果て/
あげさげ /上げ下げ/
あげしお /上げ潮/上潮/
あげぜん /上げ膳/
あげぜんすえぜん /上げ膳据え膳;至れり尽せり/
あげぞこ /上げ底/上底/
あげだい /揚代/
あげだし /揚げ出し;-豆腐/揚出し;-豆腐/
あげだしどうふ /揚げ出し豆腐;居酒屋の定番/揚出し豆腐/
あげだま /揚げ玉/揚玉;天かす/
あげち /上地/揚地/
あげつらい /論い/
あげど /揚げ戸/揚戸/
あげどうふ /揚げ豆腐;油揚げ/揚豆腐/
あげなべ /揚げ鍋/
あげの /揚野/
あげは /揚羽/
あげはちょう /揚羽蝶/
あげはば /上げ幅/
あげはま /揚浜;[囲碁] 取った石/揚げ浜;-式塩田/
あげば /揚場/揚げ場/
あげばり /幄/
あげぱん /揚げパン/
あげひばり /揚げ雲雀/
あげぶた /上げ蓋/
あげまい /上米;[日本史]享保の改革/
あげまき /揚巻/総角/
あげまつ /上松/
あげもち /揚げ餅/
あげもの /揚げ物/
あげや /揚屋/
あげやいり /揚屋入り/
あこ /吾子/亜古/彼所;there/亜子/
あこう /赤穂/亜綱/赤魚/
あこうざんたい /亜高山帯/
あこうせん /赤穂線/
あこうそく /亜光速/
あこうだい /赤魚鯛/阿候鯛/
あこうろうし /赤穂浪士/
あこがれ /憧れ/憬れ;=憧れ/
あこぎ /阿漕/
あこそ /阿古曽;地名,三重/阿古曾/
あこめ /衵/袙/
あこや /阿古屋/
あこやがい /阿古屋貝/
あご /顎/阿児/飛魚/
あごひげ /顎鬚/鬚/
あごひも /顎紐/
あごわん /英虞湾/
あさ /朝/麻/浅/晨/阿佐/厚狭/安佐/淺;「浅」の旧字/
あさあめ /朝雨/
あさい /浅井/朝井/淺井;「浅」旧字/
あさいち /朝市/朝一/朝イチ/
あさいちばん /朝一番/
あさいと /麻糸/麻絲;「糸」旧字/
あさいり /浅煎り/浅炒り/
あさえだ /朝枝/浅枝/
あさお /麻生/浅尾/朝雄/
あさおか /朝丘/朝岡/麻丘/浅丘/
あさおき /朝起き/
あさおり /麻織/
あさおりもの /麻織物/
あさか /朝霞;地名,埼玉/安積;地名,福島/浅香;地名,=安積/朝加;人名/
あさかげ /朝影/
あさかぜ /朝風/
あさかそすい /安積疎水/安積疏水/
あさかのみや /朝香宮/
あさかわ /浅川/朝川/
あさが /浅賀/朝賀/
あさがえり /朝帰り/
あさがお /朝顔/蕣/
あさがおいち /朝顔市/
あさがけ /朝駆/
あさがすみ /朝霞/
あさがた /朝方;⇔夕方/朝型;⇔夜型/
あさがみ /麻上/
あさがや /阿佐ヶ谷/阿佐谷/
あさき /麻木/
あさきた /安佐北/
あさきたく /安佐北区/
あさぎ /浅葱/浅黄/麻木/浅木/
あさぎいろ /浅葱色/
あさぎうら /浅葱裏/
あさぎぬ /麻衣/
あさぎまく /浅葱幕/
あさぎり /朝霧/
あさぎりこうげん /朝霧高原/
あさくさ /浅草/
あさくさえき /浅草駅/
あさくさこうかいどう /浅草公会堂/
あさくさしんげきじょう /浅草新劇場/
あさくさせん /浅草線/
あさくさのり /浅草海苔/
あさくさばし /浅草橋/
あさくさばしえき /浅草橋駅/
あさくさほうめん /浅草方面/
あさくち /浅口/
あさくら /朝倉/浅倉/麻倉/
あさくらえき /朝倉駅/
あさくらしょてん /朝倉書店;[出版社名]www.asakura.co.jp/
あさぐつ /浅沓/
あさけ /朝明/
あさげ /朝餉/
あさげいこ /朝稽古/
あさこ /麻子/朝子/浅子/あさ子/亜抄子/
あさご /朝来/
あさごはん /朝御飯/朝ご飯/朝ごはん/
あさざけ /朝酒/
あさしお /朝潮/
あさしな /浅科/
あさしも /朝霜/
あさしゃん /朝シャン/
あさしろ /麻城/
あさじ /朝地;地名/浅茅/朝事/
あさじう /浅茅生;-の(小野[枕詞])/
あさじうの /浅茅生の/
あさじえ /浅知恵/
あさすおう /浅蘇芳/
あさせ /浅瀬/
あさせん /阿佐線/
あさぞら /朝空/
あさだ /浅田/麻田/朝田/阿佐田/
あさだあきら /浅田彰/
あさだあめ /浅田飴/
あさだき /浅炊き/
あさだち /朝立ち/
あさだみよこ /浅田美代子/
あさぢ /浅茅/
あさぢえ /浅知恵/
あさって /明後日/
あさっぱら /朝っぱら/朝っ腹/
あさつき /浅葱/胡葱/
あさつゆ /朝露/
あさづきよ /朝月夜/
あさづくよ /朝月夜/
あさづけ /浅漬/浅漬け/
あさづま /朝妻/
あさてい /朝定/
あさで /朝出/浅手/浅傷;⇔深傷/
あさと /朝戸/麻人;人名/
あさどやゆんた /安里屋ユンタ;[民謡]沖縄/
あさどら /朝ドラ/
あさなぎ /朝凪/
あさなべ /浅鍋/
あさなゆうな /朝な夕な/
あさなわ /麻縄/
あさぬの /麻布/
あさぬま /浅沼/
あさね /朝寝/
あさねぼう /朝寝坊/
あさの /浅野/
あさのは /麻の葉/
あさのぶ /朝信/
あさのみ /麻の実/
あさはか /浅はか/
あさはなだ /浅縹/
あさはやく /朝早く/
あさはら /浅原/麻原/
あさば /浅場/浅羽;地名/
あさばん /朝晩/
あさひ /朝日/旭/朝陽/
あさひかせい /旭化成;[企業名]/
あさひかせいこうぎょう /旭化成工業;[企業名]/
あさひかせいじょうほう /旭化成情報/
あさひかわ /旭川/
あさひかわえき /旭川駅/
あさひかわけいばじょう /旭川競馬場/
あさひかわし /旭川市/
あさひかわせん /旭川線/
あさひがおか /旭ヶ丘/旭ケ丘/旭が丘/朝日ヶ丘/
あさひがらす /旭硝子/
あさひがわ /旭川/
あさひぎんこう /あさひ銀行/
あさひく /旭区/
あさひけい /朝日系/
あさひけいれつ /朝日系列/
あさひこうよう /朝日航洋/
あさひしゅっぱんしゃ /朝日出版社;[出版社名]/
あさひしんぶん /朝日新聞/
あさひしんぶんけい /朝日新聞系/
あさひしんぶんしゃ /朝日新聞社;[企業名]www.asahi.com/
あさひしんぶんちょうかん /朝日新聞朝刊/
あさひしんぶんゆうかん /朝日新聞夕刊/
あさひせいめい /朝日生命/
あさひせんしょ /朝日選書/
あさひそのらま /朝日ソノラマ/
あさひだい /旭台/
あさひだけ /旭岳/
あさひちょう /朝日町/
あさひちょうかん /朝日朝刊/
あさひつうしんしゃ /旭通信社/
あさひな /朝比奈/朝日奈/
あさひなたかし /朝比奈隆/
あさひはい /朝日杯/
あさひびーる /朝日麦酒/
あさひぶんこ /朝日文庫/
あさひほうそう /朝日放送/
あさひまち /旭町/
あさひむら /朝日村/
あさひや /旭屋/
あさひやしょてん /旭屋書店/
あさひやま /朝日山/
あさひゆうかん /朝日夕刊/
あさひる /朝昼/
あさひるばん /朝昼晩/
あさびん /朝便/
あさふく /浅福/
あさぶ /麻生/麻布/
あさぶき /麻吹/
あさぶくろ /麻袋/
あさぶろ /朝風呂/
あさほうそう /朝放送/
あさぼらけ /朝ぼらけ;曙,東雲/
あさま /浅間/朝間/
あさまおんせん /浅間温泉/
あさまさんそうじけん /浅間山荘事件/
あさました /浅間下/
あさまじんじゃ /浅間神社/
あさまつ /朝松/
あさまやま /浅間山/
あさみ /麻美/あさ美/浅見/亜沙美/麻見/朝美/亜左美/
あさみぞ /麻溝/
あさみどり /浅緑/
あさみなみ /安佐南/
あさみなみく /安佐南区/
あさみや /朝宮/麻宮;人名/
あさむし /浅虫/浅蒸し/
あさむらさき /浅紫/
あさめし /朝飯/朝メシ/
あさめしまえ /朝飯前/
あさもや /朝靄/
あさやけ /朝焼け/
あさやま /朝山/浅山/
あさゆ /朝湯/
あさゆう /朝夕/
あさり /浅蜊/浅利/朝里/蜊/鯏/漁り/
あさりじる /浅蜊汁/あさり汁/アサリ汁/
あされん /朝練/
あさんかちっそ /亜酸化窒素;N2O/
あざ /字/痣/黶;=痣/
あざい /浅井/
あざな /字/字名/
あざぶ /麻布/
あざぶじゅうばん /麻布十番/
あざぶだい /麻布台/
あざみ /薊/
あざみうま /薊馬/
あざやか /鮮やか/鮮か/
あざらし /海豹/
あざわらい /嘲笑い/
あし /足/脚;(椅子の-,動物の-)/芦;「蘆」の異体字/葦;=芦/葭;=葦/蘆/悪し/
あしあと /足跡/
あしいろ /足色/
あしうら /足裏/
あしお /足尾/
あしおえき /足尾駅/
あしおざん /足尾山/
あしおせん /足尾線/
あしおと /足音/跫/脚音/
あしおどうざん /足尾銅山;[日本史]-鉱毒事件/
あしおり /足折/
あしか /海驢/葦鹿;=海驢/
あしかが /足利/
あしかがうじみつ /足利氏満;1359-98/
あしかががっこう /足利学校/
あしかがけ /足利家/
あしかがけいば /足利競馬/
あしかがこうぎょうだいがく /足利工業大学/
あしかがこうこう /足利高校/
あしかがし /足利氏/
あしかがしげうじ /足利成氏;1438-97/
あしかがじだい /足利時代;室町時代/
あしかがたかうじ /足利尊氏;[日本史]初代 (1305-1358 在職:1338-58)/
あしかがただふゆ /足利直冬/
あしかがただよし /足利直義;1306-52/
あしかがばくふ /足利幕府/
あしかがぶんこ /足利文庫/
あしかがまさとも /足利政知;1435-91/
あしかがもちうじ /足利持氏;1398-1439/
あしかがもとうじ /足利基氏;1340-67/
あしかがよしあき /足利義昭;[日本史]十五代 (1537-97 在職:1568-73)/
あしかがよしあきら /足利義詮;[日本史]二代 (1330-67 在職:1358-67)/
あしかがよしかず /足利義量;[日本史]五代 (1407-25 在職:1423-25)/
あしかがよしかつ /足利義勝;[日本史]七代 (1434-43 在職:1442-43)/
あしかがよしずみ /足利義澄;[日本史]十一代(1480-1511 在職:1494-1508)/
あしかがよしたね /足利義稙;[日本史]十代 (1466-1523 在職:1490-93,1508-21)/
あしかがよしてる /足利義輝;[日本史]十三代 (1536-65 在職:1546-65)/
あしかがよしのり /足利義教;[日本史]六代 (1394-41 在職:1429-41)/
あしかがよしはる /足利義晴;[日本史]十二代 (1511-50 在職:1521-46)/
あしかがよしひさ /足利義尚;[日本史]九代 (1465-89 在職:1473-89)/
あしかがよしひで /足利義栄;[日本史]十四代 (1538-68 在職:1568)/
あしかがよしまさ /足利義政;[日本史]八代 (1436-90 在職:1449-73)/
あしかがよしみ /足利義視;1439-91/
あしかがよしみつ /足利義満;[日本史]三代 (1358-1408 在職:1368-1408)/
あしかがよしもち /足利義持;[日本史]四代 (1386-1428 在職:1394-1423)/
あしかけ /足掛け/足掛/
あしかせ /足枷/桎/鐐/
あしからず /悪しからず/
あしかり /芦刈/
あしかわ /芦川/
あしがかり /足掛かり/足掛り/足がかり/
あしがた /足型/足形/
あしがため /足固め/
あしがなえ /足鼎/
あしがら /足柄/
あしがらえき /足柄駅/
あしがらかみ /足柄上/
あしがらしも /足柄下/
あしがらとうげ /足柄峠/
あしがらみ /足搦み/
あしがらやま /足柄山;地名/
あしがる /足軽/
あしがわ /芦川/
あしき /悪しき/
あしきしゅうきゅう /ア式蹴球/
あしきた /芦北/葦北/
あしきょう /芦響/
あしきり /足切り;センター試験の-/
あしくせ /足癖/
あしくび /足首/
あしくびねんざ /足首捻挫/
あしぐみ /足組み/
あしげ /芦毛/足蹴/葦毛;=芦毛/
あしげい /足芸/
あしこぎ /足漕ぎ/
あしこし /足腰/脚腰/
あしごしらえ /足拵え/
あしさき /足先/脚先/
あしさばき /足捌き;footwork/
あしざま /悪し様/
あしざわ /芦沢/芦澤/
あしざわり /足触り;-のいいカーペット/
あししげく /足繁く/
あししろ /足代;足場/
あしずもう /足相撲/
あしずり /足摺/
あしずりみさき /足摺岬/
あしそこ /足底/
あしぞこばん /足底板/
あした /明日/朝/晨;あさ/
あしたか /愛鷹/
あしたば /明日葉/鹹草/
あしだ /芦田/
あしだい /足代/
あしだひとし /芦田均/
あしつき /足付/足付き/
あしつぎ /足継ぎ/
あしづかい /足遣い/
あしづけ /足付/
あしてまとい /足手纏い/
あしで /足手/葦手/
あしでえ /葦手絵/
あしでまとい /足手纏い/
あしでもじ /葦手文字/
あしとり /足取り/
あしどめ /足止め/足止/足留め/
あしどり /足取り/足鳥/
あしな /芦名/足名/蘆名/芦品/
あしなえ /跛/蹇/
あしなが /足長/
あしなみ /足並み/足並/
あしならし /足慣らし/
あしぬけ /足抜け/
あしのこ /芦ノ湖/
あしのこう /足の甲/
あしはこび /足運び/
あしはら /芦原/葦原/蘆原/
あしはらちゅう /芦原中/
あしはらちゅうがっこう /芦原中学校/
あしはらのなかつくに /葦原の中つ国/
あしば /足場/
あしばや /足早/
あしばらい /足払い/
あしひきの /足引きの;(枕詞) -山/
あしび /馬酔木/
あしびょうし /足拍子/
あしふき /足拭き/
あしぶえ /葦笛/
あしぶね /葦舟/葦船/
あしぶみ /足踏み/足踏/
あしぶみじょうたい /足踏み状態/
あしへん /足偏/
あしべ /芦辺/芦部/
あしべつ /芦別/
あしぼね /足骨/
あしまえ /足前/
あしまかせ /足任せ/
あしまわり /足回り/
あしめ /走目/
あしもと /足元/足下/足許/脚元/
あしもの /脚物;椅子やテーブルなど/
あしもり /足守/
あしゃ /唖者/
あしや /芦屋/芦谷/
あしやがわ /芦屋川/
あしやがわえき /芦屋川駅/
あしやがんのすけ /芦屋雁之助/
あしやし /芦屋市/
あしやす /芦安/
あしやすめ /足休め/
あしゅ /亜種/
あしゅう /阿州;阿波/
あしゅら /阿修羅/
あしゅらぞう /阿修羅像/
あしゅらどう /阿修羅道/
あしゆ /足湯/脚湯/
あしゆび /足指/趾/
あしょうさん /亜硝酸/
あしょうさんえん /亜硝酸塩/
あしょうさんのうど /亜硝酸濃度/
あしょろ /足寄/
あしよわ /足弱/
あしろ /安代/
あしわざ /足技/足業/
あしわだ /足和田/
あしわら /葦原/
あじ /味/鯵;「鰺」の異体字/鰺/庵治/
あじあ /亜細亜/亞細亞/
あじあかいはつぎんこう /アジア開発銀行;Asian Development Bank(ADB) www.adb.org/
あじあかっこく /アジア各国/
あじあけい /アジア系/
あじあしょこく /アジア諸国/
あじあじん /アジア人/
あじあぞう /アジア象;asian elephant/
あじあたいかい /アジア大会/
あじあだい /亜細亜大/
あじあてき /アジア的/
あじおう /味皇/
あじおか /味岡/
あじおんち /味音痴/味オンチ/
あじか /簣/
あじから /味方/
あじがさわ /鯵ヶ沢/
あじがわ /安治川/
あじき /味気/
あじきこう /味紀行/
あじけ /味気/
あじけない /味気ない/
あじさい /紫陽花/
あじさか /鯵坂/
あじじまん /味自慢/
あじす /阿知須/
あじそんびょう /アジソン病;[医]Addison's disease/
あじつけ /味付け/味付/
あじつけのり /味付け海苔/
あじとみ /安次富/
あじどころ /味処/
あじな /阿品/芦品/
あじのもと /味の素;[商標] NB:言い換え「うま味調味料」/
あじふめい /味不明/
あじま /安島/
あじみ /味見/
あじみよう /味見用/
あじむ /安心院/
あじゃら /戯/
あじゃり /阿闍梨/
あじろ /網代/足代/安代/
あじわい /味わい/
あす /明日/
あすあさって /明日明後日/
あすいこう /明日以降/
あすか /明日香/飛鳥/
あすかい /飛鳥井/
あすかいちょう /飛鳥井町/
あすかじ /飛鳥路/
あすかじだい /飛鳥時代/
あすかでら /飛鳥寺/
あすかぶんか /飛鳥文化/
あすかやま /飛鳥山/
あすけ /足助/
あすけかんちゃ /足助寒茶/
あすこ /彼所/
あすこるびんさん /アスコルビン酸/
あすじゅう /明日中/
あすたちん /At/Astatine/
あすぢゅう /明日中/
あすてかぶんめい /アステカ文明;Azteca/
あすなろ /翌檜/
あすぱらぎんさん /アスパラギン酸/
あすぺくとひ /アスペクト比/
あすら /阿修羅/
あすわ /足羽/
あずかり /預かり/預り/
あずかりきん /預り金/預かり金/
あずかりしょ /預かり所/預り所/
あずかりしょう /預かり証/
あずかりもの /預かり物/預り物/
あずき /小豆/
あずきいろ /小豆色/
あずきがゆ /小豆粥/
あずきもち /小豆餅/
あずけ /預け/
あずけあい /預合/
あずけきん /預け金/
あずさ /梓/
あずさがわ /梓川/
あずさみこ /梓巫女/
あずさゆみ /梓弓/
あずち /安土/堋/
あずま /吾妻/吾嬬/東/
あずまあそび /東遊び/東遊/
あずまおとこ /東男/
あずまかがみ /吾妻鏡/東鑑/
あずまくだり /東下り/
あずまことば /東言葉/
あずません /吾妻線/
あずまばし /吾妻橋/
あずまふじ /東富士/
あずまや /東屋/四阿/阿亭/
あずみ /安曇/安住/杏美/
あずみぐん /安曇郡/
あずみの /安曇野/
あせ /汗/阿瀬/
あせい /阿世;曲学―/
あせかき /汗掻き/汗かき/
あせだく /汗だく/
あせちるさりちるさん /アセチルサリチル酸/
あせっかき /汗っ掻き/汗っかき/
あせとり /汗取り/
あせび /馬酔木/
あせふき /汗拭き/
あせぼ /馬酔木/
あせまみれ /汗塗れ/
あせみ /馬酔木/
あせみず /汗水/
あせみどろ /汗みどろ/
あせも /汗疹/
あせり /焦り/
あせんやく /阿仙薬/
あぜ /畔/畦/
あぜくら /校倉/
あぜくらづくり /校倉造り;[建築]/校倉造/
あぜぬり /畦塗り/
あぜみち /畦道/
あぜん /唖然/
あそ /阿蘇/安蘇/阿曽/
あそう /麻生/阿僧/
あそうがわ /麻生川/
あそうぎ /阿僧祇;10^56/
あそこ /彼処/彼所/
あそさん /阿蘇山/
あそび /遊び/
あそびあいて /遊び相手/
あそびうた /遊び歌/遊び唄/
あそびかた /遊び方/
あそびがね /遊び金/
あそびがみ /遊び紙/
あそびぐせ /遊び癖/
あそびぐるま /遊び車;[機械]/
あそびげ /遊び毛;遅れ毛/
あそびごころ /遊び心/
あそびて /遊び手/
あそびどうぐ /遊び道具/
あそびにん /遊び人/遊人/
あそびはんぶん /遊び半分/
あそびば /遊び場/
あそびべ /遊部/
あそびめ /遊女/遊び女/
あそみ /朝臣/
あそん /朝臣/
あぞく /亜属;[生物]subgenus/
あた /咫/
あたい /値;value. (字義:そのものの価値)/価;price. (字義:商人のつける売値)/私/價;「価」の旧字(人名用漢字)/値い/
あたいせんきん /値千金/
あたいていぎ /値定義/
あたいひょう /値表/
あたいよび /値呼び/
あたえかた /与え方/
あたか /安宅/宛/恰/
あたかも /恰も/宛も/宛/
あたがわ /熱川/
あたく /安宅/
あたくし /私/
あたけ /安宅/
あたご /愛宕/
あたごばし /愛宕橋/
あたごやま /愛宕山/
あたし /私/
あたたかみ /暖かみ/
あたま /頭/
あたまいがい /頭以外/
あたまうち /頭打ち/
あたまかず /頭数/
あたまかぶ /頭株/
あたまがみ /頭紙/
あたまがわ /頭側/
あたまきん /頭金/
あたまごし /頭越し/
あたまごなし /頭ごなし/
あたまだし /頭出し/
あたまでっかち /頭でっかち/
あたまわり /頭割り/頭割/
あたみ /熱海/
あたみえき /熱海駅/
あたみかん /熱海間/
あたらし /新子/
あたらしや /新屋/
あたり /当たり/辺り/当り/辺/邊;「辺」の旧字1/邉;「辺」の旧字2/
あたりがね /当り鉦;ちゃんちき/
あたりくじ /当たり籤/
あたりさわり /当たり障り;-のない/当り障り/
あたりどころ /当たり所/
あたりどし /当たり年/
あたりはずれ /当たり外れ/当り外れ/
あたりばち /当たり鉢;「擂鉢」の忌言葉/当り鉢/
あたりまえ /当たり前/当り前/
あたりや /当たり屋/当り屋/
あたりやく /当たり役/当役/当り役/
あたる /鼎/中/
あたん /亜炭/
あだ /仇/徒/婀娜/讐/讎/
あだい /亜大;亜細亜大学/
あだうち /仇討ち/仇討/
あだうちもの /仇討物/
あだごと /徒事/
あだざくら /徒桜/
あだしごと /徒し事/
あだしの /徒野/化野/
あだたら /安達太良/
あだたらこうげん /安達太良高原/
あだたらやま /安達太良山/
あだち /足立/安達/足達/
あだちく /足立区/
あだっきゅう /亜脱臼/
あだて /当/
あだな /渾名;nickname/仇名;(当て字) =渾名/徒名;噂/綽名;=渾名/あだ名/
あだなみ /徒波/
あだばな /徒花/
あだもの /徒物/
あだゆめ /徒夢/
あだん /ア段/阿檀/
あち /彼方/阿智;地名,長野/閼;(呉音の一つ)/窪地;?/
あちこち /彼方此方/
あちら /彼方/
あちらこちら /彼方此方/
あちわ /阿知波/
あっか /悪化/悪貨/
あっかい /圧壊/圧潰/
あっかく /圧覚/
あっかどご /アッカド語;Akkadian/
あっかん /圧巻/悪漢/
あっかんじょう /悪感情/
あっかんたんてい /悪漢探偵/
あっかんども /悪漢共/
あっき /悪気/悪鬼/
あっきらせつ /悪鬼羅刹/
あっく /悪口/
あっけ /呆気/
あっけい /悪計/
あっけし /厚岸/
あっけない /呆気ない/
あっこう /悪口/
あっこうぞうごん /悪口雑言/
あっさい /圧砕/
あっさく /圧搾/
あっさくき /圧搾機;presser/
あっさくくうき /圧搾空気/
あっさつ /圧殺/
あっさぶ /厚沢部/
あっし /圧死/私;(要ルビ)/
あっしゅく /圧縮/
あっしゅくがす /圧縮ガス/
あっしゅくがわ /圧縮側/
あっしゅくき /圧縮機/
あっしゅくきちょう /圧縮記帳/
あっしゅくきのう /圧縮機能/
あっしゅくぎじゅつ /圧縮技術/
あっしゅくくうき /圧縮空気/
あっしゅくけい /圧縮系/
あっしゅくけいしき /圧縮形式/
あっしゅくこうりつ /圧縮効率/
あっしゅくご /圧縮後/
あっしゅくちんれつ /圧縮陳列/
あっしゅくど /圧縮度/
あっしゅくばん /圧縮版/
あっしゅくひ /圧縮比/
あっしゅくふぁいる /圧縮ファイル/
あっしゅくほう /圧縮法/
あっしゅくほうしき /圧縮方式/
あっしゅくほうほう /圧縮方法/
あっしゅくまえ /圧縮前/
あっしゅくよう /圧縮用/
あっしゅくりつ /圧縮率/
あっしょう /圧勝/
あっせい /圧政;†tyranny.「皇帝の-」/圧制;†oppression.「民衆を-する」/
あっせつ /圧雪/圧接/
あっせつしゃ /圧雪車/
あっせつじょうたい /圧雪状態/
あっせん /斡旋/
あっせんしゅうわい /斡旋収賄/
あっそう /圧送/
あっち /彼方/
あっちこっち /彼方此方/
あっちゃく /圧着/
あっちゃくぶ /圧着部/
あっつう /圧痛/
あってん /圧点/
あっと /＠/
あっとう /圧倒/
あっとうてき /圧倒的/
あっとうてきたすう /圧倒的多数/
あっとうてきたすうは /圧倒的多数派/
あっとうてきゆうり /圧倒的有利/
あっとこ /厚床/
あっばーすちょう /アッバース朝;Abbasids/
あっぱい /圧排/
あっぱく /圧迫/
あっぱくかん /圧迫感/
あっぱくこっせつ /圧迫骨折/
あっぱくめんせつ /圧迫面接/
あっぱれ /天晴れ/天晴/遖/
あっぴ /安比/
あっぴこうげん /安比高原/
あっぷく /圧服/圧伏;≒圧服/
あつ /圧/厚/暑/熱/篤/軋;軋轢/斡;斡旋/遏;(とどめる)/壓;「圧」の旧字/淳;(人名用)/惇;(人名用)/敦;(人名用)/閼;?/乢;?/
あつ> /厚/
あつあげ /厚揚げ/
あつあつ /熱々/
あついた /圧板/
あつえん /圧延/
あつえんき /圧延機/
あつお /敦夫/淳夫/厚雄/敦男/
あつかい /扱い/扱/
あつかいかた /扱い方/
あつかいさき /扱先/
あつかいだか /扱い高/
あつかいてん /扱店/
あつかいりょう /扱い量/
あつかべ /厚壁/
あつかん /熱燗/
あつがま /厚釜/
あつがましき /厚釜式/
あつがみ /厚紙/
あつがり /暑がり/
あつき /敦紀;名/
あつぎ /厚木/厚着/
あつぎえいぎょうしょ /厚木営業所/
あつぎえき /厚木駅/
あつぎかん /厚木間/
あつぎきち /厚木基地/
あつぎし /厚木市/
あつぎしない /厚木市内/
あつぎないろん /厚木ナイロン/
あつぎぬ /厚衣/
あつぎほうめん /厚木方面/
あつぎり /厚切り/
あつけし /厚岸/
あつげしょう /厚化粧/
あつこ /淳子/温子/敦子/あつ子/厚子/篤子/惇子/亜都子/
あつさ /暑さ/厚さ/
あつさしのぎ /暑さ凌ぎ/
あつし /淳/敦/篤/厚/陸/篤史/敦史/篤志/厚志/敦士;名/敦司/淳史/敦志/篤司/充史/
あつしば /厚芝/
あつじ /厚地/
あつじょう /圧条/
あつぜつし /圧舌子/
あつぞこ /厚底/
あつぞこぐつ /厚底靴/
あつた /熱田/厚田/
あつたか /篤孝/
あつたじんぐう /熱田神宮/
あつつぐ /淳嗣/
あつで /厚手/
あつでん /圧電/
あつでんき /圧電気;[化学]piezoelectricity/
あつでんこうか /圧電効果/
あつでんざい /圧電材/
あつでんたい /圧電体/
あつにゅう /圧入/
あつぬり /厚塗り/厚塗/
あつのぶ /篤信/
あつひこ /敦彦/篤彦/淳彦/
あつひと /厚人/
あつひろ /敦弘/淳裕/厚宏/
あつび /熱火/
あつへいこお /圧平衡;※仮名遣い「へいこう」/
あつべつ /厚別/
あつま /厚真/
あつまり /集まり/集り/
あつみ /厚味/厚み/温海/渥美/淳美/厚見/
あつみちょう /渥美町/
あつみつ /圧密;consolidation/
あつみはんとう /渥美半島/
あつめ /厚め/熱め/厚目/熱目/
あつもの /羹/
あつもり /敦盛/
あつもりそう /敦盛草/
あつや /篤哉/
あつやき /厚焼き/厚焼;-卵/
あつやきたまご /厚焼き卵/
あつゆ /熱湯/
あつゆき /敦之/淳之/篤幸/
あつよう /厚様/
あつらえ /誂え/
あつらえむき /誂え向き/
あつりょく /圧力/壓力;「圧」旧字/
あつりょくいじょう /圧力以上/
あつりょくか /圧力下/
あつりょくがま /圧力釜/
あつりょくけい /圧力計/
あつりょくこうばい /圧力勾配/
あつりょくさ /圧力差/
あつりょくだんたい /圧力団体/
あつりょくなべ /圧力鍋/
あつりょくは /圧力波/
あつりょくようき /圧力容器/
あつれき /軋轢/
あつろう /篤郎;名/淳良/
あづかりきん /預かり金/
あづち /安土/
あづちじだい /安土時代;1576-82/
あづちじょう /安土城/
あづちももやまじだい /安土桃山時代/
あづま /吾妻/我妻/東/
あづません /吾妻線/
あづまばし /吾妻橋/
あづまや /東谷/
あて /宛/当て/貴/
あてうま /当て馬/
あてがいぶち /宛行扶持/
あてぎ /当て木/
あてこすり /当て擦り/
あてこと /当て事/
あてさき /宛先/宛て先/
あてさきじゅん /宛先順/
あてさきにん /宛先人/
あてさきふめい /宛先不明/
あてさきめい /宛先名/
あてじ /当て字/あて字/宛字/宛て字/
あてずいりょう /当て推量/
あてずっぽう /当てずっぽう/
あてつ /阿哲/
あてつけ /当て付け/
あてど /当て所/
あてな /宛名/宛て名/
あてないんじ /宛名印字/
あてながき /宛名書/宛名書き/
あてにげ /当て逃げ/
あてぬの /当て布;patch/
あてね /雅典/
あてはつ /宛発/
あてびと /貴人/
あてぶり /当て振り/
あてみ /当て身/
あてもの /当て物/
あてらざわ /左沢/
あてるい /阿弖流為/
あで /艶/
あですがた /艶姿/
あでのしんさんりんさん /アデノシン三リン酸/
あでやか /艶やか/
あと /後/跡;trace.「-を追う」「-が残る」/痕;きずあと/蹟;物事のあと/踪;あしあと/atto;[SI接頭語]a,10^-18/
あとあし /後足/後脚/
あとあじ /後味/
あとあと /後々/後後/
あといっこ /後一個/
あといっぽ /後一歩/
あとう /阿東;地名,山口/阿党/
あとうた /後歌/
あとうだ /阿刀田/
あとおい /後追い/後追/
あとおし /後押し/
あとかいぎ /後会議/
あとかた /跡形/跡かた/
あとかたづけ /後片付け/後かたづけ/後片付/
あとかわ /後川/
あとがき /後書き/後書/
あとがね /後金;=あときん/
あとがま /後釜/
あときん /後金/
あとくされ /後腐れ/
あとくち /後口/
あとこうてい /後工程/
あとさき /後先/
あとさく /後作/
あとざん /後産/
あとしまつ /後始末/
あとしょり /後処理/
あとすうねん /後数年/
あとずさり /後退り/
あとぜめ /後攻め/
あとぞめ /後染め/
あとだし /後出し/
あとち /跡地/
あとぢえ /後知恵/
あとつぎ /跡継ぎ/後継ぎ/後継/跡継/
あとづけ /後付け/後付/
あととり /跡取り/
あとのまつり /後の祭り/後の祭/
あとのり /後乗り/後ノリ/
あとはん /後版/
あとばらい /後払い/
あとばん /後番;後番組/
あとばんぐみ /後番組/
あとぴーせい /アトピー性/
あとぴーせいひふえん /アトピー性皮膚炎/
あとべ /跡部/
あとまわし /後回し/
あとみ /跡見/
あとみがくえん /跡見学園/
あとみや /後宮/
あとめ /跡目/
あとめあらそい /跡目争い/
あとめそうぞく /跡目相続/
あともどり /後戻り/
あとやく /後厄/
あとり /花鶏/
あど /亜土/
あどがわ /安曇川/
あどりあかい /アドリア海/
あどれすちょう /アドレス帳/
あな /穴;くぼんだあな/孔;突き抜けたあな/坑;垂直なあな/
あなあき /穴開き/
あなあきせん /穴明き銭/
あなあけ /穴開け/
あない /案内/穴井/
あなうま /穴馬/
あなうめ /穴埋め/
あなかんむり /穴冠;[部首]「窓」のかんむり/
あながち /強ち/
あながま /穴窯/
あながわ /穴川/
あなきょうだい /穴兄弟;[卑]/
あなぐま /穴熊/
あなぐら /穴蔵/窖/
あなご /穴子/
あなし /阿梨/
あなた /貴方/彼方;there/貴女/
あなたがた /貴方方/貴女方/あなた方/
あなたこなた /彼方此方/
あなたじしん /貴方自身/
あなたたち /貴方達/あなた達/
あなたまかせ /貴方任せ/
あなだ /穴田/
あなとう /穴党/
あなどり /侮り/
あなにんき /穴人気/
あなば /穴場/穴馬/
あなぶき /穴吹/
あなほり /穴掘り/
あなぼこ /穴ぼこ/
あなみず /穴水/
あなやま /穴山/
あなよそう /穴予想/
あなろぐかいせん /アナログ回線/
あなろぐどけい /アナログ時計/
あなろぐばん /アナログ盤/
あなろぐほうそう /アナログ放送/
あなん /阿南/
あなんだ /阿難陀;Ananda/
あに /兄/豈/阿仁;地名,秋田/
あにい /兄い/
あにうえ /兄上/
あにき /兄貴/
あにきぶん /兄貴分/
あにぎみ /兄君/
あにさま /兄様/
あにじゃ /兄者/
あにでし /兄弟子/
あにめえ /アニメ絵/
あにめえいが /アニメ映画/
あにめか /アニメ化/
あにや /安仁屋/
あによめ /兄嫁/嫂/
あね /姉/姐/
あねうえ /姉上/
あねおとうと /姉弟/
あねがこうじ /姉小路;地名/
あねがさき /姉ヶ崎/
あねがわ /姉川/
あねき /姉貴/
あねぎみ /姉君/
あねご /姉御/姐御/
あねごはだ /姉御肌/姐御肌/
あねさき /姉崎/
あねさま /姉様/
あねさん /姐さん/姉さん;NB:「ねえさん」と同形/
あねさんにょうぼう /姉さん女房/
あねざき /姉崎/
あねじゃ /姉者/
あねたい /姉帯;姓/
あねったい /亜熱帯/
あねったいせい /亜熱帯性/
あねったいちいき /亜熱帯地域/
あねったいちほう /亜熱帯地方/
あねむこ /姉婿/
あの> /彼の/
あのう /穴太;地名/安濃;地名/
あのかた /彼の方;(要ルビ)/あの方/
あのくたら /阿耨多羅/
あのくたらさんみゃくさんぼだい /阿耨多羅三藐三菩提/
あのこ /あの子/あの娘/
あのころ /あの頃/
あのつ /安濃津;地名,三重/
あのてこのて /あの手この手/
あのひ /あの日/
あのへん /あの辺/
あのよ /あの世/彼の世/
あのよう /彼の様/
あはなち /畔放/畔放ち/
あば /阿波/浮子/網端;網用の「うき」/
あばしり /網走/
あばしりえき /網走駅/
あばしりこ /網走湖/
あばずれ /阿婆擦れ;bitch/
あばた /痘痕/
あばら /肋/
あばらぼね /肋骨/あばら骨/
あばれ /暴れ/
あばれうま /暴れ馬/
あばれがわ /暴れ川/
あばれもの /暴れ者/
あばれんぼう /暴れん坊/
あぱらちあさんみゃく /アパラチア山脈/
あひかけ /足腰/
あひさん /亜砒酸/
あひる /家鴨/鶩;=家鴨/阿比留/
あび /阿鼻/阿比;[鳥]/
あびき /網引/
あびきょうかん /阿鼻叫喚/
あびこ /我孫子/安彦/
あびこし /我孫子市/
あびじごく /阿鼻地獄/
あびせたおし /浴びせ倒し/
あびだつま /阿毘達磨;[仏教]abhidharma/
あびる /阿比留/
あふ /亜父/阿父/凹;旧仮名/押;旧仮名/
あふち /樗/楝/
あふりか /阿弗利加/
あふりかけい /アフリカ系/
あふりかじん /アフリカ人/
あふりかぞう /アフリカ象/
あふりかたいりく /アフリカ大陸/
あふりかとういつきこう /アフリカ統一機構;OAU/
あぶ /虻/阿武/
あぶく /泡/
あぶくぜに /泡銭/
あぶくま /阿武隈/
あぶくまがわ /阿武隈川/
あぶくまきゅうこう /阿武隈急行/
あぶくまさんち /阿武隈山地;地名/
あぶしんべるしんでん /アブシンベル神殿/
あぶた /虻田/
あぶな /危な/
あぶなえ /危絵/
あぶなげ /危な気/
あぶはち /虻蜂;「-取らず」/
あぶはちとらず /虻蜂取らず/
あぶみ /鐙/
あぶみがわら /鐙瓦;=軒丸瓦/
あぶみこつ /鐙骨/
あぶら /油/脂;常温で固体のあぶら/膏;肉のあぶら/
あぶらあか /脂垢/油垢/
あぶらあげ /油揚げ/油揚/
あぶらあげぼん /油揚本/
あぶらあせ /脂汗/
あぶらいし /油石/
あぶらいため /油炒め/
あぶらいろ /油色/
あぶらえ /油絵/
あぶらえのぐ /油絵具/油絵の具;oil/
あぶらかす /油粕;oilcake. (肥料にする)/油糟;<rare>/
あぶらかわ /油川/
あぶらがに /油蟹;タラバガニのパチモン/
あぶらがみ /油紙/
あぶらぐすり /膏薬/脂薬/
あぶらぐち /油口/
あぶらげ /油揚/
あぶらこし /油漉し/
あぶらさし /油差し/油注し/
あぶらざめ /油鮫/
あぶらざら /油皿/
あぶらしょう /脂性/
あぶらぜみ /油蝉/
あぶらだ /油田;姓/
あぶらつち /油土/
あぶらつぼ /油壺/油壷;「壺」異体字/
あぶらづけ /油漬;イワシの-缶詰/油漬け/
あぶらとり /脂取り/
あぶらどおし /油通し;[料理]炒める前に軽く揚げておくこと/
あぶらな /油菜/薹/
あぶらなか /アブラナ科/
あぶらぬき /油抜き/
あぶらねんど /油粘土/
あぶらひ /油日/
あぶらひき /油引き/
あぶらぶん /油分/
あぶらみ /脂身/油身/
あぶらむし /油虫/蜚/
あぶらめ /油女/
あぶらもと /油本;姓/
あぶらや /油屋/
あぶらやけ /油焼け/
あぶり /炙り/焙り/
あぶりだし /炙り出し/
あぶりやき /炙り焼き/
あぶれもの /溢れ者/
あへん /阿片/鴉片;=阿片/
あへんくつ /阿片窟/
あへんせんそう /阿片戦争;[世界史]清vs英国/
あへんちゅうどく /阿片中毒/
あべ /阿部;-和重/安倍;-晴明/安部;-公房/阿倍;-仲麻呂/阿武;あぶ?/
あべかわ /安倍川/
あべかわもち /安倍川餅/
あべがくいん /安部学院/
あべこうぼう /安部公房;(1924-93)作家。『砂の女』/
あべた /安部田/
あべの /阿倍野;†地名,大阪/阿部野;†阿倍野にある駅名/
あべのく /阿倍野区/
あべのせいめい /安倍晴明/
あべのなかまろ /阿倍仲麻呂/
あべまき /阿部槙/
あほ /阿呆/
あほう /阿呆/阿房/
あほうづら /阿呆面/
あほうどり /信天翁/
あほうれっしゃ /阿房列車/
あほだらきょう /阿呆陀羅経/
あぼ /安保/英保/阿母/
あぼう /安房/
あぼうとうげ /安房峠/
あぼがどろていすう /アボガドロ定数;6.0221367*10^23 mol^-1/
あぼし /網干/
あぽくりんせん /アポクリン腺/
あぽろてき /アポロ的;[美学]Apollonic/
あぽろんてき /アポロン的;[美学]Apollonic/
あま /尼/海人/海士/海女/亜麻/甘/天/雨/蜑;=海人/塰;=海士/
あまあし /雨足/雨脚/
あまいけ /天池/雨池/
あまいた /天板/
あまいと /亜麻糸/
あまいろ /亜麻色/
あまうけ /雨受け/
あまえ /甘え/
あまえっこ /甘えっ子/
あまえび /甘海老/甘エビ/甘えび/
あまえんぼ /甘えん坊/
あまえんぼう /甘えん坊/
あまお /雨尾/
あまおおい /雨覆い/
あまおと /雨音/
あまおとめ /天少女/
あまかす /甘粕/甘糟/
あまかぜ /雨風/
あまかみ /甘噛み/
あまから /甘辛/
あまからに /甘辛煮/
あまかわ /天川/甘皮/
あまかんむり /雨冠/
あまがい /天海/雨海/
あまがえる /雨蛙/
あまがき /甘柿/
あまがさ /雨傘;umbrella/雨笠;rain hat/雨がさ/雨ガサ/
あまがさき /尼崎/
あまがさきかん /尼崎間/
あまがさきし /尼崎市/
あまがさばんぐみ /雨傘番組;天候の都合で中止された番組の代りに放送される番組/
あまがせ /天瀬/天ケ瀬/
あまがっぱ /雨合羽/雨ガッパ;raincoat/
あまがみ /甘噛み/
あまき /天木/
あまぎ /天城/甘木/雨着/亜麻木/
あまぎごえ /天城越え/
あまぎせん /甘木線/
あまぎとうげ /天城峠/
あまぎみ /尼君/
あまぎゆがしま /天城湯ヶ島/
あまぎゆがしまちょう /天城湯ヶ島町/
あまぎり /雨霧/
あまくさ /天草/
あまくさしろう /天草四郎/
あまくさばん /天草版/
あまくだり /天下り/天降り/
あまくち /甘口/
あまくぼ /天久保/
あまぐ /雨具/
あまぐつ /雨靴/
あまぐも /雨雲/
あまぐり /甘栗/
あまこ /尼子/
あまごい /雨乞い/
あまさ /甘さ/
あまざけ /甘酒/
あまざらし /雨曝し/雨晒し/
あまし /蔗/
あましょく /甘食/
あまじ /天路/
あまじお /甘塩/
あまじみ /雨染み/
あますところ /余す所/
あまず /甘酢/
あまずあえ /甘酢和え/
あまぞら /雨空/
あまた /数多/天田/
あまだ /天田/
あまだい /甘鯛/
あまだな /天棚/
あまだれ /雨垂れ/雨だれ/
あまち /天地/天池;(いけ)/
あまちまり /天地真理/
あまちゃ /甘茶/
あまちゃづる /甘茶蔓/
あまちゃん /甘ちゃん/
あまったれ /甘ったれ/
あまつ /天津/
あまつかぜ /天つ風/天津風/
あまつかみ /天津神/天つ神/
あまつくに /天津国/
あまつさえ /剰え/
あまつじ /天辻/
あまつつみ /天津罪/天つ罪/
あまつばめ /雨燕/
あまつぶ /雨粒/
あまづ /天津/
あまてらすおおみかみ /天照大神/天照大御神/
あまでら /尼寺/
あまとう /甘党/
あまとぶや /天飛ぶや/
あまど /雨戸/
あまどい /雨樋/
あまどり /天鳥/
あまどりのみこと /天鳥命/
あまなっとう /甘納豆/
あまなつ /甘夏/
あまに /甘煮/
あまぬま /天沼/
あまね /周/
あまの /天野/雨野/
あまのいわと /天の岩戸/天の磐戸/
あまのかぐやま /天香久山/
あまのがわ /天の川/天の河/
あまのじゃく /天邪鬼/天の邪鬼/
あまのはしだて /天橋立/天の橋立/
あまのはら /天の原/
あまのむらくものつるぎ /天叢雲剣;草薙剣/
あまのり /甘海苔/
あまぶた /雨蓋/
あまべ /海部/
あまほうし /尼法師/
あまみ /甘味/奄美/甘み/
あまみおおしま /奄美大島/
あまみず /雨水/
あまみそ /甘味噌/
あまみちほう /奄美地方/
あまみや /雨宮/天宮/
あまめ /甘め/甘目/
あまも /甘藻/
あまもと /天本/
あまもよい /雨催/雨催い/
あまもよう /雨模様/
あまもり /雨漏り/雨森/雨漏/
あまやか /甘やか/
あまやどり /雨宿り/
あまよ /雨夜;-の品定め/
あまよけ /雨除け/雨避け;=雨除け/
あまり /余り/甘利/
あまりもの /余り物;-で恐縮ですが/
あまるべ /余部/餘部;「余」旧字/
あまるめ /余目/
あまんざ /甘座/
あみ /網/阿弥/亜美;人名/阿見/醤蝦/网/罔/糠蝦/
あみあげぐつ /編み上げ靴/編上靴/
あみあぶら /網油/
あみうち /網打ち/
あみえ /網江/
あみかけ /網掛け/網かけ/網掛/
あみかんり /網管理/
あみがさ /編笠/編み笠/
あみがしら /罔頭/
あみき /編み機/
あみぎょぎょう /網漁業/
あみこ /安見子/
あみこみ /編み込み/
あみしま /網島/
あみしろ /網代/
あみじ /編地/
あみじゃくし /網杓子/
あみじょう /網状/
あみせいぎょ /網制御/
あみせつぞく /網接続/
あみたいつ /網タイツ/
あみだ /阿弥陀/
あみだくじ /阿弥陀籤/
あみださんぞん /阿弥陀三尊/
あみだどう /阿弥陀堂/
あみだな /網棚/
あみだにょらい /阿弥陀如来/
あみだぶつ /阿弥陀仏/
あみちょう /阿見町/
あみてん /網点/
あみど /網戸/
あみなか /網中/
あみの /網野/
あみのき /アミノ基;animo group/
あみのさん /アミノ酸/
あみのとう /アミノ糖;aminosugar/
あみのめ /網の目/
あみはま /網浜/
あみはり /網張/
あみはん /網版/
あみばり /編み針/編針/
あみびと /網人/
あみぼう /編み棒/編棒/
あみぼし /網干/
あみめ /網目/編み目/編目/
あみめおり /網目織/
あみめじょう /網目状/
あみもと /網元/
あみもの /編み物/編物/
あみや /網屋/
あみやき /網焼き/網焼/
あみわたり /網渡/
あむ /虻/
あむろ /安室/
あめ /雨/飴/天/豆汁/
あめあがり /雨上がり/
あめあし /雨足/雨脚/
あめあられ /雨霰/雨あられ/
あめいせんそう /蛙鳴蝉噪/
あめいろ /飴色/
あめおとこ /雨男/
あめおんな /雨女/
あめかぜ /雨風/
あめかんむり /雨冠/
あめがし /飴菓子;candy/
あめこう /アメ公/
あめざいく /飴細工/
あめしゃ /アメ車/
あめたいさく /雨対策/
あめたいふう /雨台風/
あめだま /飴玉/
あめつち /天地/
あめつぶ /雨粒/
あめつゆ /雨露/
あめに /飴煮/
あめのもり /雨森/
あめふらし /雨降/雨虎/
あめふり /雨降り/雨ふり/
あめみや /雨宮/
あめもよう /雨模様/
あめや /飴屋/
あめやよこちょう /アメヤ横丁;地名,通称「アメ横」/
あめよこ /アメ横/
あめよほう /雨予報/
あめりか /亜米利加/亞米利加;「亜」旧字/米/
あめりかえいが /アメリカ映画/
あめりかえいご /アメリカ英語/
あめりかがっしゅうこく /アメリカ合衆国/
あめりかぐん /アメリカ軍/
あめりかさん /アメリカ産/
あめりかしき /アメリカ式/
あめりかしじょう /アメリカ市場/
あめりかしゃ /アメリカ車/
あめりかじん /アメリカ人/
あめりかせい /アメリカ製/
あめりかたいりく /アメリカ大陸/
あめりかてき /アメリカ的/
あめりかぶんか /アメリカ文化/
あめりしうむ /Am/Americium/
あめんぼ /水馬/水黽/飴坊/
あも /母/餅/
あもい /厦門/廈門/
あもく /亜目/
あもん /亜門/
あや /綾;言葉の-/文;≒綾/彩/絢;≒綾/礼;(人名用)/彪;(虎の縞模様)/亜弥;人名/亜矢/亜也/漢/禮;「礼」の旧字(人名用漢字)/
あやいがさ /綾藺笠/
あやいと /綾糸/
あやう /危/
あやうじ /漢氏/
あやうた /綾歌/
あやおり /綾織/綾織り/
あやか /彩香/綾香/
あやかみ /綾上/
あやがみ /綾上/
あやぎく /綾菊/
あやぎぬ /綾絹/綺/
あやこ /綾子/彩子/文子/亜矢子/絢子/章子/亜弥子/亜也子/操子/
あやし /愛子/怪し/
あやしろ /綾城/
あやせ /綾瀬;地名,足立区／神奈川/綾世;人名?/
あやせえき /綾瀬駅/
あやせがわ /綾瀬川/
あやせし /綾瀬市/
あやせししょうこうかい /綾瀬市商工会/
あやせま /綾瀬間/
あやたり /綾足/
あやだけ /綾竹/
あやつ /彼奴/
あやつか /綾塚/
あやつじ /綾辻/
あやつり /操/
あやつりにんぎょう /操り人形/操人形/
あやとも /文友/
あやとり /綾取り/
あやね /綾音/
あやの /綾乃/綾野/
あやのこうじ /綾小路/
あやのみや /礼宮/
あやはな /彩花/
あやふみ /礼史/
あやべ /綾部/
あやま /阿山/
あやまち /過ち/誤ち;?/
あやまり /誤り/謬り/謝り/
あやまりりつ /誤り率/
あやむら /文村/
あやめ /菖蒲/文目/
あやめいけ /あやめ池/
あやめか /アヤメ科/
あやめざけ /菖蒲酒/
あやめもく /アヤメ目/Iridales/
あやめもくあぐん /アヤメ目亜群/
あゆ /鮎/阿諛/東風/
あゆかわ /鮎川/
あゆこ /亜佑子/
あゆさわ /鮎澤/
あゆざわ /鮎澤/
あゆついしょう /阿諛追従/
あゆついじゅう /阿諛追従;あゆついしょう ※おもねる意では「追従」は「ついしょう」と読む/
あゆつり /鮎釣り/
あゆづり /鮎釣り/
あゆみ /歩み/亜由美/歩美/亜弓/歩/彩友美/天弓;名/
あゆみあし /歩み足/
あゆみいた /歩み板/
あゆみより /歩み寄り/
あゆむ /渉/
あら /新/粗/荒/
あら> /粗;粗挽き,粗加工,粗仕上げ/新;新手,新鉢,新屋敷/現;現人神,現御神/
あらい /新井/荒井/新居/
あらいおけ /洗い桶/
あらいかた /洗い方/
あらいがえ /洗い替え/
あらいがき /洗柿/
あらいがみ /洗い髪/
あらいぐま /洗熊/浣熊/
あらいざらい /洗い浚い/
あらいざらし /洗い晒し/
あらいし /荒石/
あらいしゅ /洗朱/
あらいじゅく /新井宿/
あらいそ /荒磯/
あらいだし /洗い出し/
あらいど /荒井戸/
あらいはくせき /新井白石/
あらいはり /洗い張り/
あらいば /洗い場/
あらいまち /新居町/
あらいもの /洗い物/
あらいわ /荒岩/
あらうま /荒馬/
あらうみ /荒海/
あらお /荒尾/荒生/
あらおり /粗織/
あらか /殿/
あらかじめ /予め/予/豫め;「予」旧字/豫;「予」の旧字/
あらかせぎ /荒稼ぎ/
あらかた /粗方/
あらかね /鉱;未精錬の金属/粗金;未精錬の金属/
あらかべ /荒壁/粗壁/
あらかわ /荒川/粗皮/
あらかわおき /荒川沖/
あらかわおきえき /荒川沖駅/
あらかわく /荒川区/
あらかわしゃこまえ /荒川車庫前/
あらかわせん /荒川線/
あらかわだけ /荒川岳/
あらかわほうすいろ /荒川放水路/
あらかん /阿羅漢/
あらがき /新垣/荒書き/
あらがね /鉱;未精錬の金属/粗金;未精錬の金属/荒金;地名(茨城県),姓/
あらき /荒木/
あらきだ /荒木田/
あらきどんさん /アラキドン酸/
あらきの /新木野/
あらきゆみこ /荒木由美子/
あらぎも /荒肝/
あらぎょう /荒行/
あらぎり /粗切り/荒切り/
あらくさ /荒草/
あらくち /新口/
あらくれ /荒くれ/
あらくれもの /荒くれ者/
あらけ /有明/
あらけずり /荒削り/粗削り/
あらこ /荒子/
あらごし /粗漉し/
あらごと /荒事/
あらごなし /荒ごなし/
あらさがし /粗探し/あら探し/粗捜し/
あらさき /荒崎/
あらさわ /荒沢/荒澤/
あらし /嵐/荒らし/
あらしがおか /嵐ヶ丘/
あらしごと /荒仕事/
あらしね /荒稲/
あらしやま /嵐山/
あらしやまびじゅつかん /嵐山美術館/
あらじお /粗塩/
あらじる /粗汁/あら汁/
あらすかはんとう /アラスカ半島/
あらすじ /粗筋/
あらず /非ず/
あらぜき /荒関/
あらそい /争い/
あらそいごと /争い事/
あらた /新た/新田/荒田/新太;名/新/
あらたけ /荒武/
あらたに /荒谷/
あらたま /新田間/
あらため /改め/
あらためて /改めて/
あらだき /あら炊き/
あらち /新血/
あらちゃ /荒茶/
あらづくり /粗造り/
あらて /新手/
あらと /荒砥/
あらどこ /新床/
あらなみ /荒波/
あらなわ /荒縄/
あらぬの /粗布/
あらねつ /粗熱/
あらの /荒野/曠野/
あらはた /荒畑/
あらはま /荒浜/
あらばち /新鉢;virgin/
あらひとがみ /現人神/荒人神/
あらびあ /亜剌比亜;Arabia/亜拉毘亜/亞剌比亞;「亜」旧字/
あらびあご /アラビア語;assalam alaikum/
あらびあじん /アラビア人;Arabian/
あらびあすうじ /アラビア数字;0123456789(普通の「数字」)/
あらびあせきゆ /アラビア石油;[企業名]/
あらびあもじ /アラビア文字/
あらびき /粗挽き;-ウインナー,-豆/粗引き/粗碾き/
あらふか /荒深/
あらふね /荒船/
あらぶけい /アラブ系/
あらぶじん /アラブ人/
あらほうし /荒法師/
あらぼとけ /新仏/
あらぼん /新盆/
あらまき /荒巻;-鮭/荒牧;地名/新巻;=荒巻/
あらまきじゃけ /新巻鮭/
あらまさ /新政/
あらまた /荒俣/
あらまち /荒町/
あらまつ /荒松/
あらむご /アラム語;Aramaic/
あらむしゃ /荒武者/
あらむしろ /荒筵/粗筵/
あらむもじ /アラム文字/
あらめ /荒目/荒布/
あらもと /荒本/
あらもの /荒物/
あらものや /荒物屋/
あらや /新屋/新谷/
あらやしき /新屋敷/阿頼耶識/
あらやま /荒山/
あらゆ /新湯/
あらゆる /凡/∀/
あららぎ /蘭;[植物]/塔;(忌み言葉) tower/
あららぎは /アララギ派/
あらり /粗利/
あらりえき /粗利益/荒利益;=粗利益/
あらりょうじ /荒療治/
あらりょうち /荒療治/
あられ /霰/
あられしょうが /霰生薑/
あらわ /露;(字義:透明なので見える)/顕;(字義:顔を見せている)/現;動詞語幹?/表;動詞語幹?/露わ/
あらわざ /荒技/荒業/
あらわし /荒鷲/
あらわしかた /表し方/
あらわれ /現れ/表れ/顕れ/
あらん /亜蘭/亜欄/
あり /蟻/有/阿梨/有り/衽/袵/
ありーなせき /アリーナ席/
ありあけ /有明/
ありあけかい /有明海/
ありあけころしあむ /有明コロシアム/
ありあけしらうお /有明白魚/
ありあけせん /有明線/
ありあけのつき /有明の月/
ありあけばし /有明橋/
ありあけひめしらうお /有明姫白魚/
ありあり /有り有り;-と分かる/在り在り;-と浮び上がる/
ありあわせ /有り合わせ/
ありう /有り得/
ありえ /有家/
ありか /在処/在り処/亜里香/
ありかた /あり方/在り方/有り方/
ありかべ /有壁/蟻壁;[建築]/
ありかわ /有川/
ありが /有賀/有我/
ありがた /有難/有り難;-や,-迷惑/
ありがたみ /有難味/ありがた味/
ありがためいわく /有難迷惑/有り難迷惑/
ありがち /有り勝ち/
ありがとう /有難う/有り難う/
ありがね /有り金/
ありき /有木/
ありきたり /在り来り/
ありくい /蟻食/食蟻獣/
ありくら /有倉/
ありげ /有り気/
ありさ /亜里沙/亜利沙/亜理佐/
ありさか /有坂/
ありさま /有様/有り様/
ありさわ /有沢/有澤/
ありさん /阿里山/
ありざ /有座/
ありしひ /在りし日;『-の歌』(中也)/
ありしま /有島;姓/
ありしまたけお /有島武郎/
ありしゃかい /蟻社会/
ありしよ /在りし世/
ありじごく /蟻地獄/
ありす /有栖/
ありすがわ /有栖川/
ありすがわのみや /有栖川宮/
ありた /有田/
ありたてつどう /有田鉄道/
ありたま /有玉/
ありたやき /有田焼/
ありだ /有田/
ありだか /有り高/
ありったけ /有りっ丈/
ありつぎ /有次/
ありつね /有恒/
ありづか /蟻塚/垤;=蟻塚/
ありてい /有り体/有体/有態/
ありとう /有藤/
ありとも /有朋/
ありなが /有永/
ありなし /有り無し/
ありのとうぐさもく /アリノトウグサ目/Haloragales/
ありのまま /有りの儘/
ありのみ /有りの実;梨/
ありはた /有畠/
ありはら /在原/有原/
ありま /有馬/
ありまおんせん /有馬温泉/
ありまきねん /有馬記念/
ありまぐち /有馬口/
ありまさ /有正/
ありみ /有里巳/
ありみつ /有光/
ありむら /有村/
ありむらさんぎょう /有村産業;[企業名]/
ありもと /有本/
ありもの /有り物/
ありもり /有森/
ありもんじ /有文字/
ありや /有家/
ありやま /有山/
ありゅーしゃんれっとう /アリューシャン列島/
ありゅう /亜流/
ありゅうさん /亜硫酸/
ありゅうさんがす /亜硫酸ガス;SO2/
ありよう /有り様/
ありよし /有吉/
ありわら /在原/
ありわらのなりひら /在原業平;平安時代の歌人。『伊勢物語』の主人公? (825-880)/
ある /或る/或/亜留/∃;exist/
ある> /或る/
あるあさ /ある朝/或る朝/
あるいは /或いは/或は/
あるかなし /有るか無し/
あるかりいおんすい /アルカリイオン水/
あるかりか /アルカリ化/
あるかりかんでんち /アルカリ乾電池/
あるかりせい /アルカリ性/
あるかりちょうせき /アルカリ長石;alkali feldspar/
あるかりでんち /アルカリ電池/
あるかりど /アルカリ度/アルカリ土/
あるかりどじょう /アルカリ土壌/
あるかりどるいきんぞく /アルカリ土類金属;Ca,Sr,Ba,Ra/
あるが /有賀/
あるき /歩き/
あるきかた /歩き方/
あるきたばこ /歩き煙草/歩きタバコ;-は迷惑です/
あるきめですのげんり /アルキメデスの原理/
あるきるき /アルキル基/
あるぎんさん /アルギン酸/
あるこーるいぞんしょう /アルコール依存症/
あるこーるいんりょう /アルコール飲料/
あるこーるちゅうどく /アルコール中毒/
あるこーるどすう /アルコール度数/
あるこーるぶん /アルコール分/
あることないこと /有る事無い事/
あるござ /アルゴ座;88星座には含まれない/
あるごん /Ar/Argon/
あるしゅ /或る種/ある種/
あるじ /主/
あるじもうけ /饗設け/
あるぜんちん /亞爾然丁;「亜」旧字/
あるたみらどうくつ /アルタミラ洞窟;Altamira/
あるちゅう /アル中/
あるつはいまーびょう /アルツハイマー病;Alzheimer/
あるとき /ある時/或る時/
あるときばらい /有る時払い/
あるところ /ある所/
あるとし /ある年/或る年/
あるばいとだい /アルバイト代/
あるばいとりょう /アルバイト料/
あるばん /ある晩/或る晩/
あるひ /ある日/或る日/
あるひと /ある人/或る人/
あるふぁ /α;alpha/Α;Alpha/
あるふぁー /α;alpha/Α;Alpha/
あるふぁせい /α星/
あるふぁせん /α線/アルファ線/
あるふぁは /α波/
あるふぁばん /α版/
あるふぁべっとじゅん /アルファベット順/
あるふぁほうかい /α崩壊/
あるふぁりゅうし /α粒子/
あるぷすでんき /アルプス電気;[企業名]/
あるへいとう /有平糖/
あるみかん /アルミ缶/
あるみせい /アルミ製/
あるみなべ /アルミ鍋/
あるみにうむ /Al/Aluminum/
あるみはく /アルミ箔;foil/
あるよ /ある夜/或る夜/
あれ /荒れ/
あれい /亜鈴;ダンベル/唖鈴;ダンベル/
あれこれ /彼是/彼此/
あれしょう /荒れ性/
あれち /荒地/荒れ地/
あれつ /ア列/あ列/
あれの /荒れ野/
あれほうだい /荒れ放題/
あれほど /彼程/
あれもよう /荒れ模様/
あれら /彼等/
あれるぎーせい /アレルギー性/
あれるぎーせいびえん /アレルギー性鼻炎/
あれるぎーたいしつ /アレルギー体質;allergic tendency/
あろかっせんものがたり /鴉鷺合戦物語/
あろじ /主/
あわ /泡;bubble/粟;millet.「濡れ手で粟」/阿波;地名,徳島/安房;地名,千葉/慌/
あわあわ /淡淡/淡々/
あわい /間/
あわいい /粟飯/
あわいけだ /阿波池田/
あわおどり /阿波踊り/
あわこうぞう /泡構造/
あわさ /粟佐/
あわさか /泡坂/
あわざ /阿波座/
あわしま /淡島/
あわじ /淡路/
あわじしま /淡路島/
あわじちょう /淡路町/
あわじちょうえき /淡路町駅/
あわじょう /泡状/
あわず /粟津/
あわせ /袷/合わせ/
あわせいれつ /泡整列/
あわせかがみ /合わせ鏡/合せ鏡/
あわせじょうゆ /合わせ醤油/合せ醤油/
あわせず /合わせ酢/合せ酢/
あわせて /併せて/
あわせみそ /合わせ味噌/合せ味噌/
あわせめ /合わせ目/合せ目/
あわせもの /合わせ物/合せ物/
あわせわざ /合わせ技/
あわた /粟田/
あわたてき /泡立て器/
あわだち /泡立ち;-の悪い石鹸/泡立/
あわだちそう /泡立草/
あわだてき /泡立て器/
あわつ /粟津/
あわつぶ /粟粒;millet/泡粒;bubble/
あわづ /粟津/
あわづおんせん /粟津温泉/
あわづはら /粟津原/
あわてもの /慌て者/
あわの /粟野/阿波野/
あわばこ /泡箱/
あわひめ /泡姫;[俗]/
あわび /鮑/鰒/蚫/
あわびむすび /鮑結び/
あわぶろ /泡風呂/
あわべん /阿波弁/
あわみどり /淡緑/
あわむらさき /淡紫/
あわめし /粟飯/
あわもり /泡盛/
あわや /粟屋/淡谷/粟谷/
あわゆき /淡雪/泡雪/沫雪/
あわゆきかん /泡雪羹/
あわゆきそば /泡雪蕎麦/
あわゆきたまご /泡雪卵/
あわゆきどうふ /泡雪豆腐/
あわら /芦原/
あわれ /哀れ/
あわれみ /哀れみ/憐れみ/
あん /案/餡/庵;いおり/安/暗/闇;明闇/諳;諳誦/黯/按;按配/鞍;鞍馬/晏/鮟;鮟鱇/罨/菴;≒庵/杏;杏子/行;行脚/閼;?/
あん> /暗;-赤褐色,-順応/
あんあんり /暗々裡/暗々裏/
あんい /安易/
あんいつ /安逸/安佚;=安逸/
あんうつ /暗鬱/
あんうん /暗雲/
あんえい /安永;年号(1772-81)/暗影/晏嬰;晏子/暗翳/
あんか /安価/行火/案下/
あんかけ /餡掛け/餡掛/
あんかせい /安価性/
あんかっしょく /暗褐色/
あんかん /安閑/暗槓/
あんかんてんのう /安閑天皇/
あんが /安臥/
あんがい /案外/
あんがいかんたん /案外簡単/
あんがいようい /案外容易/
あんき /暗記/安徽/安気;ease/安危;-存亡/暗鬼/諳記/晏起/
あんきかもく /暗記科目/
あんきほう /暗記法/
あんきも /鮟肝;アンコウのキモ/
あんきもの /暗記物/
あんきょ /暗渠/安居/
あんきりょく /暗記力/
あんぎゃ /行脚/
あんぎゃそう /行脚僧/
あんぎょう /安行/
あんくん /暗君/
あんぐ /暗愚/
あんぐう /行宮/
あんけーとちょうさ /アンケート調査/
あんけーとようし /アンケート用紙/
あんけい /安慶/
あんけん /案件/
あんけんさつ /暗剣殺/
あんげん /安元;年号(1175-1177)/
あんこ /餡こ/安固/暗刻;[麻雀](anke)/
あんこー /暗刻/
あんこう /鮟鱇/安康/暗刻;[麻雀]/鮟;(字義:サンショウウオ),?/鱇;(「鮟鱇」の一部にするために作られた国字),?/
あんこうがた /鮟鱇形/
あんこうしょく /暗紅色/
あんこうてんのう /安康天皇/
あんこうなべ /鮟鱇鍋/
あんこがた /鮟鱇形/
あんこく /暗黒/安国/闇黒/
あんこくがい /暗黒街/
あんこくくうかん /暗黒空間/
あんこくじ /安国寺/
あんこくじだい /暗黒時代/
あんこくせいうん /暗黒星雲/
あんこくたいりく /暗黒大陸/
あんこくちたい /暗黒地帯/
あんこくぶっしつ /暗黒物質;(天文) dark matter/
あんこくめん /暗黒面/
あんころもち /餡ころ餅/
あんご /安居/安吾/暗語/
あんごう /暗号;code/暗合;偶然の一致/
あんごうか /暗号化/
あんごうかぎ /暗号鍵;[情報]encryption key/
あんごうちょう /暗号帳/
あんごうひょう /暗号表/
あんごうぶん /暗号文/
あんさつ /暗殺/
あんさつけいかく /暗殺計画/
あんさつしゃ /暗殺者/
あんさつしれい /暗殺指令/
あんさつめいれい /暗殺命令/
あんさん /兄さん/
あんざ /安座/
あんざい /安西/安斉/安斎/安齋/安在/安齊/
あんざん /安産/暗算/鞍山/
あんざんがん /安山岩/
あんざんきがん /安産祈願/
あんし /暗視/晏子;春秋時代の斉の宰相/
あんししょく /暗紫色/
あんしつ /暗室/庵室/
あんしゅ /庵主/按手/
あんしゅう /暗愁/
あんしゅつ /案出/
あんしょ /暗所/
あんしょう /暗唱;†recite.「-する」/暗証;†「-番号」/暗礁;†reef.「-に乗り上げる」/暗誦;=暗唱/諳誦/
あんしょうか /暗証化/
あんしょうばんごう /暗証番号/
あんしょうぶ /暗証部/
あんしょく /暗色/
あんしん /安心/
あんしんかん /安心感/
あんしんど /安心度/
あんしんりつめい /安心立命/
あんしんりょう /安心料/
あんじ /暗示/案じ/
あんじてき /暗示的/
あんじゅ /庵主/杏樹/
あんじゅう /安住/
あんじゅんのう /暗順応/
あんじょ /晏如/
あんじょう /安城/鞍上/安生/
あんじょうきょうか /鞍上強化/
あんじょく /鞍褥/
あんじりょうほう /暗示療法;[精医]/
あんじん /安心/
あんじんりゅうみょう /安心立命/
あんじんりょうみょう /安心立命/
あんず /杏/杏子/
あんずいろ /杏子色;tangerine red/
あんせい /安静/安政;年号(1854-1860)/
あんせいじ /安静時/
あんせいど /安静度/
あんせいのたいごく /安政の大獄/
あんせきしょく /暗赤色/
あんぜん /安全/暗然/
あんぜんいき /安全域/
あんぜんうんてん /安全運転/
あんぜんえいせい /安全衛生/
あんぜんか /安全化/
あんぜんかくじつ /安全確実/
あんぜんかくにん /安全確認/
あんぜんかくほ /安全確保/
あんぜんかんり /安全管理/
あんぜんがわ /安全側/
あんぜんがわせん /安全側線/
あんぜんき /安全器/
あんぜんきかく /安全規格/
あんぜんきじゅん /安全基準/
あんぜんきょういく /安全教育/
あんぜんきょり /安全距離/
あんぜんぎじゅつ /安全技術/
あんぜんく /安全区/
あんぜんぐつ /安全靴/
あんぜんけいすう /安全係数;[物理]safety coefficient/
あんぜんけん /安全圏/安全研/
あんぜんけんきゅうしょ /安全研究所/
あんぜんこうしゅう /安全講習/
あんぜんこうしゅうかい /安全講習会/
あんぜんさく /安全策/
あんぜんじょう /安全上/
あんぜんせい /安全性/
あんぜんせいかくほ /安全性確保/
あんぜんせつび /安全設備/
あんぜんせんげん /安全宣言/
あんぜんそうこう /安全走行/
あんぜんそうち /安全装置/
あんぜんたいさく /安全対策/
あんぜんたいさくきじゅん /安全対策基準/
あんぜんだいいち /安全第一/
あんぜんちたい /安全地帯/
あんぜんていし /安全停止/
あんぜんとう /安全灯/安全燈/
あんぜんぱい /安全牌/
あんぜんひょうか /安全評価/
あんぜんび /安全日/
あんぜんぴん /安全ピン/
あんぜんべん /安全弁/
あんぜんほしょう /安全保障/
あんぜんほしょうじょうやく /安全保障条約/
あんぜんほしょうりじかい /安全保障理事会/
あんぜんぼう /安全帽;helmet/
あんぜんめん /安全面/
あんぜんもう /安全網/
あんぜんよう /安全用/
あんぜんりつ /安全率/
あんそうおん /暗騒音/
あんそく /安息/
あんそくこう /安息香/
あんそくこうさん /安息香酸;C6H5COOH/
あんそくび /安息日/
あんそっこう /安息香/
あんたい /安泰/
あんたく /安宅/
あんたくせいろ /安宅正路/
あんたん /暗澹/
あんだ /安打/
あんだすう /安打数/
あんち /安置/安地/庵地/
あんちじょ /安置所/
あんちもん /Sb/Antimony/
あんちゃく /安着/
あんちゃん /兄ちゃん;[口]兄、または若者の呼称/
あんちゅう /暗中/闇中/
あんちゅうひやく /暗中飛躍/
あんちゅうもさく /暗中模索/
あんちょく /安直/
あんちん /安珍/
あんちんきよひめ /安珍清姫;道成寺/
あんてい /安定/安貞;年号(1227-1229)/
あんていか /安定化/
あんていかでんげん /安定化電源/
あんていかどう /安定稼働/
あんていかぶぬし /安定株主/
あんていかん /安定感/
あんていかんばつぐん /安定感抜群/
あんていき /安定期/
あんていきょうきゅう /安定供給/
あんていこうぞう /安定構造/
あんていざい /安定剤/
あんていじょうたい /安定状態/
あんていせい /安定性/
あんていせいじゅうし /安定性重視/
あんていせいそう /安定成層/
あんていせいちょう /安定成長/
あんていせいりろん /安定性理論/
あんていたすう /安定多数;[政治]議長等の議席を差し引いても過半数を取れる議席数/
あんていてき /安定的/
あんていてん /安定点/
あんていど /安定度/
あんていどういたい /安定同位体/
あんていどうさ /安定動作/
あんていばん /安定板;fin/
あんていひこう /安定飛行/
あんていりくかい /安定陸塊/
あんてん /暗転/鞍点/
あんてんほう /鞍点法/
あんでぱんだんてん /アンデパンダン展/
あんでるせんどうわ /アンデルセン童話/
あんでんりゅう /暗電流/
あんとう /安東/暗闘/
あんとく /安徳/
あんとくてんのう /安徳天皇/
あんど /安堵/∩/∧/
あんどう /安藤/安東/
あんどうしょうえき /安藤昌益/
あんどうでんき /安藤電気/
あんどうひろしげ /安藤広重/
あんどかん /安堵感/
あんどく /暗読/
あんどろめだざ /アンドロメダ座;Andromeda(And)/
あんどん /行灯/行燈/闇鈍/
あんな /杏奈/安和;年号(968-970)/
あんない /案内/
あんないかんばん /案内看板/
あんないがかり /案内係/
あんないきじ /案内記事/
あんないしゃ /案内者/
あんないしょ /案内書/
あんないじょ /案内所/
あんないじょう /案内状/
あんないず /案内図/
あんないそうち /案内装置/
あんないちず /案内地図/
あんないにん /案内人/
あんないばん /案内板/
あんないひょうしき /案内標識/
あんないひょうじ /案内表示/
あんないぶん /案内文/
あんないぶんしょ /案内文書/
あんないほうそう /案内放送/
あんないやく /案内役/
あんないよう /案内用/
あんなか /安中/
あんなかかん /安中間/
あんなん /安南;地名/
あんに /暗に/
あんにん /杏仁/
あんにんどうふ /杏仁豆腐/
あんねい /安寧/
あんねいちつじょ /安寧秩序/
あんねいてんのう /安寧天皇/
あんねん /安念/
あんの /庵野/安野/
あんのう /鞍嚢/
あんのじょう /案の定/
あんのん /安穏/
あんはんのう /暗反応/
あんば /鞍馬;体操の種目/
あんばい /塩梅;≒按配/按配/案配;=按配/按排;=按配/
あんばこ /暗箱;カメラの-/
あんぱち /安八/
あんぱん /餡パン/あんパン/
あんひつ /安謐/
あんぴ /安否/
あんぴかくにん /安否確認/
あんぶ /暗部;「社会の-」/鞍部;[地質学]col/
あんぶん /按分/案文;draft/案分;≒按分/
あんぷ /暗譜/
あんぼれらか /アンボレラ科/Amborellaceae/
あんぽ /安保/
あんぽう /罨法/
あんぽじょうやく /安保条約/
あんぽたいせい /安保体制/
あんぽとうそう /安保闘争/
あんぽもんだい /安保問題/
あんぽり /安保理/
あんぽりけつぎ /安保理決議/
あんぽりじかい /安保理事会/
あんぽんたん /安本丹/
あんま /按摩/
あんまく /暗幕/
あんまん /餡饅/
あんみつ /餡蜜/
あんみん /安眠/
あんめん /暗面/
あんもく /暗黙/
あんもくち /暗黙知/
あんもくてき /暗黙的/
あんもち /餡餅/
あんもにあすい /アンモニア水/
あんもん /案文/
あんや /暗夜/闇夜/
あんやく /暗躍/
あんやこうろ /暗夜行路/
あんゆ /暗喩;[修辞]metaphor/
あんゆてき /暗喩的/
あんらく /安楽/
あんらくいす /安楽椅子/
あんらくこく /安楽国;[仏教]極楽/
あんらくし /安楽死/
あんり /杏里/
あんりゅう /暗流/
あんりょくしょく /暗緑色/
あんろくざん /安禄山/
い /胃/意/異/医/位/井/伊/委/衣/居/射/威/亥;[十二支](12)いのしし/夷;夷狄/姨;おば/洟;はな/痍;満身創痍/維;維持/帷;かたびら/惟;思惟/唯;唯唯諾諾/韋;韋駄天/違;相違/偉;偉人/緯;緯度/幃;とばり/圍;「囲」の旧字/囲;周囲/慰;慰留/尉;少尉/熨;のし/蔚/萎;萎縮/痿/逶/矮;(呉音) 矮小(わいしょう)/謂;い・う/渭;渭水/椅;椅子/倚/猗/為;行為/爲;「為」の旧字(人名用漢字)/彙;語彙/彝/彜;「彝」の異体字/以/苡/詒/貽;貽貝/怡/遺;遺産/依;依存/易;安易/畏;畏怖/移;移動/堰;せき/莞/詑/胆/猪/鮪;まぐろ/揖/噫/已;已然形/恚;瞋恚/懿/矣;(助辞)/肄;(ならう)/頤;おとがい/饐;す・える/鰄;かいらぎ/醫;「医」の旧字/囗;(「口」(くち)とは別)/五/ゐ;→うぃ/如;如何/斐;甲斐/鋳;い・る?/鑄/忌;い・む?/偽;?/僞;「偽」の旧字(人名用漢字)/李;り?/
い> /異/伊;[略語]イタリア.-首相,-企業/居;(あ行・わ行上一段 未然・連用形)居座る,居回る,居隠る/
いーじすかん /イージス艦/
いーすと /ＥＡＳＴ/
いーすときん /イースト菌/
いーた /η;eta/Η;Eta/
いーふぁん /一翻/
いーめーる /Eメール/
いあ /依阿/
いあい /居合/居合い/遺愛/畏愛/
いあいごし /居合腰/
いあいどう /居合道/
いあいぬき /居合抜き/
いあく /帷幄/
いあくじょうそう /帷幄上奏/
いあつ /威圧/威壓/
いあつかん /威圧感/
いあつてき /威圧的/
いあん /慰安/
いあんかい /慰安会/
いあんじょ /慰安所/
いあんふ /慰安婦/
いあんりょこう /慰安旅行/
いい /飯/謂/猪/井伊/伊井/猪井/依依/依違/依倚/唯々/
いいあい /言い合い/
いいあらそい /言い争い/
いいうり /言売/
いいお /飯尾;姓/
いいおか /飯岡/
いいかえ /言い換え/
いいかお /好い顔;好い顔をしなかった/
いいかげん /いい加減/好い加減/
いいかた /言い方/
いいがかり /言い掛かり/言いがかり/言い掛り/
いいき /異域/いい気/好い気/
いいぎり /椅/
いいくら /飯倉/
いいくらかたまち /飯倉片町/
いいぐさ /言い草/言い種/
いいこ /いい子/
いいこと /いい事/
いいさか /飯坂/
いいざか /飯坂/
いいざかおんせん /飯坂温泉/
いいざま /言い様/
いいざわ /飯沢/
いいし /飯石/
いいじま /飯島/飯嶋/
いいじょう /言い条/
いいすぎ /言い過ぎ/
いいすて /言い捨て/
いいずか /飯塚;※仮名遣い「いいづか」/
いいたいほうだい /言いたい放題/
いいたか /飯高/
いいたがわ /飯田川/
いいたて /飯館/
いいだ /飯田/
いいだか /飯高/
いいだくだく /唯唯諾諾/唯々諾々/
いいだこ /飯蛸/
いいだし /飯田市/
いいだしっぺ /言い出しっぺ/
いいだせん /飯田線/
いいだばし /飯田橋/
いいだばしえき /飯田橋駅/
いいだばしほうめん /飯田橋方面/
いいつけ /言い付け/
いいつたえ /言い伝え/
いいづか /飯塚/
いいづかし /飯塚市/
いいづな /飯綱/
いいで /飯豊/
いいとし /好い年/いい年/いい歳/
いいなおすけ /井伊直弼;幕末の大老/
いいなが /稲永/
いいなずけ /許婚/許嫁/
いいなり /言い成り/言いなり/
いいなん /飯南/
いいぬま /飯沼/
いいね /言い値/
いいの /飯野/
いいのがれ /言い逃れ/
いいはま /飯浜/
いいはん /一翻/
いいぶん /言い分/
いいぼし /飯干/
いいま /飯間/
いいまちがい /言い間違い/
いいまわし /言い回し/言回し/
いいむら /飯村/
いいもり /飯盛/飯森/
いいもりやま /飯盛山/
いいや /否/
いいやま /飯山/
いいやまでんき /飯山電機;[企業名]/
いいよう /言い様;他にもっと-もあるだろう/
いいわけ /言い訳/言訳/
いいわたし /言い渡し/言渡し/
いいん /委員/医院/医員/伊尹/
いいんかい /委員会/
いいんかいあん /委員会案/
いいんかいかんり /委員会管理/
いいんかいぎちょう /委員会議長/
いいんかいこうにん /委員会公認/
いいんかいさくせい /委員会作成/
いいんかいせい /委員会制/
いいんかいせいど /委員会制度/
いいんかいせつりつ /委員会設立/
いいんかいぜんたい /委員会全体/
いいんかいそしき /委員会組織/
いいんかいたいせい /委員会体制/
いいんかいとうせっちがいしゃ /委員会等設置会社;NB:H14の改正商法特例法（2003.04施行）により採択可能となった企業統治の仕組/
いいんかいないぶ /委員会内部/
いいんかいほうしき /委員会方式/
いいんぜんたい /委員全体/
いいんちょう /委員長/
いいんちょうあて /委員長宛/
いいんどうし /委員同士/
いうこと /言う事/
いうち /井内/
いうなれば /言うなれば/
いうら /井浦/
いぇん /￥/円;Yen/
いえ /家/伊江/彌;「弥」の旧字/
いえい /遺影/家居/遺詠/
いえいえ /家々/
いえいがい /家以外/
いえがた /家型/
いえがまえ /家構え/
いえがら /家柄/
いえき /胃液/
いえしま /家島/
いえじ /家路/
いえじゅう /家中/
いえすじ /家筋/
いえずすかい /イエズス会;[キリスト教]Jesuit order/
いえせいど /家制度/
いえだ /家田/
いえつき /家付き/家付/
いえづくり /家造り/家作り/
いえで /家出/
いえでしょうじょ /家出少女/
いえでにん /家出人/
いえどころ /家所/
いえども /雖も/雖/
いえなが /家永/
いえなみ /家並み/家並/
いえねこ /家猫/
いえばと /家鳩/
いえみつ /家光/
いえもち /家茂/家持ち/
いえもと /家元/
いえやしき /家屋敷/
いえやす /家康/
いえやま /家山/
いえよう /家様/
いえらいしゃん /夜来香/
いえん /胃炎/以遠/
いえんけん /以遠権/
いお /魚/五百/
いおう /硫黄/S/Sulfur/
いおうしゅう /硫黄臭/
いおうじ /医王寺/
いおうじま /硫黄島/伊王島/
いおうせん /硫黄泉/
いおうとう /硫黄島/
いおえ /五百重/五百枝/
いおか /井岡/
いおた /ι;iota/Ι;Iota/
いおち /庵地/
いおにあしき /イオニア式;[建築]Ionian order. ギリシア建築の様式/
いおの /魚野/
いおのめ /魚の目/
いおはら /庵原;姓/
いおり /庵/菴/伊織/
いおりてん /庵点/
いおん /異音/倚音;[音楽]Vorschlag/遺恩/
いおんか /イオン化/
いおんかけいこう /イオン化傾向;[化学]ionisation tendency/
いおんけっしょう /イオン結晶;[化学]ionic crystal/
いおんけつごう /イオン結合/
いおんこうかん /イオン交換;[化学]/
いおんはんけい /イオン半径;[化学]ionic radius/
いおんびん /イ音便/
いか /以下/如何/医科/烏賊/異化/位下/医家/伊香/≦;<=/
いかい /異界/位階/猪飼/伊貝/
いかいくんとう /位階勲等/
いかいよう /胃潰瘍/胃かいよう/
いかいんよう /以下引用/
いかが /如何/
いかがく /医科学;medical sciences/医化学;medical chemistry/
いかく /威嚇/位格/居角/威赫/
いかくしゃげき /威嚇射撃/
いかくしょく /威嚇色/
いかくちょう /胃拡張/
いかけ /鋳掛け/鋳掛/
いかけや /鋳掛屋/鋳掛け屋/
いかけん /医科研/
いかさま /如何様/
いかさんしょう /以下参照/
いかざき /五十崎/
いかしか /医科歯科/
いかしょうりゃく /以下省略/
いかすい /胃下垂/
いかすみ /イカ墨/烏賊墨/いか墨/
いかずち /雷/霆/霹/
いかた /伊方/
いかたる /胃カタル;[医]gastric catarrh/
いかだ /筏/桴;=筏 NB:「ばち」とも読む/
いかだい /筏井/
いかだいがく /医科大学/
いかつ /威喝/
いかづち /雷/
いかてん /イカ天/
いかどうぶん /以下同文/
いかどうよう /以下同様/
いかな /如何な/
いかないよう /以下内容/
いかなご /玉筋魚/
いかなる /如何なる/
いかに /如何に/
いかにも /如何にも/
いかの /以下の/
いかのぼり /凧/
いかひ /異花被/
いかひか /異花被花/
いかほ /伊香保/
いかほおんせん /伊香保温泉/
いかほど /如何程/
いかほんぶん /以下本文/
いかむけ /医家向け/
いかめら /胃カメラ/
いかもの /如何物/
いかやき /烏賊焼き/イカ焼き/いか焼き/
いかよう /如何様/
いからし /五十嵐/
いかり /錨/碇;=錨/怒り/怒/
いかりがせき /碇ヶ関/
いかりがた /怒り肩/
いかりしんとう /怒り心頭/
いかりそう /碇草/
いかりど /錨戸/
いかりゃく /以下略/
いかる /斑鳩/鵤/
いかるが /斑鳩/
いかるがのみや /斑鳩宮/
いかわ /井川/居川/井河/
いかわだに /伊川谷/
いかん /如何/移管/遺憾/衣冠/医官/尉官/偉観/異観/
いかんそく /維管束/
いかんそくたい /衣冠束帯/
いかんとも /如何とも;-し難い/
いかんなく /遺憾無く/
いが /伊賀/毬/
いがい /以外;†except.「それ-」/意外;†unexpected.「-な展開」/遺骸/貽貝/
いがいせい /意外性/
いがうえ /伊賀上/
いがうえの /伊賀上野;地名/
いがき /斎垣/
いがく /医学/
いがくか /医学科/
いがくかい /医学界/
いがくかんけい /医学関係/
いがくかんけいしゃ /医学関係者/
いがくかんれん /医学関連/
いがくけい /医学系/
いがくけんきゅう /医学研究/
いがくけんきゅうか /医学研究科/
いがくけんきゅうしゃ /医学研究者/
いがくざっし /医学雑誌/
いがくし /医学史/
いがくしゃ /医学者/
いがくしょ /医学書/
いがくしょいん /医学書院;[出版社名]www.igaku-shoin.co.jp/
いがくじしょ /医学辞書/
いがくじてん /医学事典/
いがくじょう /医学上/
いがくせい /医学生/
いがくそうだん /医学相談/
いがくてき /医学的/
いがくてきけんきゅう /医学的研究/
いがくてきこうさつ /医学的考察/
いがくてきじょうほう /医学的情報/
いがくてきちしき /医学的知識/
いがくてきもんだい /医学的問題/
いがくはかせ /医学博士/
いがくはくし /医学博士/
いがくぶ /医学部/
いがくぶせい /医学部生/
いがくようご /医学用語/
いがぐり /毬栗/
いがぐりあたま /毬栗頭/いがぐり頭/
いがこうべ /伊賀神戸/
いがさてつどう /井笠鉄道/
いがしら /井頭/
いがせん /伊賀線/
いがた /鋳型/井形/鎔/范/
いがっか /医学科/
いがみ /井上/
いがみあい /啀み合い/
いがや /井ヶ谷/
いがやき /伊賀焼/
いがらし /五十嵐/
いがり /猪狩/
いがりゅう /伊賀流;忍者/
いがわ /井川/居川/
いがん /胃癌/依願/胃がん/胃ガン/
いがんたいしょく /依願退職/
いがんめんしょく /依願免職/
いき /息/粋/域/閾;threshold/意気/遺棄/壱岐;地名,長崎/行/行き/生き/位記/囲気/委棄;[法]所有権の放棄/生/粹;「粋」の旧字(人名用漢字)/
いき> /活/
いきあたり /行き当たり;-ばったり/行き当り/
いきあたりばったり /行き当たりばったり/
いきいき /生き生き/活き活き/
いきうお /活き魚/
いきうつし /生き写し/
いきうま /生き馬/
いきうめ /生き埋め/生埋め/
いきえ /生き餌/
いきおい /勢い/
いきか /閾下/
いきかえり /行き帰り;-の電車/
いきかた /生き方;†lifestyle/行き方;†way/
いきかん /異機間/
いきがい /域外/生き甲斐/生きがい/
いきがかり /行き掛かり;-でやむを得なかった/行き掛り/
いきがけ /行き掛け/
いきがみ /生き神/
いきき /行き来/往き来/一箕/
いきぎも /生き肝/生き胆/
いきぎれ /息切れ/
いきくち /生き口/
いきけんこう /意気軒昂/
いきごみ /意気込み/意気ごみ/
いきさき /行き先/行先/
いきさきあんない /行先案内/
いきさきひょうじ /行先表示/
いきさつ /経緯/
いきさわ /生澤/
いきざい /遺棄罪/
いきざかな /生き魚/
いきざま /生き様/
いきしな /行きしな/
いきしに /生き死に/
いきしゅ /異機種/
いきしゅかん /異機種間/
いきしょうちん /意気消沈/
いきしょうてん /意気衝天/
いきしょうにん /生き証人/
いきじごく /生き地獄/
いきじびき /生き字引/
いきす /伊岐須/
いきすぎ /行き過ぎ/行過ぎ/
いきすじ /粋筋/
いきそそう /意気阻喪;がっくし/意気沮喪;=意気阻喪/
いきたい /生き体;[相撲]⇔死に体/
いきだおれ /行き倒れ/
いきち /閾値/生き血/生血/域値/
いきちがい /行き違い/
いきちしょり /閾値処理/
いきつき /生月/
いきつぎ /息継ぎ/
いきつけ /行き付け/
いきづかい /息遣い/息づかい/
いきづまり /行き詰まり/
いきとうごう /意気投合/
いきどおり /憤り/
いきどまり /行き止まり/
いきな /生名/
いきない /域内/
いきなり /行き成り/行成り/
いきにんぎょう /生き人形/
いきぬき /息抜き/息抜/
いきのこり /生き残り/
いきのした /息の下/
いきのね /息の根/
いきのまつばら /生の松原/
いきはじ /生き恥/
いきば /行き場/行場/
いきびん /生きビン/
いきぼとけ /生き仏/
いきみ /生き身/
いきもの /生き物/生物/
いきやすめ /息休め/
いきょ /依拠/
いきょう /異教;pagan/異郷;foreign sky/異境;≒異郷/異香;素晴らしい香り/井京/
いきょうと /異教徒/
いきょく /医局/委曲;details.「-を尽くす」/異曲;同工-/
いきようよう /意気揚々/意気揚揚/
いきりょう /生霊/生き霊/
いきわかれ /生き別れ/
いぎ /意義;†meaning.「有-」/異議;†objection.「-を唱える」/異義;†別義。「同音-」/威儀;重々しい挙動/猪木/
いぎあり /異議有り/
いぎご /異義語/
いぎす /伊岐須/
いぎそ /意義素;sememe,semanteme/
いぎなし /異議なし/
いぎもうしたて /異議申し立て/異議申立て/異議申立/
いぎょう /偉業/異形/医業/遺業/易行/イ行/い行/
いぎょうしゅ /異業種/
いぎょうどう /易行道/
いぎりす /英吉利;Inglez/
いぎりすぐん /イギリス軍/
いぎりすせい /イギリス製/
いぎりすぶんがく /イギリス文学/
いく /育/幾/畏懼/郁;馥郁/燠;おき/礇/鬻;ひさ・ぐ/粥;かゆ/毓;「育」の異体字/生/
いく> /幾;幾度,幾尾,幾秒/
いくい /生井/
いくいな /生稲/
いくうかん /異空間/
いくえ /幾重/郁恵/育江/
いくえい /育英/
いくえいかい /育英会/
いくえいしょうがくきん /育英奨学金/
いくお /郁夫/郁雄/育男/郁生/幾雄/幾夫/
いくきゅう /育休/
いくこ /郁子/育子/幾久子/以玖子/郁久子/
いくさ /戦/軍/戰;「戦」の旧字(人名用漢字)/
いくさ> /軍;複合時はほとんどがこの字。「軍場,軍船,軍ごっこ」/
いくさか /生坂/
いくさがみ /軍神/
いくさき /行く先/
いくさち /生幸/
いくさば /軍場/
いくさひょうじょう /軍評定/
いくさびと /軍人/
いくさぶぎょう /軍奉行/
いくさぶね /軍船/
いくさぼし /軍星;北斗七星/
いくさものがたり /軍物語/
いくしま /生島/
いくしゅ /育種/
いくしゅがく /育種学/
いくしゅるい /幾種類/
いくじ /育児/意気地/
いくじかいごきゅうぎょうほう /育児介護休業法/
いくじきゅうか /育児休暇/
いくじきゅうぎょう /育児休業/
いくじきゅうぎょうきゅうふ /育児休業給付/
いくじきゅうぎょうほう /育児休業法/
いくじきゅうしょくせいど /育児休職制度/
いくじけいけん /育児経験/
いくじけいけんしゃ /育児経験者/
いくじしょ /育児書/育児所/
いくじせいど /育児制度/
いくじそうだん /育児相談/
いくじなし /意気地無し/意気地なし/
いくじのう /育児嚢/
いくじひ /育児費/
いくじぶんたん /育児分担/
いくじほうき /育児放棄/
いくすう /育雛/
いくすじ /幾筋/
いくせい /育成/
いくせいしつ /育成室;学童保育を行う施設の名称/
いくせいしゃ /育成者/
いくせいしょ /育成所/
いくせいじぎょう /育成事業/
いくせいそう /幾星霜/
いくせいぶ /育成部/
いくせいぼくじょう /育成牧場/
いくせん /幾千/
いくせんまん /幾千万/
いくそ /幾十/
いくそう /幾層/
いくぞう /郁三/幾三/
いくた /幾多/生田/
いくたがわ /生田川/
いくたさい /生田祭/
いくたじんじゃ /生田神社/
いくたはら /生田原/
いくたび /幾度/
いくたま /生玉/
いくたり /幾人/
いくたりゅう /生田流;箏曲/
いくつ /幾つ/
いくつか /幾つか/
いくつき /幾月/
いくとしつき /幾年月/
いくとせ /幾年/
いくど /幾度/
いくどうおん /異口同音/
いくにち /幾日/
いくにん /幾人/
いくねん /幾年/
いくの /生野/
いくのとうげ /生野峠/
いくは /的/
いくはら /幾原/
いくばく /幾許/幾何/
いくひと /生人/
いくひろ /郁博/
いくび /猪首/
いくびょう /育苗/
いくびょうばこ /育苗箱/
いくぶん /幾分/いく分/
いくほど /幾程/
いくま /伊玖磨/
いくまん /幾万/
いくみ /育巳/
いくもう /育毛/
いくもうざい /育毛剤/
いくや /郁哉/育也/
いくゆう /育友/
いくゆうかい /育友会/
いくゆうかいかつどう /育友会活動/
いくよ /幾世/幾代/幾夜/郁代;人名/育代/
いくら /幾ら/伊倉/居倉/
いくらか /幾らか/
いくらどん /イクラ丼/
いくらなんでも /幾ら何でも/
いくりん /育林/
いくん /遺訓;「先代の-」/異訓;eg.「擦る」(する・こする)/
いぐ /伊具/
いぐさ /藺草/井草/伊草/
いぐさもく /イグサ目/Juncales/
いぐすり /胃薬/
いぐち /井口/
いぐるみ /弋/弑/
いぐん /威軍/
いけ /池/
いけい /畏敬/異形/異型/医系/
いけいさいぼう /異形細胞/
いけいざい /違警罪/
いけいしき /異形式/
いけいたい /異形態/
いけいちょう /衣掛町/
いけいのねん /畏敬の念/
いけいよう /異形葉/
いけいれん /胃痙攣/
いけうお /活魚/生け魚/活け魚/
いけうち /池内/
いけうら /池浦/
いけえ /池江/
いけお /池尾/
いけがき /生垣/生け垣/
いけがみ /池上/
いけがみきみこ /池上季実子/
いけがみせん /池上線/
いけがみつうしんき /池上通信機/
いけがめ /池亀/
いけがや /池谷/池ケ谷/
いけがわ /池川/
いけごえ /池越え/
いけさか /池坂/
いけざわ /池澤/池沢/生澤/
いけした /池下/
いけしょうじ /池庄司/
いけじり /池尻/
いけじりおおはし /池尻大橋/
いけす /生け簀/生簀/
いけずみ /活け炭/埋け炭;灰の中に埋め込んだ炭火/
いけた /井桁/
いけたに /池谷/
いけだ /池田/
いけだこうこう /池田高校/
いけだし /池田市/
いけだちょう /池田町/
いけだやじけん /池田屋事件;[日本史](1864)/
いけだりよこ /池田理代子/
いけつき /池月/
いけつつみ /池堤/
いけづくり /活け造り/活け作り/生け作り/生け造り/
いけど /池戸/
いけどり /生け捕り/
いけなが /池永/
いけなみ /池波/
いけにえ /生贄/生け贄/犠牲/犠/牲/犧;旧字/
いけの /池野/池乃/
いけのうえ /池ノ上/
いけのはた /池の端/
いけのぼう /池坊/池の坊/
いけはぎ /生剥/
いけはら /池原/
いけばな /生け花/活け花/挿花/活花/生花/
いけび /埋け火;=うずみび/
いけぶくろ /池袋/
いけぶくろえき /池袋駅/
いけぶくろえきひがしぐち /池袋駅東口/
いけぶくろかん /池袋間/
いけぶくろぐち /池袋口/
いけぶくろせいぶ /池袋西武/
いけぶくろせん /池袋線/
いけぶくろせんえんせん /池袋線沿線/
いけぶくろてん /池袋店/
いけぶくろとうぶ /池袋東武/
いけぶくろにしぐち /池袋西口/
いけべ /池辺/
いけぽちゃ /池ポチャ/
いけみず /池水/
いけみや /池宮/
いけもと /池本/
いけもり /池森;姓/
いけや /池谷/
いけやま /池山/
いけわき /池脇;姓/
いけん /意見/違憲/異見;異存・忠告/遺賢/威権/
いけんこうい /違憲行為/
いけんこうかん /意見交換/
いけんこうかんちゅう /意見交換中/
いけんこうこく /意見広告/
いけんしょ /意見書/
いけんせい /違憲性/
いけんなど /意見等/
いけんはんけつ /違憲判決/
いけんばこ /意見箱/
いけんばん /意見番/
いけんひょうめい /意見表明/
いけんようぼう /意見要望/
いけんらん /意見欄/
いけんりっぽうしんさ /違憲立法審査/
いけんりっぽうしんさけん /違憲立法審査権/
いげた /井桁/
いげん /威厳/異言/遺言/威嚴;「厳」旧字/
いげんご /異言語/
いげんびょう /医原病/
いこ /依怙/遺孤/
いこーる /＝;equal/≒/≠/
いこい /憩い/憩/
いこう /以降/移行/意向/遺構/遺稿/威光/移項/衣桁/偉功/異香/偉効/胃腔/維綱/
いこうあん /移行案/
いこうき /移行期/
いこうきかん /移行期間/
いこうきかんちゅう /移行期間中/
いこうご /移行後/
いこうさき /移行先/
いこうさぎょう /移行作業/
いこうじ /移行時/
いこうずみ /移行済/
いこうせい /移行性/
いこうそち /移行措置/
いこうそちきかん /移行措置期間/
いこうぞう /異構造/
いこうだんかい /移行段階/
いこうちゅう /移行中/
いこうちょうさ /意向調査/
いこく /異国/
いこくしゅみ /異国趣味/
いこくじょうちょ /異国情緒/
いこくじん /異国人/
いこくてき /異国的/
いこじ /意固地/依怙地/
いこつ /遺骨/
いこつちょうさ /遺骨調査/
いこま /生駒/居駒/
いこまこうさくせん /生駒鋼索線/
いこまし /生駒市/
いこまやま /生駒山/
いこみ /鋳込み/
いこみき /已己巳己/
いこん /遺恨/意根/
いこんじあい /遺恨試合/
いこんたいけつ /遺恨対決/
いご /以後/囲碁/伊語/
いごう /伊号/意業;[仏教]/
いごきし /囲碁棋士/
いごきょうかい /囲碁協会/
いごこうざ /囲碁講座/
いごこち /居心地/
いごころ /居心/
いごしょうぎぶ /囲碁将棋部/
いごたいかい /囲碁大会/
いごん /遺言/
いごんしょうしょ /遺言証書/
いさ /異差/伊佐/諌;「諫」の異体字/
いさい /委細/異才/異彩;-を放つ/偉才/
いさお /勲/功/勇夫/勲男/勳;「勲」の旧字(人名用漢字)/烈/勇雄/
いさおし /勲/功/
いさか /井坂/伊坂/
いさかい /諍い/諍/
いさき /伊佐木/鶏魚/
いさく /遺作/
いさこ /いさ子/
いさご /砂金/砂子/沙/砂/
いささか /聊か/些か/
いさつ /縊殺/
いさな /勇魚/鯨魚/細小魚/小魚/
いさはや /諫早;地名/諌早;「諫」異体字/
いさはやわん /諫早湾/
いさはら /井佐原/
いさみ /勇/
いさみあし /勇み足/勇足/
いさみはだ /勇み肌/
いさむ /勇/勲/勳;「勲」の旧字(人名用漢字)/
いさやま /諌山/伊佐山/
いさり /漁/
いさりび /漁火/
いさわ /石和/井沢/伊沢/井澤/伊澤/
いさわおんせん /石和温泉/
いさん /遺産/胃酸/胃散/違算/
いさんかた /胃酸過多/
いさんかたしょう /胃酸過多症;[医]/
いさんぜい /遺産税/
いさんそうぞく /遺産相続/
いさんそうぞくけん /遺産相続権/
いさんそうぞくにん /遺産相続人/
いさんどうき /遺産動機/
いさんぶんかつ /遺産分割/
いざい /異材/偉材/
いざかや /居酒屋/
いざき /井崎/伊崎/
いざけ /居酒/
いざなぎ /伊邪那岐/伊弉諾/
いざなぎけいき /伊弉諾景気/
いざなぎのみこと /伊邪那岐命/伊弉諾尊/
いざなみ /伊邪那美/伊弉冉/
いざやしょ /イザヤ書;[聖書]Isaiah(Is,Isa)/
いざよい /十六夜/
いざよいにっき /十六夜日記/
いざよいのつき /十六夜の月;陰暦一六日の月/
いざり /躄/
いざりうお /躄魚/
いざわ /井沢/伊沢/伊澤/
いし /石/医師/意思;†purpose. 思っていること。「-表示」/意志;†will. 決意したこと・する能力。「-が弱い」/遺志;†「亡父の-」/縊死/遺址;relics/遺子;orphan/頤使;人をアゴで使う/頤指;=頤使/遺思;?/
いしあたま /石頭/
いしい /石井/
いしいも /石芋/
いしうす /石臼/
いしうち /石打/
いしうちやま /石打山/
いしおか /石岡/
いしおざん /石尾山/
いしかい /医師会/
いしかべ /石壁/
いしかめ /石亀/
いしかり /石狩/
いしかりがわ /石狩川/
いしかりし /石狩市/
いしかりちょう /石狩町/
いしかりなべ /石狩鍋/
いしかりぬまた /石狩沼田/
いしかわ /石川/石河/
いしかわえき /石川駅/
いしかわけん /石川県/
いしかわけんない /石川県内/
いしかわこうせん /石川高専/
いしかわごえもん /石川五右衛門/
いしかわじま /石川島/
いしかわじまはりま /石川島播磨/
いしかわじゅん /石川淳/
いしかわせん /石川線/
いしかわたくぼく /石川啄木/
いしかわだい /石川台/
いしかわちょう /石川町/
いしかわちょうえき /石川町駅/
いしがき /石垣/
いしがきくうこう /石垣空港/
いしがきし /石垣市/
いしがきじま /石垣島/
いしがに /石蟹/
いしがね /石金/
いしがま /石窯;(炭焼き用)/石釜;(製塩用)/石鎌;(弥生時代の石器)/
いしがみ /石神/石上/
いしがめ /石亀/
いしがわら /石瓦/
いしき /意識/伊敷/臀/
いしきか /意識下;†subconscious.「-の願望」/意識化;†awaken.「問題の-」/
いしきかいかく /意識改革/
いしきかてい /意識過程/
いしきしょうがい /意識障害/
いしきじょう /意識上/
いしきちょうさ /意識調査/
いしきてき /意識的/
いしきのながれ /意識の流れ;[文学]stream of consciousness/
いしきふめい /意識不明/
いしきりば /石切場/石切り場/
いしきれべる /意識レベル/
いしく /石工/
いしくに /石國/
いしくら /石倉/
いしくれ /石塊/
いしぐみ /石組み/石組/
いしぐろ /石黒/
いしぐろけん /石黒賢/
いしけってい /意思決定/意志決定/
いしけっていかてい /意思決定過程/意志決定過程/
いしけっていきかん /意思決定機関/
いしけっていしゃ /意思決定者/
いしけっていほうしき /意思決定方式/
いしけっていほうほう /意思決定方法/意志決定方法/
いしけり /石蹴り/
いしげ /石毛/石下/
いしこ /石子/
いしこし /石越/
いしこしえき /石越駅/
いしこじん /医師個人/
いしこっかしけん /医師国家試験/
いしころ /石塊/石ころ/
いしごう /石郷/
いしごおり /石氷/
いしざか /石坂/
いしざかせん /石坂線/
いしざき /石崎/
いしざきがわ /石崎川/
いしざら /石皿/
いしざわ /石澤/石沢/
いししかく /医師資格/
いしした /石下/
いししゅぎ /意思主義/
いししょう /異嗜症;[精医]異食症/
いしじ /石地/
いしじま /石島/石嶋/
いしず /石津/
いしずえ /礎/
いしずか /石塚;※仮名遣い「いしづか」/
いしずけ /石附;※仮名遣い「いしづけ」?/
いしずみ /石炭/
いしそつう /意思疎通/
いしそね /石曽根/
いしぞね /石曽根/
いしだ /石田/
いしだい /石鯛/
いしだか /石高/
いしだかみち /石高道/
いしだたみ /石畳/甃;NB:「しきがわら」とも訓む/
いしだみつなり /石田三成/
いしだりゅう /石田流/
いしだん /石段/
いしつ /異質/遺失/
いしつか /石塚/
いしつせい /異質性/
いしつぶつ /遺失物/
いしつぶて /石礫/石つぶて/
いしつみ /石積み/
いしづ /石津/
いしづえ /礎/
いしづか /石塚/
いしづき /鐓/石突き/石突/
いしづくり /石造り/石作り/
いしづけ /石附/
いしづみ /石積み;mansory/
いしてき /意志的/
いしでら /石寺/
いしでんたつ /意思伝達/
いしとうろう /石燈篭/
いしとび /石飛/
いしどう /石堂/
いしどうろう /石灯籠/
いしどこ /石床/
いしどりや /石鳥谷/
いしなぎ /石投;魚名/
いしなげ /石投げ/
いしなべ /石鍋/
いしぬき /石貫/
いしの /石野/
いしのうりょく /意思能力/
いしのまき /石巻/
いしのまきえき /石巻駅/
いしのまきし /石巻市/
いしのまきせん /石巻線/
いしのみ /石鑿/
いしのもり /石之森/
いしはくじゃく /意志薄弱/
いしはた /石畑/
いしはま /石浜/
いしはら /石原/
いしはらかんじ /石原莞爾/
いしはらさんぎょう /石原産業;[企業名]/
いしはらしんたろう /石原慎太郎/
いしはらゆうじろう /石原裕次郎/
いしはり /石播/
いしば /石場/
いしばい /石灰/
いしばし /石橋/
いしばしえき /石橋駅/
いしばしかん /石橋間/
いしばち /石鉢/
いしばり /石張り/
いしひょうじ /意思表示/意志表示;?/
いしひょうめい /意思表明/意志表明;?/
いしびつ /石櫃/
いしぶし /石伏/
いしぶみ /碑/石文/
いしへん /石偏/
いしべ /石部/石辺/
いしべい /石塀/
いしべきんきち /石部金吉/
いしほう /医師法/
いしほういはん /医師法違反/
いしぼとけ /石仏/
いしま /石間/
いしまき /石巻/
いしまつ /石松/
いしまつえき /石松駅/
いしまる /石丸/
いしまるでんき /石丸電気/
いしみ /石見/
いしみち /石道/
いしみつ /石光/
いしみね /石嶺/
いしむら /石村/
いしむれ /石牟礼/
いしむろ /石室/
いしめ /石目/
いしめんきょ /医師免許/
いしもた /石母田/
いしもだ /石母田/
いしもち /石持/石首魚/
いしもと /石本/石元/
いしもり /石森/
いしもりしょうたろう /石森章太郎/
いしゃ /医者/慰謝;NB:「慰藉」の常用漢字での書き換え/慰藉;慰め労る/
いしゃやく /医者役/
いしゃりょう /慰謝料;NB:「慰藉料」の常用漢字での書き換え/慰藉料/
いしや /石屋/
いしやかわしゃこ /石屋川車庫/
いしやがわ /石屋川/
いしやき /石焼/石焼き/
いしやきいも /石焼き芋/石焼芋/
いしやま /石山/
いしやまさかもとせん /石山坂本線/
いしやまざか /石山坂/
いしやまでら /石山寺/
いしゅ /異種;variant/異株;雌雄-/意趣;-返し/遺珠;滄海の-/縊首/
いしゅう /異臭/蝟集/遺習/伊州;伊賀/
いしゅうち /意趣討ち/
いしゅかくとうぎ /異種格闘技/
いしゅかくとうぎせん /異種格闘技戦/
いしゅかんきょう /異種環境/
いしゅがえし /意趣返し/
いしゅぎり /意趣斬り/
いしゅく /萎縮/畏縮;畏れ縮こまる/蝟縮;ハリネズミ(蝟)のように畏縮する/委縮;?/
いしゅくしょう /萎縮症/
いしゅくびょう /萎縮病;[植物]/
いしゅこうはい /異種交配;[生物]crossbreed/
いしゅせい /異種性/
いしゅせいめいたい /異種生命体/
いしゅぞく /異種族/
いしゅつ /移出/
いしゅばらし /意趣晴らし/
いしゆみ /弩/石弓;crossbow/
いしょ /遺書/医書/異書/移書/緯書/
いしょう /衣装/衣裳;≒衣装 (原義は「上衣と裳裾」)/意匠/異称/囲障/遺詔/
いしょうがえ /衣装替/
いしょうけーす /衣装ケース/
いしょうけん /意匠権/
いしょうせい /意匠性/
いしょうだな /衣装棚/
いしょうだんす /衣装箪笥/
いしょうてき /意匠的/
いしょうとうろく /意匠登録/
いしょうほう /意匠法/
いしょく /移植/委嘱/異色/衣食/異食;pica/依嘱;頼りにする/
いしょくごて /移植鏝/移植ごて/
いしょくさぎょう /移植作業/
いしょくさく /異色作/移植作/
いしょくしゃ /移植者/
いしょくしゅじゅつ /移植手術/
いしょくしょう /異食症/
いしょくじゅう /衣食住/
いしょくじゅつ /移植術/
いしょくじょう /委嘱状/移植上/
いしょくじょうほう /移植情報/
いしょくすう /移植数/
いしょくせい /移植性/
いしょくたんぺんしゅう /異色短編集/
いしょくちゅう /移植中/
いしょくど /移植度/
いしょくどうげん /医食同源/
いしょくばん /移植版/
いしょくぶつ /移植物/
いしりょく /意志力/
いしわおんせん /石和温泉;※いさわおんせん?/
いしわた /石綿;asbestos/石渡;人名/
いしわたり /石渡/
いしわら /石原/
いしわり /石割/石割り/
いしん /維新/威信/以深/遺臣/異心/
いしんぐんだん /維新軍団/
いしんご /維新後/
いしんでんしん /以心伝心/
いしんは /維新派/
いしんりき /維新力/
いじ /維持/意地/医事/遺児;orphan/異字;-同訓/位次;rank/異時;another time/遺事;先代の-/異事;emergency/医治/依次/意字;⇔音字/依恃;depend/
いじかんり /維持管理/
いじげん /異次元/
いじげんくうかん /異次元空間/
いじたい /異字体/
いじち /伊地知/
いじっぱり /意地っ張り/
いじどうくん /異字同訓;eg.「取る」「録る」「撮る」/
いじひ /維持費/
いじひよう /維持費用/
いじめ /苛め/
いじめっこ /苛めっ子/いじめっ子/
いじめられっこ /苛められっ子/いじめられっ子/
いじゃく /胃弱/
いじゅう /移住/
いじゅういん /伊集院/
いじゅうけん /居住権/
いじゅうしゃ /移住者/
いじゅつ /医術/
いじょう /以上/異常;†abnormal.「-事態」/異状;†unusual.『西部戦線-なし』/移譲;†ゆずりわたす。「土地の-」/委譲;†ゆずり、ゆだねる。「権限の-」/移乗/囲繞/≧;>=/
いじょう> /異常;-事態,-値/
いじょういでんし /異常遺伝子/
いじょうおん /異常音/
いじょうかしょ /異常箇所/
いじょうきしょう /異常気象/
いじょうけい /異常系/
いじょうけんしゅつ /異常検出/
いじょうげんしょう /異常現象/
いじょうこうどう /異常行動/
いじょうしゃ /異常者/
いじょうしゅうりょう /異常終了/
いじょうしょくよく /異常食欲/
いじょうしんどう /異常振動/
いじょうしんりがく /異常心理学;abnormal psychology/
いじょうじ /異常時/
いじょうじたい /異常事態/
いじょうじょうたい /異常状態/
いじょうじんかく /異常人格/
いじょうせい /異常性/
いじょうせいかく /異常性格/
いじょうせいよく /異常性欲/
いじょうそうこう /異常走行/
いじょうぞうしょく /異常増殖/
いじょうち /異常値/
いじょうつうち /異常通知/
いじょうど /異常度/
いじょうどうさ /異常動作/
いじょうにんき /異常人気/
いじょうにんしん /異常妊娠/
いじょうねんしょう /異常燃焼/
いじょうはっせい /異常発生/
いじょうはんざい /異常犯罪/
いじょうはんしょく /異常繁殖/
いじょうふ /偉丈夫/
いじょうぶんさん /異常分散/
いじょうぶんべん /異常分娩/
いじょうぷりおん /異常プリオン/
いじょく /居職/
いじら /伊自良/
いじり /井尻/
いじるし /井印/
いじわる /意地悪/
いじん /偉人;hero/異人;foreigner/
いじんかん /異人館/
いじんしゅ /異人種/
いじんでん /偉人伝/
いす /椅子/倚子;=椅子/柞;[植物]イスノキ/
いすい /渭水/
いすう /位数/異数/
いすか /交喙/
いすがた /椅子型/
いすけ /伊介/
いすこうげき /椅子攻撃/
いすず /いすゞ/
いすずがわ /五十鈴川/
いすずじどうしゃ /いすゞ自動車;[企業名]/
いすせき /椅子席/
いすとりげーむ /椅子取りゲーム/
いすのき /柞/
いすばい /柞灰/
いすみ /夷隅/伊角;姓/
いすみぐんし /夷隅郡市/
いすみまち /夷隅町/
いすらえるぐん /イスラエル軍/
いすらむきょう /イスラム教/
いすらむきょうこく /イスラム教国/
いすらむきょうと /イスラム教徒/
いすらむけん /イスラム圏/
いすらむぶんか /イスラム文化/
いすらむほう /イスラム法/
いすらむれき /イスラム暦/
いず /伊豆/伊津/
いずい /泉井/
いずかいようこうえん /伊豆海洋公園/
いずかた /何方/
いずきゅう /伊豆急/
いずきゅうこう /伊豆急行/
いずきゅうしもだ /伊豆急下田/
いずくんぞ /焉/焉んぞ/
いずこ /何処/
いずこうげん /伊豆高原/
いずし /出石/
いずしま /出島/
いずしやき /出石焼/
いずしょとう /伊豆諸島/
いずた /泉田/
いずち /何方/
いずちほう /伊豆地方/
いずつ /井筒;※仮名遣い「いづつ」/
いずながおか /伊豆長岡/
いずながおかちょう /伊豆長岡町/
いずにった /伊豆仁田/
いずぬま /伊豆沼/
いずはこね /伊豆箱根/
いずはこねてつどう /伊豆箱根鉄道/
いずはら /厳原/
いずはんとう /伊豆半島/
いずほうめん /伊豆方面/
いずまい /居ずまい/居住まい;-を正す/居住い/
いずみ /泉/和泉;地名,大阪/出水;地名,鹿児島/湶;「泉」の異体字/五住;人名/偉津美/
いずみおおつ /泉大津/
いずみかわ /泉川/
いずみがおか /泉ヶ丘/
いずみがたけ /泉ヶ岳/
いずみがわ /泉川/
いずみきょうか /泉鏡花/
いずみく /泉区/
いずみごう /泉郷/
いずみさき /泉崎/
いずみさの /泉佐野/
いずみしきぶ /和泉式部/
いずみたに /泉谷/
いずみたまがわ /和泉多摩川/
いずみだ /泉田/
いずみちゅうおう /泉中央/
いずみどの /泉殿/
いずみや /泉谷/
いずみやま /泉山/
いずみりゅう /和泉流;狂言方/
いずも /出雲/
いずもざき /出雲崎/
いずもし /出雲市/
いずもしんわ /出雲神話/
いずもたいしゃ /出雲大社/
いずもたいしゃまえ /出雲大社前/
いずものおくに /出雲阿国/
いずものくに /出雲国/
いずもべん /出雲弁/
いずれ /何れ/孰れ;-判るだろう/
いずれか /何れか/
いせ /伊勢/
いせい /異性/威勢/以西/異星/為政/遺制/遺精/
いせいあい /異性愛;⇔同性愛/
いせいあいしゃ /異性愛者/
いせいか /異性化/
いせいかこうそ /異性化酵素/
いせいかんけい /異性関係/
いせいけん /遺生研/
いせいこうゆう /異性交友/
いせいしゃ /為政者/
いせいじん /異星人/
いせいたい /異性体/
いせいぶつ /異生物/
いせえび /伊勢海老/伊勢エビ/
いせおきつ /伊勢奥津/
いせかい /異世界/
いせかいどう /伊勢街道/
いせき /遺跡/移籍/井関/遺蹟;=遺跡/偉績/
いせききんがく /移籍金額/
いせきぐみ /移籍組/
いせきけってい /移籍決定/
いせきご /移籍後/
いせきさき /移籍先/
いせきせつ /移籍説/
いせきちょうさ /遺跡調査/
いせきのうき /井関農機/
いせきはっくつ /遺跡発掘/
いせきばなし /移籍話/
いせきもんだい /移籍問題/
いせきりょう /移籍料/
いせさき /伊勢崎/伊勢左木/
いせざき /伊勢崎/伊勢佐木/
いせざきせん /伊勢崎線/
いせざきちょう /伊勢崎町/
いせしま /伊勢志摩/
いせじ /伊勢路/
いせじどうしゃどう /伊勢自動車道/
いせじんぐう /伊勢神宮/
いせせん /伊勢線/
いせたん /伊勢丹/
いせだ /伊勢田/
いせちょう /伊勢町/
いせつ /移設/異説/
いせつこうじ /移設工事/
いせつご /移設後/
いせてつどう /伊勢鉄道/
いせなかがわ /伊勢中川/
いせのたゆう /伊勢大輔;いにしへの 奈良の都の 八重桜 けふ九重に にほひぬるかな/
いせはら /伊勢原/
いせはらし /伊勢原市/
いせはらしみん /伊勢原市民/
いせほうめん /伊勢方面/
いせまいり /伊勢参り/
いせもと /伊勢本/
いせものがたり /伊勢物語/
いせや /伊勢屋/
いせり /井芹/
いせわん /伊勢湾/
いせわんたいふう /伊勢湾台風/
いせん /緯線/伊仙/以浅/胃腺/
いせんこう /胃穿孔/
いせんじょう /胃洗浄/
いぜき /井関/
いぜな /伊是名/
いぜん /以前/依然;still.「-として」/已然;⇔未然/
いぜんけい /已然形/
いぜんとうこう /以前投稿/
いぜんほうそう /以前放送/
いぜんもんだい /以前問題/
いぜんわだい /以前話題/
いそ /磯/五十/
いそう /移送/位相;phase/異相;hetero-phase/移相;phase shift/意想/遺草/
いそうお /磯魚/
いそうかいせき /位相解析/
いそうかく /位相角/
いそうかんけい /位相関係/
いそうがい /意想外/
いそうがく /位相学/
いそうき /移相器/
いそうきかがく /位相幾何学;トポロジーのことを日本語では位相幾何学という/
いそうくうかん /位相空間/
いそうくうかんろん /位相空間論/
いそうご /位相語/
いそうさ /位相差/
いそうさき /移送先/
いそうさけんびきょう /位相差顕微鏡;phase-contrast microscope/
いそうじょうほう /位相情報/
いそうすうがく /位相数学;analysis situs, topology/
いそうせいぎょ /位相制御/
いそうそくど /位相速度/
いそうてき /位相的/
いそうとくせい /位相特性/
いそうぶんぷ /位相分布/
いそうへんちょう /位相変調/
いそうろう /居候/
いそがい /磯貝/
いそがみ /磯上/
いそがわ /五十川/
いそぎあし /急ぎ足/
いそぎんちゃく /磯巾着/
いそく /夷則/
いそくど /異速度/
いそご /磯子/
いそごえき /磯子駅/
いそごく /磯子区/
いそざお /磯竿/
いそざき /磯崎/
いそし /勤し/
いそしぎ /磯鷸/
いそじ /五十路/磯路/五十/
いそじまん /磯自慢/
いそじん /磯陣/
いそだ /磯田/礒田/
いそっぷものがたり /イソップ物語;Aesop's Fables/
いそづり /磯釣り/
いそていえん /磯庭園/
いそとし /五十年;名/
いそなみ /磯波/
いその /磯野/
いそのけ /磯野家/
いそぶし /磯節;[民謡]茨城/
いそべ /磯部/磯辺/
いそべあげ /磯辺揚げ/
いそほものがたり /伊曾保物語;イソップ物語の訳本/
いそま /磯間/
いそまつ /磯松/
いそまつもく /イソマツ目/Plumbaginales/
いそみち /磯道/
いそむら /磯村/
いそめ /磯蚯蚓/
いそもじ /急文字/
いそや /磯谷/
いそやま /磯山/礒山/
いそん /依存/
いそんかんけい /依存関係;dependency/
いそんざいげん /依存財源;地方交付税など. ⇔自主財源/
いそんしょう /依存症/
いそんしん /依存心/
いそんせい /依存性/
いそんひん /易損品/
いぞう /遺贈/以蔵/
いぞく /遺族/異族/異俗/
いぞくかい /遺族会/
いぞくねんきん /遺族年金/
いぞり /居反り/
いぞん /依存;=いそん/異存;objection.「-はない」/
いぞんかいせき /依存解析/
いぞんかんけい /依存関係/
いぞんがた /依存型/
いぞんぎみ /依存気味/
いぞんしょう /依存症/
いぞんじょうほう /依存情報/
いぞんせい /依存性/
いぞんせき /依存積/
いぞんたいしつ /依存体質/
いぞんてき /依存的/
いぞんど /依存度/
いぞんぶ /依存部/
いぞんわ /依存和/
いた /板/痛/
いたあつ /板厚/
いたい /遺体/異体/板井/
いたいいたいびょう /イタイイタイ病/
いたいけ /幼気/
いたいし /板石/
いたいじ /異体字/
いたいどうしん /異体同心/
いたいめ /痛い目/
いたいもじ /異体文字/
いたかぶ /板株/
いたかべ /板壁/
いたがき /板垣/
いたがきたいすけ /板垣退助/
いたがこい /板囲い/
いたがね /板金/鈑/
いたがみ /板紙/
いたがらす /板硝子/板ガラス;plate glass/
いたきれ /板切れ/
いたく /委託;任せる。「-販売」/依託;頼る/
いたくがいしゃ /委託会社/
いたくがくせい /依託学生/
いたくきん /委託金/依託金;?/
いたくぎょうしゃ /委託業者/
いたくけんきゅう /委託研究/
いたくしゃ /委託者/
いたくしょうこきん /委託証拠金/
いたくはんばい /委託販売/
いたくはんばいひん /委託販売品/
いたくばいばい /委託売買;証券会社が顧客の委託により行う有価証券の売買。⇔自己売買/
いたくほしょうきん /委託保証金/
いたくら /板倉/
いたくりょう /委託料/
いたけだか /居丈高/
いたこ /潮来;地名/板子/
いたこぶし /潮来節;俗謡/
いたご /板子;和船の底板/
いたさと /板里/
いたさん /板さん/
いたざい /板材/
いたざき /板崎/
いたしかた /致し方/
いたしかゆし /痛し痒し/
いたしゃ /痛車/
いたしんどう /板振動/
いたじき /板敷/
いたじょう /板状/
いたずき /病/
いたずら /悪戯;mischief.「子供の悪戯」/徒;vain.「徒な出費」/徒ら/
いたずらっこ /悪戯っ子/
いたずらに /徒に/
いたずり /板摺り;キュウリを-する/
いただき /頂き/頂/戴き/
いただきます /戴きます/
いただきもの /頂き物/戴き物/
いただたみ /板畳/
いただに /板谷;姓/
いたち /鼬/
いたちうお /鼬魚/
いたちごっこ /鼬ごっこ/
いたちょう /板長/
いたちょこ /板チョコ/
いたって /至って/
いたつき /板付き/
いたづけ /板付/
いたづら /悪戯/惡戲/
いたで /痛手/
いたでん /イタ電/
いたど /板戸/
いたどこ /板床/
いたどり /板取/
いたに /猪谷/
いたの /板野/
いたのま /板の間/
いたのり /板海苔/
いたはし /板橋/
いたば /板場/
いたばさみ /板挟み/
いたばし /板橋/
いたばしく /板橋区/
いたばしほんちょう /板橋本町/
いたばね /板発条;leaf springs/
いたばり /板張り/板張/
いたひょうめん /板表面/
いたびさし /板庇/板廂/
いたびょうし /板表紙/
いたぶんこ /板文庫/
いたべい /板塀/
いたま /板間/
いたまえ /板前/
いたみ /伊丹/痛み/
いたみし /伊丹市/
いたみどめ /痛み止め/
いたみわけ /痛み分け/傷み分け;=痛み分け/
いため /板目/炒め/
いためがみ /板目紙/
いためし /イタ飯/
いためなべ /炒め鍋/
いために /炒め煮/
いためもの /炒め物/
いためん /板面/
いたもち /板持/
いたや /板谷/板屋/板矢/
いたやえき /板谷駅/
いたやがい /板屋貝/
いたやとうげ /板谷峠/
いたやなぎ /板柳/
いたやね /板屋根;[建築]/
いたよせ /板寄/
いたらぬ /至らぬ/
いたり /至り/
いたりー /伊太利/
いたりあ /伊太利亜/伊太利屋;商号?/
いたりあご /イタリア語/
いたりあさん /イタリア産/
いたりあじん /イタリア人/
いたりあせい /イタリア製/
いたりあぶんがく /イタリア文学/
いたりありょうり /イタリア料理/
いたりっくたい /イタリック体/
いたる /至/到/格/
いたるところ /至る所/到る所/
いたれりつくせり /至れり尽くせり/至れり尽せり/
いたわさ /板山葵/板わさ/
いたわり /労り/板割り/板割/功/
いたん /異端/医短/医療技術短期大学部;※abbrev/
いたんし /異端視/
いたんしゃ /異端者/
いたんしんもん /異端審問/
いたんじ /異端児/
いたんちょう /イ短調/
いたんてき /異端的/
いたんぶんし /異端分子/
いだ /井田/伊田/委佗/
いだい /偉大/医大/
いだいさ /偉大さ/
いだし /出/
いだしぐるま /出車/
いだつ /遺脱/
いだてん /韋駄天/
いだん /イ段/
いち /一/位置/市/壱;「一」の大字/弌;「一」の異体字/壹;「壱」の旧字/伊知/依遅/１/1/Ｉ;全角英数のアイ/
いち> /一/
いちあく /一握;-の砂(啄木)/
いちあくのすな /一握の砂;啄木/
いちあん /一案/
いちい /一位/一意/櫟/市井/一井/一葦/
いちいか /一位科/
いちいしめい /一位指名/
いちいせい /一意性/
いちいせんしん /一意専心/
いちいたいすい /一衣帯水/
いちいち /一々/一一/
いちいてき /一意的/
いちいん /一員/一因/一院/
いちいんせい /一院制/
いちいんとうてい /一韻到底/
いちう /一宇/
いちえ /一会/
いちえいが /一映画/
いちえねるぎー /位置エネルギー;[物理]potential energy. mgh/
いちえん /一円/
いちえんだま /一円玉/
いちおう /一応/一往/
いちおうかくにん /一応確認/
いちおうふく /一往復/
いちおうふくぶん /一往復分/
いちおく /一億/
いちおくえん /一億円/
いちおくにん /一億人/
いちおし /一押し/一推し/
いちおん /一音/
いちおんせつ /一音節/
いちかい /市貝/
いちかいいん /一会員/
いちかいそう /一階層/
いちかくにん /位置確認/
いちかくほ /位置確保/
いちかたい /一方井;姓/
いちかたりゅう /一方流/都方流/
いちかばちか /一か八か/
いちから /一から/
いちかわ /市川/
いちかわえんのすけ /市川猿之助/
いちかわけおり /市川毛織/
いちかわし /市川市/
いちかわだいもん /市川大門/
いちかわだんじゅうろう /市川団十郎/
いちかわふさえ /市川房枝/
いちかんけい /位置関係/
いちかんそく /位置観測/
いちかんたい /一艦隊/
いちがい /一概/
いちがいに /一概に/
いちがお /市ヶ尾/
いちがくしょう /一楽章/
いちがくせい /一学生/
いちがくねん /一学年/1学年/
いちがくねんした /一学年下/
いちがしら /市頭/
いちがっき /一学期/
いちがつ /一月/１月/1月/睦月;※連想,旧暦/
いちがつごう /1月号/
いちがつまえ /一月前/
いちがめん /一画面/
いちがや /市ヶ谷/市谷/市ケ谷/
いちがやさないちょう /市谷左内町/
いちがん /一眼/一丸/
いちがんれふ /一眼レフ/
いちき /市来/一木/市來;「来」旧字/
いちきしゅ /一機種/
いちきじゅん /位置基準/
いちぎ /一義/
いちぎてき /一義的/
いちぎてきせきにん /一義的責任/
いちぎゅうめいち /一牛鳴地/
いちぎょう /一行/１行/1行/
いちぎょういちぎょう /一行一行/
いちぎょうめ /一行目/
いちぎょうやろう /一行野郎;one-liner/
いちく /移築/
いちくら /肆/
いちぐう /一隅;かたすみ。「宇宙の-」/一遇;千載-/
いちぐん /一群/一軍/
いちぐんこうしきせん /一軍公式戦/
いちぐんとうろく /一軍登録/
いちけい /位置系/
いちけいさん /位置計算/
いちけいたい /一形態/
いちけいとう /一系統/
いちけってい /位置決定/
いちけん /一研/
いちけんしき /一見識/
いちけんしゅつ /位置検出/
いちけんとう /一検討/
いちげ /市毛/
いちげい /一芸/
いちげき /一撃/
いちげきひっさつ /一撃必殺/
いちげきりだつ /一撃離脱/
いちげつさんしゅう /一月三舟/
いちげん /一言/一見/一元/一限/一弦/壱源/
いちげんか /一元化/
いちげんかんり /一元管理/
いちげんきん /一弦琴/
いちげんこじ /一言居士/
いちげんさん /一見さん/
いちげんせい /一元性/
いちげんてき /一元的/
いちげんろん /一元論/
いちこ /一子/市子/巫子/神巫/伊智子/
いちこう /一高/
いちこうさつ /一考察/
いちこうもく /一項目/
いちこくみん /一国民/
いちこし /市越/
いちこじん /一個人/
いちこたい /一個体/
いちこつ /壱越/
いちこつちょう /壱越調/
いちこてい /位置固定/
いちご /苺/一期/一語/莓;別字/
いちごあじ /イチゴ味/
いちごいちえ /一期一会/
いちごいちじゅう /一伍一什/
いちごいろ /苺色/
いちごう /一号/一合/壱号/
いちごうかん /一号館/
いちごうき /一号機/
いちごうせん /一号線/
いちごうてん /一号店/
いちごうとう /一号棟/
いちごがり /いちご狩り/
いちごん /一言/
いちごんいっく /一言一句/
いちごんはんく /一言半句/
いちさんかしゃ /一参加者/
いちざ /一座/
いちざひょう /位置座標/
いちし /一志/
いちしじん /一私人/
いちしちょうしゃ /一視聴者/
いちしてい /位置指定/
いちしみん /一市民/
いちしゅうきょう /一宗教/
いちしゅぞく /一種族/
いちしゅほう /一手法/
いちしょうじょ /一少女/
いちしょうじょう /一症状/
いちしんきょう /一神教/
いちじ /一時/一次/一字/一事;-が万事/一児/伊知地/１時/1時/１次/1次/
いちじ> /一時/一次/
いちじいっく /一字一句/
いちじおくれ /一次遅れ/
いちじおくれようそ /一次遅れ要素/
いちじかい /一次会/1次会/
いちじかいこ /一時解雇;layoff/
いちじかりいれきん /一時借入金/
いちじかん /一時間/1時間/
いちじかんいない /一時間以内/
いちじかんご /一時間後/
いちじかんすう /一次関数/
いちじかんはん /一時間半/
いちじかんまえ /一時間前/
いちじかんめ /一時間目/
いちじがわ /一次側/
いちじき /一時期/
いちじきかつどう /一時期活動/
いちじききゅう /一時帰休/
いちじきこく /一時帰国/
いちじきざいせき /一時期在籍/
いちじきもんだい /一時期問題/
いちじきゅうし /一時休止/
いちじきん /一時金/
いちじきんじ /一次近似/
いちじく /無花果/一軸/
いちじくけっしょう /一軸結晶/
いちじげん /一次元/1次元/
いちじげんてき /一次元的/
いちじこくゆうか /一時国有化/
いちじさんぴん /一次産品;primary products/
いちじさんらん /一次散乱/
いちじし /一次子/
いちじしき /一次式/
いちじしけん /一次試験/
いちじしのぎ /一時凌ぎ/
いちじしょとく /一時所得;cf.給与所得/
いちじしりょう /一次資料/
いちじせんきん /一字千金/
いちじだい /一時代/
いちじちがい /一字違い/
いちじちゅうし /一時中止/
いちじちゅうだん /一時中断/
いちじつ /一日/
いちじつさんしゅう /一日三秋/
いちじつせんしゅう /一日千秋/
いちじていし /一時停止/
いちじていしゃ /一時停車/
いちじてき /一時的;temporary/一次的;primary/
いちじでんち /一次電池;primary battery. 充電できない/
いちじのがれ /一時逃れ/
いちじはんしゃ /1次反射/
いちじばらい /一時払い/
いちじばん /一字版/
いちじふぁいる /一時ファイル;temporary file/
いちじふさいり /一事不再理/
いちじへき /一次壁/
いちじへんかん /一次変換/
いちじへんすう /一時変数/
いちじほうていしき /一次方程式/
いちじほかん /一時保管/
いちじほぞん /一時保存/
いちじま /市島/市嶋/
いちじみゃく /一次脈/
いちじもくぶ /一次木部/
いちじゅ /一樹/
いちじゅう /一重/一汁/
いちじゅういっさい /一汁一菜/
いちじゅうごさい /一汁五菜;一汁三菜プラス坪・猪口/
いちじゅうさんさい /一汁三菜;飯・汁・香の物・膾・平皿・焼物/
いちじゅん /一巡/一順/一旬/
いちじゅんめ /一巡目/
いちじょ /一助/一女/
いちじょう /一条/一場/一定/一畳/一城/
いちじょうじ /一乗寺/一条寺/
いちじょうてんのう /一条天皇/
いちじょうほう /位置情報/
いちじょせい /一女性/
いちじよせん /一次予選/
いちじわだい /一時話題/
いちじん /一陣/
いちじんえい /一陣営/
いちじんぶつ /一人物/
いちすぎ /一杉/
いちず /一途/一頭/
いちせ /一瀬/
いちせいぎょ /位置制御/
いちせいど /位置精度/
いちせいぶつ /一生物/
いちせいぶん /一成分/
いちせたい /一世帯/
いちぜん /一膳/
いちそうさ /一走査/
いちそくめん /一側面/
いちぞく /一族/
いちぞくろうとう /一族郎党/
いちぞくろうどう /一族郎党/
いちぞん /一存/
いちたいいち /一対一/1対1/
いちたいいちたいおう /一対一対応/
いちたいた /一対多/
いちたに /市谷/
いちたへん /一夕偏/
いちたろう /一太郎/市太郎/
いちたんご /一単語/
いちだ /一打/一朶/市田/伊地田/
いちだい /一大/一代/一台/
いちだい> /一大;-決戦,-決心,-ニュース/
いちだいかぎり /一代限り/
いちだいがく /一大学/
いちだいき /一代記/
いちだいけっしん /一大決心/
いちだいけつい /一大決意/
いちだいざっしゅ /一代雑種/
いちだいじ /一大事/
いちだいとしより /一代年寄/
いちだいぶん /一台分/
いちだいめ /一代目/一台目/
いちだくせんきん /一諾千金/
いちださ /一打差/
いちだん /一段/一団/
いちだんうえ /一段上/
いちだんかい /一段階/
いちだんかつよう /一段活用/
いちだんした /一段下/
いちだんだか /一段高/
いちだんどうし /一段動詞/
いちだんめ /一段目/
いちだんやす /一段安/
いちだんらく /一段落/
いちちほうとし /一地方都市/
いちちょうせい /位置調整/
いちぢ /伊知地/
いちづけ /位置付け/位置づけ/
いちてき /位置的/
いちてんき /一転機/
いちとうかせい /位置透過性/
いちとくせい /一特性/
いちとし /一都市/
いちど /一度/１度/1度/
いちどう /一同/一堂;-に会する/一道/
いちどき /一時/
いちどく /一読/
いちどくらい /一度位/
いちどていど /一度程度/
いちどめ /一度目/
いちどり /位置取り/
いちな /一名/
いちなん /一難/
いちに /一二/
いちにかい /一二回/
いちにち /一日/１日/1日/
いちにちいちぜん /一日一善/
いちにちいちにち /一日一日/
いちにちいちや /一日一夜/
いちにちいっかい /一日一回/
いちにちおき /一日置き/
いちにちくらい /一日位/
いちにちけん /一日券/
いちにちご /一日後/
いちにちしょちょう /一日署長/
いちにちじゅう /一日中/
いちにちじょうしゃけん /一日乗車券/
いちにちせんしゅう /一日千秋/
いちにちてんちょう /一日店長/
いちにちのばし /一日延ばし/
いちにちぶん /一日分/
いちにちめ /一日目/
いちにてん /一二点/
いちにほ /一二歩/
いちにょ /一如/
いちにん /一任/一人/
いちにんしゃ /一人者/
いちにんしょう /一人称/
いちにんとうせん /一人当千/
いちにんまえ /一人前/
いちねん /一年/一念/1年/
いちねんいか /一年以下/
いちねんいじょう /一年以上/
いちねんいじょうまえ /一年以上前/
いちねんいない /一年以内/
いちねんかん /一年間/1年間/
いちねんかんしよう /一年間使用/
いちねんき /一年忌/
いちねんけいか /一年経過/
いちねんけいやく /一年契約/
いちねんご /一年後/1年後/
いちねんじ /一年次/
いちねんじゅう /一年中/
いちねんせい /一年生/
いちねんせいそうほん /一年生草本/
いちねんそう /一年草/
いちねんていど /一年程度/
いちねんはん /一年半/
いちねんぶん /一年分/
いちねんほっき /一念発起/
いちねんほど /一年程/
いちねんまえ /一年前/
いちねんめ /一年目/
いちの /市野/
いちのう /一能/
いちのおり /一の折;[俳諧]/
いちのき /一の樹/
いちのぎく /市之菊/市乃菊/
いちのくら /一ノ蔵/一ノ倉/一の倉/
いちのせ /一ノ瀬/一瀬/市之瀬/一の瀬/一野瀬/
いちのせき /一関/一ノ関/
いちのちょう /一の町/
いちのつかさ /市司/
いちのへ /一戸/
いちのぼう /一の坊/
いちのみや /一宮/一の宮/一ノ宮/
いちのもと /櫟本/檪本/
いちのや /一の矢/
いちはさま /一迫/
いちはざま /一迫/
いちはし /市橋/
いちはた /一畑/
いちはつ /鳶尾/
いちはな /一端/
いちはやく /いち早く/
いちはら /市原/
いちはらし /市原市/
いちはらの /市原野/
いちば /市場/一場/一馬/市庭;≒市場/
いちばい /一倍/
いちばいはん /一倍半/
いちばた /一畑/
いちばつひゃっかい /一罰百戒/
いちばまち /市場町/
いちばめん /一場面/
いちばん /一番/壱番/
いちばん> /一番/
いちばんあんしん /一番安心/
いちばんあんぜん /一番安全/
いちばんあんてい /一番安定/
いちばんいや /一番嫌/
いちばんいんしょうてき /一番印象的/
いちばんうえ /一番上/
いちばんおく /一番奥/
いちばんかくじつ /一番確実/
いちばんかん /一番館;[映画]/一番艦/壱番館/
いちばんかんじん /一番肝心/一番肝腎/
いちばんかんたん /一番簡単/
いちばんき /一番機/
いちばんきたい /一番期待/
いちばんきほんてき /一番基本的/
いちばんくろう /一番苦労/
いちばんぐみ /一番組/
いちばんこうか /一番高価/
いちばんこうかてき /一番効果的/
いちばんこうりつ /一番効率/
いちばんごうか /一番豪華/
いちばんさいあく /一番最悪/
いちばんさいきん /一番最近/
いちばんさいご /一番最後/
いちばんさいしょ /一番最初/
いちばんさき /一番先/
いちばんざんねん /一番残念/
いちばんした /一番下/
いちばんしょうぶ /一番勝負/
いちばんじゅうよう /一番重要/
いちばんじょうず /一番上手/
いちばんそこ /一番底/
いちばんそと /一番外/
いちばんたいせつ /一番大切/
いちばんたんじゅん /一番単純/
いちばんだいこ /一番太鼓;歌舞伎の開催を知らせる/
いちばんだいじ /一番大事/
いちばんちょう /一番町/一番丁/
いちばんて /一番手/
いちばんていとう /一番抵当/
いちばんてまえ /一番手前/
いちばんでし /一番弟子/
いちばんとく /一番得/
いちばんどり /一番鶏/
いちばんにんき /一番人気/
いちばんのり /一番乗り/一番乗/
いちばんはし /一番端/
いちばんひだり /一番左/
いちばんひだりがわ /一番左側/
いちばんふしぎ /一番不思議/
いちばんべんり /一番便利/
いちばんぼし /一番星/
いちばんまえ /一番前/
いちばんみぎ /一番右/
いちばんみぎがわ /一番右側/
いちばんみりょくてき /一番魅力的/
いちばんめ /一番目/1番目/
いちばんもんだい /一番問題/
いちばんやり /一番槍/
いちばんらく /一番楽/
いちひめ /市姫/
いちひめにたろう /一姫二太郎/
いちびょう /一秒/
いちびょういか /一秒以下/
いちびょうかん /一秒間/
いちびょうそくさい /一病息災/
いちびょうたんい /一秒単位/
いちびん /一便/
いちぶ /一部/一分/1部/
いちぶ> /一部;(part of) -可,-改正,-地方/
いちぶいん /一部員/
いちぶいんよう /一部引用/
いちぶかいつう /一部開通/
いちぶかっそうか /一部滑走可/
いちぶきぎょう /一部企業/
いちぶきしゅ /一部機種/
いちぶきんえん /一部禁煙/
いちぶくかん /一部区間/
いちぶしじゅう /一部始終/
いちぶしていせき /一部指定席/
いちぶしゃりょう /一部車両/
いちぶしゅうせい /一部修正/
いちぶしょうりゃく /一部省略/
いちぶしよう /一部仕様/
いちぶしろくろ /一部白黒/
いちぶじょうじょう /一部上場/
いちぶちいき /一部地域/
いちぶつ /一物/
いちぶついか /一部追加/
いちぶていせい /一部訂正/
いちぶはっぴょう /一部発表/
いちぶはんけつ /一部判決/
いちぶばっすい /一部抜粋/
いちぶふくせんか /一部複線化/
いちぶふっき /一部復帰/
いちぶぶん /一部分/
いちぶへんこう /一部変更/
いちぶへんしゅう /一部編集/
いちぶほけん /一部保険/
いちぶもん /一部門/
いちぶゆうこう /一部有効/
いちぶりゃく /一部略/
いちぶん /一文/一分/一聞/
いちぶんかいのう /位置分解能/
いちぶんし /一分子/
いちぶんせつ /一文節/
いちぶんや /一分野/
いちへいし /一兵士/
いちへんすう /1変数/一変数/位置変数/
いちへんせい /一編成/
いちべくとる /位置ベクトル/
いちべつ /一瞥/一別/
いちぺーじ /一ページ/一頁/
いちほうこう /一方向/
いちほうし /一法師/
いちほうほう /一方法/
いちぼう /一望/
いちぼうせんり /一望千里/
いちぼく /一木/
いちぼくいっそう /一木一草/
いちぼくづくり /一木造り;[彫刻]一つの木から彫り出す/
いちまい /一枚/
いちまいいた /一枚板/
いちまいいちまい /一枚一枚/
いちまいいわ /一枚岩/
いちまいうわて /一枚上手/
いちまいえ /一枚絵/
いちまいかんばん /一枚看板/
いちまいがい /一枚貝/
いちまいがわ /一枚革/一枚皮/
いちまいした /一枚下/
いちまいぶん /一枚分/
いちまいめ /一枚目/
いちまつ /市松/一抹/一松/
いちまつもよう /市松模様/
いちまん /一万/一萬/
いちまんえん /一万円/1万円/壱万円/壱萬圓/
いちまんえんさつ /一万円札/
いちまんじゃく /一万尺/
いちまんまい /一万枚/
いちみ /一味/
いちみとうがらし /一味唐辛子/
いちみととう /一味徒党/
いちみどうしん /一味同心/
いちみゃく /一脈/
いちむら /市村/一村/
いちむらざ /市村座;[歌舞伎]江戸三座の一/
いちめ /市女/
いちめい /一名/一命;-を取り留める/1名/
いちめいれい /一命令/
いちめがさ /市女笠/
いちめん /一面/
いちめんしき /一面識/
いちめんてき /一面的/
いちもう /一望;唯一の希望 (≠いちぼう)/一毛/
いちもうさく /一毛作/
いちもうだじん /一網打尽/
いちもく /一目/
いちもくさん /一目散/
いちもくりょうぜん /一目瞭然/
いちもじ /一文字/１文字/1文字/
いちもじめ /一文字目/
いちもつ /一物/逸物/
いちもん /一門;clan/一文;-なし/一問;-一答/
いちもんいっとう /一問一答/
いちもんきなか /一文半銭;はした金/
いちもんじ /一文字/
いちもんせん /一文銭/
いちもんなし /一文無し/
いちもんはんせん /一文半銭/
いちもんふち /一文不知;illiterate/
いちもんふつう /一文不通/
いちもんめ /一問目/
いちや /一夜/
いちやく /一躍/一役/
いちやくきゃっこう /一躍脚光/
いちやじょう /一夜城/
いちやづけ /一夜漬け/一夜漬/
いちやなぎ /一柳/
いちやぶん /一夜分/
いちゅう /意中/移駐/
いちゆう /一揖/
いちょ /遺著/
いちょう /胃腸/銀杏/医長/移調/公孫樹;=銀杏/異朝/移牒/鴨脚樹;=銀杏/異聴/威張;?/
いちょういも /銀杏芋/
いちょうえん /胃腸炎/
いちょうかん /胃腸管/
いちょうがえし /銀杏返し/
いちょうがっき /移調楽器/
いちょうぎり /銀杏切り;1／4円形/
いちょうこう /イチョウ綱/Ginkgopsida/
いちょうしょうがい /胃腸障害/
いちょうちょう /イ長調/
いちょうなみき /銀杏並木/
いちょうひょう /異聴表/
いちょうびょう /胃腸病/
いちょうやく /胃腸薬/
いちよ /市代/
いちよう /一様/一葉/
いちようか /一様化/
いちようき /一葉忌;11／23/
いちようしゅうそく /一様収束/
いちようせい /一様性/
いちようそ /一要素/
いちようぶんぷ /一様分布/
いちようらいふく /一陽来復/
いちようらんすう /一様乱数/
いちよく /一翼/
いちよし /市吉/
いちよそく /位置予測/
いちらん /一覧/一蘭/壹覽/
いちらんさくせい /一覧作成/
いちらんせい /一卵性/
いちらんせいそうせいじ /一卵性双生児/
いちらんひょう /一覧表/
いちらんひょうじ /一覧表示/
いちり /一理;-ある/一利;百害あって-なし/一里/
いちりいちがい /一利一害/
いちりき /一力/
いちりつ /一律/市立/一率;?/
いちりつかぜい /一律課税/
いちりつてき /一律的/
いちりつふなばし /市立船橋/
いちりづか /一里塚/
いちりの /一里野/
いちりやま /一里山/
いちりゅう /一流/一粒;-万倍/一留/
いちりゅうきぎょう /一流企業/
いちりゅうせんしゅ /一流選手/
いちりゅうだいがく /一流大学/
いちりゅうば /一流馬/
いちりゅうまんばい /一粒万倍/
いちりょう /一両/
いちりょういき /一領域/
いちりょうしゃ /一両車/
いちりょうじつ /一両日/
いちりょうじつちゅう /一両日中/
いちりようしゃ /一利用者/
いちりん /一輪/1輪/
いちりんか /一輪花/
いちりんざし /一輪挿し/
いちりんしゃ /一輪車/
いちる /一縷/
いちるい /一塁/一類/
いちるいがわ /一塁側/
いちるいしゅ /一塁手/
いちるいそうしゃ /一塁走者/
いちれい /一例/一礼/
いちれつ /一列/1列/
いちれつめ /一列目/
いちれん /一連;-の事件/一蓮;-托生/
いちれんたくしょう /一蓮托生/
いちろ /一路/
いちろう /一浪/一郎/一朗/市郎/伊知郎/
いちろうた /一朗太/
いちろくぎんこう /一六銀行;質屋 (NB:1+6=7しち)/
いちろなんか /一路南下/
いちろへいあん /一路平安;Bon voyage!/
いちろん /一論/
いちわ /一話/一羽/
いちわかんけつ /一話完結/
いちわり /一割/
いちわりいじょう /一割以上/
いちわりびき /一割引/
いっ /逸/
いっか /一家/一過;「台風-」/一課;「捜査-」/一和;調和していること/一価;[化学]monovalent.「-のイオン」/一下;「号令-」/一顆;ひとつぶ/
いっかい /一介/一回/一階/一塊/１回/1回/１Ｆ/
いっかいいっかい /一回一回/
いっかいき /一回忌/
いっかいごと /一回毎/
いっかいじゅつごろんり /一階述語論理/
いっかいせい /一回性/一回生;freshman/
いっかいせき /一階席/
いっかいせん /一回戦/一回線;single line/
いっかいていど /一回程度/
いっかいてん /一回転/
いっかいぶん /一回分/
いっかいめ /一回目/１回目/
いっかかんすう /一価関数/
いっかく /一角/一画/一郭/一攫;-千金/一廓;=一郭/一劃;「画」旧字/一獲;=一攫/
いっかくじゅう /一角獣/
いっかくじゅうざ /一角獣座;Monoceros(Mon)/
いっかくせんきん /一攫千金/一獲千金;=一攫千金 (NB:「攫」は「掴む」の意)/
いっかくせんにん /一角仙人/
いっかげつ /一ヶ月/一カ月/一箇月/１ヶ月/１か月/
いっかげつまえ /一箇月前/
いっかげん /一家言/
いっかごん /一家言;※「いっかげん」が正しい/
いっかしょ /一箇所/一カ所/一ヶ所/一か所/1カ所/
いっかしんじゅう /一家心中/
いっかせい /一過性/
いっかだんらん /一家団欒/
いっかつ /一括;-払い/一喝;バカモン！/
いっかつこうにゅう /一括購入/
いっかつさくじょ /一括削除/
いっかつしょり /一括処理/
いっかつそうしん /一括送信/
いっかつとうろく /一括登録/
いっかつにゅうりょく /一括入力/
いっかつばらい /一括払い/
いっかつへんかん /一括変換/
いっかつほう /一括法/
いっかてき /一過的/
いっかりさん /一家離散/
いっかりつ /一価律/
いっかん /一環/一貫/一巻/一管/
いっかんきょういく /一貫教育/
いっかんせい /一貫性/
いっかんぼん /一巻本/
いっき /一気/一揆/一期/逸機/一騎/一季/一機/一輝;人名/
いっきいちゆう /一喜一憂/
いっきうち /一騎打ち/一騎討ち/一騎打/
いっきかせい /一気呵成/
いっきく /一掬/
いっきせい /一期生/
いっきつうかん /一気通貫/
いっきとうせん /一騎当千/
いっきに /一気に/
いっきのみ /一気飲み/
いっきゃく /一脚/
いっきゅう /一級/一休/一球/
いっきゅうけんちくし /一級建築士/
いっきゅうひん /一級品/
いっきょ /一挙/逸居;easygoing/
いっきょいちどう /一挙一動/
いっきょう /一興/一驚/
いっきょく /一曲/一極/一局/
いっきょくこうぞう /一極構造/
いっきょくしゅうちゅう /一極集中/一局集中;?/
いっきょくめ /一曲目/
いっきょこうかい /一挙公開/
いっきょしゅ /一挙手/
いっきょしゅいっとうそく /一挙手一投足/
いっきょりょうとく /一挙両得/
いっきょりょうどく /一挙両得/
いっきん /一斤/一金/
いっく /一句/一区/
いっくかん /一区間/
いっけい /一計;-を案じる/一系;万世-/一景/一型/
いっけいあくせんと /一型アクセント;音韻的対立のないアクセント体系/
いっけつ /一穴/一決/溢血/
いっけん /一見/一件/一軒/一間/1件/
いっけんいっけん /一軒一軒/
いっけんしき /一見識/
いっけんや /一軒家/
いっけんやど /一軒宿/
いっけんらくちゃく /一件落着/
いっこ /一個/一戸/一顧;-だにしない/一己;私-/一箇/一ヶ/1個/
いっこいっこ /一個一個/
いっこう /一行/一向;-にない/一考/一項/一幸/一稿/一鉤/溢口/1項/
いっこういっき /一向一揆/
いっこうかんけい /1項関係/一項関係/
いっこうしゅう /一向宗/一向衆/
いっこく /一刻/一国/
いっこくいちじょう /一国一城/
いっこくしゅぎ /一国主義/
いっこくせんきん /一刻千金/
いっこくせんしゅう /一刻千秋/
いっこくにせいど /一国二制度/
いっこくもの /一刻者/
いっこじん /一個人/
いっこだて /一戸建て/
いっこてん /一壺天/
いっこぶん /一個分/
いっこん /一献/
いっこんぞめ /一斤染/
いっさ /一茶/
いっさい /一切/一妻;-多夫/一再;-ならず/一歳/一際;?/一済;?/
いっさい> /一切/
いっさいがっさい /一切合切/一切合財;=一切合切/
いっさいきょう /一切経/
いっさいきんし /一切禁止/
いっさいしょうりゃく /一切省略/
いっさいせきにん /一切責任/
いっさいたふ /一妻多夫/
いっさいてん /一斎点/
いっさいふかのう /一切不可能/
いっさいむかんけい /一切無関係/
いっさいむし /一切無視/
いっさく /一策;窮余の-/一作/一昨;-日/
いっさくじつ /一昨日/
いっさくねん /一昨年/
いっさくねんど /一昨年度/
いっさくばん /一昨晩/
いっさくめ /一作目/
いっさくや /一昨夜/
いっさつ /一冊/一札/
いっさつぶん /一冊分/
いっさつめ /一冊目/
いっさんか /一酸化/
いっさんかたんそ /一酸化炭素/
いっさんかたんそちゅうどく /一酸化炭素中毒/
いっさんかちっそ /一酸化窒素/
いっし /一矢;-報いる/一糸;-纏わず/一子/一指/一志/一紙/一死/逸史/
いっしあい /一試合/
いっしき /一式/一色/
いっしそうでん /一子相伝/
いっしつ /一室/逸失/一失/
いっしつりえき /逸失利益/
いっしどうじん /一視同仁/
いっしはんせん /一紙半銭/
いっしまんるい /一死満塁/
いっしゃ /一社/一者/
いっしゃせん /一車線/
いっしゃせんり /一瀉千里/
いっしゃていきょう /一社提供/
いっしゅ /一種/一首/
いっしゅ> /一種/
いっしゅう /一周/一蹴/壱州;壱岐/一週/
いっしゅうかん /一週間/
いっしゅうかんいじょう /一週間以上/
いっしゅうかんくらい /一週間位/
いっしゅうかんご /一週間後/
いっしゅうかんていど /一週間程度/
いっしゅうかんぶん /一週間分/
いっしゅうかんほど /一週間程/
いっしゅうかんまえ /一週間前/
いっしゅうき /一周忌/一周期/
いっしゅうねん /一周年/
いっしゅうめ /一週目/一周目/
いっしゅく /一宿/
いっしゅくいっぱん /一宿一飯/
いっしゅつ /逸出/
いっしゅどくとく /一種独特/
いっしゅるい /一種類/
いっしゅん /一瞬/
いっしゅんいっしゅん /一瞬一瞬/
いっしゅんかん /一瞬間/
いっしゅんでんき /一瞬電気/
いっしょ /一緒/一書/一所/逸書/佚書;=逸書/
いっしょう /一生/一升;1.8L/一笑;-に付す/一将;-功成りて万骨枯る/一章/一勝/
いっしょういっぱい /一勝一敗/
いっしょうがい /一生涯/
いっしょうけんめい /一生懸命/
いっしょうせつ /一小節/
いっしょうびん /一升瓶/
いっしょうもの /一生物/一生モノ/一生もの/
いっしょく /一色/一食/
いっしょくそくはつ /一触即発/
いっしょくた /一緒くた/
いっしょくぶん /一食分/
いっしょけんめい /一所懸命/
いっしん /一新;陣容を-する/一心;…したい-で/一身;-に引き受ける/一審/一針;頂門の-/
いっしんいったい /一進一退/
いっしんきょう /一神教/
いっしんじょう /一身上/
いっしんとう /一親等/
いっしんどうたい /一心同体/
いっしんはいそ /一審敗訴/
いっしんふらん /一心不乱/
いっしんろん /一神論/
いっすい /一睡/溢水/一炊;-の夢/一穂/
いっすん /一寸/
いっすんさき /一寸先/
いっすんぼうし /一寸法師/
いっせ /一世/一瀬/
いっせい /一斉/一声/一世/一生;人名/一成/一誠/
いっせいいちげん /一世一元/
いっせいいちだい /一世一代;※いっせいちだい/
いっせいこうげき /一斉攻撃/
いっせいしゃげき /一斉射撃/
いっせいじゅぎょう /一斉授業/
いっせいちだい /一世一代/
いっせいちょうさ /一斉調査/
いっせいどう /一誠堂/
いっせいに /一斉に/
いっせき /一石/一隻/一席/一夕;一朝-/
いっせきがん /一隻眼;見識/
いっせきにちょう /一石二鳥/
いっせつ /一節/一説/
いっせつたしょう /一殺多生/
いっせつな /一刹那/
いっせん /一線/一戦;-交える/一銭/一閃;紫電-/一千/一煎/一洗;旧弊-/
いっせんいちやものがたり /一千一夜物語/
いっせんきゅう /一線級/
いっせんごりん /一銭五厘;≒赤紙 NB:召集令状の郵便料金/
いっせんねん /一千年/
いっせんまん /一千万/
いっせんまんえん /一千万円/
いっせんめ /一煎目/
いっそ /一噌/不如/一層/
いっそう /一層/一掃/一双;a pair/逸走/一左右;一回の連絡/
いっそう> /一層;(副詞) -便利,-お求めやすく/
いっそうこうかてき /一層効果的/
いっそうべんり /一層便利/
いっそうりゅう /一噌流;笛方/
いっそく /一足/一束;-一本/
いっそくとび /一足飛び/
いったい /一体/一帯/一隊/
いったい> /一体/
いったいいち /一対一/
いったいか /一体化/
いったいかん /一体感/
いったいがた /一体型/
いったいけい /一体形/
いったいしき /一体式/
いったいせいけい /一体成形/
いったいぜんたい /一体全体/
いったいだれ /一体誰/
いったいてき /一体的/
いったいなぜ /一体何故/
いったいなに /一体何/
いったいなにもの /一体何者/
いったく /一択/一卓/
いったん /一旦;-停止/一端;-を垣間見る/一反/一短;一長-/一箪;-の食/一たん/
いったんしゅうりょう /一旦終了/
いったんちゅうし /一旦中止/
いったんていし /一旦停止/
いったんもめん /一反木綿/
いっち /一致/
いっちしすう /一致指数;[経済]coincedent index/
いっちせい /一致性/
いっちだんけつ /一致団結/
いっちてん /一致点/
いっちど /一致度/
いっちはんかい /一知半解/
いっちはんてい /一致判定/
いっちゃく /一着/
いっちゅう /一中/一籌/
いっちゅうぶし /一中節;[浄瑠璃]/
いっちゅうや /一昼夜/
いっちょう /一丁/一聴/一朝/一兆/一長/一張/
いっちょういっし /一張一弛/
いっちょういっせき /一朝一夕/
いっちょういったん /一長一短/
いっちょうめ /一丁目/１丁目/
いっちょうら /一張羅/
いっちょくせん /一直線/
いっちょくせんじょう /一直線上/
いっちょまえ /一丁前/
いっつい /一対/
いっついひかく /一対比較/
いっついひかくほう /一対比較法/
いっつう /一通/1通/
いっつうめ /一通目/
いっつうわ /一通話/
いって /一手/
いってい /一定/
いっていいか /一定以下/
いっていいじょう /一定以上/
いっていおんどいじょう /一定温度以上/
いっていかいてん /一定回転/
いっていかいてんすう /一定回転数/
いっていかく /一定角/
いっていかんかく /一定間隔/
いっていがく /一定額/
いっていがくいじょう /一定額以上/
いっていきかん /一定期間/
いっていきぼいじょう /一定規模以上/
いっていきょうど /一定強度/
いっていきょり /一定距離/
いっていしゅうき /一定周期/
いっていしゅうはすう /一定周波数/
いっていじ /一丁字/
いっていじかん /一定時間/
いっていじかんいじょう /一定時間以上/
いっていじかんかんかく /一定時間間隔/
いっていじかんご /一定時間後/
いっていじかんない /一定時間内/
いっていすう /一定数/
いっていすういじょう /一定数以上/
いっていそくど /一定速度/
いっていち /一定値/
いっていていど /一定程度/
いっていねんげん /一定年限/
いっていはば /一定幅/
いっていふへん /一定不変/
いっていりつ /一定率/
いっていりょう /一定量/
いっていりょうきん /一定料金/
いってき /一滴/一擲;乾坤-/
いってきせんきん /一擲千金/
いってこい /行って来い;±0/
いってつ /一徹/
いってるびうむ /Yb/Ytterbium/
いってん /一点/一転/一天/1点/
いってんか /一天下/
いってんがい /一点買い/
いってんき /一転機/
いってんさ /一点差/
いってんさせん /一点鎖線;―・―・/
いってんしかい /一天四海/
いってんとうし /一点透視/
いってんばり /一点張り/
いってんめ /一点目/
いってんろ /一点炉/
いっと /一途/一斗;18.039l/一都;-三県/一兎;二兎を追うものは-をも得ず/
いっとう /一等/一頭/一党/一刀/一投/一統/一灯;貧者の-/
いっとういっぱ /一党一派/
いっとうこうかいし /一等航海士/
いっとうこく /一等国/
いっとうさい /一刀斉/
いっとうしゃ /一等車/
いっとうしょう /一等賞/
いっとうしん /一等親/
いっとうせい /一等星/
いっとうそく /一投足/
いっとうそつ /一等卒/
いっとうち /一等地/一頭地;-を抜く/
いっとうどくさい /一党独裁/
いっとうへい /一等兵/
いっとうぼり /一刀彫/一刀彫り/
いっとうりゅう /一刀流/
いっとうりょうだん /一刀両断/
いっとかん /一斗缶/
いっとき /一時/
いっとく /一得/
いっとくいっしつ /一得一失/
いっとさんけん /一都三県/
いっとます /一斗枡/
いっとりうむ /Y/Yttrium/
いっぱ /一派/一波/
いっぱい /一杯/一敗/
いっぱいいっぱい /一杯一杯;見るからに-/
いっぱいきげん /一杯機嫌/
いっぱいのみや /一杯飲み屋/
いっぱいぶん /一杯分/
いっぱいほど /一杯程/
いっぱく /一泊/一拍/一白;[陰陽道]/
いっぱくふつか /一泊二日/
いっぱくめ /一拍目/
いっぱくりょこう /一泊旅行/
いっぱし /一端/
いっぱつ /一発/一髪;危機-/
いっぱつぎゃくてん /一発逆転/
いっぱつげい /一発芸/
いっぱつしょうぶ /一発勝負/
いっぱつだい /一発台/
いっぱつだいぎゃくてん /一発大逆転/
いっぱつどり /一発録り/
いっぱつにはつ /一発二発/
いっぱつへんかん /一発変換/
いっぱつめ /一発目/
いっぱつや /一発屋/
いっぱつやろう /一発野郎/
いっぱつろくおん /一発録音/
いっぱん /一般/一版/一班/一飯;一宿-/一半/一斑/
いっぱん> /一般;-部門,-会員,-ユーザ/
いっぱんいし /一般意思/
いっぱんうけ /一般受け/一般受/
いっぱんえいが /一般映画/
いっぱんえんだい /一般演題/
いっぱんか /一般化/
いっぱんかい /一般解/
いっぱんかいいん /一般会員/
いっぱんかいけい /一般会計/
いっぱんかかく /一般価格/
いっぱんかがく /一般科学/
いっぱんかく /一般角/
いっぱんかざひょう /一般化座標/
いっぱんかてい /一般家庭/
いっぱんがいねん /一般概念/
いっぱんきぎょう /一般企業/
いっぱんきじゅん /一般基準/
いっぱんきゃく /一般客/
いっぱんきょういく /一般教育/
いっぱんきょういくぶ /一般教育部/
いっぱんきょうしょ /一般教書/
いっぱんきょうしょえんぜつ /一般教書演説/
いっぱんきょうそう /一般競争/
いっぱんきょうよう /一般教養/
いっぱんけい /一般形/一般型/
いっぱんけんきゅう /一般研究/
いっぱんけんきゅうはっぴょう /一般研究発表/
いっぱんけんせつぎょう /一般建設業/
いっぱんげんごがく /一般言語学;linguistique generale. 『-講義』(Saussure)/
いっぱんげんそく /一般原則/
いっぱんげんり /一般原理/
いっぱんこう /一般項/
いっぱんこうえん /一般講演/
いっぱんこうかい /一般公開/
いっぱんこうかいび /一般公開日/
いっぱんこうかいまえ /一般公開前/
いっぱんこうしゅうかいせん /一般公衆回線/
いっぱんこうつう /一般交通/
いっぱんこうどう /一般公道/
いっぱんこうぼ /一般公募/
いっぱんこくどう /一般国道/
いっぱんこくみん /一般国民/
いっぱんご /一般語/
いっぱんさつえい /一般撮影/
いっぱんさんか /一般参加/
いっぱんさんかしゃ /一般参加者/
いっぱんざい /一般材/
いっぱんざいげん /一般財源/
いっぱんざっし /一般雑誌/
いっぱんざひょう /一般座標/
いっぱんざひょうへんかん /一般座標変換/
いっぱんし /一般紙/一般誌/
いっぱんしじょう /一般市場/一般誌上/
いっぱんしつもん /一般質問/
いっぱんしていせき /一般指定席/
いっぱんしみん /一般市民/
いっぱんしゃ /一般車/
いっぱんしゃいん /一般社員/
いっぱんしゃかい /一般社会/
いっぱんしゃしん /一般写真/
いっぱんしゃりょう /一般車両/
いっぱんしゅふ /一般主婦/
いっぱんしょ /一般書/
いっぱんしょうひぜい /一般消費税/
いっぱんしょく /一般職/一般色/
いっぱんしょせき /一般書籍/
いっぱんしょてん /一般書店/
いっぱんしょみん /一般庶民/
いっぱんしよう /一般使用/
いっぱんじげん /一般次元/
いっぱんじこう /一般事項/
いっぱんじどう /一般児童/
いっぱんじむ /一般事務/
いっぱんじゅうたく /一般住宅/
いっぱんじゅうみん /一般住民/
いっぱんじょうきゃく /一般乗客/
いっぱんじょうしき /一般常識/
いっぱんじょうせい /一般情勢/
いっぱんじょうようしゃ /一般乗用車/
いっぱんじょせい /一般女性/
いっぱんじん /一般人/
いっぱんせい /一般性/
いっぱんせいかつ /一般生活/
いっぱんせいふ /一般政府/
いっぱんせつび /一般設備/
いっぱんせんきょ /一般選挙/
いっぱんせんしゅ /一般選手/
いっぱんぜいしゅう /一般税収/
いっぱんそうたいせいりろん /一般相対性理論/
いっぱんそうたいろん /一般相対論/
いっぱんそく /一般則/
いっぱんたいしゅう /一般大衆/
いっぱんたいしょく /一般退職/
いっぱんだい /一般台/
いっぱんだんし /一般男子/
いっぱんち /一般値/
いっぱんちしき /一般知識/
いっぱんてき /一般的/
いっぱんてきかいしゃく /一般的解釈/
いっぱんてきけいこう /一般的傾向/
いっぱんてきけんかい /一般的見解/
いっぱんてきしよう /一般的使用/
いっぱんてきじょうしき /一般的常識/
いっぱんてきもんだい /一般的問題/
いっぱんてきりかい /一般的理解/
いっぱんてん /一般店/
いっぱんでんわよう /一般電話用/
いっぱんとうえい /一般投影/
いっぱんとうしか /一般投資家/
いっぱんとうろく /一般登録/
いっぱんどう /一般道/
いっぱんどうろ /一般道路/
いっぱんどくしゃ /一般読者/
いっぱんにほんじん /一般日本人/
いっぱんにゅうし /一般入試/
いっぱんにゅうじょう /一般入場/
いっぱんにゅうじょうけん /一般入場券/
いっぱんにゅうじょうしゃ /一般入場者/
いっぱんはいきぶつ /一般廃棄物/
いっぱんはっぴょう /一般発表/
いっぱんはつばい /一般発売/
いっぱんぶもん /一般部門/
いっぱんほう /一般法/
いっぱんほうそく /一般法則/
いっぱんまどぐち /一般窓口/
いっぱんみんかんじん /一般民間人/
いっぱんむき /一般向/
いっぱんめい /一般名/
いっぱんめいし /一般名詞/
いっぱんめいしょう /一般名称/
いっぱんゆーざ /一般ユーザ/
いっぱんゆーざー /一般ユーザー/
いっぱんゆうりょうどうろ /一般有料道路/
いっぱんよう /一般用/
いっぱんようご /一般用語/
いっぱんよぼう /一般予防/
いっぱんりょく /一般力/
いっぱんりょこう /一般旅行/
いっぱんりようしゃ /一般利用者/
いっぱんりろん /一般理論/
いっぱんれっしゃ /一般列車/
いっぱんろ /一般路/
いっぱんろん /一般論/
いっぱんろんてき /一般論的/
いっぱんろんぶん /一般論文/
いっぴ /１日/
いっぴき /一匹/
いっぴきおおかみ /一匹狼/
いっぴつ /一筆/
いっぴつけいじょう /一筆啓上/
いっぴょう /一票/一瓢;-の飲/1票/
いっぴん /一品/逸品/
いっぴんいっしょう /一顰一笑/
いっぴんりょうり /一品料理/
いっぷ /一夫/
いっぷいっさい /一夫一妻/
いっぷいっぷ /一夫一婦/
いっぷう /一風/一封/
いっぷく /一服/一幅;-の絵/一腹;-の兄弟/
いっぷたさい /一夫多妻/
いっぷたさいせい /一夫多妻制/
いっぷん /一分/１分/1分/
いっぷんいない /一分以内/
いっぷんかん /一分間/
いっぺい /一平/一兵;名/
いっぺいそつ /一兵卒/
いっぺき /一碧/
いっぺん /一変/一片/一辺/一編/一遍/一篇/一偏/
いっぺんとう /一辺倒/
いっぽ /一歩/
いっぽいっぽ /一歩一歩/
いっぽう /一方/一報/一法/
いっぽうつうこう /一方通行/
いっぽうつうこうきせい /一方通行規制/
いっぽうつうこうろ /一方通行路/
いっぽうてき /一方的/
いっぽさき /一歩先/
いっぽぜんしん /一歩前進/
いっぽてまえ /一歩手前/
いっぽまえ /一歩前/
いっぽん /一本/
いっぽんあし /一本足/
いっぽんあしだほう /一本足打法/
いっぽんいっぽん /一本一本/
いっぽんか /一本化/
いっぽんがたな /一本刀/
いっぽんがち /一本勝ち/
いっぽんぎ /一本気/
いっぽんさ /一本鎖/
いっぽんざし /一本差し/
いっぽんしょうぶ /一本勝負/
いっぽんすぎ /一本杉/
いっぽんすじ /一本筋/
いっぽんせん /一本線/
いっぽんぜおい /一本背負/一本背負い/
いっぽんだち /一本立ち/
いっぽんちょうし /一本調子/
いっぽんぢょうし /一本調子/
いっぽんづり /一本釣り;カツオの-/
いっぽんばし /一本橋/
いっぽんぶん /一本分/
いっぽんまつ /一本松/
いっぽんみち /一本道/
いっぽんめ /一本目/
いっぽんやり /一本槍/
いっぽんゆび /一本指/
いつ /何時/稜威/厳;=稜威/逸;逸失/佚;散佚(≒散逸)/軼;軼事(≒逸事)/溢;横溢/鎰;(かぎ)/聿;(ここに)/鴪/一/五/壱;=一/壹;「壱」の旧字/弌;「一」の異体字/乙;(漢音) おつ/伍;(人名用)/
いついつ /何時何時/
いつう /胃痛/
いつお /厳夫;名/逸生/
いつか /五日/何時か/５日/5日/
いつかいち /五日市/
いつかいちかいどう /五日市街道/
いつかいちせん /五日市線/
いつき /斎/五木/五月/五紀/樹/
いつきだ /五木田/
いつきひろゆき /五木寛之/
いつきめ /斎女/
いつくしま /厳島/
いつくしまじんじゃ /厳島神社/
いつくしみ /慈しみ/
いつこ /伊都子/
いつごろ /いつ頃/何時頃;NB:「なんじごろ」と同形/
いつざい /逸材/
いつしか /何時しか/
いつじ /逸事/軼事/
いつぞんそうしょ /佚存叢書/
いつだつ /逸脱/
いつつ /五つ/５つ/5つ/
いつつばし /五橋/
いつつぼし /五つ星;☆☆☆☆☆ 「-レストラン」/
いつつもん /五つ紋/
いつづけ /居続け/
いつでも /何時でも/
いつとものふみ /五部書/
いつなんどき /何時何時/
いつねんごう /逸年号/
いつはし /五橋/
いつぶつ /逸物/
いつぶん /逸文;lost document/逸聞;知られていない話/佚文;=逸文/
いつまで /何時迄/
いつまでぐさ /常春藤/
いつまでも /何時迄も/
いつみ /逸見/逸美/
いつも /何時も/
いつらく /逸楽/
いつわ /逸話/五和/五輪/
いつわり /偽り/
いつわりもの /偽り者/
いづ /伊津/
いづつ /井筒/
いづつや /井筒屋/
いづな /飯綱/
いづはら /厳原/出原/
いづぶち /出渕/
いづれ /何れ/孰れ/
いて /射手/
いてき /夷狄/
いてざ /射手座;Sagittarius(Sgr),(11.22-12.21)/
いてん /移転/移点;†訓点を写す/
いてんかかく /移転価格/
いてんけいかく /移転計画/
いてんさき /移転先/
いてんしゅうし /移転収支/
いてんしょとく /移転所得;[経済]transfer income/
いてんとうき /移転登記/
いてんまえ /移転前/
いで /出/井出/井手/出澤/
いであろん /イデア論/
いでい /出居/
いでぐち /井手口/
いでさわ /出澤/出沢/
いでたち /出で立ち/
いでみつ /出光/
いでむら /出村/
いでゆ /出で湯;温泉/出湯/
いでん /遺伝/異伝/位田/
いでんあるごりずむ /遺伝アルゴリズム/
いでんあんごう /遺伝暗号/
いでんいんし /遺伝因子;[生物]genetic factor/
いでんがく /遺伝学/
いでんがくしゃ /遺伝学者/
いでんけん /遺伝研/
いでんし /遺伝子/
いでんしいじょう /遺伝子異常/
いでんしかいせき /遺伝子解析/
いでんしかんけい /遺伝子関係/
いでんしかんれん /遺伝子関連/
いでんしがく /遺伝子学/
いでんしがた /遺伝子型;[生物]genotype/
いでんしぎんこう /遺伝子銀行;[新語]gene bank/
いでんしくみかえ /遺伝子組み換え;「-大豆は使用していません」/遺伝子組換え;「-大豆は使用していません」/
いでんしげん /遺伝資源/
いでんしこうがく /遺伝子工学/
いでんしごうせい /遺伝子合成/
いでんしさいぼう /遺伝子細胞/
いでんしざ /遺伝子座/
いでんししっかん /遺伝子疾患/
いでんししんだん /遺伝子診断;[医]genetic diagnosis/
いでんしじょうほう /遺伝子情報/
いでんしぜんたい /遺伝子全体/
いでんしそうさ /遺伝子操作/
いでんしちりょう /遺伝子治療/
いでんしてき /遺伝子的/
いでんしはいれつ /遺伝子配列/
いでんしひょうげん /遺伝子表現/
いでんじょうほう /遺伝情報/
いでんじょうほうしょり /遺伝情報処理/
いでんせい /遺伝性/
いでんせいしっかん /遺伝性疾患/
いでんせいたいけんきゅう /遺伝生態研究/
いでんてき /遺伝的/
いでんてきえいきょう /遺伝的影響/
いでんてきげんいん /遺伝的原因/
いでんびょう /遺伝病/
いでんほうそく /遺伝法則/
いでんや /遺伝屋/
いと /糸/意図/伊都;地名,和歌山県/絲;「糸」の旧字/異図;謀反の意図/縷;細い糸/怡土;地名,福岡県/
いとーよーかどう /イトーヨーカ堂;[企業名]/
いとい /糸井/
いといがわ /糸魚川/
いといがわし /糸魚川市/
いといがわせん /糸魚川線/
いといしげさと /糸井重里/
いとう /伊藤/伊東/以東/依投/伊富魚/伊富/
いとうえん /伊藤園/
いとうお /糸魚/
いとうおんせん /伊東温泉/
いとうし /伊東市/
いとうじゃくちゅう /伊藤若冲/
いとうせん /伊東線/
いとうちゅう /伊藤忠;[企業名]/
いとうちゅうしょうじ /伊藤忠商事;[企業名]/
いとうちゅうねんりょう /伊藤忠燃料;[企業名]/
いとうはむ /伊藤ハム;[企業名]/
いとうひろぶみ /伊藤博文;1841-1909/
いとうまん /伊藤萬/
いとうや /伊東屋/
いとおり /糸織/
いとが /糸賀/
いときり /糸切り/
いときりば /糸切り歯;犬歯/糸切歯/
いとく /遺徳;「故人の-」/威徳;威厳と人徳/懿徳;優れた徳/
いとくず /糸屑/
いとくてんのう /懿徳天皇/
いとぐち /糸口/緒/
いとぐら /糸倉/
いとぐるま /糸車/
いとこ /従兄弟/従姉妹/従兄/従弟/従姉/従妹/
いとこおおおじ /従兄弟大小父/
いとこおおおば /従兄弟大小母/
いとこおじ /従兄弟小父/
いとこおば /従兄弟小母/
いとこん /糸コン/
いとこんにゃく /糸蒟蒻;シラタキ/糸こんにゃく/糸コンニャク/
いとさき /糸崎/
いとざき /糸崎/
いとざくら /糸桜/
いとしご /愛し子;beloved child/いとし子/
いとしま /糸島/
いとじり /糸尻/
いとすぎ /糸杉/
いとぞこ /糸底/
いとたけ /糸竹/
いとたに /糸谷/
いとだ /糸田/
いとちゅう /伊藤忠/
いとづくり /糸作り/
いとてき /意図的/
いとでんわ /糸電話/
いととじ /糸綴じ;[製本]/
いととんぼ /糸蜻蛉/
いとなみ /営み/
いとぬき /糸貫/
いとのこ /糸鋸/
いとのこぎり /糸鋸/
いとひきあじ /糸引鰺/
いとふめい /意図不明/
いとへん /糸偏;「綱」の偏/
いとま /暇/遑/
いとまき /糸巻/
いとまごい /暇乞い/
いとまん /糸満/
いとまんせん /糸満線/
いとめ /糸目/厭目/
いとやま /糸山/
いとゆう /糸遊/
いとよ /糸魚/
いとようじ /糸楊枝/
いとより /糸撚り/糸縒り/
いとよりだい /糸縒鯛/
いど /井戸/緯度/異土/
いどう /移動/異動;†「人事-」/異同;†difference.「諸写本の-」/医道/
いどういち /移動位置/
いどううんよう /移動運用/
いどうかいし /移動開始/
いどうかのう /移動可能/
いどうかんけい /移動関係/
いどうがた /移動型/
いどうきゃく /移動客/
いどうきょく /移動局/
いどうきょり /移動距離/
いどうきろく /移動記録/
いどうぐみ /異動組/
いどうけい /移動系/
いどうけんけつしゃ /移動献血車/
いどうご /移動後/
いどうさき /移動先/異動先/
いどうしき /移動式/
いどうしゃ /移動者/
いどうしゅだん /移動手段/
いどうじ /移動時/
いどうじかん /移動時間/
いどうじき /移動時期/
いどうせい /移動性/
いどうそうさ /移動操作/
いどうそうち /移動装置/
いどうそくど /移動速度/
いどうたい /移動体/
いどうたいじょうほう /移動体情報/
いどうたいつうしん /移動体通信/
いどうたいでんわ /移動体電話/
いどうだな /移動棚/
いどうち /移動地/
いどうちゅう /移動中/
いどうつうしん /移動通信/
いどうつうしんぎじゅつ /移動通信技術/
いどうつうしんもう /移動通信網/
いどうてじゅん /移動手順/
いどうとどけ /異動届/
いどうど /移動度/
いどうは /移動派/
いどうはば /移動幅/
いどうはん /移動班/
いどうはんい /移動範囲/
いどうひ /移動費/
いどうひょう /移動票/
いどうび /移動日/
いどうぶったい /移動物体/
いどうへいきん /移動平均/
いどうへいきんせん /移動平均線/
いどうへいきんほう /移動平均法/
いどうほうこう /移動方向/
いどうほうほう /移動方法/
いどうまえ /移動前/
いどうめいれい /移動命令/
いどうもう /移動網/
いどうもと /移動元/
いどうもんだい /移動問題/
いどうよう /移動用/
いどうりゆう /移動理由/
いどうりょう /移動量/
いどうりょく /移動力/
いどがわ /井戸川/
いどけいど /緯度経度/
いどころ /居所/拠所/
いどし /亥年;=いのししどし/
いどたい /緯度帯/
いどちゃわん /井戸茶碗;最高級/
いどばた /井戸端/
いどばたかいぎ /井戸端会議/
いどべい /井戸塀/
いどほうこう /緯度方向/
いどほり /井戸掘り/
いどみず /井戸水/
いな /否/稲/伊奈/伊那/伊南/維那;[仏教]/稻;「稲」の旧字(人名用漢字)/
いない /以内/稲井/
いなえ /稲枝/
いなお /稲尾/稲生/
いなおえき /稲生駅/
いなおおせどり /稲負鳥/
いなおか /稲岡/
いなおり /居直り/
いなおりごうとう /居直り強盗/
いなか /田舎/
いなかことば /田舎言葉/
いなかざむらい /田舎侍/
いなかしんし /田舎紳士/
いなかず /稲数/
いなかそば /田舎蕎麦/
いなかだて /田舎館/
いなかっぺ /田舎っぺ/
いなかふう /田舎風/
いなかま /田舎間;畳一枚 = 1760x880 (⇔京間 1910x960)/
いなかまち /田舎町/
いなかみち /田舎道/
いなかもの /田舎者/
いなかわ /稲川/
いながき /稲垣/
いながきたるほ /稲垣足穂;作家。『Ａ感覚とＶ感覚』/
いながけ /稲掛;姓/
いながわ /猪名川/稲川/
いなき /稲木/稲城/
いなぎ /稲城/稲木/稲置/
いなぎし /稲城市/
いなぐら /稲倉/
いなげ /稲毛/
いなげえき /稲毛駅/
いなこ /稲子/
いなこと /異な事/
いなご /蝗/
いなさ /引佐/
いなさく /稲作/
いなさくでんらい /稲作伝来/
いなさくぶんか /稲作文化/
いなさぐん /引佐郡/
いなさやま /稲佐山/
いなざわ /稲沢/
いなしき /稲敷/
いなしろ /稲城/
いなず /稲津/
いなずま /稲妻/霆/電/
いなせ /粹;「粋」の旧字(人名用漢字)/
いなたま /稲魂/
いなだ /稲田/鰍/
いなだき /頂/
いなだま /稲魂/
いなち /稲地/
いなつき /稲築/
いなつぎ /稲継;姓/
いなづ /稲津/
いなづま /稲妻/
いななが /稲永/
いななき /嘶き/
いなにわ /稲庭/
いなの /稲野/
いなば /稲葉/因幡/稲場/
いなひさ /稲久/
いなびかり /稲光/
いなぶ /稲武/
いなぶし /伊那節;[民謡]長野/
いなぶね /稲舟/
いなべ /員弁/
いなほ /稲穂/
いなみ /井波/稲美/印南/伊波/
いなみね /稲嶺/
いなむし /蝗/
いなむら /稲村/
いなもと /稲元/
いなもり /稲森/稲盛/
いなもりざいだん /稲盛財団/
いなや /否や/
いなよし /稲吉/
いなり /稲荷/
いなりこうじ /稲荷小路/
いなりしんこう /稲荷信仰/
いなりずし /稲荷鮨/
いなりだ /稲荷田/
いなりまち /稲荷町/
いなりやま /稲荷山/
いなわしろ /猪苗代/
いなわしろこ /猪苗代湖/
いなん /以南/
いにしえ /古/古え/
いにゅう /移入/
いにゅうしゅ /移入種;[生物]≒外来種/
いにょう /囲繞/遺尿/
いにょうち /囲繞地/
いにん /委任/
いにんうらがき /委任裏書/
いにんけいり /委任経理/
いにんけいりきん /委任経理金/
いにんじむ /委任事務/
いにんじょう /委任状/
いにんとうち /委任統治/
いにんとうちりょう /委任統治領/
いにんめいれい /委任命令/
いにんりっぽう /委任立法/
いぬ /犬/狗;(字義:愛玩用の小型犬)/戌;[十二支]11/
いぬい /乾/犬井/戌亥;北西/
いぬいもん /乾門/
いぬかい /犬飼/犬養/
いぬかいつよし /犬養毅;(1855-1932) 政治家/
いぬかき /犬掻き;[水泳]/犬かき/
いぬかみ /犬上/
いぬがみ /犬神/
いぬがみぐん /犬上郡/
いぬがみけ /犬神家/
いぬき /居抜き/
いぬくい /犬食い/
いぬくぼう /犬公方;徳川綱吉/
いぬぐい /犬食い/犬喰い/
いぬころ /犬ころ/
いぬごや /犬小屋/
いぬざくら /犬桜/
いぬじに /犬死に/
いぬじにん /犬神人/
いぬぞり /犬橇/犬ぞり/
いぬたで /犬蓼/
いぬちくしょう /犬畜生/
いぬっころ /犬っころ/
いぬつか /犬塚/
いぬどし /戌年/
いぬなき /犬鳴/
いぬにく /犬肉/
いぬねこ /犬猫/
いぬのふぐり /犬の陰嚢;[植物]/
いぬは /犬派/
いぬばしり /犬走り;[建築]建物の外周の地面を固める/犬走/
いぬぶえ /犬笛/
いぬぶし /犬伏/
いぬぼう /犬棒/
いぬぼうさき /犬吠崎/犬吠埼/
いぬぼうざき /犬吠埼/
いぬまる /犬丸/
いぬめ /犬目/
いぬやま /犬山/
いぬやまし /犬山市/
いぬやまじょう /犬山城/
いぬやまばし /犬山橋/
いぬよう /犬用/
いね /稲/稻/伊根/禾/
いねか /イネ科/稲科/
いねかり /稲刈り/稲刈/
いねだ /稲田/
いねちょう /伊根町/
いねなが /稲永/
いねの /稲野/
いねみつ /稲光/
いねむり /居眠り/
いねむりうんてん /居眠り運転/
いねもく /イネ目/Glumiflorae/Graminales/Poales/
いねん /為念/
いねんごう /異年号/
いの /猪/伊野/井野/猪野/
いのいちばん /いの一番/
いのう /異能/伊能;人名/稲生/衣嚢/
いのうえ /井上/井之上/
いのうえてつじろう /井上哲次郎/
いのうえやすし /井上靖;(1907-1991)作家。『しろばんば』/
いのうえようすい /井上陽水/
いのうただたか /伊能忠敬/
いのおか /猪岡/
いのかしら /井の頭/
いのかしらこうえん /井の頭公園/
いのかしらせん /井の頭線/
いのがしら /井の頭/
いのがしらこうえん /井の頭公園/
いのき /猪木/
いのくち /井口/
いのくま /猪熊/
いのぐち /井ノ口/井口/
いのこ /猪の子/豕/
いのこずち /牛膝/
いのこへん /豕偏/
いのこり /居残り/
いのさか /猪坂/
いのしかちょう /猪鹿蝶/
いのしし /猪/亥;[十二支]12/豕/猯;(まみ)/
いのししどし /亥年/
いのししなべ /猪鍋/
いのした /井下/
いのせ /猪瀬/
いのだ /伊野田/
いのち /命/生命;(当て字)/
いのちからがら /命辛々/命辛辛/
いのちがけ /命懸け/命がけ/
いのちごい /命乞い/
いのちしらず /命知らず/
いのちづな /命綱/
いのちとり /命取り/
いのちのつな /命の綱/
いのちびろい /命拾い/
いのなか /井の中/
いのはら /猪原/
いのふ /胃の腑/
いのぶた /猪豚/
いのべ /井ノ部/
いのま /猪摩/
いのまた /猪俣/猪股/
いのまま /意のまま/
いのめ /猪の目/
いのめげぎょ /猪の目懸魚/
いのり /祈り/祷/
いのる /祷/
いは /伊波/
いはい /位牌/違背/
いはく /威迫/医博/曰く/
いはつ /遺髪/衣鉢/
いはら /井原/伊原/庵原/
いはらさいかく /井原西鶴;(1642-93)浮世草子作者。『好色一代男』/
いはらだ /居原田/
いはん /違反/違犯;法に背き、罪を犯す/
いはんきっぷ /違反切符;-を切られる/
いはんこうい /違反行為/
いはんしゃ /違反者/違反車;「-のレッカー移動」/
いはんしゃりょう /違反車両/
いはんじじつ /違反事実/
いはんないよう /違反内容/
いば /射場/伊庭/井場/
いばく /帷幕/
いばしょ /居場所/
いばしんえん /意馬心猿/
いばら /茨/棘/荊/井原/
いばらき /茨城;-県/茨木;大阪府-市/
いばらきけん /茨城県/
いばらきてん /茨木店/
いばらきべん /茨城弁/
いばらぎ /茨城;※いばらき/
いばらぎえき /茨木駅;※いばらき/
いばらぎけん /茨城県;※いばらき/
いばらぎけんない /茨城県内;※いばらき/
いばらぎけんほくぶ /茨城県北部;※いばらき/
いばらぎけんみん /茨城県民;※いばらき/
いばらぎし /茨木市;※いばらきし/
いばらぎだいがく /茨城大学;※いばらき/
いばらぎてん /茨木店;※いばらき/
いばらぎほうそう /茨城放送;※いばらき/
いばらのみち /茨の道/
いばらももく /イバラモ目/Najadales/
いばり /尿/
いばん /異版/
いひょう /意表/依憑/違表;?/
いひょうき /異表記/
いひん /遺品/
いび /揖斐;地名/萎靡;萎縮/威部;沖縄の聖地・神/依微;かすか/
いびがわ /揖斐川/
いびき /鼾/
いびしゃ /居飛車/
いびつ /歪/飯櫃/
いびつなり /飯櫃形/
いびょう /胃病/
いふ /畏怖/異父/委付/依附/
いふ> /異父;-[兄弟姉妹]/
いふう /威風;-堂々/遺風;relic/異風;変わった風習/
いふうどうどう /威風堂々/威風堂堂/
いふきょうだい /異父兄弟/
いふく /衣服/異腹/威服/
いふくべ /伊福部/
いふごう /異符号/
いふしん /畏怖心/
いぶ /慰撫/威武/伊武/ＥＶＥ/
いぶか /井深/
いぶき /息吹;「春の-」/伊吹;[植物]chinese juniper/
いぶきやま /伊吹山/
いぶくろ /胃袋/
いぶしぎん /燻し銀/
いぶすき /指宿/
いぶすきおんせん /指宿温泉/
いぶすきせん /指宿線/
いぶすきまくらざきせん /指宿枕崎線/
いぶせ /井伏/
いぶせますじ /井伏鱒二;作家。『山椒魚』/
いぶつ /異物;-が混入する/遺物;過去の-/
いぶつかん /異物感/
いぶり /胆振/
いぶん /異文;variant.「-の註記」/異聞;珍しい話。「-録」/遺文;遺した文。「聖人の-」/遺聞;知られぬ話/
いぶんか /異文化/
いぶんかりかい /異文化理解/
いぶんし /異分子/
いぷしろん /ε;epsilon/Ε;Epsilon/
いぷしろんせんい /ε遷移/
いへき /胃壁/
いへや /伊平屋/
いへん /異変/韋編/
いへんさんぜつ /韋編三絶/
いべ /伊部/井部/
いべんとれつ /イベント列/
いほう /違法/異邦;alien/彙報;報告の取り集め/移封/異方;-性(anisotropy)/遺芳;後世に遺る業績・書跡/遺法;ancient law/異法;異なる法。「-地域」/
いほうかいぞう /違法改造/
いほうかいぞうしゃ /違法改造車/
いほうきょく /違法局/
いほうけんちく /違法建築/
いほうこうい /違法行為/
いほうこぴー /違法コピー/
いほうし /違法視/
いほうじょうたい /違法状態/
いほうじん /異邦人/
いほうせい /違法性;illegality/異方性;anisotropy.「光学-」/
いほうせいそきゃく /違法性阻却/
いほうたい /異方体/
いほうちゅうしゃ /違法駐車/
いほうちゅうしゃしゃりょう /違法駐車車両/
いほうは /違法派/
いほうひん /違法品/
いほうろん /違法論/
いほく /以北/
いほん /異本/
いぼ /異母/疣;wart/揖保;地名,兵庫県/肬;≒疣/贅;<rare> ≒疣/
いぼ> /異母;-[兄弟姉妹]/
いぼう /威望/依傍/
いぼがわ /揖保川/
いぼきょうだい /異母兄弟/
いぼく /遺墨/
いぼじ /疣痔/
いぼだい /疣鯛/
いま /今/居間/
いまい /今井/
いまいけ /今池/
いまいじょう /今以上/
いまいずみ /今泉/
いまいち /今一/今市;地名,栃木/今イチ/
いまいちど /今一度/
いまいちばん /今一番/
いまいっぽ /今一歩/
いまいで /今出/
いまいま /今今/
いまいみき /今井美樹/
いまおか /今岡/
いまかがみ /今鏡;作品名/
いまかれ /今彼;[口]今の彼氏/
いまがね /今金/
いまがわ /今川/
いまがわやき /今川焼/
いまき /今来/
いまげんざい /今現在/
いまこまち /今小町/
いまころ /今頃/
いまごろ /今頃/今ごろ/
いまさき /今崎/
いまさっき /今さっき/
いまさと /今里/
いまさら /今更/今さら/
いまし /汝/
いましがた /今し方/今しがた/
いましばらく /今暫く/
いましま /今嶋/
いましめ /戒め;warning.「師の-」/縛め;bondage.「-を解く」/誡め;=戒め/警め;≒戒め/
いまじぶん /今時分/
いまじょう /今庄/今城/
いますこし /今少し/
いまず /今津/
いまずせん /今津線/
いまぜき /今関/
いまだ /未だ/未/今田/
いまだかつて /未だ嘗て/
いまだて /今立/
いまだに /未だに/
いまち /井街/
いまちづき /居待月/
いまづ /今津/
いまづえき /今津駅/
いまづかん /今津間/
いまづほうめん /今津方面/
いまで /今出/
いまでがわ /今出川/
いまでがわどおり /今出川通り/
いまど /今戸/
いまどうしん /今道心/
いまどき /今時/今どき/
いまなお /今尚;even now/今なお/今猶/
いまなか /今中/今仲/
いまなが /今永/
いまに /今仁/
いまにし /今西/
いまにしきんじ /今西錦司/
いまはし /今橋/
いまはん /今半/
いまばやし /今林/
いまばり /今治/
いまひと /今仁/
いまひとつ /今一つ/
いまふう /今風/
いまふく /今福/
いまふじ /今藤;姓/
いまべっぷ /今別府/
いまべつ /今別/
いままで /今迄/今まで/
いまみち /今道/
いまみや /今宮/
いまむら /今村/
いまむらさき /今紫/
いまもって /今以て/
いまものがたり /今物語/
いまや /今や/
いまやま /今山/
いまよう /今様/
いまよういろ /今様色/
いまよううた /今様歌/
いまよし /今吉/
いまり /伊万里/
いまりやき /伊万里焼/
いまりゅう /今流/
いまる /井丸/
いまわ /今際/
いまわだい /今話題/
いまわの /忌野/
いまわのきわ /今際の際/
いみ /意味/
いみあい /意味合い/意味合/
いみあけ /忌明け/忌み明け/
いみかいしゃく /意味解釈/
いみかいせき /意味解析/
いみき /忌寸/
いみきじゅつ /意味記述/
いみきそく /意味規則/
いみげんご /意味言語/
いみこうぞう /意味構造/
いみことば /忌み言葉/忌み詞/忌言葉/
いみさよう /意味作用/
いみしょり /意味処理/
いみしん /意味深/
いみしんちょう /意味深長/
いみじょう /意味上/
いみず /射水/
いみそ /意味素;seme/
いみちしき /意味知識/
いみづけ /意味付け/
いみてき /意味的/
いみな /諱/
いみないよう /意味内容/
いみなし /意味無/
いみび /忌日/斎日;縁起の悪い日/忌み日/
いみふめい /意味不明/
いみふめいりょう /意味不明瞭/
いみめいりょう /意味明瞭/
いみもの /斎物/忌物/忌み物/
いみや /井宮/
いみょう /異名/
いみりょういき /意味領域/
いみろん /意味論/
いみろんてき /意味論的/
いみん /移民/
いみんきょく /移民局/
いみんぞく /異民族/
いむ /医務/異夢/諱/
いむしつ /医務室/
いむた /伊牟田/
いむちょう /医務長/
いむら /井村/
いむらや /井村屋/
いむらやせいか /井村屋製菓/
いめ /夢/
いめーじけんさく /イメージ検索/
いめい /異名/依命/遺命/威名/違名;異名の誤り?/
いも /芋/薯/藷/妹/
いもあらし /芋嵐/
いもあん /芋餡/芋あん/
いもうと /妹/
いもうとふうふ /妹夫婦/
いもうとぶん /妹分/
いもうとむこ /妹婿/
いもうとやく /妹役/
いもお /妹尾;せのお?/
いもかけどうふ /芋掛け豆腐/芋掛豆腐/
いもかわ /芋川/
いもかわうどん /芋川饂飩/
いもがい /芋貝/
いもがしら /芋頭/
いもがま /芋竈/
いもがゆ /芋粥/
いもがら /芋茎/芋幹/
いもざし /芋刺し/
いもじ /鋳物師/湯文字/
いもじょうちゅう /芋焼酎/藷焼酎/
いもじる /芋汁/
いもすけ /芋助/
いもせ /妹背/
いもたれ /胃もたれ/
いもだい /芋台/
いもちびょう /稲熱病/
いもちゃしゃく /芋茶杓/
いもつぎ /芋継ぎ/
いもづる /芋蔓/
いもづるしき /芋蔓式/芋づる式/
いもでんがく /芋田楽/
いもと /井本/井元/妹/
いもなっとう /芋納豆/
いもに /芋煮/
いもにかい /芋煮会/
いもになべ /芋煮鍋/
いもの /鋳物/
いものこ /芋の子;-を洗うよう/
いものし /鋳物師/
いもはぎ /芋接ぎ/
いもばん /芋版/
いもびな /芋雛/
いもほり /芋掘り/藷掘り/
いもぼう /芋棒/
いもむし /芋虫/
いもむしはぐるま /芋虫歯車/
いもめいげつ /芋名月/
いもめし /芋飯/
いもめじ /芋目地/
いももと /芋本/
いもようかん /芋羊羹/
いもり /井守/井森;人名/
いもるい /芋類/
いもん /慰問/
いや /嫌/厭/祖谷;地名/弥/彌;「弥」の旧字(人名用漢字)/否/
いやいとこ /弥従兄弟/弥従姉妹/
いやいや /嫌々;-引き受ける/否々;No,no./嫌嫌/否否/
いやおう /否応/
いやがうえにも /弥が上にも/
いやがおう /否が応/
いやがらせ /嫌がらせ/
いやき /嫌気/
いやく /医薬/意訳/違約/依約/
いやくきん /違約金/
いやくひん /医薬品/
いやくぶがいひん /医薬部外品/
いやくぶんぎょう /医薬分業/
いやけ /嫌気/
いやけい /祖谷渓/
いやし /癒し/鄙/癒やし/
いやしくも /苟も/
いやしけい /癒し系;[新語]和む雰囲気の人やモノ/
いやして /癒し手/
いやち /忌地;[園芸]連作障害/
いやちこ /灼然/
いやなが /彌永/
いやま /井山/
いやみ /嫌味/嫌み/厭味/厭み/
いゆう /畏友/
いよ /伊予/伊代/壱与/
いよいよ /愈々/愈/
いよう /異様/医用/威容/偉容/
いようがぞう /医用画像/
いようこうがく /医用工学/
いようこうぶんし /医用高分子/
いようせいみつこうがく /医用精密工学/
いよかん /伊予柑/
いよく /意欲/
いよくさく /意欲作/
いよくてき /意欲的/
いよこ /伊代子/
いよし /伊予市/
いよじ /五代嗣/
いよたに /伊豫谷/
いよだ /伊與田/
いよてつ /伊予鉄/
いよてつどう /伊予鉄道/
いよぶし /伊予節;[民謡]/
いよべん /伊予弁/
いよほうしょ /伊予奉書/
いよほうじょう /伊予北条/
いよみしま /伊予三島/
いら /苛/
いらい /以来/依頼/
いらいげんこう /依頼原稿/
いらいしゃ /依頼者/
いらいしょ /依頼書/
いらいしん /依頼心/
いらいじょう /依頼状/
いらいせい /依頼制/
いらいたいしょく /依頼退職/
いらいちゅう /依頼中/
いらいにん /依頼人/
いらいぬし /依頼主/
いらいひょう /依頼票/
いらいひん /依頼品/
いらいもと /依頼元/
いらいら /苛々/苛苛/
いらいらかん /苛々感/イライラ感/
いらえ /答え/応え/
いらか /甍/
いらくぐん /イラク軍/
いらくさ /蕁麻/刺草/
いらくさもく /イラクサ目/Urticales/
いらくさもくあぐん /イラクサ目亜群/
いらくじん /イラク人/
いらくせんそう /イラク戦争;[時事]2003年4月、米英軍がイラクに侵攻して起きた戦争/
いらこ /伊良湖;=いらご/
いらここう /伊良湖港;(いらごこう?)/
いらこみさき /伊良湖岬;=いらごみさき/
いらご /伊良湖;地名,愛知県・渥美半島/
いらごみさき /伊良湖岬;地名/
いらだち /苛立ち/
いらつ /苛つ/
いらつこ /郎子/
いらつめ /郎女/
いらぶ /伊良部/
いらべ /伊良部/
いらぼ /伊羅保/
いらん /伊蘭;Iran/
いらんいらくせんそう /イランイラク戦争/
いらんくう /囲卵腔/
いらんじん /イラン人/
いり /入り/入/圦;水門/杁;=圦/伊理/炒り/熬り;≒炒り (字義:「炒」は軽くいためる、「熬」は強烈にいりつける)/
いりあい /入会/入相/
いりあいけん /入会権/
いりあいち /入会地/
いりうち /入内/
いりうちじま /入内島/
いりうみ /入海/
いりえ /入江/入り江/
いりおもて /西表/
いりおもてじま /西表島/
いりおもてやまねこ /西表山猫/
いりかさやま /入笠山/
いりがい /入貝/
いりがた /入り方/
いりき /入来/
いりくち /入り口/
いりくり /入り繰り/
いりぐち /入口/入り口/
いりぐちがわ /入口側/
いりぐちふきん /入口付近/
いりぐちわき /入口脇/
いりこ /海参/炒り粉/煎り粉/熬海鼠;=海参/熬り子;≒煮干し/
いりごめ /炒り米/煎り米/
いりさ /入佐/
いりさく /入作;(受け入れ側から見た)小作/
いりさわ /入澤/
いりざけ /煎り酒/
いりしお /入潮/
いりじうむ /Ir/Iridium/
いりすみ /入隅/入角;=入隅/
いりた /入田/
いりたはま /入田浜/
いりたまご /炒り卵/炒り玉子/煎り卵/
いりどうふ /炒り豆腐/煎り豆腐/
いりなか /杁中/
いりの /入野/
いりはま /入り浜/入浜;-式塩田/
いりひ /入り日/
いりふね /入船/入り船/
いりべ /入部/
いりぼし /熬り干し/
いりまじり /入交/
いりまち /入り待ち/
いりまめ /炒り豆/煎豆/
いりむこ /入り婿/
いりもや /入母屋/
いりもやづくり /入母屋造り/入母屋造/
いりもやはふ /入母屋破風;[建築]/
いりや /入谷/
いりやま /入山/
いりゅう /慰留/移流/遺留;-品/
いりゅうぎり /移流霧/
いりゅうひん /遺留品/
いりゅうぶん /遺留分/
いりょう /医療/衣料/衣糧;衣料と食糧/
いりょういがい /医療以外/
いりょういっぱん /医療一般/
いりょうかご /医療過誤/
いりょうかつどう /医療活動/
いりょうかんけい /医療関係/
いりょうかんけいしゃ /医療関係者/
いりょうきかん /医療機関/
いりょうきき /医療機器/
いりょうきぐ /医療器具/
いりょうぎじゅつ /医療技術/
いりょうぎょうせい /医療行政/
いりょうけい /医療系/
いりょうけいむしょ /医療刑務所/
いりょうげんば /医療現場/
いりょうこうい /医療行為/
いりょうこうがく /医療工学/
いりょうさいばん /医療裁判/
いりょうしせつ /医療施設/
いりょうしょうねんいん /医療少年院/
いりょうしょち /医療処置/
いりょうしんだん /医療診断/
いりょうじこ /医療事故/
いりょうじゅうじしゃ /医療従事者/
いりょうせいど /医療制度/
いりょうせいひん /衣料製品/医療製品/
いりょうせん /医療船/
いりょうそうだん /医療相談/
いりょうそうだんまどぐち /医療相談窓口/
いりょうたんきだいがく /医療短期大学/
いりょうたんきだいがくぶ /医療短期大学部/
いりょうだんたい /医療団体/
いりょうちーむ /医療チーム/
いりょうてんすう /医療点数/
いりょうとくやく /医療特約/
いりょうはいきぶつ /医療廃棄物/
いりょうひ /医療費/
いりょうひぜんたい /医療費全体/
いりょうひふたん /医療費負担/
いりょうひん /衣料品/医療品/
いりょうひんてん /衣料品店/
いりょうふくし /医療福祉/
いりょうふたん /医療負担/
いりょうぶ /医療部/
いりょうほう /医療法/
いりょうほうしゅう /医療報酬/
いりょうほうじん /医療法人/
いりょうほけん /医療保険/
いりょうほけんせいど /医療保険制度/
いりょうみす /医療ミス/
いりょうもくてき /医療目的/
いりょうもんだい /医療問題/
いりょうよう /医療用/
いりょく /威力;power/偉力;great power/意力;will/
いりょくぎょうむぼうがい /威力業務妨害/
いりよう /入用/入り用/
いりわけ /入り訳/
いるい /衣類/異類/彙類/
いるいこんいんたん /異類婚姻譚/
いるか /海豚/鯆;=海豚 NB:「さば」とも/
いるかざ /海豚座;Delphinus(Del)/
いるかせ /忽/
いるす /居留守/
いるま /入間/
いるまがわ /入間川/
いるまし /入間市/
いれ /入れ/
いれい /異例/慰霊/威令/違例/
いれいさい /慰霊祭/
いれいひ /慰霊碑/
いれかえ /入れ替え/入替/入れ換え/入換/
いれかえせい /入れ替え制/入替制/
いれかえせん /入れ替え戦/入替戦/
いれかえよう /入換用/
いれかた /入れ方/淹れ方/
いれかわり /入れ替わり/入れ代わり/
いれかわりたちかわり /入れ替わり立ち替わり/
いれき /入木/
いれぐい /入れ食い;-状態/
いれこ /入れ子/入籠/
いれこみ /入れ込み/入込/
いれこみすう /入込数/
いれさく /入れ作/
いれずみ /入れ墨/刺青/文身/
いれたて /入れ立て/
いれちがい /入れ違い/
いれぢえ /入れ知恵/
いれつ /イ列/い列/威烈/
いれば /入れ歯/入歯/
いれふだ /入れ札/
いれぼくろ /入れ黒子/
いれもの /入れ物/容れ物/
いろ /色/艷;(つや)/
いろあい /色合い/色合/色相;?/
いろあく /色悪/
いろあげ /色揚げ/
いろあわせ /色合わせ/色合せ/
いろいがい /色以外/
いろいと /色糸/
いろいろ /色々/色色/色いろ/
いろう /慰労/遺漏/胃瘻/
いろうかい /慰労会/
いろうきん /慰労金/
いろうざき /石廊崎/
いろうつり /色移り/
いろえ /色絵/
いろえんぴつ /色鉛筆/
いろおち /色落ち/
いろおとこ /色男/
いろおび /色帯/
いろおんど /色温度/
いろおんな /色女/
いろか /色香/
いろかず /色数/
いろかわ /色川/
いろかんけい /色関係/
いろがたき /色敵/
いろがみ /色紙/
いろがら /色柄/
いろがらす /色ガラス;stained glass/
いろがわり /色変り/
いろきちがい /色気違い/
いろきろく /色記録/
いろくうかん /色空間/
いろくさ /色草/
いろくず /鱗/
いろぐすり /色釉/
いろぐるい /色狂い/
いろぐろ /色黒/
いろけ /色気/
いろこ /色子/
いろこい /色恋/
いろこいざた /色恋沙汰/
いろこう /色校/
いろこうせい /色校正/
いろごと /色事/
いろごとし /色事師/
いろごのみ /色好み/
いろさいげん /色再現/
いろさいげんせい /色再現性/
いろざと /色里/
いろざんげ /色懺悔/
いろしすう /色指数;[天文][地学]Colour Index(CI)/
いろしてい /色指定/
いろしゅうさ /色収差/
いろしんごう /色信号/
いろじかけ /色仕掛け/
いろじょうほう /色情報/
いろじろ /色白/
いろすう /色数/
いろずり /色刷り/色刷/
いろたいおう /色対応/
いろだま /色玉;柘榴/
いろちがい /色違い/
いろつき /色付き/
いろつや /色艶/
いろづかい /色使い/色遣い/
いろづけ /色付け/色付/
いろとりどり /色取り取り/
いろどめ /色止め;塩水に浸し-する/
いろどり /彩/彩り/色取り/色鳥/
いろなおし /色直し/
いろね /色音/
いろは /伊呂波/以呂波/
いろはいち /色配置/
いろはうた /伊呂波歌/
いろはじゅん /伊呂波順/
いろはじるいしょう /色葉字類抄/
いろはんてん /色反転/
いろばんごう /色番号/
いろひょうじ /色表示/
いろふごう /色符号/
いろふん /色粉/
いろぶみ /色文/
いろぶんかい /色分解/
いろほうしき /色方式/
いろほせい /色補正/
いろぼうしょ /色奉書/
いろぼけ /色ボケ/
いろまち /色町/色街/
いろみ /色見/
いろみほん /色見本/
いろむら /色斑/
いろめ /色目/
いろめい /色名/
いろめがね /色眼鏡/
いろもの /色物/
いろり /囲炉裏/鑪/鈩/
いろりったい /色立体;[色彩学]colour solid. HSBを座標化/
いろりばた /囲炉裏端/
いろわけ /色分け/色分/
いろん /異論/
いろんな /色んな/
いわ /岩/違和/磐/巖/
いわあな /岩穴/
いわい /祝/祝い/岩井/磐井/岩韋/
いわいうた /祝い唄/祝い歌/祝歌/祝唄/頌/
いわいごと /祝い事/祝事/
いわいざけ /祝い酒/祝酒/
いわいずみ /岩泉/
いわいはら /岩井原/
いわいべどき /祝部土器/
いわうち /岩内/
いわうめもく /Diapensiales/イワウメ目/
いわえのぐ /岩絵具/岩絵の具/
いわお /巌/巖;旧字/岩男/岩尾/岩夫/磐/岩雄/岩生/
いわおおじ /岩大路/
いわおか /岩岡/
いわかげ /岩陰/
いわかど /岩角/
いわかべ /岩壁/
いわかみ /岩上/
いわかめ /岩亀/
いわかわ /岩川/
いわかん /違和感/
いわがき /岩牡蠣/
いわがに /岩蟹/
いわき /岩城/磐城/岩木/岩鬼/
いわきさん /岩木山/
いわきじ /磐城路/
いわきり /岩切/
いわぎ /岩城/
いわく /曰く/曰/
いわくいんねん /曰く因縁/
いわくつき /曰く付き;-の物件/
いわくに /岩国/
いわくま /岩熊/
いわくら /岩倉/岩鞍/
いわくらともみ /岩倉具視/
いわぐみ /岩組/岩組み/
いわぐんじょう /岩群青;blue verditer/
いわさ /岩佐/
いわさき /岩崎/
いわさききょうこ /岩崎恭子/
いわさきしょてん /岩崎書店;[出版社名]/
いわさきつうしん /岩崎通信/
いわさきでんき /岩崎電気/
いわさわ /岩沢/
いわし /鰯/鰮/鰛/
いわしぐも /鰯雲/
いわした /岩下/
いわしたしま /岩下志麻/
いわしみず /岩清水/
いわしみずはちまんぐう /石清水八幡宮/
いわしみずものがたり /石清水物語/
いわしみづ /岩清水/
いわしろ /岩代/岩城/
いわずもがな /言わずもがな/
いわせ /岩瀬/石瀬/
いわた /岩田/磐田/
いわたき /岩滝/
いわたけ /岩岳/岩茸/
いわたし /磐田市/
いわたしみんぶんかかいかん /磐田市民文化会館/
いわたに /岩谷/
いわたや /岩田屋/
いわだけ /岩岳/
いわだたみ /岩畳;長瀞の- (ながとろ.天然記念物)/
いわだな /岩棚/
いわだぬき /岩狸/
いわつう /岩通/
いわつか /岩塚/
いわつき /岩槻/岩月/
いわつばめ /岩燕/
いわつぼ /岩壺/
いわて /岩手/
いわてけん /岩手県/
いわてけんみんかいかん /岩手県民会館/
いわてこうげん /岩手高原/
いわてだいがく /岩手大学/
いわてほうそう /岩手放送/
いわてんじょう /岩天井/
いわで /岩出/
いわでやま /岩出山/
いわと /岩戸/磐戸/石門/
いわとくせん /岩徳線/
いわとけいき /岩戸景気/
いわど /岩戸/
いわな /岩魚/
いわない /岩内/
いわないこう /岩内港/
いわなみ /岩波;-書店/岩浪/
いわなみえき /岩波駅/
いわなみこうざ /岩波講座/
いわなみこくごじてん /岩波国語辞典/
いわなみしょてん /岩波書店;[出版社名]/
いわなみしんしょ /岩波新書/
いわなみすうがくじてん /岩波数学辞典/
いわなみぜんしょ /岩波全書/
いわなみばん /岩波版/
いわなみぶんこ /岩波文庫/
いわなみぶんこばん /岩波文庫版/
いわなみやく /岩波訳/
いわにちせん /岩日線/
いわぬま /岩沼/
いわぬまし /岩沼市/
いわぬまや /岩沼屋/
いわね /岩根/
いわの /岩野/
いわのり /岩海苔/
いわはし /岩橋/
いわはだ /岩肌/
いわはな /岩鼻/岩端;=岩鼻/
いわはら /岩原/
いわば /岩場/言わば/謂わば/
いわばやし /岩林/
いわひろ /岩廣/
いわふじ /岩藤/
いわふね /岩船/岩舟/
いわぶえ /石笛/
いわぶき /岩蕗/
いわぶち /岩渕/岩淵/
いわぶろ /岩風呂/
いわほり /岩堀/
いわま /岩間/
いわまつ /岩松/
いわみ /石見/岩美/岩見/
いわみさわ /岩見沢/
いわみざわ /岩見沢/
いわみず /岩水/
いわみだ /岩見田/
いわみね /岩峰/
いわむら /岩村/
いわむろ /岩室/石室/
いわめ /岩女魚/岩女/
いわもと /岩本/
いわや /岩屋/窟/石屋/岩谷/巌谷/
いわやま /岩山/
いわゆる /所謂/
いわれ /謂れ/
いわんや /況んや/
いん /印/韻/員/院/陰;陰性/隠;隠者/因/殷;中国の王朝(BC16c-BC11c)/慇;慇懃/淫;淫乱/婬;≒淫/霪;ながあめ/咽;咽喉/姻;婚姻/氤/茵;しとね/飲;飲食/飮;「飲」の旧字/引;引力/蚓;蚯蚓/音;母音/韵;「韻」の異体字/隕;隕石/殞;おちる/湮;証拠湮滅/堙;≒湮/胤;落胤/尹/寅;(十二支の)とら/蔭;かげ/允/廴;(えんにょう)/贇;(うつくしい)/酳/隱;「隠」の旧字/
いん> /印;[略語]インド.-パ,-哲/陰;陰部,陰音階,陰関数 ⇔陽/
いんあつ /印圧/
いんい /陰萎/因依/
いんいおん /陰イオン/
いんいつ /隠逸/淫逸/淫佚;=淫逸/
いんいん /殷々/
いんいんめつめつ /陰々滅々/陰陰滅滅/
いんう /淫雨/
いんうつ /陰鬱/
いんえい /陰影/印影/陰翳/
いんおう /印欧/
いんおうご /印欧語/
いんおうごぞく /印欧語族;[言語]Indo-European/
いんおうそご /印欧祖語/
いんおんかい /陰音階/
いんか /引火/印加;†impress.「電圧-」/印可;†(師の)承認/印花;†[陶芸]/陰火;≒鬼火/允可;聞き届ける/陰窩/
いんかか /隠花果/
いんかく /陰核/
いんかしょくぶつ /隠花植物/
いんかせい /引火性/
いんかていこく /インカ帝国/
いんかてん /引火点/
いんかでんあつ /印加電圧/
いんかふ /印花布/
いんかぶんめい /インカ文明/
いんかろん /因果論/
いんかん /印鑑/殷鑑;-遠からず/隠閑/
いんかんしょうめい /印鑑証明/
いんかんしょうめいなど /印鑑証明等/
いんかんすう /陰関数/
いんかんとうろく /印鑑登録/
いんかんや /印鑑屋/
いんが /因果/印画/陰画/
いんがい /院外/員外/
いんがいしょほうせん /院外処方箋/
いんがおうほう /因果応報/
いんがかんけい /因果関係/
いんがし /印画紙/
いんがしじょう /印画紙上/
いんがじょう /印画上/
いんがせい /因果性/
いんがてき /因果的/
いんがほうそく /因果法則/
いんがもの /因果者/
いんがものがたり /因果物語/
いんがりつ /因果律/
いんき /陰気/印記/
いんきょ /隠居/允許/殷墟/
いんきょう /印僑;華僑のインド人版/韻鏡/
いんきょく /陰極/
いんきょくかん /陰極管/
いんきょくせん /陰極線/
いんきょくせんかん /陰極線管;CRT/
いんきょせいかつ /隠居生活/
いんきょもじ /殷墟文字/
いんきん /印金/陰金/引磬;和楽器/
いんきんたむし /陰金田虫/
いんぎ /院議/
いんぎゃく /淫虐/
いんぎょう /印形/隠形/
いんぎょうてんのう /允恭天皇/
いんぎん /慇懃/
いんぎんぶれい /慇懃無礼/
いんくぎれ /インク切れ/
いんくつぼ /インク壺;ink pot/
いんぐ /淫具/
いんぐらんど /英蘭/
いんぐらんどぎんこう /イングランド銀行;Bank of England(BOE) NB:世界最古の銀行/
いんけい /陰茎/
いんけん /陰険/引見/隠顕/隠見;=隠顕/
いんげ /院家/
いんげん /隠元/
いんげんまめ /隠元豆/
いんこ /鸚哥/
いんこう /咽喉/淫行/印行/淫荒/
いんこく /陰刻/印刻/
いんご /隠語/淫語;[新語]卑猥な隠語/韻語/
いんごう /院号/因業/引業/
いんさいだーとりひき /インサイダー取引/
いんさつ /印刷/
いんさついち /印刷位置/
いんさつかのうもじ /印刷可能文字/
いんさつがいしゃ /印刷会社/
いんさつき /印刷機/
いんさつきのう /印刷機能/
いんさつきょく /印刷局/
いんさつぎじゅつ /印刷技術/
いんさつぎょう /印刷業/
いんさつぎょうかい /印刷業界/
いんさつけいしき /印刷形式/
いんさつけいひ /印刷経費/
いんさつけっか /印刷結果/
いんさつげんこう /印刷原稿/
いんさつしつ /印刷室/
いんさつしゅっぱん /印刷出版/
いんさつしゅつりょく /印刷出力/
いんさつしょ /印刷所/
いんさつじ /印刷時/
いんさつじゅつ /印刷術/
いんさつじょ /印刷所/
いんさつそうち /印刷装置/
いんさつそくど /印刷速度/
いんさつたい /印刷体/
いんさつたいしょう /印刷対象/
いんさつだい /印刷代/
いんさつちゅう /印刷中/
いんさつはいせん /印刷配線;[電子]printed wiring. cf.プリント基板/
いんさつはんい /印刷範囲/
いんさつばいたい /印刷媒体/
いんさつひ /印刷費/
いんさつひょうじゅんじたい /印刷標準字体/
いんさつぶすう /印刷部数/
いんさつぶつ /印刷物/
いんさつほうほう /印刷方法/
いんさつぼん /印刷本/
いんさつまいすう /印刷枚数/
いんさつもじ /印刷文字/
いんさつや /印刷屋/
いんさつよう /印刷用/
いんさつようげんこう /印刷用原稿/
いんさつようご /印刷用語/
いんさつようし /印刷用紙/
いんさん /陰惨/
いんざい /印材/印西;地名/
いんし /因子/印紙/院試/淫祠;邪神のやしろ/淫祀;邪神を祭る/
いんしか /因子化/
いんしぜい /印紙税/
いんしだい /印紙代/
いんしつ /陰湿/
いんしぶんせき /因子分析/
いんしぶんせきほう /因子分析法/
いんしゅ /飲酒/
いんしゅう /因習/因襲;≒因習/因州;因幡/隠州;隠岐/
いんしゅうてき /因習的/因襲的/
いんしゅうんてん /飲酒運転/
いんしゅきんし /飲酒禁止/
いんしゅりつ /飲酒率/
いんしょ /印書/引書;引用書/韻書/淫書/音書/
いんしょう /印象/印章;はんこ/引証;cite/引照;refer/陰証/
いんしょうしゅぎ /印象主義/
いんしょうてき /印象的/
いんしょうど /印象度/
いんしょうは /印象派/
いんしょうひひょう /印象批評;impressionistic criticism/
いんしょく /飲食/
いんしょくぎょう /飲食業/
いんしょくだい /飲食代/
いんしょくてん /飲食店/
いんしょくてんがい /飲食店街/
いんしょくひ /飲食費/
いんしょくぶつ /飲食物/
いんしん /陰唇/殷賑/
いんじ /印字/印璽/韻字/
いんじいち /印字位置/
いんじうむ /In/Indium/
いんじかのう /印字可能/
いんじき /印字機/
いんじけっか /印字結果/
いんじしゅつりょく /印字出力/
いんじそくど /印字速度/
いんじのうど /印字濃度/
いんじはば /印字幅/
いんじひんしつ /印字品質/
いんじほうしき /印字方式/
いんじみつど /印字密度/
いんじめい /印字名/
いんじゃ /隠者/
いんじゅ /院主/印綬/
いんじゅう /陰獣/
いんじゅん /因循/
いんじゅんこそく /因循姑息/
いんじょ /淫女/
いんじょう /引接/引摂/
いんじれい /印字例/
いんすい /引水;我田-/飲水/淫水;愛液/
いんすう /員数;メンバー数/因数;factor/引数;NB:電算用語としては「ひきすう」が一般的/
いんすうていり /因数定理/
いんすうぶんかい /因数分解/
いんすうれつ /引数列/
いんずう /員数/
いんせい /院生/陰性/院政;上皇・法皇による政治/隠棲/隠栖;=隠棲/隕星/
いんせいけんきゅうしつ /院生研究室/
いんせいしつ /院生室/
いんせいはんのう /陰性反応/
いんせき /隕石/引責/姻戚/殞石;=隕石/
いんせきかんけい /姻戚関係/
いんせきじにん /引責辞任/
いんせつ /引接/
いんせん /陰線;shade line. 陰を表す線/隠線;hidden line. 陰に隠れる線/
いんせんしょり /陰線処理/
いんせんぽう /陰旋法/
いんぜい /印税/
いんぜいしゅうにゅう /印税収入/
いんぜいせいかつ /印税生活/
いんぜみ /院ゼミ/
いんぜん /隠然/院宣/
いんそう /印相/
いんそつ /引率/院卒/
いんそつきょうし /引率教師/
いんそつしゃ /引率者/
いんぞう /印相/
いんぞく /姻族/
いんたい /引退/隠退/院体/
いんたいあいさつ /引退挨拶/
いんたいご /引退後/
いんたいしき /引退式/
いんたいじ /引退時/
いんたいじあい /引退試合/
いんたいずもう /引退相撲/
いんたいせつ /引退説/
いんたいせんげん /引退宣言/
いんたいひょうめい /引退表明/
いんたいまえ /引退前/
いんだすぶんめい /インダス文明;Indus/
いんち /吋/引致/韻致/
いんちょう /院長/院庁/
いんちん /影青/
いんてい /陰梃/
いんてつ /隕鉄/
いんてん /院展/
いんでぃあんざ /インディアン座;Indus(Ind)/
いんでぃかまい /インディカ米;長粒種/
いんでんき /陰電気/
いんでんし /陰電子/
いんとう /咽頭/淫蕩/
いんとうえん /咽頭炎/
いんとうかじょ /隠頭花序/
いんとうけつまくねつ /咽頭結膜熱;[医]pharyngoconjunctival fever(PCF)/
いんとうへき /咽頭壁/
いんとく /隠匿/
いんとくざい /隠匿罪/
いんとん /隠遁/
いんど /印度/
いんどう /引導/陰道/犬童;姓/
いんどこうろ /インド航路;[世界史]欧州→喜望峰→印度/
いんどしな /印度支那/
いんどじん /印度人/インド人/
いんどぞう /インド象;indian elephant/
いんどてつがく /インド哲学/
いんどねしあご /インドネシア語/
いんどよーろっぱごぞく /インドヨーロッパ語族;[言語]Indo-European/
いんどよう /インド洋/
いんどりょうり /インド料理/
いんどわた /インド綿/
いんない /院内/印内/
いんないかんせん /院内感染/
いんなみ /印南/
いんに /因位/陰に/
いんにく /印肉/
いんにゅうし /院入試/
いんにょう /飲尿/廴繞;[部首]/
いんにん /隠忍/
いんにんじちょう /隠忍自重/
いんねん /因縁/
いんのう /陰嚢/
いんのしま /因島/
いんのしょう /院庄/
いんば /印旛/
いんばい /淫売/
いんばぐん /印旛郡/
いんばぬま /印旛沼/
いんばん /印判/
いんぱ /印パ;India-Pakistan/院派/
いんぱるすおうとう /インパルス応答/
いんび /淫靡/隠微/韻尾/
いんびさ /淫靡さ/
いんびせん /因美線/
いんぴ /隠避/隠秘/
いんふらせいび /インフラ整備/
いんぶ /陰部/
いんぶん /韻文/陰文;⇔陽文/
いんぷ /印譜/淫婦/殷富/陰阜/
いんぷく /隠伏/
いんべん /員弁/
いんぺい /隠蔽/
いんぺいかん /隠蔽艦/
いんぺいこうさく /隠蔽工作/
いんぺいし /隠蔽子/
いんぺいしょく /隠蔽色;保護色など/
いんぺいたいしつ /隠蔽体質/
いんぺいりょく /隠蔽力/
いんぼ /韻母/
いんぼう /陰謀/
いんぼうせつ /陰謀説/
いんぼうろん /陰謀論/
いんぽん /院本/印本/淫奔/淫本/
いんみょう /因明/
いんむ /淫夢/
いんめい /因明/
いんめつ /隠滅/湮滅/堙滅;証拠-/
いんめん /印面/隠面/
いんめんしょうきょ /隠面消去/
いんめんちょうしょ /員面調書/
いんもう /陰毛/
いんもん /陰門/陰文;=いんぶん/
いんゆ /隠喩;[修辞]metaphor/引喩;[修辞]allusion/
いんゆてき /隠喩的/
いんゆぶん /隠喩文/
いんゆほう /隠喩法/
いんよう /引用/飲用/陰陽/
いんよういがい /引用以外/
いんようか /陰陽家/引用可/
いんようかいし /引用開始/
いんようきごう /引用記号/
いんようきじ /引用記事/
いんようきょか /引用許可/
いんようぎょう /引用行/
いんようごぎょうせつ /陰陽五行説/
いんようさんしょう /引用参照/
いんようし /引用始/
いんようしゅうりょう /引用終了/
いんようしょ /引用書/
いんようじ /引用時/
いんようじゅん /引用順/
いんようすい /飲用水/
いんようちゅう /引用中/
いんようふ /引用符/
いんようふか /引用不可/
いんようぶ /引用部/
いんようぶぶん /引用部分/
いんようぶん /引用文/
いんようぶんけん /引用文献/
いんようぶんちゅう /引用文中/
いんようほうほう /引用方法/
いんようもと /引用元/
いんようれい /引用例/
いんよく /淫欲/
いんらく /淫楽/
いんらん /淫乱/
いんりつ /韻律/
いんりつろん /韻律論;prosody/
いんりょう /飲料/
いんりょうすい /飲料水/
いんりょうよう /飲料用/
いんりょく /引力/
いんりょくけん /引力圏/
いんれい /引例/
いんれき /陰暦/
いんれつ /陰裂/
いんろう /印籠/印篭/
いんわい /淫猥/
う /雨/右/得/鵜/有/卯;[十二支](4)うさぎ/羽;羽毛/挧;(くぬぎ)/于/宇;宇宙/迂;迂回/紆;紆余曲折/盂;盂蘭盆/芋;いも/兎;うさぎ/禹;古代中国の聖王/齲;(むしば)/傴;傴僂/嫗;おうな/烏;烏合/生/夘;「卯」の異体字/饂;饂飩/憂/胡;(唐音) こ/菟;?/
う> /右/
うーかーぴーちゅー /五加皮酒/
うーはん /武漢/
うーろん /烏龍/
うーろんちゃ /烏龍茶/ウーロン茶/
うぃ /ゐ/ヰ/
うぃーん /維納;Wien/
うぃーんがくだん /ウィーン学団;Wiener Kreis/
うぃり /干莉/
うい /初/有為/宇井;姓/
ういきょう /茴香/
ういぐるご /ウイグル語/
ういこうぶり /初冠;[文語]元服/
ういご /初子/
ういざん /初産/
ういじん /初陣/
ういち /宇一/
ういてんぺん /有為転変/
ういまご /初孫/
ういむじょう /有為無常/
ういるすせいかんえん /ウイルス性肝炎;[医]viral hepatitis/
ういるすびょう /ウイルス病/
ういろう /外郎/
ういろううり /外郎売/外郎売り/
ういろうまめ /外郎豆/
ううろんちゃ /烏龍茶/
うぇ /ゑ/ヱ/
うぇぶじょう /ウェブ上/
うぇるたーきゅう /ウェルター級/
うえ /上/飢え/植/↑/
うえ> /上;上半分,上寄り/
うええだ /上枝/
うえおか /植岡/
うえがはら /上ヶ原/
うえがめん /上画面/
うえがわ /上側/
うえき /植木/植え木/
うえきぐみ /植木組/
うえきざん /植木算/
うえきばち /植木鉢/植え木鉢/
うえきや /植木屋/
うえくさ /植草/
うえくぼ /上窪/
うえこみ /植え込み/植込み/植込/
うえさか /上坂/
うえさま /上様/
うえさんかく /上三角/
うえさんかくぎょうれつ /上三角行列/
うえしき /上式/
うえした /上下/
うえしば /植芝/
うえしま /上島/
うえじ /植字/
うえじに /飢え死に/餓え死に/餓死/
うえじま /上島/
うえす /上江洲/上須/
うえすぎ /上杉/
うえすぎけんしん /上杉謙信/
うえすぎてるとら /上杉輝虎/
うえすぎまさとら /上杉政虎/
うえぞの /上園/
うえた /植田/
うえたけ /植竹/
うえたに /上谷/
うえだ /上田/植田/
うえだあきなり /上田秋成/
うえだし /上田市/
うえちゅうだん /上中段/
うえつ /羽越/
うえつかた /上つ方/
うえつき /上付き/
うえつけ /植付け/植え付け/
うえつせん /羽越線/
うえつほんせん /羽越本線/
うえづけ /上付/
うえなか /植中/
うえにし /上西/
うえの /上野/植野/
うえのあおもりかん /上野青森間/
うえのえき /上野駅/
うえのえきまえてん /上野駅前店/
うえのおのこ /上の男;殿上人のこと/
うえのかん /上野間/
うえのがくえん /上野学園/
うえのぐち /上野口/
うえのこうえん /上野公園/
うえのし /上野市/
うえのせんそう /上野戦争;1868/
うえのちゃく /上野着/
うえのてん /上野店/
うえのどうぶつえん /上野動物園/
うえのはつ /上野発/
うえのはら /上野原/
うえのひろこうじ /上野広小路/
うえはま /上浜/
うえはら /上原/植原/
うえはらせい /上原成/
うえはんぶん /上半分/
うえひら /植平/
うえびと /上人;殿上人/
うえほうこう /上方向/
うえほんまち /上本町/
うえほんまちろくちょうめ /上本町六丁目/
うえまち /上町/
うえまつ /植松/上松/
うえむき /上向き/
うえむら /上村/植村/
うえもと /植本/
うえもり /上森/
うえもん /右衛門/
うえもんのかみ /右衛門督;[律令制]/
うえもんのじょう /右衛門尉/
うえもんふ /右衛門府;[律令制]/
うえや /↑/上矢/
うえやじるし /上矢印/
うえやま /上山/
うえろく /上本町六丁目;「うえほんまちろくちょうめ」の通り名 ※abbrev/
うえわらわ /上童/
うえん /有縁/迂遠/
うぉーるがい /ウォール街/
うお /魚/宇夫/
うおい /魚井/
うおいちば /魚市場/
うおうさおう /右往左往/
うおかす /魚滓/
うおがし /魚河岸/
うおごころ /魚心/
うおざ /魚座;Pisces(Psc),(2.19-3.20)/
うおざき /魚崎/
うおざききたちょう /魚崎北町/
うおざききたまち /魚崎北町/
うおしま /魚島/
うおしまどき /魚島時/
うおじょうゆ /魚醤油/
うおすき /魚鋤/
うおずみ /魚住/
うおせ /魚瀬/
うおぜっきょう /魚説経/
うおぜっぽう /魚説法/
うおそうめん /魚素麺/
うおたか /魚鷹/
うおだな /魚店/
うおつか /魚塚/
うおつきりん /魚付き林/
うおつり /魚釣り/
うおづ /魚津/
うおづし /魚津市/
うおに /魚荷/
うおにかわ /魚膠/
うおぬま /魚沼/
うおぬまさん /魚沼産/
うおのがわ /魚野川/
うおのめ /魚の目/
うおびしお /魚醤/
うおへん /魚偏/
うおみ /魚見/
うおみそ /魚味噌/
うおみつ /魚光/
うおや /魚屋/
うおんず /雨温図/
うおんびん /ウ音便/
うか /羽化/雨下/
うかい /迂回/鵜飼/鵜飼い/有界;[仏教]/
うかいうんてん /迂回運転/
うかいろ /迂回路/
うかいろせん /迂回路線/
うかがい /伺/伺い/窺;?/
うかがいしょ /伺い書/伺書/
うかじ /宇梶/
うかつ /迂闊/迂濶;「闊」異体字/
うかとうせん /羽化登仙/
うかぬかお /浮かぬ顔/
うかのみたま /稲魂/
うかみ /斥候/窺見/
うから /親族/
うかれ /浮かれ/
うかれめ /浮かれ女/
うかわ /鵜川/
うかん /有漢/
うかんむり /ウ冠/
うがい /嗽/鵜飼/
うがいぐすり /うがい薬/嗽薬/
うがき /宇垣/
うがく /有学/
うがちすぎ /穿ち過ぎ/
うがん /右岸/右眼/烏丸/烏桓/
うき /右記/雨季/雨期/浮き;釣り道具/浮/浮子/泛子/憂き/
うき> /浮/
うきあし /浮き足;-立つ/浮足/
うきいし /浮石/浮き石/
うきうお /浮き魚/浮魚/
うきうき /浮き浮き/
うきえ /浮江/
うきおり /浮織/
うきがや /浮ヶ谷/
うきくさ /浮草/浮き草/萍/
うきくさかぎょう /浮き草稼業/浮草稼業/
うきくさるい /浮草類/
うきぐ /浮具/
うきぐも /浮雲/
うきごし /浮腰/浮き腰/
うきさんばし /浮桟橋/
うきしずみ /浮き沈み/
うきしま /浮島/浮き島/
うきしろものがたり /浮城物語/
うきす /浮巣/
うきせいこう /雨奇晴好/
うきた /浮田/
うきだま /浮き玉/
うきつ /浮津/
うきどっく /浮ドック/浮きドック;floating dock/
うきな /浮名/浮き名/
うきはし /浮橋/浮き橋/
うきばし /浮橋/
うきふね /浮舟/浮船/
うきぶくろ /浮き袋/浮袋/鰾/
うきぼり /浮き彫り/浮彫/浮彫り/
うきみ /浮き身;†「プールで-」/浮身/浮き実;†「スープの-」/憂き身;†「-を窶す」/
うきめ /憂き目/
うきょう /右京/
うきょうしき /右京職;[律令制]朱雀大路東側の行政担当/
うきょうのだいぶ /右京大夫;[律令制]右京職の長官/
うきょく /迂曲/
うきよ /浮世/浮き世/憂き世/
うきよえ /浮世絵/
うきよえびじゅつかん /浮世絵美術館/
うきよことば /浮世言葉/
うきよぞうし /浮世草子;[文学]/
うきよばなれ /浮世離れ/浮き世離れ/
うきよぶろ /浮世風呂;式亭三馬/
うきよぼん /浮世本/
うきよものがたり /浮世物語/
うきわ /浮き輪/浮輪/
うぎょう /ウ行/う行/
うく /宇久/
うくらいな /烏克蘭/
うぐ /迂愚/
うぐい /鯏/石斑魚/
うぐいす /鶯/鴬;異体字/
うぐいすいろ /鶯色/
うぐいすざわ /鶯沢/鴬沢;異体字/
うぐいすじょう /鶯嬢/ウグイス嬢/
うぐいすだに /鴬谷/
うぐいすだにえき /鶯谷駅/
うぐいすちゃ /鶯茶/
うぐいすな /鶯菜/
うぐいすばり /鶯張り/
うぐいすぶえ /鶯笛/
うぐいすもち /鶯餅/
うぐら /葎/
うけ /有卦/食/槽/筌/受/受け/請け/
うけあい /請け合い/受け合い/請合い/受合い/
うけい /右傾/誓約/
うけいれ /受け入れ/受入/受入れ/
うけいれたいせい /受け入れ態勢/受入れ態勢/
うけうり /受け売り/受売り/請け売り/請売り/
うけおい /請負/
うけおいぎょう /請負業/
うけおいぎょうしゃ /請負業者/
うけおいにん /請負人/
うけかた /受け方/
うけがわ /受け側/
うけぎ /受け木;[建築]/
うけくち /受け口/
うけぐち /受け口/受口/
うけこたえ /受け答え/
うけごし /受け腰/
うけざら /受け皿/
うけしょ /請書/受書/
うけつけ /受付/受け付け/受付け/
うけつけかいし /受付開始/
うけつけきかん /受付期間/
うけつけきげん /受付期限/
うけつけじかん /受付時間/
うけつけじょう /受付嬢/
うけつけちゅう /受付中/
うけつけねんがっぴ /受付年月日/
うけつけばんごう /受付番号/
うけつけび /受付日/
うけて /受け手/受手/
うけとり /受取/受け取り/受取り;receipt/
うけとりかた /受け取り方/
うけとりかのう /受取可能/
うけとりかんじょう /受取勘定/
うけとりがわ /受け取り側/受取側/
うけとりきょひ /受取拒否/
うけとりご /受取後/
うけとりしょ /受取書/
うけとりしょうしょ /受取証書/
うけとりて /受け取り手/
うけとりてがた /受取手形/
うけとりにん /受取人/
うけとりりそく /受取利息/
うけにぬし /受荷主/
うけにん /請人/
うけのみたま /稲魂/
うけはらい /受払/受払い/受け払い/
うけばこ /受箱/受け箱/凵/
うけばらい /受け払い/受払/
うけぶみ /請文/
うけみ /受け身/受身/
うけもち /受け持ち/受持ち/
うけやど /請宿;口入れ屋/
うけら /朮/
うけわたし /受け渡し/受渡/受渡し/
うけわたしほうほう /受渡方法/
うけん /宇検/
うげつ /雨月/
うげつものがたり /雨月物語/
うげん /右舷/迂言/
うこう /宇高/
うこうけん /宇航研/
うこうこくどう /宇高国道/
うこうこつ /烏口骨/
うこうれんらくせん /宇高連絡船/
うこぎ /五加;[植物]aralia/五加木/
うこさべん /右顧左眄/
うこっけい /烏骨鶏;天然記念物/
うこん /右近;⇔左近/鬱金;turmeric/
うこんいろ /鬱金色/
うご /雨後/羽後/
うごう /烏合/
うごうのしゅう /烏合の衆/
うごき /動き/
うさ /宇佐/右左/憂さ/
うさがわ /宇佐川/
うさぎ /兎/卯;[十二支]4/兔;「兎」の異体字/菟;≒兎/莵;「菟」の異体字/
うさぎうま /兎馬;ロバ/驢/
うさぎがり /兎狩り/
うさぎごや /兎小屋/ウサギ小屋/
うさぎざ /兎座;Lepus(Lep)/
うさぎだいら /兎平/
うさぎとび /兎跳び/兎飛び/
うさぎどし /卯年/
うさせつ /右左折/
うさせつしゃ /右左折車/
うさばらし /憂さ晴らし/
うさみ /宇佐美/宇佐見/宇沙美/
うさわ /宇沢/
うさん /胡散/
うさんくさい /胡散臭い/
うざき /宇崎/
うざく /鰻ざく;[料理]鰻とキュウリの三杯酢和え/
うざわ /鵜沢/鵜澤/宇沢/宇澤;姓/
うし /牛/丑;[十二支]2/齲歯;むしば/
うしお /潮/牛尾/
うしおい /牛追い/
うしおいうた /牛追い唄/
うしおしゅっぱん /潮出版;[出版社名]/
うしおしゅっぱんしゃ /潮出版社;[出版社名]/
うしおじる /潮汁/
うしおだ /潮田/
うしおでんき /ウシオ電機;[企業名]/
うしおに /牛鬼/
うしかい /牛飼い/牛飼/
うしかいざ /牛飼い座;Bootes(Boo)/牛飼座;Bootes(Boo)/
うしかいめんじょうのうしょう /牛海綿状脳症;[時事]bovine spongiform encephalopathy(BSE),狂牛病/
うしがえる /牛蛙/
うしき /牛木/
うしく /牛久/
うしくぬま /牛久沼/
うしごめ /牛込/
うしごめやなぎちょう /牛込柳町/
うしごや /牛小屋/
うしじま /牛島/牛嶋/
うしじろう /牛次郎/
うした /牛田/
うしづ /牛津/
うしとら /艮/丑寅;北東/
うしどし /丑年/
うしね /牛根/
うしの /牛野/
うしのこく /丑の刻/
うしのこくまいり /丑の刻参り/
うしのひ /丑の日/
うしばえ /牛蠅/
うしぶか /牛深/
うしへん /牛偏/
うしぼり /牛堀/
うしまど /牛窓/
うしまる /牛丸/
うしみつ /丑三つ/
うしみつどき /丑三つ時;午前三時頃。「草木も眠る-」/丑三つ刻/
うしや /牛屋/
うしゅう /羽州;出羽/
うしゅうかいどう /羽州街道;奥州街道-羽州-青森/
うしょう /鵜匠/右相/羽觴/有生/有性/
うしょうべん /右少弁/
うしらん /烏糸欄/
うしろ /後ろ/後/
うしろあし /後ろ足/
うしろあわせ /後ろ合せ/
うしろおし /後ろ押し/
うしろかげ /後ろ影/
うしろかわ /後川/
うしろがみ /後ろ髪/後髪/
うしろがわ /後側/
うしろきず /後ろ傷;不名誉/後ろ疵/
うしろざま /後ろ方/後ろ様;-に倒れる/
うしろすがた /後ろ姿/後姿/
うしろだて /後ろ盾/後ろ楯;=後ろ盾/後立/後ろだて/
うしろで /後ろ手/
うしろはんぶん /後半分/
うしろほうこう /後方向/
うしろまえ /後ろ前/
うしろまわしげり /後ろ廻し蹴り/
うしろみ /後見/後ろ身/
うしろみごろ /後ろ身頃/
うしろむき /後ろ向き/後向き/
うしろめ /後目/
うしろゆび /後ろ指/
うしわかまる /牛若丸/
うしわた /牛渡/
うしん /有心/
うしんしつ /右心室/
うしんてい /有心体/
うしんふぜん /右心不全/
うしんぼう /右心房/
うじ /氏/宇治/蛆/
うじい /雲林院/
うじいえ /氏家/
うじかばね /氏姓/
うじがみ /氏神/
うじがわ /宇治川/
うじきんとき /宇治金時/
うじこ /氏子/
うじさと /氏郷/
うじし /宇治市/
うじしゅういものがたり /宇治拾遺物語/
うじじゅうじょう /宇治十帖;『源氏物語』末尾の十帖/
うじすじょう /氏素性/氏素姓/
うじせん /宇治線/
うじだいなごんものがたり /宇治大納言物語;現存せず/
うじちゃ /宇治茶/
うじでら /氏寺/
うじな /宇品/
うじはら /氏原/
うじばし /宇治橋/
うじびと /氏人/
うじふさ /氏房/
うじむし /蛆虫/ウジ虫/
うじやま /宇治山/
うじやまだ /宇治山田/
うじょう /有情/羽状/鵜匠/雨上/
うじょうしょう /右丞相;右大臣/
うじょうふくよう /羽状複葉/
うじょうみゃく /羽状脈/
うす /臼/薄/碓;足で搗くウス/有珠;地名,北海道/舂;臼で搗くこと/
うす> /薄;薄暗がり,薄明(か)り,薄商い/
うすあお /薄青/淡青/
うすあおいろ /薄青色/
うすあかり /薄明かり/薄明り/
うすあきない /薄商い/
うすあげ /薄揚げ/
うすあじ /薄味/
うすい /雨水;([二十四節気]2.19頃)/臼井/碓氷/碓井/薄井/
うすいえき /臼井駅/
うすいこう /雨水溝/
うすいた /薄板/
うすいとうげ /碓氷峠/
うすいまち /碓井町/
うすいろ /薄色/
うすうす /薄々/薄薄/
うすかべ /薄壁/
うすかわ /薄皮/
うすがすみ /薄霞/
うすがた /薄型/
うすがたか /薄型化/
うすがみ /薄紙/
うすき /臼杵;地名/薄/
うすきいろ /薄黄色/
うすきし /臼杵市/
うすきみ /薄気味/
うすぎ /薄着/
うすぎぬ /薄衣/薄絹/
うすぎり /薄切り/薄霧/
うすくち /薄口/
うすくちしょうゆ /薄口醤油/淡口醤油/
うすくらがり /薄暗がり/
うすくれない /薄紅/
うすぐも /薄雲/
うすぐもり /薄曇/薄曇り/うす曇り/
うすげ /薄毛;-を気にする/
うすげしょう /薄化粧/
うすこうばい /薄紅梅/
うすごおり /薄氷/
うすごろも /薄衣/
うすざいしき /薄彩色/
うすざん /有珠山/
うすじ /薄地/
うすじお /薄塩/
うすずみ /薄墨/
うすずみいろ /薄墨色/
うすずみがみ /薄墨紙/
うすた /薄田/
うすだ /臼田/
うすだいこ /臼太鼓/
うすだたみ /薄畳;春夏用/
うすちゃ /薄茶/
うすちゃいろ /薄茶色/
うすっぺら /薄っぺら/
うすづき /薄月/
うすづきよ /薄月夜/
うすづくり /薄造り/薄作り/
うすで /薄手/
うすにく /薄肉/
うすにごり /薄濁り/
うすぬり /薄塗り;-のファンデーション/薄塗/
うすねず /薄鼠/
うすのろ /薄鈍/
うすはないろ /薄花色/
うすはなざくら /薄花桜/
うすはなだ /薄縹/
うすば /薄刃/薄葉/
うすばかげろう /薄羽蜉蝣/
うすび /薄日/
うすびょう /護田鳥尾/
うすべお /護田鳥尾/
うすべに /薄紅/
うすべにいろ /薄紅色/
うすべり /薄縁/
うすぼんやり /薄ぼんやり/
うすまく /薄膜/
うすみどり /薄緑/
うすみどりいろ /薄緑色/
うすむらさき /薄紫/
うすむらさきいろ /薄紫色/
うすめ /薄目/薄め/
うすめえき /薄め液/
うすもの /薄物/羅/
うすももいろ /薄桃色/
うすもよう /薄模様/
うすやき /薄焼き/薄焼;-煎餅/
うすやみ /薄闇/
うすゆき /薄雪/
うすゆきものがたり /薄雪物語/
うすよう /薄葉/薄様/
うすようし /薄葉紙/
うすら /薄ら/
うすらばか /薄ら馬鹿/
うすらひ /薄ら氷/
うすらわらい /薄ら笑い/
うすわらい /薄笑い/
うず /渦/右図/烏頭/
うずい /渦位/
うずき /疼き/宇津木/
うずくまる /踞/蹲/
うずしお /渦潮/
うずでんりゅう /渦電流/
うずど /渦度/
うずどほうていしき /渦度方程式/
うずの /鶉野/
うずば /渦場/
うずべくご /ウズベク語/
うずまき /渦巻/渦巻き/
うずまきぎんが /渦巻銀河/渦巻き銀河/
うずまきもよう /渦巻模様/
うずまさ /太秦/
うずみび /埋み火/
うずむし /渦虫/
うずむしるい /渦虫類/
うずゆそう /渦輸送/
うずら /鶉/
うずらいし /鶉石/
うずらたまご /鶉卵/うずら卵/
うずらの /鶉野/
うせい /迂生/
うせつ /右折/雨雪/
うせつさせつ /右折左折/
うせつしゃ /右折車/
うせつしゃせん /右折車線/
うせつやじるし /右折矢印/
うせつやじるししんごう /右折矢印信号/
うせもの /失せ物/
うせんけい /右線形/
うせんせい /右旋性/
うぜん /羽前/
うぜんちとせ /羽前千歳/
うそ /嘘/鷽;[鳥]bullfinch/嘯;口笛/獺;かわうそ/
うそいつわり /嘘偽り/
うそうそ /嘘々/
うそく /右側/
うそさむ /うそ寒/
うそじ /嘘字/
うそっぱち /嘘っぱち/嘘っ八;(当て字)/
うそつき /嘘吐き/嘘つき/
うそなき /嘘泣き/
うそはっけんき /嘘発見器/嘘発見機/
うそはっぴゃく /嘘八百/
うそふき /嘯/
うそぶえ /嘯笛/
うぞうむぞう /有象無象/
うた /歌/唄/詩/謌;「歌」の異体字/宇田;人名/謳/
うたあわせ /歌合/
うたい /謡/謠/
うたいかた /歌い方/
うたいがい /歌以外/
うたいぞめ /謡初/
うたいて /歌い手/
うたいぼん /謡本/
うたいめ /歌い女/
うたいもの /歌い物;⇔語り物/謡い物;⇔語り物/
うたいもんく /謳い文句/歌い文句/謡い文句/謳文句/歌文句/
うたいり /歌入り/
うたいれ /歌入れ/
うたうたい /歌唄い/歌歌い/
うたうら /歌占/
うたえもん /歌右衛門/
うたかい /歌会/
うたかいはじめ /歌会始/
うたかた /泡沫/
うたがい /疑い/
うたがいなく /疑い無く/
うたがいれい /疑い例/
うたがき /歌垣/
うたがっせん /歌合戦/
うたがわ /歌川/宇田川/
うたがわくによし /歌川国芳/
うたがわひろしげ /歌川広重/
うたぎれ /歌切/
うたぐち /歌口/
うたげ /宴/讌;=宴/
うたこ /詩子/歌子/
うたことば /歌詞/
うたごえ /歌声/
うたごえきっさ /歌声喫茶;客が合唱する/
うたごころ /歌心/
うたしない /歌志内/
うたしろ /歌代/
うたせゆ /打たせ湯/
うたた /転/
うたたね /うたた寝/転寝/転た寝/
うただ /宇多田;姓/
うたつ /歌津/宇多津/
うたつえき /宇多津駅/
うたづ /宇多津/
うたづかさ /雅楽寮;[律令制]/
うたて /転/
うたの /菟田野/歌野/宇多野/
うたのかみ /雅楽頭/
うたのつかさ /雅楽寮;[律令制]/
うたのやまい /歌の病;和歌で、避けるべき欠点/
うたばん /歌伴/
うたばんぐみ /歌番組/
うたひめ /歌姫/
うたひめでんせつ /歌姫伝説/
うたびと /歌人/
うたほん /歌本/
うたまい /歌舞/
うたまいのつかさ /楽官;[律令制]/雅楽寮/
うたまくら /歌枕/
うたまる /歌丸;芸名/
うたまろ /歌麿/
うたもの /歌物/唄物;-の演目/
うたものがたり /歌物語/
うたよ /歌代/詩代/
うたよみ /歌詠み/
うたん /右端/
うだ /宇田/宇陀/
うだい /宇大/宇内/
うだいしょう /右大将/
うだいじん /右大臣/
うだいべん /右大弁/
うだがわ /宇田川/
うだがわちょう /宇田川町/
うだち /卯建/
うだつ /卯建/
うだてんのう /宇多天皇/
うだん /ウ段/
うち /内/打ち/家/中/鬱/欝/裡/
うち> /内;内金,内風呂,内巻き/
うちあい /打ち合い/
うちあけばなし /打ち明け話/
うちあげ /打ち上げ/打上げ;launch/内揚げ;[服飾]/内揚;[服飾]/内上げ;内金/
うちあげはなび /打ち上げ花火/打上花火/打上げ花火/
うちあみ /打網/打ち網/
うちあわせ /打ち合わせ/打合せ/打ち合せ/
うちい /内井/
うちいけ /内池/
うちいで /打出/
うちいり /討ち入り/討入り/内入り/
うちいわい /内祝/内祝い/
うちうち /内々/
うちうみ /内海/
うちうら /内浦/内裏/
うちかぎ /内鍵/
うちかけ /打掛/打ち掛け/打掛け/裲襠/
うちかた /打ち方/内方/内潟/
うちかわ /内川/
うちかんだ /内神田/
うちがけ /内掛け/
うちがし /打ち菓子/打菓子/
うちがた /内型/
うちがたな /打刀/打ち刀/
うちがま /内釜/
うちがわ /内側/
うちき /内気/内木/
うちきず /打ち傷/打傷/
うちきば /内木場/
うちきり /打ち切り/打切り/打切/
うちきん /内金/
うちぎ /袿/
うちぎぬ /打衣/
うちくび /打ち首/打首/
うちぐるま /内車/
うちけし /打ち消し/打消し/
うちげいこ /内稽古;⇔出稽古/
うちげば /内ゲバ/
うちげんかん /内玄関/
うちこ /打ち粉/内子;地名/打粉/
うちこし /打越/
うちこば /内木場/
うちこみ /打ち込み/
うちこわし /打ち毀し/
うちごろ /打ち頃/
うちさいわい /内幸/
うちさいわいちょう /内幸町/
うちさぶらい /内侍/
うちざた /内沙汰/
うちじに /討死/討ち死に/討死に/
うちじゅう /家中/
うちぜい /内税/
うちそで /内袖/
うちた /打田/
うちだ /内田/
うちだゆき /内田有紀/
うちだようこう /内田洋行/
うちだんねつ /内断熱/
うちだんねつこうほう /内断熱工法;[建築]/
うちちがい /打違い/
うちっぱなし /打ちっ放し/
うちつくに /内つ国/
うちづま /内妻/
うちづら /内面/
うちて /打ち手/討手/打手/
うちで /打ち出/打出/
うちでし /内弟子/
うちでのこづち /打ち出の小槌/打出の小槌/
うちとびら /内扉/
うちど /内戸/
うちどい /内樋/
うちどころ /打ち所/
うちどめ /打ち止め/打止め/打止/
うちなかはら /内中原/
うちなだ /内灘/
うちにわ /内庭/
うちぬき /打ち抜き/打抜き/打抜/
うちねこ /内猫/
うちの /内野/
うちのうら /内之浦/
うちのみ /内海/
うちのり /内法/内のり/
うちのりなげし /内法長押;[建築]/
うちはし /内橋;姓/
うちはちもんじ /内八文字/
うちはなし /打放し/打ち放し/
うちはら /内原/
うちばば /内馬場/
うちばらい /内払い/
うちばり /内張り/梁/
うちひとり /内一人/
うちひょうじ /内表示/
うちひら /内平/
うちびらき /内開き/
うちふづめ /打歩詰め/
うちぶ /打歩;premium. 「-公債,-発行」/
うちぶくろ /内袋/
うちぶた /内蓋/
うちぶろ /内風呂/
うちべんけい /内弁慶/
うちぼう /内房/
うちぼうせん /内房線/
うちぼうせんそが /内房線蘇我/
うちぼり /内堀/内濠/内壕/
うちぽけっと /内ポケット;財布を入れます/
うちまき /内巻き;髪型/内巻/
うちまく /内幕/
うちまご /内孫/
うちまた /内股/
うちまたごうやく /内股膏薬/
うちまちがい /打ち間違い/
うちまど /内窓/
うちまわり /内回り/
うちみ /打ち身/打見/
うちみず /打ち水/
うちみや /内宮/
うちむき /内向き/
うちむそう /内無双/
うちむら /内村/
うちむらかんぞう /内村鑑三/
うちもうこ /内蒙古/
うちもと /内一/
うちもの /打ち物/打物/
うちもも /内股/内腿/
うちやま /内山/
うちやまだ /内山田/
うちゅう /宇宙/雨中/
うちゅういがく /宇宙医学;astromedicine/
うちゅういち /宇宙一/
うちゅうえいゆう /宇宙英雄/
うちゅうかいぞく /宇宙海賊/
うちゅうかいはつ /宇宙開発/
うちゅうかいはつけいかく /宇宙開発計画/
うちゅうかいはつじぎょうだん /宇宙開発事業団/
うちゅうかいぶつ /宇宙怪物/
うちゅうかがく /宇宙科学/
うちゅうかがくけんきゅうじょ /宇宙科学研究所/
うちゅうかぞく /宇宙家族/
うちゅうかん /右中間/宇宙観/
うちゅうかんきょう /宇宙環境/
うちゅうがく /宇宙学/
うちゅうきち /宇宙基地/
うちゅうきぼ /宇宙規模/
うちゅうきょく /宇宙局/
うちゅうくうかん /宇宙空間/
うちゅうくうぼ /宇宙空母/
うちゅうぐん /宇宙軍/
うちゅうけん /宇宙研/
うちゅうげんしょう /宇宙現象/
うちゅうげんり /宇宙原理/
うちゅうこう /宇宙項/
うちゅうこうがく /宇宙工学/
うちゅうこうくうけんきゅうかいはつきこう /宇宙航空研究開発機構;JAXA/
うちゅうしょく /宇宙食/
うちゅうしょくみんち /宇宙植民地/
うちゅうじっけん /宇宙実験/
うちゅうじょうほう /宇宙情報/
うちゅうじょうやく /宇宙条約;Space Treaty(1967)/
うちゅうじん /宇宙人/宇宙塵/
うちゅうすてーしょん /宇宙ステーション;space station/
うちゅうせん /宇宙船;starship/宇宙線;cosmic rays/宇宙戦;space war/
うちゅうせんかん /宇宙戦艦/
うちゅうせんかんそくじょ /宇宙線観測所/
うちゅうせんそう /宇宙戦争/
うちゅうせんとう /宇宙戦闘/
うちゅうせんとうき /宇宙戦闘機/
うちゅうせんない /宇宙船内/
うちゅうぜんたい /宇宙全体/
うちゅうそうせい /宇宙創成/
うちゅうそくど /宇宙速度/
うちゅうたんさ /宇宙探査/
うちゅうたんさき /宇宙探査機;space probe/
うちゅうつうしん /宇宙通信/
うちゅうてい /宇宙艇/
うちゅうていおう /宇宙帝王/
うちゅうていすう /宇宙定数/
うちゅうてき /宇宙的/
うちゅうとし /宇宙都市/
うちゅうねんだいき /宇宙年代記/
うちゅうはいけいほうしゃ /宇宙背景放射;cosmic background radiation/
うちゅうひこう /宇宙飛行/
うちゅうひこうし /宇宙飛行士/
うちゅうふく /宇宙服/
うちゅうぶつり /宇宙物理/
うちゅうぶつりがく /宇宙物理学;astrophysics/
うちゅうべん /右中弁/
うちゅうぼうえんきょう /宇宙望遠鏡/
うちゅうゆうえい /宇宙遊泳/
うちゅうよう /宇宙用/
うちゅうりょこう /宇宙旅行/
うちゅうれき /宇宙暦/
うちゅうろん /宇宙論/
うちゆ /内湯/
うちょうてん /有頂天/
うちょうてんがい /有頂天外/
うちょく /右直/
うちょくじこ /右直事故/
うちら /内良/
うちわ /内輪/団扇/
うちわうけ /内輪受け/内輪受/
うちわく /内枠/
うちわけ /内訳/
うちわけしょ /内訳書/
うちわたし /内渡し/
うちわだいこ /団扇太鼓;日蓮宗/
うちわばなし /内輪話/
うちわもめ /内輪揉め/
うっかい /鬱懐/
うっかりもの /うっかり者/
うっき /鬱気/
うっくつ /鬱屈/
うっけつ /鬱血/うっ血/欝血;異体字/鬱結/
うっこ /鬱乎/
うっこん /鬱金/
うっこんこう /鬱金香/
うっさん /鬱散;憂さ晴らし/
うっすら /薄ら/
うっせい /鬱生/
うっせき /鬱積/うっ積/欝積;異体字/
うっそう /鬱蒼/欝蒼;異体字/鬱葱;盛ん/
うっそく /鬱塞/
うったい /鬱滞/
うったえ /訴え/
うったえかた /訴え方/
うっちゃり /打っ棄り/
うっちょう /鬱鬯/
うって /討手/
うっとう /鬱陶/欝陶;「鬱」異体字/
うっぷん /鬱憤/欝憤;異体字/
うっぷんばらし /鬱憤晴らし/
うつ /鬱/欝;「鬱」の異体字/蔚;[植物]オトコヨモギ/
うつい /鬱伊/
うついく /鬱郁/
うつう /鬱紆/
うつうつ /鬱々/鬱鬱/
うつお /空/靫/
うつおう /鬱怏/鬱泱/鬱懊/
うつおぶね /空舟/
うつき /宇津木/宇津喜/
うつぎ /宇津木/
うつぎみ /鬱気味/
うつく /美/
うつくしがおか /美しが丘/
うつくしがはら /美ヶ原/
うつけ /空け/虚け/
うつけもの /呆気者/空け者/
うつし /写し/写/
うつしえ /写し絵/
うつしみ /現身/現し身/
うつしよ /現世/
うつじゅう /鬱情;?/
うつじょう /鬱情/
うつじょうたい /鬱状態;[精医]⇔躁状態/
うつせ /虚/
うつせがい /虚貝/
うつせみ /空蝉/現身/
うつぜん /鬱然/
うつそみ /現身/
うつつ /現/
うつて /打つ手/
うつのみや /宇都宮/
うつのみやえき /宇都宮駅/
うつのみやこうじょう /宇都宮工場/
うつのみやし /宇都宮市/
うつのみやせん /宇都宮線/
うつのみやだい /宇都宮大/
うつのみやだいがく /宇都宮大学/
うつばり /梁/
うつびょう /鬱病/うつ病/
うつぶせ /俯せ/
うつほ /空/
うつほぶね /空舟/
うつほものがたり /宇津保物語/
うつぼ /笂/靭;地名/靱;異体字/靫;矢の容器/空穂/
うつぼかずら /靫葛/
うつぼぐさ /靫草/
うつぼつ /鬱勃/
うつぼものがたり /宇津保物語/
うつみ /内海/慈/宇都美/
うつみや /宇津宮/
うつむきかげん /俯き加減/
うつも /鬱茂/
うつもん /鬱悶/
うつゆう /鬱悒/鬱邑/
うつよく /鬱抑/
うつり /写り/映り/
うつりかわり /移り変わり/移り変り/
うつりが /移り香/
うつりぎ /移り気/
うつりこみ /写り込み/映り込み/
うつりごし /移り腰/
うつりつ /鬱律/
うつりょうとう /鬱陵島;地名,Ullung-do/
うつろ /虚ろ/虚/宇津呂/空ろ/
うつろい /移ろい/
うつわ /器/噐/
うつわもの /器物/
うづ /宇津/
うづき /卯月;陰暦4月/宇津木/
うづきゅうめいがん /宇津救命丸/
うて /右手/
うてき /雨滴/
うてきかんち /雨滴感知/
うてな /台;高台/萼;花のガク/
うてん /雨天/
うてんけっこう /雨天決行/
うてんじ /雨天時/
うてんじゅんえん /雨天順延/
うてんちゅうし /雨天中止/
うで /腕/
うでおし /腕押し;暖簾に-/
うでかざり /腕飾り/
うできき /腕利き/
うでぎ /腕木/
うでくらべ /腕比べ/
うでぐみ /腕組み/
うでじまん /腕自慢/
うでずく /腕ずく/腕尽く/
うでずもう /腕相撲/
うでぞろい /腕揃い/
うでたて /腕立/
うでたてふせ /腕立て伏せ/腕立伏せ/
うでだめし /腕試し/
うでっぷし /腕っ節/
うでづく /腕尽く/
うでどけい /腕時計/
うでぶし /腕節/
うでまえ /腕前/
うでまくら /腕枕/
うでまくり /腕捲り/腕まくり/
うでわ /腕輪/
うと /宇都/宇土/
うとう /宇藤/宇籐/
うとく /有徳/宇徳/
うとくじん /有徳人/
うとろ /宇登呂/
うど /独活;独活の大木/
うどし /卯年/
うどじんぐう /鵜戸神宮/
うどねり /内舎人/
うどの /鵜殿/
うどり /羽鳥/
うどん /饂飩/
うどんげ /優曇華;(udumbara)「盲亀の浮木-の花」/
うどんこ /饂飩粉/うどん粉/
うどんや /饂飩屋/うどん屋/
うな /鰻/項/
うない /宇内/
うなかみ /海上/
うながし /令/
うなぎ /鰻/
うなぎどんぶり /鰻丼;うなどん/
うなぎのぼり /鰻登り/鰻上り/うなぎ登り/うなぎ上り/
うなぎめし /鰻飯/
うなぎや /鰻屋/
うなぎりょうり /鰻料理/
うなさか /海境/
うなじ /項/
うなじゅう /鰻重/
うなぞこ /海底/
うなづき /宇奈月/
うなでん /ウナ電;(<URgent)至急電報/
うなどん /鰻丼/うな丼/
うなばら /海原/
うなり /唸り/
うなりごえ /唸り声/
うに /雲丹/海胆/
うにょう /右繞;[仏教]/
うぬ /己/汝/
うぬぼれ /自惚れ/己惚れ/
うね /畝/畦/宇根;地名/有年;地名/疇/畆/畴/
うねおか /宇根岡/
うねおり /畝織/
うねかわ /畝川/
うねび /畝傍/
うねびやま /畝傍山/
うねま /畝間/
うねめ /采女/
うねもと /畝本/
うの /宇野/鵜野/宇能/
うのう /右脳/
うのき /鵜木/卯木/宇野木/卯野木/
うのけ /宇ノ気/
うのせん /宇野線/
うのはな /卯の花/
うのみ /鵜呑み/鵜呑/
うのめたかのめ /鵜の目鷹の目/
うは /右派/
うば /姥/乳母/
うばい /優婆夷;[仏教]/烏梅/
うばいあい /奪い合い/
うばいし /姥石/
うばがい /姥貝/
うばぐるま /乳母車/
うばざくら /姥桜/
うばすて /姥捨/姥捨て/
うばすてやま /姨捨山/
うばそく /優婆塞/
うばめがし /姥目樫/
うひょう /雨氷/
うひょうえ /右兵衛/
うひょうえのかみ /右兵衛督;[律令制]/
うひょうえのじょう /右兵衛尉;[律令制]/
うびょう /宇廟/
うふさま /右府様/
うぶ /産/初/初心/有部/生/
うぶぎ /産着/産衣/
うぶぎぬ /産衣/
うぶげ /産毛/
うぶこ /産子/
うぶご /産子/
うぶごえ /産声/
うぶごや /産小屋/
うぶすな /産土/
うぶすながみ /産土神/
うぶね /鵜舟/
うぶめ /産女/
うぶや /産屋/
うぶやま /産山/
うぶゆ /産湯/
うぷしろん /υ;upsilon/Υ;Upsilon/
うへん /右辺/羽片/
うへんち /右辺値/
うべ /宇部/宜/
うべこう /宇部興/
うべこうさん /宇部興産/
うべせん /宇部線/
うべんかん /右弁官/
うほ /禹歩/
うほう /右方/
うま /馬/午;[十二支]7/旨/
うまあぶ /馬虻/
うまいち /馬市/
うまいり /馬入/
うまうま /旨々;-と/
うまおい /馬追い/
うまかたぶし /馬方節;馬子唄/
うまき /鰻巻き/
うまくさ /秣/
うまくち /甘口/
うまこ /馬子/
うまこし /馬越/
うまご /孫/
うまごめ /馬込/
うまごや /馬小屋/
うまごやし /苜蓿/馬肥やし;[植物]alfalfa/
うまさけ /味酒;-の三諸の山/旨酒;(枕詞)-の,-を/
うまじ /馬路/
うまじしん /馬自身/
うまじたい /馬自体/
うまじるし /馬印/馬標/
うまずめ /石女/不生女/
うまずら /馬面;※仮名遣い「うまづら」/
うまたち /馬達/
うまたて /馬立/
うまたん /馬単/
うまづら /馬面/
うまづらはぎ /馬面剥;フグ目の海魚。カワハギの仲間。/
うまとび /馬跳び/馬飛び/
うまどし /午年/
うまに /甘煮/旨煮;白菜の-/馬荷/
うまぬし /馬主/
うまの /馬野/
うまのかみ /右馬頭/馬頭/
うまのすけ /右馬助/
うまのすずくさか /ウマノスズクサ科/Aristolochiaceae/
うまのすずくさもく /ウマノスズクサ目/Aristolochiales/
うまのはなむけ /餞/
うまのほね /馬の骨/
うまのり /馬乗り/
うまはし /馬橋/
うまば /馬場/
うまばえ /馬蠅/
うまばしら /馬柱;[競馬]/
うまばん /馬番/
うまふざい /馬不在/
うまぶね /馬槽/
うまへん /馬偏/
うまみ /旨味/旨み/
うまみち /馬道/
うまみちょうみりょう /旨味調味料;『味の素』の類/
うまや /厩/馬屋/廐/廏/
うまやごえ /厩肥;[農業]barnyard manure/
うまやどのおうじ /厩戸皇子;聖徳太子/
うまら /茨/
うまれ /生まれ/生れ/生/
うまれかわり /生まれ変わり;reincarnation/生れ変り/
うまれこきょう /生まれ故郷/
うまれつき /生まれつき/生まれ付き/
うまれどし /生まれ年/
うまれん /馬連/
うみ /海/膿/生/宇美/
うみいぐあな /海イグアナ/
うみいちめん /海一面/
うみうお /海魚/
うみうし /海牛/
うみうま /海馬;タツノオトシゴ/
うみかぜ /海風/
うみがみ /海神/
うみがめ /海亀/
うみがわ /海側/
うみぎり /海霧/
うみさち /海幸/
うみざかな /海魚/
うみしばうら /海芝浦/
うみせんやません /海千山千/
うみそだち /海育ち/
うみぞい /海沿い/
うみだし /海田市/
うみち /膿血/
うみつばめ /海燕/
うみづき /産み月/
うみづり /海釣り/海釣/
うみて /海手;⇔山手/
うみどり /海鳥/
うみなり /海鳴り/
うみねこ /海猫/
うみの /海野/
うみのいえ /海の家/
うみのおや /生みの親;-より育ての親/産みの親/
うみのくるしみ /産みの苦しみ/生みの苦しみ/
うみのさち /海の幸/
うみのなかみち /海の中道/
うみのひ /海の日;七月の第三月曜日/
うみはら /海腹/
うみはらかわせ /海腹川背/
うみびらき /海開き/
うみへび /海蛇/
うみへびざ /海蛇座;Hydra(Hya)/
うみべ /海辺/
うみべり /海縁/
うみほたる /海蛍/
うみぼうず /海坊主/
うみやま /海山/
うむ /有無/孳/
うむき /蛤/
うめ /梅/楳/
うめあわせ /埋め合わせ/埋め合せ/
うめがえ /梅枝/
うめがえもち /梅枝餅;太宰府名物/
うめがおか /梅が丘/
うめがき /梅垣/
うめがしま /梅ヶ島/
うめがたに /梅ヶ谷/
うめがわ /梅川/
うめき /埋木/呻き/
うめきごえ /呻き声/
うめきち /梅吉/
うめくさ /埋め草/埋草/
うめこ /梅子/
うめこうじ /梅小路/
うめこぶちゃ /梅昆布茶/
うめこみ /埋め込み/
うめさお /梅棹/
うめさわ /梅沢/
うめざき /梅崎/
うめざわ /梅沢/梅澤/
うめしゅ /梅酒/
うめず /梅酢/楳図;人名/梅津/梅図/
うめぞの /梅園/
うめぞめ /梅染/
うめた /梅田/
うめたて /埋め立て/埋立/埋立て/
うめたてち /埋立地/埋め立て地/
うめたに /梅谷/
うめだ /梅田/楳田/
うめだえき /梅田駅/
うめだかもつえき /梅田貨物駅/
うめだかもつせん /梅田貨物線/
うめだがわ /梅田川/
うめだきた /梅田北/
うめだしてん /梅田支店/
うめだはんしん /梅田阪神/
うめづ /梅津/
うめづけ /梅漬け/梅漬/
うめにしき /梅錦/
うめの /梅野/
うめはら /梅原/
うめばち /梅鉢;紋所/
うめびしお /梅醤/
うめぼし /梅干し/梅干/
うめみ /梅見/
うめみや /梅宮/
うめむら /梅村/
うめむろ /梅室/
うめもと /梅本/
うめもどき /梅擬/
うめもり /梅森/
うめやま /梅山/
うも /芋/
うもう /羽毛/
うもうだ /羽毛田/
うもうふく /羽毛服/
うもうふとん /羽毛布団/
うもうぶとん /羽毛布団/
うもん /宇門/
うや /雨夜/礼/
うやく /烏薬/
うやま /宇山/
うやむや /有耶無耶/
うゆう /烏有;-に帰す/
うよ /紆余/紆餘;「余」旧字/
うよう /右葉/
うよきょくせつ /紆余曲折/
うよく /右翼/羽翼;wing. assist./
うよくしゅ /右翼手/
うよくせき /右翼席/
うよくだんたい /右翼団体/
うよくてき /右翼的/
うら /裏/浦/占/裡/心;心恋しい,心寂しい,心無し/錙;?/
うら> /裏/
うらあみ /裏編み/
うらうえ /裏表/
うらうす /浦臼/
うらうち /裏打ち/裏打/
うらうつり /裏移り/
うらえ /浦江/
うらえり /裏襟/
うらおもて /裏表/
うらおもてがみ /裏表紙/
うらかいどう /裏街道/
うらかすみ /浦霞/
うらかぜ /浦風/裏風/
うらかた /裏方/
うらかみ /浦上/
うらかわ /浦河/浦川/
うらが /浦賀/
うらがえし /裏返し/
うらがお /裏顔/
うらがき /裏書/裏書き/
うらがききんし /裏書禁止/
うらがききんしうらがき /裏書禁止裏書/
うらがきじょうと /裏書譲渡/
うらがきてがた /裏書手形/
うらがきにん /裏書人/
うらがすいどう /浦賀水道/
うらがすみ /浦霞/
うらがすみぜん /浦霞禅/
うらがすみだいぎんじょう /浦霞大吟醸/
うらがせん /浦賀線/
うらがね /裏金/
うらがみ /浦上/裏紙/
うらがみえきまえ /浦上駅前/
うらがみしゃこ /浦上車庫/
うらがめん /裏画面/
うらがわ /裏側/浦川/裏革/裏皮/
うらきど /裏木戸/
うらきばん /裏基盤/
うらきもん /裏鬼門/
うらぎり /裏切り/裏切/
うらぎりもの /裏切り者/裏切者/
うらぐち /裏口/
うらぐちにゅうがく /裏口入学/
うらけい /裏罫/
うらけん /裏拳/
うらげい /裏芸/
うらこう /浦港/
うらこうさく /裏工作/
うらごえ /裏声/
うらごし /裏漉し/
うらさ /浦佐/
うらさく /裏作/
うらさわ /浦沢/
うらさんしょう /裏参照/
うらしの /嬉野/
うらしま /浦島/
うらしまそう /浦島草/
うらしまたろう /浦島太郎/
うらしゃかい /裏社会/
うらじ /裏地/
うらじおすとっく /浦鹽斯徳/
うらじじょう /裏事情/
うらじゃけ /裏ジャケ/
うらじょうほう /裏情報/
うらじろ /裏白/
うらじろがし /裏白樫/
うらじろど /裏白戸/
うらじろれんが /裏白連歌/
うらすじ /裏筋/
うらずみ /裏住み/
うらせ /浦瀬/
うらせってい /裏設定/
うらせんけ /裏千家/
うらぜん /浦禅/
うらそえ /浦添/
うらぞこ /浦底/
うらた /浦田/
うらだな /裏店/
うらち /浦地/
うらづけ /裏付け/裏付/
うらて /裏手/
うらとりひき /裏取引/
うらどおり /裏通り/
うらどら /裏ドラ/
うらない /占い/卜い/卦;?/
うらないし /占い師/
うらなげ /裏投げ/
うらなみ /浦波/
うらなり /末成り/末生り/
うらにし /浦西/
うらにほん /裏日本/
うらにわ /裏庭/
うらの /浦野/
うらはいけい /裏背景/
うらはく /裏拍/
うらはず /末弭/末筈/
うらはま /浦浜/
うらはら /裏腹/裏原;[略語]裏原宿(原宿の裏通り)/
うらはらじゅく /裏原宿/
うらば /裏葉/
うらばなし /裏話/
うらばなしてき /裏話的/
うらばん /裏番/
うらばんぐみ /裏番組/
うらばんだい /裏磐梯/
うらばんだいねこま /裏磐梯猫魔/
うらびでお /裏ビデオ/
うらびょうし /裏表紙/
うらぶた /裏蓋/
うらぶたい /裏舞台/
うらべ /卜部/占部/浦部/浦辺/裏部/
うらべかねよし /卜部兼好/
うらべや /裏部屋/
うらほ /裏帆/
うらほろ /浦幌/
うらぼん /盂蘭盆/裏盆/
うらまち /裏町/
うらまど /裏窓/
うらみ /恨み/怨み/憾み;残念なこと。欠点。/浦見/
うらみごと /恨み言/怨み言/
うらみごろ /裏身頃/
うらみち /裏道/
うらみっこ /恨みっこ;-なし/
うらみつらみ /恨みつらみ;-をぶちまける/
うらみぶし /恨み節/怨み節/
うらむ /怏/
うらめ /裏目/
うらめい /裏銘/
うらめし /浦飯/
うらめん /裏面/
うらもと /浦本/
うらもの /裏物/
うらもん /裏門/裏紋/
うらもんじょ /裏文書/
うらやき /裏焼き;すまりなに逆右左/
うらやす /浦安/
うらやすかん /浦安間/
うらやすし /浦安市/
うらやま /浦山/裏山/
うらよみ /裏読み/
うらら /麗ら/麗/
うららか /麗らか/
うらる /烏拉/
うらるあるたいごぞく /ウラルアルタイ語族;[言語]Ural-Altaic/
うらるごぞく /ウラル語族;[言語]/
うらわ /浦和/
うらわえき /浦和駅/
うらわざ /裏技/
うらわざてき /裏技的/
うらわし /浦和市/
うらわせん /浦和戦/
うらわだいもん /浦和大門/
うらわでんしゃく /浦和電車区/
うらわにしぐち /浦和西口/
うらわみなみ /浦和南/
うらん /U/Uranium/
うらんけいれつ /ウラン系列;4n+2系列/
うらんのうしゅく /ウラン濃縮;[科技]uranium enrichment/
うり /瓜/売り/
うりあげ /売上/売り上げ/売上げ/
うりあげかかく /売上価格/
うりあげかくほ /売上確保/
うりあげがく /売上額/
うりあげきん /売上金/
うりあげきんがく /売上金額/
うりあげけいさんしょ /売上計算書/
うりあげげんか /売上原価/
うりあげこうせいひ /売上構成比/
うりあげさいけん /売上債権/
うりあげさいけんかいてんりつ /売上債権回転率/
うりあげぜい /売上税/
うりあげそうりえきりつ /売上総利益率/
うりあげぞう /売上増/
うりあげぞうだい /売上増大/
うりあげだいすう /売上台数/
うりあげだか /売上高/
うりあげふしん /売上不振/
うりいえ /売り家/
うりう /瓜生/
うりおしみ /売り惜しみ/
うりか /ウリ科/
うりかい /売り買い/
うりかけ /売掛/売り掛け/
うりかけきん /売掛金/
うりかけちょう /売掛帳/
うりかた /売り方/売方/
うりきれ /売り切れ/売切れ/売切/
うりきれごめん /売り切れ御免/
うりぎょく /売玉;[相場]/売り玉;[相場]selling account/
うりくち /売り口/
うりぐい /売り食い/
うりぐすり /売薬/売り薬/
うりけはい /売気配/売り気配/
うりこ /売り子/売子/
うりことば /売り言葉/売言葉/
うりこひめ /瓜子姫;説話/
うりこみ /売り込み/
うりごえ /売り声/売声/
うりざいりょう /売り材料/
うりざね /瓜実/瓜核/
うりざねがお /瓜実顔/
うりざん /売り残/
うりそうば /売相場/
うりだし /売り出し/売出し/売出/
うりだしきかん /売出期間/
うりだしちゅう /売り出し中/売出中/
うりだて /売建/売り建て;[相場]/売建て;[相場]/
うりだてぎょく /売建玉/
うりち /売地/
うりちゅうもん /売り注文/
うりづら /瓜連/
うりて /売り手/売手/
うりてしじょう /売り手市場/売手市場/
うりどき /売り時/
うりぬけ /売り抜け/
うりぬし /売主/売り主/
うりね /売値/売り値/
うりの /売野/
うりば /売り場/売場/
うりばめんせき /売場面積/
うりふたつ /瓜二つ/
うりぼう /瓜坊/
うりみばえ /瓜実蠅/
うりもく /ウリ目/Cucurbitales/
うりもの /売り物/売物/
うりもんく /売り文句/
うりや /売り家/
うりゅ /雨龍/
うりゅう /雨竜/瓜生/雨龍/
うりゅうの /瓜生野/
うりょう /雨量/
うりょうけい /雨量計/
うりよね /糶/売り米/
うりわたし /売渡/売り渡し/売渡し/
うりん /雨林/
うりんけ /羽林家/
うる /宇留/
うるい /潤/
うるう /閏/
うるうづき /閏月/
うるうどし /閏年/
うるうび /閏日;2.29/
うるうびょう /閏秒/
うるおい /潤い/
うるか /潤香;鮎の内臓の塩漬/
うるき /売木/夏枯草/
うるごめ /粳米/
うるさ /煩/
うるさがた /うるさ型/
うるし /漆/
うるしえ /漆絵/
うるしじ /漆地/
うるしぬり /漆塗り/漆塗/
うるしね /粳/粳稲/
うるしねんぐ /漆年貢/
うるしはら /漆原/
うるしばた /漆畑/
うるしま /漆島/
うるしまけ /漆負け/
うるしやま /漆山/
うるた /粳田/
うるち /粳/
うるちまい /粳米/うるち米/
うるとらしー /ウルトラＣ/
うるむち /烏魯木斉/
うるめ /潤目/
うるめいわし /潤目鰯/
うれ /末/売れ/
うれあし /売れ足/
うれい /憂い/愁い/恙/騷;「騒」の旧字(人名用漢字)/
うれいがお /憂い顔/愁い顔/
うれう /悄/
うれえ /憂え/愁え/
うれくち /売れ口/
うれし /嬉し/
うれしがらせ /嬉しがらせ/
うれしなき /嬉し泣き/
うれしなみだ /嬉し涙/
うれしの /嬉野/
うれすじ /売れ筋/
うれせん /売れ線/
うれたんじゅし /ウレタン樹脂/
うれだか /売れ高/
うれっこ /売れっ子/
うれつ /ウ列/う列/
うれのこり /売れ残り/
うれゆき /売れ行き/売行き/売行/
うろ /雨露/烏鷺/迂路/有漏/空/洞/空洞/虚/
うろう /傴僂/
うろおぼえ /うろ覚え/疎覚え/
うろくず /鱗/
うろこ /鱗/
うろこがた /鱗形/
うろこぐも /鱗雲/
うろこじょう /鱗状/
うろん /胡乱/
うわ /上/宇和/
うわ> /上;上枠,上滑り/
うわあご /上顎/
うわえ /上絵/
うわえだ /上枝/
うわえつけ /上絵付け/
うわえのぐ /上絵の具/
うわがき /上書き/上書/
うわがきほぞん /上書き保存/
うわがけ /上掛け/
うわがまち /上框;[建築]/
うわがみ /上紙/
うわがわ /上側/
うわき /浮気/
うわきがんぼう /浮気願望/
うわきごころ /浮気心/
うわきしょう /浮気性/
うわきちゅう /浮気中/
うわきちょうさ /浮気調査/
うわきもの /浮気者/
うわぎ /上着/上衣/
うわくちびる /上唇/
うわぐすり /釉/釉薬/上薬;釉薬/
うわぐつ /上靴/
うわごえ /上声/
うわごと /譫言/
うわさ /噂/
うわさのたね /噂の種/
うわさばなし /噂話/
うわざら /上皿/
うわざらてんびん /上皿天秤/
うわじま /宇和島/
うわじまじどうしゃ /宇和島自動車;[企業名]/
うわじまひがし /宇和島東/
うわすべり /上滑り/
うわずみ /上澄み/上住/
うわぜい /上背/
うわぞこ /上底/
うわだな /上棚/
うわちょうし /上調子/
うわぢょうし /上調子;[音楽] 1octave上/
うわっちょうし /上っ調子/
うわっつら /上っ面/
うわっぱり /上っ張り/
うわつき /上付き/
うわつら /上面/
うわづつみ /上包み/
うわづみ /上積み/
うわて /上手/
うわてだしなげ /上手出し投げ/
うわてなげ /上手投げ/
うわてひねり /上手捻り/
うわなり /嫐/
うわに /上荷/
うわにぶね /上荷船/
うわぬり /上塗り/
うわね /上値/
うわの /宇和野/
うわのせ /上乗せ/
うわのそら /上の空/
うわのだい /上の台/
うわのり /上乗り/
うわばき /上履き/
うわばみ /蟒蛇/蠎蛇;「蟒」異体字/
うわばり /上張り/
うわひ /上翳/
うわぶたしき /上蓋式/
うわべ /上辺/
うわまい /上米;年貢米に掛ける通行税(「上前」の語源)/
うわまえ /上前/
うわみ /上身/宇和海/
うわみぞ /上溝/
うわみの /上蓑/
うわむき /上向き/
うわめ /上目/
うわめづかい /上目使い/上目遣い/
うわもの /上物/
うわや /上屋/
うわやく /上役/
うわん /右腕/
うん /運/雲/暈;(かさ)眩暈/云;云々/紜;紛紜/耘;耕耘機/吽;阿吽/繧;繧繝/慍;(いか・る)慍色/薀;薀蓄(=蘊蓄)/蘊;蘊蓄/褞;褞袍/黄;?/曇;?/
うんう /雲雨/
うんうんうにうむ /Uuu/Unununium/
うんうんおくちうむ /Uuo/Ununoctium/
うんうんくあじうむ /Uuq/Ununquadium/
うんうんにりうむ /Uun/Ununnilium/
うんうんびうむ /Uub/Ununbium/
うんうんへきしうむ /Uuh/Ununhexium/
うんえい /運営/
うんえいいいん /運営委員/
うんえいいいんかい /運営委員会/
うんえいかつどう /運営活動/
うんえいがいしゃ /運営会社/
うんえいがわ /運営側/
うんえいしきん /運営資金/
うんえいしつ /運営室/
うんえいしゃ /運営者/
うんえいしゃがわ /運営者側/
うんえいじょう /運営上/
うんえいちゅう /運営中/
うんえいどりょく /運営努力/
うんえいのうりょく /運営能力/
うんえいひ /運営費/
うんえいひよう /運営費用/
うんえいぶ /運営部/
うんえいほうしん /運営方針/
うんえいほうほう /運営方法/
うんえいぼたい /運営母体/
うんえいもと /運営元/
うんえいよう /運営用/
うんえいりねん /運営理念/
うんえん /雲煙/
うんえんかがん /雲煙過眼/
うんえんひょうびょう /雲煙縹渺/
うんか /雲霞/浮塵子/
うんかい /雲海/
うんかく /雲鶴/雲客;殿上人/
うんかん /雲漢;天の川/
うんが /運河/
うんがかん /運河間/
うんき /運気/温気/
うんきゅう /運休/運弓;[音楽]bowing.「バイオリンの-」/
うんきゅうほう /運弓法/
うんけい /運慶/雲形/
うんけいじょうぎ /雲型定規/
うんげいせん /雲芸線/
うんげん /繧繝/
うんこう /運行;†(バス|天体)の-/運航;†(船|飛行機)の-/暈光/
うんこうがいしゃ /運行会社/
うんこうけいたい /運行形態/
うんこうじかん /運行時間/
うんこうじかんたい /運行時間帯/
うんこうじょうきょう /運行状況/
うんこうじょうけん /運行条件/
うんこうじょうむいん /運航乗務員/
うんこうちゅう /運行中;†「-の電車」/運航中;†「-の船舶」/
うんこうちゅうし /運航中止/
うんこうていし /運航停止/
うんこうにってい /運航日程/
うんこうまえてんけん /運行前点検/
うんこうよう /運行用/
うんこく /雲谷/
うんごうむしゅう /雲合霧集/
うんさん /雲散/
うんさんむしょう /雲散霧消;跡形もなく消える/
うんざん /運算/
うんし /運指/
うんしだい /運次第/
うんしゅう /温州;(Wenzhou) 中国・浙江省の都市/雲州;出雲/雲集;-霧散/
うんしゅうみかん /温州蜜柑/
うんしゅうむさん /雲集霧散;集まったり散ったりする/
うんしょうむさん /雲消霧散;=雲散霧消/
うんしょく /慍色;むっとした顔色/暈色;鉱物の虹色/
うんしん /運針/雲身/
うんしんげっせい /雲心月性/
うんじゃく /雲雀/
うんじゅ /琅珠/
うんじょう /雲上/運上/
うんじょうびと /雲上人/
うんすい /雲水/
うんせい /運勢/運星;†星の巡り合わせ/
うんぜん /雲仙/
うんぜんこうえん /雲仙公園/
うんぜんだけ /雲仙岳/
うんぜんふげんだけ /雲仙普賢岳/
うんそう /運送/
うんそうがいしゃ /運送会社/
うんそうぎょう /運送業/
うんそうぎょうかい /運送業界/
うんそうぎょうしゃ /運送業者/
うんそうけいやく /運送契約/
うんそうじょう /運送状/
うんそうちゅう /運送中/
うんそうてん /運送店/
うんそうにん /運送人/
うんそうひ /運送費/
うんそうひよう /運送費用/
うんそうほけん /運送保険/
うんそうや /運送屋/
うんそうやっかん /運送約款/
うんそうりょう /運送料/
うんそく /運足/
うんだい /雲台/
うんだめし /運試し/
うんちく /蘊蓄/薀蓄;=蘊蓄/
うんちゃん /運ちゃん/
うんちゅうはっかく /雲中白鶴/
うんちょう /雲頂/
うんちん /運賃/
うんちんかいせい /運賃改正/
うんちんかいてい /運賃改定/
うんちんかくさ /運賃格差/
うんちんきそく /運賃規則/
うんちんけいさん /運賃計算/
うんちんしゅうにゅう /運賃収入/
うんちんせい /運賃制/
うんちんたいけい /運賃体系/
うんちんばこ /運賃箱/
うんちんひょう /運賃表/
うんちんひょうじ /運賃表示/
うんちんひょうじき /運賃表示器/運賃表示機/
うんちんふたん /運賃負担/
うんちんぶん /運賃分/
うんちんめん /運賃面/
うんちんりょうきん /運賃料金/
うんてい /雲梯;遊具/
うんてん /運転/
うんてんいがい /運転以外/
うんてんかい /運転会/
うんてんかんかく /運転間隔/運転感覚/
うんてんぎじゅつ /運転技術/
うんてんぎりょう /運転技量/
うんてんくかん /運転区間/
うんてんけいたい /運転形態/
うんてんけいとう /運転系統/
うんてんさいかい /運転再開/
うんてんし /運転士/
うんてんしきん /運転資金/
うんてんしつ /運転室/
うんてんしどう /運転指導/
うんてんしほん /運転資本/
うんてんしゃ /運転者/
うんてんしゃいがい /運転者以外/
うんてんしゃせき /運転者席/
うんてんしゅ /運転手/
うんてんしゅうりょうご /運転終了後/
うんてんしゅし /運転手氏/
うんてんしよう /運転士用/
うんてんしれい /運転指令/
うんてんじ /運転時/
うんてんじかん /運転時間/
うんてんじき /運転時期/
うんてんじゅつ /運転術/
うんてんじょう /運転上/
うんてんせき /運転席/
うんてんせきがわ /運転席側/
うんてんせきこうほう /運転席後方/
うんてんせきじょう /運転席上/
うんてんせきひだりがわ /運転席左側/
うんてんせきよこ /運転席横/
うんてんそうさ /運転操作/
うんてんたいど /運転態度/
うんてんだい /運転台/
うんてんちゅう /運転中/
うんてんていしゃ /運転停車/
うんてんのうりょく /運転能力/
うんてんひんど /運転頻度/
うんてんび /運転日/
うんてんびちゅうい /運転日注意/
うんてんほう /運転法/
うんてんほうほう /運転方法/
うんてんほんすう /運転本数/
うんてんめんきょ /運転免許/
うんてんめんきょしけん /運転免許試験/
うんてんめんきょしょう /運転免許証/
うんてんよう /運転用/
うんてんれき /運転歴/
うんでい /雲泥/
うんでいのさ /雲泥の差/
うんどう /運動/
うんどういん /運動員/
うんどうえねるぎー /運動エネルギー;[物理]kinetic energy. mv^2／2/
うんどうか /運動家/
うんどうかい /運動会/
うんどうかく /運動覚/
うんどうかんかく /運動感覚;kinesthesia/
うんどうがく /運動学/
うんどうがくてき /運動学的/
うんどうがわ /運動側/
うんどうき /運動器/
うんどうきのう /運動機能/
うんどうきょうぎ /運動競技;athletics/
うんどうぐ /運動具;飛び箱やボールなど/
うんどうぐつ /運動靴/
うんどうこう /運動項/
うんどうこうえん /運動公園/
うんどうこうえんない /運動公園内/
うんどうこうぞう /運動構造/
うんどうし /運動史/
うんどうしっちょう /運動失調;[医]ataxia/
うんどうしょうがい /運動障害/
うんどうしんけい /運動神経/
うんどうじ /運動時/
うんどうじょう /運動場/
うんどうじょうたい /運動状態/
うんどうせい /運動性/
うんどうせいぎょ /運動制御/
うんどうせいのう /運動性能/
うんどうせいぶん /運動成分/
うんどうそしき /運動組織/
うんどうたい /運動体/
うんどうちゅう /運動中/
うんどうちゅうすう /運動中枢/
うんどうのう /運動能/
うんどうのうりょく /運動能力/
うんどうひ /運動費/
うんどうぶ /運動部/
うんどうぶそく /運動不足/
うんどうぶそくぎみ /運動不足気味/
うんどうぶったい /運動物体/
うんどうほうこう /運動方向/
うんどうほうそく /運動法則/
うんどうほうていしき /運動方程式/
うんどうまひ /運動麻痺;[医]akinesia/
うんどうや /運動野;[解剖]motor area/
うんどうようそ /運動要素/
うんどうりょう /運動量/
うんどうりょうほう /運動療法;kinesiology/
うんどうりょうほぞんそく /運動量保存則/
うんどうりょうゆそう /運動量輸送/
うんどうりょく /運動力/
うんどんこん /運鈍根/
うんなん /雲南/
うんなんしょう /雲南省/
うんぬん /云々/云云/
うんの /海野/
うんのう /蘊奥/雲衲/暈ノウ;(サンズイに「翁」)/
うんのじゅうざ /海野十三/
うんぱん /運搬/雲版/
うんぱんかのう /運搬可能/
うんぱんき /運搬機/
うんぱんぐ /運搬具/
うんぱんしゅだん /運搬手段/
うんぱんちゅう /運搬中/
うんぱんよう /運搬用/
うんぱんりょく /運搬力/
うんぴつ /運筆/
うんぴょう /雲表/
うんぷう /雲風/
うんぷてんぷ /運否天賦/
うんぼ /雲母/
うんまかせ /運任せ/
うんむ /雲霧/
うんめい /運命/
うんめいあい /運命愛/
うんめいきょうどうたい /運命共同体;一蓮托生/
うんめいてき /運命的/
うんめいとうげ /運命峠/
うんめいろん /運命論/
うんめん /温麺/
うんも /雲母/
うんもじょう /雲母状/
うんゆ /運輸/
うんゆぎょうせい /運輸行政/
うんゆしょう /運輸省;NB:2001年1月の中央省庁再編で国土交通省に再編された/
うんゆせいさく /運輸政策/
うんゆだいじん /運輸大臣/
うんゆとうけい /運輸統計/
うんよう /運用/
うんようえき /運用益/
うんようかいし /運用開始/
うんようかのう /運用可能/
うんようかんきょう /運用環境/
うんようかんり /運用管理/
うんようかんりしゃ /運用管理者/
うんようがかり /運用掛/
うんようきゅうし /運用休止/
うんようけいけん /運用経験/
うんようけいたい /運用形態/
うんようしゃ /運用者/
うんようしゅうりょう /運用終了/
うんようじ /運用時/
うんようじかん /運用時間/
うんようじっけん /運用実験/
うんようじっせき /運用実績/
うんようじゅつ /運用術/
うんようじょう /運用上/
うんようじょうたい /運用状態/
うんようすう /運用数/
うんようせい /運用性/
うんようぞん /運用損/
うんようたいせい /運用体制/
うんようちゅう /運用中/
うんようていし /運用停止/
うんようてき /運用的/
うんようばしょ /運用場所/
うんようばんごう /運用番号/
うんようひ /運用費/
うんようひょう /運用表/
うんようほう /運用法/
うんようほうこくしょ /運用報告書/
うんようほうしん /運用方針/
うんようほうほう /運用方法/
うんようほんぶ /運用本部/
うんようめん /運用面/
うんようよう /運用用/
うんようりょく /運用力/
うんりゅう /雲竜/
うんりゅうがた /雲龍型/
うんりょう /雲量/
え /絵/画/江/餌/重/柄;handle/会/得;取り柄/荏;荏胡麻/枝/恵;知恵/慧;智慧(=知恵)/衣/依;帰依/榎/笑;笑顔/衛/回/囘;「回」の旧字/會;「会」の旧字/惠;「恵」の旧字(人名用漢字)/畫;「画」の旧字/繪;「絵」の旧字/衞;「衛」の旧字(人名用漢字)/懷;「懐」の旧字(人名用漢字)/猥;(ワイ) 呉音/杖;?/
え> /得;(ア行下一・下二 未然・連用形)得手,得難い,得具足/
えーがた /Ａ型/A型/
えーがたかんえん /Ａ型肝炎;[医]/A型肝炎;[医]hepatitis A/
えーきゅう /Ａ級/A級/
えーきゅうせんぱん /Ａ級戦犯/
えーげかい /エーゲ海/
えーげぶんめい /エーゲ文明/
えーた /η;eta/Η;Eta/
えーばん /Ａ判/A判/
えーびーがた /ＡＢ型/AB型/
えーびーしーじゅん /ABC順/
えーぶいきき /ＡＶ機器/AV機器/
えーぶいじょゆう /ＡＶ女優/AV女優/
えーめん /Ａ面/A面/
えあわせ /絵合わせ/絵合/
えい /英/映/影/鋭/永/泳/詠/衛/営/栄/郢;楚の都/嬰;(音楽の)sharp/纓;冠の紐/瓔;首飾り/珱;「瓔」の異体字/穎;ほさき/頴;「穎」の異体字/潁;潁川(中国の河川名)/洩;漏洩/曳;曳航/曵;「曳」の異体字/睿;≒叡/叡;叡智/瑛;美瑛町/暎;「映」の異体字/盈;み・ちる/楹;(はしら)/贏/瀛/瑩;(みがき)/塋;(はか)/蠑;蠑螺/榮;「栄」の旧字(人名用漢字)/營;「営」の旧字/裔;末裔/翳;陰翳/咏;≒詠/殪;たお・す/縊/衞;「衛」の旧字(人名用漢字)/娃;?/衡;?/頴娃/海鷂魚/
えい> /英;[略語]イギリス.-軍,-詩/嬰;嬰ロ短調/
えいい /鋭意/営為/衛尉/嬰イ/栄位/
えいいしっぴつちゅう /鋭意執筆中/
えいいたんちょう /嬰イ短調/
えいいち /栄一/英一/榮一/詠一/
えいいちょうちょう /嬰イ長調/
えいいちろう /英一郎/栄一郎/
えいいどりょく /鋭意努力/
えいいん /影印/
えいえい /営々/営営/英英/永々/
えいえいじしょ /英英辞書/
えいえいじてん /英英辞典/
えいえん /永遠/永延;年号(987-989)/
えいえんせい /永遠性/
えいえんふめつ /永遠不滅/
えいおうしつ /英王室/
えいおおもじ /英大文字/
えいおん /嬰音/
えいか /詠歌/穎果/
えいかいわ /英会話/
えいかいわかんけい /英会話関係/
えいかいわがっこう /英会話学校/
えいかいわきょうざい /英会話教材/
えいかいわきょうしつ /英会話教室/
えいかく /鋭角/
えいかくさんかくけい /鋭角三角形/
えいかくさんかっけい /鋭角三角形/
えいかくてき /鋭角的/
えいかん /栄冠/永観;年号(983-985)/
えいかんたい /英艦隊/
えいが /映画/栄華/栄画/
えいがおんがく /映画音楽/
えいがおんがくとくしゅう /映画音楽特集/
えいがか /映画化/
えいがかい /映画界/
えいがかけん /映画化権/
えいがかん /映画館/
えいがかんけい /映画関係/
えいがかんしょう /映画鑑賞/映画観賞/
えいがかんとく /映画監督/
えいがかんめい /映画館名/
えいががいしゃ /映画会社/
えいががっこう /映画学校/
えいがく /英学/栄学/
えいがげいじゅつ /映画芸術/
えいがげきじょう /映画劇場/
えいがさい /映画祭/
えいがさくひん /映画作品/
えいがさっか /映画作家/
えいがざっし /映画雑誌/
えいがし /映画史/映画誌/
えいがしじょう /映画史上/
えいがしゅだいきょく /映画主題曲/
えいがしょう /映画賞/
えいがじたい /映画自体/
えいがじょうえいかい /映画上映会/
えいがじょゆう /映画女優/
えいがじん /映画人/
えいがじんこう /映画人口/
えいがせいさく /映画制作/
えいがせいさくしゃ /映画製作者/
えいがぜんたい /映画全体/
えいがだいぜんしゅう /映画大全集/
えいがてき /映画的/
えいがないえいが /映画内映画/
えいがはいゆう /映画俳優/
えいがばん /映画版/
えいがひょう /映画評/
えいがひょうろん /映画評論/
えいがひょうろんか /映画評論家/
えいがびじゅつ /映画美術/
えいがぶもん /映画部門/
えいがむら /映画村/
えいがめい /映画名/
えいがものがたり /栄花物語/栄華物語/
えいがや /映画屋/
えいがよう /映画用/
えいがらん /映画欄/
えいき /鋭気;†鋭い気勢。「-を挫く」/英気;†立ち働く気力。「-を養う」/永記/盈虧/
えいきごう /嬰記号;♯/
えいきち /栄吉/永吉/
えいきゅう /永久;年号(1113-1118)/
えいきゅうかいいん /永久会員/
えいきゅうきかん /永久機関/
えいきゅうけつばん /永久欠番/
えいきゅうし /永久歯/
えいきゅうしゅうしょく /永久就職/
えいきゅうじしゃく /永久磁石/
えいきゅうだつもう /永久脱毛/
えいきゅうついほう /永久追放/
えいきゅうていし /永久停止/
えいきゅうてき /永久的/
えいきゅうとうど /永久凍土/
えいきゅうほうき /永久放棄/
えいきゅうほしょう /永久保証/
えいきゅうほぞん /永久保存/
えいきゅうほぞんばん /永久保存版/
えいきょ /盈虚/
えいきょう /影響/永享;年号(1429-1441)/
えいきょうか /影響下/
えいきょうだい /影響大/
えいきょうちょうさ /影響調査/
えいきょうど /影響度/
えいきょうりょく /影響力/
えいきょく /郢曲/
えいぎょう /営業/
えいぎょうあんない /営業案内/
えいぎょういん /営業員/
えいぎょううんてん /営業運転/
えいぎょうか /営業課/
えいぎょうかいし /営業開始/
えいぎょうかちょう /営業課長/
えいぎょうかつどう /営業活動/
えいぎょうかんりか /営業管理課/
えいぎょうがい /営業外/
えいぎょうがいしゅうえき /営業外収益/
えいぎょうがいひよう /営業外費用/
えいぎょうがわ /営業側/
えいぎょうきそく /営業規則/
えいぎょうきゅうし /営業休止/
えいぎょうきょか /営業許可/
えいぎょうきょてん /営業拠点/
えいぎょうきろ /営業キロ;business kilometre/
えいぎょうけい /営業系/
えいぎょうけいすう /営業係数/営業系数/
えいぎょうけいたい /営業形態/
えいぎょうけん /営業権/
えいぎょうこうい /営業行為/
えいぎょうさき /営業先/
えいぎょうざいさん /営業財産/
えいぎょうしゃ /営業車/営業者/
えいぎょうしゅ /営業主/
えいぎょうしゅうにゅう /営業収入/
えいぎょうしゅうりょう /営業終了/
えいぎょうしゅうりょうご /営業終了後/
えいぎょうしょ /営業所/
えいぎょうしょく /営業職/
えいぎょうしょすう /営業所数/
えいぎょうしょとく /営業所得/
えいぎょうしょめい /営業所名/
えいぎょうじ /営業時/
えいぎょうじかん /営業時間/
えいぎょうじかんがい /営業時間外/
えいぎょうじかんない /営業時間内/
えいぎょうじょう /営業上/
えいぎょうじょうと /営業譲渡/
えいぎょうせいさく /営業政策/
えいぎょうせん /営業線/
えいぎょうそんしつ /営業損失/
えいぎょうたんとう /営業担当/
えいぎょうたんとうしゃ /営業担当者/
えいぎょうちゅう /営業中/
えいぎょうていし /営業停止/
えいぎょうていししょぶん /営業停止処分/
えいぎょうてき /営業的/
えいぎょうてん /営業店/
えいぎょうにっすう /営業日数/
えいぎょうねんど /営業年度/
えいぎょうばたけ /営業畑/
えいぎょうひ /営業費/
えいぎょうひみつ /営業秘密/
えいぎょうび /営業日/
えいぎょうぶ /営業部/
えいぎょうぶちょう /営業部長/
えいぎょうぶもん /営業部門/
えいぎょうほうこくしょ /営業報告書/
えいぎょうほんぶ /営業本部/
えいぎょうぼうがい /営業妨害/
えいぎょうまん /営業マン/
えいぎょうめん /営業面/
えいぎょうめんきょ /営業免許/
えいぎょうよう /営業用/
えいぎょうりえき /営業利益/
えいぎょうりょく /営業力/
えいぎょうれっしゃ /営業列車/
えいぎん /詠吟/
えいぐん /英軍/
えいけい /英系/鋭形/
えいけつ /英傑/永訣/
えいけん /英検/
えいげつ /盈月;満ちゆく月。⇔虧月/
えいげん /永源/
えいげんじ /永源寺/
えいこ /栄枯/栄子/英子/映子/瑛子/永子/暎子/江威子/
えいこう /栄光/曳航/曳行/栄孝/栄幸/営口/曳光/
えいこうき /曳航機/
えいこうだん /曳光弾/
えいこく /英国/
えいこくかいぐん /英国海軍/
えいこくがた /英国型/
えいこくがわ /英国側/
えいこくき /英国旗/
えいこくきかく /英国規格/
えいこくこうくう /英国航空/
えいこくこうし /英国公使/
えいこくこっきょうかい /英国国教会/
えいこくご /英国語/
えいこくしき /英国式/
えいこくしゃ /英国車/
えいこくじん /英国人/
えいこくせい /英国製/
えいこくない /英国内/
えいこくばん /英国版/英国盤/
えいこくぶつりがっかい /英国物理学会/
えいこくみん /英国民/
えいこくりゅう /英国流/
えいこくりょう /英国領/
えいこさくけん /永小作権/
えいこせいすい /栄枯盛衰/
えいこもじ /英小文字/
えいこん /英魂/
えいご /英語/英五;人名/
えいごあんない /英語案内/
えいごいがい /英語以外/
えいごう /永劫/
えいごうかいき /永劫回帰/
えいごか /英語科/英語化/
えいごかいわ /英語会話/
えいごがく /英語学/
えいごがくしゅう /英語学習/
えいごがっこう /英語学校/
えいごきじ /英語記事/
えいごきょういく /英語教育/
えいごきょういくばんぐみ /英語教育番組/
えいごきょうし /英語教師/
えいごきょく /英語局/
えいごけん /英語圏/
えいごけんてい /英語検定/
えいごげき /英語劇/
えいごじしょ /英語辞書/
えいごじてん /英語辞典/
えいごじん /英語人/
えいごだい /英語題/
えいごてき /英語的/
えいごとうろん /英語討論/
えいごにゅうりょく /英語入力/
えいごのうりょく /英語能力/
えいごはつおん /英語発音/
えいごばん /英語版/
えいごひょうき /英語表記/
えいごひょうげん /英語表現/
えいごひょうじ /英語表示/
えいごふう /英語風/
えいごぶん /英語文/
えいごぶんか /英語文化/
えいごほうそう /英語放送/
えいごめい /英語名/
えいごめいしょう /英語名称/
えいごめん /英語面/
えいごやく /英語訳/
えいごよう /英語用/
えいごりょく /英語力/
えいごろんぶん /英語論文/
えいさい /英才/栄西/穎才;≒英才 (NB:「穎」は穂先)/
えいさいきょういく /英才教育/
えいさく /栄作/英作/栄策/
えいさくぶん /英作文/
えいさつ /縊殺/
えいざぶろう /栄三郎/
えいざん /叡山/
えいざんでんしゃ /叡山電車/
えいざんでんてつ /叡山電鉄/
えいざんほんせん /叡山本線/
えいし /英紙/英詩/英資/衛士;†guard/衛視;†国会の守衛/英姿/詠史/
えいしき /英式;British/
えいしゃ /映写/泳者/営舎/影写;なぞって写す/
えいしゃき /映写機/
えいしゃく /栄爵/
えいしゃぼん /影写本/
えいしゃまく /映写幕/
えいしゅ /英主/
えいしゅう /瀛州;三神山の一/
えいしゅつ /映出/詠出/
えいしゅん /英俊/
えいしょ /英書/営所/
えいしょう /詠唱/永正;年号(1504-1521)/永承;年号(1046-1053)/
えいしょうぼん /影照本/影鈔本/
えいしょく /栄職/
えいしん /栄進/詠進/
えいじ /英字/嬰児/英二/英治/栄治/英司/栄二/英次/英志/栄次/英史/鋭二/永治;年号(1141-1142)/英嗣/永二/英児/
えいじし /英字紙/
えいじしんぶん /英字新聞/
えいじつ /永日/
えいじにゅうりょく /英字入力/
えいじへんかん /英字変換/
えいじゅ /衛戍/
えいじゅう /永住/
えいじゅうけん /永住権/
えいじゅうしゃ /永住者/
えいじゅびょういん /衛戍病院/
えいじょく /栄辱/
えいじよう /英字用/
えいじろう /英辞郎;英語辞書名。www.eijiro.jp/栄次郎;人名/
えいじん /英人/
えいすう /英数/
えいすうこく /英数国/
えいすうじ /英数字/
えいすうもじ /英数文字/
えいすけ /英介/英輔/栄介/
えいせい /衛生;†hygiene.「公衆-」/衛星;†satellite.「通信-」/永世;†permanent.「-名人」/永生;†long life/永逝;die/衞生;「衛」旧字/衞星;「衛」旧字/
えいせいか /衛生科/
えいせいかいせん /衛星回線/
えいせいかん /衛星間/
えいせいかんきょう /衛生環境/
えいせいかんり /衛生管理/
えいせいかんりしゃ /衛生管理者/
えいせいがく /衛生学/
えいせいきどう /衛星軌道/
えいせいきょく /衛生局/
えいせいぎょうせい /衛生行政/
えいせいけんさぎし /衛生検査技師;国家資格/
えいせいこう /衛生工/
えいせいこうがく /衛生工学/
えいせいこうほう /衛星航法/
えいせいこく /衛星国/
えいせいし /衛生士/
えいせいじょう /衛生上/
えいせいじょうたい /衛生状態/
えいせいせつび /衛生設備/
えいせいぞう /衛星像/
えいせいだい /衛星第/
えいせいだいいち /衛星第一/
えいせいだいに /衛星第二/
えいせいちゅうけい /衛星中継/
えいせいちゅうりつ /永世中立/
えいせいつうしん /衛星通信/
えいせいてき /衛生的/
えいせいてれび /衛星テレビ/
えいせいでんわ /衛星電話/
えいせいとうき /衛生陶器/
えいせいとし /衛星都市/
えいせいなまちゅうけい /衛星生中継/
えいせいひ /衛生費/
えいせいへい /衛生兵/
えいせいほうそう /衛星放送/
えいせいめいじん /永世名人/
えいせいめん /衛生面/
えいせん /曳船/鋭尖/
えいぜん /営繕/
えいそ /永祚;年号(989-990)/
えいそう /営巣/詠草/営倉/
えいぞう /映像;image/影像;絵姿/営造/栄三/英三/栄蔵/
えいぞうか /映像化/
えいぞうかいろ /映像回路/
えいぞうきき /映像機器/
えいぞうきょうりょく /映像協力/
えいぞうぎじゅつ /映像技術/
えいぞうけんきゅうかい /映像研究会/
えいぞうけんきゅうしょ /映像研究所/
えいぞうさい /映像祭/
えいぞうさくひん /映像作品/
えいぞうさっか /映像作家/
えいぞうしゅつりょく /映像出力/
えいぞうしりょう /映像資料/
えいぞうしんごう /映像信号/
えいぞうしんごうよう /映像信号用/
えいぞうじょうほう /映像情報/
えいぞうせいさくぶ /映像制作部/
えいぞうせかい /映像世界/
えいぞうそうち /映像装置/
えいぞうたいしょう /映像大賞/
えいぞうたんし /映像端子/
えいぞうてき /映像的/
えいぞうてんじ /映像展示/
えいぞうとくてん /映像特典/
えいぞうとし /映像都市/
えいぞうはいしん /映像配信/
えいぞうはくぶつかん /映像博物館/
えいぞうひょうげん /映像表現/
えいぞうぶつ /営造物/
えいぞうぶんか /映像文化/
えいぞうぶんぽう /映像文法/
えいぞうよう /映像用/
えいぞうようひん /映像用品/
えいぞうりょく /映像力/
えいぞうろん /映像論/
えいぞく /永続/
えいぞくか /永続化/
えいぞくせい /永続性/
えいぞくてき /永続的/
えいた /英太/
えいたい /永代/
えいたいくよう /永代供養/
えいたつ /栄達/英達/
えいたろう /英太郎/栄太郎/永太朗/
えいたん /詠嘆/詠歎/
えいたんご /英単語/
えいだ /栄田/英田/
えいだい /永代/英題/
えいだいさんぎょう /永大産業;[企業名]/
えいだつ /穎脱/
えいだん /英断/営団/帝都高速度交通営団;NB:現・東京メトロ ※abbrev/
えいだんえき /営団駅/
えいだんぎんざせん /営団銀座線;NB:現・東京メトロ銀座線/
えいだんしゃ /営団車/
えいだんちかてつ /営団地下鉄;NB:現・東京メトロ/
えいだんちよだ /営団千代田/
えいだんちよだせん /営団千代田線;NB:現・東京メトロ千代田線/
えいだんとうざいせん /営団東西線;NB:現・東京メトロ東西線/
えいだんなんぼくせん /営団南北線;NB:現・東京メトロ南北線/
えいだんひびやせん /営団日比谷線;NB:現・東京メトロ日比谷線/
えいだんゆうらくちょうせん /営団有楽町線;NB:現・東京メトロ有楽町線/
えいち /英知/叡智/英智/叡知/睿智/
えいちしゅっぱん /英知出版;[出版社名]/
えいちだいがく /英知大学/
えいちょう /永長;年号(1096-1097)/
えいてい /営庭/
えいてん /栄転/栄典/
えいでん /叡電/営田/
えいでんでまちやなぎ /叡電出町柳/
えいと /嬰ト/
えいとう /衛陶/
えいとく /永徳;年号(1381-1384)/
えいとたんちょう /嬰ト短調/
えいとちょうちょう /嬰ト長調/
えいどう /泳動/栄道/
えいどく /英独/
えいに /嬰ニ/
えいにたんちょう /嬰ニ短調/
えいにち /英日/
えいにちょうちょう /嬰ニ長調/
えいにん /永仁;年号(1293-1299)/
えいねん /永年/
えいねんきんぞく /永年勤続/
えいのう /営農/
えいは /嬰ハ/
えいはたんちょう /嬰ハ短調/
えいはちょうちょう /嬰ハ長調/
えいはつ /映発/
えいばん /英盤/
えいびん /鋭敏/
えいふう /英風/
えいふく /永福/
えいふくちょう /永福町/
えいふつ /英仏/
えいふつかいきょう /英仏海峡/
えいぶつ /詠物/
えいぶん /英文/叡聞/
えいぶんか /英文科/
えいぶんかいしゃく /英文解釈/
えいぶんかいせつしょ /英文解説書/
えいぶんがく /英文学/
えいぶんがくせんしゅう /英文学専修/
えいぶんざっし /英文雑誌/
えいぶんし /英文誌/
えいぶんしゅっぱんぶつ /英文出版物/
えいぶんせつめい /英文説明/
えいぶんひょうき /英文表記/
えいぶんぽう /英文法/
えいぶんめい /英文名/
えいへ /嬰ヘ/
えいへい /衛兵/
えいへいじ /永平寺/
えいへたんちょう /嬰ヘ短調/
えいへちょうちょう /嬰ヘ長調/
えいべい /英米/
えいべいぐん /英米軍/
えいべいじん /英米人/
えいべいぶんがく /英米文学/
えいべいほう /英米法/
えいべいりょうこく /英米両国/
えいべつ /永別/
えいほ /嬰ホ/
えいほう /泳法/永保;年号(1081-1084)/鋭鋒/英法/
えいほたんちょう /嬰ホ短調/
えいほちょうちょう /嬰ホ長調/
えいぽんど /英ポンド/
えいまい /英邁/
えいまん /永万;年号(1165-1166)/
えいみ /詠美/
えいみん /永眠/
えいめい /英明;brilliant/英名;English name/
えいめいかん /穎明館/
えいもじ /英文字/
えいもじひょうき /英文字表記/
えいもり /栄森/
えいもん /営門/
えいや /永夜/
えいやく /英訳/
えいゆう /英雄/
えいゆうぐんぞう /英雄群像/
えいゆうし /英雄視/
えいゆうしゅぎ /英雄主義;heroism/
えいゆうしんわ /英雄神話/
えいゆうじだい /英雄時代;heroic age/
えいゆうすうはい /英雄崇拝;hero-worship/
えいゆうたん /英雄譚;heroic(n.)/
えいゆうてき /英雄的/
えいゆうでん /英雄伝/
えいゆうでんせつ /英雄伝説/
えいゆうれつでん /英雄列伝/
えいよ /栄誉/
えいよう /栄養;nourriture/栄耀;glory/営養;=栄養/
えいようえいが /栄耀栄華/
えいようか /栄養価/
えいようかけいさん /栄養価計算/
えいようがく /栄養学/
えいようがくしゃ /栄養学者/
えいようき /栄養期/
えいようきかん /栄養器官/
えいようきのうしょくひん /栄養機能食品/
えいようきょうゆ /栄養教諭;[新語]/
えいようげん /栄養源/
えいようざい /栄養剤/
えいようし /栄養士/栄養枝/
えいようしっちょう /栄養失調/
えいようしどうかんり /栄養指導管理/
えいようしょうがい /栄養障害/
えいようしょく /栄養食/
えいようじょうたい /栄養状態/
えいようせいしょく /栄養生殖/
えいようそ /栄養素/
えいようたい /栄養体/
えいようてき /栄養的/
えいようはんしょく /栄養繁殖/
えいようふりょう /栄養不良/
えいようぶつ /栄養物;nutrition/
えいようぶん /栄養分/
えいようほきゅう /栄養補給/
えいようほきゅうしょくひん /栄養補給食品/
えいようほじょしょくひん /栄養補助食品/
えいようまんてん /栄養満点/
えいようりょう /栄養量/
えいらく /永楽/
えいらん /英蘭/
えいり /営利/鋭利/絵入り/栄利/
えいりか /営利化/
えいりかつどう /営利活動/
えいりきぎょう /営利企業/
えいりきょうげんぼん /絵入狂言本/
えいりこうい /営利行為/
えいりしゅぎ /営利主義/
えいりじぎょう /営利事業/
えいりせい /営利性/
えいりだんたい /営利団体/
えいりてき /営利的/
えいりほうじん /営利法人/
えいりもくてき /営利目的/
えいりもくてきりよう /営利目的利用/
えいりゃく /永暦;年号(1160-1161)/
えいりょ /叡慮/
えいりょう /英領/
えいりりよう /営利利用/
えいりん /映倫/営林/英鈴/
えいりんしょ /営林署;国有林の保護、監督を行う官庁/
えいりんしょちょう /営林署長/
えいれい /英霊/
えいれんぽう /英連邦/
えいろ /嬰ロ/
えいろく /永禄;年号(1558-1570)/
えいろたんちょう /嬰ロ短調/
えいろちょうちょう /嬰ロ長調/
えいろんぶん /英論文/
えいわ /英和/永和;年号(1375-1379)/
えいわじしょ /英和辞書/
えいわじてん /英和辞典/
えいわたいやくしゅうちんじしょ /英和対訳袖珍辞書/
えいわだいじてん /英和大辞典/
えいわちゅうじてん /英和中辞典/
えいん /会陰/
えいんせっかい /会陰切開/
えいんぶ /会陰部/
えいんれっしょう /会陰裂傷/
えうぽまちあか /エウポマチア科/Eupomatiaceae/
ええた /η/Η/
えかき /絵描き/絵書き/
えかきうた /絵書き歌/
えがお /笑顔/
えがきて /描き手/
えがしら /江頭/
えがたい /得難い/
えがみ /江上/
えがら /絵柄/
えがわ /江川/
えがわすぐる /江川卓/
えき /駅/液/益/役/疫;疫病/腋;わき/掖;≒腋/繹;演繹/懌;≒悦/驛;「駅」の旧字/易;貿易/蜴;蜥蜴(せきえき,トカゲ)/亦;また/奕;博奕/依帰/伯;佐伯,?/
えきあつぷれす /液圧プレス/
えきあんない /駅案内/
えきいん /駅員/
えきいんはいちえき /駅員配置駅/
えきうら /駅裏/
えきうり /駅売り/
えきえき /液液/
えきおん /液温/
えきか /液化/腋窩;わきのくぼみ/腋下;わきのした/液果;berry.⇔乾果/腋花;[園芸]axillary flower/
えきかかりいん /駅係員/
えきかがす /液化ガス/
えきかせきゆがす /液化石油ガス/
えきかちっそ /液化窒素/
えきかてんねんがす /液化天然ガス;liquefied natural gas(LNG)/
えきかん /駅間/
えきかんきょり /駅間距離/
えきが /腋芽/
えきがく /疫学/易学/
えきがくしゃ /疫学者/
えきがくてき /疫学的/
えきがくてきちょうさ /疫学的調査/
えきがわ /駅側/
えきき /疫鬼/
えききょう /易経/
えききん /益金/
えきぎゅう /役牛/
えきけん /益軒/
えきげしゃ /駅下車/
えきこうない /駅構内/
えきごと /駅毎/
えきざい /液剤/
えきしせつ /駅施設/
えきしゃ /駅舎/易者/
えきしゃあと /駅舎跡/
えきしゃさんゆう /益者三友/
えきしゅう /腋臭/
えきしゅうしょう /腋臭症/
えきしゅうへん /駅周辺/
えきしゅうへんちず /駅周辺地図/
えきしょう /液晶/
えきしょうがめん /液晶画面/
えきしょうてれび /液晶テレビ/
えきしょうでぃすぷれい /液晶ディスプレイ/
えきしょうぱねる /液晶パネル/
えきしょうひょうじ /液晶表示/
えきしょうもにたー /液晶モニター/
えきじたい /駅自体/
えきじゅう /液汁/益獣/
えきじょう /液状/
えきじょうか /液状化;地盤の-/
えきじょうかげんしょう /液状化現象/
えきす /越幾斯/
えきすう /駅数/
えきせい /液性/易姓;「-革命」/駅制;[律令制]/腋生;[植物]axillary/
えきせいかくめい /易姓革命/
えきせん /易占/
えきぜんぶ /駅全部/
えきそう /液相/
えきたい /液体/
えきたいくうき /液体空気;liquid air/
えきたいさんそ /液体酸素/
えきたいじょう /液体状/
えきたいせんざい /液体洗剤/
えきたいちっそ /液体窒素/
えきたいにんげん /液体人間/
えきたいねんりょう /液体燃料/
えきたいひりょう /液体肥料/
えきだん /易断/
えきちく /役畜/
えきちゅう /液中/益虫/
えきちょう /駅長/益鳥/
えきちょうあて /駅長宛/
えきちょうしつ /駅長室/
えきてい /駅逓/
えきてき /液滴/
えきてきか /液滴化/
えきでん /駅伝/驛傳/
えきでんたいかい /駅伝大会/
えきとう /駅頭/
えきどめ /駅止/駅止め/
えきない /駅内/
えきね /駅寝/
えきばいてん /駅売店/
えきばしゃ /駅馬車/
えきひ /液肥/
えきひょうじ /駅表示/
えきびょう /疫病/
えきびょうがみ /疫病神;やくびょうがみ?/
えきびる /駅ビル/
えきふ /役夫/
えきふきん /駅付近/
えきべつ /駅別/
えきべん /駅弁/液便/
えきべんぎょうしゃ /駅弁業者/
えきべんだいがく /駅弁大学;[口]戦後に粗製濫造された大学の賤称/
えきべんや /駅弁屋/
えきほう /液胞/
えきほんや /駅本屋/
えきまえ /駅前/
えきまえさいかいはつ /駅前再開発/
えきまえしょうてんがい /駅前商店街/
えきまえどおり /駅前通り/
えきまえひろば /駅前広場/
えきまえりょかん /駅前旅館/
えきむ /役務/
えきめい /駅名/
えきめいかいしょう /駅名改称/
えきめいばん /駅名板/
えきめいひょう /駅名標/駅名票/駅名表/
えきめいひょうじ /駅名表示/
えきもれ /液漏れ/
えきや /駅家/
えきゆう /益友/
えきらん /液卵;加工用の割った卵/
えきり /疫痢/
えきりようしゃ /駅利用者/
えきりんぼん /易林本/
えきれい /液冷/疫癘/
えきろ /駅路/
えぎ /江木/
えぎぬ /絵絹/
えぎょう /エ行/え行/
えくさ /exa;[SI接頭語]E,10^18/
えくすおーじゃん /XO醤/
えくぼ /靨/
えぐち /江口/
えぐみ /絵組/絵組み/刳味;タケノコ独特の-/
えけい /恵瓊/
えげ /会下/
えこ /依怙/
えこう /回向/
えこじ /依怙地/
えこだ /江古田/
えことば /絵詞/
えこひいき /依怙贔屓/
えこん /慧根/
えこんて /絵コンテ/
えごうらい /絵高麗/
えごころ /絵心/
えごのり /恵胡海苔/
えごま /荏胡麻/
えごよみ /絵暦/
えさ /餌/
えさか /江坂/
えさかてん /江坂店/
えさき /江崎/
えさぎ /餌木/
えさし /江刺/江差/枝幸/江指/
えさしおいわけ /江差追分/
えさだい /餌代/
えさづり /餌釣り/
えさば /餌場/
えさばこ /餌箱/
えさや /餌屋/
えさん /恵山/
えざ /会座/
えざき /江崎/
えざきぐりこ /江崎グリコ;[企業名]/
えざきれおな /江崎玲於奈/
えざら /絵皿/
えざわ /江沢/江澤/
えし /絵師/壊死/画師/
えしき /会式/
えしゃく /会釈/
えしゃじょうり /会者定離/
えじ /衛士/江地/
えじき /餌食/
えじぷと /埃及;Egypt/
えじぷとご /エジプト語;Egyptian/
えじぷとじん /エジプト人/
えじま /江島/江嶋/
えすえすせいやく /エスエス製薬;[企業名]/
えすえぬひ /ＳＮ比/SN比;signal-to-noise ratio/
えすえふしょうせつ /ＳＦ小説/SF小説/
えすがた /絵姿/
えすきもーけん /エスキモー犬/
えすきょく /Ｓ極/S極;south pole. 「方位磁石の-」/
えすさいず /Ｓサイズ/Sサイズ/
えすしき /S式;symbol-expression/
えすじ /Ｓ字/
えすせき /Ｓ席/
えすは /Ｓ波;横波/
えすびーしょくひん /エスビー食品;[企業名] NB:1992年7月以降の表記/ヱスビー食品;[企業名] NB:登記上の表記/
えず /絵図/
えずみ /江角/
えずめん /絵図面/
えずりこ /江釣子/
えせ /似非/似而非/
えそ /壊疽;[医]gangrene/狗母魚;lizard fish/
えそらごと /絵空事/
えぞ /蝦夷/
えぞいわな /蝦夷岩魚/
えぞう /絵像/
えぞえ /江副/
えぞしか /蝦夷鹿/
えぞち /蝦夷地/
えぞまつ /蝦夷松/
えぞら /江面/
えた /穢多/
えたい /得体/
えたじま /江田島/
えだ /枝/江田/荏田/
えだうち /枝打ち/
えだかり /枝刈り/
えだがり /枝刈り/
えだがわ /枝川/
えだがわり /枝変わり;[植物]bud variation. 枝単位の突然変異/
えだきりばさみ /枝切り鋏/
えだげ /枝毛/
えだじょう /枝状/
えだずみ /枝炭/
えだせん /枝線/
えだち /役/
えだなみ /枝並/
えだにく /枝肉/
えだにょう /支繞/
えだの /枝野;姓/
えだは /枝葉/
えだばり /枝針/
えだばん /枝番/
えだぶり /枝振り/
えだまつ /枝松/
えだまめ /枝豆/
えだみち /岐路/枝道/
えだわかれ /枝分かれ/枝わかれ/
えだん /エ段/
えち /乢/
えちがわ /愛知川/
えちご /越後/
えちごこうつう /越後交通/
えちごじし /越後獅子/
えちごせん /越後線/
えちごや /越後屋/
えちごゆざわ /越後湯沢/
えちごゆざわえき /越後湯沢駅/
えちぜん /越前/
えちぜんかいがん /越前海岸/
えちぜんがに /越前蟹/
えちぜんみさき /越前岬/
えちぜんやき /越前焼/
えっか /越夏;⇔越冬/
えっきょう /越境/
えっきょうしゃ /越境者/
えっくすおーじゃん /XO醤/
えっくすきゃく /Ｘ脚/X脚/
えっくすじく /Ｘ軸/X軸/
えっくすせん /Ｘ線/
えっくすせんしょくたい /X染色体;[生物]X-chromosome/Ｘ染色体;[生物]X-chromosome/
えっけん /謁見/越権/
えっけんこうい /越権行為/
えっしゅう /越州;越前・越中・越後/
えっせいしゅう /エッセイ集/
えっそ /越訴/
えっちゅう /越中/
えっちゅうおわらぶし /越中おわら節;[民謡]/
えっちゅうじま /越中島/
えっちゅうだいもんえき /越中大門駅/
えっちゅうふんどし /越中褌/
えっとう /越冬/
えっとうたい /越冬隊/
えっとうち /越冬地/
えっふぇるとう /エッフェル塔;la tour Eiffel/
えっぷく /悦服/
えっぺい /閲兵/
えっぺいしき /閲兵式/
えつ /悦;-に入る/閲;閲覧/咽;嗚咽/噎;む・せる/謁;謁見/粤;(中国南部の少数民族)/戉;≒鉞/越;優越/鉞;斧鉞/斉魚/
えつお /悦夫/
えつけ /絵付け/
えつこ /悦子/英津子/恵津子/えつ子/絵津子/
えつじ /悦司/悦次/
えつたろう /悦太郎/
えつづみ /兄鼓;大鼓/
えつどく /閲読/
えつなん /越南;Vietnam/
えつねん /越年/
えつねんそう /越年草/
えつもくしょう /悦目抄/
えつや /悦也/悦哉/
えつよ /悦代/
えつらく /悦楽/
えつらん /閲覧/
えつらんかのう /閲覧可能/
えつらんきょひ /閲覧拒否/
えつらんしつ /閲覧室/
えつらんしゃ /閲覧者/
えつらんせいきゅう /閲覧請求/
えつり /桟/
えつれき /閲歴/
えつろう /悦朗/
えづくり /絵作り/
えづけ /餌付け/
えづら /絵面/
えて /得手/
えてかって /得手勝手/
えてき /絵的/
えてこう /猿公/エテ公/猿猴;えんこう?/
えてして /得てして/
えてふえて /得手不得手/
えてんらく /越天楽;雅楽の曲名/
えでほん /絵手本/
えと /干支/江渡;姓/
えとう /江藤/衛藤/江頭/恵藤/
えとき /絵解き/
えとく /会得/
えとり /餌取り/
えとるりあご /エトルリア語;Etruscan/
えとるりあじん /エトルリア人;Etruscan/
えとろふ /択捉/
えど /江戸/穢土/
えどえ /江戸絵/
えどおもて /江戸表/
えどがろう /江戸家老;[日本史]⇔国家老/
えどがわ /江戸川/
えどがわく /江戸川区/
えどがわくみん /江戸川区民/
えどがわじょし /江戸川女子/
えどがわばし /江戸川橋/
えどがわらんぽ /江戸川乱歩/
えどがわらんぽしょう /江戸川乱歩賞/
えどき /江戸期/
えどくら /江戸蔵/
えどことば /江戸言葉/
えどこもん /江戸小紋/
えどご /江戸語/
えどさき /江戸崎/
えどさんざ /江戸三座/
えどざき /江戸崎/
えどじだい /江戸時代/
えどじだいこうき /江戸時代後期/
えどじょう /江戸城/
えどっこ /江戸っ子/
えどてん /江戸展/
えどばくふ /江戸幕府/
えどひがん /江戸彼岸/
えどふう /江戸風/
えどぶんがく /江戸文学/
えどま /江戸間/
えどまえ /江戸前/
えどむらさき /江戸紫/
えどや /江戸屋/
えな /恵那;地名/胞衣/絵奈/
えなが /柄長/
えなさん /恵那山;地名,/
えなざくら /恵那櫻/
えなつ /江夏/
えなみ /榎並/
えなめるがわ /エナメル革/
えなめるしつ /エナメル質;[解剖]enamel. 歯の表面/
えなめるせん /エナメル線/
えなり /江成/
えなんじ /淮南子;劉安/
えに /縁/
えにし /縁/
えにっき /絵日記/
えにわ /恵庭/
えぬえちけいほーる /ＮＨＫホール/
えぬかっけい /Ｎ角形/
えぬきょう /Ｎ響/
えぬきょく /Ｎ極/N極;north pole. 「方位磁針の-」/
えぬこ /Ｎ個/
えぬじげん /Ｎ次元/
えぬま /江沼/
えねるぎーぐん /エネルギー群/
えねるぎーげん /エネルギー源/
えねるぎーこうりつ /エネルギー効率/
えねるぎーしょう /エネルギー省/
えねるぎーせいさく /エネルギー政策/
えねるぎーそんしつ /エネルギー損失/
えねるぎーもんだい /エネルギー問題/
えの /榎/
えのき /榎/榎木/
えのきたけ /榎茸/
えのきだ /榎田/
えのきど /榎戸/
えのぐ /絵の具/絵具/
えのぐざら /絵の具皿/
えのこ /狗/
えのしま /江ノ島/江の島/
えのしません /江ノ島線/
えのぞの /榎園/
えのでん /江の電/
えのと /榎戸/
えのもと /榎本/
えはがき /絵葉書/絵はがき/
えはた /江畑/江幡/
えはだ /絵肌/
えはら /江原/荏原/
えばた /江端/
えばら /江原/荏原/
えばらこ /桧原湖/
えひめ /愛媛/
えひめけん /愛媛県/
えひめしんぶんしゃ /愛媛新聞社;[企業名]/
えひめだい /愛媛大/
えひめだいがく /愛媛大学/
えび /海老/蝦;=海老/蛯;=海老/鰕;=海老/葡萄;ぶどう。「-色」/
えびいも /蝦芋/海老芋/
えびいろ /葡萄色/
えびお /海老尾/
えびがため /海老固め/
えびがに /海老蟹;ざりがに/
えびさわ /海老沢/海老澤/
えびじゃこ /海老雑魚/
えびす /恵比須;豊漁神 (地名:姫路など)/恵比寿;≒恵比須 (地名:東京)/夷;語源:中国人以外の民族/戎;(≒夷) 語源:古代中国・北西部の異民族/蛭子/胡/狄;語源:古代中国・北方の異民族/貊;語源:古代中国・東北部のツングース族/
えびすがお /恵比寿顔/
えびすぐさ /恵比須草/夷草/
えびすこう /恵比須講/
えびすこうじょう /恵比寿工場/
えびすごころ /夷心/
えびすさま /恵比寿様/
えびすちょう /恵比寿町/
えびすのうお /恵比須の魚/
えびすばし /戎橋/
えびすほうこう /恵比寿方向/
えびすほうめん /恵比寿方面/
えびすや /蛭子屋/
えびせんべい /海老煎餅/
えびぞり /海老反り/
えびちゃ /海老茶/葡萄茶/
えびちゃいろ /海老茶色/
えびづか /海老塚/
えびづる /蝦蔓/
えびてん /エビ天/海老天/
えびな /海老名/蝦名/蛯名/
えびなし /海老名市/
えびね /恵比根/
えびはら /海老原/蛯原/
えびふらい /海老フライ/
えびら /箙/
えふ /衛府;[律令制]内裏の警備担当/
えふだ /絵札/
えふで /絵筆/
えぶっし /絵仏師/
えぷろんすがた /エプロン姿/
えべ /江辺/
えべつ /江別/
えべつえき /江別駅/
えほう /吉方/恵方;縁起の良い方角/
えほうまき /恵方巻/恵方巻き/
えほん /絵本/
えほんさっか /絵本作家/
えぼうしょ /絵奉書/
えぼし /烏帽子/
えぼしおや /烏帽子親/
えぼだい /えぼ鯛/
えぽ /ＥＰＯ/
えぽきしじゅし /エポキシ樹脂/
えま /絵馬/絵麻/江馬/
えまき /絵巻/
えまきもの /絵巻物/
えみ /笑み/恵美/絵美/映見/江見/栄美/恵実/笑/江民/
えみか /恵美香/
えみこ /恵美子/絵美子/英美子/江美子/栄美子/絵己子/
えみし /蝦夷/
えみや /江美弥;名/円宮;名/
えみり /恵美里/
えむかえ /江迎/
えむさいず /Ｍサイズ/Mサイズ/
えむら /江村/
えめらるどいろ /エメラルド色/
えもじ /絵文字/
えもじじゅくご /絵文字熟語/
えもと /江本/絵本/柄本/
えもの /獲物/得物/
えものがたり /絵物語/
えもん /衛門/衣紋/衣文/
えもんかけ /衣紋掛け/衣紋掛/
えもんふ /衛門府/
えやみ /瘧;マラリアなどの間欠熱/疫病み;流行病/
えよう /栄耀;-栄華/
えようえいが /栄耀栄華/
えら /鰓/腮/江良/
えらーおん /エラー音/
えらーしょり /エラー処理/
えらーりつ /エラー率/
えらあな /鰓孔;[生物]gill slit/
えらこきゅう /鰓呼吸/
えらさ /偉さ/
えらびかた /選び方/
えらぶた /鰓蓋;opercle/
えらぶつ /豪物/偉物/
えり /襟;=衿/衿;=襟/絵里/恵理/絵理/恵里/恵利/英理/愛理/衣里;名/江利/絵莉/枝里/惠理/愛莉/衣理/
えりあか /襟垢/
えりあし /襟足/
えりうら /襟裏/
えりか /恵理香/絵里花/惠理香/江利香/
えりかざり /襟飾り/
えりがみ /襟髪/
えりくび /襟首/
えりぐり /襟刳り/
えりこ /えり子/恵理子/絵理子/江梨子/恵里子/江里子/英理子/英里子/江利子/絵梨子/悦吏子;名/
えりごのみ /選り好み/えり好み/
えりさ /恵利沙/
えりさき /襟先;[服飾]/
えりしょう /襟章/衿章/
えりすぐり /選りすぐり/
えりぜきゅう /エリゼ宮;フランスの大統領官邸。elysee.fr/
えりぜに /撰り銭/
えりだぬすざ /エリダヌス座;Eridanus(Eri)/
えりな /江理奈/
えりぬき /選り抜き/
えりはば /襟幅;[服飾]/
えりまき /襟巻/
えりまきとかげ /襟巻蜥蜴/
えりまわり /襟周り;[服飾]/襟回り/
えりみ /恵里美/
えりもと /襟元/
えりもみさき /襟裳岬/
えるえるきょうしつ /LL教室/
えるえるさいず /ＬＬサイズ/LLサイズ/
えるさいず /Ｌサイズ/Lサイズ/
えるびうむ /Er/Erbium/
えれつ /エ列/え列/
えろがぞう /エロ画像/
えろほん /エロ本/
えん /円/縁/塩/園/苑/宴/艶/焉;(助字)終焉/嫣;嫣然/篶;(細竹)すず/鉛;鉛直/沿;沿岸/堰;(せき)堰堤/偃;偃月/焔;火焔/閻;閻魔/炎;火炎/煙;禁煙/烟;「煙」の異体字/厭;厭戦/魘;うな・される/黶;あざ/燕;(つばめ)海燕/嚥;嚥下/臙;臙脂/讌;うたげ/捐;義捐金/悁/援;援助/媛;(ひめ)才媛/湲/爰;ここに/猿;野猿/遠;遠方/袁;袁紹/轅;ながえ/薗;「園」の旧字(人名用漢字)/延;延長/筵;むしろ/蜒;蚰蜒/奄;気息奄々/掩;掩護射撃/淹;い・れる/閹;閹官(=宦官)/宛;あて/怨;怨恨/鴛;鴛鴦/婉;婉曲/蜿;蜿々/冤;冤罪/寃;「冤」の異体字/簷;のき/檐;のき/掾/櫞;枸櫞酸/演;演説/垣;かき/鳶;とび/淵;深淵/衍;敷衍/艷;「艶」の旧字/鹽;「塩」の旧字/圓;「円」の旧字(人名用漢字)/圜/渕;「淵」の異体字1/渊;「淵」の異体字2/覃/閼/￥/
えんあん /塩安;塩化アンモニウム/
えんい /遠位/
えんいた /縁板/
えんいん /遠因/延引/援引/
えんう /煙雨/
えんうり /円売り/
えんうん /煙雲/
えんうんどう /円運動/
えんえい /遠泳/
えんえき /演繹/
えんえきぎ /演繹木/
えんえきけい /演繹系/
えんえきたいけい /演繹体系/
えんえきてき /演繹的/
えんえきほう /演繹法/
えんえきろんりがく /演繹論理学/
えんえん /延々;endless/炎々;-と燃える/奄々;気息-/蜿蜒;-長蛇の列/蜿々;≒蜿蜒/延延/炎炎/奄奄;気息-/蜿蜿;≒蜿蜒/
えんお /厭悪/
えんおう /鴛鴦;おしどり/延応;年号(1239-1240)/閻王/
えんか /演歌/塩化/嚥下/円貨/煙火;(主に[法])花火/艶歌/円価/怨歌/煙霞/縁家/烟霞/
えんか> /塩化;[化学]chloride/
えんかあえん /塩化亜鉛/
えんかい /宴会/沿海/延会/遠海/
えんかいおう /塩化硫黄/
えんかいがかり /宴会係/
えんかいげい /宴会芸/
えんかいしゅう /沿海州/
えんかいしょく /鉛灰色/
えんかいじょう /宴会場/
えんかいもくてき /宴会目的/
えんかいや /宴会屋/
えんかいよう /宴会用/
えんかかしゅ /演歌歌手/
えんかきん /塩化金;[化学]AuCl,AuCl2/
えんかぎん /塩化銀;[化学]AgCl. フイルム原料/
えんかく /沿革/遠隔/
えんかくいりょう /遠隔医療;[医]/
えんかくかんし /遠隔監視/
えんかくさよう /遠隔作用/
えんかくそうさ /遠隔操作/
えんかくそくてい /遠隔測定;telemetry/
えんかくち /遠隔地/
えんかくりょく /遠隔力/
えんかけい /演歌系/
えんかすいぎん /塩化水銀;[化学]HgCl2,Hg2Cl2/
えんかすいそ /塩化水素;[化学]HCl/
えんかちょう /演歌調/
えんかつ /円滑/
えんかつか /円滑化/
えんかつせい /円滑性/
えんかてつ /塩化鉄;[化学]FeCl2,FeCl3/
えんかどう /塩化銅;[化学]CuCl,CuCl2/
えんかびにる /塩化ビニル;vinyl chloride/
えんかびにるじゅし /塩化ビニル樹脂/
えんかぶつ /塩化物/
えんかぶもん /演歌部門/
えんかる /遠軽/
えんかわ /圓川;姓/
えんかわせ /円為替/
えんかん /円環/煙管/鉛管/
えんかんぎょ /塩乾魚/
えんかんさん /円換算/
えんかんじょう /円環状/
えんかんすう /円関数/
えんがい /塩害/円外/円買い/煙害/円蓋/鉛害/掩蓋/
えんがく /縁覚/
えんがる /遠軽/
えんがわ /縁側/
えんがん /沿岸/遠眼/
えんがんぎょ /沿岸魚;littoral fish/
えんがんぎょぎょう /沿岸漁業/
えんがんけいびたい /沿岸警備隊/
えんがんちいき /沿岸地域/
えんがんぶ /沿岸部/
えんがんゆうしょう /沿岸湧昇/
えんき /延期/塩基/円規/
えんきごう /円記号;￥/
えんきど /塩基度;basicity/
えんきどう /円軌道/
えんきはいれつ /塩基配列/
えんきゅう /延久;年号(1069-1074)/円球/円丘/
えんきょう /延享;年号(1744-1748)/燕京/延慶;年号(1308-1311)/円鏡/
えんきょく /婉曲/
えんきょくひょうげん /婉曲表現/
えんきょり /遠距離/
えんきょりこうげき /遠距離攻撃/
えんきょりじゅしん /遠距離受信/
えんきょりつうがくしゃ /遠距離通学者/
えんきょりつうきん /遠距離通勤/
えんきょりつうきんしゃ /遠距離通勤者/
えんきょりれんあい /遠距離恋愛/
えんきり /縁切り/
えんきりでら /縁切寺/縁切り寺/
えんきん /遠近/
えんきんかん /遠近感/
えんきんほう /遠近法/
えんきんりょうよう /遠近両用/
えんぎ /演技/縁起/演義;†わかりやすく・面白く書く。『三国志-』/延喜;年号(901-23)/演戯;†play. 『ガラス玉-』(Hesse)/
えんぎかい /演技会/
えんぎしき /延喜式/
えんぎしょ /縁起書/
えんぎせい /演技性/
えんぎなおし /縁起直し/
えんぎは /演技派/
えんぎもの /縁起物/
えんぎょ /塩魚/
えんぎりょく /演技力/
えんくう /円空/
えんぐみ /縁組/
えんぐらふ /円グラフ/
えんぐん /援軍/
えんけい /円形/遠景/燕京/冤刑/
えんけいきょうぎじょう /円形競技場/
えんけいげきじょう /円形劇場/
えんけいだつもうしょう /円形脱毛症;[医]/
えんけいだんめん /円形断面/
えんけいひょうしき /円形標識/
えんけん /偃蹇/
えんげ /嚥下/
えんげい /園芸/演芸/園藝/
えんげいか /園芸家/
えんげいざっし /園芸雑誌/
えんげいしゅ /園芸種/
えんげいじょう /演芸場/
えんげいたいしょう /演芸大賞/
えんげいてん /園芸店/
えんげいひんしゅ /園芸品種/
えんげいぶ /園芸部/
えんげいめい /園芸名/
えんげいよう /園芸用/
えんげき /演劇/
えんげきかつどう /演劇活動/
えんげきかんけい /演劇関係/
えんげきさい /演劇祭/
えんげきしゅうだん /演劇集団/
えんげきてき /演劇的/
えんげきぶ /演劇部/
えんげきよう /演劇用/
えんげきりろん /演劇理論/
えんげきろん /演劇論/
えんげつ /偃月/
えんげつとう /偃月刀/
えんげるけいすう /エンゲル係数;[経済]Engel's coefficient. (食費÷消費支出)/
えんげん /淵源/延元;年号(1336-1340)/怨言/
えんこ /縁故/円弧/塩湖/⌒;arc/
えんこう /援交;[新語]援助交際/円光/猿猴/
えんこうきんこう /遠交近攻/
えんこうじばん /円光寺版/
えんこうるい /円口類/
えんこく /遠国/
えんこけい /円弧形/
えんこさい /縁故債;≒私募債/
えんこじょう /円弧上/
えんこん /怨恨/
えんご /援護/縁語/掩護/婉語/
えんごか /援護下/
えんごく /遠国/
えんごさく /延胡索/
えんごしゃげき /援護射撃/掩護射撃/
えんさ /怨嗟/
えんさき /縁先/
えんさつ /円札/
えんさん /塩酸/演算;えんざん/
えんさんし /演算子/
えんざ /円座/宴座/縁座/縁坐;=縁座/円坐;=円座/
えんざい /冤罪/寃罪/
えんざん /演算/塩山/遠山/圓山/鉛槧/
えんざんか /演算化/
えんざんかいすう /演算回数/
えんざんかいろ /演算回路/
えんざんき /演算器/演算機/
えんざんきごう /演算記号/
えんざんけっか /演算結果/
えんざんごさ /演算誤差/
えんざんし /演算子/
えんざんしき /演算式/
えんざんじかん /演算時間/
えんざんじゅんい /演算順位/
えんざんじゅんじょ /演算順序/
えんざんすう /演算数/
えんざんせいど /演算精度/
えんざんせいのう /演算性能/
えんざんそうち /演算装置/
えんざんそくど /演算速度/
えんざんのうりょく /演算能力/
えんざんぶ /演算部/
えんざんほう /演算法/
えんざんめい /演算名/
えんざんりょう /演算量/
えんし /遠視/艶姿/
えんしつ /煙室/
えんしゃ /演者/園舎/
えんしゃっかん /円借款/
えんしゅう /演習/遠州/円周/怨讐/円宗/
えんしゅうおおはし /遠州大橋/
えんしゅうかく /円周角;[数学]「共通の弧の-は等しい/
えんしゅうしえん /演習支援/
えんしゅうしつ /演習室/
えんしゅうしょ /演習書/
えんしゅうじょう /演習場/円周上/
えんしゅうてつどう /遠州鉄道/
えんしゅうべん /遠州弁/
えんしゅうもんだい /演習問題/
えんしゅうりつ /円周率/
えんしゅうりん /演習林/
えんしゅつ /演出/
えんしゅついと /演出意図/
えんしゅつか /演出家/
えんしゅつしゃ /演出者/
えんしゅつじ /演出時/
えんしゅつじょう /演出上/
えんしゅつてき /演出的/
えんしゅつほう /演出法/
えんしゅつめん /演出面/
えんしょ /炎暑/艶書/縁書/
えんしょう /炎症/延焼/艶笑/袁紹;人名,三国志/円生/煙硝/遠称/
えんしょうじ /円勝寺/
えんしょく /炎色/焔色/怨色/
えんしょくせい /演色性/
えんしょくはんのう /炎色反応/
えんしん /延伸/遠心/円心/円唇/
えんしんか /延伸化/円唇化;[音声学](lip-)rounding/
えんしんかじょ /遠心花序/
えんしんしき /遠心式/
えんしんせい /遠心性/
えんしんせいしんけい /遠心性神経/
えんしんちゅうぞうき /遠心鋳造機/
えんしんてき /遠心的/
えんしんぶぶん /延伸部分/
えんしんぶんり /遠心分離/
えんしんぶんりき /遠心分離機/遠心分離器/
えんしんぼいん /円唇母音;[音声学]round vowel/
えんしんりょく /遠心力/
えんじ /園児/臙脂;dark red/燕脂;=臙脂/衍字/槐;姓/
えんじいろ /臙脂色/
えんじたち /園児達/
えんじつてん /遠日点/
えんじて /演じ手/
えんじゃ /演者/縁者/
えんじゃく /燕雀/
えんじゅ /槐/
えんじゅく /円熟/
えんじゅくみ /円熟味/
えんじゅつ /演述/
えんじゅんれつ /円順列/
えんじょ /援助/
えんじょう /炎上/円状/遠城/
えんじょうじ /円城寺/
えんじょがく /援助額/
えんじょきん /援助金/
えんじょこうさい /援助交際/
えんじょこく /援助国/
えんじょだんたい /援助団体/
えんじょひ /援助費/
えんじょぶっし /援助物資/
えんじん /猿人/円陣/遠人/煙塵/厭人/閹人/
えんじんおん /エンジン音/
えんすい /円錐/塩水/鉛錘/
えんすいかじょ /円錐花序/
えんすいがた /円錐型/
えんすいきょくせん /円錐曲線/
えんすいけい /円錐形/
えんすいこ /塩水湖/
えんすいこう /塩水港/
えんすいじょう /円錐状/
えんすいずほう /円錐図法/
えんすいだい /円錐台/
えんすいめん /円錐面/
えんずい /延髄/
えんずいぎり /延髄斬/
えんせい /遠征/延性/厭世/縁生/
えんせいがい /袁世凱/
えんせいさき /遠征先/
えんせいしゅぎ /厭世主義;pesimism/
えんせいたい /遠征隊/
えんせいちゅう /遠征中/
えんせいてき /厭世的/
えんせいひ /遠征費/
えんせき /縁石/宴席/遠赤/塩析/遠戚/
えんせきがいせん /遠赤外線/
えんせきもんだい /円積問題/
えんせん /沿線/厭戦/塩泉/
えんせんじゅうみん /沿線住民/
えんせんじんこう /沿線人口/
えんせんず /円線図/
えんせんぜんたい /沿線全体/
えんせんちいき /沿線地域/
えんぜつ /演説/演舌/
えんぜつしゅう /演説集/
えんぜつほう /演説法/
えんぜん /艶然;にっこり/嫣然;≒艶然/婉然;しなやか/宛然;あたかも/
えんそ /塩素;Cl/遠祖/塩酢;[文語]不可欠な調味料・食品/Cl/Chlorine/
えんそう /演奏/燕巣/
えんそうか /演奏家/
えんそうかい /演奏会/
えんそうかいけいしき /演奏会形式/
えんそうかいし /演奏開始/
えんそうかつどう /演奏活動/
えんそうかのう /演奏可能/
えんそうきかい /演奏機会/
えんそうきごう /演奏記号/
えんそうきょく /演奏曲/
えんそうきょくもく /演奏曲目/
えんそうぎじゅつ /演奏技術/
えんそうけいしき /演奏形式/
えんそうけいたい /演奏形態/
えんそうけん /演奏権/
えんそうこうか /演奏効果/
えんそうご /演奏後/
えんそうしゃ /演奏者/
えんそうしゃめい /演奏者名/
えんそうしゅうりょうご /演奏終了後/
えんそうじ /演奏時/
えんそうじかん /演奏時間/
えんそうじたい /演奏自体/
えんそうじょう /演奏上/
えんそうじょうほう /演奏情報/
えんそうせいぎょ /演奏制御/
えんそうちゅう /演奏中/
えんそうないよう /演奏内容/
えんそうのうりょく /演奏能力/
えんそうば /円相場/
えんそうひょうげん /演奏表現/
えんそうふのう /演奏不能/
えんそうほう /演奏法/
えんそうようしき /演奏様式/
えんそうりょく /演奏力/
えんそうりょこう /演奏旅行/
えんそうれい /演奏例/
えんそうれんしゅう /演奏練習/
えんそく /遠足/
えんそくこ /堰塞湖/
えんそけい /塩素系/
えんそけいさっきんざい /塩素系殺菌剤/
えんそけいひょうはくざい /塩素系漂白剤/
えんそさん /塩素酸/
えんそしょうどく /塩素消毒/
えんそひょうはく /塩素漂白/
えんぞう /塩蔵;-ワカメ,-昆布/円蔵/
えんた /遠田/苑田/
えんたい /延滞/掩体/淹滞/
えんたいきん /延滞金/
えんたいぜい /延滞税;delinquency tax. 現行14.6%/
えんたいぶん /延滞分/
えんたいりそく /延滞利息/
えんたいりょう /延滞料/
えんたく /円卓/
えんたくかいぎ /円卓会議/
えんたくものがたり /円卓物語/
えんたん /鉛丹/
えんたんい /円単位/
えんたんいろ /鉛丹色;minium/
えんだ /遠田/苑田/
えんだい /演題/遠大/演台/縁台/円台/
えんだか /円高/
えんだかさえきかんげん /円高差益還元/
えんだて /円建て/
えんだま /円玉/
えんだん /縁談/演壇/
えんち /園地/遠地/園池;†(いけ)/
えんちくでんち /鉛蓄電池/
えんちてん /遠地点/
えんちゃく /延着/
えんちゅう /円柱/
えんちゅうじょう /円柱状/
えんちゅうめん /円柱面/
えんちょう /延長;年号(923-931)/園長/円頂/
えんちょううんてん /延長運転/
えんちょうきかんちゅう /延長期間中/
えんちょうきゅう /円頂丘/
えんちょうくかん /延長区間/
えんちょうけいかく /延長計画/
えんちょうこうじ /延長工事/
えんちょうこくい /円頂黒衣/
えんちょうじょう /延長上/
えんちょうせん /延長線/延長戦/
えんちょうせんじょう /延長線上/
えんちょうぜんはん /延長前半/
えんちょうぶ /延長部/
えんちょうぶぶん /延長部分/
えんちょく /鉛直/
えんちょくこうぞう /鉛直構造/
えんちょくせん /鉛直線/
えんちょくほうこう /鉛直方向/
えんちん /遠沈/
えんつづき /縁続き/
えんてい /園庭;garden/堰堤;dam/園丁;gardener/
えんてつ /遠鉄/
えんてつでんしゃ /遠鉄電車/
えんてん /炎天/遠点/
えんてんか /炎天下/
えんてんかつだつ /円転滑脱/
えんでん /塩田/
えんとう /円筒/遠投/遠島/円頭/煙筒/
えんとうけい /円筒形/円筒型/
えんとうじょう /円筒状/
えんとうずほう /円筒図法/
えんとく /延徳;年号(1489-1492)/
えんとつ /煙突/
えんど /塩度/
えんどう /遠藤/沿道/豌豆/羨道;墓室に通じる地下道/筵道/
えんどうしゅうさく /遠藤周作/
えんどうまめ /豌豆豆/
えんどおい /縁遠い/
えんどく /鉛毒/煙毒/
えんどる /円ドル/
えんない /園内/円内/
えんないあんない /園内案内/
えんにち /縁日/
えんにゅう /衍入/
えんにょう /延繞;[部首]/
えんねつ /炎熱/
えんねん /延年/
えんのう /延納/
えんのぎょうじゃ /役行者/
えんのした /縁の下/
えんのすけ /猿之助/
えんば /焉馬/
えんばく /燕麦/
えんばん /円盤/円板/鉛版/
えんばんがた /円盤型/
えんばんじょう /円盤状/
えんばんなげ /円盤投げ;陸上競技/
えんばんぶ /円盤部/
えんぱく /延泊/鉛白/
えんぱくかのう /延泊可能/
えんぱくぶん /延泊分/
えんぱくりょうきん /延泊料金/
えんぱつ /延発/
えんび /燕尾/塩ビ/
えんびかん /塩ビ管/
えんびふく /燕尾服/
えんぴ /猿臂/円匙/
えんぴつ /鉛筆/
えんぴつけずり /鉛筆削り/
えんぶ /演舞;†(dance)「-場」/演武;†「空手の-」/円舞;rondeau/
えんぶきょく /円舞曲/
えんぶん /塩分/延文;年号(1356-1361)/艶聞/艶文/
えんぶんのうど /塩分濃度/
えんぶんれん /遠文連/
えんぷく /艶福/
えんぷん /円墳/
えんへんこう /円偏光/
えんべつ /遠別/
えんぺい /掩蔽/援兵/
えんぺん /縁辺/
えんぺんたいざ /縁辺胎座/
えんぼう /遠望/遠謀/怨望/
えんぼうしんりょ /遠謀深慮/
えんぽう /遠方/延宝;年号(1673-1681)/演報/
えんぽうば /遠方場/
えんぽん /円本/艶本/
えんま /閻魔/絵馬/
えんまがお /閻魔顔/
えんまく /煙幕/
えんまだいおう /閻魔大王/
えんまちょう /閻魔帳/
えんまん /円満/
えんまんかいけつ /円満解決/
えんまんぐそく /円満具足/
えんみらい /遠未来/
えんむ /煙霧/
えんむすび /縁結び/
えんめい /延命/艶名/
えんめいこうじ /延命工事/
えんめいちりょう /延命治療/
えんもく /演目/
えんもくとじ /鳶目兎耳/
えんや /塩冶/艶冶/
えんやす /円安/
えんゆ /縁由/
えんゆう /円融/
えんゆうかい /園遊会/宴遊会/
えんゆうさんだい /円融三諦/
えんゆうてんのう /円融天皇/
えんゆうむげ /円融無碍/
えんよう /援用/遠洋/艶容/
えんようぎょぎょう /遠洋漁業/
えんようこうかい /遠洋航海/
えんらい /遠来/遠雷/
えんらく /猿楽/円楽/宴楽/
えんらくちょう /猿楽町/
えんり /厭離/
えんりえど /厭離穢土/
えんりゃく /延暦;年号(782-806)/
えんりゃくじ /延暦寺/
えんりゅう /淹留/
えんりょ /遠慮/
えんりょがち /遠慮勝ち/
えんりん /園林/
えんる /遠流/
えんるい /塩類;[化学]salt/縁類/
えんれい /艶麗/延齢/
えんれいそう /延齢草/
えんろ /遠路/
お /尾/御/汚/緒/小/雄/牡/男/悪;悪寒/苧;hemp/麻;hemp/於/唹/淤;どろ/嗚;(擬声語.「鳴」とは別字)/塢;どて/乎;(呉音)乎古止点/生;(人名読み)/和;(人名読み)/夫;(人名読み)/央;(人名読み)/将;(人名読み)/勇;(人名読み)/郎;(人名読み)/朗;(人名読み)/穂;(人名読み)/桜;?/織;?/
お> /御/牡/
おーがた /Ｏ型/O型/
おーきゃく /Ｏ脚/O脚/
おーすとらりあ /濠太剌利;Australia/
おーすとらりあさん /オーストラリア産/
おーすとらりあじん /オーストラリア人/
おーすとらりあたいりく /オーストラリア大陸/
おーすとりあ /墺太利;Austria/
おーすとりあじん /オーストリア人/
おーすとろねしあごぞく /オーストロネシア語族;[言語]Austronesian/
おーとましゃ /オートマ車/
おーとむぎ /オート麦/
おーなーめい /オーナー名/
おーぷんかかく /オープン価格/
おーぷんせん /オープン戦;非公式試合/
おーむ /Ω/王蟲/
おーやんふぃふぃ /欧陽菲菲/
おーるすたーせん /オールスター戦/
おーれ /ＯＲＥ/
おあ /∪/∨/
おあいそ /お愛想/
おあいて /お相手/御相手/
おあいにくさま /御生憎様/
おあがり /お上がり/
おあげ /お揚げ/
おあし /御足/
おあじ /お味/
おあずかり /お預り/お預/
おあずけ /お預け/
おあそび /お遊び/
おあふとう /オアフ島/
おあらため /お改め/
おい /甥/笈/追/老い/及/
おいうち /追い討ち/追い打ち/追い撃ち/追討ち/追打ち/追撃ち/
おいえ /尾家/
おいえげい /お家芸/御家芸/御家藝/
おいえそうどう /御家騒動/
おいえりゅう /御家流/
おいおい /追い追い/追々/
おいかぜ /追い風/追風/
おいかわ /及川/追川/生川/
おいがつお /追い鰹/
おいけ /御池/
おいこし /追い越し/追越/追越し/
おいこしえき /追越駅/
おいこししゃせん /追越車線/
おいこみ /追い込み/追込/追込み/
おいこみうま /追い込み馬/追込み馬/
おいこん /追いコン/
おいごえ /追い肥/追肥/
おいさき /老い先/生い先/
おいしゃ /お医者/
おいしゃさま /お医者様/
おいしゃさん /お医者さん/
おいしょう /追証;追証拠金/
おいしょうこきん /追証拠金/
おいしんぼ /美味しんぼ/
おいせん /追い銭/追銭;盗人に-/
おいそぎ /お急ぎ/
おいたち /生い立ち/生立ち/
おいたて /追立て/
おいだき /追い炊き/追い焚/追炊き/
おいだし /追い出し/追出し/追出/
おいだしこんぱ /追い出しコンパ/
おいち /尾市/お市/
おいっこ /甥っ子/
おいつ /老津/
おいつおわれつ /追いつ追われつ/
おいて /於て/追風/於/
おいてきぼり /置いてきぼり/
おいてけぼり /置いてけ堀;ひどいや/
おいで /お出で/御出で/
おいとま /御暇/お暇/
おいのこぶみ /笈の小文;芭蕉/
おいのり /お祈り/
おいはぎ /追剥/追い剥ぎ/
おいはま /生浜/追浜/
おいばね /追羽根/
おいばらい /追い払い/
おいべ /及部/
おいぼし /追星;[生物]/
おいぼれ /老いぼれ/
おいまつ /老松/
おいまわし /追廻/追い回し;使い走り/追回し/
おいみどり /老緑/
おいめ /負い目/
おいめい /甥姪/
おいらく /老いらく/
おいらせ /奥入瀬/
おいらん /花魁/
おいろ /御色/
おいろけ /お色気/
おいろなおし /お色直し/御色直し/
おいわ /お岩;四谷怪談/
おいわい /お祝い/御祝/御祝い/
おいわけ /追分/
おいわけちょう /追分町/
おいわけぶし /追分節;[民謡]江差-/
おう /王/欧/翁/黄/横/皇;皇女/凰;鳳凰/惶;おそ・れる/応;応用/應;「応」の旧字(人名用漢字)/央;中央/怏/殃;余殃/泱/秧;さなえ/鞅;むながい/鴎;鴎外/嘔;嘔吐/歐;「欧」の旧字/殴;殴打/毆;「殴」の旧字/甌/謳;謳歌/奥/奧;「奥」の旧字(人名用漢字)/襖;ふすま/墺;墺太利(Austria)/懊;懊悩/澳;オキ/押;押収/鴨;かも/閘;閘門(こうもん)/往;往復/徃;「往」の異体字/旺;旺盛/枉;ま・げる/汪/桜;桜花/櫻;「桜」の旧字(人名用漢字)/嚶;嚶鳴/罌;罌粟/鸚;鸚鵡/凹;凹凸/媼;おうな/鴬;「鶯」の異体字/泓;ふかい/浤/瓮/蓊/鏖;鏖殺/姶/邑;(呉音) むら/悒;(呉音) 悒鬱/
おうあ /欧亜/歐亞/
おうあん /応安;年号(1368-1375)/
おうあんせき /王安石;1021-86/
おうい /王位/横位/王威/
おういけいしょう /王位継承/
おういけいしょうしゃ /王位継承者/
おういせん /王位戦/
おういつ /横溢/汪溢;=横溢/
おういん /押印/押韻/桜蔭/
おういんこうこう /桜蔭高校/
おういんご /欧印語/
おういんし /押韻詩;⇔無韻詩/
おうう /奥羽/
おううせん /奥羽線/
おううん /桜雲/
おうえ /黄衣/
おうえい /応永;年号(1394-1428)/
おうえん /応援/
おうえんえんぜつ /応援演説/
おうえんか /応援歌/
おうえんせき /応援席/
おうえんだん /応援団/
おうえんだんいん /応援団員/
おうえんだんちょう /応援団長/
おうえんぶ /応援部/
おうえんぶいん /応援部員/
おうえんよう /応援用/
おうお /大魚/
おうおう /往々;-にして/怏々;-として楽しまず/汪々;水・度量が広い/怏怏/
おうか /桜花/謳歌/押下/応化/欧化/王化/櫻花;「桜」旧字/
おうかがい /お伺い/
おうかく /旺角/凹角/
おうかくまく /横隔膜/横膈膜;本来の表記/
おうかざい /横架材;[建築]梁・桁・棟木など/
おうかしゅぎ /欧化主義/
おうかしょう /桜花賞/
おうかしょうぐみ /桜花賞組/
おうかしょうば /桜花賞馬/
おうかじ /押下時/
おうかっしょく /黄褐色/
おうからんまん /桜花爛漫/
おうかん /王冠/往還/
おうが /横臥/
おうがい /鴎外/
おうがく /王学;陽明学/
おうがた /凹型/
おうき /嘔気/応器/
おうきゅう /応急/王宮/
おうきゅうきゅうごしょち /応急救護処置/
おうきゅうしゅうり /応急修理/
おうきゅうしょち /応急処置/
おうきゅうそち /応急措置/
おうきゅうたいさく /応急対策/
おうきゅうてあて /応急手当/
おうきゅうてき /応急的/
おうぎ /扇/奥義;極意。「おくぎ」ともいう/奥儀;=奥義/横議;勝手に論議すること/
おうぎがた /扇形/
おうぎがやつ /扇ヶ谷/
おうぎさわ /扇沢/
おうぎし /王羲之;人名/
おうぎしょ /奥義書/
おうぎじょう /扇状/
おうぎや /扇谷/
おうぎょく /黄玉/
おうけ /王家/
おうけつ /甌穴/
おうけとり /お受け取り/
おうけん /王権/
おうけんしんじゅせつ /王権神授説/
おうげ /応化/
おうこ /往古/
おうこう /横行/王侯;王と諸侯/王公;王族と公族/王后;queen/往航;⇔復航/
おうこうかっぼ /横行闊歩/
おうこうかっぽ /横行闊歩/
おうこうきぞく /王侯貴族/
おうこく /王国/
おうご /朷/鶯語/
おうごん /黄金/
おうごんかいがん /黄金海岸;地名,/
おうごんかぶ /黄金株;株主総会の決議に拒否権を有する種類株/
おうごんき /黄金期/
おうごんきょう /黄金郷/
おうごんしゅうかん /黄金週間/
おうごんじだい /黄金時代/
おうごんすう /黄金数/
おうごんちゅう /黄金虫/
おうごんでんせつ /黄金伝説/
おうごんひ /黄金比/
おうごんもんじょ /黄金文書/
おうごんりつ /黄金律/
おうさか /逢坂/
おうさだはる /王貞治/
おうさつ /応札/殴殺;殴り殺す/鏖殺;みなごろし/
おうさま /王様/
おうざ /王座/
おうざけってい /王座決定/
おうざけっていせん /王座決定戦/
おうざせん /王座戦/
おうざだっかい /王座奪回/
おうざだっしゅ /王座奪取/
おうざてんらく /王座転落/
おうざとういつせん /王座統一戦/
おうざぼうえい /王座防衛/
おうし /雄牛/牡牛/横死/黄紙/
おうしかん /欧氏管/
おうしき /黄鐘/
おうしきちょう /黄鐘調/
おうしざ /牡牛座;Taurus(Tau),(4.20-5.20)/
おうしつ /王室/
おうしゃ /王者/
おうしゃじょう /王舎城;Rajagrha/
おうしゅ /応手/
おうしゅう /欧州/押収/応酬/奥州/欧洲/歐洲/歐州/
おうしゅうかいどう /奥州街道;千住-白河/
おうしゅうかっこく /欧州各国/
おうしゅうきょうどうたい /欧州共同体;European Community(EC)/
おうしゅうぎかい /欧州議会;European Parliament, Parlement Europeen/
おうしゅうけい /欧州系/
おうしゅうしじょう /欧州市場/
おうしゅうしゃ /欧州車/
おうしゅうしょこく /欧州諸国/
おうしゅうしよう /欧州仕様/
おうしゅうせい /欧州製/
おうしゅうせんしゅけん /欧州選手権/
おうしゅうぜい /欧州勢/
おうしゅうなみ /欧州並/
おうしゅうばん /欧州版/
おうしゅうふじわら /奥州藤原/
おうしゅうふじわらし /奥州藤原氏/
おうしゅうほうめん /欧州方面/
おうしゅうれんごう /欧州連合;European Union(EU),Union Europeen(UE) europa.eu.int/
おうしょ /押書/
おうしょう /王将/応召/応鐘;[音楽]/鞅掌;多忙/
おうしょうかい /王将会/
おうしょうぎむ /応召義務/
おうしょうくん /王昭君/
おうしょうせん /王将戦/
おうしょく /黄色/応嘱/
おうしょくじんしゅ /黄色人種/
おうしん /往診;⇔宅診/往信;⇔返信/
おうじ /王子/皇子;天皇の息子/往時/王寺/往事;昔のこと/王地/欧字/
おうじえき /王子駅/王寺駅/
おうじさま /王子様/
おうじせいし /王子製紙;[企業名]/
おうじせん /王子線/
おうじつ /往日/
おうじつせい /横日性/
おうじゃ /王者/
おうじゃく /往昔;=おうせき/
おうじやま /皇子山/
おうじゅ /応需/
おうじゅく /黄熟/
おうじゅほうしょう /黄綬褒章/
おうじょ /王女/皇女/
おうじょう /往生/王城/応情/
おうじょうぎわ /往生際/
おうじょうけん /応情研/応用情報学研究センター;※abbrev/
おうじょさま /王女様/
おうじん /応身/
おうじんてんのう /応神天皇/
おうす /御薄;薄茶/
おうすい /王水/
おうすう /応数/
おうせ /逢瀬/
おうせい /旺盛/王政/王制/応制/黄精/
おうせいふっこ /王政復古/
おうせいもう /黄青盲/
おうせき /往昔/
おうせつ /応接/
おうせつしつ /応接室/
おうせつせっと /応接セット/
おうせつま /応接間/
おうせん /応戦/横線/鏖戦/
おうせんこぎって /横線小切手/
おうぜん /汪然/
おうぜんじ /王禅寺/
おうそ /応訴/
おうそう /押送/
おうそうじ /大掃除;おおそうじ/
おうそうだん /応相談/
おうぞく /王族/
おうた /御歌/桜多/
おうたい /応対/黄体/横隊/
おうたいほるもん /黄体ホルモン;[生物]progesterone. 女性ホルモンの一/
おうたどころ /御歌所/
おうだ /殴打/
おうだく /応諾/黄濁/
おうだつ /横奪/
おうだん /横断/黄疸/応談/黄胆/黄丹/
おうだんか /応談可/
おうだんきょう /横断橋/
おうだんけんさく /横断検索/
おうだんちゅう /横断中/
おうだんてき /横断的/
おうだんほこうしゃ /横断歩行者/
おうだんほどう /横断歩道/
おうだんまく /横断幕/
おうだんめん /横断面/
おうち /樗/楝/お家/相知/邑智/欒/尾内/
おうちゃく /横着/
おうちゃくもの /横着者/
おうちょう /王朝/応長;年号(1311-1312)/
おうちょうじだい /王朝時代;奈良・平安/
おうちょうぶんがく /王朝文学/
おうて /追手/王手/
おうてい /奥底/
おうてき /横笛/
おうてっこう /黄鉄鉱/
おうてひしゃ /王手飛車/
おうてびしゃ /王手飛車/
おうてん /横転/
おうでん /応電/
おうでんけん /応電研/
おうと /嘔吐/王都/
おうとう /応答/桜桃/鴨東/王統/王党/櫻桃/
おうとうかんすう /応答関数/
おうとうき /桜桃忌;6／13/
おうとうきょくせん /応答曲線/
おうとうしゃ /応答者/
おうとうしゅっぱん /桜桃出版;[出版社名]/
おうとうしょぼう /桜桃書房/
おうとうしんごう /応答信号/
おうとうじかん /応答時間/
おうとうせい /応答性/
おうとうそくど /応答速度/
おうとうてき /応答的/
おうとうぶん /応答文/
おうとうや /応答野/
おうとく /応徳;年号(1084-1087)/
おうとつ /凹凸/
おうど /黄土/王土/
おうどいろ /黄土色/
おうどう /王道/横道/黄銅/黄道/横動/
おうどうこう /黄銅鉱/黄道光/
おうどうざひょう /黄道座標/
おうどうたい /黄道帯/
おうどうらくど /王道楽土/
おうな /媼/嫗/
おうなつ /押捺/
おうに /黄丹/
おうにん /応仁/
おうにんのらん /応仁の乱/
おうねつびょう /黄熱病/
おうねん /往年/
おうのう /懊悩/応能/
おうはん /黄斑/凹版/往反/
おうばい /黄梅/
おうばく /黄檗/黄蘗/
おうばくさん /黄檗山/
おうばくし /黄蘗紙/
おうばくしゅう /黄檗宗/
おうばくばん /黄檗版/
おうばん /黄幡;[陰陽道]八将神の一。羅ゴ星/
おうばんが /凹版画/
おうばんぶるまい /椀飯振舞/椀飯振舞い/椀飯振る舞い/
おうひ /王妃/奥秘/応否/横披/横被/
おうびゃく /黄白/
おうびりん /桜美林/
おうびりんこうこう /桜美林高校/
おうびりんだいがく /桜美林大学/
おうふ /王父/
おうふう /欧風/
おうふく /往復/
おうふくきっぷ /往復切符/
おうふくこうくうけん /往復航空券/
おうふくじかん /往復時間/
おうふくじょうしゃけん /往復乗車券/
おうふくにじかん /往復二時間/
おうふくはがき /往復葉書/
おうふくはん /往復半/
おうふくびんた /往復ビンタ/
おうふくよう /往復用/
おうふくわり /往復割/
おうふくわりびき /往復割引/
おうふくわりびききっぷ /往復割引切符/
おうぶつ /応物/応用物理;※abbrev/
おうぶん /欧文/応分/
おうぶんし /欧文誌/
おうぶんしゃ /旺文社;[出版社名]/
おうぶんしゃぶんこ /旺文社文庫/
おうへい /横柄/
おうへん /黄変/応変;臨機-/往返/往反;=往返/王偏/
おうべい /欧米/
おうべいがた /欧米型/
おうべいけい /欧米系/
おうべいしき /欧米式/
おうべいしょこく /欧米諸国/
おうべいじん /欧米人/
おうべいば /欧米馬/
おうべいれっきょう /欧米列強/
おうほう /応報/王法/往訪/応保;年号(1161-1163)/應報;「応」旧字/
おうぼ /応募/王母/
おうぼう /横暴/王法/
おうぼきかん /応募期間/
おうぼけん /応募券/
おうぼさくひん /応募作品/
おうぼしかく /応募資格/
おうぼしめきり /応募締切/
おうぼしめきりご /応募締切後/
おうぼしゃ /応募者/
おうぼしゃしめい /応募者氏名/
おうぼしゃぜんいん /応募者全員/
おうぼしゃたすう /応募者多数/
おうぼしゃりまわり /応募者利回り/
おうぼしょるい /応募書類/
おうぼしょるいざいちゅう /応募書類在中/
おうぼじょうきょう /応募状況/
おうぼすう /応募数/
おうぼそうすう /応募総数/
おうぼたすう /応募多数/
おうぼないよう /応募内容/
おうぼはがき /応募葉書/
おうぼばこ /応募箱/
おうぼほうほう /応募方法/
おうぼよう /応募用/
おうぼようこう /応募要項/
おうぼようし /応募用紙/
おうぼりゆう /応募理由/
おうま /逢魔/お馬/黄麻/
おうまがとき /逢魔が刻/
おうまし /黄麻紙/
おうみ /近江/青海/
おうみいまずえき /近江今津駅/
おうみいまづ /近江今津/
おうみいまづえき /近江今津駅/
おうみしおつ /近江塩津/
おうみしおつかん /近江塩津間/
おうみしおづ /近江塩津/
おうみしま /青海島;地名,山口県/
おうみじ /近江路/
おうみちょうしじょう /近江町市場/
おうみてつどう /近江鉄道/
おうみはちまん /近江八幡/
おうみまいこ /近江舞子/
おうむ /鸚鵡/雄武/王蟲;[アニメ]『風の谷のナウシカ』/
おうむがい /鸚鵡貝/
おうむがえし /鸚鵡返し/おうむ返し/
おうむしんりきょう /オウム真理教/
おうむちょう /雄武町/
おうむびょう /鸚鵡病/オウム病/
おうめ /青梅/
おうめい /王命/
おうめえき /青梅駅/
おうめかいどう /青梅街道/
おうめし /青梅市/
おうめしゃこ /青梅車庫/
おうめせん /青梅線/
おうめとっかい /青梅特快/
おうめん /凹面/
おうめんきょう /凹面鏡/
おうもう /王莽;BC45-AD23/
おうもんきん /横紋筋/
おうゆう /鴎友/
おうゆうがくえん /鴎友学園/
おうよう /応用/鷹揚/應用;旧字/
おうよう> /応用;-科学,-数学/
おうようおんきょう /応用音響/
おうようか /応用可/
おうようかいせき /応用解析/
おうようかがく /応用科学/
おうようかがくか /応用化学科/
おうようかんれん /応用関連/
おうようがっかい /応用学会/
おうようきのう /応用機能/
おうようぎじゅつ /応用技術/
おうようぎじゅつぶ /応用技術部/
おうようけんきゅう /応用研究/
おうようけんきゅうしつ /応用研究室/
おうようけんきゅうじょ /応用研究所/
おうようげんごがく /応用言語学/
おうようしゅう /欧陽脩;1007-72/
おうようしんりがく /応用心理学;applied psychology/
おうようじょう /応用上/
おうようじょうほう /応用情報/
おうようじょうほうがく /応用情報学/
おうようすうがく /応用数学/
おうようすうがくか /応用数学科/
おうようすうがっか /応用数学科/
おうようすうり /応用数理/
おうようせい /応用性/
おうようせいひん /応用製品/
おうようせいめい /応用生命/
おうようそう /応用層/
おうようてき /応用的/
おうようてきのうりょく /応用的能力/
おうようでんし /応用電子/
おうようはんい /応用範囲/
おうようびじゅつ /応用美術/
おうようぶつり /応用物理/
おうようぶつりがく /応用物理学/
おうようぶつりがっか /応用物理学科/
おうようぶつりがっかい /応用物理学会/
おうようぶんや /応用分野/
おうようへん /応用編/
おうようめい /王陽明;(1472-1528) 大儒/
おうようめん /応用面/
おうようもんだい /応用問題/
おうようりきがく /応用力学/
おうようりょういき /応用領域/
おうようりょく /応用力/
おうようれい /応用例/
おうら /邑楽/
おうらい /往来/
おうらいもの /往来物/
おうりつ /王立/
おうりつがっかい /王立学会/
おうりゅう /横流/
おうりょう /横領/押領;統率/
おうりょうき /応量器/
おうりょうざい /横領罪/
おうりょうし /押領使/
おうりょく /応力/
おうりょくこう /鴨緑江;地名/
おうりょくしょく /黄緑色/
おうりょくど /応力度/
おうりん /黄燐/
おうれつ /横列/
おうれつか /横裂果/
おうれん /黄蓮/黄連/
おうれんあか /オウレン亜科/Coptidoideae/
おうれんず /凹レンズ;concave lens/
おうろ /往路/欧露/
おうわ /応和;年号(961-964)/
おえ /小江/汚穢/
おえかき /お絵描き/お絵かき/お絵書き/
おえつ /嗚咽/
おえどにほんばし /お江戸日本橋;古謡.「♪-七つ立ち」/
おえらがた /お偉方/御偉方/
おお /大/多/夛;「多」の異体字/
おお> /大/
おおあえ /大饗/
おおあかじ /大赤字/
おおあきない /大商い;大きな商い。主に株式市場で使う。/
おおあきんど /大商人;seth/
おおあさ /大朝/大麻/
おおあざ /大字/
おおあし /大足/
おおあじ /大味/
おおあせ /大汗/
おおあたま /大頭;bighead/巨頭/
おおあたり /大当り/大当たり/
おおあな /大穴/
おおあね /大姉/
おおあばれ /大暴れ/
おおあま /大甘/
おおあまのおうじ /大海人皇子/
おおあみ /大網/
おおあみえき /大網駅/
おおあめ /大雨/
おおあめけいほう /大雨警報/
おおあめこうずいけいほう /大雨洪水警報/
おおあめちゅういほう /大雨注意報/
おおあらい /大洗/
おおあり /大有り/
おおありくい /大蟻食;ant bear/
おおあれ /大荒れ/
おおあわ /粱/
おおあわて /大慌て/
おおい /覆い;cover/大井/大飯/大炊/
おおいえ /大家/
おおいがわ /大井川/
おおいがわてつどう /大井川鉄道/
おおいけ /大池/
おおいけいば /大井競馬/
おおいし /大石/
おおいしだ /大石田/
おおいずみ /大泉/
おおいずみがくえん /大泉学園/
おおいずみがくえんちょう /大泉学園町/
おおいそ /大磯/
おおいそがし /大忙し/
おおいそぎ /大急ぎ/
おおいた /大分/大板/
おおいたかん /大分間/
おおいたけん /大分県/
おおいたけんみん /大分県民/
おおいたこうつう /大分交通/
おおいたし /大分市/
おおいたしない /大分市内/
おおいたたいかい /大分大会/
おおいただい /大分大/
おおいただいがく /大分大学/
おおいたべん /大分弁/
おおいたほうそう /大分放送/
おおいち /大市/
おおいちばん /大一番/
おおいちもんじ /大一文字/
おおいちょう /大銀杏/大井町/大堰町/
おおいと /大糸/
おおいとせん /大糸線/
おおいど /大井戸/
おおいなる /大いなる/
おおいに /大いに/
おおいぬざ /大犬座;Canis Major(CMa)/
おおいのかみ /大炊頭/
おおいばり /大威張り/
おおいまち /大井町/
おおいまちせん /大井町線/
おおいまちほうめん /大井町方面/
おおいむさしのかん /大井武蔵野館/
おおいり /大入り/大入/
おおいりぶくろ /大入り袋/大入袋/
おおいわ /大岩/
おおう /奥羽/
おおうえ /大上/
おおうずまき /大渦巻/
おおうそ /大嘘/大ウソ/
おおうたどころ /大歌所;[律令制]/
おおうだ /大宇陀/
おおうち /大内/
おおうちがり /大内刈り/
おおうちどおり /大内通/
おおうちばん /大内版/
おおうちやま /大内山/
おおうつし /大写し/
おおうなばら /大海原/
おおうほんせん /奥羽本線/
おおうら /大浦/
おおうらてんしゅどう /大浦天主堂/
おおうらわざ /大裏技/
おおうりだし /大売り出し/大売出し/
おおえ /大江/大兄/
おおえけんざぶろう /大江健三郎;作家。『万延元年のフットボール』/
おおえせんり /大江千里/
おおえちょう /大江町/
おおえど /大江戸/
おおえどせん /大江戸線/
おおえどそうさもう /大江戸捜査網/
おおえどはなび /大江戸花火/
おおえのき /大榎/
おおえのちさと /大江千里;月みれば ちぢに物こそ かなしけれ わが身ひとつの 秋にはあらねど/
おおえのまさふさ /大江匡房;(1041-1111) 『江談抄』/
おおえやま /大江山/
おおおか /大岡/
おおおかえちぜん /大岡越前/
おおおかさばき /大岡裁き;人情的な裁定/
おおおかやま /大岡山/
おおおかやまえき /大岡山駅/
おおおく /大奥/
おおおくさま /大奥様/
おおおじ /大叔父;祖父母の弟/大伯父;祖父母の兄/従祖父/
おおおとこ /大男/
おおおば /大叔母;祖父母の妹/大伯母;祖父母の姉/従祖母/
おおおみ /大臣/
おおおやぶん /大親分/
おおおんな /大女/
おおかがみ /大鏡;作品名/
おおかじ /大火事/大鍛冶/
おおかぜ /大風/
おおかた /大方;-片付いた/大片;人名?/
おおかたびら /大帷子/
おおかながい /大金貝/大金書/
おおかぶぬし /大株主/
おおかべ /大壁/
おおかみ /狼/大神/
おおかみうお /狼魚/
おおかみおとこ /狼男/
おおかみおんな /狼女/
おおかみざ /狼座;Lupus(Lup)/
おおかみしょうねん /狼少年/
おおかめ /狼/
おおかれ /多かれ/
おおかれすくなかれ /多かれ少なかれ/
おおかわ /大川/大河/大鼓;おおつづみ/大革;おおつづみ/
おおかわかん /大川間/
おおかわぐち /大川口/
おおかわこうぎょう /大川興業;[企業名]/
おおかわばた /大川畑/
おおかわら /大河原/
おおかん /大缶/
おおかんだ /大神田/
おおが /大賀/大鋸/
おおがい /頁;[部首]「顔」/大貝/
おおがえし /大返し/
おおがかり /大掛かり/大掛り/大がかり/
おおがき /大垣/大柿/大書/
おおがきえき /大垣駅/
おおがきほうめん /大垣方面/
おおがきやこう /大垣夜行/
おおがけ /大駆/
おおがた /大型/大形;=大型/大方;地名/大潟;地名,秋田/
おおがたうちゅうせん /大型宇宙船/
おおがたえいが /大型映画/
おおがたえいぞう /大型映像/
おおがたか /大型化/
おおがたかぶ /大型株/
おおがたかもつ /大型貨物/
おおがたかもつしゃ /大型貨物車/
おおがたかんせつぜい /大型間接税/
おおがたき /大型機/
おおがたきかい /大型機械/
おおがたきょうたい /大型筐体/
おおがたぎょ /大型魚/
おおがたけいさんき /大型計算機/
おおがたけいさんきせんたー /大型計算機センター/
おおがたけん /大型犬/
おおがたけんいん /大型牽引/
おおがたさんきゃく /大型三脚/
おおがたしゃ /大型車/
おおがたしゃりょう /大型車両/
おおがたしょてん /大型書店/
おおがたじどう /大型自動/
おおがたじどうにりん /大型自動二輪/
おおがたじゅう /大型獣/
おおがたじょうようしゃ /大型乗用車/
おおがたせん /大型船/
おおがたせんしゅ /大型選手/
おおがたせんぱく /大型船舶/
おおがたちゅうしゃじょう /大型駐車場/
おおがたつりぐてん /大型釣具店/
おおがたてん /大型店/
おおがたとくしゅ /大型特殊/
おおがたにりん /大型二輪/
おおがたはんようき /大型汎用機/
おおがたば /大型馬/
おおがたひこうき /大型飛行機/
おおがたぼん /大型本/
おおがたまど /大型窓/
おおがためんきょ /大型免許/
おおがたれんきゅう /大型連休/
おおがち /大勝ち/
おおがね /大金/大鐘/
おおがねもち /大金持ち/大金持/
おおがみ /大神/
おおがめ /鰲/
おおがら /大柄/
おおがらす /大鴉/
おおがわら /大河原/
おおき /大木/大城/
おおきい /大きい/
おおきさ /大きさ/
おおきさいのみや /皇太后宮/
おおきすめらみこと /太上天皇/
おおきた /大北/
おおきど /大木戸/
おおきな /大きな/
おおきに /大きに/
おおきみ /大君/
おおきめ /大き目/大きめ/
おおぎ /扇;おうぎ/青木/仰木/
おおぎがた /扇型/
おおぎがはら /扇ヶ原/
おおぎし /大岸/
おおぎたに /扇谷/
おおぎばし /扇橋/
おおぎまち /扇町/
おおぎまちこうえん /扇町公園/
おおぎみ /大宜味/
おおぎょう /大仰/大形;≒大仰/
おおぎり /大喜利/大切り/
おおく /多く/
おおくずれ /大崩れ/
おおくち /大口/
おおくちばかま /大口袴/
おおくに /大国/
おおくにぬしのかみ /大国主神/
おおくにぬしのみこと /大国主命/
おおくび /衽/
おおくびえ /大首絵/
おおくぼ /大久保/大窪/
おおくぼえき /大久保駅/
おおくぼどおり /大久保通り/
おおくま /大熊/大隈/逢隈/
おおくまざ /大熊座/
おおくましげのぶ /大隈重信/
おおくら /大倉/大蔵/
おおくらしょう /大蔵省;NB:2001年1月の中央省庁再編で財務省に再編された/
おおくらしょうしょうけん /大蔵省証券/
おおくらだいじん /大蔵大臣/
おおくらやま /大倉山/
おおくり /お送り/
おおくわ /大桑/
おおぐい /大食い;痩せの-/大喰い/
おおぐし /大串/
おおぐす /大楠/
おおぐち /大口/
おおぐちこうにゅう /大口購入/
おおぐちさいけんしゃ /大口債権者/
おおぐちしゅっししゃ /大口出資者/
おおぐまざ /大熊座;Ursa Major(UMa)/
おおぐれ /大暮/
おおぐろ /大黒/
おおけが /大怪我;(当て字)/大けが/大ケガ/
おおげさ /大袈裟/大げさ/
おおげんか /大喧嘩/
おおこうち /大河内/
おおこし /大越;人名/
おおこめ /大米/
おおご /大胡/大湖/
おおごえ /大声/大越;地名,福岡県/
おおごし /大腰/
おおごしょ /大御所/
おおごしょじだい /大御所時代;1804-30/
おおごと /大事/
おおごま /大駒/
おおごんはくぶつかん /黄金博物館/
おおさ /大佐/
おおさか /大阪/大坂;†/逢坂;※仮名遣い「おうさか」/
おおさかいかだいがく /大阪医科大学/
おおさかいがい /大阪以外/
おおさかいだい /大阪医大/
おおさかいちりつだいがく /大阪市立大学/
おおさかうめだ /大阪梅田/
おおさかえき /大阪駅/
おおさかえきまえ /大阪駅前/
おおさかおうしょう /大阪王将/
おおさかかん /大阪間/
おおさかかんじょうせん /大阪環状線/
おおさかがいこくごだいがく /大阪外国語大学;www.osaka-gaidai.ac.jp/
おおさかがくいん /大阪学院/
おおさかがす /大阪ガス;[企業名]www.osakagas.co.jp/大阪瓦斯;[企業名]/
おおさかがわ /大阪側/
おおさかきたこう /大阪北港/
おおさかきゅうじょう /大阪球場/
おおさかきょういくだい /大阪教育大/
おおさかきょういくだいがく /大阪教育大学/
おおさかきんこう /大阪近郊/
おおさかぎじゅつ /大阪技術/
おおさかくうこう /大阪空港/
おおさかけい /大阪系/
おおさかけいざいだいがく /大阪経済大学/
おおさかげいだい /大阪芸大/
おおさかげいにん /大阪芸人/
おおさかこう /大阪港/大阪校/
おおさかこうえん /大阪公演/
おおさかこうぎょうだいがく /大阪工業大学/
おおさかこうせいねんきん /大阪厚生年金/
おおさかこうだい /大阪工大/
おおさかこうべかん /大阪神戸間/
おおさかこくさいくうこう /大阪国際空港/
おおさかこくさいこうりゅう /大阪国際交流/
おおさかこくぜいきょく /大阪国税局/
おおさかさやま /大阪狭山/
おおさかさんぎょうだい /大阪産業大/
おおさかさんぎょうだいがく /大阪産業大学/
おおさかさんだい /大阪産大/
おおさかし /大阪市/
おおさかしえい /大阪市営/
おおさかしがい /大阪市街/
おおさかしこう /大阪市交/
おおさかししゃ /大阪支社/
おおさかしだい /大阪市大/
おおさかしちかてつ /大阪市地下鉄/
おおさかしてん /大阪支店/
おおさかしでん /大阪市電/
おおさかしない /大阪市内/
おおさかしゃかいぶ /大阪社会部/
おおさかしょうぎょうだいがく /大阪商業大学/
おおさかしょうけんとりひきじょ /大阪証券取引所;大証/
おおさかしょうちくざ /大阪松竹座/
おおさかしょてん /大阪書店/
おおさかしりつだいがく /大阪市立大学/
おおさかじぎょうしょ /大阪事業所/
おおさかじょう /大阪城/
おおさかじょうこうえん /大阪城公園/
おおさかじん /大阪人/
おおさかせめんと /大阪セメント/
おおさかせん /大阪線/
おおさかたいいくだいがく /大阪体育大学/
おおさかたいかい /大阪大会/
おおさかだい /大阪大/
おおさかだいがく /大阪大学/
おおさかちかてつ /大阪地下鉄/
おおさかちほう /大阪地方/
おおさかちゃく /大阪着/
おおさかてき /大阪的/
おおさかてん /大阪店/
おおさかでんつうだい /大阪電通大/
おおさかとういん /大阪桐蔭/
おおさかなんば /大阪難波/
おおさかなんぶ /大阪南部/
おおさかにほんばし /大阪日本橋/
おおさかねやがわ /大阪寝屋川/
おおさかはい /大阪杯/
おおさかはつ /大阪発/
おおさかばしょ /大阪場所/
おおさかばん /大阪版/
おおさかばんぱく /大阪万博/
おおさかふ /大阪府/
おおさかふう /大阪風/
おおさかふけい /大阪府警/
おおさかふだい /大阪府大/
おおさかふみん /大阪府民/
おおさかふりつ /大阪府立/
おおさかふりつだい /大阪府立大/
おおさかふりつだいがく /大阪府立大学/
おおさかべん /大阪弁/
おおさかほうめん /大阪方面/
おおさかほか /大阪他/
おおさかほんしゃ /大阪本社/
おおさかみやげ /大阪土産/
おおさかめいぶつ /大阪名物/
おおさかやま /逢坂山/
おおさかわん /大阪湾/
おおさき /大崎/
おおさこ /大迫/
おおさじ /大匙/大さじ/
おおさと /大里/大郷/
おおさま /王様/
おおさめ /お納め/
おおさわ /大沢/大澤/
おおさわぎ /大騒ぎ/
おおさわの /大沢野/
おおさんしょううお /大山椒魚/
おおさんばし /大棧橋/大桟橋/
おおざけ /大酒/
おおざけのみ /大酒飲み/
おおざっぱ /大雑把/
おおざと /大里/
おおざはた /大座畑/
おおざら /大皿/
おおし /凡/
おおしお /大潮/大塩/
おおしおへいはちろう /大塩平八郎/
おおしか /大鹿/
おおしけ /大時化/
おおしげ /大重/
おおしこうちのみつね /凡河内躬恒;心あてに 折らばや折らむ 初霜の おきまどはせる 白菊の花/
おおしごと /大仕事/
おおした /大下/
おおしば /大柴/大芝/
おおしま /大島/大嶋/
おおしましょうせんこうせん /大島商船高専/
おおしまちょう /大島町/
おおしまつむぎ /大島紬/
おおしまぶし /大島節;[民謡]伊豆/
おおしみず /大清水/
おおしょうぎ /大将棋/
おおしょうぶ /大勝負/
おおしろ /大城/
おおじ /大路/祖父/王寺/
おおじか /大鹿/麋/
おおじしん /大地震/
おおじだい /大時代/
おおじぬし /大地主/
おおじま /大島/
おおじょたい /大所帯/大世帯/
おおす /大須/
おおすか /大須賀/
おおすが /大須賀/
おおすぎ /大杉/
おおすぎさかえ /大杉栄;(1885-1923) アナーキスト/
おおすじ /大筋/
おおすず /大鈴/
おおすみ /大隅/大住/大角/
おおすみせん /大隅線/
おおすみはんとう /大隅半島/
おおず /大洲/
おおずもう /大相撲/
おおずわ /大諏訪/
おおせ /大瀬/仰せ/
おおせいだされしょ /被仰出書/
おおせざき /大瀬崎/
おおせと /大瀬戸/
おおぜい /大勢/
おおぜき /大関/
おおぜきしょうしん /大関昇進/
おおぜきじん /大関陣/
おおそうじ /大掃除/
おおそうじちゅう /大掃除中/
おおそうどう /大騒動/
おおそが /大曽我/
おおそこ /大底/
おおそと /大外/
おおそとがり /大外刈り/大外刈/
おおそとわく /大外枠/
おおそね /大曽根;姓/
おおその /大園/
おおぞこ /大底/
おおぞね /大曽根/
おおぞら /大空/
おおぞん /大損/
おおた /太田;(ふとい)/大田;(おおきい)/
おおたいさん /太田胃散/
おおたか /大高/大鷹/
おおたがき /大田垣/
おおたがわ /太田川/
おおたがわばし /太田川橋/
おおたき /大滝/大多喜/大瀧/王滝/
おおたきむら /王滝村/
おおたく /大田区/
おおたくたいいくかん /大田区体育館/
おおたくひがしゆきがや /大田区東雪谷/
おおたぐろ /太田黒/
おおたけ /大竹/大嶽/大武/大丈/
おおたけしのぶ /大竹しのぶ/
おおたし /太田市/
おおたしゅっぱん /太田出版;[出版社名]/
おおたち /大立/
おおたちまわり /大立ち回り;-を演じる/大立回り/
おおたてもの /大立者/
おおたなんぽ /大田南畝;(1749-1823) =蜀山人/
おおたに /大谷/
おおたにやき /大谷焼/
おおたひろみ /太田裕美/
おおたま /大玉/
おおたわら /大田原/
おおたわらし /大田原市/
おおだ /大田/
おおだい /大台/
おおだいこ /大太鼓/
おおだか /大高/
おおだけ /大岳/
おおだこ /大凧/大ダコ/
おおだすかり /大助かり/
おおだち /大立/大館/
おおだて /大館/
おおだてもの /大立者/大立て者/
おおだな /大店/
おおだま /大玉/
おおだんな /大旦那/
おおち /邑智/
おおちがい /大違い/
おおっぴら /大っぴら/
おおつ /大津/
おおつえ /大津絵/
おおつか /大塚/大束/
おおつかあきら /大塚明/
おおつかえき /大塚駅/
おおつかかん /大塚間/
おおつかさ /大学寮;[律令制]/
おおつかせいやく /大塚製薬;[企業名]/
おおつが /大津賀/
おおつき /大月/大槻/大附/大津寄;姓/大規/
おおつきしょてん /大月書店;[出版社名]マルクス主義。www.otsukishoten.co.jp/
おおつごもり /大晦/大晦日/
おおつし /大津市/
おおつしがい /大津市街/
おおつしない /大津市内/
おおつせん /大津線/
おおつち /大槌/
おおつちわん /大槌湾/
おおつなみ /大津波/
おおつの /大角/
おおつぶ /大粒/
おおつぼ /大坪/大壺/
おおつま /大妻/
おおつまこうこう /大妻高校/
おおつまじょしだい /大妻女子大/
おおつやま /大津山/
おおつる /大鶴/
おおづ /大津/
おおづかみ /大掴み/
おおづくり /大作り/
おおづつ /大筒/
おおづな /大綱/
おおづめ /大詰め/大詰/
おおて /大手/
おおてい /大体/
おおてきぎょう /大手企業/
おおてぎんこう /大手銀行/
おおてしてつ /大手私鉄/
おおてしゅっぱんしゃ /大手出版社/
おおてしょうよう /大手商用/
おおてしょてん /大手書店/
おおてしんぶん /大手新聞/
おおてすーぱー /大手スーパー/
おおてすじ /大手筋/
おおてせきゆがいしゃ /大手石油会社/
おおてでんきがいしゃ /大手電気会社/
おおてまち /大手町/
おおてみんてつ /大手民鉄/
おおてもん /大手門/
おおてら /大寺/
おおてりょこうがいしゃ /大手旅行会社/
おおてる /大照/
おおてんじょう /大天井/
おおで /大手/
おおでき /大出来/
おおとう /大塔/大任/
おおとかげ /大蜥蜴/
おおとね /大利根/
おおとの /大殿/
おおとのごもり /大殿籠り;[文語]貴人が寝ること/
おおとのさま /大殿様/
おおとも /大伴/大友/
おおともい /弁/
おおともいのつかさ /弁官;[律令制]文書官/
おおともそうりん /大友宗麟/
おおとものやかもち /大伴家持;717?-785/
おおとよ /大豊/
おおとり /大鳥/鳳/鴻/鵬/
おおとりい /大鳥居/
おおとりじんじゃ /大鳥神社/
おおとりじんじゃまえ /大鳥神社前/
おおとろ /大トロ/
おおど /大戸/
おおどう /大胴;おおつづみ/
おおどうぐ /大道具/
おおどおり /大通り/大通/
おおどけい /大時計/
おおどころ /大所/
おおどしま /大年増/
おおどまり /大泊/
おおな /大名/
おおなえ /大苗/
おおなかぐろ /大中黒/
おおなかとみのよしのぶ /大中臣能宣;みかきもり 衛士のたく火の 夜はもえ 昼は消えつつ 物をこそ思へ/
おおなき /大泣き/
おおなた /大鉈/大ナタ/
おおなべ /大鍋/
おおなみ /大波/大浪/
おおなみこなみ /大波小波/
おおなめ /大滑/
おおなめまつり /大嘗祭/
おおなんじ /大汝/
おおにえ /大嘗/
おおにぎわい /大賑わい/
おおにし /大西/
おおにしまち /大西町/
おおにた /大仁田/
おおにもつ /大荷物/
おおにわ /大庭/
おおにんずう /大人数/
おおぬき /大貫/
おおぬま /大沼/
おおぬまこうえん /大沼公園/
おおね /大根/
おおねじめ /大根占/
おおねた /大ネタ/
おおねだ /大根田/
おおの /大野/
おおのくに /大乃国/
おおのじょう /大野城/
おおのみ /大野見/
おおのやすまろ /太安万侶;古事記/
おおはさ /大迫/
おおはざま /大間/
おおはし /大橋/
おおはしきょせん /大橋巨泉/
おおはしゃぎ /大はしゃぎ/
おおはじ /大恥/
おおはずれ /大外れ/大ハズレ/
おおはた /大畑/大畠/
おおはたせん /大畑線/
おおはなび /大花火/
おおはば /大幅/
おおはばげん /大幅減/
おおはばげんぜい /大幅減税/
おおはばぞう /大幅増/
おおはばだか /大幅高/
おおはばねびき /大幅値引き/
おおはばひきさげ /大幅引下げ/
おおはばへんこう /大幅変更/
おおはばやす /大幅安/
おおはま /大浜/大濱/
おおはやり /大流行/大流行り/
おおはら /大原/
おおはらい /大祓/
おおはらえ /大祓/
おおはらさんぜんいん /大原三千院/
おおはらそうどう /大原騒動/
おおはらの /大原野/
おおはらほうめん /大原方面/
おおはり /大梁/
おおはる /大治/
おおば /大葉/大場/大庭/大羽/祖母/
おおばか /大馬鹿/大バカ/
おおばかもの /大馬鹿者/大莫迦者/
おおばかやろう /大馬鹿野郎/
おおばくち /大博打;一世一代の-/
おおばけ /大化け/
おおばこ /大箱/車前;[植物]plantain/車前草;=車前/大葉子;=車前/
おおばたけ /大畠/
おおばな /大花/
おおばやし /大林/
おおばん /大判/大番/大盤/大版/
おおばんくるわせ /大番狂わせ/
おおばんぶるまい /大盤振る舞い/大盤振舞/大盤振舞い/
おおばんやき /大判焼/
おおばんよう /大判用/
おおひさ /大久/
おおひと /大仁/
おおひとちょう /大仁町/
おおひやき /大樋焼/
おおひら /大平/大衡/
おおひらだい /大平台/
おおひらちょう /大平町/
おおひらむら /大衡村/
おおひろ /大広/
おおひろま /大広間/
おおびき /大引/
おおびけ /大引け/
おおびゃくしょう /大百姓/
おおびん /大瓶/大壜/
おおふか /大深/
おおふく /大福/
おおふな /大船/
おおふなえき /大船駅/
おおふなと /大船渡/
おおふなとせん /大船渡線/
おおふね /大舟/
おおふろしき /大風呂敷/
おおぶ /大府/
おおぶえき /大府駅/
おおぶくろ /大袋/
おおぶたい /大舞台/
おおぶち /大渕/大淵/
おおぶね /大船/
おおぶり /大振り;†「HR狙いの-」「-の器」/大降り;†「-の雨」/
おおぶろしき /大風呂敷/
おおべや /大部屋/
おおほ /大穂/
おおほり /大堀/大濠/
おおほりこうえん /大濠公園/
おおほん /大本/
おおぼうしょ /大奉書/
おおぼけ /大歩危;地名,徳島/大ボケ/大ぼけ/
おおぼけこぼけ /大歩危小歩危;地名,徳島/
おおぼし /大星/
おおぼね /大骨/
おおぼら /大ボラ/
おおぽか /大ポカ/
おおま /大間/
おおまえ /大前/
おおまか /大まか/
おおまがき /大間書/
おおまがとき /大禍時/
おおまがり /大曲/
おおまがりかん /大曲間/
おおまがりせん /大曲線/
おおまき /大蒔/
おおまけ /大負け/
おおまじめ /大真面目/
おおまた /大股/
おおまち /大町/
おおまちえき /大町駅/
おおまちがい /大間違い/
おおまつ /大松/
おおまと /大的/
おおまど /大窓/
おおまぬけ /大間抜け/大間抜/
おおまま /大間々/
おおまみゅうだ /大豆生田;人名/
おおまゆ /大眉/
おおまわり /大回り/
おおまんどころ /大政所/
おおみ /大見/大身/
おおみえ /大見得/
おおみか /大甕/
おおみかみ /大御神/
おおみき /大御酒/
おおみしま /大三島/
おおみず /大水/
おおみそか /大晦日/
おおみぞ /大溝/
おおみだし /大見出し/
おおみち /大道/
おおみつ /大光/
おおみなと /大湊/
おおみなとせん /大湊線/
おおみね /大峰/
おおみや /大宮/
おおみやえき /大宮駅/
おおみやえきまえ /大宮駅前/
おおみやかん /大宮間/
おおみやこうじょう /大宮工場/
おおみやごしょ /大宮御所/
おおみやし /大宮市/
おおみやすんどころ /大御息所/
おおみやせん /大宮線/
おおみやちょう /大宮町/
おおみよ /大御代/
おおみら /薤/
おおみわじんじゃ /大神神社/
おおむ /御/
おおむかし /大昔/
おおむぎ /大麦/
おおむこう /大向こう/大向う/
おおむた /大牟田/
おおむね /概ね/概/大棟;[建築]寄棟 >―< で ― を形成する棟/大旨;=概(ね)/
おおむら /大村/
おおむらさき /大紫/
おおむらじ /大連/
おおむらせん /大村線/
おおむらわん /大村湾/
おおむろ /大室/
おおめ /大目;-に見る/多め/多目/
おおめし /大飯/
おおめしぐらい /大飯食らい/
おおめだま /大目玉/
おおめつけ /大目付/
おおもじ /大文字/
おおもじえいじ /大文字英字/
おおもじえいすうじ /大文字英数字/
おおもじか /大文字化/
おおもじこもじ /大文字小文字/
おおもと /大本/大元/
おおもときょう /大本教/
おおもの /大物/
おおものかしゅ /大物歌手/
おおものかん /大物感/
おおものじょせい /大物女性/
おおもめ /大揉め/
おおもも /大桃/
おおもり /大盛り/大盛/大森/
おおもりえき /大森駅/
おおもりく /大森区/
おおもん /大門/
おおや /大家/大屋/大谷/大矢/大宅/
おおやかず /大矢数/
おおやぎ /大八木/大谷木/
おおやけ /公/大宅/
おおやけごと /公事/
おおやけど /大火傷/
おおやしろ /大社;出雲大社/
おおやしろづくり /大社造り;[建築]=たいしゃづくり/大社造;[建築]=たいしゃづくり/
おおやす /大保/
おおやすうり /大安売り/大安売/
おおやち /大矢知/
おおやね /大屋根;[建築]/
おおやの /大矢野/
おおやま /大山/
おおやまえき /大山駅/
おおやまぐち /大山口/
おおやまざき /大山崎/
おおやまだ /大山田/
おおやまちょう /大山町/
おおやまと /大日本/大倭/
おおやまねこ /大山猫/
おおやままち /大山町/
おおやまやすはる /大山康晴/
おおやん /欧陽/
おおゆ /大湯/
おおゆか /大床/
おおゆき /大雪/
おおゆきけいほう /大雪警報/
おおゆきちゅういほう /大雪注意報/
おおゆみ /大弓/
おおよう /大様/
おおよせ /大寄/大寄せ/
おおよそ /凡そ/大凡/
おおよど /大淀/
おおよろこび /大喜び/
おおよわり /大弱り/
おおらか /大らか;generous/多らか;<rare>/
おおわ /大輪/
おおわき /大脇/
おおわく /大枠/大和久/
おおわざ /大技/
おおわし /大鷲/
おおわだ /大和田/大輪田/
おおわだちょう /大和田町/
おおわだばく /大和田獏/
おおわに /大鰐/
おおわらい /大笑い/
おおわらわ /大童/
おおん /御/
おおんべ /大嘗;=おおにえ/
おか /丘/岡/陸/岳/陵/阜/峻/崗/
おかあさま /お母様/お母さま/御母様/
おかあさん /お母さん/
おかあちゃん /お母ちゃん/
おかい /小粥/汚怪/
おかいあげ /お買い上げ/お買上/お買上げ/
おかいけい /お会計/
おかいどく /お買い得/
おかいもの /お買い物/
おかうち /岡内/
おかえ /岡江/
おかえくみこ /岡江久美子/
おかえし /お返し/御返し/
おかえり /お帰り/
おかお /お顔/
おかかえ /お抱え/御抱え;-料理人/
おかがき /岡垣/
おかがきちょう /岡垣町/
おかがみ /岡上/
おかくら /岡倉/
おかくらてんしん /岡倉天心;(1862-1913) 『茶の本』/
おかぐら /御神楽/
おかげ /お陰/お蔭;=お陰/御陰/御蔭/
おかげさま /お蔭様/御蔭様/
おかげん /お加減/御加減/
おかさか /岡坂/
おかさん /岡三/
おかさんしょうけん /岡三証券;[企業名]www.okasan.co.jp/
おかざき /岡崎/丘咲/
おかざきえき /岡崎駅/
おかざきし /岡崎市/
おかざわ /岡澤/
おかざわちょう /岡沢町/
おかし /お菓子/
おかしま /岡島/
おかしや /お菓子屋/
おかしら /尾頭;鯛の-付き/
おかしらつき /尾頭付き/尾頭付/
おかじま /岡島/岡嶋/
おかじょうき /陸蒸気/
おかず /御数/御菜/
おかせっけい /岡設計/
おかぞえ /岡添/
おかた /お方/御方/岡田/
おかたに /岡谷/
おかだ /岡田/
おかだい /岡大/
おかだいぞう /岡田以蔵/
おかだけいすけ /岡田啓介/
おかだせん /岡多線/
おかだま /丘珠/
おかだや /岡田屋/
おかちまち /御徒町/
おかって /お勝手/
おかっぴき /岡っ引き/
おかつ /雄勝/
おかづり /陸釣/
おかと /岡登/
おかど /尾角;姓/
おかどちがい /御門違い/お門違い/
おかどめ /岡留/
おかね /お金/
おかねもうけ /お金儲け/
おかねもち /お金持ち/
おかの /岡野/
おかのり /陸海苔/
おかはし /岡橋/
おかはち /岡八/
おかはら /岡原/
おかはる /岡原/
おかばしょ /岡場所/
おかばやし /岡林/
おかひさ /岡久/
おかひじき /陸鹿尾菜/
おかひら /岡平/
おかふじ /岡藤/
おかぶ /雄株;⇔雌株/お株;-を奪う/御株/
おかべ /岡部/
おかべちょう /岡部町/
おかぼ /陸稲/
おかぼれ /岡惚れ;≒片想い/傍惚れ;≒片想い/
おかま /御釜/お釜/
おかまい /御構い/
おかみ /御上/女将;旅館の-/お上/岡見/お内儀;(店|ウチ)の-/御内儀/傍見/
おかみさん /お内儀さん/
おかむら /岡村/
おかむろ /岡室/
おかめ /傍目;-八目/お亀;お多福/阿亀;=お亀/
おかめはちもく /傍目八目/岡目八目/
おかもち /岡持/岡持ち/
おかもと /岡本/岡元/
おかもとあやこ /岡本綾子/
おかもときどう /岡本綺堂;(1872-1939) 作家。『半七捕物帳』/
おかや /岡谷/
おかやす /岡安/
おかやすこう /岡安高/
おかやま /岡山/
おかやまえき /岡山駅/
おかやまえきまえ /岡山駅前/
おかやまかん /岡山間/
おかやまがわ /岡山側/
おかやまくうこう /岡山空港/
おかやまけん /岡山県/
おかやまけんじん /岡山県人/
おかやまし /岡山市/
おかやまじょう /岡山城/
おかやまだい /岡山大/
おかやまだいがく /岡山大学/
おかやまちほう /岡山地方/
おかやまひがし /岡山東/
おかやまべん /岡山弁/
おかやまめいぶつ /岡山名物/
おかゆ /お粥/小粥/
おからだ /お身体/
おかわり /お代わり/お変わり/お代り/お変り/
おかん /悪寒/お燗/お母ん/惡寒;「悪」旧字/
おかんがえ /お考え/
おかんじょう /お勘定/
おかんむり /御冠/
おが /男鹿/大鋸/
おがい /小粥/
おがくず /大鋸屑/
おがさ /小笠/
おがさか /小賀坂/
おがさはら /小笠原/
おがさわら /小笠原/
おがさわらきんかい /小笠原近海/
おがさわらしょとう /小笠原諸島/
おがさわらりゅう /小笠原流/
おがた /緒方/尾形/小方/小形/緒形/
おがたけん /緒形拳/
おがたけんざん /尾形乾山;(1663-1743) 陶工。兄は光琳/
おがたこうりん /尾形光琳/
おがつ /雄勝/
おがの /小鹿野/
おがはんとう /男鹿半島/
おがひき /大鋸挽き/
おがみ /尾上/男神/
おがや /小萱/
おがゆ /小粥/
おがら /麻幹/
おがわ /小川/小河/緒川/尾川/尾河/
おがわえき /緒川駅/
おがわちょう /小川町/
おがわな /小川名/
おがわまち /小川町/
おがわみめい /小川未明;(1882-1961)作家 NB:正しくは「おがわびめい」/
おき /沖/隠岐/燠;暖炉の-/熾;=燠/澳;≒沖/置き/起き/お気/興;(人名用)/煕;(人名用)/熈;(人名用)/
おきあい /沖合/沖合い/
おきあいぎょぎょう /沖合漁業/
おきあがりこぼし /起き上がり小法師/
おきあじ /沖鰺/
おきあみ /置網/置き網/沖醤蝦/
おきあゆ /置鮎;姓/
おきいし /置き石/置石/
おきうお /沖魚/
おきかえ /置き換え/置換え/
おきかた /置き方/
おきがけ /起き掛け/
おきがさ /置き傘/
おきがる /御気軽/お気軽/
おきくら /沖倉/
おきぐすり /置き薬/
おきこうぎょう /沖工業;[企業名]/
おきことば /沖言葉/
おきご /置き碁/
おきごたつ /置き炬燵/
おきさわら /沖鰆;宗太鰹のこと/
おきざり /置き去り/
おきじ /置字/置き字;漢文の読まない字/
おきす /沖洲/
おきそ /小木曽/
おきた /沖田/小木田/
おきたそうじ /沖田総司/
おきたま /置賜/
おきち /お吉/
おきつ /興津/
おきつうしん /沖通信/
おきつち /置き土/
おきつのり /興津海苔/
おきづき /お気付き/
おきづけ /沖漬;タコの-/沖漬け/
おきて /掟/諚/沖手/
おきてがき /掟書/
おきてがみ /置き手紙/置手紙/
おきてぬぐい /置き手拭い/
おきでんき /沖電気/
おきでんきこうぎょう /沖電気工業;[企業名]/
おきとちょう /置戸町/
おきどけい /置時計/置き時計/
おきどこ /置床;ポータブル床の間/置き床/
おきどころ /置き所/
おきな /翁/奥菜/
おきなあめ /翁飴/
おきなか /沖中/
おきなかし /沖仲仕/沖仲士;?/
おきなごうし /翁格子/
おきなわ /沖縄/沖繩/
おきなわかいはつちょう /沖縄開発庁;NB:2001年1月の中央省庁再編で内閣府に再編された/
おきなわけん /沖縄県/
おきなわけんえいてつどう /沖縄県営鉄道/
おきなわこくぜいじむしょ /沖縄国税事務所/
おきなわご /沖縄語/
おきなわさん /沖縄産/
おきなわし /沖縄市/
おきなわしょとう /沖縄諸島;地名,Okinawa Isles/
おきなわじん /沖縄人/
おきなわすいさん /沖縄水産/
おきなわせん /沖縄戦;[世界史]1945/
おきなわふう /沖縄風/
おきなわふじつう /沖縄富士通/
おきなわべん /沖縄弁/
おきなわほうげん /沖縄方言/
おきなわほんとう /沖縄本島/
おきなわほんとうない /沖縄本島内/
おきなわみんよう /沖縄民謡/
おきなわもの /沖縄物/
おきなわりょうりや /沖縄料理屋/
おきにいり /お気に入り/
おきぬけ /起き抜け/
おきのしま /隠岐島/沖ノ島/
おきのとりしま /沖ノ鳥島/
おきのどく /お気の毒/
おきのどくさま /お気の毒様/お気の毒さま/
おきば /置き場/置場/
おきばしょ /置き場所/置場所/
おきひ /置き肥/置肥/
おきび /熾火/燠火/
おきふじ /沖藤/
おきぶみ /置文/
おきまつしま /沖松島/
おきまり /お決まり/御決まり/御決り/
おきみ /沖美/
おきみやげ /置き土産/置土産/
おきめ /沖目/
おきもじ /御気文字/
おきもち /お気持ち/お気持/
おきもと /沖本/
おきもの /置物/置き物/
おきゃく /お客/
おきゃくさま /お客様/御客様/お客さま/
おきゃくさん /お客さん/
おきゃん /御侠/お侠/
おきや /置屋/置き屋/
おきゅう /お灸/
おきょう /お経/
おきらく /お気楽/
おきわすれ /置き忘れ/置忘れ/
おきわたし /沖渡し/
おぎ /荻/小城/小木/尾木/蒹/
おぎうえ /荻上/
おぎえぶし /荻江節;三味線/
おぎくぼ /荻窪/
おぎくぼかん /荻窪間/
おぎしま /荻島/
おぎそ /小木曽/
おぎた /荻田/小木田/
おぎつ /荻津/
おぎにしき /小城錦/
おぎの /荻野/荻布/
おぎのしき /オギノ式/荻野式;避妊法/
おぎのめ /荻野目/荻目/
おぎのめようこ /荻野目洋子/
おぎはら /荻原/
おぎゅう /荻生/
おぎゅうそらい /荻生徂徠/
おぎょう /オ行/お行/
おぎょうぎ /お行儀/
おぎろ /頤/
おぎわら /荻原/
おく /奥/億;10^8/邑久;地名,岡山県/尾久;地名,東京都北区/屋;家屋/憶;憶測/臆;臆病/檍;もちのき/奧;「奥」の旧字(人名用漢字)/
おく> /奥;奥二重,奥多摩/
おくい /奥井/奥居/
おくいし /奥医師/
おくいずも /奥出雲/
おくいぶき /奥伊吹/
おくいり /奥入;源氏物語の注釈書。定家/
おくう /屋烏;-の愛/
おくえん /億円/
おくか /奥処/屋下;屋下に屋を架す/
おくかい /億回/
おくかわ /奥川/
おくがい /屋外/
おくがいよう /屋外用/
おくがき /奥書/
おくがた /奥方/
おくきょうと /奥京都/
おくぎ /奥義;「おうぎ」ともいう/奥儀;「おうぎ」ともいう/
おくこ /億個/
おくさがみ /奥相模/
おくさき /奥崎/
おくさま /奥様/
おくさわ /奥沢/奥澤/
おくさん /奥さん/
おくざしき /奥座敷/
おくしが /奥志賀/
おくしゃ /屋舎/
おくしょん /億ション;[俗]億単位の分譲マンション/
おくしり /奥尻/
おくしりとう /奥尻島/
おくじょう /屋上/
おくじょうおく /屋上屋/
おくじょうていえん /屋上庭園;roof garden/
おくじょちゅう /奥女中/
おくすり /お薬/
おくせ /奥瀬/
おくせつ /憶説/臆説/
おくそく /憶測/臆測/
おくそこ /奥底/
おくただみ /奥只見/
おくたに /奥谷/
おくたま /奥多摩/
おくたまえき /奥多摩駅/
おくたまほうめん /奥多摩方面/
おくたんい /億単位/
おくだ /奥田/
おくだいら /奥平/
おくだて /奥立/
おくだん /臆断/
おくち /奥地/お口/
おくちょう /億兆/
おくつ /奥津/
おくつき /奥つ城/
おくづけ /奥付/
おくて /奥手;「-な娘」/晩生;[植物]late.「-の品種」/晩稲;⇔早稲/
おくで /奥出/
おくでら /奥寺/
おくでん /奥伝/
おくとね /奥利根/
おくとみ /奥富/
おくど /奥土/
おくない /屋内/奥内/
おくないしせつ /屋内施設/
おくないはいせん /屋内配線/
おくないぷーる /屋内プール/
おくなが /奥永/
おくに /御国/阿国/お国/
おくにがら /お国柄/
おくにことば /御国言葉/
おくにし /奥西;姓/
おくにじまん /御国自慢/お国自慢/
おくにっかわ /奥新川/
おくにっこう /奥日光/
おくになまり /御国訛り/お国訛り/
おくにん /億人/
おくぬき /奥貫/
おくねん /億年/
おくの /奥野/奥乃/
おくのいん /奥の院/
おくのて /奥の手/
おくのと /奥能登/
おくのほそみち /奥の細道/
おくのま /奥の間/
おくはら /奥原/
おくば /奥歯/
おくひだ /奥飛騨/
おくびょう /臆病/
おくびょうかぜ /臆病風/
おくびょうもの /臆病者/
おくぶ /奥部/
おくほ /奥穂/
おくほうこう /奥方向/
おくほたかだけ /奥穂高岳;地名/
おくぼいん /奥母音/
おくまつしま /奥松島/
おくまん /億万/
おくまんちょうじゃ /億万長者/
おくみ /衽/袵/
おくみかわ /奥三河/
おくみの /奥美濃/
おくみのちほう /奥美濃地方/
おくむら /奥村/
おくめ /奥目/
おくめん /臆面/
おくもと /奥本/納本/
おくやま /奥山/
おくやみ /お悔やみ/
おくゆき /奥行/奥行き/
おくゆきかん /奥行感/
おくら /御蔵/憶良;人名/お蔵/
おくらいり /お蔵入り/
おくり /送り/
おくりあし /送り足;[相撲]/
おくりあしばらい /送り足払い/
おくりおおかみ /送り狼/
おくりかた /送り方/
おくりかな /送り仮名/
おくりがな /送り仮名/
おくりさき /送り先/贈り先/
おくりじょう /送り状/
おくりたおし /送り倒し/
おくりだし /送り出し/
おくりて /送り手/
おくりな /諡/贈り名/
おくりぬし /送り主/贈り主/送主/
おくりばんと /送りバント;[野球]sacrifice bunt/
おくりび /送り火/
おくりむかえ /送り迎え/
おくりもと /送り元/
おくりもの /贈り物/贈物/贈りもの/饋/賻/
おくれ /遅れ/
おくれげ /後れ毛/
おくれじかん /遅れ時間/
おくればせ /遅れ馳せ/遅馳/
おくればせながら /遅ればせながら/
おくわざ /奥技/
おぐさ /小草/
おぐし /小串/御髪/
おぐち /小口/尾口/
おぐに /小国/
おぐにまち /小国町/
おぐま /小熊/
おぐら /小倉/小椋/
おぐらあん /小倉餡/
おぐらけい /小椋佳/
おぐらしきし /小倉色紙/
おぐらやま /小倉山/
おぐり /小栗/
おぐりはんがん /小栗判官/
おぐるま /小車/
おぐろ /小黒/
おけ /桶/
おけいこ /お稽古/
おけがやぬま /桶ケ谷沼/
おけがわ /桶川/
おけがわし /桶川市/
おけしょう /お化粧/
おけつ /悪血/
おけと /置戸/
おけどう /桶胴;太鼓/
おけはざま /桶狭間/
おけや /桶屋/
おけら /螻蛄;[昆虫]「-になる」(=無一文)/朮;[植物]/
おける /於ける/
おげひん /お下品/
おげれつ /お下劣/
おげんき /お元気/御元気/
おこ /痴;foolish. 「-がましい」/烏滸;=痴/お子/
おこう /お香/汚行/
おこうでん /御香典/
おこえ /御声/
おこげ /お焦げ/御焦げ/
おこころ /御心/
おこさま /お子様/お子さま/
おこさまらんち /お子様ランチ/
おこさん /お子さん/
おこし /お越し/小越/
おこぜ /虎魚/
おこたえ /お答え/御答え/
おこたち /御子達/
おこちゃま /お子ちゃま/
おこっぺ /興部/
おこっぺちょう /興部町/
おこと /お琴/お箏/
おことてん /乎古止点/
おことば /御言葉/
おことわり /お断り/お断わり/
おこない /行い/行ない/
おこのぎ /小此木/
おこのみ /お好み/
おこのみやき /お好み焼き/
おこのみやきや /お好み焼き屋/
おこぼれ /お零れ;-に与る/
おこめ /お米/御米/
おこめけん /お米券/
おこり /瘧;malaria/起り/
おこりいし /瘧石/
おこりかた /怒り方/
おこりんぼう /怒りん坊/
おこわ /御強;赤飯/
おごうりかん /小郡間/
おごおり /小郡/
おごおりし /小郡市/
おごおりちょう /小郡町/
おごし /生越;姓/
おごせ /越生/
おごそか /厳か/
おごと /雄琴/
おごのり /於胡海苔/海髪海苔/
おごり /奢り/驕り/傲り/
おさ /長/筬;織機の-/通事/訳語/
おさいせん /お賽銭/
おさいふ /お財布/
おさいほう /お裁縫/
おさえ /抑え/押さえ/押え/
おさえかた /押さえ方/押え方/
おさえこみ /抑え込み/
おさえどころ /押え所/押さえ所/
おさえめ /抑え目/
おさか /小坂/尾坂/苧坂/
おさかな /お魚/
おさがり /お下がり/御下がり/御下り/
おさき /御先/お先/
おさきに /お先に/
おさきぼう /御先棒/
おさきまっくら /お先真っ暗/御先真っ暗/
おさぎ /兎/
おさくひん /御作品/
おさけ /お酒/
おさけび /雄叫び/
おさげ /お下げ/御下げ;髪型/
おさげがみ /お下げ髪/
おさしみ /お刺身/
おさそい /お誘い/
おさたがき /御沙汰書/
おさたけ /尾佐竹/
おさだ /長田/
おさだまり /御定まり/
おさだみほ /長田美穂/
おさだめがき /御定書/
おさつ /お札/
おさと /お里/御里;-が知れる/長都/
おさな /幼/
おさない /小山内/長内/幼い/
おさないころ /幼い頃/
おさないみえこ /小山内美江子/
おさながお /幼顔/
おさなご /幼子/幼な子/
おさなごころ /幼心/
おさなさ /幼さ/
おさなづま /幼妻/
おさなともだち /幼友達/
おさななじみ /幼馴染/幼馴染み/幼なじみ/
おさなものがたり /幼物語/
おさふね /長船/
おさべ /長部/
おさまり /収まり;-がつかない/納まり;部材の-/
おさみ /修美/
おさむ /修/治/理/収/治虫/納/
おさめ /納め/
おさめこみ /納込/
おさめつくるつかさ /修理職/
おさめふだ /納め札/
おさら /お皿/
おさらぎ /大仏;姓/大佛;姓/
おさらぎじろう /大佛次郎;(1897-1973) 作家/大仏次郎;※新字表記/
おさる /お猿/
おさわがせ /お騒がせ/
おさん /お産/
おさんかた /御三方/
おさんぽ /お散歩/
おざ /尾座/
おざき /尾崎/小崎/尾前/
おざきこうよう /尾崎紅葉/
おざきなおみち /尾崎直道/
おざきまさし /尾崎将司/
おざきゆたか /尾崎豊/
おざく /小作/
おざさ /小笹/
おざしき /お座敷/御座敷/
おざしきうた /御座敷唄/
おざなり /御座なり/
おざわ /小沢/小澤/尾沢/
おざわりゅう /小沢流/
おし /唖;dumb/鴛鴦/御師/押し/鴛/忍;(人名用)/
おしあい /押合い/押し合い/
おしあいへしあい /押し合い圧し合い/押合い圧し合い/
おしあいまつり /押し合い祭り/押合い祭り/
おしあげ /押上/
おしあげかん /押上間/
おしあげせん /押上線/
おしあわせ /お幸せ/
おしい /押井/
おしいれ /押入/押し入れ/
おしうり /押し売り/押売り/押売/
おしえ /押絵/教え/
おしえかた /教え方/
おしえご /教え子/
おしお /押尾/
おしおき /お仕置き/御仕置/
おしか /牡鹿/
おしかく /押角/
おしかけ /押し掛け/
おしかせん /男鹿線/
おしかた /押方/
おしかり /御叱り/お叱り/
おしかわ /押川/
おしがし /押し貸し/
おしがた /押型/押し型/
おしがみ /押紙/
おしき /折敷/
おしきせ /御仕着せ/
おしきり /押切/
おしくま /押熊/
おしくも /惜しくも/
おしくらまんじゅう /押し競饅頭;押されて泣くな/
おしげ /惜しげ/
おしこみ /押し込み/押込み/
おしこみごうとう /押し込み強盗/押込み強盗/
おしごと /お仕事/
おしずし /押し寿司/押し鮨/押鮨/
おしずもう /押し相撲/
おしたおし /押し倒し/
おしだ /押田/
おしだし /押し出し/
おしち /お七;八百屋-/
おしちや /御七夜/お七夜/
おしつけ /押し付け/
おして /押手/
おしどり /鴛鴦/鴦/
おしながき /お品書き/
おしなべて /押し並べて/
おしね /晩稲/
おしの /忍野/
おしのはっかい /忍野八海/
おしのび /御忍び/
おしのむら /忍野村/
おしはらい /お支払い/
おしば /押し葉/押葉/
おしばい /お芝居/
おしばこ /押し箱/押箱/
おしばな /押し花/押花/
おしぴん /押しピン;pushpin/
おしぶち /押縁/押し縁;[建築]/
おしべ /雄蕊/
おしほり /押堀/
おしぼたん /押しボタン;push button/押ボタン/
おしぼり /御絞り/
おしま /渡島/小島/
おしまい /御仕舞い/お仕舞い/御仕舞/
おしまずき /几/
おしまはんとう /渡島半島/
おしみ /惜しみ/
おしみず /押水/
おしむぎ /押し麦/押麦/
おしむらくは /惜しむらくは/
おしめ /押し目;-買い/襁褓;オムツ/押目/御湿;=襁褓/襁/繦/
おしめがい /押し目買い;[相場]/
おしめり /お湿り/御湿り/
おしもんどう /押し問答/押問答/
おしゃか /お釈迦/御釈迦/
おしゃかさま /御釈迦様/
おしゃく /お酌/御酌/
おしゃべり /お喋り/
おしゃまんべ /長万部/
おしゃらく /御洒落/
おしゃれ /お洒落/御洒落/おシャレ/
おしゅう /汚臭/
おしょう /和尚/
おしょうがつ /お正月/
おしょく /汚職/
おしょくぎいん /汚職議員/
おしょくじ /お食事/御食事/
おしょくじかい /お食事会/
おしょくじけん /お食事券/汚職事件/
おしらせ /お知らせ/
おしり /お尻/
おしるこ /お汁粉/
おしろ /お城/
おしろい /白粉/
おしろいばな /白粉花/
おしわり /押割り/
おしん /悪心/
おしんこ /御新香/お新香/
おじ /叔父;†父・母の弟/伯父;†父・母の兄/小父;†よその年配男性/老翁/祖父/
おじい /お爺/
おじいさん /お爺さん/お祖父さん/
おじいちゃん /お爺ちゃん/
おじおば /叔父叔母/
おじか /牡鹿/小値賀/
おじかせん /男鹿線/
おじかん /お時間/
おじき /叔父貴/伯父貴/
おじぎ /御辞儀/
おじぎそう /含羞草/御辞儀草/
おじけ /怖気/
おじさま /叔父様;†父母の弟/伯父様;†父母の兄/小父様;†よその年配男性(オジサン)/
おじさん /叔父さん;†父母の弟/伯父さん;†父母の兄/小父さん;†よその年配男性(オジサン)/
おじま /小島/尾島/
おじまちょう /小島町/
おじゃま /お邪魔/御邪魔/
おじゃまむし /お邪魔虫/
おじゅう /御重;重箱/
おじゅけん /お受験;[新語]名門幼稚園・小学校の受験/
おじょう /御嬢/お嬢/
おじょうさま /お嬢様/御嬢様/
おじょうさん /お嬢さん/御嬢さん/
おじょうさんそだち /御嬢さん育ち/
おじょうず /御上手/お上手/
おじょうちゃん /お嬢ちゃん/
おじょく /汚辱/
おじろ /尾白/
おす /雄/牡/お酢/♂/
おす> /牡/雄;-犬,-虎/
おすい /汚水/
おすいかん /汚水管/
おすいしょり /汚水処理/
おすいぬ /雄犬/オス犬/牡犬/
おすいもじ /御推文字/
おすいもの /お吸い物/
おすうし /雄牛/
おすうま /牡馬/
おすかぶ /雄株/
おすがた /御姿/
おすき /お好き/
おすごし /お過ごし/
おすし /お寿司/
おすすめ /お勧め/お薦め/
おすそわけ /お裾分け/御裾分け/おすそ分け/
おすたかやま /御巣鷹山/
おすだ /小須田/
おすとめす /雄と雌/
おすねこ /雄猫/牡猫/オス猫/
おすまい /お住い/
おすまし /御澄まし/
おすまんご /オスマン語;Osmanli/
おすみ /お済み/
おすみうむ /Os/Osmian/
おすみつき /お墨付き/御墨付/御墨付き/
おすめす /雄雌/牡牝/
おず /小津/
おせ /尾瀬/
おせいぼ /お歳暮/御歳暮/
おせおせ /押せ押せ/
おせき /お席/
おせざき /大瀬崎/
おせじ /お世辞/御世辞/
おせち /御節/
おせちりょうり /御節料理/
おせっかい /お節介/御節介/
おせつ /お説/
おせわ /お世話/御世話/
おせわさま /お世話様/御世話様/
おせん /汚染/
おせんげん /汚染源/
おせんじょうきょう /汚染状況/
おせんすい /汚染水/
おせんち /おセンチ;[口](皮肉で) sentimental/
おせんちたい /汚染地帯/
おせんどじょう /汚染土壌/
おせんぶっしつ /汚染物質/
おぜ /尾瀬/小瀬;人名/
おぜき /尾関/小関/
おぜぬま /尾瀬沼/
おぜん /お膳/御膳/
おぜんだて /お膳立て/御膳立て/
おそ /遅/悪阻/獺;かわうそ/遲;「遅」の旧字/
おそ> /遅;遅番,遅便,遅咲き/
おそあがり /遅上がり/
おそい /襲/
おそうざい /お惣菜/
おそうしき /お葬式/御葬式/
おそうじ /お掃除/
おそうまれ /遅生まれ/遅生れ/
おそかれはやかれ /遅かれ早かれ/
おそくとも /遅くとも/
おそざき /遅咲き/
おそざくら /遅桜/
おそし /遅し/
おそぢえ /遅知恵/
おそで /遅出/
おそなえ /お供え/御供え/
おそなえもち /御供え餅/
おそなえもの /お供え物/御供え物/
おそね /遅寝/
おそば /御側/遅場/
おそばん /遅番/遅版/
おそびん /遅便;⇔早便/
おそまき /遅蒔き/
おそまつ /お粗末/御粗末/
おそまつさま /御粗末様/お粗末様/お粗末さま/
おそめ /遅め/遅目/お染;「鳥辺山心中」の人物/
おそらく /恐らく/
おそらくは /恐らくは/
おそる /惶/
おそるおそる /恐る恐る/
おそるべき /恐るべき/
おそるべし /恐るべし/
おそれ /虞;(悪いことの起こる可能性)「風俗を害する虞」/恐れ/畏れ;awe/
おそれげ /恐れ気/
おそれざん /恐山/
おそれる /惶/
おそろい /お揃い/
おそん /汚損/
おぞうに /お雑煮/
おぞけ /怖気;-づく/
おぞんそう /オゾン層/
おた /織田/
おたから /お宝/御宝/
おたがい /お互い/
おたがいさま /お互い様/御互い様/
おたく /お宅/御宅/
おたけび /雄叫び/
おたじま /小田島/小田嶋/
おたずね /お尋ね/
おたずねもの /お尋ね者/
おたち /お発ち/
おたちだい /お立ち台/御立ち台/
おたっし /お達し/御達し/
おたな /御店/
おたねにんじん /御種人参/
おたのしみ /お楽しみ/
おたのしみぶくろ /お楽しみ袋/
おたび /御旅/
おたふく /お多福/阿多福/
おたべ /小田部/
おたま /お玉/御玉/
おたまじゃくし /御玉杓子/蝌蚪/
おたまや /霊屋/
おたまやした /霊屋下/
おため /御為;-ごかし/
おためごかし /御為倒し/
おためし /お試し/
おたより /お便り/
おたり /小谷/
おたる /小樽/
おたるえき /小樽駅/
おたるし /小樽市/
おたるしょうかだいがく /小樽商科大学/
おたんじょうび /お誕生日/
おだ /小田/織田/纓田/
おだい /お題/お代/御題/御代;-は要らぬ/小田井/
おだいじに /お大事に/
おだいじん /お大尽/
おだいとう /尾岱沼/
おだいば /御台場;地名/
おだいもく /御題目/
おだいら /小平/
おだうらくさい /織田有楽斎/
おだか /小高/尾高/
おだかしょう /尾高賞/
おだかずまさ /小田和正/
おだがわ /小田川/
おだきゅう /小田急/
おだきゅうえんせん /小田急沿線/
おだきゅうしゃりょう /小田急車両/
おだきゅうしんじゅく /小田急新宿/
おだきゅうしんじゅくえき /小田急新宿駅/
おだきゅうじこくひょう /小田急時刻表/
おだきゅうせん /小田急線/
おだきゅうせんえんせん /小田急線沿線/
おだきゅうせんない /小田急線内/
おだきゅうたません /小田急多摩線/
おだぎ /小田木/
おだぎり /小田切/小田桐/
おだく /汚濁/
おだくら /小田倉/
おだけ /雄竹/織田家/
おだしま /小田嶋/
おだじま /小田島/小田嶋/尾田島/
おだて /煽て/
おだなか /小田中/
おだに /小谷/
おだのぶなが /織田信長/
おだのぶひで /織田信秀/
おだぶつ /御陀仏/お陀仏/
おだべ /小田部/
おだまき /苧環/
おだまきむし /小田巻蒸し/苧環蒸し/
おだまり /お黙り/
おだやか /穏やか/
おだわら /小田原/
おだわらかん /小田原間/
おだわらがた /小田原方/
おだわらじょう /小田原城/
おだわらせん /小田原線;小田急/
おだわらぢょうちん /小田原提灯/
おだわらひょうじょう /小田原評定/
おだわらほうめん /小田原方面/
おだん /オ段/
おち /越智/落ち/落/越知/尾知/彼方/遠/
おちあい /落合/
おちあゆ /落ち鮎/
おちいし /落石/
おちうお /落ち魚/落魚/
おちうど /落人/
おちえ /御知恵/
おちおち /落ち落ち/
おちかた /遠方;over there/落ち方;how it falls/落方/墜ち方/
おちから /お力/御力/
おちからぞえ /お力添え/
おちくぼものがたり /落窪物語/
おちぐち /落ち口/
おちけん /落研/
おちこち /遠近/彼方此方/
おちこぼれ /落ちこぼれ/落ち零れ/
おちこみ /落ち込み/落ちこみ/
おちご /御稚児/
おちち /お乳/
おちつき /落ち着き/落着き/
おちど /落ち度/落度/越度;=落ち度 NB:「落(ち)度」はこの当て字/
おちば /落葉/落ち葉/
おちばいろ /落葉色/
おちばたき /落ち葉焚き/落葉焚き/
おちびと /落人/
おちぼ /落穂/落ち穂/
おちぼひろい /落穂拾い/
おちみず /落水/落ち水/
おちむしゃ /落ち武者/落武者/
おちめ /落ち目/
おちゃ /お茶/御茶/
おちゃうけ /御茶請け/お茶請け/
おちゃかい /お茶会/
おちゃがし /お茶菓子/
おちゃくみ /お茶汲み/
おちゃしつ /お茶室/
おちゃだい /お茶代/お茶大/
おちゃっぱ /お茶っ葉/
おちゃづけ /お茶漬け/お茶漬/
おちゃづけのり /御茶漬海苔/
おちゃのこ /御茶の子;茶菓子。「-さいさい」/
おちゃのこさいさい /御茶の子さいさい/
おちゃのま /お茶の間/御茶乃間/
おちゃのみず /お茶の水/御茶ノ水/御茶の水/
おちゃのみずじょしだいがく /お茶の水女子大学/
おちゃのみば /お茶飲み場/
おちゃめ /お茶目/
おちゅうげん /御中元/お中元/
おちゅうしゃ /お注射/
おちょうし /お銚子/
おちょうしもの /お調子者/
おちょこ /御猪口/お猪口/
おちょぼぐち /おちょぼ口/
おぢや /小千谷/
おっか /屋下;屋下に屋を架す/
おっかあ /おっ母/
おっかけ /追っかけ/追っ掛け/
おっかさん /おっ母さん/
おっきな /大っきな/
おっくう /億劫/
おっくご /オック語;langue d'oc/
おっくすふぉーどだいがく /オックスフォード大学;Oxford University. www.ox.ac.uk/
おっそ /越訴/
おって /追手/追っ手/追って/
おってがき /追而書/
おっと /夫/良人/
おっとう /おっ父/
おっとせい /膃肭臍/
おっとりがたな /押っ取り刀/
おっぱま /追浜/
おっぱまえき /追浜駅/
おっぽ /尾っぽ/
おつ /乙/榲;(すぎ)/膃;膃肭臍(おっとせい)/
おつあん /乙案/
おつうじ /お通じ/
おつかい /お使い/
おつかれさま /お疲れ様/お疲れさま/御疲れ様/
おつがわ /乙川/
おつがわえき /乙川駅/
おつき /御付き;付き人/
おつきあい /お付き合い/
おつきさま /お月様/お月さま/
おつくり /御造り;お刺身/お造り/御作り/お作り/
おつけ /御付け;味噌汁/
おつげ /お告げ/御告げ/
おつざいよう /乙剤用/
おつしゅ /乙種/
おつじ /尾辻/
おつたえ /お伝え/
おつつ /現/
おつとめ /お勤め/御勤め/
おつにょう /乙繞/
おつぼね /お局/
おつぼねさま /お局様/
おつや /お通夜/御通夜/
おつゆ /御汁/
おつり /お釣り/お釣/御釣り/
おづ /小津/
おづき /小月/
おづつ /尾筒/
おづやすじろう /小津安二郎/
おて /お手/御手/
おてあげ /お手上げ/御手上げ/お手あげ/
おてあらい /御手洗/お手洗い/お手洗/
おてあわせ /お手合わせ/
おていれ /お手入れ/
おてかず /お手数/
おてがみ /お手紙/御手紙/
おてがる /お手軽/
おてごろ /お手頃/
おてすう /お手数/御手数/
おてだま /お手玉/
おてつき /御手付き/
おてつだい /お手伝い/
おてて /お手々/
おてなみはいけん /お手並み拝見/御手並拝見/
おてのもの /お手の物/御手の物/
おてほん /お手本/
おてま /お手間/
おてまえ /お点前/
おてもち /お手持ち/
おてもと /お手元/お手許/
おてもり /お手盛り/
おてら /お寺/
おてん /汚点/
おてんき /お天気/
おてんとうさま /お天道様/
おてんとさま /お天道様/御天道様/
おてんば /お転婆/御転婆/
おでい /汚泥/
おでいしょり /汚泥処理/
おでいはっせいりょう /汚泥発生量/
おでかけ /お出かけ/お出掛け/
おでかけまえ /お出かけ前/
おでき /御出来/
おでし /御弟子/
おでら /小寺/
おでん /御田/
おでんだね /おでん種/
おでんわ /お電話/
おと /音/乙/彼方/遠/
おとあわせ /音合わせ/音合せ/
おといあわせ /お問い合わせ/
おといち /音一/
おといれ /音入れ/
おとうさま /お父様/御父様/
おとうさん /お父さん/
おとうす /音薄/
おとうちゃん /お父ちゃん/
おとうと /弟/
おとうとでし /弟弟子/
おとうとぶん /弟分/
おとうとよめ /弟嫁/
おとおし /御通し/お通し/
おとおんかい /音音階/
おとかず /音数/
おとかわ /乙川/
おとかんきょう /音環境;sound environment/
おとがい /頤/
おとがめ /お咎め/
おとき /御斎/
おとぎ /御伽/
おとぎぞうし /御伽草子/
おとぎばなし /おとぎ話/お伽話/御伽話/
おとぎりそう /弟切草/
おとぎりそうもく /オトギリソウ目/Dilleniales/Guttiferales/Hypericales/
おとぎりそうもくぐん /オトギリソウ目群/Hypericales/
おとく /お得/
おとくい /お得意/
おとくいさま /お得意様/
おとくうかん /音空間/
おとくに /乙訓/
おとくよう /お徳用/
おとけんしゅつ /音検出/
おとこ /男/漢/♂/
おとこあいて /男相手/
おとこあそび /男遊び/
おとこうぞう /音構造/
おとこうん /男運;⇔女運/
おとこえし /男郎花/
おとこおとこ /男男/
おとこおや /男親/
おとこおんな /男女/
おとこかんけい /男関係/
おとこがみ /男神/
おとこがわ /男側/
おとこきょうだい /男兄弟/
おとこぎ /男気;きっぷ/侠気/
おとこぎみ /男君/
おとこぎらい /男嫌い/
おとこぐせ /男癖/
おとこぐみ /男組/
おとこぐるい /男狂い/
おとこげ /男気;おとこっけ/
おとこげいしゃ /男芸者/
おとこことば /男言葉/
おとこごころ /男心/
おとこごろし /男殺し/
おとこざか /男坂/
おとこざかり /男盛り/
おとこしゃかい /男社会/
おとこしゅう /男衆/
おとこじゅく /男塾/
おとこじょたい /男所帯/
おとこずき /男好き/
おとこたち /男達/
おとこだて /男伊達/
おとこっけ /男っ気/
おとこっぷり /男っ振り/
おとこで /男手/
おとこともだち /男友達/
おとこどうし /男同士/
おとこども /男共/
おとこなき /男泣き/
おとこなまえ /男名前/
おとこのこ /男の子/男のコ/
おとこのひと /男の人/
おとこばら /男腹/
おとこひとり /男一人/
おとこべや /男部屋/
おとこべんじょ /男便所/
おとこまえ /男前/
おとこまさり /男勝り/男勝/
おとこみこ /男御子/
おとこみち /男道/
おとこみょうり /男冥利/
おとこもじ /男文字/
おとこもの /男物/
おとこやく /男役/
おとこやま /男山/
おとこやもめ /男鰥/
おとこゆ /男湯/
おとさた /音沙汰/
おとし /御年/御歳/お年/落し/お歳/落とし/
おとしあな /落とし穴/落し穴/陥穽/
おとしかた /落し方/
おとしがけ /落とし掛け/落し掛け/落とし懸け/落し懸け/
おとしがみ /落し紙/
おとしげき /音刺激/
おとしご /落とし子/落し子/
おとしごろ /お年頃/
おとしだね /落とし胤/落し胤/
おとしだま /お年玉/御年玉/おとし玉/
おとしどころ /落とし所/落し所/
おとしなちょう /音更町/
おとしぬし /落とし主/落し主/
おとしぶた /落とし蓋/落し蓋/
おとしぶみ /落し文/落とし文/落書/
おとしまえ /落とし前/落し前/
おとしもの /落とし物/落し物/
おとしより /お年寄り/
おとしんごう /音信号/
おとじたい /音自体/
おとじょうほう /音情報/
おとじろう /音二郎/
おとずれ /訪れ/
おとせってい /音設定/
おとそ /お屠蘇/
おとそしき /音組織/
おとだ /音田/
おとだし /音出し/
おとっつぁん /お父っつぁん/
おとつい /一昨日/
おとつづみ /弟鼓;小鼓/
おとづくり /音作り/
おとてき /音的/
おとと /弟/
おととい /一昨日/
おととし /一昨年/
おととび /音飛び/
おととり /音取り/音取/
おとどけ /お届け/
おとどけさき /お届先/お届け先/
おとどまち /大殿町/
おとな /大人/
おとながい /大人買い;[口]子供が小遣いでちびちび買うようなものを、経済力のある大人がまとめ買いすること/
おとなけいかく /大人計画/
おとなげ /大人気/
おとなし /音無/音無し/
おとなせんよう /大人専用/
おとなたち /大人達/
おとなひとり /大人一人/
おとなむけ /大人向け/
おとなよう /大人用/
おとなり /お隣/お隣り/御隣/
おとなりさん /お隣さん/
おとにゅうりょく /音入力/
おとは /乙葉;名/
おとひと /弟/
おとひめ /乙姫/
おとひめさま /乙姫様/
おとふけ /音更/
おとふじ /乙藤/
おとべ /乙部/
おとべちょう /乙部町/
おとべつ /音別/
おとむすめ /乙娘/
おとめ /乙女/少女/夫婦/夫妻;めおと/
おとめご /少女子/乙女子/
おとめごころ /乙女心/
おとめざ /乙女座;Virgo(Vir),(8.23-9.22)/
おとめじゅく /乙女塾/
おとめたい /乙女隊/
おとめたち /乙女達/
おとも /お供/御供/お伴/御伴/
おともだち /お友達/お友だち/
おともれ /音洩れ/
おとよめ /弟嫁/
おとり /囮/劣り/
おとりあつかい /お取り扱い/お取扱い/
おとりおき /お取り置き/
おとりこみちゅう /お取り込み中/
おとりそうさ /囮捜査/
おとりはからい /お取り計らい/お取計らい/
おとりひき /お取り引き/
おとりよせ /お取り寄せ/お取寄せ/
おとろえ /衰え/
おとわ /音羽/
おとわや /音羽屋/
おとわやま /音羽山/
おどき /男時;good time ⇔女時/
おどけ /戯け/
おどし /縅/脅し/
おどしもんく /脅し文句/
おどしゃ /御土砂/
おどり /踊り/
おどりぐい /踊り食い;白魚の-/
おどりこ /踊り子/
おどりじ /踊り字;「々」「ゝ」など/
おどりて /踊り手/
おどりねんぶつ /踊り念仏/
おどりば /踊り場/
おどれ /己/
おどろ /棘/
おどろき /驚き/愕き/駭き/
おな /女/
おない /小内/尾内/
おないぎ /御内儀;おかみさん/
おないどし /同い年/同い歳/
おなか /お腹/御中/
おなかま /お仲間/
おなが /尾長/翁長/
おながざる /尾長猿/
おながどり /尾長鶏/
おながれ /お流れ/御流れ/
おながわ /女川/
おなご /女子/
おなさけ /御情け/
おなじ /同じ/々;漢字/ゝ;ひらがな/ゞ;ひらがな、濁点つき/ヽ;カタカナ/ヾ;カタカナ、濁点つき。「スヾ(スズ)」/〃;文単位/仝;同上/
おなじく /同じく/々/
おなじみ /お馴染/お馴染み/
おなはま /小名浜/
おなべ /小鍋/
おなまえ /お名前/御名前/
おなみ /男波/
おなみだちょうだい /お涙頂戴/
おなもみ /葹/
おなやみ /お悩み/
おなり /御成/
おなりもん /御成門/
おなれそめ /御馴染/
おなんどいろ /御納戸色/
おに /鬼/
おに> /鬼;鬼娘,鬼教官,鬼部長/
おにあい /お似合い/
おにいさま /お兄様/
おにいさん /お兄さん/
おにいた /鬼板/
おにいちゃん /お兄ちゃん/
おにうだ /鬼生田/
おにおこぜ /鬼虎魚/
おにかわ /鬼可愛/
おにがしま /鬼ヶ島/
おにがらやき /鬼殻焼/
おにがわ /鬼皮/
おにがわら /鬼瓦/
おにきょうかん /鬼教官/
おにぎり /お握り/御握り/
おにく /お肉/尾肉;鯨のおいしい部分/
おにぐも /鬼蜘蛛/
おにぐるま /鬼車/
おにけいじ /鬼刑事/
おにこうべ /鬼首/
おにころし /鬼殺し;やたら強い安酒/
おにご /鬼子/
おにごっこ /鬼ごっこ/
おにごろし /鬼殺し/
おにざわ /鬼沢/
おにし /鬼石/
おにたいじ /鬼退治/
おにっこ /鬼っ子;親に似ない子/
おにつか /鬼束/鬼塚/
おにづか /鬼塚/
おにはは /鬼母/
おにば /鬼歯/
おにばば /鬼婆/
おにひとで /鬼海星/
おにび /鬼火/
おにへい /鬼平/
おにへいはんかちょう /鬼平犯科帳/
おにぼし /鬼星/
おにまる /鬼丸/
おにまろ /鬼磨呂/
おにみそ /鬼味噌;やたら塩っぱい/
おにむすめ /鬼娘/
おにもつ /お荷物/
おにゆり /鬼百合/
おによめ /鬼嫁/
おにわばん /御庭番/
おにわやき /御庭焼/
おぬま /小沼/
おね /尾根/
おねうち /お値打ち/
おねえ /お姉/
おねえさま /お姉さま/お姉様/
おねえさん /お姉さん/
おねえちゃん /お姉ちゃん/
おねがい /お願い/
おねじ /雄螺子/
おねせん /尾根線/
おねだん /お値段/
おねてん /尾根点/
おねば /大根葉/
おねみち /尾根道/
おの /斧/己/小野/尾野/
おのうえ /尾上/
おのうえおんせんえき /小野上温泉駅/
おのえ /尾上/
おのお /小野尾/
おのおか /小野岡/
おのおの /各々/各各/各/
おのおのがた /各々方/
おのかわ /小野川/
おのが /己が/
おのがくえん /小野学園/
おのがじし /己がじし/
おのがみ /小野上/
おのがわ /小野川/
おのがわこ /小野川湖/
おのき /小野木/
おのぎ /小野木/
おのこ /男子/男/男の子/
おのさと /小野里/
おのざき /小野崎/
おのざわ /小野沢/
おのず /自ず/
おのずか /小野塚/
おのずから /自ら/自ずから/
おのずと /自ずと/自と/
おのそっき /小野測器/
おのぞみ /お望み/
おのだ /小野田/
おのだか /小野高/
おのだせめんと /小野田セメント/
おのだせん /小野田線/
おのづか /小野塚/
おのでら /小野寺/
おののいもこ /小野妹子;遣隋使/
おののこまち /小野小町;平安時代の歌人。美人の代名詞/
おののたかむら /小野篁/
おののとうふう /小野道風;894-966/
おのぼりさん /お上りさん/
おのみ /尾の身/
おのみち /尾道/
おのむら /小野村/
おのやま /小野山/
おのれ /己/
おは /尾羽/
おはぎ /御萩;餅/
おはぐろ /鉄漿/御歯黒/お歯黒/
おはぐろどぶ /御歯黒溝;吉原の-/
おはこ /十八番/
おはこびさん /お運びさん/
おはし /お箸/御箸/
おはせ /小長谷/生長谷/
おはだ /お肌/
おはち /御鉢/お鉢/
おはつ /お初/御初/
おはな /お花/お鼻/
おはなし /お話/
おはなしちゅう /お話中/
おはなばたけ /御花畑;高山植物の花が咲く場所。単なる花畑ではない。/
おはなみ /お花見/
おはやし /お囃子/
おはやめ /お早め/
おはよう /お早う/
おはら /小原/大原/尾原/
おはらい /御祓い/お祓い/御祓/
おはらいばこ /お払い箱/
おはらぶし /おはら節;[民謡]鹿児島-/
おはらりゅう /小原流;生け花/
おはりこ /御針子/
おば /叔母;†父母の妹/伯母;†父母の姉/尾羽/小場/小母;†よその年配女性/
おばあ /お婆/
おばあさん /お婆さん/お祖母さん/
おばあちゃん /お婆ちゃん/
おばか /おバカ/
おばけ /お化け/尾羽毛;鯨の尾の部分/
おばけやしき /お化け屋敷/
おばさま /叔母様;†父母の妹/伯母様;†父母の姉/小母様;†よその年配女性(オバサン)/
おばさん /叔母さん;†父母の妹/伯母さん;†父母の姉/小母さん;†よその年配女性(オバサン)/
おばしま /欄/
おばすて /姨捨/
おばすてやま /姨捨山/
おばた /小幡/小畑/小俣/
おばたやま /小畑山/
おばな /雄花/尾花;すすき/
おばなざわ /尾花沢/
おばね /尾羽/
おばま /小浜/
おばまおんせん /小浜温泉/
おばません /小浜線/
おばら /小原/
おばらりゅうかいかん /小原流会館/
おひきうけ /お引受け/
おひきたて /お引き立て/
おひさしぶり /お久しぶり/お久し振り/
おひさま /お日様/お日さま/御日様/
おひざもと /お膝元/御膝下/
おひたき /御火焚/
おひたし /お浸し/御浸し/
おひつ /御櫃/お櫃/
おひつじ /牡羊/
おひつじざ /牡羊座;Aries(Ari),(3.21-4.19)/
おひと /御人/お人/
おひとかた /お一方/
おひとがら /お人柄/
おひとつ /お一つ/
おひとよし /御人好し/お人好し/
おひとり /お一人/
おひとりさま /お一人様/
おひなさま /御雛様/
おひねり /御捻り;小銭を包んで芸人に投げる/お捻り/
おひま /お暇/御暇/
おひめさま /お姫様/
おひゃくど /御百度/
おひや /御冷や/
おひら /御平/
おひらき /お開き/御開き/
おひる /お昼/
おひるころ /お昼頃/
おひるどき /お昼時/
おひるね /お昼寝/
おひるまえ /お昼前/
おひるやすみ /お昼休み/
おひれ /尾鰭/尾ひれ/
おひろめ /お披露目/御披露目/
おび /帯/飫肥;地名/小尾/帶;「帯」の旧字(人名用漢字)/
おびあげ /帯揚げ/
おびいた /帯板/
おびえ /怯え/
おびかわ /帯川/帯革/
おびがき /帯書/
おびがね /帯金/
おびがみ /帯紙/
おびきおく /帯記憶/
おびきん /帯筋;[建築]hoop. ⇔主筋/
おびぎょうれつ /帯行列/
おびぐらふ /帯グラフ/
おびこうこく /帯広告/
おびした /帯下/
おびじ /帯地/
おびじめ /帯締め/
おびじょう /帯状/
おびつ /小櫃/帯津/
おびと /首/
おびとけ /帯解/
おびどめ /帯留め/
おびなた /大日方/
おびなど /帯等/
おびのこ /帯鋸/
おびはば /帯幅/
おびばんぐみ /帯番組/
おびひろ /帯広/
おびひろえき /帯広駅/
おびひろはくようこうこう /帯広柏葉高校/
おびふう /帯封/
おびぶん /帯文/
おびまくら /帯枕/
おびもの /佩物/
おびら /小平/
おびれ /尾鰭/
おふぃすがい /オフィス街/
おふかい /オフ会/
おふく /御福/
おふくろ /お袋/御袋/
おふせ /御布施/
おふせっといんさつ /オフセット印刷/
おふたかた /御二方/
おふたり /お二人/御二人/
おふだ /御札/
おふでさき /御筆先/
おふみ /御文/
おふゆ /雄冬/
おふる /お古/
おふれ /御触れ/お触れ/
おふれがき /御触書/
おふろ /お風呂/
おふろあがり /お風呂上がり/
おふろば /お風呂場/
おぶき /小吹/
おぶくろ /尾袋/
おぶさ /綬/
おぶし /男節;背肉で作った鰹節/雄節/
おぶじぇくとしこう /オブジェクト指向/
おぶせ /小布施/
おぶち /小渕/尾駮/
おぶちざわ /小淵沢/
おぶつ /汚物/
おぶね /小舟/
おぷしょんとりひき /オプション取引/
おへや /お部屋/
おへんじ /お返事/御返事/
おへんろ /お遍路/
おべんきょう /お勉強/
おべんとう /お弁当/
おべんとうばこ /お弁当箱/
おぺ /手術/
おぺらかしゅ /オペラ歌手/
おぺらざ /オペラ座;l'Opera. www.opera-de-paris.fr/
おほ /凡/
おほしさま /お星様/お星さま/
おぼう /お坊/
おぼうさん /お坊さん/
おぼえ /覚え/憶え/
おぼえがき /覚書/覚え書き/
おぼえず /覚えず/
おぼこむすめ /おぼこ娘/
おぼし /男星/思し/
おぼしめし /思し召し/
おぼっちゃま /御坊ちゃま/お坊ちゃま/
おぼっちゃん /御坊ちゃん/お坊ちゃん/
おぼつかな /覚束無/
おぼろ /朧/朦;≒朧/
おぼろぐも /朧雲/
おぼろげ /朧げ/
おぼろづき /朧月/
おぼろづきよ /朧月夜/
おぼろづくよ /朧月夜/
おぼろどうふ /朧豆腐/
おぼろよ /朧夜/
おぼん /お盆/
おぼんやすみ /お盆休み/
おまい /御前/
おまいり /お参り/御参り/
おまえ /お前/御前/
おまえさま /御前様/
おまえさん /御前さん/お前さん/
おまえざき /御前崎/
おまえざきおき /御前崎沖/
おまえたち /御前達/お前達/
おまかせ /お任せ/
おまけ /御負け/
おまけつき /オマケ付き/おまけ付き/
おまごさん /お孫さん/
おまた /小俣/尾又/尾股/
おまち /雄町/お待ち/
おまちがい /お間違い/
おまちどおさま /御待ち遠様/
おまつり /御祭/お祭り/御祭り/
おまつりさわぎ /お祭り騒ぎ/御祭騒ぎ/
おまな /御真魚/
おまもり /お守り/御守り/
おまる /御虎子/
おまわり /お巡り/
おまわりさん /お巡りさん;犬の-/
おまんま /御飯/
おみ /臣/麻績/尾美/御神/
おみあい /お見合い/
おみあし /御御足/
おみおくり /お見送り/
おみおつけ /御御御付け/
おみがわ /小見川/
おみき /御神酒/お神酒/
おみくじ /御神籤/
おみくろん /ο;omicron/Ο;Omicron/
おみこし /御神輿/お神輿/
おみごと /お見事/御見事/
おみず /お水/御水/
おみずとり /御水取り;東大寺二月堂の行事/
おみせ /お店/御店/
おみそれ /御見逸れ/御見逸/
おみつもり /御見積/
おみとおし /お見通し/御見通し/
おみな /嫗;老婆/女;美女/
おみなえし /女郎花/
おみぬぐい /御身拭い;仏像等の掃除/
おみね /小峰/
おみまい /お見舞い/お見舞/御見舞/御見舞い/
おみみ /お耳/
おみむら /麻績村;姓/
おみや /御宮/お宮/
おみやげ /お土産/御土産/
おみやまいり /お宮参り/
おみわたり /御神渡り/
おむかい /お向かい/
おむかえ /御迎え/
おむこさん /お婿さん/
おむすび /お結び/御結び/
おむつ /繦/御襁褓/
おむな /嫗/
おむろ /御室/
おめ /御目;-にか[かけ]る/お目/
おめあて /お目当て/お目あて/
おめい /汚名/
おめいこう /御命講/
おめいし /お名刺/
おめいばんかい /汚名挽回;※汚名返上あるいは名誉挽回の誤り/
おめいへんじょう /汚名返上/
おめえ /御前;(要ルビ)/
おめえさん /御前さん;(要ルビ)/
おめが /ω;omega/Ω;Omega/
おめがね /御眼鏡;-に適う/お眼鏡/
おめざめ /お目覚め/
おめし /御召/
おめしもの /御召物/
おめしれっしゃ /御召列車;天皇用/
おめずおくせず /怖めず臆せず/
おめつけ /御目付け/
おめどおり /御目通り/
おめみえ /お目見え/御目見得/
おめもじ /御目文字/
おめんじょう /御免状/
おも /主/面/重/
おもい /思い/想い/重茂;地名,岩手/思/
おもいあがり /思い上がり;-も甚だしい/
おもいいれ /思い入れ/
おもいおもい /思い思い/
おもいかねのかみ /思兼神/
おもいがわ /思川/
おもいきや /思いきや/
おもいきり /思い切り/
おもいこみ /思い込み/
おもいすごし /思い過ごし/思い過し/
おもいだしわらい /思い出し笑い/
おもいちがい /思い違い/
おもいっきり /思いっきり/思いっ切り/
おもいつき /思い付き/
おもいで /思い出/想い出/
おもいでづくり /思い出作り/
おもいでばなし /思い出話/
おもいどおり /思い通り/
おもいなし /思い做し/
おもいのたけ /思いの丈/
おもいのほか /思いの外/
おもいびと /思い人/
おもいもの /思い者/
おもいやり /思いやり/思い遣り/
おもうさま /思う様/
おもうしこみ /お申し込み/お申込み/
おもうぞんぶん /思う存分/
おもうつぼ /思う壺/思う壷;「壺」異体字/
おもおも /重々/重重;-と/
おもかげ /面影/俤/於母影;(1889)新声社の訳詩集/
おもかじ /面舵/
おもがい /羈/面繋/面懸/
おもがわり /面変り/
おもげぎょ /本懸魚/
おもご /面河/
おもさ /重さ/
おもざし /面差し/
おもし /重石/重し;-をする/
おもしろ /面白/
おもしろい /面白い/
おもしろさ /面白さ/
おもしろはんぶん /面白半分/
おもしろみ /面白み/面白味/
おもしろやま /面白山/
おもしろやまこうげん /面白山高原/
おもしろやまこうげんえき /面白山高原駅/
おもたに /面谷/
おもだか /面高/沢瀉/
おもだかもく /オモダカ目/Alismatales/
おもだかもくぐん /オモダカ目群/
おもだち /面立ち/
おもち /お餅/
おもちかえり /お持ち帰り/
おもちゃ /玩具/
おもちゃばこ /玩具箱;toybox/おもちゃ箱/
おもちゃや /おもちゃ屋/玩具屋/
おもづかい /主遣い;人形浄瑠璃の-/
おもづら /羈/
おもて /表/面/
おもて> /表;-革,-街道,-舞台/
おもてあみ /表編み/
おもてうら /表裏/
おもてかいどう /表街道/
おもてかた /表方/
おもてかんばん /表看板/
おもてがえ /表替え/
おもてがき /表書き/表書/
おもてがまえ /表構え/
おもてがわ /表側/
おもてぐち /表口/
おもてぐみ /表組/
おもてけい /表罫/
おもてげんかん /表玄関/
おもてごう /表郷/
おもてさく /表作/
おもてさんどう /表参道/
おもてさんどうえき /表参道駅/
おもてさんどうこうさてん /表参道交差点/
おもてさんどうてん /表参道店/
おもてざしき /表座敷/
おもてざた /表沙汰/表ざた/
おもてじ /表地/
おもてせんけ /表千家/
おもてだな /表店/
おもてどおり /表通り/
おもてにほん /表日本/
おもてはく /表拍/
おもてぶた /表蓋/
おもてぶたい /表舞台/
おもてまんざ /表万座/
おもてみごろ /表身頃/
おもてむき /表向き/表向/
おもてめい /表銘/
おもてもん /表門/表紋/
おもてやま /表山/
おもてろっこう /表六甲/
おもと /御許/万年青;[植物]/
おもな /主な/
おもなが /面長/
おもに /重荷/主に/
おもの /御物;食事/佩物/
おものがわ /雄物川/
おもばば /重馬場/
おもぶき /趣/
おもみ /重み/重味/
おもみけいすう /重み係数/
おもむき /趣/趣き/
おもむけ /趣/
おもむろ /徐/
おもむろに /徐に/
おもめ /重め/
おももち /面持ち/面持/
おもや /母屋/
おもゆ /重湯/
おもらし /お漏らし/
おもり /錘/重り/お守り/
おもわ /面輪/
おもわく /思惑/思わく/
おもわくうり /思惑売り/
おもわくがい /思惑買い/
おもわすれ /面忘れ/
おもわず /思わず/
おもわせぶり /思わせ振り/
おもわれびと /思われ人/
おや /親/
おや> /親;親猫,親猿,親羊/
おやいし /親石;[建築]/首石;[建築]=親石/
おやいず /小柳津/
おやいづ /小柳津/
おやいで /小柳出/
おやいぬ /親犬/
おやいも /親芋/
おやおもい /親思い/
おやかぎ /親鍵/
おやかく /親核/
おやかた /親方/お館/
おやかたさま /お館様/
おやかためい /親方名/
おやかぶ /親株/
おやがいしゃ /親会社/
おやがかり /親掛かり/親掛り/
おやがみ /祖神/
おやがめ /親亀/
おやがわり /親代わり/親代り/
おやき /親機/親器/
おやきじ /親記事/
おやきゅうだん /親球団/
おやきょうだい /親兄弟/
おやきょく /親局/
おやぎ /親木/
おやぎみ /親君/
おやく /お役/御役/
おやくごめん /御役御免/お役御免/お役ご免/
おやくしょ /お役所/
おやくしょしごと /お役所仕事/
おやくそく /お約束/御約束/
おやくそくどおり /お約束通り/お約束どおり/御約束通り/
おやくにん /お役人/
おやけ /小宅/
おやこ /親子/母子/父子/母娘/父娘/親娘/
おやこうこう /親孝行/
おやこうこうもの /親孝行者/
おやこかん /親子間/
おやこかんけい /親子関係/
おやこたか /親子鷹/
おやこづれ /親子連れ/
おやこどん /親子丼/
おやこどんぶり /親子丼/
おやこなべ /親子鍋/
おやご /親御/
おやごころ /親心/
おやざと /親里/
おやしお /親潮/
おやしおいき /親潮域/
おやしらず /親不知/親知らず;=親不知/
おやじ /親父/親爺;=親父/親仁;=親父/親字;親文字/
おやじしん /親自身/
おやすみ /お休み/
おやせたい /親世帯/
おやたち /親達/
おやだ /親田/
おやだいだい /親代代/親代々/
おやだま /親玉/
おやつ /御八つ/
おやつだい /おやつ代/
おやといがいこくじん /御雇外国人/
おやど /御宿/
おやどけい /親時計/
おやどり /親鳥/
おやなぎ /小柳/
おやにらみ /親睨/
おやねこ /親猫/
おやばか /親馬鹿/親バカ/
おやばなれ /親離れ/
おやばら /親腹/
おやばれ /親バレ/
おやひとりこひとり /親一人子一人/
おやふこう /親不孝/
おやふこうもの /親不孝者/
おやぶね /親船/
おやぶん /親分/
おやぶんこぶん /親分子分/
おやぶんやく /親分役/
おやべ /小矢部/
おやぼね /親骨;扇の-/
おやま /小山/雄山/尾山/女形/御山/お山/女方/
おやまえき /小山駅/
おやまかん /小山間/
おやまこうじょう /小山工場/
おやまし /小山市/
おやまだ /小山田/
おやまのたいしょう /御山の大将/
おやまゆうえんち /小山遊園地/
おやみ /小止み/
おやむすめ /親娘/
おやもじ /親文字/
おやもと /親元/
おやゆずり /親譲り/
おやゆび /親指/拇/
おやゆびがわ /親指側/
おやゆびくん /親指君/
おゆ /お湯/
おゆうぎ /お遊戯/
おゆずり /御譲り/
おゆび /拇/
おゆるし /お許し/
おゆわり /お湯割り/御湯割り/
およぎ /泳ぎ/
およずれ /妖/
およずれごと /妖言/
およそ /凡そ/
およばずながら /及ばず乍ら/
およばれ /御呼ばれ/
および /及び/及/指/御呼び/お呼び/
およびごし /及び腰/
およめ /お嫁/
およめさん /お嫁さん/
およろこび /お喜び/お慶び/
おら /己/
おらんだ /和蘭;Olanda/
おらんだご /オランダ語;ベルギーでも使われる/
おらんだじん /オランダ人/
おり /檻;cage/澱;沈殿物/折/織;textile/折り/織り/
おりーぶいろ /オリーブ色;olive green/
おりーぶゆ /オリーブ油/
おりあい /折り合い/折合い/
おりあしく /折悪しく/
おりいと /織り糸/織糸/
おりお /折尾/
おりおえき /折尾駅/
おりおり /折々/折折/
おりおんざ /オリオン座;Orion(Ori)/
おりおんせいうん /オリオン星雲/
おりかえし /折り返し/
おりかえしちてん /折り返し地点/
おりかえしてん /折り返し点/
おりかさ /折笠/織笠/
おりかた /折形/
おりかも /氈/
おりから /折柄/
おりがさ /織笠/
おりがみ /折り紙/折紙/
おりがみざいく /折り紙細工/
おりがみつき /折り紙付き;便利さは-/
おりき /織機/
おりきど /折木戸/
おりくち /降り口/下り口/
おりくちしのぶ /折口信夫;民俗学者。別名釈迢空。『古代研究』/
おりぐち /降り口/下り口/
おりけい /折罫/
おりこみ /折込/折り込み;新聞の-/折込み/
おりこみこうこく /折り込み広告/折込み広告/
おりこみずみ /織り込み済み/織込み済み/
おりごとう /オリゴ糖;oligo saccharide.整腸作用がある/
おりしげ /折茂/
おりしも /折しも/
おりじなるきょく /オリジナル曲/
おりじなるばん /オリジナル版/
おりた /織田/
おりたたみ /折り畳み/折畳み/
おりたて /折立/
おりちょう /折丁/
おりづめ /折詰/折り詰め/折詰め/
おりづる /折り鶴/折鶴/
おりど /折戸/折り戸/
おりどしき /折戸式/
おりはし /折橋/
おりはら /折原/織原/
おりば /降り場/
おりばこ /折箱/折り箱/
おりひめ /織姫/
おりひめぼし /織姫星/
おりふし /折節/
おりべ /織部/
おりべやき /織部焼/
おりほん /折本/
おりめ /折り目/折目/織り目/織目/
おりも /織茂/折茂/
おりもと /織元/
おりもの /織物/下り物/
おりものきじ /織物生地/
おりもん /織文/
おりや /織屋/
おりやま /折山/
おりょうり /お料理/
おりよく /折良く;副詞/折よく/
おりんぴっくき /オリンピック旗;Olympic flag/
おりんぴっくしゅもく /オリンピック種目/
おるすばん /お留守番/
おるせーびじゅつかん /オルセー美術館;Musee d'Orsay. www.musee-orsay.fr/
おるどびすき /オルドビス紀;[地質年代]Ordovician. 5100-4390万年前/
おれ /俺/折れ/
おれい /御礼/お礼/
おれいきん /お礼金/
おれいごえ /お礼肥/
おれいまいり /御礼参り/
おれおれさぎ /おれおれ詐欺;[新語]/
おれくぎ /折れ釘/
おれくち /折れ口/
おれさま /俺様/オレ様/
おれじしん /俺自身/
おれせん /折れ線/折線/
おれせんぐらふ /折れ線グラフ/
おれたち /俺達/
おれっち /俺っち/
おれつ /オ列/お列/
おれめ /折れ目/
おれら /俺等/俺ら/
おれんじいろ /オレンジ色/
おれんち /俺んち/俺ん家/
おろ /悪露/疎/
おろおぼえ /疎覚え/
おろか /愚か/疎か/
おろかもの /愚か者/
おろし /卸/颪/卸し/下ろし/
おろし> /卸;-価格,-正味/
おろしうり /卸売/卸売り/
おろしうりかかく /卸売価格;wholesale price/
おろしうりがいしゃ /卸売会社/
おろしうりぎょう /卸売業/
おろしうりしじょう /卸売市場/
おろしうりてん /卸売店/
おろしうりぶっかしすう /卸売物価指数;[経済]Wholesale Price Index(WPI)/
おろしかかく /卸価格/
おろしがね /下ろし金/
おろししょう /卸商/
おろしそうば /卸相場/
おろしたて /下ろし立て/
おろしどんや /卸問屋/
おろしね /卸値/
おろしまち /卸町/
おろそか /疎か/
おろち /大蛇/
おわ /尾羽/
おわい /汚穢/
おわいや /汚穢屋/
おわかれ /お別れ/
おわかれかい /お別れ会/
おわせ /尾鷲/
おわだ /小和田/
おわだまさこ /小和田雅子/
おわび /お詫び/
おわらい /お笑い/
おわらいぐさ /お笑い種/お笑い草/
おわらいげいにん /お笑い芸人/
おわらぶし /おわら節;[民謡]越中-/
おわり /尾張/終/終わり/終り/
おわりあさひ /尾張旭/
おわりいちのみや /尾張一宮/
おわりこまき /尾張小牧/
おわりごろ /終頃/
おわりね /終値/
おわん /お碗/
おん /恩/音/温/御/怨;怨念/穏;穏健/隠;(呉音)隠密/遠;(呉音)久遠/園;(呉音)/瘟;瘟疫/穩;「穏」の旧字/隱;「隠」の旧字/
おん> /御/
おんあい /恩愛/
おんあつ /音圧/
おんあつさ /音圧差/
おんあつち /音圧値/
おんあつひ /音圧比/
おんあつぶんぷ /音圧分布/
おんあつれべる /音圧レベル/
おんい /恩威/
おんいき /音域/
おんいん /音韻/
おんいんかん /音韻間/
おんいんがく /音韻学/
おんいんし /音韻史/
おんいんじょう /音韻上/
おんいんじょうほう /音韻情報/
おんいんせい /音韻性/
おんいんたいけい /音韻体系/
おんいんてき /音韻的/
おんいんにんしき /音韻認識/
おんいんへんか /音韻変化/
おんいんほうそく /音韻法則/
おんいんろん /音韻論/
おんえい /恩栄/
おんえん /恩怨/
おんか /音価/恩化/恩仮/恩暇/
おんかい /音階/
おんかいれんしゅう /音階練習/
おんかく /温覚/
おんかた /御方/
おんかみ /御神/御髪/
おんかん /音感/
おんが /遠賀;地名/温雅/音画/
おんがえし /恩返し/
おんがく /音楽/
おんがくあいこうしゃ /音楽愛好者/
おんがくいがい /音楽以外/
おんがくいん /音楽院/
おんがくえいが /音楽映画/
おんがくえんそう /音楽演奏/
おんがくおんきょう /音楽音響/
おんがくか /音楽家/音楽科/音楽化/
おんがくかい /音楽会/音楽界/
おんがくかつどう /音楽活動/
おんがくかん /音楽館/音楽観/
おんがくかんけい /音楽関係/
おんがくかんけいしゃ /音楽関係者/
おんがくかんしょう /音楽鑑賞/
おんがくかんとく /音楽監督/
おんがくがく /音楽学/
おんがくがくいん /音楽学院/
おんがくがくしゃ /音楽学者/
おんがくがくぶ /音楽学部/
おんがくがっかい /音楽学会/
おんがくがっこう /音楽学校;conservatoire/
おんがくがわ /音楽側/
おんがくきき /音楽機器/
おんがくきょういく /音楽教育/
おんがくきょうし /音楽教師/
おんがくきょうしつ /音楽教室/
おんがくぎょうかい /音楽業界/
おんがくけい /音楽系/
おんがくけいしき /音楽形式/
おんがくけいたい /音楽携帯/
おんがくけんきゅう /音楽研究/
おんがくげいじゅつ /音楽芸術/
おんがくげき /音楽劇/
おんがくこうぎょう /音楽工業/
おんがくこうぼう /音楽工房/
おんがくさい /音楽祭/
おんがくさいせいき /音楽再生機/
おんがくさくひん /音楽作品/
おんがくさんぎょう /音楽産業/
おんがくざっし /音楽雑誌/
おんがくし /音楽史;history/音楽誌;magazine/
おんがくしこう /音楽指向/
おんがくしじょう /音楽市場/
おんがくしつ /音楽室/
おんがくしゅう /音楽集/
おんがくしゅうだん /音楽集団/
おんがくしゅっぱん /音楽出版/
おんがくしゅっぱんしゃ /音楽出版社/
おんがくしょう /音楽賞/
おんがくしょしんしゃ /音楽初心者/
おんがくしょり /音楽処理/
おんがくしんごう /音楽信号/
おんがくしんりがく /音楽心理学/
おんがくじたい /音楽自体/
おんがくじてん /音楽辞典/
おんがくじむしょ /音楽事務所/
おんがくじょうきょう /音楽状況/
おんがくじょうほう /音楽情報/
おんがくじょうほうかがく /音楽情報科学/
おんがくじょうほうけんさく /音楽情報検索/
おんがくじょうほうしょり /音楽情報処理/
おんがくずかん /音楽図鑑/
おんがくせい /音楽性/
おんがくせいかつ /音楽生活/
おんがくせいさく /音楽制作/
おんがくぜんしゅう /音楽全集/
おんがくそざい /音楽素材/
おんがくたい /音楽隊/
おんがくたいけん /音楽体験/
おんがくたんとう /音楽担当/
おんがくだいがく /音楽大学/
おんがくちかく /音楽知覚/
おんがくづくり /音楽作り/
おんがくてき /音楽的/
おんがくてききそ /音楽的基礎/
おんがくてきこうぞう /音楽的構造/
おんがくてきしゅほう /音楽的手法/
おんがくどう /音楽堂/
おんがくにんち /音楽認知/
おんがくのとも /音楽之友/音樂之友/
おんがくのともしゃ /音楽之友社/
おんがくは /音楽派/
おんがくはいしん /音楽配信/
おんがくばたけ /音楽畑/
おんがくばんぐみ /音楽番組/
おんがくひょうろんか /音楽評論家/
おんがくびがく /音楽美学/
おんがくふう /音楽風/
おんがくぶ /音楽部/
おんがくぶんか /音楽文化/
おんがくへん /音楽編/音楽篇/
おんがくほんらい /音楽本来/
おんがくや /音楽屋/
おんがくよう /音楽用/
おんがくようご /音楽用語/
おんがくりかい /音楽理解/
おんがくりょうほう /音楽療法;[精医]musicotherapy/
おんがくりょこう /音楽旅行/
おんがくりょだん /音楽旅団/
おんがくりろん /音楽理論/
おんがくれき /音楽歴/
おんがくろん /音楽論/
おんがぐん /遠賀郡/
おんがっか /音学家/
おんがっかい /音楽会/
おんがっかん /音楽館/
おんがな /音仮名/
おんがん /温顔/
おんき /遠忌/恩紀/
おんきごう /音記号/
おんきゅう /恩給/
おんきゅうしょうしょ /恩給証書/
おんきょう /音響/音強/
おんきょうかん /音響管/
おんきょうがいしょう /音響外傷/
おんきょうがく /音響学/
おんきょうがっかい /音響学会/
おんきょうがっかいし /音響学会誌/
おんきょうきき /音響機器/
おんきょうぎじゅつ /音響技術/
おんきょうくうかん /音響空間/
おんきょうけい /音響系/
おんきょうけん /音響研/
おんきょうげんしょう /音響現象/
おんきょうこうか /音響効果/
おんきょうこうがく /音響工学/
おんきょうごうせい /音響合成/
おんきょうしんごう /音響信号/
おんきょうしんごうしょり /音響信号処理/
おんきょうしんり /音響心理/
おんきょうじゅしん /音響受信/
おんきょうじょう /音響上/
おんきょうじょうほう /音響情報/
おんきょうせっけい /音響設計/
おんきょうせっけいがっか /音響設計学科/
おんきょうせつび /音響設備/
おんきょうつうしん /音響通信/
おんきょうてき /音響的/
おんきょうとくせい /音響特性/
おんきょうふか /音響負荷/
おんきょうぶ /音響部/
おんきょうぶんせき /音響分析/
おんぎ /恩義/音義/御義/恩誼/
おんぎょう /隠形/
おんぎょく /音曲/
おんくん /音訓/
おんくんさくいん /音訓索引/
おんぐう /恩遇/
おんぐすとろーむ /Å;angstrom,(10^-10)m/
おんぐん /音群/
おんけい /恩恵/音型/
おんけいてき /恩恵的/
おんけつ /温血/
おんけつどうぶつ /温血動物/
おんけん /穏健/
おんけんは /穏健派/
おんげん /音源/
おんげんいがい /音源以外/
おんげんいち /音源位置/
おんげんがわ /音源側/音現側/
おんげんすう /音源数/
おんげんばん /音源版/
おんげんぶ /音源部/
おんげんぶぶん /音源部分/
おんげんほうこう /音源方向/
おんげんほうしき /音源方式/
おんげんよう /音源用/
おんこ /恩顧/
おんこう /温厚/音高/音効/恩光/恩幸/
おんこうとくじつ /温厚篤実/
おんこうろん /音講論/
おんこちしん /温故知新/
おんこちしんしょ /温故知新書/
おんごく /遠国/
おんさ /音叉/
おんさく /音作/
おんさん /音産/
おんざ /穏座/
おんし /恩師/恩賜;天子から賜る/音詩/恩旨;天子の考え/恩私/
おんししょう /恩賜賞/
おんしっぷ /温湿布;⇔冷湿布/
おんしつ /音質/温室/
おんしつかいぜん /音質改善/
おんしつかいぜんこうか /音質改善効果/
おんしつこうか /温室効果/
おんしつこうかがす /温室効果ガス/
おんしつこうじょう /音質向上/
おんしつさ /音質差/
おんしつさいばい /温室栽培/
おんしつそだち /温室育ち/
おんしつてき /音質的/
おんしつど /温湿度/
おんしつどけい /温湿度計/
おんしつめん /音質面/
おんしつれっか /音質劣化/
おんしゃ /御社/恩赦/音写/
おんしゃく /恩借/
おんしゅう /温州/恩讐/恩讎/
おんしょう /温床/恩賞/恩詔/恩奨/
おんしょうかた /恩賞方/
おんしょうちょう /音象徴;[言語]sound symbolism/
おんしょく /音色/温色;≒暖色/慍色;むっとした顔色/
おんしょくすう /音色数/
おんしょくはいれつ /音色配列/
おんしょくめい /音色名/
おんしらず /恩知らず/
おんしん /音信/
おんしんふつう /音信不通/
おんじ /陰地/音字/遠志/
おんじき /飲食/
おんじゃく /温石/
おんじゃくめん /温石綿/
おんじゅ /飲酒/
おんじゅうとんこう /温柔敦厚/
おんじゅかい /飲酒戒/
おんじゅく /御宿/
おんじゅつ /恩恤/
おんじゅん /温順/音順/
おんじょう /音声/音場/温情/恩情/音情/
おんじょうかいせき /音場解析/
おんじょうかん /音場感/
おんじょうけん /音情研/
おんじょうさいせい /音場再生/
おんじょうしゅぎ /温情主義;paternalism/
おんじょうせいぎょ /音場制御/
おんじょうない /音場内/
おんじん /恩人/
おんすい /温水/
おんすいき /温水機/
おんすいぷーる /温水プール/
おんすいよく /温水浴/
おんすう /音数/
おんすうりつ /音数律/
おんず /音図/
おんせい /音声/
おんせいか /音声化/
おんせいかいせき /音声解析/
おんせいかんけい /音声関係/
おんせいがく /音声学/
おんせいがくてき /音声学的/
おんせいきかん /音声器官/
おんせいきごう /音声記号/
おんせいきょうちょう /音声強調/
おんせいきりかえ /音声切換/
おんせいくかん /音声区間/
おんせいけん /音声研/
おんせいけんきゅう /音声研究/
おんせいけんきゅうかい /音声研究会/
おんせいげんご /音声言語/
おんせいげんごしょり /音声言語処理/
おんせいごうせい /音声合成/
おんせいごうせいそうち /音声合成装置/
おんせいさんぷる /音声サンプル/
おんせいしゅうろく /音声収録/
おんせいしゅつりょく /音声出力/
おんせいしょり /音声処理/
おんせいしんごう /音声信号/
おんせいしんごうしょり /音声信号処理/
おんせいじょうほう /音声情報/
おんせいじょうほうしょり /音声情報処理/
おんせいせいせい /音声生成/
おんせいたいいき /音声帯域/
おんせいたいおう /音声対応/
おんせいたじゅう /音声多重/
おんせいたじゅうほうそう /音声多重放送/
おんせいちかく /音声知覚/
おんせいてき /音声的/
おんせいでんたつ /音声伝達/
おんせいにゅうりょく /音声入力/
おんせいにゅうりょくたんし /音声入力端子/
おんせいにんしき /音声認識/
おんせいにんしきそうち /音声認識装置/
おんせいは /音声波/
おんせいはけい /音声波形/
おんせいひょうき /音声表記/
おんせいひんしつ /音声品質/
おんせいふごうか /音声符号化/
おんせいぶ /音声部/
おんせいぶぶん /音声部分/
おんせいぶんせき /音声分析/
おんせいりかい /音声理解/
おんせき /恩錫/
おんせつ /音節/
おんせつこうぞう /音節構造/
おんせつすう /音節数/
おんせつちょう /音節長/
おんせつもじ /音節文字/
おんせん /温泉/音線/音栓/
おんせんえき /温泉駅/
おんせんかんこうち /温泉観光地/
おんせんがい /温泉街/
おんせんじょうほう /温泉情報/
おんせんじるし /温泉印/
おんせんたまご /温泉卵/
おんせんち /温泉地/
おんせんつあー /温泉ツアー/
おんせんぷーる /温泉プール/
おんせんほう /音線法/
おんせんまーく /温泉マーク/
おんせんまんじゅう /温泉饅頭/
おんせんやど /温泉宿/
おんせんよくじょう /温泉浴場/
おんせんりょうほう /温泉療法;[医]/
おんせんりょかん /温泉旅館/
おんせんりょこう /温泉旅行/
おんそ /音素/
おんそく /音速/音束;sound flux/
おんそくいか /音速以下/
おんそくひこう /音速飛行/
おんそぐん /音素群/
おんそたんい /音素単位/
おんそてき /音素的;phonemic/
おんそめい /音素名/
おんそもじ /音素文字/
おんそれつ /音素列/
おんそろん /音素論/
おんぞ /御衣/
おんぞう /音像/
おんぞうえく /怨憎会苦/
おんぞうし /御曹司/御曹子/
おんぞうていい /音像定位/
おんぞん /温存/
おんぞんりょうほう /温存療法;[医]/
おんた /音多;音声多重/
おんたい /御大/温帯/恩貸/
おんたいしょう /御大将/
おんたいせい /温帯性/
おんたいちいき /温帯地域/
おんたいちほう /温帯地方/
おんたいていきあつ /温帯低気圧/
おんたく /恩沢/
おんたけ /御岳/
おんたけさんえき /御嶽山駅/
おんだ /恩田/音田/
おんだい /音大/
おんだいせい /音大生/
おんだいそつ /音大卒/
おんだん /温暖/
おんだんか /温暖化/
おんだんかさよう /温暖化作用/
おんだんき /温暖期/
おんだんぜんせん /温暖前線;⇔寒冷前線/
おんち /音痴/恩地/
おんちく /音蓄/
おんちくけい /音蓄系/
おんちけん /音知研/
おんちゅう /御中/音注/
おんちょう /恩寵/温調;†温度調節/音調;†tone.「詩の-」/音長/
おんつう /音通/
おんてい /音程/温低/
おんていかん /音程感/
おんていがい /音程外/
おんていぶん /音程分/
おんてき /怨敵/
おんてん /恩典/温点/
おんでこざ /鬼太鼓座;[固有名詞]www.ondekoza.com/
おんと /音吐/
おんとう /穏当/温湯/
おんとろうろう /音吐朗朗/音吐朗々/
おんど /温度/音頭/音戸;地名,広島県安芸郡/
おんどかしょう /温度過昇/
おんどかんかく /温度感覚;[生理]冷覚と温覚/
おんどかんり /温度管理/
おんどく /音読/
おんどけい /温度計/
おんどこ /温床;おんしょう./
おんどこうばい /温度勾配/
おんどさ /温度差/
おんどしつど /温度湿度/
おんどじょうしょう /温度上昇/
おんどせってい /温度設定/
おんどちょうせつ /温度調節/
おんどてん /温度点/
おんどとり /音頭取り;乾杯の-/
おんどはんい /温度範囲/
おんどへんか /温度変化/
おんどほしょう /温度補償/
おんどほせい /温度補正/
おんどやくそう /温度躍層/
おんどり /雄鶏/雄鳥/
おんどる /温突/
おんな /女/恩納/恩名/音奈/♀/
おんなあそび /女遊び/
おんない /恩愛/
おんなうん /女運;⇔男運/
おんなおや /女親/
おんなかんけい /女関係/
おんながた /女形/女方/
おんながみ /女神/
おんながわ /女側/
おんなきょうし /女教師/
おんなきょうだい /女姉妹/
おんなぎみ /女君/
おんなぎらい /女嫌い/
おんなぐせ /女癖/
おんなぐるい /女狂い/
おんなけいず /婦系図/
おんなげいしゃ /女芸者/
おんなことば /女言葉/
おんなこども /女子供/
おんなころしあぶらのじごく /女殺油地獄;(1721)近松門左衛門/
おんなごころ /女心/
おんなごろし /女殺し/
おんなさんのみや /女三の宮;[源氏物語]/
おんなざか /女坂/
おんなざかり /女盛り/
おんなざちょう /女座長/
おんなししょ /女四書/
おんなしまい /女姉妹/
おんなしゃかい /女社会/
おんなしゅう /女衆/
おんなしゅじん /女主人/
おんなじ /同じ/
おんなじしん /女自身/
おんなじょたい /女所帯;⇔男所帯/
おんなずき /女好き/
おんなずもう /女相撲/
おんなせんし /女戦士/
おんなそうばし /女相場師/
おんなたいこ /女太鼓;女性幇間/
おんなたち /女達/
おんなたらし /女たらし/女誑し/女誑/
おんなだいがく /女大学/
おんなだて /女伊達/
おんなっけ /女っ気/
おんなっぷり /女っ振り/
おんなで /女手/
おんなともだち /女友達/
おんなどうし /女同士/
おんなどうらく /女道楽/
おんなども /女共/
おんななまえ /女名前/
おんなにのみや /女二の宮;[源氏物語]/
おんなのこ /女の子/女のコ/
おんなのひと /女の人/
おんなばら /女腹/
おんなばん /女版/
おんなひとり /女一人/
おんなへん /女偏;「媚」の偏/
おんなべや /女部屋/
おんなべんごし /女弁護士/
おんなべんじょ /女便所/
おんなみこ /女御子/
おんなみや /女宮/
おんなめ /妾/
おんなもじ /女文字/
おんなもの /女物/
おんなやく /女役/
おんなやもめ /女寡/
おんなゆ /女湯/
おんにん /穏忍/
おんねつ /温熱/
おんねつかんきょう /温熱環境/
おんねつりょうほう /温熱療法;[医]/
おんねん /怨念/
おんのじ /御の字/
おんはいすい /温排水/
おんば /音場/穏婆/
おんばこうか /音場効果/
おんばしらまつり /御柱祭;諏訪大社/
おんばひがさ /乳母日傘/
おんばん /音盤/
おんぱ /音波/恩波/
おんひ /音飛/
おんひょう /音標/
おんび /音尾/
おんびき /音引き/
おんびん /穏便/音便/
おんびんけい /音便形/
おんぴょう /音表/
おんぴょうもじ /音標文字/
おんぶきごう /音部記号;[音楽]ト音記号・ヘ音記号等/
おんぷ /音符;note/音譜;score/♪;quaver/
おんぷう /温風/
おんべつ /音別/
おんぼう /御坊/隠亡/
おんみ /御身/
おんみつ /隠密/
おんみつどうしん /隠密同心/
おんみつり /隠密裏/隠密裡/
おんみょう /陰陽/
おんみょうじ /陰陽師/
おんみょうどう /陰陽道/
おんめい /音名/恩名/恩命/
おんもと /御許/
おんもの /佩物;「おびもの」の転/
おんやく /音訳/
おんやさい /温野菜/
おんよう /陰陽/温容/恩養/
おんようけ /陰陽家;諸子百家/
おんようじ /陰陽師/
おんようどう /陰陽道/
おんよく /温浴/
おんよみ /音読/音読み/
おんり /遠離/厭離/
おんりえど /厭離穢土/
おんりつ /音律/
おんりょう /音量/怨霊/温良/
おんりょうちょうせい /音量調整/
おんりょうちょうせつ /音量調節/
おんる /遠流/
おんれい /御礼/恩礼/
おんれつ /音列/
おんわ /温和;†のどか。「-な気候」/穏和;†おだやか。「-な表現」/
か /蚊/化/可/下/日/歌/課/果/価/過/花/火/仮/夏/香/家/貨/科;科目/萪;(植物名)/蝌;蝌蚪(かと,おたまじゃくし)/箇/個/个/ヵ;小さなカタカナの「カ」/ヶ;「個」の略字/稼;稼動/嫁;よめ/靴;軍靴/訛;なまり/譌;「訛」の異体字/寡;寡婦/廈;大廈/厦;「廈」の異体字/賈;≒価/價;「価」の旧字(人名用漢字)/佳;佳作/掛;(慣用音)/卦/菓;菓子/夥;夥多/踝;くるぶし/顆;顆粒/華;華麗/嘩;喧嘩/譁;「嘩」の異体字/崋;崋山/暇;ひま/蝦;えび/霞;かすみ/葭;あし/遐;(とお・い)/假;「仮」の旧字/渦;うず/禍;舌禍/咼/堝;坩堝(かんか,るつぼ)/窩;眼窩/蝸;蝸牛/加;加算/伽;閼伽/迦;釈迦/跏;結跏趺坐/嘉;嘉慶/賀;年賀/架;架橋/茄;(慣用音) 茄子/袈;(漢音) 袈裟/枷;かせ/珈;珈琲/痂;かさぶた/笳;あしぶえ/何;幾何/河;河川/珂/苛;過酷/荷;出荷/呵;呵責/柯;爛柯/渮/舸/訶;摩訶不思議/軻/哥;うた/謌;「歌」の異体字/禾;のぎ/馨;かお・る/啝/戈;ほこ。干戈/罅;ひび/鹿;しか/耶;(疑問の助詞)/彼;(指示代名詞) か・の/墟;?/苟;?/
か> /可/過;過払い,過塩素酸,過冷却/加;加鉛,加糖/
かーきいろ /カーキ色;khaki/
かーどがいしゃ /カード会社/
かーどけっさい /カード決済/
かーどしき /カード式/
かーどはさん /カード破産/
かーびんじゅう /カービン銃;carbine/
かーぼんし /カーボン紙/
かーようひん /カー用品/
かあ /母/
かあさま /母様/
かあさん /母さん/
かあちゃん /母ちゃん/
かあつ /加圧/
かあつき /加圧器/
かあつすい /加圧水/
かあつすいがたげんしろ /加圧水型原子炉;PWR/
かい /会/回/解/貝/怪/快/甲斐/下位/改/階/界/海/塊;かたまり/隗;-より始めよ/櫂;oar/開/下意/歌意/戒/械;機械/誡;訓誡(=訓戒)/壊;破壊/懐;懐紙/壞;「壊」の旧字(人名用漢字)/懷;「懐」の旧字(人名用漢字)/皆;皆勤/偕;偕老同穴/揩;(ぬぐう)/楷;楷書/諧;諧謔/悔;悔悟/晦;韜晦/誨;教誨/魁;さきがけ/瑰;≒魁/傀;傀儡/嵬/槐;えんじゅ/介;介護/芥;あくた/价/畍;「界」の異体字/疥;疥癬/蟹;かに/蠏;「蟹」の異体字/廨;(役所)/懈;懈惰/觧;「解」の異体字/邂;邂逅/囘;「回」の異体字/廻;廻船問屋/徊;徘徊/茴;茴香(ういきょう)/蛔;蛔虫/迴;(めぐる)/灰;灰燼/恢;恢復/詼;(たわむれる)/絵;絵画/繪;「絵」の旧字/會;「会」の旧字/獪;老獪/拐;誘拐/枴;(おうご)/潰;潰滅/乖;乖離/喙;容喙/丐;(こう)/匯;(めぐる)/咼/夬;(わける)/恠;「怪」の異体字/椢;(くぬぎ)/榿;(はんのき)/褂;(うちかけ)/峡/醢;ひしお/街;まち/買い/飼/飼い/交い/垣;(熟字訓)垣間/χ;chi/Χ;Chi/
かい> /開/改/皆/怪;怪魚,怪事件,怪人物/下位;-領域,-互換性,-20%/
かいあく /改悪/
かいあげ /買い上げ/買上げ/
かいあわせ /貝合わせ/貝合せ/
かいい /怪異/階位/会意/魁偉/海尉/介意/
かいいき /海域/
かいいきがい /海域外/
かいいぬ /飼い犬;よく手を噛む/飼犬/
かいいもじ /会意文字;「日」+「月」＝「明」/
かいいれ /買入れ/買い入れ/買入/
かいいれさいむ /買入債務/
かいいれしょうきゃく /買入れ消却/
かいいん /会員/開院/海員/改印/
かいいんいがい /会員以外/
かいいんか /会員課/
かいいんかーど /会員カード/
かいいんかかく /会員価格/
かいいんかくしゃ /会員各社/
かいいんかん /会員間/
かいいんかんゆう /会員勧誘/
かいいんがい /会員外/
かいいんがっこう /海員学校/
かいいんきやく /会員規約/
かいいんけん /会員権/
かいいんし /会員誌/
かいいんしかく /会員資格/
かいいんしゅべつ /会員種別/
かいいんしょう /会員証/
かいいんしょうかい /会員紹介/
かいいんすう /会員数/
かいいんせい /会員制/
かいいんせいど /会員制度/
かいいんせんよう /会員専用/
かいいんせんようでんわ /会員専用電話/
かいいんぜんいん /会員全員/
かいいんそしき /会員組織/
かいいんとうろく /会員登録/
かいいんとくてん /会員特典/
かいいんとどけ /改印届/
かいいんどうし /会員同士/
かいいんないがい /会員内外/
かいいんはんばい /会員販売/
かいいんばんごう /会員番号/
かいいんぼ /会員簿/
かいいんぼしゅう /会員募集/
かいいんめいぼ /会員名簿/
かいいんゆうし /会員有志/
かいいんよう /会員用/
かいいんりょうきん /会員料金/
かいいんわりびき /会員割引/
かいう /海芋/
かいうん /開運/海運/海雲/
かいうんぎょう /海運業/
かいうんこく /海運国/
かいえい /開映/
かいえいまえ /開映前/
かいえき /改易/
かいえだ /海江田/
かいえん /開演/開園/海塩/怪演/海燕/開宴/快演/海淵/
かいえんじかん /開演時間/
かいえんたい /海援隊/
かいえんちゅう /開演中/
かいえんばん /開円板/
かいえんまえ /開演前/
かいおうせい /海王星/
かいおうせいきどう /海王星軌道/
かいおうまる /海王丸/
かいおき /買い置き/
かいおん /快音/回音/開音;[音声学]open sound/介音/
かいおんじ /海音寺/
かいおんせつ /開音節/
かいか /開花;†blossom.「才能が-する」/階下/開架;⇔閉架。「-図書」/開化;†civilise.「文明-」/怪火/開果/槐花/
かいかい /開会/恢恢;ゆったり。「天網-」/
かいかいあいさつ /開会挨拶/
かいかいいん /会会員/
かいかいしき /開会式/
かいかいしきちょくご /開会式直後/
かいかいせんげん /開会宣言/
かいかいそう /下位階層/
かいかえ /買い替え/買い換え/買換え/買替え/
かいかく /改革/開核/
かいかくあん /改革案/
かいかくがわ /改革側/
かいかくど /開角度/
かいかくは /改革派/
かいかくろせん /改革路線/
かいかけ /買掛/
かいかけきん /買掛金/
かいかけちょう /買掛帳/
かいかしき /開架式/
かいかた /買い方/買方/
かいかつ /快活/開豁/
かいかつどう /会活動/
かいかてんのう /開化天皇/
かいかわ /會川/
かいかん /快感/会館/開館/開巻/會舘/会舘/開管/怪漢/快漢/
かいかんがわ /会館側/
かいかんげんそく /快感原則;[精医]Lustprinzip/
かいかんじ /怪幹事/
かいが /絵画/怪訝/繪畫;旧字/
かいがい /海外/
かいがいあて /海外宛/
かいがいえんせい /海外遠征/
かいがいかつどう /海外活動/
かいがいきんむ /海外勤務/
かいがいけいけん /海外経験/
かいがいけしょうひん /海外化粧品/
かいがいけんしゅう /海外研修/
かいがいさいしんじょうほう /海外最新情報/
かいがいさくひん /海外作品/
かいがいしじょう /海外市場/
かいがいしてん /海外支店/
かいがいしゅっちょう /海外出張/
かいがいしゅっちょうちゅう /海外出張中/
かいがいしゅぼば /海外種牡馬/
かいがいしんしゅつ /海外進出/
かいがいじょうほう /海外情報/
かいがいじんじ /海外人事/
かいがいせい /海外製/
かいがいせいかつ /海外生活/
かいがいせいさん /海外生産/
かいがいせいひん /海外製品/
かいがいそうきん /海外送金/
かいがいつあー /海外ツアー/
かいがいてんかい /海外展開/
かいがいとうし /海外投資/
かいがいとうぼう /海外逃亡/
かいがいとくはいん /海外特派員/
かいがいとこう /海外渡航/
かいがいねん /下位概念;subordinate concept./
かいがいはけん /海外派遣/
かいがいはっけん /海外発券/
かいがいはっそう /海外発送/
かいがいはっちゅう /海外発注/
かいがいはつ /海外発/
かいがいはへい /海外派兵/
かいがいばん /海外版/海外盤/
かいがいふにん /海外赴任/
かいがいぶもん /海外部門/
かいがいぶんがく /海外文学/
かいがいへん /海外編/
かいがいほうそう /海外放送;NHKの-/
かいがいほうろう /海外放浪/
かいがいぼうえき /海外貿易/
かいがいむけ /海外向け/海外向/
かいがいもの /海外物/
かいがいよう /海外用/
かいがいりゅうがく /海外留学/
かいがいりょこう /海外旅行/
かいがいりょこうしゃ /海外旅行者/
かいがいりょこうほけん /海外旅行保険/
かいがいりょこうよう /海外旅行用/
かいがいろけ /海外ロケ/
かいがく /開学/
かいがさくひん /絵画作品/
かいがてき /絵画的/
かいがてん /絵画展/
かいがね /胛/
かいがもり /貝ヶ森/貝が森/
かいがら /貝殻/
かいがらぶし /貝殻節;[民謡]鳥取。「カワイヤノー」/
かいがん /海岸/開眼/
かいがんきょく /海岸局/
かいがんせん /海岸線/
かいがんぞい /海岸沿い/海岸沿/
かいがんだんきゅう /海岸段丘/
かいがんどおり /海岸通/
かいがんぶ /海岸部/
かいがんへいや /海岸平野;[地理]coastal plain/
かいき /回帰/怪奇/会期/開基/会規/快気/回忌/皆既/買い気/改軌/買気/回歸/
かいきいわい /快気祝い/快気祝/
かいきえん /怪気炎/
かいきがた /回帰型/
かいききょくせん /回帰曲線/
かいきげっしょく /皆既月食/
かいきげんしょう /怪奇現象/
かいきげんそう /怪奇幻想/
かいきしゅ /下位機種/
かいきしょうせつ /怪奇小説/
かいきしょうせつしゅう /怪奇小説集/
かいきしょく /皆既食/
かいきせん /回帰線/
かいきだいさくせん /怪奇大作戦/
かいきちゅう /会期中/
かいきてき /回帰的/
かいきてきていぎ /回帰的定義/
かいきにっしょく /皆既日食/皆既日蝕/
かいきぶんせき /回帰分析/
かいきへん /怪奇編/
かいきゃく /開脚/
かいきゅう /階級/懐旧/海丘/開球/
かいきゅういしき /階級意識/
かいきゅうかん /階級間/
かいきゅうこうぞう /階級構造/
かいきゅうさべつ /階級差別/
かいきゅうしょう /階級章/
かいきゅうせい /階級制/
かいきゅうせいとう /階級政党/
かいきゅうたいりつ /階級対立/
かいきゅうてき /階級的/
かいきゅうとうそう /階級闘争/
かいきゅうべつ /階級別/
かいきょ /快挙/開渠/
かいきょう /海峡/海況/回教/開胸;[医]-(手)術,-心マッサージ/開経/懐郷/契経/
かいきょうせん /海峡線/
かいきょうと /回教徒/
かいきょうれき /回教暦;イスラム暦/
かいきょく /開局/
かいきょくしんせい /開局申請/
かいきょくじ /開局時/
かいきょくねんがっぴ /開局年月日/
かいきり /買い切り/買切り/
かいきん /解禁/皆勤/開襟/
かいきんしょう /皆勤賞/
かいきんび /解禁日/
かいぎ /会議/懐疑/海技/回議/解義/
かいぎあんない /会議案内/
かいぎし /海技士;国家資格。航海・機関・通信・電気通信の４種/
かいぎしつ /会議室/
かいぎしゅぎ /懐疑主義/
かいぎしゅっせきしゃ /会議出席者/
かいぎしょ /会議所/
かいぎしりょう /会議資料/
かいぎじたい /会議自体/
かいぎじょう /会議場/
かいぎじろく /会議事録/
かいぎたい /会議体/
かいぎだいがっこう /海技大学校;国交省。www.mtc.ac.jp/
かいぎちゅう /会議中/
かいぎてき /懐疑的/
かいぎないよう /会議内容/
かいぎは /懐疑派/
かいぎばしょ /会議場所/
かいぎひ /会議費/
かいぎめい /会議名/
かいぎゃく /諧謔/詼謔/
かいぎゃくみ /諧謔味/
かいぎょ /海魚/怪魚/
かいぎょう /開業/改行/
かいぎょうい /開業医/
かいぎょういち /改行位置/
かいぎょういちへんこう /改行位置変更/
かいぎょうご /改行後/
かいぎょうしきん /開業資金/
かいぎょうしょにち /開業初日/
かいぎょうじ /開業時/
かいぎょうちゅう /開業中/
かいぎょうとうしょ /開業当初/
かいぎょうとうじ /開業当時/
かいぎょうび /開業日/
かいぎょうまえ /開業前/改行前/
かいぎょうもじ /改行文字/
かいぎょく /買玉;[相場]/買い玉;[相場]buying account/
かいぎろく /会議録/
かいぎろん /懐疑論;scepticism/
かいく /海区/化育/皆苦/
かいくうかん /解空間;space of solution/開空間;open space/
かいくかん /開区間/
かいくん /回訓/
かいぐ /戒具/
かいぐい /買い食い/
かいぐさ /飼い草/飼草/
かいぐん /海軍/
かいぐんきち /海軍基地/
かいぐんしょう /海軍省/
かいぐんしょうさ /海軍少佐/
かいぐんだいがっこう /海軍大学校/
かいぐんだいじん /海軍大臣/
かいぐんよびがくせい /海軍予備学生/
かいけい /会計/海景/塊茎/会稽;-の恥/快慶/
かいけいか /会計科/
かいけいかんさ /会計監査/
かいけいがく /会計学/
かいけいきかん /会計期間/
かいけいきじゅん /会計基準/
かいけいぎょうむ /会計業務/
かいけいけんさ /会計検査/
かいけいけんさいん /会計検査院/
かいけいけんさかん /会計検査官/
かいけいざん /会稽山/
かいけいし /会計士/
かいけいしょり /会計処理/
かいけいせいど /会計制度/
かいけいねんど /会計年度/
かいけいのはじ /会稽の恥/
かいけいほう /会計法/
かいけいほうこく /会計報告/
かいけいほうこくしょ /会計報告書/
かいけいりろん /階型理論;theory of types/
かいけおんせん /皆生温泉/
かいけつ /解決/快傑/怪傑/魁傑/
かいけつあん /解決案/
かいけつかてい /解決過程/
かいけつさく /解決策/
かいけつしゅだん /解決手段/
かいけつずみ /解決済み/
かいけつびょう /壊血病/
かいけつふかのう /解決不可能/
かいけつへん /解決編/解決篇/
かいけつほう /解決法/
かいけつほうほう /解決方法/
かいけはい /買気配/買い気配/
かいけん /会見/改憲/懐剣/開顕/海研/
かいけんじょう /会見場/
かいけんは /改憲派/
かいけんろん /改憲論/
かいげつ /海月/
かいげん /開眼/改元/戒厳/
かいげんしょう /怪現象/
かいげんじ /甲斐源氏/
かいげんれい /戒厳令/
かいげんれいか /戒厳令下/
かいこ /解雇/蚕/回顧;ふりかえる。「-展」/懐古;なつかしむ。「-趣味」/蠶;「蚕」の旧字/廻顧/回雇;?/蚕儚;?/解顧;?/
かいこう /開講/開校/開口/開港/邂逅/改稿/海溝/回航/海港/回行/怪光/開高;姓/海口;中国の都市/蟹行/開項/
かいこういちばん /開口一番/
かいこうおん /開口音/
かいこうかもく /開講科目/
かいこうがた /海溝型/
かいこうきねんび /開校記念日/
かいこうしき /開講式/
かいこうしゃ /偕行社/
かいこうしょうがい /開口障害/
かいこうしょく /灰黄色/
かいこうたけし /開高健/
かいこうたん /開口端/
かいこうび /開講日/
かいこうぶ /開口部/
かいこうめん /開口面/
かいこうもんじ /蟹行文字/
かいこうりつ /開口率/
かいこく /開国/戒告/会告/海国/回国/廻国;=回国/
かいこくへいだん /海国兵談;林子平(1791)/
かいこくらん /会告欄/
かいこくろん /開国論/
かいこしゅぎしゃ /懐古主義者/
かいこしゅみ /懐古趣味/
かいこだな /蚕棚/
かいこちょう /回顧調/
かいこてき /懐古的/
かいこてん /回顧展/
かいことば /買い言葉/買言葉/
かいこは /懐古派/
かいこま /甲斐駒/
かいころく /回顧録/
かいこん /開墾/開梱/悔恨/塊根/
かいこんち /開墾地/
かいご /介護/悔悟/開悟/下位語/戒護/改悟/諧語/解語/
かいごう /会合/改号/開合;[言語]開音と合音/蟹螯/
かいごうしゅうき /会合周期/
かいごかんせい /下位互換性/
かいごきゅうぎょう /介護休業/
かいごけん /介護犬/
かいごし /介護士/
かいごしせつ /介護施設/
かいごにん /介護人/
かいごふくしし /介護福祉士/
かいごほうしゅう /介護報酬/
かいごほけん /介護保険/
かいごほけんほう /介護保険法/
かいごほけんりょう /介護保険料/
かいごよう /介護用/
かいごようひん /介護用品/
かいごろし /飼い殺し/
かいさ /階差/海佐/
かいさい /開催/快哉/皆済/
かいさいあんない /開催案内/
かいさいきかん /開催期間/
かいさいきかんちゅう /開催期間中/
かいさいきかんない /開催期間内/
かいさいきじつ /開催期日/
かいさいきねん /開催記念/
かいさいけいけん /開催経験/
かいさいこく /開催国/
かいさいしんせい /開催申請/
かいさいじ /開催時/
かいさいじき /開催時期/
かいさいじゅんび /開催準備/
かいさいじょうけん /開催条件/
かいさいせきにんしゃ /開催責任者/
かいさいち /開催地/
かいさいちゅう /開催中/
かいさいちゅうし /開催中止/
かいさいちょくぜん /開催直前/
かいさいつうち /開催通知/
かいさいと /下位サイト/
かいさいとし /開催都市/
かいさいにちじ /開催日時/
かいさいにっすう /開催日数/
かいさいにってい /開催日程/
かいさいねん /開催年/
かいさいばしょ /開催場所/
かいさいび /開催日/
かいさいようこう /開催要項/
かいさいよてい /開催予定/
かいさく /開削/快作;masterpiece/改作;remake/開作;cultivate.「荒野の-」/怪作;horrible piece/開鑿;=開削/
かいさつ /改札/開札/
かいさつがかり /改札係/
かいさつき /改札機/
かいさつぐち /改札口/
かいさん /解散/海産/開山;寺院の建立/
かいさんかい /解散会/
かいさんき /開山忌/
かいさんけん /解散権/
かいさんご /解散後/
かいさんじ /解散時/
かいさんじょうたい /解散状態/
かいさんせいきゅう /解散請求;[法]住民が地方議会の解散を請求すること・する権利。<地方自治法/
かいさんせつ /解散説/
かいさんぶつ /海産物/
かいさんめいれい /解散命令/
かいざい /介在/
かいざいく /貝細工/
かいざいはいれつ /介在配列/
かいざいりょう /買い材料/
かいざん /改竄/海山/開山;山開き/買い残/改ざん/
かいざんじけん /改竄事件/
かいし /開始/会誌/海士/懐紙/海市;蜃気楼/怪死/戒師/会試;科挙の二次試験/界紙/芥子/
かいしいち /開始位置/
かいしいらい /開始以来/
かいしき /開式/解式/下意識/
かいしきごう /開始記号/
かいしきねん /開始記念/
かいしぎょう /開始行/
かいしご /開始後/
かいしじ /開始時/
かいしじかん /開始時間/
かいしじこく /開始時刻/
かいしじてん /開始時点/
かいしたん /開始端/
かいしち /開始値/
かいしちょくご /開始直後/
かいしつ /開室/
かいしつび /開室日/
かいしてん /開始点/
かいしとうしょ /開始当初/
かいしねん /開始年/
かいしひづけ /開始日付/
かいしび /開始日/
かいしまえ /開始前/
かいしめ /買占め/
かいしめい /会誌名/
かいしゃ /会社/膾炙;人口に-する(=広く愛される)/會社;「会」旧字/
かいしゃあんない /会社案内/
かいしゃいん /会社員/
かいしゃいんせいかつ /会社員生活/
かいしゃかん /会社間/
かいしゃかんけい /会社関係/
かいしゃかんけいしゃ /会社関係者/
かいしゃがいよう /会社概要/
かいしゃがえり /会社帰り/
かいしゃがわ /会社側/
かいしゃく /解釈/介錯/解釋/
かいしゃくかいけん /解釈改憲;F15やM1は陸海空その他の戦力ではありません/
かいしゃくかのう /解釈可能/
かいしゃくがく /解釈学/
かいしゃくけい /解釈系/
かいしゃくしゃ /解釈者/
かいしゃくじっこう /解釈実行/
かいしゃくほう /解釈法/
かいしゃくほうほう /解釈方法/
かいしゃくろん /解釈論/
かいしゃけいえい /会社経営/
かいしゃこうせい /会社更生/
かいしゃこうせいほう /会社更生法/
かいしゃしゃかい /会社社会/
かいしゃしゃちょう /会社社長/
かいしゃしょうかい /会社紹介/
かいしゃじたい /会社自体/
かいしゃじん /会社人/
かいしゃせい /会社製/
かいしゃせいかつ /会社生活/
かいしゃせいり /会社整理/
かいしゃせつめいかい /会社説明会/
かいしゃせん /会社線/
かいしゃぜんたい /会社全体/
かいしゃそしき /会社組織/
かいしゃぞう /開写像/
かいしゃたんい /会社単位/
かいしゃづとめ /会社勤め/
かいしゃない /会社内/
かいしゃないぶ /会社内部/
かいしゃにんげん /会社人間/
かいしゃほう /会社法/
かいしゃほうもん /会社訪問/
かいしゃめい /会社名/
かいしゃもち /会社もち/
かいしゃやくいん /会社役員/
かいしゃろく /会社録/
かいしゅ /拐取/
かいしゅう /回収/改修;repair.「ビルの-工事」/改宗;convert.「ムスリムへの-」/会衆/回收;「収」旧字/
かいしゅうがく /回収額/
かいしゅうこうじ /改修工事/
かいしゅうこうじちゅう /改修工事中/
かいしゅうごう /開集合/
かいしゅうさき /回収先/
かいしゅうしゃ /回収車/
かいしゅうちゅう /改修中/回収中/
かいしゅうばこ /回収箱/
かいしゅうばしょ /回収場所/
かいしゅうりつ /回収率/
かいしゅん /回春/改悛/悔悛;≒改悛/買春/
かいしゅんびょういん /回春病院/
かいしょ /開所/楷書/甲斐性;=かいしょう/会所/回書/
かいしょう /解消/改称/快勝/甲斐性/海象;maritime phenomena/海商/海将/介紹/海嘯/会商/海相/回章/廻章/
かいしょうかん /解消感/
かいしょうぎじゅつ /解消技術/
かいしょうさく /解消策/
かいしょうなし /甲斐性無し/
かいしょうほう /解消法/
かいしょく /会食/快食;-快眠/解職/海食/
かいしょくがい /海食崖/
かいしょくせいきゅう /解職請求/
かいしょくだい /海食台/
かいしょくどう /海食洞/
かいしょしき /開所式/
かいしょたい /楷書体/
かいしよてい /開始予定/
かいしろ /垣代/
かいしん /会心;†satisfaction.「-の笑み|一撃」/改心;†reform.「犯罪者の-」/回診;「医師の-」/回心;†[宗教]convert.「キリスト教に-」/快心;†pleasant.「-の出来事」/改新/開進/海進;[地学]marine transgression/改進/戒心/
かいしんげき /快進撃/
かいじ /開示/海事/海自;[略語]海上自衛隊/怪事/甲斐路/解字/快事/
かいじがく /解字学/
かいじけん /怪事件/
かいじさいけん /開示債権/
かいじじょうほう /開示情報/
かいじせいきゅう /開示請求/
かいじせいきゅうけん /開示請求権/
かいじつ /会日;会合のある日/晦日;月の末日/
かいじむきょく /会事務局/
かいじゃり /海砂利/
かいじゅ /槐樹/解呪/
かいじゅう /怪獣;monster/海獣;sea animal/懐柔/晦渋/
かいじゅうえいが /怪獣映画/
かいじゅうご /怪獣語/
かいじゅうさく /懐柔策/
かいじゅうだいひゃっか /怪獣大百科/
かいじゅうめい /怪獣名/
かいじゅんびかい /会準備会/
かいじょ /解除/介助/
かいじょう /会場/海上/開場/階上/開錠/開城/塊状/階乗/回状/廻状/塊上/階状/解錠/
かいじょうあんないず /会場案内図/
かいじょううけつけ /会場受付/
かいじょうえ /戒定慧;[仏教]/
かいじょうかさい /海上火災/
かいじょうかさいほけん /海上火災保険/
かいじょうがい /会場外/
かいじょうがかり /会場係/
かいじょうがわ /会場側/
かいじょうけん /海上権/
かいじょうげんていひん /会場限定品/
かいじょうこうえん /海上公園/
かいじょうこうつう /海上交通/
かいじょうごえい /海上護衛/
かいじょうしょうとつよぼうほう /海上衝突予防法/
かいじょうじ /開場時/
かいじょうじえいたい /海上自衛隊/
かいじょうじかん /開場時間/
かいじょうじゅう /会場中/
かいじょうじゅんび /会場準備/
かいじょうせいり /会場整理/
かいじょうぜんたい /会場全体/
かいじょうだい /会場代/
かいじょうていいん /会場定員/
かいじょうない /会場内/
かいじょうひ /会場費/
かいじょうふきん /会場付近/
かいじょうほあんだいがっこう /海上保安大学校;www.jcga.ac.jp/
かいじょうほあんちょう /海上保安庁/
かいじょうほう /怪情報/
かいじょうほけん /海上保険/
かいじょうぼうえい /海上防衛/
かいじょうまえ /会場前/開場前/
かいじょうめい /会場名/
かいじょうゆそうろ /海上輸送路/
かいじょけん /介助犬/解除権/
かいじょしゃ /介助者/
かいじょじょうけん /解除条件/
かいじり /海尻/
かいじん /怪人/海神/海人/灰燼;燃え滓。「-に帰す」/灰塵;灰とチリ。取るに足りぬもの/
かいじんぶつ /怪人物/
かいすい /海水/
かいすいおん /海水温/
かいすいおんど /海水温度/
かいすいぎ /海水着/
かいすいぎょ /海水魚/
かいすいちゅう /海水中/
かいすいぱんつ /海水パンツ;swim trunks/
かいすいめん /海水面/
かいすいよく /海水浴/
かいすいよくきゃく /海水浴客/
かいすいよくじょう /海水浴場/
かいすう /回数/階数/
かいすうけん /回数券/
かいすうじゅん /回数順/
かいず /海図/海津/
かいずか /貝塚;※仮名遣い「かいづか」/
かいせ /貝瀬/
かいせい /改正/快晴/回生/開成/海星/改姓/改製;remake/海棲/魁星;Dubhe/
かいせいあん /改正案/開盛庵/
かいせいいぜん /改正以前/
かいせいきてい /改正規定/
かいせいげんあん /改正原案/
かいせいこうこう /開成高校/
かいせいご /改正後/
かいせいごう /改正号/
かいせいしっこう /回生失効/
かいせいしゃ /偕成社;[出版社名]www.kaiseisha.co.jp/
かいせいじ /改正時/回生時/
かいせいじょうほう /改正情報/
かいせいせいどう /回生制動/
かいせいそう /海成層/
かいせいてん /改正点/
かいせいでんりゅう /回生電流/
かいせいでんりょく /回生電力/
かいせいばん /改正版/
かいせいび /改正日/
かいせいほう /改正法/
かいせいまえ /改正前/
かいせき /解析/懐石/会席/階席/
かいせきかい /解析解/
かいせきかんすう /解析関数/
かいせきがく /解析学/
かいせきき /解析器/
かいせききかがく /解析幾何学/
かいせききかん /解析機関/
かいせきぎ /解析木/
かいせきぎじゅつ /解析技術/
かいせきぎほう /解析技法/
かいせきけい /解析系/
かいせきけいかく /解析計画/
かいせきけっか /解析結果/
かいせきけんきゅうしつ /解析研究室/
かいせきしゃ /解析者/
かいせきしゅほう /解析手法/
かいせきしんごう /解析信号/
かいせきじ /解析時/
かいせきじょう /解析上/
かいせきせつぞく /解析接続/
かいせきたいしょう /解析対象/
かいせきちゅう /解析中/
かいせきてき /解析的/
かいせきてじゅん /解析手順/
かいせきほう /解析法/
かいせきほうほう /解析方法/
かいせきぼん /解析本/
かいせきりきがく /解析力学/
かいせきりょうり /懐石料理/会席料理/
かいせきろん /解析論/
かいせつ /解説/開設/回折/回雪/
かいせつかい /解説会/
かいせつきじ /解説記事/
かいせつげんしょう /回折現象/
かいせつこうし /回折格子/
かいせつしゃ /解説者/
かいせつしゃたち /解説者達/
かいせつしゅう /解説集/
かいせつしょ /解説書/
かいせつじま /回折縞/
かいせつじん /解説陣/
かいせつず /解説図/
かいせつてき /解説的/
かいせつとうしょ /開設当初/
かいせつふよう /解説不要/
かいせつぶん /解説文/
かいせつぶんしょ /解説文書/
かいせつへん /解説編/
かいせつぼん /解説本/
かいせつめい /解説名/
かいせつもくろく /解説目録/
かいせつらん /解説欄/
かいせつりつ /会設立/
かいせつりつじゅんびかい /会設立準備会/
かいせつりつそうかい /会設立総会/
かいせん /回線/海鮮/開戦/改選/海戦/開栓/会戦/回旋/疥癬/廻船/回戦/界線/回船/
かいせんいじょう /回線異常/
かいせんいちば /海鮮市場/
かいせんきほんりょうきん /回線基本料金/
かいせんこうかん /回線交換/
かいせんご /開栓後/
かいせんじじょう /回線事情/
かいせんすう /回線数/
かいせんせんようりょう /回線専用料/
かいせんぜんや /開戦前夜/
かいせんそくど /回線速度/
かいせんだい /回線代/
かいせんだん /回線断/
かいせんちゅう /改選中/
かいせんでんわ /回線電話/
かいせんどんや /廻船問屋/
かいせんひ /回線費/
かいせんひんしつ /回線品質/
かいせんへんけい /回旋変形/
かいせんもう /回線網/
かいせんりょうきん /回線料金/
かいせんりよう /回線利用/
かいぜいやくしょ /改税約書/
かいぜつ /快絶/
かいぜん /改善/
かいぜんあん /改善案/
かいぜんいけん /改善意見/
かいぜんかのう /改善可能/
かいぜんかんこく /改善勧告/
かいぜんこうか /改善効果/
かいぜんこうもく /改善項目/
かいぜんさく /改善策/
かいぜんしゅほう /改善手法/
かいぜんていあん /改善提案/
かいぜんてん /改善点/
かいぜんど /改善度/
かいぜんまえ /改善前/
かいぜんめいれい /改善命令;公取委の-/
かいぜんやく /改善薬/
かいぜんようきゅう /改善要求/
かいぜんりつ /改善率/
かいそ /改組/開祖/海鼠;ナマコ/
かいそう /階層/改装/回想/海藻/海草/快走/回送/会葬/改葬/下位層/回漕/潰走/海曹/回走/
かいそううちゅう /階層宇宙/
かいそううんてん /回送運転/
かいそうか /階層化/階層下/
かいそうかん /階層間/
かいそうかんけい /階層関係/
かいそうがた /階層型/
かいそうき /回想記/
かいそうこうじ /改装工事/
かいそうこうぞう /階層構造/
かいそうご /改装後/
かいそうごと /階層毎/
かいそうしゃ /回送車/
かいそうじ /回送時/
かいそうせい /階層性/
かいそうちゅう /改装中/回送中/階層中/
かいそうてき /階層的/
かいそうてきこうぞう /階層的構造/
かいそうでんしゃ /回送電車/
かいそうない /階層内/
かいそうば /買相場/
かいそうばなし /回想話/
かいそうひ /改装費/
かいそうべつ /階層別/
かいそうめい /階層名/
かいそうれっしゃ /回送列車/
かいそうろく /回想録/
かいそく /快速/会則/快足/
かいそくうんてん /快速運転/
かいそくか /快速化/
かいそくきゅうこう /快速急行/
かいそくじゅんきゅう /快速準急/
かいそくせん /快速線/
かいそくつうか /快速通過/
かいそくていしゃ /快速停車/
かいそくていしゃえき /快速停車駅/
かいそくでんしゃ /快速電車/
かいそくとっきゅう /快速特急/
かいそくば /快速馬/
かいそくよう /快速用/
かいそくれっしゃ /快速列車/
かいそしき /下位組織/
かいそん /海村;⇔山村/海損/
かいぞう /改造/解像/海象;I am the walrus, goo-goo-goo-joob!/海三/
かいぞうあん /改造案/
かいぞうき /改造機/
かいぞうきじ /改造記事/
かいぞうこうじ /改造工事/
かいぞうご /改造後/
かいぞうしゃ /改造車/
かいぞうしゃけん /改造車検/
かいぞうしゅじゅつ /改造手術/
かいぞうてん /改造点/
かいぞうど /解像度/
かいぞうどてき /解像度的/
かいぞうないかく /改造内閣/
かいぞうにんげん /改造人間/
かいぞうばん /改造版/
かいぞうひ /改造費/
かいぞうほう /改造法/
かいぞうよう /改造用/
かいぞうりょう /改造量/
かいぞうりょく /解像力/
かいぞうれき /改造歴/
かいぞえ /介添/介添え/
かいぞく /海賊/回族;中国のイスラム教徒/
かいぞくおとこ /海賊男/
かいぞくせん /海賊船/
かいぞくてき /海賊的/
かいぞくばん /海賊版/海賊盤/
かいぞくばんたいさく /海賊版対策/
かいぞめ /買い初め/
かいぞん /買い損/
かいた /海田/頴田/
かいたい /解体/懐胎/戒体/拐帯/
かいたいぎょう /解体業/
かいたいぎょうしゃ /解体業者/
かいたいこうじ /解体工事/
かいたいさぎょう /解体作業/
かいたいしゅうり /解体修理/
かいたいしんしょ /解体新書/
かいたいせつび /解体設備/
かいたいち /海田市/
かいたいや /解体屋/
かいたく /開拓/
かいたくし /開拓史/
かいたくしゃ /開拓者/
かいたくしゃせいしん /開拓者精神/
かいたくじだい /開拓時代/
かいたくち /開拓地/
かいたくのうみん /開拓農民/
かいたん /海単/
かいだ /開田/海田/貝田/改田/快打/
かいだい /改題/解題/海内/開題/
かいだか /階高/
かいだく /快諾/
かいだこ /貝蛸/
かいだこうげん /開田高原/
かいだし /買い出し/買出し/
かいだて /階建/買建/階建て/買い建て;[相場]/買建て;[相場]/
かいだめ /買いだめ/買い溜め/買い貯め;?/
かいだん /階段/会談;meeting/怪談;chilly story/解団;disband/戒壇/快談;agreable conversation/
かいだんきょうしつ /階段教室/
かいだんご /会談後/
かいだんし /快男子/
かいだんしつ /階段室/
かいだんじ /快男児/
かいだんじょう /階段状/
かいだんのぼり /階段登り/
かいだんばなし /怪談話/
かいだんふきん /階段付近/
かいだんよこ /階段横/
かいち /嘉一/垣内/
かいちく /改築/
かいちくあん /改築案/
かいちくこうじ /改築工事/
かいちくじ /改築時/
かいちくまえ /改築前/
かいちゅう /海中/回虫/懐中;pocket.「-時計」/改鋳/蛔虫;=回虫/界中/蛔蟲/懷中;旧字/
かいちゅうこうえん /海中公園/
かいちゅうでんとう /懐中電灯/
かいちゅうどけい /懐中時計/
かいちゅうもん /買い注文/
かいちょう /会長/快調/階調;tone/開帳/海鳥/怪鳥;「-ロック」/開庁;官庁の業務開始/回腸/開張;[法]=開帳。「賭博-」/諧調;harmony/
かいちょうおん /海潮音/
かいちょうしつ /会長室/
かいちょうせき /灰長石;anorthite/
かいちょく /回勅/
かいちん /開陳/
かいつう /開通/
かいつういらい /開通以来/
かいつうご /開通後/
かいつうしき /開通式/
かいつうじょうほう /開通情報/
かいつうとうしょ /開通当初/
かいつうび /開通日/
かいつうぶぶん /開通部分/
かいつうまえ /開通前/
かいつうよていび /開通予定日/
かいつけ /買い付け/買付/買付け/
かいつぶり /鳰/
かいづ /海津/
かいづか /貝塚/
かいづかし /貝塚市/
かいて /買い手/買手/
かいてい /改訂;†「本の-」/改定;†「法律の-」/海底/開廷/階梯/海程/
かいていかざん /海底火山/
かいていぐんかん /海底軍艦/
かいていこう /改訂稿/
かいていさぎょう /改訂作業/改定作業/
かいていしんでん /海底神殿/
かいていじ /改訂時/
かいていじしんけい /海底地震計/
かいていだいにはん /改訂第二版/
かいていちけい /海底地形/
かいていてつづき /改定手続/改定手続き/
かいていにまんり /海底二万里/
かいていばん /改訂版/改定版;価格-/
かいていぶん /改訂文/
かいていほうほう /改定方法/
かいていゆでん /海底油田/
かいていりれき /改訂履歴/
かいてき /快適/会的/
かいてきか /快適化/
かいてきくうかん /快適空間/
かいてきせい /快適性/
かいてしじょう /買い手市場/買手市場/
かいてん /回転/開店/廻転/廻天/廻轉/
かいてんいか /回転以下/
かいてんいき /回転域/
かいてんいす /回転椅子/
かいてんいわい /開店祝/開店祝い/
かいてんうんどう /回転運動/
かいてんおん /回転音/
かいてんかく /回転角/
かいてんかくそくど /回転角速度/
かいてんきゅうぎょう /開店休業/
かいてんけい /回転計/回転系/
かいてんさ /回転差/
かいてんざひょうけい /回転座標系/
かいてんし /回転子/
かいてんしき /回転式/
かいてんしきん /回転資金/
かいてんじ /回転時/開店時/
かいてんじかい /回転磁界/
かいてんじく /回転軸/
かいてんじくほうこう /回転軸方向/
かいてんじょ /回転所/
かいてんじょうきょう /回転状況/
かいてんすう /回転数/
かいてんすうけい /回転数計/
かいてんすうせいぎょ /回転数制御/
かいてんすしや /回転寿司屋/
かいてんずし /回転寿司/
かいてんせいのう /回転性能/
かいてんせんい /回転遷移/
かいてんそくど /回転速度/
かいてんたい /回転体/
かいてんたいしょう /回転対称/
かいてんちゅう /回転中/
かいてんちょくご /開店直後/
かいてんていすう /回転定数/
かいてんとう /回転灯/
かいてんどあ /回転ドア/
かいてんはんけい /回転半径/
かいてんば /回転刃/回転場/
かいてんばん /回転板/
かいてんび /開店日/
かいてんぶぶん /回転部分/
かいてんほうこう /回転方向/
かいてんほうほう /回転方法/
かいてんまえ /開店前/
かいてんまど /回転窓/
かいてんめん /回転面/
かいてんもくば /回転木馬/
かいてんやき /回転焼/
かいてんよく /回転翼/
かいてんりつ /回転率/
かいてんりょう /回転量/
かいてんりょく /回転力/
かいてんれいき /回転励起/
かいてんろ /回転炉/
かいでん /皆伝/海田/
かいでんぱ /怪電波/
かいと /垣内/
かいとう /回答;†response.「質問への-」/解答;†answer.「問題の-例」/解凍;†defrost.「(食品|アーカイブ)の-」/怪盗/会頭/快投;[野球]wonderful pitching/開頭;[医]craniotomy/快刀;「-乱麻」/解糖;[化学]glycolysis/解党/快盗/灰陶/海濤/
かいとうあん /回答案/
かいとういがい /回答以外/
かいとうきかん /回答期間/
かいとうぐん /解答群;†「次の-から選べ」/回答群;†「調査に寄せられた-」/
かいとうけっか /回答結果/
かいとうけん /解答権/
かいとうご /解凍後/
かいとうしだい /回答次第/
かいとうしゃ /回答者;†「アンケートの-」/解答者;†「クイズの-」/
かいとうしゃこじん /回答者個人/
かいとうしゃすう /回答者数/
かいとうしゃぜんいん /回答者全員/
かいとうしゃちゅう /回答者中/
かいとうしゅう /回答集;†「よくある質問と-」/解答集;†「ワークブックの-」/
かいとうしょ /回答書/
かいとうじ /解凍時/
かいとうすう /回答数/
かいとうせき /解答席/
かいとうちゅう /解凍中/
かいとうない /回答内/
かいとうぶん /回答文/
かいとうもと /回答元/
かいとうようし /解答用紙;†answer sheet.「テストの-」/回答用紙;†response sheet.「アンケートの-」/
かいとうらん /解答欄;†「テストの-」/回答欄;†「アンケートの-」/
かいとうらんま /快刀乱麻;-を断つ/
かいとうれい /解答例;†「試験問題の-」/回答例;†「調査票の-」/
かいとり /買取/買い取り/買取り/貝取/貝取り/
かいとりかかく /買取価格/買い取り価格/買取り価格/
かいとりて /買取手/
かいとりや /買取屋/買い取り屋/買取り屋/
かいど /開度/灰土/
かいどう /街道;甲州-/海道;東-/海堂/会堂;hall/会同;meeting/海棠;[植物]aronia/怪童/皆藤/
かいどうあと /街道跡/
かいどうすじ /街道筋/海道筋;(東)海道の道筋/
かいどうぞい /街道沿い/
かいどき /買い時/
かいどく /解読/買い得/買得/回読/会読/
かいどくのうりょく /解読能力/
かいどくふかのう /解読不可能/
かいどくほうほう /解読方法/
かいどくほん /解読本/
かいどくぼん /解読本/
かいどくよう /解読用/
かいどり /飼鳥/
かいな /腕/
かいなげ /腕挙げ/
かいなで /掻い撫で;通り一遍/
かいなひねり /腕捻り/
かいなん /海難/海南/
かいなんきゅうじょ /海難救助/
かいなんしんぱんちょう /海難審判庁/
かいなんじこ /海難事故/
かいなんとう /海南島/
かいにゅう /介入/
かいにゅうけん /介入権/
かいにん /解任/懐妊/
かいにんじょう /解任状/
かいにんそう /海仁草/海人草/
かいぬし /飼い主/買主/飼主/買い主/
かいぬま /貝沼;姓/海沼/
かいね /買値/買い値/
かいねこ /飼い猫/飼猫/
かいねんきん /皆年金/
かいのう /戒能/
かいは /会派/
かいはい /改廃/
かいはく /灰白/
かいはくしつ /灰白質/
かいはくしょく /灰白色/
かいはつ /開発/解発;elicitation/
かいはついっか /開発一課/
かいはついん /解発因/
かいはつえんじょ /開発援助/
かいはつか /開発課/
かいはつかんきょう /開発環境/
かいはつがいしゃ /開発会社/
かいはつがわ /開発側/
かいはつき /開発機/
かいはつきかくぶ /開発企画部/
かいはつきかん /開発期間/
かいはつきぼ /開発規模/
かいはつきょういく /開発教育/
かいはつきょうそう /開発競争/
かいはつきょか /開発許可/
かいはつきょく /開発局/
かいはつぎじゅつ /開発技術/
かいはつぎじゅつしゃ /開発技術者/
かいはつぎょうしゃ /開発業者/
かいはつぎょうむ /開発業務/
かいはつぐるーぷ /開発グループ/
かいはつけいかく /開発計画/
かいはつけんきゅうしつ /開発研究室/
かいはつけんきゅうじょ /開発研究所/
かいはつげんご /開発言語/
かいはつげんば /開発現場/
かいはつこうがく /開発工学/
かいはつこうがくか /開発工学科/
かいはつこうてい /開発工程/
かいはつこうりつ /開発効率/
かいはつさぎょう /開発作業/
かいはつしえん /開発支援/
かいはつしきん /開発資金/
かいはつしつ /開発室/
かいはつしゃ /開発者/
かいはつしゃかん /開発者間/
かいはつしゃがわ /開発者側/
かいはつしゅだん /開発手段/
かいはつしゅほう /開発手法/
かいはつしょう /開発省/
かいはつしょく /開発職/
かいはつじ /開発時/
かいはつじかん /開発時間/
かいはつじぎょう /開発事業/
かいはつじぎょうぶ /開発事業部/
かいはつじじょう /開発事情/
かいはつじっけんしつ /開発実験室/
かいはつじょう /開発上/
かいはつじょうきょう /開発状況/
かいはつじん /開発陣/
かいはつすいしん /開発推進/
かいはつすいしんか /開発推進課/
かいはつすいしんしつ /開発推進室/
かいはつすいしんぶ /開発推進部/
かいはつせいさく /開発製作/
かいはつぞう /開発像/
かいはつたいしょう /開発対象/
かいはつたんとう /開発担当/
かいはつたんとうしゃ /開発担当者/
かいはつだいいちぶ /開発第一部/
かいはつだいさんぶ /開発第三部/
かいはつだんかい /開発段階/
かいはつち /開発値/
かいはつちーむ /開発チーム/
かいはつちゅう /開発中/
かいはつちゅうし /開発中止/
かいはつとうかつぶ /開発統括部/
かいはつとうしょ /開発当初/
かいはつとじょう /開発途上/
かいはつとじょうこく /開発途上国/
かいはつとちゅう /開発途中/
かいはつのうりょく /開発能力/
かいはつひ /開発費/
かいはつぶ /開発部/
かいはつぶかいはつか /開発部開発課/
かいはつぶだい /開発部第/
かいはつぶもん /開発部門/
かいはつほう /開発法/
かいはつほうしき /開発方式/
かいはつほうほう /開発方法/
かいはつほうほうろん /開発方法論/
かいはつほんぶ /開発本部/
かいはつめん /開発面/
かいはつもくてき /開発目的/
かいはつもと /開発元/
かいはつよう /開発用/
かいはつよういん /開発要員/
かいはつりょう /開発量/
かいはつりょく /開発力/
かいはら /開原/
かいはん /改版;revise/開板;publish/解版;⇔組版/
かいば /海馬/飼い葉/飼葉/
かいばおけ /飼い葉桶/飼葉桶/
かいばしら /貝柱/
かいばつ /海抜/皆伐/
かいばら /柏原/海原/貝原/開原/
かいばらえきけん /貝原益軒/
かいばん /改版/改番/
かいばんさぎょう /改版作業/
かいひ /回避/会費/開扉/海彼;overseas/廻避;=回避/
かいひぎむ /回避義務/
かいひこうどう /回避行動/
かいひさく /回避策/
かいひせい /会費制/
かいひちょうしゅう /会費徴収/
かいひてき /回避的/
かいひどうさ /回避動作/
かいひなど /会費等/
かいひにゅうきん /会費入金/
かいひば /回避馬/
かいひふく /開被覆/
かいひほう /回避法/
かいひほうほう /回避方法/
かいひむりょう /会費無料/
かいひょう /開票/海氷;sea ice/解氷;ice-out/界標/回表/
かいひょうけっか /開票結果/
かいひょうさぎょう /開票作業/
かいひょうじょ /開票所/
かいひょうじょうほう /開票情報/
かいひょうせっちけん /界標設置権/
かいひょうそくほう /開票速報/
かいひょうりつ /開票率/
かいひよう /回避用/
かいひりょく /回避力/
かいひん /海浜/
かいひんまくはり /海浜幕張/
かいひんまくはりえき /海浜幕張駅/
かいひんりょくち /海浜緑地/
かいび /快美/
かいびかえ /買い控え/
かいびゃく /開闢/
かいふ /開府/回付/海部;人名/
かいふう /開封/海風/
かいふうそう /懐風藻;日本の漢詩集/
かいふうちょくご /開封直後/
かいふうつうち /開封通知/
かいふかい /快不快/
かいふき /貝吹/
かいふく /回復/開腹;laparotomy/快復;病気が-する/恢復;=回復/開福/
かいふくき /回復期/
かいふくきちょう /回復基調/
かいふくご /回復後/
かいふくざい /回復剤/
かいふくしゅじゅつ /開腹手術/
かいふくじ /回復時/
かいふくじゅつ /開腹術;[医]laparotomy/
かいふくじゅもん /回復呪文/
かいふくそち /回復措置/
かいふくとうき /回復登記/
かいふくふのう /回復不能/
かいふくほう /回復法/
かいふくりつ /回復率/
かいふくりょく /回復力/
かいぶったい /怪物体/
かいぶつ /怪物/
かいぶつせいむ /開物成務/
かいぶつたち /怪物達/
かいぶん /灰分/回文;たけやぶやけた/回分;(助数詞)/怪聞/
かいぶんしょ /怪文書/
かいぶんだけ /開聞岳/
かいぶんるい /下位分類;subclass/
かいへい /開閉/海兵/開平/皆兵/
かいへいおん /開閉音/
かいへいき /開閉器/
かいへいたい /海兵隊/
かいへいだん /海兵団/
かいへき /界壁/
かいへん /改変;†change.「ファイルの-」/改編;†reform.「組織の-」/海辺/壊変;disintegrate/貝偏;[部首]「賭」/拐騙/
かいへんき /改編期/
かいへんこうい /改変行為/
かいへんぶぶん /改変部分/
かいべくとる /解ベクトル/
かいべん /快便/快弁/
かいぺーじ /改ページ/改頁/
かいぺいじ /改頁/
かいほ /海保/
かいほう /開放;†(open)「ドアを開放する」/解放;†(liberate)「(人質|メモリ)を解放する」/会報/解法;solution.「問題の-」/介抱/快方/回報/海法;marine law/海北;人名/開法;「平方根の-」/開方;=開法/海堡/快報;good news/戒法/懐抱/壊崩/改封/潰崩/廻報;=回報/
かいほううんどう /解放運動/
かいほうかん /開放感;†(openness)「吹き抜けの-」/解放感;†(liberation)「週末の-」/
かいほうがた /開放型/解放型;?/
かいほうく /開放区/
かいほうぐん /解放軍/開放軍;?/
かいほうけい /開放系/
かいほうけいざい /開放経済/
かいほうげん /開放弦;open string/解放弦;?/
かいほうこうざ /開放講座/
かいほうさく /開放策/
かいほうじ /開放時/
かいほうせい /開放性/
かいほうせいさく /開放政策/
かいほうせき /海泡石/
かいほうせんせん /解放戦線/
かいほうだい /開放台/
かいほうち /開放値/解放値/
かいほうてき /開放的;open/解放的;liberating/
かいほうどうめい /解放同盟/
かいほうびょうとう /開放病棟/
かいほうやく /介抱役/
かいほうよう /会報用/
かいほうれい /解放令/
かいほつ /開発/
かいぼ /介母/
かいぼう /解剖/海防/海膨;oceanic rise/
かいぼうかん /海防艦/
かいぼうがく /解剖学/
かいぼうがくてき /解剖学的/
かいぼうじっしゅう /解剖実習/
かいぼうず /解剖図/
かいぼうよう /解剖用/
かいぼん /海盆/
かいま /垣間/
かいまい /回米/廻米/買米/
かいまいしほう /買米仕法/
かいまき /掻巻/
かいまく /開幕/
かいまくけん /開幕権/
かいまくご /開幕後/
かいまくしき /開幕式/
かいまくしゅう /開幕週/
かいまくせん /開幕戦/
かいまくちょくご /開幕直後/
かいまくとうしょ /開幕当初/
かいまくまえ /開幕前/
かいまみ /垣間見/
かいまわりひん /買回り品;shopping goods. 小売の分類の一/買い回り品/
かいみ /快味/
かいみょう /戒名/
かいみん /快眠/
かいむ /皆無/会務/海霧/怪夢/
かいめ /回目/
かいめい /解明/改名/開明;文明の進歩/階名;[音楽]ドレミファソラシド/晦冥;darkness/晦明;dark and light/晦暝;=晦冥/
かいめいじゅう /開明獣/
かいめいほうほう /解明方法/
かいめいもんだい /改名問題/
かいめつ /壊滅/潰滅;≒壊滅/
かいめつじょうたい /壊滅状態/
かいめつてき /壊滅的/潰滅的;≒壊滅的/
かいめん /海面;sea-surface/界面;interface.「-活性剤」/海綿;sponge/
かいめんか /海面下/
かいめんかっせい /界面活性/
かいめんかっせいざい /界面活性剤/
かいめんじょう /海綿状/海面上/
かいめんじょうしょう /海面上昇/
かいめんじょうそしき /海綿状組織/
かいめんたい /海綿体/
かいめんどうぶつ /海綿動物/
かいめんは /界面波/
かいもうぶ /回盲部/
かいもく /皆目/
かいもくけんとう /皆目見当/
かいもどし /買い戻し/買戻し/
かいもの /買い物/買物/買いもの/
かいものかご /買い物籠/買い物篭/買い物カゴ/買い物かご/
かいものがえり /買い物帰り/
かいものきゃく /買い物客/
かいものちゅう /買物中/
かいものぶくろ /買い物袋/買物袋/
かいものゆうたいけん /買物優待券/
かいもん /開門/開聞/海門/階紋/
かいもんきょくろ /槐門棘路/
かいもんだけ /開聞岳/
かいや /海谷/
かいやく /解約/改訳/
かいやくご /華夷訳語/
かいやくてすうりょう /解約手数料/
かいやくび /解約日/
かいゆ /快癒/
かいゆう /回遊/灰釉/会友/回游;≒回遊 (特に魚の)/
かいゆうかん /海遊館/
かいゆうぎょ /回遊魚/回游魚;=回遊魚/
かいゆうせい /回遊性/
かいよう /海洋/潰瘍/海容/
かいようおせん /海洋汚染/
かいようかいはつ /海洋開発/
かいようかんきょう /海洋環境/
かいようかんそく /海洋観測/
かいようがっかい /海洋学会/
かいようきしょう /海洋気象/
かいようきしょうぶ /海洋気象部/
かいようけん /海洋研/
かいようこうがく /海洋工学/
かいようこく /海洋国/
かいようしんそうすい /海洋深層水/
かいようじっしゅう /海洋実習/
かいようじゅんかん /海洋循環/
かいようせい /海洋性/
かいようせいぶつ /海洋生物/
かいようせいぶつがくしゃ /海洋生物学者/
かいようだいじゅんかん /海洋大循環/
かいようちけいがく /海洋地形学/
かいようちしつがく /海洋地質学/
かいようちゅう /海洋中/
かいようちょうさ /海洋調査/
かいようとうき /海洋投棄/
かいようぶつり /海洋物理/
かいようぶつりがく /海洋物理学/
かいようほう /海洋法/
かいようみんぞく /海洋民族/
かいようりきがく /海洋力学/
かいよね /糴/買い米/
かいらい /傀儡/界雷/
かいらいし /傀儡師/
かいらいせいけん /傀儡政権/
かいらぎ /鰄/梅花皮;=鰄/
かいらく /快楽;pleasure/偕楽;人と楽しむ/海楽;地名,千葉/皆楽/
かいらくえん /偕楽園/
かいらくげんそく /快楽原則/
かいらくしゅぎ /快楽主義/
かいらくてき /快楽的/
かいらん /回覧/壊乱/解纜;船出/潰乱;≒壊乱/介卵/廻覽/
かいらんし /回覧誌/
かいらんしゃ /回覧者/
かいらんじゅん /回覧順/
かいらんじょうきょう /回覧状況/
かいらんばん /回覧板/
かいらんぶつ /回覧物/
かいらんもと /回覧元/
かいらんよう /回覧用/
かいり /乖離;背き離れる。「人心の-」/解離;解け離れる。「分子の-」/海里;1852m/浬;=海里/
かいりき /怪力/
かいりきし /下位力士/
かいりきしょうじょ /怪力少女/
かいりく /海陸/
かいりくふう /海陸風/
かいりせい /解離性/
かいりつ /戒律/介立/
かいりど /解離度/
かいりゅう /海流/開立/
かいりゅうがく /海流学/
かいりょう /改良/
かいりょうあん /改良案/
かいりょういき /開領域/
かいりょうがた /改良型/
かいりょうしゅ /改良種/
かいりょうしゅぎ /改良主義;reformism/
かいりょうせいひん /改良製品/
かいりょうてん /改良点/
かいりょうばん /改良版/
かいりょうひん /改良品/
かいりょうほう /改良法/
かいりょくしょく /灰緑色/
かいりょくらんしん /怪力乱神/
かいる /蛙/
かいるい /貝類/
かいれい /海嶺/回礼/瑰麗/
かいれき /改暦/回歴/回暦;イスラム暦/
かいれつ /開裂/
かいれつか /開裂果/
かいろ /回路/海路/懐炉/
かいろいじょう /回路異常/
かいろう /回廊/廻廊;=回廊/海老/貝楼/
かいろうどうけつ /偕老同穴/
かいろきじゅつ /回路記述/
かいろけい /回路系/
かいろけんしょう /回路検証/
かいろこうせい /回路構成/
かいろず /回路図/
かいろせっけい /回路設計/
かいろせんよう /回路専用/
かいろちゅう /回路中/
かいろていすう /回路定数/
かいろてき /回路的/
かいろぶんかつ /回路分割/
かいろへんこう /回路変更/
かいろめい /回路名/
かいろもう /回路網/
かいろや /回路屋/
かいろろん /回路論/
かいわ /会話/海和/貝輪/諧和/會話;「会」旧字/
かいわい /界隈/
かいわがた /会話型/
かいわがたしょり /会話型処理/
かいわご /会話語/
かいわごえ /会話声/
かいわしゅう /会話集/
かいわたい /会話体/
かいわちゅう /会話中/
かいわてき /会話的/
かいわとう /会話等/
かいわのうりょく /会話能力/
かいわひょうげん /会話表現/
かいわぶん /会話文/
かいわほうほう /会話方法/
かいわれ /貝割れ;-大根/貝割/
かいわれい /会話例/
かいわれだいこん /貝割れ大根/
かいわれな /貝割れ菜;カイワレダイコン/
かいわん /海湾/怪腕/
かいん /下院/課員/禍因/
かいんぎいん /下院議員/
かう /斯う/
かうん /家運/
かうんたーせき /カウンター席/
かえ /替え/替/佳枝/華絵/
かえい /嘉永;年号(1848-1854)/
かえうた /替え歌/替歌/
かえき /課役/
かえぎ /替え着/替着/
かえし /返し/反し/
かえしうた /返歌/
かえしうま /返馬/
かえしぬい /返し縫い/
かえしょうぞく /替装束/
かえしわざ /返し技/
かえしん /替え芯;シャーペンの-/
かえじ /替字;eg.豆腐→豆富/替え字/
かえすかたな /返す刀/
かえすがえす /返す返す/
かえすがえすも /返す返すも/
かえだま /替え玉/替玉/
かえち /替地/替え地/
かえって /却って/反って;NB:「そって」と同形/
かえつ /加越/嘉悦/
かえつじょし /嘉悦女子/
かえつのうてつどう /加越能鉄道/
かえで /楓/槭樹/替手/
かえでぞく /カエデ属/
かえば /替刃/替え刃/
かえもん /替紋/
かえり /帰り/返り/
かえりうち /返り討ち/
かえりがけ /帰り掛け;on one's way back/
かえりぎわ /帰り際/
かえりぐるま /帰り車/
かえりざき /返り咲き/
かえりしな /帰りしな/
かえりしんざん /帰り新参/
かえりじ /返り字;漢文/
かえりじたく /帰り支度/
かえりち /返り値;†return value/返り血;†(blood)「-を浴びる」/返値/
かえりてん /返り点/
かえりびと /帰り人/帰人/
かえりみ /顧み/
かえりみち /帰り道/帰り路/
かえりやま /帰山/
かえる /蛙/
かえるあし /蛙足;[水泳]平泳ぎの運足/
かえるとび /蛙飛び/蛙跳び/
かえん /火炎/火焔/花園/
かえんこうげき /火炎攻撃/
かえんざん /火焔山/
かえんじごく /火炎地獄/
かえんだいこ /火焔太鼓;=大太鼓(だだいこ)/
かえんびん /火炎瓶/
かえんほうしゃき /火炎放射器/
かお /顔/貌/顏;「顔」の旧字/
かおあわせ /顔合わせ/顔合せ/
かおいろ /顔色/
かおう /花王/花押/鹿央;地名/嘉応;年号(1169-71)/
かおうかぶしきがいしゃ /花王株式会社/
かおかたち /顔貌/顔容/顔形/
かおく /家屋/
かおくぜい /家屋税/
かおこうげき /顔攻撃/
かおじゃしん /顔写真/
かおじゅう /顔中/
かおそり /顔剃り/
かおだし /顔出し/
かおだち /顔立ち/
かおぢゅう /顔中/
かおつき /顔付き/
かおつなぎ /顔繋ぎ/
かおづくり /顔作り/
かおなじみ /顔馴染み/
かおはんぶん /顔半分/
かおぱす /顔パス;[口]顔が利くこと/
かおぶれ /顔ぶれ/顔触れ/
かおまけ /顔負け/
かおみ /顔見/
かおみしり /顔見知り/
かおみせ /顔見せ/顔見世/
かおむけ /顔向け/
かおもじ /顔文字/
かおやく /顔役/
かおよごし /顔汚し/
かおよせ /顔寄せ/
かおり /香/香り/薫り/香織/香里/歌織/佳央理/薫理/佳央里/
かおりづけ /香り付け/
かおりまい /香り米/
かおる /薫/香/馨/郁;名/
かおるこ /薫子/
かおん /加温/訛音/
かおんばん /加温盤/
かか /嬶/花下/仮果/窩家/
かかあ /嬶/嚊/
かかあてんか /嚊天下/
かかあでんか /嚊天下;⇔亭主関白/
かかい /下界/科会/下階/河海/花会;活花の会/可解/課会/歌会/
かかいせい /可解性/
かかえ /抱え/
かかおし /カカオ脂;cacao butter/
かかく /価格/過客/家格/貨客/蝸角;[漢語]カタツムリのツノ。「-の争い」/
かかくおうだん /価格応談/
かかくかくめい /価格革命/
かかくかんさん /価格換算/
かかくかんざん /価格換算/
かかくきょうそう /価格競争/
かかくけいせい /価格形成/
かかくこうしょう /価格交渉/
かかくさ /価格差/
かかくじゅん /価格順/
かかくじょうげん /価格上限/
かかくせいさく /価格政策/
かかくせいのうひ /価格性能比/
かかくせってい /価格設定/
かかくたい /価格帯/
かかくちょうさ /価格調査/
かかくてき /価格的/
かかくとう /価格等/
かかくとうせい /価格統制/
かかくはかい /価格破壊/
かかくはかいてき /価格破壊的/
かかくひょう /価格表/
かかくひょうじ /価格表示/
かかくへんどう /価格変動/
かかくみてい /価格未定/
かかくめん /価格面/
かかさま /母様/
かかし /案山子/
かかたいしょう /呵々大笑/呵呵大笑/
かかぢ /香々地/
かかと /踵/
かかとおとし /踵落し/踵落とし/かかと落とし/
かかみがはら /各務原/
かかり /係/係り/掛/
かかりあい /掛り合い/
かかりいん /係員/係り員/
かかりかん /係官/
かかりじょし /係助詞/
かかりちょう /係長/掛長/
かかりつけ /掛かり付け;-のお医者さん/掛り付け/
かかりなし /係無/
かかりむすび /係り結び;「ぞ・なむ・や・か」連体形/
かかわらず /拘わらず/拘らず;それにも-/係わらず/
かかわり /関わり/係わり/
かかわりあい /関わり合い/
かかん /果敢/花冠/可換/日間;(助数詞)/花間/加冠/河漢/夏官/禍患/下瞰/下浣/下澣;=下浣/華翰/
かかんかん /可換環/
かかんきしょうこうぐん /過換気症候群/
かかんぐん /可換群/
かかんず /可換図/
かかんせい /可換性/
かかんぜん /過完全/
かかんそく /可観測/
かかんそくせい /可観測性/
かかんぷ /火浣布/
かが /加賀/花芽;[植物]flower bud/夏芽;[植物]summer bud ⇔冬芽/鹿賀/加我/火蛾/
かがい /課外/加害/花街/禍害/
かがいかつどう /課外活動/
かがいしゃ /加害者/
かがいしゃいしき /加害者意識/
かがいしゃがわ /加害者側/
かがいじゅぎょう /課外授業/
かがいちのみや /加賀一の宮/
かがおんせん /加賀温泉/
かがおんせんえき /加賀温泉駅/
かがきくざけ /加賀菊酒/
かがく /科学;†science/化学;†chemistry/価額/下顎/歌学/家学/
かがくあさひ /科学朝日/
かがくえいご /科学英語/
かがくえいせい /科学衛星/
かがくか /科学科;†(science)/化学科;†(chemistry)/
かがくかい /科学会;†(複合用途)/化学会;†chemical society/科学界;scientific world/
かがくかいかいいん /科学会会員/
かがくかいじむきょく /科学会事務局/
かがくかいせつ /科学解説/
かがくかいせつしょ /科学解説書/
かがくかいだい /科学会第/
かがくかくめい /科学革命;『-の構造』(T.Kuhn)/
かがくかん /科学館/科学舘;「館」異体字/化学館/
かがくかんけい /科学関係/
かがくかんれん /科学関連;†/化学関連;†/
かがくがくじゅつ /化学学術/
かがくがわ /科学側/
かがくきかい /化学機械/
かがくきごう /化学記号/
かがくきじ /科学記事/
かがくきょういく /科学教育/
かがくぎじゅつ /科学技術/
かがくぎじゅつかん /科学技術館/
かがくぎじゅつけい /科学技術系/
かがくぎじゅつけいさん /科学技術計算/
かがくぎじゅつしんこうちょうせいひ /科学技術振興調整費/
かがくぎじゅつせいさく /科学技術政策/
かがくぎじゅつちょう /科学技術庁;NB:2001年1月の中央省庁再編で文部科学省と経済産業省に再編された/
かがくぎじゅつぶ /科学技術部/
かがくぎじゅつぶんや /科学技術分野/
かがくけい /化学系/科学系/
かがくけいがくぶ /化学系学部/
かがくけいさん /科学計算/
かがくけいそくけんきゅうじょ /科学計測研究所/
かがくけいとう /科学系統/
かがくけいもう /科学啓蒙/
かがくけいもうしょ /科学啓蒙書/
かがくけつごう /化学結合/
かがくけんきゅう /科学研究/化学研究;†/
かがくけんきゅうかい /化学研究会/
かがくけんきゅうしつ /科学研究室/
かがくけんきゅうしゃ /科学研究者/
かがくけんきゅうじょ /科学研究所/
かがくけんきゅうひ /科学研究費/
かがくげんろん /科学原論/
かがくこうがく /化学工学/
かがくこうがくか /化学工学科/
かがくこうぎょう /化学工業/
かがくこうざ /科学講座/
かがくこうじょう /化学工場/
かがくこうぞう /化学構造/
かがくこうぞうしき /化学構造式/
かがくごうせい /化学合成/
かがくごうせいひん /化学合成品/
かがくさよう /化学作用/
かがくざっし /科学雑誌/
かがくし /科学史/
かがくしか /科学史家/
かがくしき /化学式/
かがくしせつ /化学施設/
かがくしそう /科学思想/
かがくしつもんばこ /科学質問箱/
かがくしゃ /科学者;†scientist/化学者;†chemist/科学社;[出版社名]/
かがくしゃじしん /科学者自身/
かがくしゃたち /科学者達/
かがくしゅぎ /科学主義/
かがくしゅっぱん /科学出版/
かがくしゅほう /科学手法/
かがくしょ /科学書/歌学書/
かがくしょう /化学賞;†/科学賞;†/
かがくしょうせつ /科学小説;SF/
かがくしょうねん /科学少年/
かがくしょり /化学処理/
かがくしんこうきょうかい /科学振興協会/
かがくじっけんしつ /化学実験室/
かがくじょう /科学上/
かがくじょうたつ /下学上達/
かがくじょうほう /科学情報/
かがくせい /科学性/
かがくせいさく /科学政策/
かがくせいひん /化学製品/
かがくせいぶつ /化学生物/
かがくせいぶん /化学成分/
かがくせん /化学戦/
かがくせんい /化学繊維/
かがくせんこう /科学専攻;†/化学専攻;†/
かがくそうさ /科学捜査/
かがくだいじてん /化学大辞典/
かがくちしき /科学知識/
かがくちょうみりょう /化学調味料/
かがくてき /科学的;†scientific/化学的;†chemical/
かがくてきかいせき /科学的解析/
かがくてきがいねん /科学的概念/
かがくてききょういく /科学的教育/
かがくてきげんり /科学的原理/
かがくてきこうさつ /科学的考察/
かがくてきこんきょ /科学的根拠/
かがくてきごうりせい /科学的合理性/
かがくてきさんそようきゅうりょう /化学的酸素要求量;COD/
かがくてきしこう /科学的思考/
かがくてきしゅほう /科学的手法/
かがくてきじじつ /科学的事実/
かがくてきじっけん /科学的実験/
かがくてきせいしつ /化学的性質/
かがくてきそくめん /科学的側面/
かがくてきたいど /科学的態度/
かがくてきどくせい /化学的毒性/
かがくてきはっけん /科学的発見/
かがくてきはっそう /科学的発想/
かがくてきひょうか /科学的評価/
かがくてきほうそく /科学的法則/
かがくてきほうほう /科学的方法;†/化学的方法;†/
かがくてきほうほうろん /科学的方法論/
かがくてつがく /科学哲学/
かがくてつがくかい /科学哲学会/
かがくてつがっかい /科学哲学会/
かがくどくせい /化学毒性/
かがくにんじゃたい /科学忍者隊/
かがくねつりきがく /化学熱力学;chemical thermodynamics/
かがくはく /科学博/
かがくはくぶつかん /科学博物館/
かがくはんのう /化学反応/
かがくはんのうしき /化学反応式/
かがくはんのうろん /化学反応論/
かがくばたけ /科学畑/
かがくばなれ /科学離れ/
かがくばんぐみ /科学番組/
かがくばんのう /科学万能/
かがくばんのうしゅぎ /科学万能主義/
かがくぱるぷ /化学パルプ/
かがくひりょう /化学肥料/
かがくひん /化学品/
かがくびんらん /化学便覧/
かがくぶ /科学部;†/化学部;†/
かがくぶっしつ /化学物質/
かがくぶつり /化学物理/
かがくぶつりがく /化学物理学;chemical physics/
かがくぶつりてき /化学物理的/
かがくぶもん /科学部門/
かがくぶんせき /化学分析/
かがくぶんめい /科学文明/
かがくぶんや /科学分野/
かがくへいき /化学兵器/
かがくへいこう /化学平衡/
かがくへんか /化学変化/
かがくほうそく /科学法則/
かがくほうほうろん /科学方法論/
かがくまんが /科学漫画/
かがくもの /科学物/
かがくや /化学屋/
かがくらん /科学欄/
かがくりょう /化学量/
かがくりょうほう /化学療法/
かがくりょく /科学力/
かがくりろん /科学理論/
かがくろん /科学論/
かがくろんぶん /科学論文/
かがごう /加賀号/
かがじ /加賀寺/
かがじょう /加賀城/
かがたけし /鹿賀丈史/
かがっか /科学科;†(science)/化学科;†(chemistry)/
かがっかい /科学会/
かがっかん /化学館/
かがふり /冠/
かがほうしょ /加賀奉書/
かがみ /鏡;mirror/鑑;模範/各務;人名/加賀美/加賀見/香我美/鏡味/鑒;「鑑」の異体字/
かがみいし /鏡石/
かがみいた /鏡板/
かがみいわ /鏡岩/
かがみえ /鏡絵/
かがみがた /鏡形/
かがみじごく /鏡地獄/
かがみじし /鏡獅子/
かがみつくりべ /鏡作部/
かがみぬま /鏡沼/
かがみの /鏡野/
かがみのくに /鏡の国/
かがみのま /鏡の間/
かがみばり /鏡張り/
かがみびらき /鏡開き/
かがみもじ /鏡文字/
かがみもち /鏡餅/
かがみやま /鏡山/
かがみわり /鏡割り;鏡開き/
かがもん /加賀紋/
かがや /加賀屋/加賀谷/
かがやき /輝き/
かがり /篝/炬/
かがりび /篝火/炬火/
かがりょうり /加賀料理/
かがわ /香川/賀川/加川/嘉川/
かがわけん /香川県/
かがわけんない /香川県内/
かがわだいがく /香川大学/
かがわちょう /香川町/
かがん /河岸/花顔/過雁/
かがんだんきゅう /河岸段丘/
かき /下記/柿/夏季;†季節としての夏。「-五輪」/夏期;†時期としての夏。「-休暇」/垣/牡蠣/花器;vase/花期;flower season/花卉;-園芸/火気;-厳禁/火器;firearms/牡蛎;「蠣」異体字/書/書き/堵/蠣/蛎;「蠣」の異体字/硴;=牡蠣/家記/夏記/
かき> /掻き;掻き口説く,掻き捨て,掻き曇る/
かきあげ /かき揚げ/掻き揚げ/掻揚げ/書上げ/掻上げ/
かきあじ /書き味/
かきあて /下記宛/
かきあぶら /牡蠣油;oyster sauce/
かきいれ /書入れ/
かきいれどき /書き入れ時/書入れ時/
かきいろ /柿色/
かきうち /垣内/
かきえもん /柿右衛門/
かきえんげい /花卉園芸/
かきお /柿生/
かきおか /柿岡/
かきおき /書き置き/書置き/書置/
かきおろし /書き下ろし/描き下ろし/書下ろし/書下し/
かきかえ /書き換え/書換/書換え/書き替え/
かきかえかた /書き換え方/
かきかえきそく /書き換え規則/
かきかえけい /書き換え系/
かきかた /書き方/
かきからちょう /蛎殻町/
かきがら /牡蠣殻;-グラタン/
かきがらちょう /蠣殻町/
かきがらばい /牡蠣殻灰/
かきがらぶき /牡蠣殻葺き/
かきがらやね /牡蠣殻屋根/
かききず /掻き傷/
かききゅうか /夏期休暇/夏季休暇/
かききゅうぎょう /夏季休業/
かききゅうぎょうちゅう /夏季休業中/夏期休業中/
かきぎ /柿木/
かきぎんこうこうざ /下記銀行口座/
かきくだし /書き下し;漢文の./
かきくだしぶん /書き下し文/書下し文/
かきぐせ /書き癖/
かきげんきん /火気厳禁/
かきこうしゅう /夏期講習/
かきことば /書き言葉/書言葉/
かきこみ /書き込み/書込み/書込/書きこみ/
かきこみけん /書き込み権/
かきこみじ /書き込み時/
かきごう /夏季号/
かきごおり /かき氷/欠氷/
かきざき /柿崎/蠣崎/硴崎;姓/
かきした /柿下/
かきしぶ /柿渋/
かきしょうかいさき /下記照会先/
かきじゅん /書き順/
かきすて /掻き捨て/書捨て/
かきそんじ /書き損じ/
かきぞめ /書き初め/書初め/
かきた /柿田/垣田/
かきたかわ /柿田川/
かきたがわ /柿田川/
かきたに /柿谷/垣谷/
かきだがわ /柿田川/
かきだし /書き出し/
かきちょう /蠣殻町/
かきつ /嘉吉;年号(1441-1444)/
かきつけ /書付/書き付け/書付け/
かきつばた /杜若/燕子花/
かきて /書き手/描き手/
かきとめ /書留/
かきとめゆうびん /書留郵便/
かきとり /書取/書取り/書き取り/
かきどなり /垣隣/
かきなおし /書き直し/
かきなべ /牡蠣鍋/蛎鍋/
かきなみ /柿並/
かきにってい /下記日程/
かきぬま /柿沼/
かきね /垣根/墻/牆/
かきねごし /垣根越し/
かきの /柿野/垣野/
かきのうち /垣野内/
かきのき /柿木/
かきのきもく /Elanales/カキノキ目/
かきのたね /柿の種/
かきのたみ /民部/部曲/
かきのへた /柿の蔕;高麗茶碗の一種/
かきのもと /柿本/
かきのもとのひとまろ /柿本人麻呂/
かきのもとひとまろ /柿本人麻呂/
かきはちねん /柿八年/
かきはら /柿原/垣原/
かきはん /書判/花押/書き判/
かきぶっけん /下記物件/
かきべ /民部/部曲/
かきほん /書本/書き本/
かきまちがい /書き間違い/
かきまみ /垣間見/
かきもうしこみさき /下記申込先/
かきもく /カキ目/Ebenales/
かきもじ /書き文字/書文字/
かきもち /柿餅/欠餅/
かきもと /柿本/
かきもの /書き物/
かきゃくせん /貨客船/
かきや /垣屋/
かきやすさ /書き易さ/
かきやね /牡蠣屋根/
かきやまぶし /柿山伏/
かきゅう /下級/火球/過給/加給/火急/可及/下丘/苛求/
かきゅうき /過給機/過給器/
かきゅうきぞく /下級貴族/
かきゅうさいばんしょ /下級裁判所/
かきゅうざい /下級財;[経済]inferior goods/
かきゅうしょく /下級職/
かきゅうしん /下級審/
かきゅうせい /下級生/
かきゅうてき /可及的/
かきょ /科挙/家居/火炬/河渠/
かきょう /架橋/佳境/華僑/家教/家郷/嘉慶/歌境/
かきょういん /花京院/
かきょく /歌曲/佳曲/
かきょくおう /歌曲王/
かきょくしゅう /歌曲集/
かきようし /下記用紙/
かきようりょう /下記要領/
かきれんらくさき /下記連絡先/
かきわき /垣脇/
かきわけ /書き分け/書分け/
かきわり /書割/書き割り/
かきん /課金/家禽/瑕瑾/
かきんしょり /課金処理/
かきんじょうほう /課金情報/
かきんせい /課金制/
かきんたいけい /課金体系/
かきんど /火金土/
かぎ /鍵;key/鉤;hook/鈎;「鉤」の異体字/科技;[略語]科学技術/『/』/「/」/『』/「」/
かぎあな /鍵穴/
かぎかっこ /鉤括弧/かぎ括弧/『/』/「/」/【;隅付き括弧/】/
かぎかっことじ /』/」/
かぎがた /鍵形/鉤形/
かぎぐすり /嗅ぎ薬/
かぎざき /鉤裂き/
かぎし /鍵師/
かぎじゅうじ /鉤十字;Hakenkreuz/
かぎたば /鍵束/
かぎたばこ /嗅ぎタバコ/嗅煙草/
かぎだい /科技大/東京都立科学技術大学;※abbrev/
かぎちょう /科技庁;NB:2001年1月の中央省庁再編で文部科学省に再編された/鍵長/科学技術庁;※abbrev/
かぎっこ /鍵っ子/
かぎづめ /鉤爪/鈎爪/
かぎの /鍵野/
かぎばな /鉤鼻/
かぎばり /鉤針/
かぎばりあみ /鉤針編み/
かぎほっく /鉤ホック/
かぎもと /鍵本/
かぎもとけいこ /鍵本景子/
かぎゃく /可逆/加虐/苛虐/
かぎゃくあっしゅく /可逆圧縮/
かぎゃくせい /可逆性/
かぎゃくてき /可逆的/
かぎゃくはんのう /可逆反応/
かぎゃくへんか /可逆変化;reversible reaction/
かぎや /鍵屋;屋号/
かぎゅう /蝸牛/
かぎょう /家業;†family business.「-を継ぐ」/稼業;†job.「しがない-」/下行/課業;task/か行/カ行/
かぎょうへんかくかつよう /カ行変格活用;[文法]カ変(「来る」)/
かぎり /限り/限/
かく /核/格;rank/各;each/角/画/確/閣/佳句/斯く/賀来/加来/穫;収穫/獲;獲得/郭;外郭/廓;(≒郭)遊廓/椁;棺椁/槨;「椁」の異体字/隔;間隔/膈;横膈膜/赫;赫々/嚇;威嚇/拡;拡大/擴;「拡」の旧字/殻;甲殻/殼;「殻」の旧字/愨;まこと/掴;つか・む/膕;ひかがみ/幗;巾幗/鶴;(つる)鶴声/寉;「鶴」の異体字/攫;さら・う/癨/矍;矍鑠/蠖;尺蠖/霍;霍乱/客/喀;喀血/咯/恪;恪勤/挌;挌闘(=格闘)/擱;擱筆/狢;むじな/貉;≒狢/茖/骼;あらぼね/覚;自覚/覺;「覚」の旧字/攪;(慣用音)攪乱/撹;「攪」の異体字/革;革命/較;比較/馘;馘首/埆;そね/壑;たに/覈;しらべる/畫;「画」の旧字/劃;≒画/恁く/∠;angle/
かく> /各/核;-反応,-不拡散体制/角;角皿,角速度,角頭巾/斯く;-も,-迄,-許/
かくあげ /格上げ/
かくい /各位/隔意/角井;人名/
かくいいん /各委員/
かくいえ /各家/
かくいがく /核医学/
かくいち /各位置/
かくいちだい /各一台/
かくいつ /画一/劃一/
かくいつか /画一化/
かくいつせい /画一性/
かくいつてき /画一的/
かくいでんし /各遺伝子/
かくいりぐち /各入口/
かくいん /客員;guest/角印/各員;each member/閣員;ministers/
かくいんきょうじゅ /客員教授/
かくいんけんきゅういん /客員研究員/
かくう /架空/
かくうえ /格上/
かくうけいたい /架空携帯/
かくうこうざ /架空口座/
かくうせいきゅう /架空請求/
かくうんどう /角運動/
かくうんどうりょう /角運動量/
かくうんどうりょうほぞん /角運動量保存/
かくえい /角栄/角榮/
かくえいががいしゃ /各映画会社/
かくえいぎょうしょ /各営業所/
かくえき /各駅/赫奕/
かくえきていしゃ /各駅停車/隔駅停車/
かくおうざん /覚王山/
かくおち /角落ち/角落/
かくおび /角帯/
かくおん /各音/核音/
かくおんいん /各音韻/
かくおんせつ /各音節/
かくか /各課/角化/核果/
かくかい /各界/各回/各階/角界;相撲界/角回;[解剖]angular gyrus/郭隗;「隗より始めよ」と言った人/
かくかいいん /各会員/
かくかいきゅう /各階級/
かくかいせつ /各解説/
かくかいそう /各階層/
かくかいだん /各階段/
かくかいはつ /核開発/
かくかく /各々;おのおの/赫々;-たる戦果/赫赫/斯く斯く;-しかじか/
かくかくさん /核拡散/
かくかしょう /角化症;[医]魚の目など/
かくかそう /角化層/
かくかそくど /角加速度/
かくかぞく /核家族/
かくかぞくか /核家族化/
かくかぞくしゃかい /核家族社会/
かくかっこ /角括弧/［/］;大括弧(bracket)/〔/〕;亀甲括弧/【/】;隅付き括弧/
かくかてい /各家庭/各過程/
かくかでん /各家電/
かくかん /各巻/各艦/各間/
かくかんごと /各巻毎/
かくかんすう /各関数/
かくかんりしゃ /各管理者/
かくかんりにん /各管理人/
かくがい /格外/閣外/核外/
かくがいきょうりょく /閣外協力/
かくがくねん /各学年/
かくがくぶ /各学部/
かくがた /角型/角形/
かくがっか /各学科/
かくがっかい /各学会/
かくがっこ /角括弧/［/］;大括弧(bracket)/〔/〕;亀甲括弧/【/】;隅付き括弧/
かくがめん /各画面/
かくがり /角刈り/角刈/
かくがわ /角川/
かくがん /各眼/
かくき /各期/各機/
かくきー /各キー/
かくきかん /各機関/各期間/
かくきき /各機器/
かくきぎょう /各企業/
かくきごう /各記号/
かくきしゅ /各機種/各騎手/
かくきしゅきょうつう /各機種共通/
かくきしゅべつ /各機種別/
かくきじ /各記事/
かくきそく /各規則/
かくきたい /各機体/
かくきち /各基地/
かくきのう /各機能/
かくきゃくしつ /各客室/
かくきゅうじょう /各球場/
かくきゅうだん /各球団/
かくきょうか /各教科/
かくきょうし /各教師/
かくきょうじゅ /各教授/
かくきょく /各局/各曲/
かくきょくせん /各曲線/
かくきょり /角距離/
かくぎ /閣議/
かくぎけってい /閣議決定/
かくぎょう /各行/角行/
かくぎょうかい /各業界/
かくぎょうごと /各行毎/
かくぎょうまつ /各行末/
かくぎり /角切り/
かくぎわく /核疑惑/
かくぎんこう /各銀行/
かくく /各区/
かくくかん /各区間/
かくぐう /角隅/
かくぐるーぷ /各グループ/
かくけーす /各ケース/
かくけい /角形/
かくけいさん /核計算/
かくけいしき /各形式/
かくけいすう /各係数/
かくけいとうべつ /各系統別/
かくけん /各県/核研/
かくけんきゅうきかん /各研究機関/
かくけんきゅうしつ /各研究室/
かくげき /核撃/
かくげっかん /隔月刊/
かくげっかんか /隔月刊化/
かくげつ /各月;every month/隔月;bimonthly/客月;先月/
かくげつかん /隔月刊/
かくげつはっこう /隔月発行/
かくげん /格言/確言/
かくげんご /各言語/
かくこ /確固/各戸/加久子;人名/
かくこう /各項/各校/
かくこうかん /角交換/
かくこうくうがいしゃ /各航空会社/
かくこうげき /核攻撃/
かくこうざ /各講座/
かくこうせいいん /各構成員/
かくこうぞう /核構造/
かくこうつうきかん /各交通機関/
かくこうほ /各候補/
かくこうほしゃ /各候補者/
かくこうもく /各項目/
かくこうりてん /各小売店/
かくこきゃく /各顧客/
かくこく /各国/
かくこくご /各国語/
かくこじん /各個人/
かくこたい /各個体/
かくこゆう /各個有/
かくご /覚悟/各語/恪勤;=かくごん/客語/
かくごう /各号/
かくごうしゃ /各号車/
かくごしっく /角ゴシック/
かくごび /格語尾/
かくごん /恪勤/
かくさ /格差;gap.「所得-」/較差;difference,range.「年-」 NB:「こうさ」の慣用読み/隔差;?/
かくさいぼう /各細胞/
かくさく /画策/
かくさくひん /各作品/
かくさげ /格下げ/
かくささつ /核査察/
かくさもんだい /格差問題/
かくさん /拡散/核酸/
かくさんおんじょう /拡散音場/
かくさんかしゃ /各参加者/
かくさんがた /拡散型/
かくさんけいすう /拡散係数/
かくさんせい /拡散性/
かくさんはんしゃ /拡散反射/
かくさんぶんし /核酸分子/
かくさんほう /拡散法/
かくさんめん /拡散面/
かくさんりつ /拡散率/
かくざ /擱座/擱坐/
かくざい /角材/
かくざせき /各座席/
かくざっし /各雑誌/
かくざとう /角砂糖/
かくざら /角皿;⇔丸皿/
かくし /各誌/各市/各紙/各氏/核子/客死/隠し/
かくしあい /各試合/
かくしあじ /隠し味/
かくしぇるたー /核シェルター;nuclear shelter/
かくしかめら /隠しカメラ/
かくしき /格式/
かくしきばる /格式張る/
かくしげい /隠し芸/
かくしご /隠し子/
かくしごと /隠し事/
かくしせつ /各施設/核施設/
かくした /格下/
かくしだい /隠し題/
かくしだま /隠し玉/
かくしつ /角質;keratinous/確執/各室/革質;coriaceous/
かくしつそう /角質層/
かくして /斯くして/
かくしとりで /隠し砦/
かくしどころ /隠し所/
かくしどり /隠し撮り/
かくしぬの /隠し布/
かくしはい /格支配/
かくしぼうちょう /隠し包丁/
かくしまいく /隠しマイク/
かくしゃ /各社/各車/覚者/
かくしゃいん /各社員/
かくしゃかくよう /各社各様/
かくしゃかん /各社間/各者間/
かくしゃく /矍鑠/
かくしゃどくじ /各社独自/
かくしゃほ /各社保/
かくしゃりょう /各車両/
かくしゃりん /各車輪/
かくしやくしょ /各市役所/
かくしゅ /各種/核種;nuclide/鶴首;-して待つ(=首を長くして待つ)/馘首;dismiss/攫取/獲取;=攫取/
かくしゅいいんかい /各種委員会/
かくしゅう /隔週;biweekly/確執;=かくしつ/各週;every week/客愁;旅愁/
かくしゅうかん /隔週刊/
かくしゅうはすう /角周波数;angular frequency,ω/各周波数/
かくしゅうはすうせいぶん /各周波数成分/
かくしゅうほう /隔週報/
かくしゅおんがく /各種音楽/
かくしゅかいはつかんきょう /各種開発環境/
かくしゅかがく /各種科学/
かくしゅかつどう /各種活動/
かくしゅがぞう /各種画像/
かくしゅがっこう /各種学校/
かくしゅきき /各種機器/
かくしゅく /拡縮/
かくしゅこうじょ /各種控除/
かくしゅさぎょう /各種作業/
かくしゅさんぎょう /各種産業/
かくしゅしせつ /各種施設/
かくしゅしゅっぱんぶつ /各種出版物/
かくしゅしょせき /各種書籍/
かくしゅじむ /各種事務/
かくしゅじょうほう /各種情報/
かくしゅじょうやく /各種条約/
かくしゅせいやく /各種制約/
かくしゅたよう /各種多様/
かくしゅちょうせい /各種調整/
かくしゅっぱんしゃ /各出版社/
かくしゅにほんご /各種日本語/
かくしゅぶんけん /各種文献/
かくしゅほう /各手法/
かくしゅほうりつ /各種法律/
かくしゅるい /各種類/
かくしょ /各所/各署/角所/
かくしょう /確証/各省/各章/各賞/
かくしょうじょう /各症状/
かくしょうたい /核小体/
かくしょうちょう /各省庁/
かくしょうめいしょ /各証明書/
かくしょく /各色/
かくしょくいき /各職域/
かくしょてん /各書店/
かくしょり /各処理/
かくしよう /各仕様/
かくしん /確信/革新/核心/確診;確定診断/客心;旅情/隔心/
かくしんかてい /革新過程/
かくしんかんせん /各新幹線/
かくしんかんりょう /革新官僚/
かくしんけい /革新系/
かくしんせい /革新性/
かくしんせいとう /革新政党/
かくしんせいりょく /革新勢力/
かくしんてき /革新的/
かくしんど /確信度/
かくしんどうすう /角振動数/
かくしんはん /確信犯;原義:実行を義務と確信してなされる犯罪/
かくしんはんてき /確信犯的/
かくしんぶんしゃ /各新聞社/
かくじ /各自/覚治/
かくじかん /各時間/
かくじき /各時期/
かくじききょうめい /核磁気共鳴;NMR/
かくじぎょうしょ /各事業所/
かくじく /各軸/
かくじけん /各事件/
かくじこく /各時刻/
かくじしよう /各自使用/
かくじすう /各次数/
かくじだいてき /画時代的/
かくじちたい /各自治体/
かくじっけん /核実験/
かくじつ /確実/隔日/
かくじつし /確実視/
かくじつせい /確実性/
かくじどうしゃどう /各自動車道/
かくじふたん /各自負担/
かくじゅ /鶴寿;長生き/
かくじゅいん /鶴寿院/
かくじゅう /拡充/
かくじょうけん /各条件/
かくじょうほう /各情報/
かくじょし /格助詞/
かくじん /各人/核仁/
かくじんかく /各人格/
かくじんかくよう /各人各様/
かくじんこゆう /各人固有/
かくすい /角錐/
かくすう /画数/
かくすうしき /各数式/
かくすうじ /各数字/
かくすうじゅん /画数順/
かくず /各図/
かくせい /覚醒/拡声/隔世;-の感/郭清;[医]resection.「リンパ節-」/廓清;≒粛清/鶴声/客星/革正/
かくせいいでん /隔世遺伝/
かくせいき /拡声器/
かくせいけい /拡声系/
かくせいざい /覚醒剤/覚せい剤/
かくせいじ /覚醒時/
かくせいじょうたい /覚醒状態/
かくせいそうち /拡声装置/
かくせいとう /各政党/
かくせいのかん /隔世の感/
かくせいひん /各製品/
かくせいひんごと /各製品毎/
かくせいぶん /各成分/
かくせいよう /拡声用/
かくせき /各席/
かくせきにんしゃ /各責任者/
かくせだい /各世代/
かくせってん /各節点/
かくせつ /各節/確説/
かくせつもん /各設問/
かくせん /各線/
かくせんきょく /各選挙区/
かくせんこう /各専攻/
かくせんざい /各洗剤/
かくせんしつ /各船室/
かくせんしゅ /各選手/
かくせんそう /核戦争/
かくせんとう /角先頭/
かくせんもんぶんや /各専門分野/
かくせんりょく /核戦力/
かくぜつ /隔絶/
かくぜん /画然;clear.「-とした差」/確然;sure.「-たる証拠」/廓然;心が広い/劃然;=画然/
かくそう /各層/核相/
かくそうこうたい /核相交代/
かくそうさ /各操作/
かくそうち /各装置/
かくそくど /角速度/
かくそし /各素子/
かくそしき /各組織/
かくそしきない /各組織内/
かくぞう /覚三/
かくた /角田/
かくたい /各隊/革帯/
かくたいいき /各帯域/
かくたいかい /各大会/
かくたに /角谷/
かくたる /確たる/
かくたん /喀痰/
かくたんけんさ /喀痰検査/
かくたんげん /各単元/
かくたんご /各単語/
かくたんとうしゃ /各担当者/
かくたんまつ /各端末/
かくだ /角田/
かくだい /拡大/
かくだいうんよう /拡大運用/
かくだいかいしゃく /拡大解釈/
かくだいかぞく /拡大家族;[社会学]extended family/
かくだいがく /各大学/
かくだいがめん /拡大画面/
かくだいきょう /拡大鏡/
かくだいきょうかしょ /拡大教科書/
かくだいきんこう /拡大均衡;[経済]/
かくだいけいこう /拡大傾向/
かくだいさいせいさん /拡大再生産/
かくだいさつえい /拡大撮影/
かくだいしゃしん /拡大写真/
かくだいしゅぎ /拡大主義/
かくだいしゅくしょう /拡大縮小/
かくだいず /拡大図/
かくだいせいさん /拡大生産/
かくだいばん /拡大版/
かくだいひょうじ /拡大表示/
かくだいもじ /拡大文字/
かくだいりつ /拡大率/
かくだいろせん /拡大路線/
かくだん /格段;†special.「-の配慮」/各段;†each paragraph/
かくだんい /各段位/
かくだんかい /各段階/
かくだんたい /各団体/
かくだんとう /核弾頭/
かくだんらく /各段落/
かくち /各地/隔地/覚知/確知/
かくちいき /各地域/
かくちく /各地区/角逐/
かくちくだいひょう /各地区代表/
かくちしゃ /隔地者/
かくちじ /各知事/
かくちほう /各地方/
かくちゅう /角柱/
かくちょう /拡張/格調/各町/
かくちょうあん /拡張案/
かくちょういき /拡張域/
かくちょうか /拡張可/
かくちょうかのう /拡張可能/
かくちょうがいねん /拡張概念/
かくちょうがた /拡張型/
かくちょうきき /拡張機器/
かくちょうきのう /拡張機能/
かくちょうくかく /拡張区画/
かくちょうけい /拡張形/
かくちょうこうじ /拡張工事/
かくちょうし /拡張子/
かくちょうしゅう /拡張集/
かくちょうしゅぎ /拡張主義/
かくちょうしよう /拡張使用/
かくちょうせい /拡張性/
かくちょうせいぎょ /拡張制御/
かくちょうてん /各頂点/
かくちょうばん /拡張版/
かくちょうぶぶん /拡張部分/
かくちょうほう /拡張法/
かくちょうもじ /拡張文字/
かくちょうよう /拡張用/
かくちょうりょういき /拡張領域/
かくつう /各通/格通;雑誌『格闘技通信』の略語(?)/
かくつき /各月/隔月/
かくつけ /格付/
かくづけ /格付け/
かくて /斯くて/
かくてあて /各手当/
かくてい /確定/各停;[略語]各駅停車/画定;境界線を決める/
かくていい /各定位/
かくていきげん /確定期限/
かくていきばいばい /確定期売買/
かくていきゅうふ /確定給付/
かくていきょしゅつ /確定拠出/
かくていきょしゅつがたねんきん /確定拠出型年金/
かくていきょしゅつねんきん /確定拠出年金/
かくていご /確定後/
かくていさいけん /確定債権/
かくていさいばん /確定裁判/
かくていしんこく /確定申告/
かくていしんこくしょ /確定申告書/
かくていじ /確定時/
かくていじき /確定時期/
かくていずみ /確定済/
かくていせい /確定性/
かくていせつ /確定節/
かくていち /確定値/
かくていてき /確定的/
かくていにゅうりょく /確定入力/
かくていはんけつ /確定判決/
かくていばん /確定版/
かくていひづけ /確定日付/
かくていまえ /確定前/
かくていめい /確定名/
かくていりつ /確定率/
かくていわくじゅん /確定枠順/
かくてつどう /各鉄道/
かくてん /各店/各点/
かくてんきょうつう /各店共通/
かくてんぽ /各店舗/
かくでーた /核データ/
かくでん /各伝/
かくとう /格闘/各党/各棟/挌闘/確答/角灯/角藤;姓/
かくとうか /格闘家/
かくとうかたち /格闘家達/
かくとうぎ /格闘技/
かくとうぎしょく /格闘技色/
かくとうぎだんたい /格闘技団体/
かくとうじゅつ /格闘術/
かくとうせん /格闘戦/
かくとうちゅう /格闘中/
かくとうひょうしゃ /各投票者/
かくとうもの /格闘物/
かくとか /殻斗果/
かくとく /獲得/
かくとくかのう /獲得可能/
かくとくけい /獲得形/
かくとくけいしつ /獲得形質/
かくとくしえん /獲得支援/
かくとくしゃ /獲得者/
かくとくしょうきん /獲得賞金/
かくとくしょうきんがく /獲得賞金額/
かくとくすう /獲得数/
かくとくせいこう /獲得成功/
かくとくぶつ /獲得物/
かくとくりつ /獲得率/
かくとし /各都市/
かくとしかん /各都市間/
かくとどうふけん /各都道府県/
かくとりしまりやく /各取締役/
かくど /角度/確度/客土/赫怒/
かくどう /覚道/
かくどうさ /各動作/
かくどうりん /各動輪/
かくどけい /角度計/
かくどけんしゅつ /角度検出/
かくどちょうせい /角度調整/
かくない /核内/閣内/
かくなみ /角波/
かくに /角煮/
かくにゅうりょく /各入力/
かくにん /確認/
かくにんかぶしきがいしゃ /確認株式会社/
かくにんきかん /確認期間/
かくにんきかんちゅう /確認期間中/
かくにんこうもく /確認項目/
かくにんご /確認後/
かくにんさぎょう /確認作業/
かくにんしょ /確認書/
かくにんしょり /確認処理/
かくにんしんせい /確認申請/
かくにんじ /確認時/
かくにんじこう /確認事項/
かくにんじっけん /確認実験/
かくにんずみ /確認済/
かくにんせいぎょ /確認制御/
かくにんたんまつ /確認端末/
かくにんだんたい /確認団体/
かくにんちゅう /確認中/
かくにんていど /確認程度/
かくにんでんわ /確認電話/
かくにんぶそく /確認不足/
かくにんよう /確認用/
かくねん /各年;each year/隔年;biennial/核燃/客年;last year/
かくねんだい /各年代/
かくねんりょう /核燃料/
かくねんりょうさいくる /核燃料サイクル/
かくねんりょうゆそう /核燃料輸送/
かくねんれい /各年齢/
かくの /角野/
かくのーど /各ノード/
かくのう /格納/
かくのういき /格納域/
かくのうけいしき /格納形式/
かくのうこ /格納庫/
かくのうさき /格納先/
かくのうしき /格納式/
かくのうど /各濃度/
かくのうばん /格納版/
かくのうほう /格納法/
かくのうりょく /核能力/
かくのかさ /核の傘/
かくのごとく /斯くの如く/
かくのだて /角館/
かくのふゆ /核の冬;nuclear winter/
かくは /各派/
かくはいき /核廃棄/
かくはいきぶつ /核廃棄物/
かくはく /攫搏/
かくはさい /核破砕/
かくはん /拡販/攪拌/各班/撹拌;「攪」異体字/各般/各版/
かくはんき /攪拌機;mixer/
かくはんのう /核反応/
かくはんばいてん /各販売店/
かくば /各馬/
かくばくだん /核爆弾/
かくばくはつ /核爆発/
かくばしょ /各場所/
かくばしら /角柱;square pillar/
かくばん /各晩/
かくひけんじゃ /各被験者/
かくひつ /擱筆/
かくひょう /各表/
かくひょうしき /格標識/
かくひんし /各品詞/
かくびき /画引き/
かくびん /角瓶;ブランデーの-/各便/
かくふ /角歩/
かくふうとう /角封筒/
かくふく /拡幅/
かくふくこうじ /拡幅工事/
かくぶ /各部/
かくぶい /各部位/
かくぶきょく /各部局/
かくぶしょ /各部署/
かくぶそう /核武装/
かくぶたい /各部隊/
かくぶっしつ /核物質/
かくぶつ /格物/杜父魚/
かくぶつちち /格物致知/
かくぶつり /核物理/
かくぶつりがく /核物理学/
かくぶつりけんきゅう /核物理研究/
かくぶひん /各部品/
かくぶぶん /各部分/
かくぶもん /各部門/
かくぶん /各文/確聞/
かくぶんかかい /各分科会/
かくぶんさつ /各分冊/
かくぶんたい /各分隊/
かくぶんぽう /格文法/
かくぶんや /各分野/
かくぶんやごと /各分野毎/
かくぶんれつ /核分裂/
かくぶんれつしゅうりつ /核分裂収率/
かくぶんれつせい /核分裂性/
かくぶんれつせいせいぶつ /核分裂生成物/
かくぶんれつだんめんせき /核分裂断面積/
かくぶんれつはんのう /核分裂反応/
かくへいき /核兵器/
かくへき /隔壁/
かくへや /各部屋/
かくへん /各辺/確変;[略語]確率変動/
かくへんか /格変化/
かくへんかん /核変換/
かくへんすう /各変数/
かくへんせい /各編成/
かくべえじし /角兵衛獅子/
かくべつ /格別/各別/
かくほ /確保/
かくほう /確報/
かくほうこう /各方向/
かくほうしき /各方式/
かくほうめん /各方面/
かくほこんなん /確保困難/
かくほずみ /確保済/
かくほゆう /核保有/
かくほゆうこく /核保有国/
かくぼいん /各母音/
かくぼう /角帽/
かくま /角間/
かくまき /角巻/
かくまく /角膜;[解剖](目の)cornea/隔膜;[生物]diaphragm/
かくまくいしょく /角膜移植/
かくまくえん /角膜炎/
かくまくせんこう /角膜穿孔/
かくまくはくり /角膜剥離/
かくまち /各街/
かくまる /角丸/革マル;革命的マルクス主義(派)/
かくみさいる /核ミサイル/
かくみんぞく /各民族/
かくむ /各務/
かくめ /各目/
かくめい /革命/
かくめいか /革命家/革命歌;la Marseillaiseなど/革命下/
かくめいご /革命後/
かくめいじ /革命児/革命時/
かくめいせい /革命性/
かくめいせんそう /革命戦争/
かくめいちゅう /革命中/
かくめいてき /革命的/
かくめいまえ /革命前/
かくめいれい /各命令/
かくめいれき /革命暦;[世界史]calendrier revolutionnaire/
かくめいろん /革命論/
かくめん /各面/
かくも /斯くも/
かくもじ /各文字/
かくもじれつ /各文字列/
かくもん /各問/
かくもんだい /核問題/
かくや /隔夜/覚弥/
かくやく /確約/赫奕/核薬/
かくやくしょ /各役所/
かくやくぶん /確約文/
かくやす /格安/
かくやすけん /格安券/
かくやすこうくうけん /格安航空券/
かくやすてん /格安店/
かくゆうごう /核融合/
かくゆうごうけん /核融合研/
かくゆうごうけんきゅう /核融合研究/
かくゆうごうけんきゅうじょ /核融合研究所/
かくゆうごうろ /核融合炉/
かくよう /各様/
かくようそ /各要素/
かくよく /鶴翼/
かくよくし /核抑止/
かくよくしりょく /核抑止力/
かくら /加倉/
かくらい /加倉井/
かくらん /攪乱/撹乱;「攪」異体字/各欄/霍乱;暑気中り。「鬼の-」/
かくり /隔離/郭李/核理/
かくりきし /各力士/
かくりけん /核理研/
かくりしいく /隔離飼育/
かくりしつ /隔離室/
かくりせいさく /隔離政策/
かくりっこうほしゃ /各立候補者/
かくりつ /確立;†establish.「接続の-」/確率;†probability.「成功する-」/格率;maximの訳語/格律/
かくりつかいしゃく /確率解釈/
かくりつかてい /確率過程/
かくりつがくしゅう /確率学習/
かくりつぎょうれつ /確率行列/
かくりつし /確率紙/
かくりつじしょう /確率事象/
かくりつせいぎょ /確率制御/
かくりつだい /確率大/
かくりつてき /確率的/
かくりつとうけい /確率統計/
かくりつとうけいがく /確率統計学/
かくりつぶんぷ /確率分布/
かくりつぶんぷかんすう /確率分布関数/
かくりつぶんぷきょくせん /確率分布曲線/
かくりつぶんぽう /確率文法/
かくりつへんすう /確率変数/
かくりつへんどう /確率変動/
かくりつへんどうちゅう /確率変動中/
かくりつみつど /確率密度/
かくりつみつどぶんぷ /確率密度分布/
かくりつもでる /確率モデル/
かくりつろん /確率論/
かくりつろんてき /確率論的/
かくりびょうとう /隔離病棟/
かくりょう /閣僚/
かくりょういき /各領域/
かくりょうきゅう /閣僚級/
かくりょく /角力/核力/
かくりようしゃ /各利用者/
かくりん /鶴林;[仏教]沙羅双樹の林/
かくりんじ /鶴林寺;兵庫/
かくれ /隠れ/
かくれい /鶴唳/
かくれいわ /礁/
かくれうお /隠れ魚/
かくれが /隠れ家/
かくれそう /隠れ層/
かくれっしゃ /各列車/
かくれつ /各列/
かくれば /隠れ場/
かくれみの /隠れ蓑/
かくれやど /隠れ宿/
かくれんぼう /隠れん坊;もーいーかい/
かくろせん /各路線/
かくろん /各論/確論;certain argument/
かくろんはんたい /各論反対/
かくわ /各話/
かくわしゃ /各話者/
かくん /家訓/家君/
かぐ /家具/下愚/
かぐう /仮寓/
かぐちょう /家具調/
かぐちょうど /家具調度/
かぐてん /家具店/
かぐや /家具屋/
かぐやひめ /かぐや姫/輝夜姫/
かぐやま /香具山/香久山/
かぐよう /家具用/
かぐら /神楽/
かぐらうた /神楽歌/
かぐらお /神楽男/
かぐらざか /神楽坂/
かぐらだいこ /神楽太鼓/
かぐらづき /神楽月;霜月(旧暦11月)/
かぐらばやし /神楽囃子/
かぐらぶえ /神楽笛/
かぐん /下郡/加群/
かけ /賭け/掛/賭/欠け/×;→かける,x/
かけあい /掛け合い/
かけあし /駆け足/駆足/駈け足/
かけい /家計/家系/筧/花茎/花形/火刑/嘉慶;年号(1387-1389)/家兄/下掲/科刑/
かけいかんり /家計管理/
かけいず /家系図/
かけいちょうさ /家計調査/
かけいひ /家計費/
かけいぼ /家計簿/
かけいぼこうかい /家計簿公開/
かけうり /掛売/掛売り/掛け売り/
かけおち /駆け落ち/駆落ち/駆落/
かけかえ /掛替え/
かけがい /掛買い/
かけがえ /掛け替え/掛替え/掛替/
かけがね /掛け金/
かけがわ /掛川/
かけがわえき /掛川駅/
かけきん /掛金/掛け金/賭け金;bet/賭金/
かけことば /掛詞/
かけこみ /駆け込み/駆込み/駈け込み/掛け込み/掛込み/
かけこみじゅよう /駆け込み需要/
かけこみでら /駆け込み寺;DV男から守ります/駆込み寺/
かけごう /掛香/掛け香/懸香/懸け香/
かけごえ /掛け声/かけ声/掛声/掛聲/
かけごと /賭け事/賭事/
かけごや /掛け小屋/掛小屋/
かけざかな /懸け魚/懸魚/
かけざん /かけ算/掛け算/掛算/
かけした /掛下/
かけしょうぎ /賭将棋/
かけじ /欠字/掛字/掛け字/懸け路/欠け字/
かけじく /掛け軸/掛軸/
かけす /懸巣/
かけすて /掛け捨て;-の保険/
かけず /掛図/掛け図/
かけそば /掛け蕎麦/
かけぞり /掛け反り/
かけだおれ /掛倒れ/
かけだし /駆け出し;novice/駆出し/掛け出し;-舞台/掛出し/
かけだしもの /駆け出し者/駆出し者/
かけちがい /掛け違い;ボタンの-/掛違い/
かけっこ /駆けっこ/
かけつ /可決/可欠/
かけつかばし /掛塚橋/
かけつご /可決後/
かけど /掛戸/
かけどけい /掛け時計/掛時計/
かけなげ /掛け投げ/
かけね /掛け値/掛値/
かけのうお /懸けの魚/
かけはし /架け橋/掛け橋/懸け橋/掛橋/懸橋/梯/棧/
かけはた /欠端/欠畑/
かけひ /筧/懸け樋/
かけひき /駆け引き/駆引き/
かけふ /掛布/
かけふだ /掛札/
かけぶとん /掛布団/掛け布団/
かけべり /掛減り/
かけまーじゃん /賭麻雀/
かけまま /欠真間/
かけめ /掛け目/掛目/欠け目/欠目/
かけもち /掛け持ち/掛持ち/
かけもの /掛物/掛け物/
かけや /掛合/
かけら /欠片/破片;?/欠けら/
かけり /翔/
かけりつ /掛率/賭け率/
かける /×/＊/掛ける/
かけん /家憲/科研/化研/科学計測研究所;※abbrev/
かけんせいやく /科研製薬;[企業名]/
かけんひ /科研費/科学研究費;※abbrev/
かげ /影;shadow/陰;shade/蔭;≒陰/翳;かげり/鹿毛/景/
かげうら /影浦/
かげえ /影絵/影画/
かげかつ /景勝/
かげき /過激;radical/歌劇;opera/
かげききょう /蔭桔梗/
かげきじょう /歌劇場/
かげきだん /歌劇団/
かげきは /過激派/
かげきよ /景清/
かげぐち /陰口/蔭口/
かげごと /陰言/
かげさわ /影沢/
かげしばい /陰芝居/
かげぜん /陰膳/
かげつ /花月/ヶ月/カ月/ヵ月/か月/ケ月/箇月/荷月/
かげつえん /花月園/
かげとものみち /山陽道;地名/
かげどうろう /影灯籠/
かげばら /陰腹/
かげひこ /景彦/
かげひなた /陰日向/
かげふみ /影踏み/
かげぼうし /影法師/
かげぼし /陰干し/
かげま /陰間/
かげまぢゃや /陰間茶屋/
かげまる /影丸/
かげみつ /景光/
かげむしゃ /影武者/
かげもと /影本/
かげやま /影山/景山/蔭山/陰山/
かげやまこうえん /景山公園/
かげゆ /勘解由/
かげり /翳り/
かげろう /陽炎;heat haze/蜉蝣;ephemera/蜻蛉;NB:「とんぼ」とも/
かげろうにっき /蜻蛉日記/
かげん /下限/加減/下弦;-の月/下元;陰暦10月15日/嘉元;年号(1303-06)/仮現/嘉言;戒め/寡言;寡黙/仮言;hypothesis/過言;言い間違い/過現;過去と現在/訛言;なまり,デマ/⊃/
かげんさん /加減算/
かげんさんき /加減算器/
かげんざん /加減算/
かげんじょうじょ /加減乗除/
かげんそく /加減速/
かげんそくじ /加減速時/
かげんち /下限値/
かげんてき /仮言的;[論理]hypothetisch/
かげんほう /加減法/
かげんめいほう /仮言命法/
かこ /過去/加古/加挙;[律令制]例挙を超える出挙/苛湖/水夫/水手/
かこい /囲い;隣の家に-が/
かこいこみ /囲い込み/
かこいもの /囲い者/
かこう /加工/河口/下降/化工;化学工業/火口;nozzle/下行;⇔上行。「-結腸」/架構;frame/仮構;fiction/花香/火工;pyrotechnic/河港/花梗/佳肴;ごちそう/歌稿/華甲/加功/嘉肴;≒佳肴/
かこういき /河口域/
かこうおんけい /下降音形/
かこうかいはつ /加工開発/
かこうがた /下降型/
かこうがん /花崗岩/
かこうき /下降期/
かこうきゅう /火口丘/
かこうきりゅう /下降気流/
かこうぎじゅつ /加工技術/
かこうけいれつ /下降系列/
かこうげん /火口原/
かこうこ /火口湖/河口湖;‖「かわぐちこ」かも/
かこうこう /河口港/
かこうこほうめん /河口湖方面/
かこうし /加工紙/
かこうしょくひん /加工食品/
かこうせい /加工性/
かこうせいど /加工精度/
かこうせき /河口堰/
かこうせん /下降線/
かこうぜき /河口堰/
かこうち /可耕地/
かこうちゅう /加工中/
かこうちん /加工賃/
かこうづけ /加工付/
かこうなべ /加工鍋/
かこうにく /加工肉/
かこうにゅう /加工乳/
かこうひん /加工品/火工品;pyrotechnics/
かこうへん /下降辺/
かこうぼうえき /加工貿易/
かこうよう /加工用/
かこかんりょう /過去完了/
かこがた /過去型/
かこがわ /加古川/
かこがわし /加古川市/
かこがわしみん /加古川市民/
かこがわせん /加古川線/
かこきじ /過去記事/
かこきゅう /過呼吸/
かこきゅうしょうこうぐん /過呼吸症候群/
かこく /過酷;(ひどすぎる)「-な条件」/苛酷;(情け容赦ない)「-なレース」/河谷/カ国/ヶ国/苛刻;=苛酷/禾穀/
かこくぼん /家刻本/
かこくるい /禾穀類/
かこけい /過去形/
かこさいこう /過去最高/
かこさいた /過去最多/
かこさいだい /過去最大/
かこさいてい /過去最低/
かこしんこうけい /過去進行形/
かこじせい /過去時制/
かこすうねん /過去数年/
かこすうねんかん /過去数年間/
かこせい /過去生/
かこぜ /過去世;[仏教]/
かこちょう /過去帳/
かこつ /化骨/
かこなんど /過去何度/
かこはんとしかん /過去半年間/
かこぶんし /過去分詞/
かこみきじ /囲み記事/
かこもん /過去問/
かこもんだい /過去問題/
かころぐ /過去ログ/
かこん /禍根/仮根;[植物]rhizoid/
かご /籠/過誤/駕籠/加護/篭;「籠」の異体字/花後/華語/歌語/訛語/
かごう /化合/加号/
かごうぶつ /化合物/
かごかき /駕籠舁き;-駕籠に乗らず/
かごさか /籠坂/
かごしま /鹿児島/
かごしまかん /鹿児島間/
かごしまくうこう /鹿児島空港/
かごしまけん /鹿児島県/
かごしまこう /鹿児島港/
かごしまし /鹿児島市/
かごしましがい /鹿児島市街/
かごしましでん /鹿児島市電/
かごしましょうこう /鹿児島商工/
かごしまじつぎょう /鹿児島実業/
かごしまじん /鹿児島人/
かごしません /鹿児島線/
かごしまだいがく /鹿児島大学/
かごしまべん /鹿児島弁/
かごしまほうそう /鹿児島放送/
かごしまほうめん /鹿児島方面/
かごしまほんせん /鹿児島本線/
かごしまわん /鹿児島湾/
かごせ /籠瀬/篭瀬/
かごそう /夏枯草/
かごたに /籠谷/篭谷/
かごと /託言/
かごのとり /籠の鳥;そうよ私は-/
かごはら /篭原/
かごみみ /籠耳;ちゃんと聞いてない/
かごめ /籠目/
かごや /駕籠屋;お猿の-はほいさっさ/
かごん /過言/
かさ /傘/笠/嵩/瘡;できもの一般/暈;halo/加佐/疽;はれものの一種/
かさあげ /嵩上げ/
かさい /火災/家裁;家庭裁判所/花菜/果菜/家宰/歌才/家妻/葛西;地名/笠井/加西/河西/家栽;?/
かさいえき /葛西駅/
かさいかいじょうほけん /火災海上保険/
かさいかんちき /火災感知器/
かさいがん /火砕岩;pyroclast/
かさいきょうさい /火災共済/
かさいし /笠石/
かさいしゃりょう /火災車両/
かさいじこ /火災事故/
かさいぜんぞう /葛西善蔵;作家(1887-1928) 『子をつれて』/
かさいちょうさかん /家裁調査官/
かさいのり /葛西海苔/
かさいはっせい /火災発生/
かさいぶつ /火砕物/
かさいほうちき /火災報知器/
かさいほうめん /葛西方面/
かさいほけん /火災保険/
かさいよぼう /火災予防/
かさいりゅう /火砕流/
かさいりんかいこうえん /葛西臨海公園/
かさいるい /果菜類;vegetable fruit/花菜類;flower vegetable/
かさおか /笠岡/
かさかき /瘡掻き;梅毒/
かさかけ /笠懸/
かさがたけ /笠ヶ岳;地名,/
かさぎ /笠木/笠置;地名/
かさく /佳作;fine work.「入選なし、-２作」/寡作;⇔多作/家作/仮作/
かさくものがたり /仮作物語/
かさくら /笠倉/
かさくらしゅっぱん /笠倉出版;[出版社名]/
かさぐも /笠雲/
かささ /笠沙/
かささぎ /鵲/
かさしま /笠島/
かさじぞう /笠地蔵/
かさじま /笠島/
かさじょう /傘状/
かさたて /傘立/傘立て/
かさだか /嵩高/
かさだかひん /嵩高品/
かさつ /苛察/
かさでら /笠寺/
かさど /笠戸/
かさなり /重なり/
かさぬい /笠縫/
かさね /重ね/襲/
かさねあわせ /重ね合わせ/
かさねうち /重ね打ち/
かさねがき /重ね描き/
かさねがさね /重ね重ね/
かさねぎ /重ね着/
かさねつぎ /重ね継ぎ/
かさねて /重ねて/
かさねどり /重ね録り/
かさねぬり /重ね塗り/
かさねのいろめ /襲の色目/
かさのり /傘海苔/
かさはら /笠原/
かさぶくろ /傘袋/
かさぶた /瘡蓋/痂;=瘡蓋/
かさま /笠間/
かさまつ /笠松/
かさまつけいばじょう /笠松競馬場/
かさみ /嵩/
かさり /笠利/
かさん /加算;+/可算;countable/家産/加餐/
かさんうんちん /加算運賃/
かさんか /過酸化/
かさんかいすう /加算回数/
かさんかいろ /加算回路/
かさんかししつ /過酸化脂質/
かさんかすいそ /過酸化水素/
かさんかすいそすい /過酸化水素水/
かさんかぶつ /過酸化物;[化学]/
かさんがた /加算型/
かさんき /加算器/加算機/
かさんこ /可算個/
かさんごうせい /加算合成/
かさんしゅうごう /可算集合/
かさんせい /加算性/
かさんぜい /加算税/
かさんそうさ /加算操作/
かさんへいきん /加算平均/
かさんほうしき /加算方式/
かさんむげんこ /可算無限個/
かさんめいし /可算名詞/
かさんめいれい /加算命令/
かざ /風/
かざあな /風穴/
かざい /家財/花材/貨財/歌材/夏材/
かざいどうぐ /家財道具/
かざいれ /風入れ/
かざおと /風音/
かざおれ /風折れ/
かざかみ /風上/
かざきり /風切り/
かざきりば /風切羽/
かざきりばね /風切り羽;(鳥の)remex/
かざぐも /風雲/
かざぐるま /風車/
かざごえ /風邪声/風声/
かざし /挿頭/
かざしも /風下/
かざしもがわ /風下側/
かざと /風戸/
かざとおし /風通し/
かざはな /風花/
かざはや /風早/
かざばな /風花/
かざま /風間/
かざまち /風街/
かざまつり /風祭/風祭り/
かざまど /風窓/
かざみ /風見/
かざみどり /風見鶏/
かざむき /風向き/風向/
かざり /飾り/
かざりがし /飾り菓子/
かざりけ /飾り気/
かざりけい /飾り罫/
かざりだけ /飾り竹/
かざりだな /飾り棚;cabinet/
かざりっけ /飾りっ気/
かざりつけ /飾り付け/
かざりぬい /飾り縫い/
かざりばね /飾り羽/
かざりひも /飾り紐/
かざりまど /飾り窓/飾窓/
かざりもの /飾り物/
かざりわく /飾り枠/
かざわ /鹿沢/
かざん /火山/華山/加算/
かざんかつどう /火山活動/
かざんがす /火山ガス;volcanic gas/
かざんがん /火山岩/
かざんさいせつぶつ /火山砕屑物/
かざんせい /火山性/
かざんせいじしん /火山性地震;volcanic earthquake/
かざんたい /火山帯/火山体/
かざんだん /火山弾/
かざんてんのう /花山天皇/
かざんとう /火山島/
かざんばい /火山灰/
かざんばいち /火山灰地/
かざんみゃく /火山脈/
かざんむげん /可算無限/
かざんれき /火山礫/
かざんれつ /火山列/
かし /菓子/歌詞/可視/瑕疵/下肢/樫/河岸/華氏/仮死/下賜/貸/貸し/花糸/下士/橿/槝/嫁資/
かし> /貸し;-金庫,-衣裳,-主/華氏;Fahrenheit/貸/
かしあげ /借上;高利貸/
かしい /香椎/
かしいかえん /香椎花園/
かしいしょう /貸し衣裳/
かしいせん /香椎線/
かしうり /貸売り/
かしお /加塩/
かしおか /柏岡/
かしおけいさんき /カシオ計算機/
かしおぺあざ /カシオペア座;Cassiopeia(Cas)/
かしおぺやざ /カシオペヤ座;Cassiopeia(Cas)/
かしおり /菓子折り/菓子折/
かしか /可視化/
かしかーど /歌詞カード/
かしかた /貸方/貸し方/
かしかぶ /貸株/
かしかり /貸し借り/
かしかん /下士官/
かしき /下式/花式/菓子器/爨/炊き/
かしきり /貸切/貸し切り/貸切り/
かしきりれっしゃ /貸切列車/
かしきん /貸金/貸し金/
かしきんぎょう /貸金業/
かしきんぎょうきせいほう /貸金業規制法/
かしきんこ /貸金庫/貸し金庫/
かしく /畏/
かしこ /賢/畏/彼処/
かしこう /可視光/
かしこうせん /可視光線/
かしこうせんいがい /可視光線以外/
かしこし /貸越/
かしこじまかん /賢島間/
かしこどころ /賢所/
かしさげ /貸下げ/
かしざお /貸竿/
かしざしき /貸座敷/
かしざら /菓子皿/
かししつ /貸室/
かししぶり /貸し渋り/
かししょくにん /菓子職人/
かしじょうたい /仮死状態/
かしずき /傅き/
かしずきびと /傅き人/
かしせい /可視性/
かしせき /貸席/
かしそうこ /貸倉庫/
かしたいやく /歌詞対訳/
かしたんぽ /瑕疵担保/
かしたんぽせきにん /瑕疵担保責任/
かしだ /樫田/
かしだおれ /貸倒/貸倒れ/貸し倒れ/
かしだおれそんしつ /貸倒損失/
かしだおれひきあてきん /貸倒引当金;[会計]勘定科目。bad debt reserve/
かしだし /貸出/貸し出し/貸出し/
かしだしきかん /貸出期間/
かしだしぎょうむ /貸出業務/
かしだしさき /貸出先/
かしだしちゅう /貸出中/貸し出し中/
かしだしぼ /貸し出し簿/
かしだしよう /貸出用/
かしち /貸地/貸し地/
かしちょう /可視聴/
かしちん /貸賃/貸し賃/
かしつ /過失/加湿/火室/加執/呵叱/
かしつかさ /菓子司/
かしつき /加湿器/加湿機/
かしつきのう /加湿機能/
かしつけ /貸付/貸し付け/貸付け/
かしつけきん /貸付金/
かしつけしんたく /貸付信託/
かしつせきにん /過失責任/
かしつそうさい /過失相殺/
かしつちし /過失致死/
かしつちしざい /過失致死罪/
かしつにんてい /過失認定/
かしつのうりょく /加湿能力/
かしつはん /過失犯/
かしつぶん /過失分/
かしつよう /加湿用/
かしつわりあい /過失割合/
かして /貸し手/貸手/
かしてき /可視的/
かしてん /菓子店/
かしてんぽ /貸店舗/
かしど /可視度/
かしぬし /貸主/貸し主/
かしの /柏野/
かしはがし /貸し剥がし/
かしはら /橿原/樫原/
かしはらじんぐう /橿原神宮/
かしはらじんぐうまえ /橿原神宮前/
かしはらせん /橿原線/
かしば /香芝/
かしばこ /菓子箱/
かしぱん /菓子パン/
かしびる /貸しビル/
かしぶね /貸舟/
かしぶんさん /家資分散/
かしべっそう /貸別荘/
かしほん /貸本/
かしほんや /貸本屋/
かしま /貸間/鹿島/鹿嶋/嘉島/加島/加嶋/貸し間/
かしまこう /鹿島港/
かしまじんぐう /鹿島神宮/
かしません /鹿島戦/
かしまた /樫又;姓/
かしまだ /鹿島田/
かしまだい /鹿島台/
かしまちょう /鹿島町/
かしまやり /鹿島槍/
かしまりんかいてつどう /鹿島臨海鉄道/
かしみせ /貸し店/
かしむら /樫村/鹿志村/
かしも /加子母/
かしもと /貸元/
かしもり /樫森/
かしゃ /加者/貨車/華奢/火車/
かしゃがた /花車方/花車形/
かしゃく /呵責;良心の-/仮借;-ない/苛責;=呵責/
かしゃばば /火車婆/
かしゃわたし /貨車渡し/
かしや /菓子屋/貸家/
かしやま /樫山/
かしゅ /歌手/火酒;蒸留酒/佳酒/
かしゅう /歌集/加州;California／加賀(石川県)/家集;個人の歌集/河州;河内/賀集;人名/何首烏/加集/
かしゅういも /何首烏芋/
かしゅかつどう /歌手活動/
かしゅく /可縮/
かしゅめい /歌手名/
かしょ /箇所/個所/ヶ所/カ所/過書/華胥/家書/歌書/過所;=過書/花書/
かしょう /仮称/歌唱/過少;†too few.「-申告」/過小;†too small.「-評価」/仮象;[哲学]Schein/火床/河床;riverbed/火傷;やけど/過昇/華宵/寡少;†few/花床;[植物]blossom end/嘉祥;年号(848-851)/嘉承;年号(1106-1108)/加商/過賞;ほめすぎ/迦葉;[仏教]Mahakasyapa/
かしょう> /過少;†too few.「-申告」/過小;†too small.「-評価」/
かしょうさんぜん /菓匠三全/
かしょうしどう /歌唱指導/
かしょうしょう /歌唱賞/
かしょうしんこく /過少申告/過小申告;?/
かしょうひょうか /過小評価/
かしょうほう /歌唱法/
かしょうりょく /歌唱力/
かしょく /過食/華燭;-の典(=結婚式)/仮植/家職/貨殖/火食/稼穡/河食/河蝕;=河食/
かしょくしょう /過食症/
かしょくのてん /華燭の典/
かしょくぶ /可食部;[栄養学]edible portion/
かしょくぶぶん /可食部分/
かしょぜんたい /箇所全体/
かしょぶん /可処分/
かしょぶんしょとく /可処分所得/
かしら /頭/
かしらいも /頭芋/
かしらがき /頭書/
かしらもじ /頭文字/
かしりょう /貸料/
かしるい /菓子類/
かしろ /嘉代/
かしわ /柏/栢;「柏」の異体字/
かしわぎ /柏木/
かしわくら /柏倉/
かしわざき /柏崎/
かしわし /柏市/
かしわしみん /柏市民/
かしわで /柏手;NB:大元は「拍手」のtypo/拍手/膳;宮中の料理人/膳夫;=膳/
かしわば /柏葉/
かしわばら /柏原/
かしわぶち /柏渕/
かしわほうめん /柏方面/
かしわまち /柏町/
かしわもち /柏餅/
かしわら /柏原/
かしん /過信/家臣/花心/加振/火神/花神/下唇/河神/歌神/仮身;NB:BTRON のファイルシステム上の概念/花唇/下臣/禍心/
かしんがわ /加振側/
かしんてん /加振点/
かしんりょく /加振力/
かしんれいげつ /嘉辰令月/
かじ /家事/火事/鍛冶/舵/梶;=舵/楫;=舵/柁;=舵/花時/加持;-祈祷/嘉事/加治;地名/加地;人名/加冶;人名?/鍛治;?/
かじい /梶井/
かじいくじ /家事育児/
かじいもとじろう /梶井基次郎/
かじうら /梶浦/
かじえんじょ /家事援助/
かじお /梶尾/
かじか /鰍/河鹿;(カエル)/杜父魚;=鰍/鮖/梶賀/
かじかがえる /河鹿蛙/
かじかざわ /鰍沢/
かじかわ /舵川/加冶川/
かじがや /梶ケ谷/
かじき /梶木/旗魚/加治木;地名/
かじきざ /旗魚座;Dorado(Dor)/
かじきとう /加持祈祷/
かじきまぐろ /梶木鮪/
かじく /花軸;[植物]rachis/仮軸;[植物]sympodium/
かじげんば /火事現場/
かじし /華字紙/
かじしごと /家事仕事/
かじしんぱんほう /家事審判法/
かじせいけい /下自成蹊/
かじた /梶田/
かじたに /梶谷/
かじたんとう /家事担当/
かじつ /果実/過日;the other day/夏日/花実;花と実／外観と内容/佳日;good day/
かじつあじ /果実味/
かじつしゅ /果実酒/
かじつす /果実酢/
かじつはん /夏日斑/
かじつるい /果実類/
かじづか /舵柄/
かじてつだい /家事手伝い/
かじとり /舵取り/
かじの /梶野/
かじのき /梶の木/
かじはら /梶原/
かじば /火事場/
かじばどろぼう /火事場泥棒/
かじぶんたん /家事分担/
かじま /鹿島/鹿嶋/梶真/
かじまけんせつ /鹿島建設;[企業名]/
かじみまい /火事見舞/
かじもと /梶本/
かじゃ /冠者/
かじや /鍛冶屋/梶谷/
かじやちょう /加治屋町/
かじゅ /果樹;fruit tree/花樹;flower tree/
かじゅう /果汁/荷重;†load.「トラックの-」/加重;†(サ変) weighting.「-平均」/過重;†overload.「-労働」/
かじゅういどう /荷重移動/
かじゅうぞうか /荷重増加/
かじゅうち /可住地/
かじゅうでん /過充電/
かじゅうぶん /果汁分/
かじゅうへいきん /加重平均/
かじゅうへんか /荷重変化/
かじゅうりょう /下重量/
かじゅえん /果樹園/
かじゅく /家塾/過熟/
かじゅくじ /過熟児;⇔未熟児/
かじゅし /果樹試/
かじゅしけんじょう /果樹試験場/
かじょ /加除/花序/家女/歌女/
かじょう /過剰/箇条/河上/家常/渦状/下情/
かじょうがき /箇条書き/箇条書/個条書き/
かじょうきょういく /過剰教育/
かじょうさはん /家常茶飯/
かじょうざいこ /過剰在庫/
かじょうしょう /過剰症;⇔欠乏症/
かじょうしんりょう /過剰診療/
かじょうじんこう /過剰人口/
かじょうせいさん /過剰生産/
かじょうせっしゅ /過剰摂取/
かじょうてきおう /過剰適応/
かじょうとうし /過剰投資/
かじょうとうよ /過剰投与/
かじょうねつ /過剰熱/
かじょうはんのう /過剰反応/
かじょうひなん /過剰避難/
かじょうぼうえい /過剰防衛/
かじょしき /加除式/
かじよう /家事用/
かじろうどう /家事労働/
かじろうどうしゃ /家事労働者/
かじわら /梶原/
かじわらいっき /梶原一騎/
かじん /歌人/家人/佳人/寡人/
かじんはくめい /佳人薄命/
かす /粕;酒かす/糟;酒かす/滓;クズ/
かすい /加水/下垂/河水/火水/仮睡/
かすいたい /下垂体/
かすいど /火水土/
かすいぶんかい /加水分解/
かすいぶんかいこうそ /加水分解酵素;[生化学]hydrolase/
かすいもく /火水木/
かすいもくきんど /火水木金土/
かすう /価数/仮数/
かすうぶ /仮数部/
かすかべ /春日部/
かすかべきょうえい /春日部共栄/
かすかべし /春日部市/
かすかわ /粕川/
かすが /春日/
かすがい /春日井/鎹/春日居/
かすががわ /春日川/
かすがし /春日市/
かすがたいしゃ /春日大社/
かすがちょう /春日町/
かすがづくり /春日造り;[建築]/春日造/
かすがどおり /春日通り/
かすがの /春日野/
かすがのつぼね /春日局/
かすがのみち /春日野道/
かすがばる /春日原/
かすがばん /春日版/
かすがふじ /春日富士/
かすがやま /春日山/
かすけーどせつぞく /カスケード接続/
かすじる /粕汁/
かすず /粕酢;主に寿司に/糟酢;=粕酢/
かすたに /糟谷/
かすたむか /カスタム化/
かすだ /粕田/
かすづけ /粕漬/糟漬/
かすとり /粕取り;-焼酎、転じてカストリ(酒、雑誌)/糟取り;=粕取り/
かすとりざっし /カストリ雑誌/
かすとりしゅ /粕取り酒/カストリ酒/
かすなべ /粕鍋/
かすぴかい /カスピ海/
かすみ /霞/香澄/香住/香純/
かすみあみ /霞網;使用禁止/
かすみがうら /霞ヶ浦/霞浦/
かすみがせき /霞が関/霞ヶ関/霞ケ関/
かすみがせきびる /霞が関ビル/
かすみさい /霞祭/
かすみさんしょううお /霞山椒魚/
かすみそう /霞草/
かすみちょう /香澄町/
かすみのめ /霞目/
かすや /粕谷/粕屋/糟谷/
かすり /絣/飛白/緕/纃/綛/
かすりきず /かすり傷/擦り傷/
かすれ /掠れ/
かず /数/下図/和/一/數;旧字/一寿/香鶴/
かずあき /和明/和昭/一明/一彰/一晃/和晃/一章/和晶/
かずあわせ /数合わせ/
かずい /花蕊/花蘂;「蕊」異体字/
かずえ /主計/一恵/和恵/和枝/一枝/
かずえのかみ /主計頭/
かずえりょう /主計寮;[律令制]/
かずお /和夫/一夫/一生/和男/一雄/一男/和雄/和生/和郎/一穂/
かずおか /数岡/
かずおみ /和臣/
かずかず /数々/数数/
かずき /一樹/和樹/一機/和紀/一喜/一起/被衣/
かずこ /和子/量子/佳寿子/数子/加純子/加寿子/
かずさ /上総/
かずさいちのみや /上総一宮/
かずさなかの /上総中野/
かずさんしょう /下図参照/
かずし /和志/和司/一司/一至/和士/数史/一志/
かずしげ /和重/一茂/和茂/一繁/
かずしれず /数知れず/
かずじたい /数自体/
かずすけ /一助/
かずたか /一隆/一貴/和貴/一任/
かずてる /一輝/一晃/
かずと /一人/和人/
かずとき /和時;名/
かずとし /和敏/和利/一利/一敏/一寿/一世/数敏/和淑/
かずなり /一成/
かずね /和音/
かずの /数野/
かずのこ /数の子/鯑/
かずのみや /和宮/
かずのり /和則/和典/和徳/和憲/和紀/一憲/一紀;名/一範/一孔/千典/主紀/
かずひこ /和彦/一彦/和比古/
かずひさ /和久/一久/一寿/数久/
かずひで /一秀/和英/和秀/一英/
かずひと /一人/一仁/和人/和仁/
かずひろ /和弘/和宏/和博/一博/一弘/一浩/和広/一宏/和浩/和裕/一洋/一裕/一広/一寛/
かずふみ /和史/一文/
かずほ /一穂/
かずほど /数程/
かずま /和馬/一磨/和磨/數間/
かずまさ /和正/一正/数正/和政/一昌/和昌/
かずまる /一丸/
かずまろ /和麻呂/
かずみ /和美/一美/和巳/一味/一三/和実/香津美/一巳/香樹実/
かずみち /一路/
かずもと /一元/
かずもの /数物/
かずや /和也/一也/和哉/一哉/一弥/和弥/一八/数也/
かずやす /一泰/
かずゆき /和幸/和之/一幸/一之/和行/一行/和恭/数幸/
かずよ /和代/一代/和世/
かずよし /和義/一義/和良/和美/和好/和由/和芳/
かずら /葛;つるくさ/蔓;=葛/鬘;(wig) =かつら/
かずらばし /蔓橋/
かずらもの /鬘物/
かずわり /数割/
かせ /枷/綛;糸を巻く器具/加勢/加瀬/加世/
かせい /火星/化成/加勢;assist/仮性;pseudo.「-近視」/苛性;caustic.「-ソーダ」/家政/火勢/河清;-を俟つ/化政;(年号の)文化・文政/歌聖/火成;igneous.「-岩」/苛政;-は虎よりも猛し/
かせい> /仮性;-近視,-クループ/
かせいか /家政科/
かせいかり /苛性カリ/苛性加里/
かせいがく /家政学/
かせいがくいん /家政学院/
かせいがん /火成岩/
かせいきょういく /家政教育/
かせいきんし /仮性近視/
かせいぎょ /可制御/
かせいぎょせい /可制御性/
かせいこうぎょう /化成工業/
かせいじん /火星人/
かせいそーだ /苛性ソーダ;水酸化ナトリウム/
かせいたい /仮声帯/
かせいだい /家政大/
かせいねんだいき /火星年代記/
かせいひょうめん /火星表面/
かせいひりょう /化成肥料/
かせいひん /化成品/
かせいふ /家政婦/
かせいふちょう /家政婦長/
かせいほうけい /仮性包茎/
かせいめん /火星面/
かせいろん /火成論/
かせき /化石/可積/
かせきか /化石化/
かせきさい /過積載/
かせきさいしゃりょう /過積載車両/
かせきねんりょう /化石燃料/
かせきぶん /可積分/
かせきぶんかんすう /可積分関数/
かせぎ /稼ぎ/鹿/
かせぎがしら /稼ぎ頭/
かせぎだか /稼ぎ高/
かせぎて /稼ぎ手/
かせだ /加世田/
かせつ /仮説;†hypothesis.「量子-」/仮設;†temporary.「-住宅」/架設;†install.「ケーブルの-」/佳節/
かせつか /仮説化/
かせつきょう /仮設橋/
かせつけいせい /仮説形成/
かせつけんてい /仮説検定;[統計]hypothesis test/
かせつすいろん /仮説推論/
かせづえ /鹿杖/
かせやま /鹿背山/
かせん /河川/下線;underline/架線;-工事/寡占/化繊;[略語]化学繊維/歌仙/火線;[光学]caustic curve/加線;added line/火箭;=火矢/貨泉/
かせんか /寡占化/
かせんしき /河川敷/
かせんした /架線下/
かせんじ /架線事/
かせんじき /河川敷/
かせんじきどうろ /河川敷道路/
かせんじこ /架線事故/
かせんじょうたい /寡占状態/
かせんすい /河川水/
かせんせつだん /架線切断/
かせんちゅう /架線柱/
かせんでんあつ /架線電圧/
かせんぶ /下線部/
かせんほう /河川法/
かせんよう /架線用/
かせんよこ /河川横/
かぜ /風/風邪;flu/
かぜあたり /風当たり/風当り/
かぜい /課税/寡勢/苛税/
かぜいかかく /課税価格/
かぜいがく /課税額/
かぜいきかん /課税期間/
かぜいしょうめいしょ /課税証明書/
かぜいしょとく /課税所得/
かぜいたいしょう /課税対象/
かぜいたいしょうがく /課税対象額/
かぜいひょうじゅん /課税標準/
かぜいぶっけん /課税物件/
かぜいぶん /課税分/
かぜいりつ /課税率/
かぜおき /風興/
かぜおと /風音/
かぜかじゅう /風荷重;[建築]/
かぜきた /風北/
かぜぎみ /風邪気味/
かぜぐすり /風邪薬/カゼ薬/
かぜけ /風邪気/
かぜごえ /風邪声/
かぜごこち /風邪心地/
かぜたいふう /風台風/
かぜたち /風立/
かぜつかい /風使い/
かぜとおし /風通し/
かぜのたに /風の谷;[アニメ]『-のナウシカ』/
かぜのたより /風の便り/
かぜのぼん /風の盆;おわら。八尾の祭(9.1-3)/
かぜひき /風邪引き/
かぜまかせ /風任せ/
かぜまち /風待ち/
かぜまつり /風祭/風祭り/
かぜむき /風向き/
かぜよけ /風よけ/
かぜん /果然/
かそ /過疎/可塑/火鼠;=ひねずみ/
かそう /仮想/下層/仮装;disguise/火葬/家相/仮葬/仮相/価層/
かそう> /仮想;-現実,-領域,-デバイス/
かそううん /下層雲/
かそうおんげん /仮想音源/
かそうか /仮想化/
かそうかい /可想界;mundus intelligibilis/
かそうかいきゅう /下層階級/
かそうかんすう /仮想関数/
かそうがめん /仮想画面/
かそうきおく /仮想記憶/
かそうきおくきこう /仮想記憶機構/
かそうきかい /仮想機械/
かそうぎょうれつ /仮装行列/
かそうくうかん /仮想空間/
かそうけいさんき /仮想計算機/
かそうげんじつ /仮想現実/
かそうげんじつかん /仮想現実感/
かそうこうし /仮想光子/
かそうさ /可操作/
かそうさせい /可操作性/
かそうさど /可操作度/
かそうしゃかい /下層社会/
かそうじょう /仮想上/
かそうすい /仮想水/
かそうせかい /仮想世界/
かそうせん /仮想戦/
かそうたいしょう /仮装大賞/
かそうたんまつ /仮想端末/
かそうてき /仮想的/仮想敵;imaginary enemy/
かそうてきこく /仮想敵国/
かそうば /火葬場/
かそうぶ /下層部/
かそうへんい /仮想変位/
かそうりゅうし /仮想粒子/
かそく /加速/可測/仮足/
かそくうんどう /加速運動/
かそくかのう /加速可能/
かそくかん /加速感/
かそくかんすう /可測関数/
かそくき /加速器/
かそくくうかん /可測空間/
かそくくかん /加速区間/
かそくけい /加速系/
かそくげんそく /加速減速/
かそくざい /加速剤/
かそくしゃせん /加速車線/
かそくしゅうごう /可測集合/
かそくしゅうそく /加速収束/
かそくじ /加速時/
かそくじっけん /加速実験/
かそくせい /加速性/
かそくせいのう /加速性能/
かそくそうち /加速装置/
かそくちゅう /加速中/
かそくてき /加速的/
かそくど /加速度/
かそくどうんどう /加速度運動/
かそくどけい /加速度計;accelerometer/加速度系;accelerating system/
かそくどてき /加速度的/
かそくのうりょく /加速能力/
かそくふりょう /加速不良/
かそくよう /加速用/
かそくりょく /加速力/
かそざい /可塑剤/
かそせい /可塑性/
かそちいき /過疎地域/
かそてき /可塑的/
かそり /加曽利/
かぞ /加須/数/數/
かぞう /加増/家蔵/架蔵/
かぞえ /数え/
かぞえあげ /数え上げ/
かぞえうた /数え歌/
かぞえかた /数え方/
かぞえどし /数え年/
かぞえやくまん /数え役満/
かぞく /家族/華族/
かぞくあい /家族愛/
かぞくいがい /家族以外/
かぞくいしき /家族意識/
かぞくおもい /家族思い/
かぞくおん /下属音/
かぞくかい /家族会/
かぞくかいぎ /家族会議/
かぞくかいご /家族介護/
かぞくかん /家族間/
かぞくかんけい /家族関係/
かぞくけいえい /家族経営/
かぞくけいえいきょうてい /家族経営協定/
かぞくけいかく /家族計画/
かぞくこうせい /家族構成/
かぞくしゅぎ /家族主義;familism/
かぞくしょゆう /家族所有/
かぞくすう /家族数/
かぞくせいど /家族制度/
かぞくぜんいん /家族全員/
かぞくそう /家族葬/
かぞくだんらん /家族団欒/
かぞくづれ /家族連れ/
かぞくてあて /家族手当/
かぞくてき /家族的/
かぞくどうし /家族同士/
かぞくない /家族内/
かぞくはっけい /家族八景/
かぞくぶろ /家族風呂/
かぞくよう /家族用/
かぞくりょうほう /家族療法;[精医]/
かぞくりょこう /家族旅行/
かぞくれき /家族歴/
かぞくわりびき /家族割引/
かた /肩/方/型;type/形;form/過多;too much/片/潟/夥多;very much/沫;?/
かた> /片;片開き,片為替,片時雨/
かたあし /片足/
かたあて /肩当て/
かたあやまり /型誤り/
かたい /下腿/化体/過怠/歌体/難;?/
かたいきん /過怠金/
かたいじ /片意地/
かたいせつ /化体説;[キリスト教]transubstantiation/
かたいっぽう /片一方/
かたいと /片糸/
かたいなか /片田舎/
かたいれ /肩入れ/肩入/
かたうで /片腕/
かたうど /方人/
かたうらみ /片恨み/
かたうんてんだい /片運転台/
かたえ /傍/
かたお /片尾/
かたおか /片岡/
かたおかつるたろう /片岡鶴太郎;芸能人名/
かたおし /型押し/
かたおち /型落ち;old model.「-のPC」/片落ち;unbalance.「-の裁定」/
かたおとし /片落とし/片落し/
かたおなみ /片男波/
かたおもい /片思い/片想い/
かたおや /片親/
かたかいそう /型階層/
かたかけ /肩掛け/肩掛/
かたかな /片仮名/片假名/
かたかなご /カタカナ語/片仮名語/
かたかなひょうき /片仮名表記/カタカナ表記/
かたかま /片鎌/
かたかんせつ /肩関節/
かたがい /片貝/
かたがき /肩書/肩書き/
かたがた /方々/旁/旁々/
かたがため /肩固め/
かたがみ /型紙/
かたがみてつどう /片上鉄道/
かたがわ /片側/
かたがわいっしゃせん /片側一車線/
かたがわはんぶん /片側半分/
かたがわり /肩代わり/肩代り/
かたき /仇/敵/
かたきうち /仇討ち/敵討ち/敵討/
かたきやく /敵役/
かたぎ /気質/堅気/形木/
かたぎし /片岸/
かたぎぬ /肩衣/
かたぎのしゅう /堅気の衆/
かたぎり /片桐/
かたく /家宅/火宅/仮託/花托;[植物]receptacle/
かたくしんにゅう /家宅侵入/
かたくずれ /型崩れ/型くずれ/
かたくそうさく /家宅捜索/
かたくち /片口/
かたくちいわし /片口鰯/
かたくな /頑/頑な/
かたくら /片倉/
かたくらちょう /片倉町/
かたくり /片栗/
かたくりこ /片栗粉/
かたくるし /堅苦し/
かたぐち /片口/肩口/
かたぐるま /肩車/
かたけんさ /型検査/
かたげんご /型言語/
かたこ /片子/
かたこい /片恋/
かたこう /形鋼/型項/型鋼;[建築]/
かたこと /片言/
かたこり /肩凝り/肩こり/
かたごし /肩越し;-に小さく頷く/
かたさき /肩先/
かたしき /型式/
かたしきばんごう /型式番号/
かたしぐれ /片時雨/
かたしすてむ /型システム/
かたしていし /型指定子/
かたしな /片品/
かたしなむら /片品村/
かたしょう /過多症/
かたしろ /形代/
かたじょうほう /型情報/
かたじん /堅人/
かたすいろん /型推論/
かたすかし /肩透かし/肩透し/
かたすみ /片隅/
かたず /固唾/
かたずみ /堅炭/
かたせ /片瀬/
かたせんげん /型宣言/
かたそで /片袖/
かたぞめ /型染め/
かたた /堅田/
かたたいけい /型体系/
かたたいすう /片対数/
かたたがえ /方違え/
かたたそう /型多相/
かたたたき /肩叩き;辞職勧告/
かたたち /方達/
かただより /片便り/
かたち /形/容/貌/型/
かたちじたい /形自体/
かたちぜんたい /形全体/
かたちづくり /形作り/
かたちんば /片跛/
かたっぱし /片っ端/
かたっぽ /片っ方/片っぽ/
かたつ /下達;上意-/可達;reachable/
かたつう /肩痛/
かたつき /型付;typed.「-言語」/肩付;superscript.「-文字」/肩付き/型つき/可達木;[情報]reachability tree/
かたつけ /型付け/型付/
かたつばさ /肩翼/
かたつぶり /蝸牛/
かたつむり /蝸牛/蝸/
かたづ /固唾/
かたづけ /片付け/型付け;typing/
かたづけま /片付け魔/
かたて /片手/
かたていぎ /型定義/
かたていすう /型定数/
かたておち /片手落ち/片手落/
かたてなべ /片手鍋/
かたてま /片手間/
かたてましごと /片手間仕事/
かたで /堅手/
かたとき /片時/
かたどおり /型通り/
かたな /刀/
かたなかじ /刀鍛冶/
かたながり /刀狩/刀狩り/
かたながれ /片流れ;[建築] 正面から見て ／| の形の屋根/
かたなきず /刀傷/刀疵/
かたなし /形無し/
かたなめい /刀銘/
かたなや /刀屋/
かたならし /肩慣らし/
かたにく /肩肉/
かたぬき /型抜き/型抜/
かたの /交野/片野/
かたのし /交野市/
かたは /片刃/片羽/
かたはい /片肺/
かたはし /片端/
かたはじ /片端/
かたはだ /片肌/
かたはば /肩幅/
かたはま /片浜/
かたはまえき /片浜駅/
かたはら /片腹/
かたばかり /形許り/
かたばみ /酢漿草/
かたばみか /カタバミ科/Oxalidaceae/
かたばん /型番/型板/型版/
かたばんごう /型番号/
かたばんふめい /型番不明/
かたぱっと /肩パット/
かたぱん /堅パン/
かたひがし /潟東/
かたひざ /片膝/
かたひじ /肩肘/片肘/
かたひと /方人/
かたひも /肩紐/
かたひら /片平/
かたびら /帷子/
かたびらのつじ /帷子ノ辻/
かたふち /片淵/
かたぶつ /堅物/
かたぶとり /固太り/
かたへん /方偏/
かたへんかん /型変換/
かたへんすう /型変数/
かたほ /片帆/
かたほう /片方/
かたほうこう /片方向/
かたほとり /片辺/
かたぼう /片棒/
かたま /片間/
かたまち /片町/
かたまちせん /片町線/
かたまひ /片麻痺;[医]hemiplegia/
かたまり /塊/固まり/
かたまりにく /塊肉/
かたみ /形見;-分け/肩身;-が狭い/片身;半身/片見;姓/
かたみごろ /片身頃/
かたみだし /肩見出し/
かたみち /片道/
かたみちいちじかん /片道一時間/
かたみちいっしゃせん /片道一車線/
かたみちうんちん /片道運賃/
かたみちきっぷ /片道切符/
かたみちこうくうけん /片道航空券/
かたみみ /片耳/
かたみわけ /形見分け/形見わけ/
かたむき /傾き/
かたむきほせい /傾き補正/
かたむすび /片結び/
かため /片目/片眼/固め/堅め/
かためい /型名/
かためん /片面/
かためんきろく /片面記録/
かためんやき /片面焼き/
かたもじ /片文字/
かたもちばり /片持ち梁;[建築]cantilever/
かたもと /片本/
かたもの /型物/
かたもみ /肩揉み/
かたもり /容保/
かたや /片や/
かたやき /固焼き;-パン/
かたやぶり /型破り/
かたやま /片山/
かたやません /片山潜/
かたやまづ /片山津/
かたやまづおんせん /片山津温泉/
かたやまてつ /片山哲/
かたゆで /固茹で;-の茹で卵/
かたよせ /片寄/
かたより /偏り/
かたらい /語らい/
かたり /語り/騙り/
かたりくち /語り口/
かたりぐさ /語り草/語り種/
かたりて /語り手;narrateur/
かたりべ /語り部/
かたりもの /語り物;⇔歌い物/
かたりろん /型理論/
かたりん /片輪/
かたりんそうこう /片輪走行/
かたる /拐/
かたろーす /肩ロース/
かたろうか /片廊下/
かたわ /片輪/片端/
かたわき /片脇/
かたわら /傍ら/傍/旁;≒傍/
かたわれ /片割れ/
かたん /下端/加担/荷担/可鍛/
かたんいと /カタン糸;cotton thread/
かたんちゅうてつ /可鍛鋳鉄/
かだ /華陀;人名,中国の名医/華佗;=華陀/伽陀;[仏教]gatha/
かだい /課題/過大/仮題/架台/歌題/
かだいおん /過大音/
かだいきょく /課題曲/
かだいけんきゅう /課題研究/
かだいし /過大視/
かだいせいきゅう /過大請求/
かだいとしょ /課題図書/
かだいばんごう /課題番号/
かだいひょうか /過大評価/
かだいめい /課題名/
かだん /花壇/歌壇/果断/華壇/下段;げだん/
かち /価値/勝ち/勝/徒/加地/可知/磆/褐/徒歩/
かちあげ /搗ち上げ/
かちいくさ /勝ち戦/勝ち軍/歩兵/徒歩軍/
かちいろ /褐色/勝色/勝ち色/
かちいろおどし /褐色縅/
かちうま /勝馬/勝ち馬/
かちうまとうひょうけん /勝馬投票券/勝ち馬投票券/
かちうん /勝運/
かちえ /勝絵/褐衣/勝ち絵/
かちおでら /勝尾寺/
かちかちやま /かちかち山/
かちかぶり /褐冠/
かちかん /価値観/価値感/
かちかんねん /価値観念/
かちがしら /徒士頭/
かちき /勝気/勝ち気/
かちきじゅん /価値基準/
かちきはん /価値規範/
かちぎぬ /褐衣/
かちぎね /搗ち杵/
かちく /家畜/
かちくえいせいしけんじょう /家畜衛生試験場/
かちくか /家畜化/
かちくごや /家畜小屋/
かちくにん /家畜人/
かちぐみ /勝ち組/
かちぐり /搗ち栗/
かちこし /勝ち越し/
かちこしだ /勝ち越し打/
かちじあい /勝ち試合/
かちじゆう /価値自由;Wertfreiheit (Weberの用語)/
かちすう /勝数/
かちたいけい /価値体系/
かちてん /勝ち点/勝点/
かちとうしゅ /勝ち投手;⇔負け投手/
かちどき /勝鬨/勝ち鬨/勝ちどき/
かちどきばし /勝鬨橋/
かちなのり /勝ち名乗り/勝名乗り/
かちにげ /勝ち逃げ/
かちぬき /勝ち抜き/勝抜き/
かちぬきせん /勝ち抜き戦/
かちはんだん /価値判断/
かちほうそく /価値法則/
かちぼし /勝ち星/勝星/
かちまけ /勝ち負け/
かちみ /勝ち味/
かちめ /勝目/勝ち目/
かちゅう /家中/渦中;-の人/火中;-の栗/華中/花柱;[植物]style/
かちょ /家猪/
かちょう /課長/蚊帳/科長/花鳥/家長/可聴/課徴/
かちょういき /可聴域/
かちょういん /課長印/
かちょうおん /可聴音/
かちょうが /花鳥画/
かちょうがた /可聴型/
かちょうきん /課徴金/
かちょうけん /家長権/
かちょうげんかい /可聴限界/
かちょうしゅうはすう /可聴周波数/
かちょうせいど /家長制度/
かちょうせん /花蝶扇/
かちょうたいいき /可聴帯域/
かちょうたいいきない /可聴帯域内/
かちょうだいり /課長代理/
かちょうち /可聴値/
かちょうづき /課長付/
かちょうのみや /華頂宮/
かちょうふうえい /花鳥諷詠/
かちょうふうげつ /花鳥風月/
かちろん /価値論;axiology/
かちん /褐/餅/
かぢ /鍛冶/加地/加治/
かっ /合/渇/
かっか /閣下/角化/各課/
かっかい /各界/各回/角界/
かっかく /赫々/
かっかざん /活火山/
かっかそうよう /隔靴掻痒;痒いところが掻けない。転じて思い通りにゆかずにもどかしい/
かっかんてき /客観的/
かっき /活気/各期/画期/客気/
かっきてき /画期的/劃期的/
かっきゅう /割球/
かっきょ /割拠/
かっきょう /活況/
かっきょく /各局/各曲/
かっきょくめん /各局面/
かっきん /恪勤/
かっくう /滑空/
かっくうき /滑空機/
かっくうじょう /滑空場/
かっくうせいのう /滑空性能/
かっくうひ /滑空比/
かっけ /脚気/
かっけい /活計/角形/
かっけた /各桁/
かっけつ /喀血/
かっこ /確固/括弧/各個/各戸/確乎/羯鼓;雅楽の打楽器/格好/『/』;二重鉤括弧/【/】;隅付き括弧/［/］;大括弧(bracket)/〔/〕;亀甲括弧/〈/〉;山括弧/《/》;二重山括弧/｛/｝;中括弧(brace)/「/」;鉤括弧/（/）;小括弧,丸括弧(parenthesis)/‘/’;singlequote/“/”;doublequote/『』/【】/［］/〔〕/〈〉/《》/｛｝/「」/（）/‘’/“”/
かっこう /格好/恰好;=格好/滑降/郭公/滑行;?/角行/割腔/
かっこうきょうぎ /滑降競技/
かっこうほう /滑腔砲/
かっこく /各国/
かっこくかん /各国間/
かっこくきょうかい /各国協会/
かっこくご /各国語/
かっこくせいふ /各国政府/
かっこくだいひょう /各国代表/
かっこくぼん /活刻本/
かっこげきは /各個撃破/
かっことじ /〉/》/】/
かっこない /括弧内/カッコ内/
かっこん /葛根/
かっこんとう /葛根湯/
かっさい /葛西;姓/喝采/
かっさつ /活殺/
かっさつじざい /活殺自在/
かっしき /喝食/
かっしゃ /活写/滑車/
かっしゃしんけい /滑車神経/
かっしょう /滑翔/
かっしょく /褐色/
かっしょくわいせい /褐色矮星;[天文]brown dwarf/
かっすい /渇水/活水/
かっすいき /渇水期/
かっすいじょしだい /活水女子大/
かっせい /活性/
かっせいか /活性化/
かっせいがた /活性型/
かっせいさんそ /活性酸素/
かっせいざい /活性剤/
かっせいそう /活性層/
かっせいたん /活性炭/
かっせいち /活性値/
かっせいちゅうしん /活性中心/
かっせいど /活性度/
かっせき /滑石/滑席/
かっせん /合戦/活線/割線/活栓/合戰;「戦」旧字/
かっせんそうばつ /活線挿抜/
かっそう /滑走/褐藻/割創/
かっそうか /滑走可/
かっそうかのう /滑走可能/
かっそうきょり /滑走距離/
かっそうきんし /滑走禁止/
かっそうしゃ /滑走者/
かっそうじかん /滑走時間/
かっそうせい /滑走性/
かっそうちゅう /滑走中/
かっそうにっすう /滑走日数/
かっそうふか /滑走不可/
かっそうめん /滑走面/
かっそうよう /滑走用/
かっそうろ /滑走路/
かった /勝田/刈田/
かったい /癩/乞丐/
かったぐん /刈田郡/
かったつ /闊達/豁達;≒闊達/
かったん /褐炭/
かっちゃく /活着/
かっちゅう /甲冑/
かっちゅうぎょ /甲冑魚/
かって /勝手/
かってきまま /勝手気儘/勝手気まま/
かってぐち /勝手口/
かってつけ /勝手付/
かってほうだい /勝手放題/
かってれん /勝手連/
かっとう /葛藤/
かっとわり /カット割り/
かっぱ /河童/合羽/喝破/川童;<rare> =河童/κ;kappa/Κ;Kappa/
かっぱき /河童忌;7／24/
かっぱつ /活発/活溌/
かっぱつか /活発化/
かっぱつはっち /活溌溌地/
かっぱばし /河童橋/合羽橋/
かっぱばん /合羽版/
かっぱまき /河童巻き;胡瓜の巻き寿司/河童巻/かっぱ巻き/カッパ巻き/
かっぱん /活版/
かっぱんいんさつ /活版印刷/
かっぱんずり /活版刷/
かっぱんびょう /褐斑病;[植物]/
かっぱんぼん /活版本/
かっぷ /割賦/∪;cup/
かっぷきん /割賦金/
かっぷく /恰幅/割腹/
かっぷはんばい /割賦販売/
かっぷめん /カップ麺/
かっぺい /勝平/
かっぽ /闊歩/濶歩/
かっぽう /割烹/活法/
かっぽうぎ /割烹着/
かっぽうてん /割烹店/
かっぽうりょうり /割烹料理/
かつ /喝/且つ/且/活;「-を入れる」/闊;闊達/濶;「闊」の異体字/括;一括/筈;はず/刮;刮目/聒;(かまびすしい)/蛞;蛞蝓/割;分割/轄;管轄/瞎;(かため)/豁;豁達/滑;滑走/猾;狡猾/磆/渇;渇望/葛;かずら/褐;褐色/曷;(なんぞ)/羯;羯鼓/蝎;蛇蝎/蠍;さそり/鞨;靺鞨/劼;(つつしむ)/黠/戛;(擬音語)/戞;「戛」の異体字/恰;恰幅/勝;(人名用)/捷;(人名用)/克;(人名用)/剋;(人名用)/∧;and/∩;and/
かつあい /割愛/
かつあき /克明/勝昭/勝章/
かつい /勝井;姓/
かついち /勝一/
かつうら /勝浦/
かつうらかん /勝浦間/
かつうらこう /勝浦港/
かつうらし /勝浦市/
かつえ /勝江/勝恵/
かつえき /滑液/
かつお /鰹/勝男/勝雄/勝夫/克夫/勝生/堅魚/松魚/
かつおうり /鰹売り/
かつおぎ /鰹木/堅魚木/
かつおだし /鰹出汁/
かつおどり /鰹鳥/
かつおぶし /鰹節/かつお節/
かつかいしゅう /勝海舟/
かつかざん /活火山/
かつかじゅう /活荷重/
かつかつ /戛戛/戛々/
かつかわ /勝川/
かつがん /活眼/
かつき /香月/勝木/克己/
かつきち /勝吉/
かつぎ /被/
かつぎや /担ぎ屋/
かつぎょ /活魚/
かつくら /勝倉/勝鞍/
かつげき /活劇/
かつこ /勝子/克子/
かつご /活語/
かつごう /渇仰/
かつさい /勝斉/
かつざい /滑剤/
かつし /克/勝志/且/克志/克史/
かつしか /葛飾/
かつしかく /葛飾区/
かつしかほくさい /葛飾北斎/
かつしま /勝島/
かつしろう /勝四郎/
かつしんたろう /勝新太郎/
かつじ /活字/勝治/勝次/功至/
かつじけい /活字系/
かつじたい /活字体/
かつじばなれ /活字離れ/
かつじばん /活字版/
かつじぶんか /活字文化/
かつじぼん /活字本/
かつじょう /割譲/
かつじょうほう /活情報/
かつじん /活人/
かつじんが /活人画/
かつぜつ /滑舌/活舌;≒滑舌/
かつぜん /豁然;開けた様子/戛然;硬い物のぶつかる音/
かつぞう /勝三/
かつた /勝田/
かつたし /勝田市/
かつたに /勝谷/
かつたろう /勝太郎/
かつだんそう /活断層/
かつて /嘗て/曾て/曽て;「曾」の異体字/
かつとし /勝利/勝敏/勝俊/克敏/克俊/克年/
かつどう /活動/
かつどういき /活動域/
かつどうか /活動家/活動化/
かつどうかいし /活動開始/
かつどうがいよう /活動概要/
かつどうきかん /活動期間/
かつどうきゅうし /活動休止/
かつどうきゅうしちゅう /活動休止中/
かつどうきょてん /活動拠点/
かつどうけいかく /活動計画/
かつどうけいひ /活動経費/
かつどうげん /活動源/
かつどうさいかい /活動再開/
かつどうさんか /活動参加/
かつどうしゃしん /活動写真/
かつどうしゅうにゅう /活動収入/
かつどうじょうきょう /活動状況/
かつどうたい /活動体/
かつどうちゅう /活動中/
かつどうていし /活動停止/
かつどうてき /活動的/
かつどうでんい /活動電位;[生物]action potential/
かつどうないよう /活動内容/
かつどうねんすう /活動年数/
かつどうはんい /活動範囲/
かつどうひ /活動費/
かつどうび /活動日/
かつどうほうこく /活動報告/
かつどうほうしん /活動方針/
かつどうほじょきん /活動補助金/
かつどうよてい /活動予定/
かつどうりょく /活動力/
かつどうれき /活動歴/
かつどん /カツ丼/
かつなり /勝成/
かつぬま /勝沼/
かつぬまちょう /勝沼町/
かつの /勝野/鹿角/
かつのぶ /克亘/
かつのり /勝則/克典/克則/勝典/
かつはた /勝畑/
かつば /活馬/
かつひこ /克彦/勝彦/捷彦/
かつひさ /勝久/克久/
かつひで /勝秀/
かつひと /克仁/
かつひら /勝平/
かつひろ /勝弘/克洋/勝広/勝浩/克弘/勝洋/勝宏/克博/克宏/克裕/勝寛/
かつふみ /克文/
かつぶし /鰹節/
かつぶつ /活仏/
かつべ /勝部/
かつべん /活弁/
かつぼう /渇望/
かつま /勝間/克馬/
かつまく /滑膜/
かつまさ /勝正/克正/
かつまた /且つ又/勝又/勝俣/勝間田/勝亦/勝股/
かつみ /克己/勝美/克巳/勝巳/勝己/克美/勝見/克実/香津美/
かつもく /刮目/割目/
かつもと /勝本/勝元/
かつや /克也/勝也/克哉/勝哉/勝谷/克弥/勝弥/
かつやく /活躍/括約/
かつやくきん /括約筋/
かつやくしだい /活躍次第/
かつやくちゅう /活躍中/
かつやくば /活躍馬/
かつやま /勝山/
かつやまこうえん /勝山公園/
かつやません /勝山線/
かつゆき /勝之/克之/克幸/克行/勝行/勝幸/勝征/
かつよう /活用/
かつようけい /活用形/
かつようご /活用語/
かつようごび /活用語尾/
かつようじゅ /闊葉樹/
かつようじゅつ /活用術/
かつようひょう /活用表/
かつようほう /活用法/
かつようれい /活用例/
かつようれんご /活用連語/
かつよし /勝義/克義/勝吉/克能/克善/
かつより /勝頼/
かつら /桂/鬘;wig/蘰;(髪飾り)/
かつらお /葛尾/
かつらか /カツラ科/Cercidiphyllaceae/
かつらかわ /桂川/
かつらがわ /桂川/
かつらぎ /葛城/桂木/
かつらぎさん /葛城山;地名/
かつらく /滑落/
かつらさんし /桂三枝/
かつらたろう /桂太郎/
かつらだ /桂田/
かつらのみや /桂宮/
かつらはま /桂浜/
かつらばやし /桂林/
かつらぶんちん /桂文珍/
かつらむき /桂剥き;大根の-/
かつらゆみ /桂由美/
かつらりきゅう /桂離宮/
かつりょく /活力/
かつりょくげん /活力源/
かつれい /割礼/
かつれき /活歴/
かつれん /勝連/
かつろ /活路/
かつろう /克朗/
かづき /香月/
かづけ /日付/
かづさ /加津佐/
かづさちょう /加津佐町/
かづの /鹿角/
かづみ /香津美/
かて /糧;食糧。「日々の-」/糅;(ご飯の混ぜ物)/粮;「糧」の異体字/
かてい /家庭/過程;process/課程;course.「教育-」/仮定/河底/下底/嘉禎;年号(1235-1238)/河堤/
かていい /家庭医/
かていか /家庭科/
かていかしつ /家庭科室/
かていかんきょう /家庭環境/
かていがい /家庭外/
かていがいれんあい /家庭外恋愛/
かていきょういく /家庭教育/
かていきょうし /家庭教師/
かていきょうしさき /家庭教師先/
かていけい /仮定形/
かていげき /家庭劇;home drama/
かていさいえん /家庭菜園/
かていさいばんしょ /家庭裁判所/
かていさいばんしょちょうさかん /家庭裁判所調査官/
かていしき /仮定式/
かていじじょう /家庭事情/
かていじょうきょう /家庭状況/
かていせいかつ /家庭生活/
かていそうぎ /家庭争議/
かていちょうさ /家庭調査/
かていつき /仮定付/
かていてき /家庭的/仮定的/
かていでんき /家庭電器/
かていとう /家庭等/
かていない /家庭内/
かていないふわ /家庭内不和/
かていないぼうりょく /家庭内暴力;domestic violence(DV)/
かていないりこん /家庭内離婚/
かていはいすい /家庭排水/
かていはかせ /課程博士/
かていぶ /仮定部/
かていほう /仮定法/
かていほうかい /家庭崩壊/
かていほうもん /家庭訪問/
かていむけ /家庭向け/
かていよう /家庭用/
かていようき /家庭用機/
かていようひん /家庭用品/
かていらん /家庭欄/
かていりょうり /家庭料理/
かてきおう /過適応/
かてつ /科哲/
かててくわえて /糅てて加えて/
かてん /加点/火点/
かてんほう /加点法/
かてんようそ /加点要素/
かでな /嘉手納/
かでん /家電/家伝;-の秘宝/荷電;charge.「-粒子」/架電/瓜田;「-に履を納れず」/訛伝/
かでんきょうやくへんかん /荷電共役変換/
かでんこうりてん /家電小売店/
かでんし /価電子/
かでんしょ /花伝書/
かでんしょうひん /家電商品/
かでんせいひん /家電製品/
かでんてん /家電店/
かでんひん /家電品/
かでんや /家電屋/
かでんよう /家電用/
かでんりゅう /過電流;overcurrent/渦電流;eddy current. =うずでんりゅう/
かでんりゅうし /荷電粒子/
かでんりょうはんてん /家電量販店/
かと /過渡;-期/加登;人名/過度;渡し場/蝌蚪;おたまじゃくし/科斗;=蝌蚪/
かとう /加藤/下等/果糖;[化学]fructose. C6H12O6/加糖;sweeten.「-練乳」/可撓/過当;excessive.「-競争」/花筒/寡頭;-政治(oligarchy)/河東/加東/加登/賀藤/裹頭;頭と顔を覆う。「-姿の弁慶」/
かとうきょうそう /過当競争/
かとうきょうそうじょうたい /過当競争状態/
かとうぎ /加藤木/
かとうしょくぶつ /下等植物/
かとうせい /寡頭制;oligarchy/
かとうせいぶつ /下等生物/
かとうともさぶろう /加藤友三郎/
かとうどうぶつ /下等動物/
かとうひろゆき /加藤弘之/
かとうぶし /河東節;[浄瑠璃]/
かとかい /過渡解/
かとき /過渡期/
かときち /加ト吉;[企業名]/
かとく /家督/嘉徳/稼得/
かとくそうぞく /家督相続/
かとくたい /科特隊/
かとてき /過渡的/
かととくせい /過渡特性/
かともじ /蝌蚪文字/
かともんじ /蝌蚪文字/
かとり /蚊取り/香取;人名/鹿取/
かとりじんぐう /香取神宮/
かとりせんこう /蚊取り線香/蚊取線香/
かとりなひこ /楫取魚彦;(1723-82) 国学者。『古言梯』/
かとりんかい /過渡臨界/
かとん /火遁/
かとんぼ /蚊蜻蛉/
かど /角/過度/門;笑う-/廉;盗みの-/過渡/加登/下土/火度/賀戸/柧/┘/┐/┌/└/
かどいけ /門池/
かどう /稼動/稼働;≒稼動/可動;mobile/華道/歌道/渦動/火道/火動;腎虚/可導/
かどうかん /仮導管/
かどうきょう /可動橋/架道橋;立体交差/
かどうけい /稼動系/
かどうしき /可動式/
かどうじかん /稼働時間/
かどうじょうきょう /稼働状況/
かどうせい /可動性/可導性/
かどうぜき /可動堰/
かどうそう /稼働相/稼動相/
かどうちゅう /稼働中/
かどうぶ /可動部/華道部/
かどうぶぶん /可動部分/
かどうまじきり /可動間仕切り;[建築]movable partition/
かどうりつ /稼働率/
かどおか /角岡/
かどかど /廉々/
かどかり /下土狩/
かどかわ /角川/角革/
かどかわえいが /角川映画/
かどかわしょてん /角川書店/
かどかわはるき /角川春樹/
かどかわばん /角川版/
かどかわぶんこ /角川文庫/
かどかわぶんこばん /角川文庫版/
かどがき /門垣/
かどがまえ /門構え/
かどがわ /門川/
かどく /可読/
かどくか /可読化/
かどくせい /可読性/
かどくら /門倉/
かどぐち /門口/
かどさき /門崎/
かどさわ /門澤/
かどた /門田/角田/
かどち /角地/
かどちがい /門違い/
かどづけ /門付/門付け/
かどてき /過度的/
かどで /門出/
かどなか /門仲/
かどなが /門長/
かどの /門野/
かどばしら /門柱/
かどばやし /門林/
かどばん /カド番/角番;-を脱する/
かどび /門火/
かどふだ /門札/
かどべ /門部;[律令制]/門辺/
かどべや /角部屋/
かどま /門真/
かどまし /門真市/
かどまつ /門松/角松/
かどみうむ /Cd/Cadmium/
かどみせ /角店/
かどや /角屋/門屋/
かどわき /門脇/
かな /仮名/哉/金/加奈/佳奈/香奈/華奈/華菜/假名/
かなあしのう /金足農/
かなあみ /金網/
かない /家内/課内/科内/金井/
かないあんぜん /家内安全/
かないかいぎ /課内会議/
かないけ /金池/
かないこうぎょう /家内工業/
かないし /金石/
かないろ /金色/
かないろうどう /家内労働/
かなう /叶/
かなえ /鼎/香苗/鬲;≒鼎/彝;?/彜;「彝」の異体字,?/
かなおか /金岡/
かなかな /蜩/
かなかん /かな漢/仮名漢/
かなかんじ /かな漢字/仮名漢字/
かなかんじへんかん /かな漢字変換/仮名漢字変換/
かながき /仮名書き/カナ書き/金垣/
かながきろぶん /仮名垣魯文;作家(1829-94),『安愚楽鍋』/
かながた /金型/
かながわ /神奈川/金川/
かながわえき /神奈川駅/
かながわく /神奈川区/
かながわけん /神奈川県/
かながわけんけい /神奈川県警/
かながわけんげんてい /神奈川県限定/
かながわけんじん /神奈川県人/
かながわけんとうぶ /神奈川県東部/
かながわけんない /神奈川県内/
かながわけんみん /神奈川県民/
かながわしんぶん /神奈川新聞/
かながわしんまち /神奈川新町/
かながわせんしゅけん /神奈川選手権/
かながわだい /神奈川大/
かながわだいがく /神奈川大学/
かながわちいき /神奈川地域/
かながわちほう /神奈川地方/
かながわほうしき /神奈川方式/
かながわほうめん /神奈川方面/
かなきりごえ /金切り声/
かなぎ /金城/金木/
かなくぎ /金釘/
かなくぎりゅう /金釘流/
かなくず /金屑/
かなくそ /金屎/
かなぐ /金具/
かなぐさり /金鎖/
かなぐし /金串/
かなぐつき /金具付き/
かなけ /鉄気/金気;「鉄気」とも。/
かなこ /加奈子/可奈子/佳奈子/香奈子/佳那子/嘉奈子/称子/
かなさき /金崎/
かなさし /金指/
かなざき /加奈崎/
かなざわ /金沢/金澤/
かなざわえき /金沢駅/
かなざわかん /金沢間/
かなざわく /金沢区/
かなざわこうぎょうだいがく /金沢工業大学/
かなざわこうだい /金沢工大/
かなざわこくぜいきょく /金沢国税局/
かなざわし /金沢市/
かなざわしぜんこうえん /金沢自然公園/
かなざわしない /金沢市内/
かなざわだい /金沢大/
かなざわだいがく /金沢大学/
かなざわだいり /金沢大理/
かなざわはっけい /金沢八景/
かなざわぶんこ /金沢文庫/
かなざわべん /金沢弁/
かなざわほうめん /金沢方面/
かなしき /金敷/鉄敷/
かなしばり /金縛り/
かなしま /金島/
かなしみ /悲しみ/哀しみ/愛しみ;愛惜/
かなじょ /仮名序/
かなぞうし /仮名草子/
かなた /彼方/華薙刀/
かなたに /金谷/
かなだ /加奈陀;Canada/金田/片田/
かなだこく /カナダ国/
かなださん /カナダ産/
かなだじん /カナダ人/
かなだらい /金盥/
かなちゅう /神奈中/
かなつじ /金辻/
かなつぼ /金壺/
かなつぼまなこ /金壺眼/
かなづ /金津/
かなづかい /仮名遣い/
かなづち /金槌/金鎚/鉄鎚/
かなてこ /鉄梃/
かなで /金出/奏で/
かなでほん /仮名手本/
かなでほんちゅうしんぐら /仮名手本忠臣蔵/
かなとこ /金床/鉄床/
かなとこぐも /鉄床雲/
かなにゅうりょく /仮名入力/
かなばち /金鉢/
かなばん /金版/
かなひょうき /仮名表記/
かなぶつ /金仏/
かなへび /金蛇;(トカゲ)lacertid/蛇舅母;=金蛇/
かなへんかん /仮名変換/
かなほうご /仮名法語/
かなぼう /金棒/鉄棒;NB:「てつぼう」と同形/
かなぼうひき /金棒引き;噂をやたら広げる奴/
かなぼん /仮名本/
かなまじり /仮名交じり/かな混じり/かな交じり/仮名混じり/
かなまち /金町/
かなまちせん /金町線/
かなまり /鋺/
かなまる /金丸/
かなまるしん /金丸信/
かなみつ /金光/
かなむら /金村/
かなめ /要/
かなめいし /要石/
かなめちょう /要町/
かなもじ /仮名文字/
かなもと /金本/
かなもの /金物/
かなものてん /金物店/
かなものや /金物屋/
かなもり /金森/
かなや /金谷/金屋/
かなやえき /金谷駅/
かなやま /金山/
かなやまえき /金山駅/
かなやまちょう /金山町/
かなやまばし /金山橋/
かならず /必ず/必らず;※非正則/
かならずしも /必ずしも/
かならずや /必ずや/
かなり /可成/金成/
かなりあいろ /カナリア色;canary/
かなわ /鉄輪/
かなん /河南/華南/火難/伽南/
かに /蟹/可児/蠏/
かにあるき /カニ歩き/
かにえ /蟹江/
かにえじょう /蟹江城/
かにく /果肉/
かにくそ /蟹屎/
かにこうせん /蟹工船/
かにざ /蟹座;Cancer(Cnc),(6.21-7.22)/
かにせいうん /蟹星雲/
かにた /蟹田/
かにたま /蟹玉/かに玉/
かにばさみ /蟹挟み/
かにみそ /蟹味噌/
かにもじ /蟹文字/
かにゅう /加入/
かにゅうきぼう /加入希望/
かにゅうきん /加入金/
かにゅうけん /加入権/
かにゅうしゃ /加入者/
かにゅうしゃばんごう /加入者番号/
かにゅうしゃめい /加入者名/
かにゅうぼしゅう /加入募集/
かにゅうまえ /加入前/
かにゅうりつ /加入率/
かにゅうりょう /加入料/
かにゅうりょく /過入力/
かにゅうれい /加入例/
かにわ /樺/
かぬき /香貫/
かぬま /鹿沼/
かぬまつち /鹿沼土/
かね /金/鐘;bell.「-が鳴る」/鉦;gong.「-や太鼓」/兼/鉄漿;おはぐろ/
かねあい /兼ね合い/兼合い/兼合/
かねあまり /金余り/
かねいがい /金以外/
かねいし /金石/
かねいそ /金磯/
かねおか /金岡/兼岡/
かねかし /金貸し/金貸/
かねかんじょう /金勘定/
かねがさき /金ヶ崎/
かねがね /予々;前々から/予予/兼ね兼ね;=予々/
かねがふち /鐘淵/
かねきち /兼吉/
かねきよ /兼清/
かねくいむし /金食い虫/
かねぐら /金蔵/
かねぐり /金繰り/
かねこ /金子/兼子/金児/
かねごえ /金肥/
かねざき /金崎/鐘崎/
かねざわ /金沢/
かねしげ /金重/
かねしたけんせつ /金下建設;[企業名]/
かねしだい /金次第/
かねしま /金嶋/
かねしろちょう /金城町/
かねじゃく /曲尺/矩尺/
かねずく /金ずく/金尽く/
かねぞう /兼蔵/
かねた /金田/兼太/
かねたか /兼貴/
かねたに /金谷/
かねだ /金田/
かねだか /金高/
かねつ /加熱;heat.「-調理」/過熱;overheat.「ブームの-」/金津/火熱/
かねつおんど /加熱温度/
かねつご /加熱後/
かねつさっきん /加熱殺菌/
かねつじかん /加熱時間/
かねつせいざい /加熱製剤/
かねつそうち /加熱装置/
かねつちょうり /加熱調理/
かねつへんけい /加熱変形/
かねつほう /加熱法/
かねつよう /加熱用/
かねつろ /加熱炉/
かねづか /金塚/
かねづかい /金遣い/金使い/
かねづまり /金詰まり/金詰り/
かねづる /金蔓/金づる/
かねて /予て/
かねと /兼人/
かねなし /金無し/
かねなり /金成/
かねはた /金畑/
かねはま /金浜/
かねはら /金原/
かねばこ /金箱/
かねばなれ /金離れ/
かねひさ /金久/
かねひと /兼人/
かねへん /金偏/
かねぼう /鐘紡/
かねまき /金巻/鐘巻/
かねまち /金町/
かねまつ /兼松/
かねまつごうしょう /兼松江商/
かねまる /金丸/
かねまわり /金回り/
かねみつ /金光/
かねみゆしょう /カネミ油症;PCB中毒/
かねめ /金目/
かねめあて /金目当て/
かねもうけ /金儲け/
かねもち /金持ち/
かねもと /金本/兼元/金元/
かねもり /兼森/
かねや /金谷/
かねやま /金山/兼山/
かねらか /カネラ科/Canellaceae/
かねん /可燃/ヶ年/
かねんせい /可燃性/
かねんせいがす /可燃性ガス/
かねんど /過年度/
かねんどししゅつ /過年度支出/
かねんどしゅうにゅう /過年度収入/
かねんぶつ /可燃物/
かの /彼の/狩野/鹿野/彼/
かの> /彼の/彼/
かのあし /鹿足/
かのい /鹿井/
かのう /可能/化膿/加納/狩野/嘉納/加能/叶/
かのうえいとく /狩野永徳/
かのうざん /鹿野山/
かのうじごろう /嘉納治五郎/
かのうせい /可能性/
かのうせいけんとう /可能性検討/
かのうせいだい /可能性大/
かのうせかい /可能世界/
かのうたい /可能態/
かのうてき /可能的/
かのうどうし /可能動詞/
かのうは /狩野派/
かのうひょうげん /可能表現/
かのえ /庚;[十干]7/
かのえいぬ /庚戌/
かのえうま /庚午/
かのえさる /庚申/
かのえたつ /庚辰/
かのえとら /庚寅/
かのえね /庚子/
かのこ /鹿の子/
かのこうお /鹿の子魚/
かのこしぼり /鹿の子絞り/
かのこそう /鹿の子草/
かのこもち /鹿の子餅/
かのしし /鹿/
かのじょ /彼女/
かのじょじしん /彼女自身/
かのじょたち /彼女達/
かのじょひとり /彼女一人/
かのじょら /彼女等/
かのせ /鹿瀬/
かのと /辛;[十干]8/
かのとい /辛亥/
かのとう /辛卯/
かのとうし /辛丑/
かのととり /辛酉/
かのとひつじ /辛未/
かのとみ /辛巳/
かのや /鹿屋/
かのんほう /カノン砲;cannon/
かはい /加配/
かはいじく /下胚軸/
かはいらん /過排卵/
かはく /仮泊/下膊/下拍;[音楽]downbeat/
かはつ /仮髪/
かはらい /過払い/
かはん /河畔/過半/下半/可搬;portable/過般;さきごろ/
かはんがた /可搬型/
かはんしき /可搬式/
かはんしん /下半身/
かはんしんふずい /下半身不随/
かはんすう /過半数/
かはんすうぎけつ /過半数議決/
かはんせい /可搬性/
かはんぶ /下半部/
かば /樺;birch.「-の木」/蒲;cattail.「-の穂」/河馬/椛;赤黄色/
かばいだて /庇い立て/
かばいて /庇い手;[相撲]/
かばいろ /樺色;赤黄色/蒲色;=樺色/
かばさん /加波山/
かばしま /樺嶋/
かばしら /蚊柱/
かばた /椛田;姓/
かばつ /可罰/
かばと /樺戸/
かばね /屍/姓/
かばねがき /姓書/
かばのき /樺の木;[植物]birch/
かばのり /樺海苔/
かばやき /蒲焼/蒲焼き/
かばやま /樺山/
かばらい /過払い/
かばん /鞄/花盤/
かばんご /鞄語/
かばんじょう /花盤状/
かばんもち /鞄持ち/
かひ /可否/歌碑/果皮/花被;[植物]perianth/痂皮;かさぶた/化肥;[略語]化学肥料/下婢;はしため/下皮;hypodermis/下肥;しもごえ?/下卑;?/
かひつ /加筆/
かひつしゅうせい /加筆修正/
かひつていせい /加筆訂正/
かひどうすう /可否同数/
かひはんだん /可否判断/
かひへん /花被片/
かひょう /下表/華表;鳥居/苛評/
かひん /佳品/河浜/
かび /華美/黴/
かびどく /黴毒/
かびぶん /可微分/
かびょう /歌病;=うたのやまい/
かびん /花瓶/過敏/
かびんしょう /過敏症;[医]光線-,知覚-,化学物質-/
かびんせい /過敏性/
かびんせいだいちょうしょうこうぐん /過敏性大腸症候群/
かふ /寡婦/下付/家譜/寡夫;おとこやもめ/家父/花布/家扶/
かふう /家風/荷風;人名,永井-/歌風;よみぶり/下風/
かふか /過負荷/可不可/
かふきゅう /過不及/
かふく /下腹/禍福/
かふくぶ /下腹部/
かふそく /過不足/
かふちょう /家父長/
かふちょうけん /家父長権/
かふちょうせい /家父長制/
かふちょうせいど /家父長制度/
かふねんきん /寡婦年金;国民年金/
かふん /花粉/
かふんしょう /花粉症/
かぶ /株/下部/蕪/歌舞/(株)/（株）/
かぶおんぎょく /歌舞音曲/
かぶか /株価/
かぶかこうとう /株価高騰/
かぶかしすう /株価指数/
かぶかしゅうえきりつ /株価収益率/
かぶかじゅんしさんばいりつ /株価純資産倍率/
かぶかへんどう /株価変動/
かぶき /歌舞伎/冠木/
かぶきおんがく /歌舞伎音楽/
かぶきかい /歌舞伎会/
かぶきこうえん /歌舞伎公演/
かぶきざ /歌舞伎座/
かぶきちょう /歌舞伎町/
かぶきもの /歌舞伎者/
かぶけん /株券/
かぶこうぞう /下部構造/
かぶしき /株式/
かぶしきいてん /株式移転/
かぶしきか /株式化/
かぶしきかいしゃ /株式会社/
かぶしきがいしゃ /株式会社/株式會社;「会」旧字/(株)/
かぶしきがいしゃがっこう /株式会社学校/
かぶしきがいしゃすずか /株式会社鈴鹿/
かぶしきがいしゃとうしば /株式会社東芝/
かぶしきこうかい /株式公開/
かぶしきこうかん /株式交換/
かぶしきしきょう /株式市況/
かぶしきしじょう /株式市場/
かぶしきしょうきゃく /株式消却/
かぶしきじょうとえきかぜい /株式譲渡益課税/
かぶしきすう /株式数/
かぶしきそうすう /株式総数/
かぶしきそうば /株式相場/
かぶしきとうし /株式投資/
かぶしきとりひきじょ /株式取引所/
かぶしきはいとう /株式配当/
かぶしきぶんかつ /株式分割/
かぶしきもちあい /株式持合/
かぶせ /被せ/
かぶそく /過不足/
かぶそしき /下部組織/
かぶだか /株高/
かぶだち /株立ち/
かぶだん /歌舞団/
かぶつ /果物/
かぶと /兜/甲/加太/
かぶとうお /兜魚/
かぶとえび /兜海老/
かぶとがに /兜蟹;horseshoe crab/
かぶとちょう /兜町/
かぶとに /兜煮;鯛の-/
かぶとのお /兜の緒/
かぶとむし /甲虫/兜虫/
かぶとやき /兜焼き/
かぶとやま /甲山/
かぶなかま /株仲間/
かぶぬし /株主/
かぶぬしけん /株主権/
かぶぬししほん /株主資本/
かぶぬししほんひりつ /株主資本比率;株主資本÷総資産/
かぶぬししほんりえきりつ /株主資本利益率;ROE (return on equity)/
かぶぬしそうかい /株主総会/
かぶぬしだいひょうそしょう /株主代表訴訟/
かぶぬしゆうたい /株主優待/
かぶぬしゆうたいけん /株主優待券/
かぶぬしわりあて /株主割当/
かぶばいきゃく /株売却/
かぶま /株間/
かぶや /株屋/
かぶやす /株安/
かぶら /蕪;radish/鏑;鏑矢/
かぶらき /鏑木;姓/
かぶらぎ /鏑木/
かぶり /頭/
かぶりつき /齧り付き/
かぶりもの /被り物/
かぶれ /気触れ/
かぶれんじょう /歌舞練場/
かぶろ /禿/
かぶわけ /株分け/
かぶん /過分;excessive.「-のお褒めに与る」/寡聞;「-にして知らない」/可分;divisible/
かぶんさいむ /可分債務/
かぶんすう /仮分数/
かぷせるか /カプセル化/
かへい /貨幣/花柄/加平/寡兵/歌病;=うたのやまい/貨弊;?/
かへいかち /貨幣価値/
かへいけいざい /貨幣経済;monetary economy/
かへいしゃかい /貨幣社会/
かへいた /嘉平太/
かへえ /嘉兵衛/
かへん /可変/下辺/河辺/花片/カ変;カ行変格活用(来る)/佳編/佳篇/
かへんこ /可変個/
かへんご /可変語/
かへんしき /可変式/
かへんしほん /可変資本/
かへんそく /可変速/
かへんそくくどう /可変速駆動/
かへんちょう /可変長/
かへんていこう /可変抵抗/
かへんてき /可変的/
かへんはば /可変幅/
かべ /壁/可部/
かべあつ /壁厚/
かべいた /壁板/
かべいちめん /壁一面/
かべかけ /壁掛け/壁掛/
かべかけしき /壁掛け式/
かべがみ /壁紙/
かべがわ /壁側/
かべぎわ /壁際/
かべぎわしき /壁際式/
かべこうぞう /壁構造;[建築](柱によらず)壁が構造を担う。RC造など/
かべごし /壁越し/
かべざい /壁材/
かべしき /壁式/
かべしたじ /壁下地/
かべしろ /壁代/
かべしんぶん /壁新聞/
かべせん /可部線/
かべつち /壁土/
かべどこ /壁床/
かべぬり /壁塗り;左官/
かべもと /河部本/
かべよう /壁用/
かべりょう /壁量;[建築]wall quantity/
かべん /花弁/
かほ /花圃/花穂;名/嘉穂/果歩/香穂;名/
かほう /下方/家宝/加法/果報/火砲/家法/嘉保;年号(1094-1096)/加俸/過褒/苛法/
かほうこう /下方向/
かほうしゅうせい /下方修正/
かほうせい /加法性/
かほうちかん /下方置換;水に溶けやすく空気より重い気体の収集法/
かほうていり /加法定理/
かほうてき /加法的/
かほうでん /過放電/
かほうもの /果報者/
かほうわ /過飽和/
かほく /河北/華北/鹿北/香北/可北;?/
かほくしょう /河北省/
かほくしんぽう /河北新報/
かほくじん /華北人/
かほくちほう /華北地方/
かほご /過保護/
かほど /斯程/
かほり /佳保里/
かぼう /苛暴/
かぼく /花木;花樹/下木;bush/佳木/嘉木;=佳木/家僕/華墨;お手紙/
かぼちゃ /南瓜/
かぽじにくしゅ /カポジ肉腫;HIV/
かま /釜;湯を沸かす容器/鎌;草などを切る刃物/窯;器などを焼く設備/竈;煮炊きの設備(かまど)/缶;boiler/蒲;がま/竃;「竈」の異体字/釡;「釜」の異体字/窰;「窯」の異体字/罐;「缶」の旧字/
かまあげ /釜揚げ;うどん/
かまあと /窯跡/
かまい /釜井/
かまいし /釜石/
かまいたち /鎌鼬/
かまいり /釜煎り/
かまえ /構え/蒲江/釜江/鎌江/
かまがさき /釜ケ崎/
かまがた /鎌形/
かまがや /鎌ヶ谷/鎌谷/
かまがやし /鎌ヶ谷市/
かまがり /蒲刈/
かまきり /蟷螂/螳螂/鎌切/杜父魚/
かまくび /鎌首/
かまくら /鎌倉/
かまくらえき /鎌倉駅/
かまくらかいどう /鎌倉街道/
かまくらがくえんこうこう /鎌倉学園高校/
かまくらくぼう /鎌倉公方/
かまくらげんじ /鎌倉源氏/
かまくらこ /鎌倉湖/
かまくらし /鎌倉市/
かまくらじだい /鎌倉時代/
かまくらどの /鎌倉殿/
かまくらばくふ /鎌倉幕府/
かまくらぶし /鎌倉武士/
かまくらぼり /鎌倉彫/
かまくらやま /鎌倉山/
かまし /釜師/
かまじゅうもんじ /鎌十文字/
かまじるし /窯印/
かます /叺/梭子魚/梭魚/
かまた /鎌田/蒲田;地名,大田区/
かまたえき /蒲田駅/
かまたがわ /蒲田側/
かまたき /釜炊き;-ごはん/缶焚き;boilerman/
かまたこうしんきょく /蒲田行進曲/
かまたじょし /蒲田女子/
かまたせん /蒲田線/
かまたほうめん /蒲田方面/
かまたり /鎌足/
かまだ /鎌田/
かまだし /窯出し/
かまち /框/蒲池;†(いけ) 人名/蒲地;†(じめん) 人名/
かまとと /蒲魚/
かまとり /鎌取/
かまど /竃;異体字/竈/
かまどがみ /竈神;奥津日子命と奥津比売命/
かまはら /鎌原/
かまば /窯場/
かまふさ /釜房/
かまべ /鎌部/
かまぼこ /蒲鉾/
かまぼこや /蒲鉾屋/
かまめ /鴎/
かまめし /釜飯/
かまもと /窯元/釜本/鎌本/
かまやり /鎌槍/
かまゆで /釜茹で;五右衛門/
かまわぬ /鎌輪奴/
かみ /神/紙/髪/加味/上/守/佳味/加美;人名/香美/可美/祇/帋/髮;「髪」の旧字(人名用漢字)/長官;[律令制]/督/
かみ> /上;上一段,上御所,上台所/
かみあげ /髪上げ/
かみあぶら /髪油/
かみあらい /髪洗い/
かみありづき /神在月;陰暦十月/
かみあわせ /噛み合わせ/噛み合せ/
かみい /神居/
かみいいざか /上飯坂/
かみいいだ /上飯田/
かみいけだい /上池台/
かみいしづ /上石津/
かみいしはら /上石原/
かみいずみ /上泉/神泉/
かみいそ /上磯/
かみいた /上板/
かみいち /上市/上一/
かみいちだん /上一段/
かみいちだんかつよう /上一段活用/
かみいな /上伊那/
かみいれ /紙入れ/
かみいろ /髪色/
かみうけな /上浮穴/
かみうま /上馬/
かみうら /上浦/
かみえしゅう /上江洲/
かみお /神尾/
かみおおおか /上大岡/
かみおか /神岡/上岡/
かみおかりゅうたろう /上岡龍太郎/
かみおだいえき /上小田井駅/
かみおぼろ /上尾幌/
かみおむつ /紙オムツ/
かみおろし /神降ろし/
かみかくし /神隠し/神隠/
かみかざり /髪飾り/
かみかせだ /上加世田/
かみかぜ /神風/
かみかたち /髪形/
かみかつ /上勝/
かみかやく /紙火薬/
かみかわ /上川/神川/
かみかわち /上河内/
かみかんむり /髪冠;[部首](髟)/
かみがかり /神懸かり/神懸り/神憑り/神がかり/神懸/神憑/
かみがき /神垣/
かみがしら /髪頭;[部首](髟)/
かみがた /髪型/上方/髪形;=髪型／=かみかたち/紙型/
かみがたえ /上方絵/
かみがたげいのう /上方芸能/
かみがたご /上方語/
かみがたらくご /上方落語/
かみがみ /神々/
かみがもじんじゃ /上賀茂神社/
かみがや /神ケ谷/
かみき /上期/
かみきず /噛み傷/咬み傷/
かみきた /上北/
かみきたざわ /上北沢/
かみきたやま /上北山/
かみきょうく /上京区/
かみきり /髪切り/
かみきりむし /天牛/髪切虫/
かみきれ /紙切れ/紙切/
かみぎし /神岸;姓/
かみぎょう /上京/
かみぎれ /紙切れ/
かみぎわ /髪際;生え際/
かみくいしき /上九一色/
かみくいしきむら /上九一色村/
かみくず /紙屑/紙くず/
かみくずどうぜん /紙屑同然/
かみくち /神口/
かみくぼ /上窪;姓/
かみくまもとえきまえ /上熊本駅前/
かみぐち /上口/
かみぐみ /上組/
かみけーす /紙ケース/
かみこ /神子/紙衣/紙子/
かみこうす /上口洲/
かみこうち /上高地/
かみこしき /上甑/
かみこっぷ /紙コップ/
かみこま /上駒;三味線のコマ/
かみこんしき /紙婚式;1周年/
かみごうり /上郡/
かみごおり /上郡/
かみごとう /上五島/
かみさいばら /上斉原/
かみさかえまち /上栄町/
かみさと /上里/上郷/
かみさま /神様/上様/神さま/
かみさん /上さん/カミさん/
かみさんごう /上参郷/
かみざ /上座/
かみざき /神崎/
かみざら /紙皿/
かみざわ /上澤/
かみしつ /紙質/髪質/
かみしばい /紙芝居/
かみしばいてき /紙芝居的/
かみしひ /上志比/
かみしほうがため /上四方固め/
かみしほろ /上士幌/
かみしま /上島/
かみしも /上下/裃/
かみしゃちょう /神社長/
かみしろ /神代/神城/上代/
かみしろえき /神城駅/
かみじま /上島/神島/
かみじゃけ /紙ジャケ/
かみじゃけっと /紙ジャケット/
かみじゅうじょう /上十条/
かみじょう /上條/上条/神城/
かみす /神栖/
かみすき /紙漉き/
かみすぎ /上杉/
かみすながわ /上砂川/
かみすわ /上諏訪/
かみすわえき /上諏訪駅/
かみずもう /紙相撲/
かみずる /上水流/
かみせい /紙製/
かみせいひん /紙製品/
かみせっけん /紙石鹸/
かみぜに /紙銭/
かみそうやぎ /上草柳/
かみそり /剃刀/
かみそりまけ /剃刀負け/
かみた /上田/神田/
かみたいせん /神大戦/
かみたいら /上平/
かみたかい /上高井/
かみたから /上宝/
かみたばこ /噛みタバコ/
かみだい /紙代/
かみだな /神棚/
かみだのみ /神頼み/
かみつ /過密/花蜜/上津;地名/
かみつか /神塚/
かみつかさ /上司/
かみつが /上都賀/
かみつしま /上対馬/
かみつせん /花蜜腺/
かみつな /上綱/
かみつふさ /上総;かずさ/
かみつぶて /紙礫/
かみつるま /上鶴間/
かみつれか /カミツレ花/
かみづか /神塚/
かみづかさ /主神/
かみづつみ /紙包み;paper wrapping/
かみづまり /紙詰まり/
かみづる /上水流/
かみて /上手/
かみてーぷ /紙テープ/
かみで /上出/
かみでっぽう /紙鉄砲/
かみとばぐち /上鳥羽口/
かみとり /神取/
かみとんだ /上富田/
かみどめ /髪留め/
かみなか /上中/上那賀/
かみなが /髪長/神永/神長/
かみなづき /神無月;陰暦12月/
かみなべ /神鍋/
かみなり /雷/
かみなりうお /雷魚/
かみなりおやじ /雷親父/
かみなりぐも /雷雲/
かみなりさま /雷様/
かみなりちゅういほう /雷注意報/
かみなりもん /雷門/
かみに /上二/
かみにいかわ /上新川/
かみにいかわぐん /上新川郡/
かみにし /上西/
かみにだん /上二段/
かみにだんかつよう /上二段活用/
かみにんぎょう /紙人形/
かみぬま /上沼/
かみねんど /紙粘土/
かみのかわ /上三川/
かみのく /上の句/
かみのくに /上ノ国/
かみのけ /髪の毛/
かみのけざ /髪座;Coma Berenices(Com)/
かみのげ /上野毛/
かみのこ /神の子/
かみのせき /上関/
かみのほ /上之保/
かみのみや /上の宮/
かみのやま /上山/
かみはやし /神林/
かみはら /神原/
かみはんき /上半期/
かみばいたい /紙媒体/
かみばこ /紙箱/
かみばやし /上林/
かみばり /紙張り/紙貼り/
かみぱっく /紙パック/
かみぱるぷ /紙パルプ/
かみひこうき /紙飛行機/
かみひとえ /紙一重/
かみふうせん /紙風船/紙ふうせん/
かみふくおか /上福岡/
かみふぶき /紙吹雪/
かみふらの /上富良野/
かみぶくろ /紙袋/
かみぶた /紙蓋/
かみぶんしょ /紙文書/
かみへい /上閉伊/
かみほとけ /神仏/
かみまい /神舞/
かみまえづ /上前津/
かみまき /紙巻/紙巻き/
かみまち /上町/
かみみず /上水/
かみみぞ /上溝/
かみみね /上峰/
かみむ /上無/
かみむかえ /神迎え/
かみむら /上村/神村/
かみもと /神本/
かみもの /神物/
かみや /神谷/紙屋/上谷/神屋/
かみやいん /紙屋院/
かみやがみ /紙屋紙/
かみやく /上屋久/
かみやしき /上屋敷/
かみやしろ /上社/
かみやすり /紙鑢/
かみやちょう /紙屋町/神谷町/
かみやどり /神宿り/
かみやま /神山/上山/
かみやまだ /上山田/
かみやまだせん /上山田線/
かみゆい /髪結い/髪結;-の亭主/
かみゆいどこ /髪結い床/髪結床/
かみゆうべつ /上湧別/
かみよ /神代/神余/神世/
かみら /韮/
かみわざ /神事/神業/神技/
かみわざてき /神技的/
かみん /仮眠/夏眠/
かみんきゅうけい /仮眠休憩/
かみんしつ /仮眠室/
かみんじょ /仮眠所/
かみんちゅ /神人/
かみんちゅう /仮眠中/
かむ /家務/
かむい /神居/
かむいこたん /神居古潭;地名,/
かむくら /神座/
かむだち /麹/
かむながら /随神/
かむら /嘉村/
かむり /冠/
かむろ /禿/
かむわざ /神事/
かめ /亀/瓶/甕/日目/龜/
かめあり /亀有/
かめい /加盟/仮名/科名;[生物]family name/家名/課名/下名/下命/亀井;人名/
かめいがいしゃ /加盟会社/
かめいきじゅん /加盟基準/
かめいこく /加盟国/
かめいし /亀石/
かめいしんせい /加盟申請/
かめいちょう /亀井町/
かめいてん /加盟店/
かめいど /亀戸/
かめいの /亀井野/
かめいりょう /加盟料/
かめうら /亀卜/
かめお /亀夫/
かめおか /亀岡/
かめかん /甕棺/
かめがた /亀型/
かめきち /亀吉/
かめさき /亀崎/
かめじま /亀島/
かめじろう /亀次郎/
かめたろう /亀太郎/
かめだ /亀田/
かめの /亀野/
かめのこ /亀の子;-タワシ/
かめのこう /亀の甲/
かめのすけ /亀之助/
かめぶし /亀節;小型の鰹で作った亀の甲型の鰹節。⇔本節/
かめまん /亀萬/
かめむし /亀虫/
かめや /亀屋/亀谷/
かめやま /亀山/
かめやまかん /亀山間/
かめやまこ /亀山湖/
かめやまてんのう /亀山天皇/
かめやまんねんどう /亀屋万年堂/
かめらめせん /カメラ目線/
かめれおんざ /カメレオン座;Chamaeleon(Cha)/
かめん /仮面/下面/
かめんうつびょう /仮面鬱病/
かめんげき /仮面劇/
かめんこうけつあつ /仮面高血圧/
かめんふうふ /仮面夫婦/
かめんぶとうかい /仮面舞踏会/
かめんろうにん /仮面浪人/
かも /鴨/加茂/賀茂/鳧/鳬/
かもい /鴨居/神威/鴨井/
かもいけ /鴨池/
かもう /蒲生/
かもうり /氈瓜/
かもえ /鴨江/
かもえない /神恵内/
かもがた /鴨方/
かもがわ /鴨川/賀茂川/
かもく /科目/寡黙/課目;†課せられた科目/
かもくきん /火木金/
かもくすう /科目数/
かもくとうりしゅうせい /科目等履修生/
かもくど /火木土/
かもくべつ /科目別/
かもくめい /科目名/
かもぐつ /鴨沓;蹴鞠用の靴/
かもしか /羚羊/
かもした /鴨下/
かもしだ /鴨志田/
かもじ /髢/母文字/髪文字/
かもじま /鴨島/
かもだ /加守田/
かもつ /貨物/
かもつうんそう /貨物運送/
かもつうんちん /貨物運賃/
かもつえき /貨物駅/
かもつしつ /貨物室/
かもつしゃ /貨物車/
かもつしゃりょう /貨物車両/
かもつじこくひょう /貨物時刻表/
かもつじどうしゃ /貨物自動車/
かもつせん /貨物船/貨物線/
かもつせんようせん /貨物専用線/
かもつでんしゃ /貨物電車/
かもつひきかえしょう /貨物引換証/
かもつびん /貨物便/
かもつゆそう /貨物輸送/
かもつよう /貨物用/
かもつる /賀茂鶴/
かもつれっしゃ /貨物列車/
かもづる /賀茂鶴/
かもと /鹿本/
かもなくふかもなく /可もなく不可もなく/
かもなべ /鴨鍋/
かもなんばん /鴨南蛮;[料理]/
かもにく /鴨肉/
かもねぎ /鴨葱/
かものちょうめい /鴨長明/
かものまぶち /賀茂真淵/
かものみや /鴨宮/
かもみや /鴨宮/
かもめ /鴎/
かもり /掃部/
かもん /家紋/嘉門/厦門/花紋/家門/下問/渦紋/
かもんのかみ /掃部頭/
かや /蚊帳/萱/茅/榧/伽耶;任那/加悦/栢/加耶/
かやく /火薬/化薬;化学薬品/課役/加薬;「うどんの-」/可約/
かやくき /可約基/
かやくこ /火薬庫/
かやくめし /加薬飯/
かやくるい /火薬類/
かやくるいとりしまりほう /火薬類取締法/
かやぐむ /伽耶琴/
かやしま /萱島/萱嶋/
かやつ /彼奴/
かやつりぐさ /蚊帳吊草/
かやつりぐさもく /カヤツリグサ目/Cyperales/
かやと /茅戸/
かやね /茅根/
かやの /萱野;「茅野」とも/茅野/栢野/
かやのみや /賀陽宮/
かやはら /栢原/
かやば /茅場/
かやばちょう /茅場町/
かやぶき /茅葺き/
かやべ /茅部/
かやま /香山/加山/
かやまゆうぞう /加山雄三/
かやもり /萱森/
かやり /蚊遣り/
かゆ /粥/糜/
かゆかん /粥羹/
かゆみ /痒み/
かゆみどめ /痒み止め/
かよ /佳代/嘉代/佳世/加代/香代/
かよい /通い/
かよいじ /通い路;-吹き閉じよ/
かよいちょう /通い帳/
かよう /火曜/歌謡/賀陽;地名/斯様/花葉/可溶/加陽/加養/斯樣;旧字/可容/仮葉;[植物]phyllode/
かようか /可溶化;[化学]solubilisation/
かようかい /歌謡界/
かようきくざけ /加陽菊酒/
かようきょく /歌謡曲/
かようきょくふう /歌謡曲風/
かようさい /歌謡祭/
かようしゅう /歌謡集/
かようせい /可用性;†availability.「サーバの-」/可溶性;†solubility.「-繊維」/
かようせんしゅけん /歌謡選手権/
かようばんぐみ /歌謡番組/
かようび /火曜日/
かよく /寡欲/
かよこ /佳代子/加代子/香代子/佳世子/加世子/夏代子/
かよちょう /駕輿丁/
から /空/殻/唐/柄/辛/漢/韓/殼;「殻」の旧字/伽羅/掛落/〜;→なみせん/→;→みぎや,->/
から> /空/唐;唐草,唐太刀,唐屋形船/
からーいんさつ /カラー印刷/
からーえきしょう /カラー液晶/
からーか /カラー化/
からーしゃしん /カラー写真/
からーばん /カラー版/
からーひょうじ /カラー表示/
からあげ /唐揚げ/から揚げ/唐揚/空揚げ/
からあし /空足/
からあや /唐綾/
からい /花蕾/空井/渦雷/柄井;姓/
からいと /唐糸/
からいばり /空威張り/
からいも /唐薯/唐芋/
からいり /乾煎り/
からうす /碓/
からうた /唐歌;漢詩/
からうち /空打ち/
からうま /空馬/
からうり /空売り/カラ売り/
からえ /唐絵/
からおし /空押し/
からおり /唐織/
からかさ /傘/唐傘/
からかさまつ /傘松/
からかぜ /空風/乾風/
からかね /唐金/唐銅/
からかみ /唐紙/
からかわ /唐川/
からがい /空買い/
からがし /カラ貸し/
からがら /辛辛/辛々;命-/
からき /唐木/
からきだ /唐木田/
からぎぬ /唐衣/
からぎょう /空行/
からくさ /唐草/
からくさがわら /唐草瓦/
からくさもよう /唐草模様/
からくさもん /唐草文/
からくじ /空籤/
からくだもの /唐菓子/
からくち /辛口/
からくら /唐鞍/
からくり /機関/絡繰り/
からくりにんぎょう /絡繰り人形/
からくれない /韓紅/
からくわ /唐桑/
からけん /空券/
からげいき /空景気/
からげんき /空元気/カラ元気/
からこ /唐子/
からことば /韓語/唐語/
からこまげ /唐子髷/
からこるむ /和林/
からころも /唐衣/
からさき /唐崎/
からさわ /唐沢/唐澤/柄沢/
からさわぎ /空騒ぎ/
からざお /連枷/
からざけ /乾鮭;-色/
からし /辛子/芥子/
からしあえ /芥子和え/
からしいろ /芥子色/
からしじょうゆ /辛子醤油/
からしづけ /芥子漬/
からしな /芥子菜/
からしま /辛島/
からしまちょう /辛島町/
からしめんたいこ /辛子明太子/
からしゅっちょう /カラ出張/
からじし /唐獅子/
からす /烏/鴉/香良洲/
からすあげは /烏揚羽/
からすがい /烏貝/
からすき /犂/唐鋤/
からすぐち /烏口/カラス口/
からすざ /烏座;Corvus(Crv)/
からすてんぐ /烏天狗/
からすば /烏羽/
からすばいろ /烏羽色/
からすびしゃく /烏柄杓/
からすま /烏丸/
からすまきたおおじ /烏丸北大路/
からすまごじょう /烏丸五条/
からすましじょう /烏丸四条/
からすましゃこ /烏丸車庫/
からすません /烏丸線/
からすまななじょう /烏丸七条/
からすままつばら /烏丸松原/
からすままるたまち /烏丸丸太町/
からすまる /烏丸/
からすみ /唐墨/
からすむぎ /烏麦/カラス麦/
からすやま /烏山/
からせいもん /空誓文/
からせき /空咳/
からぜき /空咳/
からそうば /空相場/
からたけ /唐竹/漢竹/
からたけわり /幹竹割り/
からたち /枳殻/
からたに /柄谷;姓/
からだ /体/身体;(熟字訓)/躯;≒体/躰;「体」の異体字/體;「体」の旧字1/軆;「体」の旧字2/
からだき /空焚き/
からだじたい /体自体/
からだじゅう /体中/
からだぜんたい /体全体/
からだつき /体付き/体つき/身体つき/
からだづくり /体作り/
からだのみ /空頼み/
からちゃ /空茶/唐茶/枯茶/
からっかぜ /空っ風/乾っ風/からっ風/
からっけつ /空っ穴/
からっぽ /空っぽ/
からつ /唐津/
からつき /殻付き/
からつきたまご /殻付卵/
からつせん /唐津線/
からつば /空唾/
からつやき /唐津焼/
からつゆ /空梅雨/
からづみ /空積み/
からづり /空釣/
からて /空手/
からてか /空手家/
からてがた /空手形/
からてどう /空手道/
からてばか /空手バカ/
からてばかいちだい /空手バカ一代/
からてぶ /空手部/
からてわざ /空手技/
からてんじく /唐天竺/
からでっぽう /空鉄砲/
からでんぴょう /空伝票/
からと /唐櫃/
からとう /辛党/
からとりひき /空取引/
からなし /唐梨/
からなみだ /空涙/
からに /空荷/
からにしき /唐錦/
からねんぶつ /空念仏/
からはし /唐橋/
からはふ /唐破風/
からばこ /空箱/
からびん /空瓶/
からふと /樺太/
からふとけん /樺太犬/
からぶき /乾拭き/
からぶみ /漢書/
からぶり /空振り/空振/
からぼり /空堀/
からまーぞふのきょうだい /カラマーゾフの兄弟;Brat'ya Karamazovi, 1879-80, Dostoevskii/
からまつ /唐松/落葉松/
からまつそうあか /カラマツソウ亜科/Thalictoideae/
からまつだけ /唐松岳/
からまわり /空回り/
からみ /絡み/辛味;(当て字)/辛み/空身/
からみざけ /絡み酒/
からみそ /辛味噌/
からみそば /辛味蕎麦/
からみだいこん /辛味大根/
からみもち /辛味餅/
からむし /苧麻/苧/空蒸し/
からめ /辛め/辛目/
からめて /搦手/搦め手/
からもじ /空文字/唐文字/
からもじれつ /空文字列/
からもの /唐物/
からものがたり /唐物語/
からものだて /唐物点/
からものや /唐物屋/
からもん /唐門/
からやき /空焼き/
からやくそく /空約束/
からやま /唐山/
からやまちょう /唐山町/
からよう /唐様/
からようき /空容器/
からん /下欄/
かり /仮/狩/雁;[鳥]wild goose/加里;[化学]kali/狩り/借り/刈/猟/鴈;=雁/鳫;「鴈」の異体字/苅;「刈」の異体字/假;「仮」の旧字/獵;「猟」の旧字/
かり> /仮/
かりあげ /借り上げ/借上げ/刈り上げ/刈上げ/
かりあげしゃたく /借り上げ社宅/
かりいれ /借入/借り入れ/借入れ/刈り入れ/刈入れ/
かりいれきん /借入金/
かりうえ /仮植え/
かりうけ /借受/借受け/
かりうけきん /仮受金;[会計]勘定科目。suspense receipt/
かりうた /仮歌/
かりうど /狩人/猟人/
かりうむ /K/Potassium/
かりうむえん /カリウム塩/
かりえき /仮駅/
かりおや /仮親/
かりかいいんしょう /仮会員証/
かりかえ /借換/借り換え;住宅ローンの-/借換え/
かりかえさい /借換債;[金融]refinancing bond/
かりかし /借り貸し/
かりかた /借方/借り方/
かりかつよう /カリ活用;[国語学]から-かり-かり-かる-かれ-かれ/
かりかぶ /刈株/借株/
かりかんじ /仮幹事/
かりかんじょう /仮勘定/
かりがね /雁金/雁が音/
かりきん /借り金/
かりぎ /借り着/借着/
かりぎちょう /仮議長/
かりぎぬ /狩衣/
かりくび /雁首/
かりくみたて /仮組立/
かりくら /狩座/狩競/
かりぐみ /仮組/仮組み/
かりけいやく /仮契約/
かりけっさん /仮決算/
かりこ /雁子/
かりこし /借越/借り越し/
かりこみ /刈り込み/刈込/刈込み/苅込;「刈」異体字/
かりごや /仮小屋/
かりさかとうげ /雁坂峠/
かりしっこう /仮執行/
かりしっこうのせんげん /仮執行の宣言/
かりしどう /仮始動/
かりしゃくほう /仮釈放/
かりしゅっしょ /仮出所/
かりしゅつごく /仮出獄/
かりしゅつじょう /仮出場/
かりしゅひ /仮種皮/
かりしょぶん /仮処分/
かりじゅうしょ /仮住所/
かりじょうけん /仮条件/
かりすませい /カリスマ性/
かりすまてき /カリスマ的/
かりずまい /仮住まい/仮住い/
かりせいさん /仮精算/
かりせいほん /仮製本/
かりそめ /苟且/仮初め;-の恋/
かりた /苅田/刈田/
かりたいいん /仮退院/
かりたこう /苅田港/
かりだ /刈田/
かりだな /仮棚/
かりち /借り地/
かりちゅうしん /仮中心/
かりちょういん /仮調印/
かりちん /借賃/借り賃/
かりっぱなし /借りっ放し/
かりて /借り手/借手/
かりていも /訶梨帝母/
かりてんぽ /仮店舗/
かりでん /仮伝/
かりとうき /仮登記/
かりとじ /仮綴じ/
かりとり /刈り取り/刈取り/刈取/
かりとりき /刈取機/
かりどめ /仮止め/
かりに /仮に/
かりにはいえん /カリニ肺炎;[医]carinii pneumonia/
かりにも /仮にも/
かりにゅうもん /仮入門/
かりぬい /仮縫い/
かりぬし /借り主/
かりね /仮寝/
かりはいせん /仮配線/
かりはいぞく /仮配属/
かりはく /仮泊/
かりば /狩場/狩り場/
かりばし /仮橋/
かりばら /借り腹/借腹/
かりばらい /仮払/仮払い/
かりばらいきん /仮払金/
かりひきすう /仮引数/
かりびと /狩り人/猟人/
かりぶかい /カリブ海/
かりぶしん /仮普請/
かりへんすう /仮変数/
かりほ /刈穂/
かりほうめん /仮放免/
かりほるにうむ /Cf/Californium/
かりまた /雁股/
かりめん /仮免/
かりめんきょ /仮免許/
かりもがり /殯/
かりもの /借り物/借物/
かりゃく /嘉暦;年号(1326-29)/下略/
かりや /刈谷/仮屋/雁屋/狩谷/苅屋;「刈」異体字/借り家/借家/
かりやく /仮訳/
かりやし /刈谷市/
かりやす /刈安/
かりやど /仮宿/
かりやま /狩山/
かりゅう /下流/顆粒/花柳/加硫;[化学]vulcanise/渦流/火竜/河流/
かりゅういき /下流域/
かりゅうかい /花柳界/
かりゅうきゅう /顆粒球/
かりゅうしほう /加粒子砲/
かりゅうじょう /顆粒状/
かりゅうせい /顆粒性/
かりゅうど /狩人/猟人/
かりゅうびょう /花柳病/
かりょう /過料;†(あやまちりょう) 刑法上の刑罰ではない課金/加療/科料;†(とがりょう) 刑法上の刑罰としての課金/下僚/
かりょうびんが /迦陵頻伽/
かりょく /火力/夏緑/
かりょくせん /火力船/
かりょくはつでん /火力発電/
かりょくはつでんき /火力発電機/
かりょくはつでんしょ /火力発電所/
かりょくぶそく /火力不足/
かりょくりん /夏緑林/
かりよやく /仮予約/
かりわ /刈羽/
かりわく /仮枠/
かりわたし /仮渡し/
かりわりあて /仮割当/
かりん /花梨/華鈴/花櫚/可憐;かれん/火輪/
かりんさんせっかい /過燐酸石灰/
かりんしゃ /火輪車/
かりんせん /火輪船/
かりんとう /花林糖/
かる /軽/輕;「軽」の旧字/刈/苅;「刈」の異体字/狩/
かるい /科類/
かるいさわ /軽井沢/
かるいざわ /軽井沢/
かるいざわちょう /軽井沢町/
かるいし /軽石/
かるかや /刈萱/苅萱/
かるかん /軽羹/
かるがも /軽鴨/
かるがる /軽々/軽軽/
かるくち /軽口/
かるさ /軽さ/
かるしうむ /Ca/Calcium/
かるた /歌留多/骨牌/
かるでらこ /カルデラ湖;caldera lake/
かるはずみ /軽はずみ/
かるひと /狩人/
かるぼきしるき /カルボキシル基;[化学]carboxyl group. -COOH/
かるぼんさん /カルボン酸;[化学]carboxylic acid. 一般式R-COOH/
かるま /業;karma/
かるまい /軽米/
かるみ /軽み/
かるめ /軽め/軽目/
かるら /迦楼羅/
かるわざ /軽業/
かるわざし /軽業師/
かれ /彼/枯れ/嗄れ/涸/
かれーあじ /カレー味/
かれーこ /カレー粉/
かれーどん /カレー丼/
かれーなんばん /カレー南蛮/
かれーや /カレー屋/
かれあて /彼宛/
かれい /華麗/加齢/鰈/餉;乾飯/家令/過冷;supercool/嘉例/佳麗/佳例/家例/鰔;=鰈/遐齢/
かれいい /餉/乾飯/
かれいきゃく /過冷却/
かれいけん /加齢研/
かれいしゅう /加齢臭/
かれいすい /加冷水/
かれいせい /加齢性/
かれいろ /枯れ色/枯色/
かれえだ /枯れ枝/枯枝/
かれおばな /枯尾花/
かれがし /彼某/
かれがれ /離れ離れ;心の離れてゆくこと/枯れ枯れ;草木の枯れようとすること/
かれがわ /涸れ川;wadi/
かれき /枯れ木/枯木/
かれくさ /枯れ草/
かれくさいろ /枯れ草色/
かれこれ /彼此/
かれごえ /嗄れ声/
かれさわ /涸沢/
かれさんすい /枯山水/
かれし /彼氏/
かれしかのじょ /彼氏彼女/
かれじしん /彼自身/
かれせんすい /枯山水/枯れ山水/
かれだに /涸れ谷/
かれつ /苛烈/
かれの /枯野/
かれは /枯葉/枯れ葉/
かれはいろ /枯葉色/
かれはざい /枯葉剤/枯れ葉剤;米軍がベトナムで撒きました/
かれひとり /彼一人/
かれら /彼等/彼ら/
かれん /可憐/苛斂/
かれんちゅうきゅう /苛斂誅求/
かろ /火炉/
かろう /過労/家老/
かろううんてん /過労運転/
かろうぎみ /過労気味/
かろうし /過労死/
かろうじて /辛うじて/
かろうじょうたい /過労状態/
かろうれつ /家老列/
かろきょう /下路橋/
かろく /嘉禄;年号(1225-1227)/
かろこん /瓜呂根/
かろとうせん /夏炉冬扇/
かろやか /軽やか/
かろん /歌論/
かわ /川/河;(大きな川。原義:黄河)/皮;skin/革;leather. なめした動物のかわ/側/巛;「川」の異体字/
かわあそび /川遊び/
かわい /河合/川合/河井/川井/川相/可愛/可哀/
かわいい /可愛い/
かわいがっき /河合楽器/
かわいげ /可愛げ/可愛気/
かわいじゅく /河合塾/
かわいそう /可哀想;(当て字)/可哀相;(当て字)/
かわいだ /川井田/
かわいちょう /河合町/
かわいで /河出/
かわいろ /革色/
かわうえ /川上/
かわうお /川魚/
かわうそ /獺/川獺/
かわうち /川内/河内/
かわうら /川浦/河浦/
かわおと /川音/
かわおび /革帯/
かわかぜ /川風/
かわかつ /川勝/
かわかみ /川上/河上/
かわがり /川狩り/川狩/
かわがわ /川側/
かわき /乾き/渇き;(特に喉や精神のかわき) 「-を覚える」/
かわきた /川北/河北/
かわきもの /乾き物;おつまみ/
かわきゅう /川久/
かわきり /皮切り/
かわぎし /川岸/河岸/
かわぎぬ /裘/皮衣/
かわぎり /川霧/
かわくぼ /川久保/
かわくら /川倉/
かわぐ /革具/
かわぐち /川口/河口/
かわぐちえきまえ /川口駅前/
かわぐちこ /河口湖/
かわぐちこせん /河口湖線/
かわぐちし /川口市/
かわぐちとつか /川口戸塚/
かわぐつ /革靴/皮靴/革沓/
かわけ /河毛/
かわげ /河芸/
かわごえ /川越/川越え/
かわごえかいどう /川越街道/
かわごえし /川越市/
かわごえじょう /川越城/
かわごえせん /川越線/
かわごえでんしゃく /川越電車区/
かわごえほうめん /川越方面/
かわごけそうもく /カワゴケソウ目/Podostemonales/
かわごし /川越し/
かわごろも /裘/皮衣/
かわさき /川崎/河崎/川嵜/
かわさきえき /川崎駅/
かわさきかいどう /川崎街道/
かわさきかん /川崎間/
かわさきがわ /川崎側/
かわさききゅうじょう /川崎球場/
かわさきく /川崎区/
かわさきくない /川崎区内/
かわさきけいばじょう /川崎競馬場/
かわさきこう /川崎港/
かわさきこうえん /川崎公演/
かわさきこうじょう /川崎工場/
かわさきし /川崎市/
かわさきしあさおく /川崎市麻生区/
かわさきしえい /川崎市営/
かわさきしでん /川崎市電/
かわさきしない /川崎市内/
かわさきしほくぶ /川崎市北部/
かわさきしみん /川崎市民/
かわさきしりつ /川崎市立/
かわさきじゅうこう /川崎重工/
かわさきじゅうこうぎょう /川崎重工業;[企業名]/
かわさきせいてつ /川崎製鉄/川崎製鐵;[企業名]/
かわさきせきゆ /川崎石油;[企業名]/
かわさきせん /川崎戦/
かわさきぞうせん /川崎造船/
かわさきだいし /川崎大師/
かわさきちょう /川崎町/
かわさきてん /川崎店/
かわさきびょう /川崎病;[医]/
かわさきほうめん /川崎方面/
かわさと /川里/
かわざかな /川魚/
かわざんよう /皮算用/
かわしげ /川重/
かわしま /川島/川嶋/河島/河嶋/
かわしまおりもの /川島織物/
かわしも /川下/
かわしもがわ /川下側/
かわじ /川路/川治/
かわじおんせん /川治温泉/
かわじま /川島/
かわじゃん /革ジャン/
かわじょうき /川蒸気;steamboat/
かわじり /川尻/
かわすぎ /川杉/
かわすじ /川筋/
かわすずみ /川涼み/
かわすみ /川澄;姓/
かわず /蛙/河津/川津/
かわずいくさ /蛙軍;蛙の集団交尾/
かわせ /為替/川瀬/河瀬/川背/
かわせい /革製/
かわせいひん /革製品/皮製品;NB:鞣したものは「革製品」/
かわせかいにゅう /為替介入/
かわせぎょうむ /為替業務/
かわせぎんこう /為替銀行;exchange bank/
かわせさえき /為替差益/
かわせさそん /為替差損/
かわせしじょう /為替市場/
かわせそうば /為替相場/
かわせてがた /為替手形/
かわせへいか /為替平価/
かわせみ /川蝉/翡翠;=川蝉 NB:「ひすい」とも/翡/魚狗/
かわせよやく /為替予約/
かわせりすく /為替リスク;exchange risk/
かわせれーと /為替レート/
かわそう /革装/
かわそえ /川副/
かわぞい /川沿い/河沿/
かわぞえ /川添/河添/
かわぞこ /川底/河底/
かわた /川田/河田/
かわたけ /河竹/川竹/
かわたな /川棚/
かわたび /川渡/川旅/
かわたろう /河太郎;河童/
かわだ /川田/河田/
かわだいら /川平/
かわだちょう /河田町/
かわち /河内/
かわちおんど /河内音頭/
かわちながの /河内長野/
かわちべん /河内弁/
かわちや /河内屋/河内谷/
かわつ /川津/
かわつき /皮付き/
かわつこう /川津港/
かわづ /河津/川津/
かわづがけ /河津掛け/
かわづくり /皮作り;[料理]皮を付けたまま刺身にする/
かわづはな /川津花/
かわづら /川面/
かわづり /川釣り/
かわてつ /川鉄/
かわてぶくろ /皮手袋/革手袋/
かわで /河出/
かわでしょぼう /河出書房/
かわでしょぼうしんしゃ /河出書房新社/
かわでぶんこ /河出文庫/
かわと /川人/
かわとう /川藤/川東/
かわどこ /河床/川床/
かわな /川名/川奈/
かわなか /川中/
かわなかじま /川中島/
かわながれ /川流れ;河童の-/
かわなざき /川奈崎/
かわなべ /川辺/河鍋/川鍋/
かわなみ /川波/
かわなり /川成/
かわにし /川西/河西/
かわにしし /川西市/
かわにしのせぐち /川西能勢口/
かわにな /川蜷/河貝子/
かわぬま /河沼/
かわね /川根/
かわねずみ /川鼠/
かわの /河野/川野/
かわのえ /川之江/
かわのかみ /河の神/
かわのべ /河之邊/
かわのり /川海苔/
かわはぎ /皮剥/
かわはた /河鰭;姓。かわばた、とも/
かわはば /川幅/
かわはま /川浜/
かわはら /川原/河原/
かわば /川場/
かわばた /川端;姓/川畑;姓/河端;姓/河鰭;姓。かわはた、とも/川幡;姓/
かわばたやすなり /川端康成;(1899-1972) 作家。『雪国』/
かわばり /革張り/皮張り/
かわぱん /革パン/
かわひがし /川東/河東/
かわひと /川人/
かわひも /革紐/皮紐/
かわひら /川平/
かわびょうし /革表紙/
かわびらき /川開き/
かわふく /川福/川副/
かわふじ /川藤/
かわぶくろ /皮袋/革袋/
かわぶち /川淵/
かわぶね /川船/川舟/
かわべ /川辺/河辺/川部/川邊/河部;姓/川邉/河邊/川連;かわづれ?/
かわべり /川縁/
かわほね /河骨;=こうほね/
かわほり /蝙蝠/
かわまえちょう /川前町/
かわます /河鱒/
かわまた /川俣/川又/川股/
かわまたせん /川俣線/
かわみ /川見/
かわみなみ /川南/
かわみや /河宮/
かわむかい /川向かい/川向い/
かわむき /皮剥き/
かわむこう /川向う/川向こう/
かわむら /川村/河村/
かわも /川面/
かわもと /川本/河本/川元/
かわもり /川守/川森/
かわや /厠/廁;「厠」の異体字/
かわやなぎ /川柳/
かわゆおんせん /川湯温泉/
かわゆか /川床;川に突き出した座敷.「四条-」/
かわよう /革用/川用/
かわよけ /川除/
かわよろい /革鎧;leather armour/
かわら /瓦/河原/川原/香春;地名/磧;=河原/
かわらい /河原井/
かわらがはま /瓦ケ浜/
かわらがま /瓦窯/
かわらけ /土器/
かわらけいろ /土器色/
かわらけし /土器師/
かわらざき /河原崎/
かわらし /瓦師/
かわらせんべい /瓦煎餅/
かわらたけ /瓦茸/
かわらだ /河原田/
かわらばん /瓦版/かわら版/
かわらふじ /河原藤/
かわらぶき /瓦葺き;tile-roofed/瓦葺/
かわらべい /瓦塀/
かわらまち /河原町/
かわらまちいまでがわ /河原町今出川/
かわらまちごじょう /河原町五条/
かわらまちせん /河原町線/
かわらもの /河原者/
かわらや /瓦屋/
かわらやき /瓦焼/瓦焼き/
かわらやね /瓦屋根;[建築]/
かわり /代わり;replacement.「-の品」/変わり;change.「-ない」/変り/代り/替わり/替り/
かわりだね /変わり種/
かわりばえ /代わり映え/
かわりばんこ /代わり番こ/代り番こ/
かわりびな /変わり雛/変り雛/
かわりみ /変わり身/変り身/
かわりめ /変わり目/変り目/代わり目/代り目/
かわりもの /変わり者/変り者/
かわりやく /代役/
かわりよう /変わり様/変り様/
かわるがわる /代わる代わる/代る代る/
かわわ /川和/
かわわせん /河和線/
かわわちょう /川和町/
かわん /下腕/
かん /缶/勘;山勘/間/感/観/巻/完/冠/官/館/管;†pipe/菅;†すが・すげ/棺/漢/韓/刊/燗;†-酒/癇;†-に障る/関;関数/閑;閑居/槓;[麻雀]/寒/乾/緩;緩慢/患;患者/看;看病/寛;寛容/姦;姦淫/監;監督/艦/鑑;鑑賞/鑒;「鑑」の異体字/貫;3.75kg/慣;慣習/樌/環;ベンゼン環/還;帰還/鐶;≒環/寰;(世界)/坎;[八卦]陰陽陽/款;約款/歛;(ねがう)/歓;歓迎/歡;「歓」の旧字/勧;勧業/勸;「勧」の旧字/觀;「観」の旧字/罐;「缶」の本字/鑵;≒罐/灌;灌漑/潅;「灌」の異体字/浣;浣腸/懽;≒歓/讙;≒歓/驩;≒歓/鸛;こうのとり/敢;敢行/橄;橄欖岩/瞰;俯瞰/甘;甘味/柑;蜜柑/坩;坩堝(かんか,るつぼ)/嵌;嵌張/箝;箝口令/拑;≒箝/鉗;鉗子/疳;疳の虫/篏;象嵌/邯;邯鄲の夢/酣;たけなわ/干;干潮/汗;発汗/肝;肝臓/奸;奸計/扞;ふせ・ぐ/杆;槓杆/骭/旱;ひでり/悍;精悍/捍;「扞」の異体字/桿;操縦桿/稈;わら/駻;駻馬/幹;幹線/澣;(すす・ぐ)/竿;(さお)/罕;(まれ)/咸/喊;喊声/鹹;しおからい。「鹹湖」/憾;遺憾/撼;震撼/緘;封緘/轗/諫;諫言/諌;「諫」の異体字/柬;(えら・ぶ)/揀;≒揀/簡;簡単/嫺;(しとやか)/嫻;「嫺」の異体字/澗;澗水/繝/奐/換;交換/喚;わめ・く。「喚声」/渙;渙然氷釈/煥;才気煥発/莞;莞爾/皖;中国・安徽省/陥;陥落/陷;「陥」の旧字(人名用漢字)/翰;翰林院/瀚;浩瀚(broad)/函;函数/凾;「函」の異体字/涵;涵養/堪;堪忍/侃;侃々諤々/桓;桓公/甲;甲高い/丱;髪型の一種/厂;(がんだれ)/宦;宦官/戡/淦;あか/盥;たらい/羹;羊羹/羮;「羹」の異体字/艱;艱難辛苦/莟;つぼみ/蒄;草の名/豢/鰥;やもめ/神;神田/舘;「館」の異体字/啣;「銜」の異体字/卷;「巻」の旧字(人名用漢字)/關;「関」の旧字/康;?/潤;?/
かん> /間/完/環;-太平洋/缶/韓/
かんあく /奸悪/
かんあけ /寒明け/
かんあつ /感圧/缶圧/
かんあつし /感圧紙/
かんあつしき /感圧式/
かんあみ /観阿弥/
かんあん /勘案/
かんい /簡易/官位/冠位;-十二階/漢医;漢方医/敢為/官医/寛衣/換位/簡意/
かんい> /簡易/
かんいか /簡易化/
かんいかきとめ /簡易書留/
かんいかぜい /簡易課税/
かんいかぜいせいど /簡易課税制度/
かんいがた /簡易型/
かんいけいたいでんわ /簡易携帯電話/
かんいけんさ /簡易検査/
かんいげんご /簡易言語/
かんいこうしゅう /簡易講習/
かんいこうはんてつづき /簡易公判手続/
かんいさいばん /簡易裁判/
かんいさいばんしょ /簡易裁判所/
かんいしき /簡易式/
かんいしょく /肝移植/
かんいじゅうにかい /冠位十二階;[日本史]603/
かんいせいめいほけん /簡易生命保険;簡保/
かんいち /貫一/乾一/
かんいっぱつ /間一髪/
かんいてき /簡易的/
かんいといれ /簡易トイレ/
かんいばん /簡易版/
かんいほうしき /簡易方式/
かんいほけん /簡易保険/
かんいほけんきょく /簡易保険局/
かんいほけんほーる /簡易保険ホール/
かんいむせん /簡易無線/
かんいゆうびんきょく /簡易郵便局/
かんいり /缶入り/缶入/
かんいれいぼう /簡易冷房/
かんいん /姦淫/館員/官員/官印/完飲/
かんいんりょう /缶飲料/
かんう /関羽;三国時代・蜀漢の武将/換羽/冠羽/甘雨;≒慈雨/寒雨/
かんうていそうしょ /甘雨亭叢書/
かんうん /閑雲/
かんうんやかく /閑雲野鶴/
かんえい /寛永;年号(1624-1644)/官営/完泳/
かんえいつうほう /寛永通宝/
かんえいてつどう /官営鉄道/
かんえいにち /漢英日/
かんえつ /関越/観閲/簡閲/
かんえつこうそく /関越高速/
かんえつしき /観閲式/
かんえつじどうしゃどう /関越自動車道/
かんえつどう /関越道/
かんえん /肝炎/寛延;年号(1748-1751)/
かんおう /感応/観桜/陥凹/観応;年号(1350-1352)/
かんおけ /棺桶/
かんおん /漢音;漢字の-/感音;(音声)/感温;(温度)/感恩;gratitude/幹音;一オクターブの七つの幹音/
かんおんけい /感音系/
かんおんじ /観音寺/
かんおんせい /感温性/
かんか /感化/看過/管下/換価/閑暇/干戈/乾果/坩堝;るつぼ/鰥寡/轗軻;不遇/柑果/旱戈;?/
かんかい /寛解;[医]remission/官界/緩解;=寛解/感懐/勧戒/
かんかいかんちょう /管海官庁/
かんかいん /感化院/
かんかく /感覚/間隔/看客/　;全角スペース/
かんかくかい /感覚界;mundus sensibilis/
かんかくき /感覚器/
かんかくきかん /感覚器官/
かんかくけい /感覚系/
かんかくさいぼう /感覚細胞/
かんかくしんけい /感覚神経/
かんかくじゅよう /感覚受容/
かんかくじょう /感覚上/
かんかくじょうひ /感覚上皮/
かんかくじょうほう /感覚情報/
かんかくせい /感覚性/
かんかくだいこう /感覚代行/
かんかくちゅうすう /感覚中枢/
かんかくてき /感覚的/
かんかくにゅうりょく /感覚入力/
かんかくまひ /感覚麻痺;[医]anesthesia/
かんかくもう /感覚毛/
かんかくもじ /間隔文字/
かんかくや /感覚野;[解剖]sensory area/
かんかこどく /鰥寡孤独/
かんかつ /管轄/寛闊;generous/管割;割った管。パイプの断面。「-図」/奸黠;cunning/
かんかつえいぎょうしょ /管轄営業所/
かんかつか /管轄下/
かんかつがい /管轄外/
かんかつけん /管轄権/
かんかつさいばんしょ /管轄裁判所/
かんかつじこう /管轄事項/
かんかつちがい /管轄違い/
かんかん /寛々/閑々/感官;sense/汗簡;文書/灌灌/
かんかんがくがく /侃々諤々;遠慮なく議論する,侃諤/侃侃諤諤/
かんかんしき /観艦式/
かんかんでり /かんかん照り/
かんが /官衙;役所/閑雅/漢画/
かんがい /感慨;emotion/灌漑;irrigation/館外/管外;管轄外/干害;drought/寒害;cold damage/潅漑;「灌」異体字/潅がい;「灌」異体字 ※不自然な交ぜ書き?/
かんがいむりょう /感慨無量/
かんがいようすい /灌漑用水/
かんがえ /考え/
かんがえおち /考え落ち/
かんがえかた /考え方/
かんがえごと /考え事/
かんがえすぎ /考え過ぎ/
かんがえちがい /考え違い/
かんがえちゅう /考え中/
かんがえもの /考え物/
かんがく /官学;⇔私学/管楽;[音楽]wind/漢学;⇔国学/勧学;学問ノススメ/関学;[略語]関西学院大学/侃諤;遠慮なく議論する/
かんがくいん /勧学院/
かんがくがわ /関学側/
かんがくこう /関学高/
かんがくせん /関学戦/
かんがくで /関学出/
かんがっき /管楽器/
かんがっきそうしゃ /管楽器奏者/
かんがん /肝癌/宦官/汗顔/肝がん/肝ガン/
かんき /換気;†ventilation.「部屋の-」/喚起;†arouse.「注意を-する」/歓喜/寒気/間期/乾季/乾期;=乾季/刊記/勘気/寒期/官記/官紀/
かんきこう /換気口/換気孔/
かんきせん /換気扇/
かんきだん /寒気団/歓喜団/
かんきち /乾吉/
かんきつ /柑橘/
かんきつけい /柑橘系/
かんきつるい /柑橘類/
かんきのう /肝機能/
かんきのうしょうがい /肝機能障害/
かんきゃく /観客/閑却/
かんきゃくすう /観客数/
かんきゃくせき /観客席/
かんきゃくどういん /観客動員/
かんきゃくどういんすう /観客動員数/
かんきゃくにんずう /観客人数/
かんきゅう /緩急/官給/感泣/
かんきゅうしゃ /緩急車/
かんきゅうじざい /緩急自在/
かんきゅうせつぞく /緩急接続/
かんきゅうほう /緩急法/
かんきょ /閑居/官許/
かんきょう /環境/艦橋/感興/緩頬;にっこり/喚叫/漢鏡/干姜/乾薑/寒郷/
かんきょうあっか /環境悪化/
かんきょうえいぞう /環境映像;BGV/
かんきょうおせん /環境汚染/
かんきょうおん /環境音/
かんきょうおんがく /環境音楽/
かんきょうか /環境下/
かんきょうかいぜん /環境改善/
かんきょうかいはつ /環境開発/
かんきょうかいはつぶ /環境開発部/
かんきょうかんれん /環境関連/
かんきょうがく /環境学/
かんきょうがくけんきゅうか /環境学研究科/
かんきょうきじゅん /環境基準/
かんきょうきほんほう /環境基本法/
かんきょうきょういく /環境教育/
かんきょうけい /環境系/
かんきょうけいかくがっか /環境計画学科/
かんきょうけん /環境権;[新語]environmental rights/環境研/
かんきょうけんきゅうじょ /環境研究所/
かんきょうげいじゅつ /環境芸術/
かんきょうこう /環境光/
かんきょうこうがい /環境公害/
かんきょうこうがく /環境工学/
かんきょうこうがくこうざ /環境工学講座/
かんきょうこうげん /環境抗原/
かんきょうさ /環境差/
かんきょうざつおん /環境雑音/
かんきょうしだい /環境次第/
かんきょうしょう /環境省;NB:環境庁、厚生省が2001年1月の中央省庁再編で再編されたもの/
かんきょうじゅうし /環境重視/
かんきょうじょう /環境上/
かんきょうじょうか /環境浄化/
かんきょうじょうけん /環境条件/
かんきょうじょうほう /環境情報/
かんきょうじょうほうがくぶ /環境情報学部/
かんきょうじょうやく /環境条約/
かんきょうせいび /環境整備/
かんきょうせってい /環境設定/
かんきょうせっていちゅう /環境設定中/
かんきょうせっていよう /環境設定用/
かんきょうせん /関京戦/
かんきょうぜい /環境税/
かんきょうそうおん /環境騒音/
かんきょうたいさく /環境対策/
かんきょうだいじん /環境大臣/
かんきょうちゅう /環境中/
かんきょうちょう /環境庁;NB:2001年1月の中央省庁再編で環境省に再編された/
かんきょうちょうかん /環境長官/
かんきょうちょうこくじ /環境庁告示/
かんきょうちょうちょうかん /環境庁長官/
かんきょうてき /環境的/
かんきょうはかい /環境破壊/
かんきょうはかいかつどう /環境破壊活動/
かんきょうはくしょ /環境白書/
かんきょうびか /環境美化/
かんきょうぶんや /環境分野/
かんきょうへんか /環境変化/
かんきょうへんすう /環境変数/
かんきょうへんすうせってい /環境変数設定/
かんきょうへんすうめい /環境変数名/
かんきょうほう /環境法/
かんきょうほうき /環境法規/
かんきょうほうこくしょ /環境報告書/
かんきょうほご /環境保護/
かんきょうほごうんどう /環境保護運動/
かんきょうほごきょく /環境保護局/
かんきょうほごぜい /環境保護税/
かんきょうほごたいさく /環境保護対策/
かんきょうほごだんたい /環境保護団体/
かんきょうほごもんだい /環境保護問題/
かんきょうほぜん /環境保全/
かんきょうほるもん /環境ホルモン;ホルモン類似作用を持つ合成化学分質。動物や人間の生殖、代謝機能を攪乱/
かんきょうめい /環境名/
かんきょうもんだい /環境問題/
かんきょうもんだいいっぱん /環境問題一般/
かんきょうよういん /環境要因/
かんきょく /寒極/
かんきり /缶切り/
かんきりょう /換気量/
かんきん /監禁/換金/桿菌/看経/官金/
かんきんか /換金化/
かんきんかのう /換金可能/
かんきんきゃく /換金客/
かんきんご /換金後/
かんきんざい /監禁罪/
かんきんじょ /換金所/
かんきんせい /換金性/
かんきんばしょ /換金場所/
かんきんよう /換金用/
かんきんりつ /換金率/
かんぎ /寛喜;年号(1229-1232)/
かんぎく /寒菊/観菊/
かんぎてん /歓喜天/
かんぎゅうじゅうとう /汗牛充棟/
かんぎょ /還御/干魚/乾魚/鹹魚/
かんぎょう /官業/勧業/寒行/鑑行/
かんぎん /勧銀/閑吟/感吟/
かんく /管区/甘苦;sweet and bitter/艱苦;艱難辛苦/寒苦/
かんくう /関空;[略語]関西国際空港/管腔/
かんくうかいそく /関空快速/
かんくうはつ /関空発/
かんくろう /官九郎;名/
かんぐり /勘繰り/
かんぐん /官軍/
かんけ /菅家/
かんけい /関係/奸計/姦計;=奸計/環形/寛刑;⇔厳刑/換刑/簡勁/還啓/
かんけいあっか /関係悪化/
かんけいあり /関係有/
かんけいいがい /関係以外/
かんけいえんざんし /関係演算子/
かんけいかいぜん /関係改善/
かんけいかくい /関係各位/
かんけいかくしょ /関係各所/
かんけいかくほうめん /関係各方面/
かんけいかくりょう /関係閣僚/
かんけいかくりょうかいぎ /関係閣僚会議/
かんけいかんちょう /関係官庁/
かんけいがいしゃ /関係会社/
かんけいがく /関係学;Beziehungslehre(独)/
かんけいがた /関係型/
かんけいがっかい /関係学会/
かんけいきかん /関係機関/
かんけいきょうか /関係強化/
かんけいけいさん /関係計算/
かんけいこく /関係国/
かんけいさき /関係先/
かんけいざっし /関係雑誌/
かんけいし /関係詞/
かんけいしき /関係式/
かんけいしつど /関係湿度/
かんけいしゃ /関係者/
かんけいしゃかくい /関係者各位/
かんけいしゃそうご /関係者相互/
かんけいしゅうふく /関係修復/
かんけいしゅぎ /関係主義;relationism/
かんけいしょうちょう /関係省庁/
かんけいしょかんちょう /関係諸官庁/
かんけいしょこく /関係諸国/
かんけいしょし /関係諸氏/
かんけいしょせき /関係書籍/
かんけいしょるい /関係書類/
かんけいしりょう /関係資料/
かんけいじちたい /関係自治体/
かんけいじょう /関係上/
かんけいすう /関係数/
かんけいすじ /関係筋/
かんけいず /関係図/
かんけいせい /関係性/
かんけいせつ /関係節/
かんけいだいすう /関係代数/
かんけいだいめいし /関係代名詞/
かんけいだんたい /関係団体/
かんけいちょう /関係調/
かんけいてき /関係的/
かんけいどうぶつ /環形動物/
かんけいひん /関係品/
かんけいふくし /関係副詞;[文法]relative adverb/
かんけいぶしょ /関係部所/
かんけいぶんけん /関係文献/
かんけいほうき /関係法規/
かんけいもうそう /関係妄想/
かんけいろん /関係論/
かんけつ /完結/簡潔/間欠/観血;[医]invasive/間歇;=間欠/
かんけつおん /間欠音/
かんけつか /簡潔化/
かんけつきねん /完結記念/
かんけつせい /簡潔性/
かんけつせん /間欠泉/
かんけつてき /間欠的/
かんけつねつ /間欠熱/
かんけつば /汗血馬/
かんけつへん /完結編/
かんけり /缶蹴り/
かんけん /官憲;-横暴/管見;狭い見識/官権;官吏の権限/換券/
かんげ /勧化/
かんげい /歓迎/
かんげいかい /歓迎会/
かんげいこ /寒稽古/
かんげき /感激/観劇/間隙/
かんげきかい /観劇会/
かんげきてき /感激的/
かんげきど /感激度/
かんげざい /緩下剤/
かんげつ /観月/寒月/
かんげん /還元/管弦/換言;paraphrase/甘言;甘い言葉/諫言;諫める言葉/管絃;=管弦/寛元;年号(1243-1247)/諌言;「諫」異体字/
かんげんえん /還元炎/還元焔;[化学]/
かんげんがく /管弦楽/
かんげんがくきょく /管弦楽曲/
かんげんがくさくひん /管弦楽作品/
かんげんがくだん /管弦楽団/
かんげんがくばん /管弦楽版/
かんげんがくぶ /管弦楽部/
かんげんがくへんきょく /管弦楽編曲/
かんげんがくほう /管弦楽法/
かんげんがっき /管弦楽器/
かんげんがっきょく /管弦楽曲/
かんげんこうか /還元効果/
かんげんこうそ /還元酵素/
かんげんさよう /還元作用/
かんげんざい /還元剤/
かんげんしゅぎ /還元主義/
かんげんとう /還元糖/
かんげんはんのう /還元反応/
かんげんぶん /還元分/
かんげんぶんれつ /還元分裂/
かんげんろん /還元論/
かんげんろんてき /還元論的/
かんこ /歓呼;cheer.「群集の-」/喚呼;call.「『出発！』と-する」/鹹湖;salt lake/
かんこーひー /缶コーヒー/
かんこう /観光/刊行;publish/敢行;dare/慣行;custom/感光/官公/完工/緩行;⇔急行/漢江;地名,(Seoulの)Han-gang, (中国の)Han Jiang/漢口;地名,Hankou/款項/緘口/寛弘;年号(1004-1012)/艦攻;艦上攻撃機/桓公;人名/勘考/寛厚/還向/箝口;=緘口/甘汞;Hg2Cl2/勧降/刊稿/
かんこうあんない /観光案内/
かんこうあんないじょ /観光案内所/
かんこうか /観光課/観光化/
かんこうかい /刊行会/
かんこうかいはつ /観光開発/
かんこうきせん /観光汽船/
かんこうきゃく /観光客/
かんこうきゃくあいて /観光客相手/
かんこうきゃくかかく /観光客価格/
かんこうきょうかい /観光協会/
かんこうきょく /観光局/
かんこうぎょう /観光業/
かんこうさんぎょう /観光産業/
かんこうざい /感光剤/環孔材;⇔散孔材/
かんこうし /感光紙/
かんこうしき /感光式/
かんこうしげん /観光資源/
かんこうしょ /官公署/
かんこうしょう /観光省/観光相;†大臣/
かんこうじぎょう /観光事業/
かんこうじゅ /官公需/
かんこうじょうほう /観光情報/
かんこうせい /緩効性/感光性/
かんこうせいひりょう /緩効性肥料;[園芸]/
かんこうせん /観光船/緩行線/
かんこうたい /感光体/
かんこうち /観光地/
かんこうちか /観光地化/
かんこうちず /観光地図/
かんこうちゃ /缶紅茶/
かんこうちゅう /敢行中/
かんこうちょう /官公庁/
かんこうちりょうきん /観光地料金/
かんこうてき /観光的/
かんこうてつどう /観光鉄道/
かんこうとし /観光都市/
かんこうとっきゅう /観光特急/
かんこうど /感光度/
かんこうば /勧工場/
かんこうばい /緩勾配/寒紅梅/
かんこうばしょ /観光場所/
かんこうばす /観光バス/
かんこうびざ /観光ビザ/
かんこうぶ /観光部/
かんこうぶつ /刊行物/
かんこうへん /肝硬変/
かんこうまえ /刊行前/
かんこうむき /観光向き/
かんこうめいしょ /観光名所/
かんこうもくてき /観光目的/
かんこうよう /観光用/
かんこうり /官公吏/
かんこうりっこく /観光立国/
かんこうりつびょういん /官公立病院/
かんこうりょこう /観光旅行/
かんこうれい /箝口令/
かんこうろう /官公労;[略語]日本官公庁労働組合協議会/
かんこうろせん /観光路線/
かんこく /韓国/勧告/寒国/官刻/
かんこくいがい /韓国以外/
かんこくえいが /韓国映画/
かんこくえんせい /韓国遠征/
かんこくがわ /韓国側/
かんこくけい /韓国系/
かんこくご /韓国語/
かんこくごかんきょう /韓国語環境/
かんこくごほうそう /韓国語放送/
かんこくさん /韓国産/
かんこくしき /韓国式/
かんこくしじょう /韓国市場/
かんこくしょくざい /韓国食材/
かんこくじん /韓国人/
かんこくせい /韓国製/
かんこくせいふ /韓国政府/
かんこくせき /韓国籍/
かんこくだいとうりょう /韓国大統領/
かんこくちょくゆにゅう /韓国直輸入/
かんこくない /韓国内/
かんこくのり /韓国海苔/
かんこくばん /韓国版/
かんこくふう /韓国風/
かんこくぶんか /韓国文化/
かんこくへいごう /韓国併合/
かんこくほうじん /韓国法人/
かんこくりょうり /韓国料理/
かんこくりょうりてん /韓国料理店/
かんこくりょうりや /韓国料理屋/
かんこつ /寛骨;[解剖]hipbone/顴骨;=頬骨/
かんこつきゅう /寛骨臼/
かんこつだったい /換骨奪胎/
かんこどり /閑古鳥/かんこ鳥;「閑古鳥」は当て字/
かんこぴ /完コピ/
かんこん /冠婚/
かんこんそうさい /冠婚葬祭/
かんご /看護/漢語/監護/韓語;朝鮮語/閑語/歓娯/款語/
かんごう /巻号/嵌合;はめあい/勘合;-貿易/冠号/
かんごうしゅうらく /環濠集落/
かんごうせん /勘合船/
かんごうふ /勘合符/
かんごうぼうえき /勘合貿易/
かんごえ /寒肥/
かんごがく /看護学/
かんごがっこう /看護学校/
かんごく /監獄/
かんごくほう /監獄法/
かんごくゆき /監獄行き/監獄行/
かんごけい /漢語系/
かんごし /看護師;†/看護士;† NB:保健婦助産婦看護婦法一部改正により「看護師」に呼称変更/
かんごにん /看護人/
かんごふ /看護婦/看護夫/
かんごふめんきょ /看護婦免許/
かんごへい /看護兵/
かんごりん /漢語林/
かんさ /監査/感作/間差/鑑査/
かんさい /関西/完済/簡裁;簡易裁判所/寛斎/艦載/
かんさいいがい /関西以外/
かんさいいん /監査委員/
かんさいいんかい /監査委員会/
かんさいえんせい /関西遠征/
かんさいかんとう /関西関東/
かんさいがい /関西外/
かんさいがくせい /関西学生/
かんさいがわ /関西側/
かんさいき /艦載機/
かんさいきせん /関西汽船/
かんさいきょうかい /関西協会/
かんさいくうこう /関西空港/
かんさいくうこうえき /関西空港駅/
かんさいくうこうせん /関西空港線/
かんさいくうこうちゃく /関西空港着/
かんさいぐち /関西口/
かんさいけい /関西系/
かんさいけん /関西圏/関西圈;旧字/
かんさいこうえん /関西公演/
かんさいこくさいくうこう /関西国際空港;www.kansai-airport.or.jp/
かんさいご /関西語/
かんさいししゃ /関西支社/
かんさいししょ /関西支所/
かんさいしてつ /関西私鉄/
かんさいしてん /関西支店/
かんさいしぶ /関西支部/
かんさいしゃかいじん /関西社会人/
かんさいしょうぎかいかん /関西将棋会館/
かんさいしんくうこう /関西新空港/
かんさいじょうほう /関西情報/
かんさいじん /関西人/
かんさいせん /関西線/
かんさいせんしゅけん /関西選手権/
かんさいたいかい /関西大会/
かんさいだい /関西大/
かんさいだいがく /関西大学/
かんさいだいひょう /関西代表/
かんさいちく /関西地区/
かんさいちほう /関西地方/
かんさいちゅうしん /関西中心/
かんさいつうしん /関西通信/
かんさいてき /関西的/
かんさいてつどう /関西鉄道/
かんさいで /関西出/
かんさいでんりょく /関西電力;[企業名]/
かんさいば /関西馬/
かんさいばん /関西版/
かんさいふう /関西風/
かんさいふうみ /関西風味/
かんさいべん /関西弁/
かんさいぺいんと /関西ペイント;[企業名]/
かんさいほうげん /関西方言/
かんさいほうめん /関西方面/
かんさいほんせん /関西本線/
かんさいぼう /幹細胞;[生物]stem cell/間細胞;[生物]interstitial cell/
かんさいりゅう /関西流/
かんさいん /監査員/鑑査員/
かんさかん /監査官/
かんさく /間作/奸策/姦策;=奸策/
かんさくめい /関作命/
かんさしつ /監査室/
かんさせいきゅう /監査請求;[法]petition for audit. <地方自治法/
かんさつ /観察;†observe.「アサガオの-」/監察;†inspect.「行政の-」/鑑札;license tag.「犬の-」/
かんさつい /監察医/
かんさついん /監察員/監察院/
かんさつかい /観察会/
かんさつがくしゅう /観察学習/
かんさつがん /観察眼/
かんさつぐん /監察軍/
かんさつけっか /観察結果/
かんさつしゃ /観察者/
かんさつりょく /観察力/
かんさにん /監査人/
かんさぶ /監査部/
かんさほうじん /監査法人/
かんさやく /監査役/
かんさん /換算/閑散/甘酸/
かんさんき /閑散期/
かんさんけいすう /換算係数/
かんさんしき /換算式/
かんさんじ /閑散時/
かんさんひょう /換算表/
かんざい /管財/寒剤/
かんざいにん /管財人/
かんざき /神崎/神埼/
かんざきがわ /神崎川/
かんざけ /燗酒/
かんざし /簪/
かんざぶろう /勘三郎/
かんざまし /燗冷まし;まずっ/
かんざらし /寒晒し/
かんざん /換算/
かんざんかのう /換算可能/
かんざんしき /換算式/
かんざんじ /舘山寺/
かんざんじっとく /寒山拾得;画題/
かんざんひょう /換算表/
かんざんび /換算日/
かんし /監視/漢詩/冠詞;[文法]article/鉗子;(手術道具)forceps/看視;気を付け見守る。「病人の-」/干支;=えと/管子/官司/幹枝/環視;取り巻いて見る。「衆人-」/諫止;いさめて止める/諫死;死んでいさめる/敢死;≒決死/
かんしいん /監視員/
かんしかつどう /監視活動/
かんしかめら /監視カメラ/
かんしき /乾式/鑑識/環式/
かんしきか /鑑識課/
かんしきがん /鑑識眼/
かんしきき /監視機器/
かんしききょう /漢式鏡/
かんしきこう /漢詩紀行/
かんしきこうほう /乾式工法;dry construction/
かんしきはん /鑑識班/
かんししゃ /監視車/
かんししょう /監視哨;lookout/
かんしじょ /監視所/
かんしだん /監視団/
かんしち /環七/
かんしつ /間質/乾湿/乾漆;dry lacquer/
かんしつけい /乾湿計/
かんしつせいはいえん /間質性肺炎;[医]/
かんして /関して/
かんしぼう /肝脂肪/
かんしもう /監視網/
かんしゃ /感謝/官舎/観者;「かんじゃ」とも/官社/檻車;昔の護送車/患者;かんじゃ?/甘蔗/
かんしゃかんげき /感謝感激/
かんしゃきん /感謝金/
かんしゃく /癇癪/官爵/疳積;幼児の貧血/
かんしゃくだま /癇癪玉/かんしゃく玉/
かんしゃくもち /癇癪持ち/
かんしゃさい /感謝祭/
かんしゃじょう /感謝状/
かんしゃめん /緩斜面/
かんしやく /監視役/
かんしゅ /看守;†guard.「刑務所の-」/看取;†perceive.「意図を-する」/艦首;bow/艦種/監守;†guard and control.「危険物を-する」/巻首/関手/肝腫/緩手/観取;見て取る/感取;感じ取る/函手;[数学]/凾手;異体字/
かんしゅう /監修/慣習/観衆/甘州/
かんしゅうか /慣習化/
かんしゅうこくさいほう /慣習国際法/
かんしゅうしゃ /監修者/
かんしゅうてき /慣習的/
かんしゅうばん /監修版/
かんしゅうほう /慣習法/
かんしゅかんせい /間主観性/
かんしゅく /甘粛/
かんしょ /官署/漢書/寒暑/甘蔗/甘薯/
かんしょう /鑑賞;†理解し味わう。「映画-」/観賞;†見て楽しむ。「-魚」/干渉/感傷;sentiment/完勝/勧奨;encourage/緩衝/環礁/管掌/観照;†contemplate/寛正;年号(1460-1466)/冠省;(手紙の)前文略/官省;ministries/観象;気象観測/冠称;=角書(つのがき)/冠賞/感賞;praise/勧賞;prise/癇性/簡捷/
かんしょうえき /緩衝液/
かんしょうかい /鑑賞会;映画の-/観賞会;熱帯魚の-/
かんしょうがん /鑑賞眼/
かんしょうぎょ /観賞魚/
かんしょうけい /干渉計/緩衝系/
かんしょうけいさん /干渉計算/
かんしょうこく /緩衝国/
かんしょうご /鑑賞後/
かんしょうさよう /緩衝作用/
かんしょうざい /緩衝材/
かんしょうしゃ /鑑賞者/観賞者/
かんしょうしゅぎ /感傷主義/
かんしょうしょく /干渉色/
かんしょうじま /干渉縞/
かんしょうせい /干渉性/
かんしょうそうち /緩衝装置/
かんしょうたい /緩衝帯;buffer zone/干渉帯;interference zone/
かんしょうだんたい /鑑賞団体/
かんしょうちたい /緩衝地帯/
かんしょうちゅう /観賞中/
かんしょうてき /感傷的/
かんしょうは /干渉波/
かんしょうひん /観賞品/
かんしょうほうほう /観賞方法/
かんしょうやく /緩衝役/
かんしょうよう /観賞用/鑑賞用/
かんしょうようえき /緩衝溶液/
かんしょく /感触/間食/完食/官職/寒色/間色/閑職/寒食/
かんしょくけい /寒色系/
かんしょくめい /官職名/
かんしょとう /甘蔗糖/
かんしん /関心;†interest.「-がある」/感心;†admiration.「-する」/汗疹;あせも/歓心;†favour.「-を買う」/奸臣/感震/寒心;肝を冷やす/甘心;満足・納得/姦臣;=奸臣/
かんしんじ /関心事/
かんしんじこう /関心事項/
かんしんせい /完新世;[地質年代]Holocene. 1万年前-現在/
かんしんど /関心度/
かんじ /漢字/幹事;manager/監事;inspector/感じ/寛治;年号(1087-1094)/莞爾;にっこり。「-と笑う」/完爾;人名/完治;かんち/官寺;⇔私寺/換字/冠辞;枕言葉/完児;人名/
かんじいがい /漢字以外/
かんじおん /漢字音/
かんじか /漢字化/
かんじかい /幹事会/
かんじかた /感じ方/
かんじかなまじり /漢字仮名交じり/
かんじかなまじりぶん /漢字かな混じり文/
かんじかんけい /漢字関係/
かんじがいしゃ /幹事会社/
かんじがく /漢字学/
かんじがっかい /幹事学会/
かんじがわ /幹事側/
かんじき /橇/
かんじぎょう /閑事業/
かんじけってい /幹事決定/
かんじけんてい /漢字検定/
かんじこーど /漢字コード/
かんじこう /幹事校/
かんじこうほ /漢字候補/
かんじご /漢字語/
かんじさま /幹事様/
かんじざい /観自在;[仏教]観世音/
かんじしょり /漢字処理/
かんじじしょ /漢字辞書/
かんじじてん /漢字辞典/漢字字典/
かんじじゅくご /漢字熟語/
かんじせいげん /漢字制限/
かんじせんたく /漢字選択/
かんじたいおう /漢字対応/
かんじたんまつ /漢字端末/
かんじだいひょう /幹事代表/
かんじだしょう /カンジダ症;[医]candidiasis/
かんじだん /幹事団/
かんじちょう /幹事長/
かんじつげつ /閑日月/
かんじとうろく /漢字登録/
かんじどりる /漢字ドリル/
かんじにゅうりょく /漢字入力/
かんじはつおん /漢字発音/
かんじばん /漢字版/
かんじひょう /漢字表/
かんじひょうき /漢字表記/
かんじひょうじ /漢字表示/
かんじひょうじかのう /漢字表示可能/
かんじふごう /漢字符号/
かんじふごうけい /漢字符号系/
かんじぶぶん /漢字部分/
かんじぶん /漢字分/
かんじぶんか /漢字文化/
かんじぶんかけん /漢字文化圏/
かんじへんかん /漢字変換/
かんじへんかんじしょ /漢字変換辞書/
かんじへんかんほうしき /漢字変換方式/
かんじへんかんよう /漢字変換用/
かんじほうこく /幹事報告/
かんじめい /漢字名/
かんじもじれつ /漢字文字列/
かんじゃ /患者/冠者/間者/観者/
かんじゃかい /患者会/
かんじゃく /閑寂/
かんじゃすう /患者数/
かんじゃふたん /患者負担/
かんじゃふたんわりあい /患者負担割合/
かんじやく /幹事役/
かんじゅ /甘受/感受;-性/貫主/貫首/官需/
かんじゅーす /缶ジュース/
かんじゅうしき /間充織;[生物]mesenchyme/
かんじゅく /完熟/慣熟/
かんじゅくそうこう /慣熟走行/
かんじゅくど /完熟度/慣熟度/
かんじゅくほこう /慣熟歩行/
かんじゅせい /感受性/
かんじゅん /間順/
かんじょ /漢書/官女/緩徐/寛恕/閑所/感書/
かんじょう /感情/勘定/環状/勧請/艦上/管状/灌頂/完乗/冠状/感状/
かんじょういにゅう /感情移入/
かんじょうか /管状花/
かんじょうかもく /勘定科目;簿記の計算単位の各勘定の名称/管状花目/Tubiflorae/
かんじょうがい /勘定外/
かんじょうき /艦上機/
かんじょうきょういく /感情教育;L'Education Sentimentale,Flaubert,1869/
かんじょうけんきゅう /感情研究/
かんじょうこうざ /勘定口座/
かんじょうしょ /勘定書/
かんじょうしょうがい /感情障害/
かんじょうせいうん /環状星雲/
かんじょうせん /環状線/
かんじょうせんてんまえき /環状線天満駅/
かんじょうたい /桿状体;[生物]rod/
かんじょうてき /感情的/
かんじょうてきたいりつ /感情的対立/
かんじょうてきはんぱつ /感情的反発/
かんじょうでんたつ /感情伝達/
かんじょうなど /感情等/
かんじょうはんのう /感情反応/
かんじょうひょうげん /感情表現/
かんじょうぶぎょう /勘定奉行/
かんじょうみゃく /冠静脈/
かんじょうめん /感情面/
かんじょうようそ /管状要素/
かんじょうれっせき /環状列石/
かんじょうろん /感情論/
かんじょきん /緩徐筋/
かんじよう /漢字用/
かんじれつ /漢字列/
かんじん /肝心/肝腎/官人/勧進/閑人/寛仁/漢人/韓人/
かんじんかなめ /肝心要/
かんじんずもう /勧進相撲/
かんじんたいど /寛仁大度/
かんじんちょう /勧進帳/
かんじんもと /勧進元/
かんすい /完遂/冠水/灌水/潅水;異体字/鹹水;⇔淡水/漢水;地名,長江の支流/
かんすいきんぞく /関水金属/
かんすいぎょ /寒水魚/鹹水魚/
かんすいせき /寒水石/
かんすう /関数/巻数/函数/函數/
かんすうかいせき /関数解析/函数解析/
かんすうかいせきがく /関数解析学/
かんすうかん /関数環/
かんすうがい /関数外/
かんすうがた /関数型/函数型/
かんすうがたげんご /関数型言語/
かんすうきごう /関数記号/
かんすうくうかん /関数空間/
かんすうぐん /関数群/
かんすうけい /関数系/関数型/関数形/
かんすうけいさん /関数計算/
かんすうごうせい /関数合成/
かんすうじ /漢数字/
かんすうじへんかん /漢数字変換/
かんすうせんげん /関数宣言/
かんすうぜんたい /関数全体/
かんすうぞく /関数族/
かんすうち /関数値/
かんすうていぎ /関数定義/
かんすうていすう /関数定数/
かんすうてき /関数的/
かんすうてきよう /関数適用/
かんすうでんたく /関数電卓/
かんすうない /関数内/
かんすうひきすう /関数引数/
かんすうひょう /関数表/
かんすうひょうげん /関数表現/
かんすうほうていしき /関数方程式/
かんすうめい /関数名/
かんすうよびだし /関数呼び出し/
かんすうろん /関数論/函数論/
かんすぼん /巻子本/
かんする /関する/
かんず /貫主/貫首/
かんせい /完成/感性/歓声/閑静/管制;control/慣性/寛政;年号(1789-1801)/官製;-葉書/乾性/陥穽/官制;行政機関の規定/間性;[生物]intersex/喚声;叫び声/甘精;saccharine/甘井/喊声;ときの声/監製/感声;感嘆の声/乾生;[植物]⇔湿生/関西/
かんせいうんどう /慣性運動/
かんせいかい /感性界;mundus sensibilis/
かんせいかん /管制官/
かんせいがくいん /関西学院/
かんせいがくいんだい /関西学院大/
かんせいがくいんだいがく /関西学院大学/
かんせいけい /慣性系/
かんせいこうほう /慣性航法/
かんせいご /完成後/
かんせいししゃかい /完成試写会/
かんせいしつ /管制室/
かんせいしつりょう /慣性質量/
かんせいしゃ /完成車/
かんせいしょくぶつ /乾生植物;xerophyte/
かんせいじ /完成時/
かんせいじょうほう /感性情報/
かんせいじょうほうしょり /感性情報処理/
かんせいていこう /慣性抵抗/
かんせいてき /感性的/
かんせいてんそる /慣性テンソル/
かんせいとう /管制塔/
かんせいとじょう /完成途上/
かんせいど /完成度/
かんせいのうりつ /慣性能率/
かんせいのかいかく /寛政の改革;[日本史]天明7-寛政5(1787-93),松平定信/
かんせいはがき /官製葉書/
かんせいば /慣性場/
かんせいばん /完成版/
かんせいひん /完成品/
かんせいめい /官姓名/
かんせいもーめんと /慣性モーメント/
かんせいゆ /乾性油/
かんせいよてい /完成予定/
かんせいりょく /慣性力/
かんせいれき /寛政暦/
かんせき /漢籍/艦籍/寛晰/
かんせつ /関節;joint/間接;indirect/冠雪/官設/環節/
かんせつ> /間接;-操作,-疑問/
かんせつえき /関節液/
かんせつえん /関節炎/
かんせつおん /間接音/
かんせつかく /関節角/
かんせつきつえん /間接喫煙/
かんせつきょう /関節鏡/
かんせつきょうしか /関節鏡視下/
かんせつきょうせい /間接強制/
かんせつきんゆう /間接金融/
かんせつさぎょう /間接作業/
かんせつさんしょう /間接参照/
かんせつしょう /関節症/
かんせつしょうこ /間接証拠/
かんせつしょうめい /間接照明/
かんせつすい /間接水/
かんせつすいしゅ /関節水腫/
かんせつせんきょ /間接選挙/
かんせつせんきょせい /間接選挙制/
かんせつぜい /間接税/
かんせつつう /関節痛/
かんせつてき /間接的/
かんせつてん /関節点/
かんせつでんせん /間接伝染/
かんせつとうし /間接投資/
かんせつひ /間接費/
かんせつぶ /間接部/
かんせつほう /間接法/関節包/
かんせつみんしゅせい /間接民主制/
かんせつもくてきご /間接目的語/
かんせつわざ /関節技/
かんせつわほう /間接話法/
かんせん /感染/観戦/幹線/艦船/汗腺/乾癬/艦戦;[略語]艦上戦闘機/官選/官撰/
かんせんか /感染価/
かんせんかい /観戦会/
かんせんかくだい /感染拡大/
かんせんき /観戦記/
かんせんきぼう /観戦希望/
かんせんきゃく /観戦客/
かんせんけいろ /感染経路/
かんせんけん /観戦券/
かんせんげん /感染源/
かんせんご /感染後/
かんせんしゃ /感染者/観戦者/
かんせんしゃすう /感染者数/
かんせんしょう /感染症/
かんせんしょうよぼういりょうほう /感染症予防医療法/
かんせんじ /観戦時/
かんせんじょう /観戦上/
かんせんせい /感染性/
かんせんせつ /感染説/
かんせんちゅう /観戦中/感染中/
かんせんどうろ /幹線道路/
かんせんべんごにん /官選弁護人/
かんせんようしき /感染様式/
かんせんりつ /感染率/
かんせんりょく /感染力/
かんぜ /観世/
かんぜい /関税/勧説/
かんぜいけいさつ /関税警察/
かんぜいしょうへき /関税障壁/
かんぜいじしゅけん /関税自主権/
かんぜいじょうきょ /関税譲許/
かんぜいせいさく /関税政策/
かんぜいていりつほう /関税定率法/
かんぜいどうめい /関税同盟/
かんぜいほう /関税法/
かんぜいりつ /関税率/
かんぜおん /観世音/
かんぜおんじ /観世音寺/
かんぜおんぼさつ /観世音菩薩/
かんぜつ /冠絶/
かんぜりゅう /観世流/
かんぜん /完全/勧善/敢然/間然;「-する所がない」(=perfect)/煥然;(brillant)「-と輝く」/
かんぜん> /完全;-限定版,-年表,-４度/
かんぜんいしょく /完全移植/
かんぜんいっち /完全一致/
かんぜんうらがき /完全裏書/
かんぜんえん /完全円/
かんぜんか /完全化/完全花;[植物]perfect flower/
かんぜんかい /完全解/
かんぜんかいとう /完全解答/
かんぜんきょうそう /完全競争/
かんぜんきんえん /完全禁煙/
かんぜんきんし /完全禁止/
かんぜんけっちゃく /完全決着/
かんぜんげんてい /完全限定/
かんぜんげんていばん /完全限定版/
かんぜんこしつ /完全個室/
かんぜんこよう /完全雇用;full employment/
かんぜんごかん /完全互換/
かんぜんさつじんじけん /完全殺人事件/
かんぜんしあい /完全試合/
かんぜんしつぎょうしゃ /完全失業者/
かんぜんしつぎょうりつ /完全失業率;[経済]求職していない失業者を計算に含めない失業率/
かんぜんしてい /完全指定/
かんぜんしゅうろく /完全収録/
かんぜんしゅうろくばん /完全収録版/
かんぜんしゅぎ /完全主義/
かんぜんしゅぎしゃ /完全主義者/
かんぜんしょうとう /完全消灯/
かんぜんじあい /完全試合/
かんぜんじどう /完全自動/
かんぜんじどううんてん /完全自動運転/
かんぜんじゅくすい /完全熟睡/
かんぜんじゅんきょ /完全準拠/
かんぜんすう /完全数/
かんぜんせい /完全性/
かんぜんせいき /完全正規/
かんぜんせいていり /完全性定理/
かんぜんせいは /完全制覇/
かんぜんそうび /完全装備/
かんぜんたい /完全体/
かんぜんたいおう /完全対応/
かんぜんちゅうけい /完全中継/
かんぜんちょうあく /勧善懲悪/
かんぜんちょっこう /完全直交/
かんぜんとういつ /完全統一/
かんぜんどうさ /完全動作/
かんぜんに /完全に/
かんぜんねんしょう /完全燃焼/
かんぜんはんざい /完全犯罪/
かんぜんはんしゃ /完全反射/
かんぜんばん /完全版/
かんぜんひせっしょく /完全非接触/
かんぜんひてい /完全否定/
かんぜんふっかつ /完全復活/
かんぜんふっき /完全復帰/
かんぜんふっきゅう /完全復旧/
かんぜんふっこくばん /完全復刻版/
かんぜんぶあい /完全歩合/
かんぜんぶあいせい /完全歩合制/
かんぜんぶそう /完全武装/
かんぜんぶんえん /完全分煙/
かんぜんぶんり /完全分離/
かんぜんへんけい /完全変形/
かんぜんへんたい /完全変態/
かんぜんほうえい /完全放映/
かんぜんほうかい /完全崩壊/
かんぜんほうそう /完全放送/
かんぜんほうでん /完全放電/
かんぜんほしょう /完全保証/
かんぜんほそう /完全舗装/
かんぜんぼうび /完全防備/
かんぜんみっぷう /完全密封/
かんぜんみっぺいがた /完全密閉型/
かんぜんむけつ /完全無欠/
かんぜんむし /完全無視/
かんぜんむせいげん /完全無制限/
かんぜんむりょう /完全無料/
かんぜんゆうしょう /完全優勝/
かんぜんよやくげんてい /完全予約限定/
かんぜんよやくせい /完全予約制/
かんぜんよやくはんばい /完全予約販売/
かんぜんりゅうたい /完全流体/
かんぜんわやく /完全和訳/
かんそ /簡素/
かんそう /感想/乾燥/完走/間奏/換装/歓送/乾草/観想;contemplation.「-に耽る」/観相;physiognomy.「-術」/完奏/閑窓;[漢語]静かな家/間想/
かんそうかい /歓送会/
かんそうがく /観相学/
かんそうき /乾燥機/乾燥器/
かんそうきかん /乾燥期間/
かんそうきょく /間奏曲/
かんそうくうき /乾燥空気/
かんそうげい /歓送迎/
かんそうげいかい /歓送迎会/
かんそうこ /乾倉庫/
かんそうご /乾燥後/
かんそうざい /乾燥剤/
かんそうしつ /乾燥室/
かんそうしゃ /完走者/
かんそうじゅうりょう /乾燥重量/
かんそうせいざい /乾燥製剤/
かんそうせん /感想戦/
かんそうちたい /乾燥地帯/
かんそうちゅういほう /乾燥注意報/
かんそうど /乾燥度/
かんそうなど /感想等/
かんそうはだ /乾燥肌;カサカサの-/
かんそうぶ /間奏部/
かんそうぶん /感想文/
かんそうやさい /乾燥野菜/
かんそうゆ /乾燥油/
かんそうよう /乾燥用/
かんそうらん /乾燥卵/
かんそうりつ /完走率/
かんそうろめん /乾燥路面/
かんそか /簡素化/
かんそく /観測/緩速;slow/患側;[医]affected side/管束;[植物]bundle/
かんそくえいせい /観測衛星/
かんそくかい /観測会/
かんそくかのう /観測可能/
かんそくがぞう /観測画像/
かんそくき /観測機/観測器/
かんそくききゅう /観測気球;ballon d'essai(ばろんでっせ)/
かんそくけい /観測系/
かんそくけいけん /観測経験/
かんそくけっか /観測結果/
かんそくこんなん /観測困難/
かんそくしじょう /観測史上/
かんそくしゃ /観測者/
かんそくしょ /観測所/
かんそくじじつ /観測事実/
かんそくじょ /観測所/
かんそくすじ /観測筋/
かんそくせん /観測船/
かんそくたいしょう /観測対象/
かんそくち /観測地/観測値/
かんそくちてん /観測地点/
かんそくてん /観測点/
かんそくてんすう /観測点数/
かんそくばしょ /観測場所/
かんそくふかのう /観測不可能/
かんそくふのう /観測不能/
かんそくほうていしき /観測方程式/
かんそくもう /観測網/
かんそくりょう /観測量/
かんそくれき /観測歴/
かんそん /寒村/
かんそんみんぴ /官尊民卑/
かんぞう /肝臓/甘草/鑑三/
かんぞういろ /萱草色/
かんぞうがん /肝臓癌/肝臓がん/肝臓ガン/
かんぞうきのう /肝臓機能/
かんぞうびょう /肝臓病/
かんぞく /漢族/奸賊/姦賊/
かんた /幹太/
かんたい /艦隊/歓待/寒帯/簡体;⇔繁体/艦体/桿体;-細胞/冠帯/緩怠/款待;=歓待/冠体/鑑隊;?/
かんたいか /簡体化/
かんたいきかん /艦隊旗艦/
かんたいきどう /艦隊機動/
かんたいこうどう /艦隊行動/
かんたいじ /簡体字/
かんたいせん /艦隊戦/
かんたいは /艦隊派/
かんたいへいよう /環太平洋/
かんたく /干拓/乾拓/
かんたくち /干拓地/
かんたろう /勘太郎/間太郎/
かんたん /簡単/感嘆/肝胆;-相照らす/邯鄲;-の夢/感歎;=感嘆/簡單;「単」旧字/簡短/
かんたんか /簡単化/
かんたんし /感嘆詞/
かんたんじ /簡単字/
かんたんふ /感嘆符;！/
かんたんぶん /感嘆文/
かんたんめいりょう /簡単明瞭/
かんだ /神田/苅田/関田/
かんだい /寛大/関大/漢代/棺台/
かんだいせん /関大戦/
かんだいまえ /関大前/
かんだいまええき /関大前駅/
かんだえき /神田駅/
かんだか /甲高/
かんだかん /神田間/
かんだがわ /神田川/神田側/
かんだこしょ /神田古書/
かんだじょがくえん /神田女学園/
かんだじんぼうちょう /神田神保町/
かんだち /神立/
かんだちこうげん /神立高原/
かんだつ /神立/
かんだほんてん /神田本店/
かんだまつり /神田祭;5.15/
かんだみょうじん /神田明神/
かんだん /歓談/寒暖/間断/閑談/
かんだんけい /寒暖計/
かんだんさ /寒暖差/
かんち /感知;sense/完治/関知;concern/換地/寒地/監置/官治/奸智/閑地/奸知/姦智/
かんちがい /勘違い/
かんちき /感知器/
かんちく /患畜/寒竹/漢竹/
かんちしょぶん /換地処分/
かんちそうち /感知装置/
かんちつ /巻帙/
かんちばん /感知板/
かんちゃく /緩着;(囲碁などで)緩すぎる手/
かんちゃん /嵌張;[麻雀]/
かんちゅう /寒中/管中/勘注/冠注/
かんちゅうすいえい /寒中水泳/
かんちゅうはい /缶酎ハイ/
かんちょう /館長/官庁/艦長/浣腸/干潮/管長/完調/間諜/灌頂/官長/勧懲;勧善懲悪/
かんちょうがい /官庁街/
かんちょうき /浣腸器/
かんちょうじ /干潮時/
かんつ /槓子/
かんつい /完遂;「かんすい」の誤読/
かんつう /貫通/姦通/
かんつうがわ /貫通側/
かんつうざい /姦通罪/
かんつうしき /貫通式/
かんつうじゅうそう /貫通銃創/
かんつうとびら /貫通扉/
かんつうりょく /貫通力/
かんつうろ /貫通路/
かんつばき /寒椿/
かんづかさ /主神/
かんづくり /寒造り;-の酒/
かんづめ /缶詰/缶詰め/罐詰/
かんてい /鑑定/官邸/艦艇/勘亭/
かんていしょ /鑑定書/
かんていしょく /艦底色/
かんていない /艦艇内/
かんていにん /鑑定人/
かんていりゅう /勘亭流/
かんてき /観的/看的/
かんてくすとせい /間テクスト性;intertextualite(仏) cf.R.Barthes/
かんてつ /貫徹;†carry through.「初志-」/完徹;†完全な徹夜。「-で仕上げる」/関鉄/肝蛭;ヌートリアにつく寄生虫/官鉄/
かんてん /観点/寒天/干天/旱天/官展;le Salon/
かんてんきち /歓天喜地/
かんてんしつ /寒天質;ゼラチン質/
かんてんのじう /干天の慈雨/
かんてんぼうき /観天望気/
かんでん /感電/関電/乾田/
かんでんこう /関電工;[企業名]/
かんでんし /感電死/
かんでんち /乾電池/
かんでんちしき /乾電池式/
かんと /官途/
かんとう /関東/巻頭/完投/竿頭/敢闘/間道;舶来の織物/竿灯/完答/冠頭/
かんとうい /貫頭衣/
かんとういがい /関東以外/
かんとういち /関東一/
かんとういちえん /関東一円/
かんとうおおてしてつ /関東大手私鉄/
かんとうからー /巻頭カラー/
かんとうかんれい /関東管領/
かんとうがくいん /関東学院/
かんとうがくいんせん /関東学院戦/
かんとうがくいんだい /関東学院大/
かんとうがくいんだいがく /関東学院大学/
かんとうがくいんむつうら /関東学院六浦/
かんとうがくせい /関東学生/
かんとうがた /完投型/
かんとうきじ /巻頭記事/
かんとうきんけん /関東近県/
かんとうきんこう /関東近郊/
かんとうぐん /関東軍/關東軍;「関」旧字/
かんとうけい /関東系/
かんとうけん /関東圏/
かんとうげん /巻頭言/
かんとうこうしんえつ /関東甲信越/
かんとうこくさい /関東国際/
かんとうし /間投詞/
かんとうしぶ /関東支部/
かんとうしゅっしんしゃ /関東出身者/
かんとうしょう /敢闘賞/
かんとうしょうり /完投勝利/
かんとうしんえつこくぜいきょく /関東信越国税局/
かんとうじょし /間投助詞/
かんとうじょしがくせい /関東女子学生/
かんとうじん /関東人/
かんとうせん /関東戦/
かんとうせんしゅしょう /敢闘選手賞/
かんとうぜい /関東勢/
かんとうぜんぱん /関東全般/
かんとうたいかい /関東大会/
かんとうだいがく /関東大学/
かんとうだいしんさい /関東大震災/
かんとうだき /関東炊き/
かんとうちいき /関東地域/
かんとうちく /関東地区/
かんとうちくいがい /関東地区以外/
かんとうちほう /関東地方/
かんとうてつどう /関東鉄道/
かんとうでんし /関東電子/
かんとうとくしゅう /巻頭特集/
かんとうに /関東煮/
かんとうば /関東馬/
かんとうばん /関東版/
かんとうふう /関東風/
かんとうへいや /関東平野/
かんとうべん /関東弁/
かんとうよう /関東用/
かんとうりゅう /関東流/
かんとうれんめい /関東連盟/
かんとうろーむ /関東ローム/
かんとうろーむそう /関東ローム層/
かんとうろうさいびょういん /関東労災病院/
かんとく /監督/感得/寛徳;年号(1044-1046)/
かんとくいん /監督員/
かんとくえん /関特演/
かんとくか /監督下/
かんとくかん /監督官/
かんとくかんちょう /監督官庁/
かんとくきかん /監督機関/
かんとくけん /監督権/
かんとくさく /監督作/
かんとくさくひん /監督作品/
かんとくしゃ /監督者/
かんとくしょう /監督賞/
かんとくじん /監督陣/
かんとくすいせん /監督推薦/
かんとくせきにん /監督責任/
かんとくだいこう /監督代行/
かんとくちょう /監督庁/
かんとん /広東/嵌頓/
かんとんご /広東語/廣東語;「広」旧字/
かんとんふう /広東風/
かんとんめん /広東麺/
かんとんりょうり /広東料理/
かんど /感度/神戸;地名,鳥取/
かんどう /感動/勘当/完動/間道/官道/貫道/
かんどうさく /感動作/
かんどうし /感動詞/
かんどうてき /感動的/
かんどうひん /完動品/
かんどうみゃく /冠動脈;[解剖](心臓の)coronary artery/肝動脈;[解剖](肝臓の)hepatic artery/
かんどうもの /感動物/感動モノ/
かんどころ /勘所/
かんどせってい /感度設定/
かんどちょうせい /感度調整/
かんどっく /乾ドック;dry dock/
かんどてん /感度点/
かんどぶんぷ /感度分布/
かんどり /神取/
かんな /鉋/寛和;年号(985-987)/
かんない /館内/管内;管轄内/関内;地名,横浜/艦内/幹内/
かんないえき /関内駅/
かんながら /随神/
かんなぎ /巫/覡/
かんなくず /鉋屑/
かんなぜん /看話禅/
かんなづき /神無月;陰暦11月/
かんなな /環七/
かんなべ /神辺/
かんなみ /函南/
かんなめさい /神嘗祭;伊勢神宮/
かんなり /金成/
かんなん /艱難;hardship.「-汝を玉にす」/患難;grief. 憂い/
かんなんしんく /艱難辛苦/
かんにち /韓日/
かんにほんかい /環日本海/
かんにゅう /貫入;つらぬき入る/陥入;おちこみ入る/嵌入;はまりこむ/観入/
かんにょ /官女/
かんにょう /凵繞/
かんにん /堪忍/官人/寛仁;年号(1017-1021)/
かんにんぶくろ /堪忍袋/
かんぬき /閂/貫木;=閂/
かんぬし /神主/
かんねい /奸佞/姦佞/
かんねつ /感熱/乾熱/
かんねつし /感熱紙/
かんねつしき /感熱式/
かんねん /観念/
かんねんけいたい /観念形態;ideology/
かんねんしょうせつ /観念小説/
かんねんせい /観念性/
かんねんてき /観念的/
かんねんてききょうごう /観念的競合/
かんねんろん /観念論/
かんねんろんしゃ /観念論者/
かんの /菅野;くさかんむり/神野/管野;たけかんむり/冠野/
かんのう /官能/感応/完納/間脳/還納/肝脳/感能;?/
かんのうがた /感応型/
かんのうき /官能基;[化学]functional group/
かんのうしき /感応式/
かんのうしゃしんしゅう /官能写真集/
かんのうしょうせつ /官能小説/
かんのうせい /官能性;sensuality/感応性;responsiveness/
かんのうせいしんびょう /感応精神病;[精医]folie a deux/
かんのうせかい /官能世界/
かんのうてき /官能的/
かんのうど /感応度/
かんのうび /官能美/
かんのき /閂;=かんぬき/
かんのすが /管野スガ/
かんのむし /疳の虫/
かんのん /観音/
かんのんきょう /観音教/
かんのんぎょう /観音経/
かんのんさま /観音様/
かんのんざき /観音崎/
かんのんじ /観音寺/
かんのんぞう /観音像/
かんのんちく /観音竹;[植物]ヤシ科/
かんのんとうげ /観音峠/
かんのんどう /観音堂/
かんのんびらき /観音開き/
かんのんぼさつ /観音菩薩/
かんはっしゅう /関八州/
かんはつ /間髪/
かんば /樺/悍馬/汗馬/駻馬/燗場/
かんばい /完売/寒梅/観梅/
かんばいこ /寒梅粉/
かんばく /艦爆/
かんばせ /顔/
かんばっじ /缶バッジ/
かんばつ /間伐/旱魃/干魃/簡抜/
かんばつざい /間伐材/
かんばのろう /汗馬の労/
かんばめい /冠馬名/
かんばやし /上林/神林/
かんばら /蒲原/神原/
かんばん /看板/乾板/燗番/
かんばんしょうひん /看板商品/
かんばんじょゆう /看板女優/
かんばんせんしゅ /看板選手/
かんばんだおれ /看板倒れ/
かんばんまえ /看板前/
かんばんむすめ /看板娘/
かんばんや /看板屋/
かんばんれっしゃ /看板列車/
かんぱ /寒波/看破/
かんぱい /乾杯/完敗/
かんぱく /関白/
かんぱけ /完パケ/
かんぱち /環八;環状八号線/間八;[魚]/
かんぱつ /間髪;-を入れず/煥発;才気-/渙発;詔勅の発布/
かんぱん /甲板/乾パン/乾板;[写真]dry plate/干犯;干渉・侵犯/
かんぱんいん /甲板員/
かんび /完備/甘美/艦尾/巻尾/完美/
かんびーる /缶ビール/
かんびか /完備化/
かんびせい /完備性/
かんびそく /完備束/
かんびょう /看病/
かんびん /簡便/
かんぴ /韓非;始皇帝の時代の韓の公子/官費/乾皮;-症/
かんぴし /韓非子;始皇帝の時代の韓の公子/
かんぴしょう /柑皮症;ミカンの食べ過ぎで肌が黄色くなります/
かんぴょう /鑑評/干瓢/乾瓢/
かんぴょうかい /鑑評会/
かんぴょうき /間氷期/
かんふー /功夫/
かんふぜん /肝不全;[医]/
かんふるちゅうしゃ /カンフル注射;camphor/
かんぶ /幹部/患部/官武/
かんぶかい /幹部会/
かんぶくろ /紙袋;♪猫を-に押し込んで/
かんぶこうほ /幹部候補/
かんぶこうほせい /幹部候補生/
かんぶしゃいん /幹部社員/
かんぶしょくいん /幹部職員/
かんぶつ /乾物/官物/換物/灌仏/観仏/奸物/干物/
かんぶつえ /灌仏会;4.8/潅仏会;異体字/
かんぶつや /乾物屋/
かんぶり /寒ブリ/寒鰤/
かんぶりあき /カンブリア紀;[地質年代]Cambrian. 5700-5100万年前/
かんぶん /漢文/寛文;年号(1661-1673)/
かんぶんがく /漢文学/
かんぶんくんどくたい /漢文訓読体/
かんぶんてき /漢文的/
かんぷ /還付/完膚/乾布/関釜/官府/姦婦/姦夫/
かんぷう /完封/寒風/
かんぷうかい /観楓会;北海道のみ通じる単語ですか？/
かんぷうざん /寒風山/
かんぷうしょうり /完封勝利/
かんぷきん /還付金/
かんぷく /感服/官服/
かんぷしんこく /還付申告/
かんぷせいきゅう /還付請求/
かんぷまさつ /乾布摩擦/
かんぷれんらくせん /関釜連絡船/
かんぷん /感奮/
かんべ /神戸/神部/
かんべえ /勘兵衛/
かんべつ /鑑別/
かんべつしょ /鑑別所/
かんべに /寒紅/
かんべん /勘弁/簡便/
かんべんか /簡便化/
かんべんせい /簡便性/
かんべんほう /簡便法/
かんぺい /寛平;年号(889-898)/勘平/干貝/
かんぺいしき /観兵式/
かんぺいしゃ /官幣社/
かんぺき /完璧/癇癖/完ぺき/
かんぺきしゅぎ /完璧主義/
かんぺきばん /完璧版/
かんぺん /官辺/
かんぺんすじ /官辺筋/
かんぼう /官房;「内閣-」/観望/感冒/監房;ward/冠帽/奸謀/姦謀;=奸謀/
かんぼうかい /観望会/
かんぼうきみつひ /官房機密費/
かんぼうち /観望地/
かんぼうちょう /官房長/
かんぼうちょうかん /官房長官/
かんぼうやく /感冒薬/
かんぼうよう /観望用/
かんぼく /灌木/潅木;異体字 =灌木/翰墨/
かんぼじあ /柬蒲寨/
かんぼつ /陥没/
かんぽ /簡保;[略語]簡易保険/
かんぽう /漢方/官報/館報/寛保;年号(1741-1744)/艦砲/観法;[仏教]/汗疱;水虫/咸豐;清の年号(1851-1861),旧字/
かんぽうい /漢方医/
かんぽういがく /漢方医学/
かんぽういりょう /漢方医療/
かんぽうのまじわり /管鮑の交わり/
かんぽうやく /漢方薬/
かんぽうやくや /漢方薬屋/
かんぽん /刊本/完本/官本/監本/韓本/
かんまき /上牧/
かんまく /間膜/
かんまつ /巻末/
かんまつちゅう /巻末注/
かんまつふろく /巻末付録/
かんまん /緩慢/干満/
かんみ /甘味/鹹味/寛美/
かんみざい /甘味剤/
かんみどころ /甘味処/
かんみゃく /間脈/
かんみょう /漢名;=かんめい/
かんみりょう /甘味料/
かんみん /官民/
かんみんいったい /官民一体/
かんみんぞく /漢民族/韓民族/
かんむ /桓武/官務/
かんむし /完無視/
かんむてんのう /桓武天皇/
かんむへいし /桓武平氏/
かんむり /冠/
かんむりざ /冠座;Corona Borealis(CrB)/
かんむりょう /感無量/
かんめ /貫目/
かんめい /感銘/簡明/官名/艦名/漢名/官命/
かんめいか /簡明化/
かんめん /乾麺/管面/
かんもう /換毛;生え変わり/冠毛;トサカ/
かんもく /緘黙/
かんもじ /閑文字/
かんもち /寒餅/
かんもん /関門/喚問/環紋/
かんもんかいきょう /関門海峡/
かんもんきょう /関門橋/
かんもんじ /閑文字/
かんもんてつどう /関門鉄道/
かんや /寒夜/
かんやく /監訳/完訳/漢訳/簡約/漢薬/
かんやくか /簡約化/
かんやくけい /簡約形/
かんやくしゃ /監訳者/
かんやくばん /完訳版/
かんやくりつ /簡約律/
かんやどり /神宿り/
かんゆ /肝油/換喩;[修辞]metonymy/
かんゆう /勧誘/官有/奸雄/姦雄;=奸雄/
かんゆういん /勧誘員/
かんゆうざいさん /官有財産/
かんゆうでんわ /勧誘電話/
かんゆうほうほう /勧誘方法/
かんゆうりん /官有林/
かんゆてき /換喩的/
かんゆほう /換喩法/
かんよ /関与/干与;≒関与/
かんよう /寛容/肝要/涵養/慣用/官用/観葉;-植物/間葉;[生物]mesenchyme/官窯/漢陽;(Hanyang) 湖北省の都市/咸陽;(Xianyang) 陝西省の都市/観洋/簡要/
かんようおん /慣用音/
かんようか /慣用化/
かんようく /慣用句/
かんようご /慣用語;idiom/
かんようしょくぶつ /観葉植物/
かんようてき /慣用的/寛容的/
かんようひょうげん /慣用表現/
かんようめい /慣用名/
かんようよみ /慣用読み;「攪拌」(こうはん)を「かくはん」と読む類/慣用読/
かんようりょく /寛容力/
かんよど /関与度/
かんら /甘楽/
かんらい /寒雷/
かんらく /陥落/歓楽/乾酪;cheese/
かんらくがい /歓楽街/
かんらくそ /乾酪素;casein/
かんらん /観覧/甘藍;cabbage/橄欖;canarium/觀覽;「観覧」旧字/
かんらんがん /橄欖岩/
かんらんざん /橄欖山/
かんらんしゃ /観覧車/
かんらんしょく /橄欖色/
かんらんせき /観覧席/橄欖石/
かんらんよう /観覧用/
かんらんりょう /観覧料/
かんり /管理;manage/監理;supervise/官吏/
かんりいいん /管理委員/
かんりいいんかい /管理委員会/
かんりいん /管理員/
かんりうんえい /管理運営/
かんりうんよう /管理運用/
かんりえいようし /管理栄養士/
かんりか /管理課/管理下/管理化/
かんりかかく /管理価格/
かんりかちょう /管理課長/
かんりかん /管理官/
かんりかんけい /管理関係/
かんりがいしゃ /管理会社/
かんりがえ /管理換/
かんりがかり /管理掛/
かんりがく /管理学/
かんりがわ /管理側/
かんりき /管理機/
かんりきこう /管理機構/
かんりきてい /管理規定/
かんりきのう /管理機能/
かんりきょういく /管理教育/
かんりきょく /監理局/
かんりぎじゅつ /管理技術/
かんりぎょうむ /管理業務/
かんりぎょうむしゃ /管理業務者/
かんりくいき /管理区域/
かんりくみあい /管理組合/
かんりけいたい /管理形態/
かんりけん /管理権/
かんりけんげん /管理権限/
かんりけんしゅう /管理研修/
かんりこうい /管理行為/
かんりこうがく /管理工学/
かんりこうがっか /管理工学科/
かんりこうざ /管理講座/
かんりこすと /管理コスト/
かんりさいと /管理サイト/
かんりさぎょう /管理作業/
かんりし /管理士/
かんりしつ /管理室/
かんりしゃ /管理者/
かんりしゃいがい /管理者以外/
かんりしゃかい /管理社会/
かんりしゃさま /管理者様/
かんりしゃどうし /管理者同士/
かんりしゃよう /管理者用/
かんりしゅぎ /管理主義/
かんりしゅぎきょういく /管理主義教育/
かんりしゅぎてき /管理主義的/
かんりしゅたい /管理主体/
かんりしょく /管理職/
かんりじむしょ /管理事務所/
かんりじょう /管理上/
かんりじょうたい /管理状態/
かんりじょうほう /管理情報/
かんりせい /管理性/
かんりせいど /管理制度/
かんりせきにん /管理責任/
かんりせきにんしゃ /管理責任者/
かんりそしき /管理組織/
かんりたいけい /管理体系/
かんりたいしょう /管理対象/
かんりたいせい /管理体制/
かんりたんとうしゃ /管理担当者/
かんりつ /官立/
かんりてき /管理的/
かんりてきそくめん /管理的側面/
かんりてじゅん /管理手順/
かんりとう /管理棟/
かんりにん /管理人/
かんりにんいがい /管理人以外/
かんりにんけんげん /管理人権限/
かんりにんこじん /管理人個人/
かんりにんじしん /管理人自身/
かんりにんせい /管理人制/
かんりにんせいど /管理人制度/
かんりにんだいり /管理人代理/
かんりにんほさ /管理人補佐/
かんりのーど /管理ノード/
かんりのうりょく /管理能力/
かんりひ /管理費/
かんりひょう /管理表/管理票/
かんりひよう /管理費用/
かんりぶ /管理部/
かんりぶちょう /管理部長/
かんりぶもん /管理部門/
かんりぶんや /管理分野/
かんりほう /管理法/
かんりほうしき /管理方式/
かんりほうしん /管理方針/
かんりほうほう /管理方法/
かんりほしゅ /管理保守/
かんりほんぶ /管理本部/
かんりぼ /管理簿/
かんりぽすと /監理ポスト;上場廃止のおそれがある銘柄が置かれるポスト/
かんりめいれい /管理命令/
かんりめん /管理面/
かんりゃく /簡略/
かんりゃくか /簡略化/
かんりゃくけい /簡略形/
かんりゅう /韓流;[新語]韓国の流行/還流/貫流/寒流/環流/乾溜/潅流/緩流/
かんりゅうけい /寒流系/
かんりょう /完了/官僚/管領/
かんりょうきこう /官僚機構/
かんりょうけい /完了形/
かんりょうご /完了後/
かんりょうしだい /完了次第/
かんりょうしゅぎ /官僚主義/
かんりょうじ /完了時/
かんりょうせい /官僚制/
かんりょうせいじ /官僚政治/
かんりょうそう /完了相/
かんりょうてき /官僚的/
かんりょうび /完了日/
かんりよう /管理用/
かんりりょう /管理料/監理料/
かんりりょういき /管理領域/
かんりれい /管理令/
かんりん /翰林;文人たち/官林;官有林/寒林;墓地/
かんりんまる /咸臨丸/
かんるい /感涙/
かんれい /慣例/寒冷/管領/艦齢/
かんれいか /寒冷化/慣例化/
かんれいき /寒冷期/
かんれいしゃ /寒冷紗/
かんれいじょう /慣例上/
かんれいぜんせん /寒冷前線/
かんれいち /寒冷地/
かんれいちしよう /寒冷地仕様/
かんれいちよう /寒冷地用/
かんれいてき /慣例的/
かんれき /還暦;60歳/官歴/
かんれきいわい /還暦祝/還暦祝い/
かんれん /関連/關聯;「関」旧字,「聯」別字/
かんれんかいぎしつ /関連会議室/
かんれんがいしゃ /関連会社/
かんれんきかん /関連機関/
かんれんきき /関連機器/
かんれんきぎょう /関連企業/
かんれんきじ /関連記事/
かんれんぎじゅつ /関連技術/
かんれんけんきゅう /関連研究/
かんれんけんきゅうしゃ /関連研究者/
かんれんこうもく /関連項目/
かんれんこく /関連国/
かんれんご /関連語/
かんれんざっし /関連雑誌/
かんれんしせつ /関連施設/
かんれんしつもん /関連質問/
かんれんしゅっぱんぶつ /関連出版物/
かんれんしょ /関連書/
かんれんしょうちょう /関連省庁/
かんれんしょうひん /関連商品/
かんれんしょせき /関連書籍/
かんれんしりょう /関連資料/
かんれんじこう /関連事項/
かんれんじょう /関連上/
かんれんじょうきょう /関連状況/
かんれんじょうほう /関連情報/
かんれんず /関連図/
かんれんせい /関連性/
かんれんせいひん /関連製品/
かんれんだんたい /関連団体/
かんれんちしき /関連知識/
かんれんづけ /関連付け/関連付/
かんれんとうこう /関連投稿/
かんれんとしょ /関連図書/
かんれんぶぶん /関連部分/
かんれんぶんけん /関連文献/
かんれんぶんや /関連分野/
かんれんぺーじ /関連ページ/
かんれんほうあん /関連法案/
かんれんほうき /関連法規/
かんれんようご /関連用語/
かんれんりょういき /関連領域/
かんれんわだい /関連話題/
かんろ /甘露/管路/寒露;[二十四節気]10.9頃/
かんろく /貫禄/勘六/環六/
かんろくじしょ /干禄字書/
かんろくじゅうぶん /貫禄十分/
かんろに /甘露煮/
かんわ /緩和/漢和/閑話/官話/
かんわいりょう /緩和医療;palliative care/
かんわきこう /緩和機構/
かんわきゅうだい /閑話休題/
かんわざ /神事/
かんわざまい /神事舞/
かんわじてん /漢和辞典/漢和字典/
かんわそち /緩和措置/
かんわほう /緩和法/
が /画/我;me/蛾;moth/ヵ;小さなカタカナの「カ」/ヶ;「個」の略字/伽;伽藍/賀;年賀/駕;凌駕/俄;(にわか)俄然/峨;嵯峨/峩;「峨」の異体字/餓;餓死/哦;(うたう)/娥;(みめよい)/莪/鵞;鵞鳥/鵝;「鵞」の異体字/牙;歯牙/芽;萌芽/呀/訝;いぶか・る/臥;座臥/雅;優雅/瓦;瓦解/衙;官衙/果;(連濁)因果/河;大河/訛;なまり/畫;「画」の旧字/ケ/
がーどした /ガード下/
がい /害/外/街/階/甲斐/我意/賀意/買い/慨;憤慨/概;概念/漑;灌漑/凱;凱旋/鎧;(よろい)鎧袖/剴;(きる)/皚/磑;(うす)/亥;辛亥/劾;弾劾/咳;(せき)労咳/該;該当/骸;骸骨/垓;(さかい) 10^20/孩;(ちのみご)孩児/駭;(おどろ・く)驚駭/崖;断崖/崕;「崖」の異体字/涯;生涯/啀;いが・む/睚;(まなじり)/乂/艾;もぐさ/蓋;(ふた)天蓋/葢;「蓋」の異体字1/盖;「蓋」の異体字2/碍;碍子/礙;≒碍子/愾;敵愾心/既;?/
がい> /外;外破音,外陰部,外花蓋/
がいあく /害悪/
がいあつ /外圧/
がいい /外衣/害意/外囲/
がいいん /外因/外陰;[解剖]external genitals. 「-炎,-ジストロフィ」/外印;=げいん/
がいいんせい /外因性/
がいいんぶ /外陰部/
がいうちゅう /外宇宙;⇔内宇宙/
がいえん /外苑;outer garden.「神宮-」/外縁;outer edge.「穴の-」/外延;extension.「-的定義」/外園/外薗;「園」異体字/外炎;[化学]⇔内炎/
がいえんせい /外延性/
がいえんてき /外延的/
がいえんどおり /外苑通り/
がいえんひがしどおり /外苑東通り/
がいえんまえ /外苑前/
がいか /外貨/凱歌/外化/蓋果/
がいかい /外界/外海/
がいかいじょうほう /外界情報/
がいかく /外郭;-団体/外角;-球/外殻/外廓;=外郭/
がいかく> /外郭;(external) -団体,-都市,-概念/
がいかくきゅう /外角球/
がいかくだんたい /外郭団体/
がいかげんきん /外貨現金/
がいかさい /外貨債/
がいかだかんけん /外貨兌換券/
がいかつ /概括/
がいかつてき /概括的/
がいかひ /外果皮/
がいかよきん /外貨預金/
がいかりょうがえ /外貨両替/
がいかん /外観;appearances/概観;overview/外環;[略語]外郭環状道路/外患;内憂-/
がいかんざい /外患罪/
がいかんじょう /外観上/
がいかんてき /概観的/
がいかんどうろ /外環道路/
がいかんび /外観美/
がいがい /皚々/
がいがんきん /外眼筋;[解剖]extraocular muscles/
がいき /外気/
がいきおん /外気温/
がいきけん /外気圏/
がいきゃく /外客/
がいきゅう /鎧球/
がいきょ /街渠/
がいきょう /概況/外教;外国の宗教/外筐/
がいきょく /外局/
がいきれいぼう /外気冷房/
がいきん /外勤/
がいきんこん /外菌根/
がいぎょ /害魚/
がいく /街区/街衢;ちまた/
がいくうかん /外空間/
がいけい /外形/外径/概形/外傾/
がいけいたい /外形態/
がいけいてき /外形的/
がいけいひょうじゅんかぜい /外形標準課税/
がいけん /外見/外圏/
がいけんじょう /外見上/
がいけんてき /外見的/
がいげん /概言/
がいげんご /外言語/
がいこう /外交;diplomacy/外構;exterior/外光;outside light/外向;outgoing/外港;outport/外項;outer term/外寇/
がいこういん /外交員/
がいこうか /外交家/
がいこうかん /外交官/
がいこうかんけい /外交関係/
がいこうきみつひ /外交機密費/
がいこうこうしょう /外交交渉/
がいこうこうじ /外構工事/
がいこうし /外交史/
がいこうしせつ /外交使節/
がいこうじょう /外交上/
がいこうじれい /外交辞令/
がいこうすじ /外交筋/
がいこうせい /外向性/
がいこうせいしょ /外交青書;diplomatic blue book. 外務省発行の青い「白書」/
がいこうせん /外航船/
がいこうだん /外交団/
がいこうてき /外交的/外向的/
がいこうとっけん /外交特権/
がいこうどりょく /外交努力/
がいこうぶ /外交部/
がいこうぶんしょ /外交文書/
がいこうもんだい /外交問題;-に発展する/
がいこうりょく /外交力/
がいこうるい /外肛類/
がいこきゅう /外呼吸/
がいこく /外国/
がいこくえいが /外国映画/
がいこくか /外国課/
がいこくかぶ /外国株/
がいこくかわせ /外国為替/
がいこくかわせおよびがいこくぼうえきかんりほう /外国為替及び外国貿易管理法/
がいこくかわせぎんこう /外国為替銀行/
がいこくかわせこうにんぎんこう /外国為替公認銀行/
がいこくかわせしじょう /外国為替市場/
がいこくかわせそうば /外国為替相場/
がいこくかわせてがた /外国為替手形/
がいこくがた /外国型/
がいこくきぎょう /外国企業/
がいこくぎんこう /外国銀行;foreign bank.「外国の法令に準拠して外国において銀行業を営む者」(銀行法4)/
がいこくけい /外国系/
がいこくこうかん /外国公館/
がいこくこくせき /外国国籍/
がいこくご /外国語/
がいこくごがくぶ /外国語学部/
がいこくごきょういく /外国語教育/
がいこくごやく /外国語訳/
がいこくごろんぶん /外国語論文/
がいこくさい /外国債/
がいこくさん /外国産/
がいこくさんば /外国産馬/
がいこくさんまい /外国産米/
がいこくざい /外国材/
がいこくしほん /外国資本/
がいこくしゅっちょう /外国出張/
がいこくしょうたいば /外国招待馬/
がいこくじどうしゃ /外国自動車/
がいこくじん /外国人/
がいこくじんか /外国人課/
がいこくじんかしゅ /外国人歌手/
がいこくじんかんとく /外国人監督/
がいこくじんさっか /外国人作家/
がいこくじんせんしゅ /外国人選手/
がいこくじんせんしゅわく /外国人選手枠/
がいこくじんせんよう /外国人専用/
がいこくじんだんせい /外国人男性/
がいこくじんとうしか /外国人投資家/
がいこくじんとうろく /外国人登録/
がいこくじんとうろくしょう /外国人登録証/
がいこくじんとうろくほう /外国人登録法/
がいこくじんはんざい /外国人犯罪/
がいこくじんりゅうがくせい /外国人留学生/
がいこくじんりょこうしゃ /外国人旅行者/
がいこくじんろうどうしゃ /外国人労働者/
がいこくじんわく /外国人枠/
がいこくせい /外国製/
がいこくせいひん /外国製品/
がいこくせいふ /外国政府/
がいこくせき /外国籍/
がいこくせん /外国船/
がいこくせんしゅ /外国選手/
がいこくせんぱくかんとく /外国船舶監督/
がいこくぜい /外国勢/
がいこくぜいがくこうじょ /外国税額控除;foreign tax credit/
がいこくそうきん /外国送金/
がいこくば /外国馬/
がいこくぶ /外国部/
がいこくぶつ /外国物/
がいこくぶんがく /外国文学/
がいこくほう /外国法/
がいこくぼうえき /外国貿易/
がいこくぼん /外国本/
がいこくめんきょ /外国免許/
がいこくもの /外国物/
がいこくゆうびんかわせ /外国郵便為替/
がいこくりょこう /外国旅行/
がいこっかく /外骨格/
がいこつ /骸骨/外骨/蓋骨/
がいこつか /骸骨化/
がいこん /外婚/
がいご /外語/
がいごう /外合/
がいごうないじゅう /外剛内柔/
がいさい /外債/
がいさん /概算/
がいさんち /概算値/
がいさんようきゅう /概算要求/
がいざい /外在/外材;⇔国産材/
がいざいせい /外在性/
がいざいてき /外在的/
がいし /外資/碍子/外史/外紙/外使/外姉/芥子/
がいしけい /外資系/
がいして /概して/
がいしどうにゅう /外資導入/
がいしゃ /外車/会社/害者;[隠]被害者/
がいしゃや /外車屋/
がいしゅう /外周/鎧袖/
がいしゅういっしょく /鎧袖一触/
がいしゅうき /概周期/
がいしゅうちょう /外周長/
がいしゅうぶ /外周部/
がいしゅっけつ /外出血/
がいしゅつ /外出/
がいしゅつきょか /外出許可/
がいしゅつきんし /外出禁止/
がいしゅつきんしれい /外出禁止令/
がいしゅつぎ /外出着;よそいき/
がいしゅつさき /外出先/
がいしゅつじ /外出時/
がいしゅつちゅう /外出中/
がいしゅつまえ /外出前/
がいしゅつよう /外出用/
がいしょ /外書/
がいしょう /外相/外傷/外商/街娼/外渉/
がいしょうかいぎ /外相会議/
がいしょうきゅう /外相級/
がいしょうぶ /外商部/
がいしょく /外食/
がいしょくさんぎょう /外食産業/
がいしょくや /外食屋/
がいしょこうどく /外書講読/
がいしん /外信/外心/外申/害心/
がいじ /外字/外事/外耳/孩児/
がいじえん /外耳炎/
がいじつせい /概日性/
がいじつりずむ /概日リズム/
がいじとうろく /外字登録/
がいじどう /外耳道/
がいじにゅうりょく /外字入力/
がいじゅ /外需/
がいじゅう /害獣/
がいじゅうないごう /外柔内剛/
がいじょう /街上/
がいじよう /外字用/
がいじん /外人/外陣/
がいじんあいて /外人相手/
がいじんおんな /外人女/
がいじんかしゅ /外人歌手/
がいじんぐみ /外人組/
がいじんせんしゅ /外人選手/
がいじんぜい /外人勢/
がいじんぶたい /外人部隊/
がいじんぼち /外人墓地/
がいじんりょうきん /外人料金/
がいじんわく /外人枠/
がいすう /概数/
がいず /概図/
がいせい /外生/外征/外声/蓋世;世をおおうほどの気勢。「抜山-」/慨世;世をなげく。「-の士」/
がいせいき /外性器/
がいせいてき /外生的/
がいせき /外積/外戚/
がいせつ /概説/外接/
がいせつえん /外接円/
がいせつしょ /概説書/
がいせつちょうほうけい /外接長方形/
がいせつほう /外接法/
がいせん /凱旋/外線/街宣/
がいせんきこく /凱旋帰国/
がいせんしゃ /街宣車/
がいせんしょう /凱旋賞/
がいせんちょくつう /外線直通/
がいせんもん /凱旋門/
がいせんもんしょう /凱旋門賞/
がいせんよう /外線用/
がいぜん /蓋然/慨然/
がいぜんせい /蓋然性/
がいぜんてき /蓋然的/
がいそう /外装/咳嗽/外挿/外層/
がいそうこうじ /外装工事/
がいそうざい /外装材/
がいそうち /外挿値/
がいそうひん /外装品/
がいそうぶひん /外装部品/
がいそうほう /外挿法;[数学]extrapolation/
がいそく /外側/外足/概則/
がいそくど /外測度/
がいそふ /外祖父/
がいそぼ /外祖母/
がいそん /外孫/
がいたい /外帯/
がいため /外為/
がいためほう /外為法/
がいたれ /外タレ/
がいたん /慨嘆/外端/慨歎;=慨嘆/
がいだ /咳唾/
がいだい /外大/
がいだて /階建/階建て/
がいだん /街談/
がいだんこうせつ /街談巷説/
がいち /外地/
がいちゅう /害虫/外注/
がいちゅうくじょ /害虫駆除/
がいちゅうさき /外注先/
がいちゅうひ /外注費/
がいちょう /害鳥/外朝/
がいちょうどう /外聴道/
がいてき /外的/外敵/
がいてきよういん /外的要因/
がいてん /外転/外典/外点/
がいてんしんけい /外転神経/
がいでん /外伝/外電/
がいでんてき /外伝的/
がいとう /該当/街頭;street.「-演説」/街灯;streetlamp/外套/外灯;outdoor lamp/街燈;「灯」旧字/
がいとう> /該当;-者,-部分/
がいとうえんぜつ /街頭演説/
がいとうかしょ /該当個所/
がいとうきかん /該当機関/
がいとうきしゅ /該当機種/
がいとうきじ /該当記事/
がいとうくかん /該当区間/
がいとうこうもく /該当項目/
がいとうしゃ /該当者/該当車;car/
がいとうしゃしゅ /該当車種/
がいとうすう /該当数/
がいとうはんばい /街頭販売/
がいとうぶぶん /該当部分/
がいとうぼきん /街頭募金/
がいとうまく /外套膜/
がいどう /外道/
がいどく /害毒/
がいねん /概念/外燃/
がいねんか /概念化/
がいねんがくしゅう /概念学習/
がいねんきかん /外燃機関/
がいねんきてい /概念規定/
がいねんくうかん /概念空間/
がいねんけいせい /概念形成/
がいねんこうぞう /概念構造/
がいねんじたい /概念自体/
がいねんじょう /概念上/
がいねんず /概念図/
がいねんせかい /概念世界/
がいねんてき /概念的/
がいねんてきちしき /概念的知識/
がいねんりかい /概念理解/
がいはいよう /外胚葉/
がいはおん /外破音;[音声学]explosive/
がいはく /外泊/該博/駭魄/
がいはつてき /外発的/
がいはん /外販/外板/
がいはんぼし /外反母趾/外反拇趾/外反拇指;?/
がいばつてき /外罰的/
がいばん /外盤/
がいひ /外皮/外被/
がいひがわ /外皮側/
がいひょう /概評/
がいひん /外賓/
がいびぶん /外微分/
がいふうしゃ /凱風社;[出版社名]www.gaifu.co.jp/
がいぶ /外部/外侮/
がいぶかんきょう /外部環境/
がいぶかんさ /外部監査/
がいぶかんすう /外部関数/
がいぶきおく /外部記憶/
がいぶきおくばいたい /外部記憶媒体/
がいぶきかん /外部機関/
がいぶきき /外部機器/
がいぶけいざい /外部経済/
がいぶけいしき /外部形式/
がいぶこうか /外部効果/
がいぶさんしょう /外部参照/
がいぶしゅつりょく /外部出力/
がいぶしよう /外部仕様/
がいぶせい /外部性/外部生/
がいぶせかい /外部世界/
がいぶそうち /外部装置/
がいぶそしき /外部組織/
がいぶぞうせつ /外部増設/
がいぶたんし /外部端子/
がいぶだんたい /外部団体/
がいぶちょうこう /外部調光/
がいぶつ /外物/
がいぶてき /外部的/
がいぶでんげん /外部電源/
がいぶどうき /外部同期/
がいぶにゅうりょく /外部入力/
がいぶにゅうりょくたんし /外部入力端子/
がいぶひょうか /外部評価/
がいぶふけいざい /外部不経済;[経済]external diseconomy/
がいぶへんすう /外部変数/
がいぶもう /外部網/
がいぶん /外分/外聞/
がいぶんぴつ /外分泌/
がいへき /外壁/
がいへきあつ /外壁厚/
がいへきざい /外壁材/
がいへきじょう /外壁上/
がいへん /外編/外篇/
がいほう /外報/概包/
がいぼう /外貌/
がいまい /外米/
がいむ /外務/
がいむきょう /外務卿/
がいむしょう /外務省/
がいむしょうじかん /外務省次官/
がいむじかん /外務次官/
がいむだいじん /外務大臣/
がいめん /外面/
がいめんせい /外面性/
がいめんてき /外面的/
がいもう /外毛/
がいもん /外門/
がいや /外野/
がいやしゅ /外野手/
がいやじゆうせき /外野自由席/
がいやじん /外野陣/
がいやせき /外野席/
がいゆう /外遊/外憂/
がいよう /概要/外用/外洋/外葉/艾葉/
がいようがわ /外洋側/
がいようぎょ /外洋魚;pelagic fish/
がいようしょ /概要書/
がいようしょうかい /概要紹介/
がいようず /概要図/
がいようせつめい /概要説明/
がいようせつめいしょ /概要説明書/
がいようづ /概要図/
がいようやく /外用薬/
がいらい /外来/
がいらいかんじゃ /外来患者;outpatient.⇔入院患者/
がいらいぎょ /外来魚/
がいらいご /外来語/
がいらいざつおん /外来雑音/
がいらいしゃ /外来者/
がいらいしゅ /外来種/
がいらいてき /外来的/
がいらいよう /外来用/
がいらん /外乱/
がいりゃく /概略/
がいりゃくず /概略図/
がいりゃくてき /概略的/
がいりょく /外力/
がいりん /外輪/
がいりんざん /外輪山/
がいりんせん /外輪船/
がいろ /街路/
がいろじゅ /街路樹/
がいろとう /街路灯/
がいろん /概論/
がいわくせい /外惑星/
がいわん /蓋碗;中国の茶器/
がいん /画院/雅音/画因/
がう /號;「号」の旧字/
がうすぶんぷ /ガウス分布/
がえ /換/
がえし /返し/
がえり /帰り/
がえん /賀宴/
がお /顔/顏;「顔」の旧字/
がおう /画王/
がおか /ヶ丘/
がおんしつ /画音質/
がか /画家/雅歌/画架/
がかい /瓦解/画会/雅懐/
がかく /画角/畫角;「画」旧字/
がかざ /画架座;Pictor(Pic)/
がかり /係/掛/
がが /峨々/峨峨/
ががく /雅楽/画学/
ががくせい /画学生/
ががくりょう /雅楽寮;[律令制]/
ががっき /雅楽器/
ががんぼ /大蚊/
がき /餓鬼/垣/瓦器/書き/
がきだいしょう /餓鬼大将/
がきだな /餓鬼棚/
がきどう /餓鬼道;三悪道(三途)の一。/
がきょう /画境/
がぎ /画技/
がぎじょうぶ /鉤状部/
がぎょ /駕御/
がぎょう /画業/ガ行/が行/
がく /額/学/楽/萼;花のウテナ/顎;あご/岳/嶽;「岳」の旧字/咢/愕;驚愕/鄂;中国・湖北省/齶;≒顎/諤;侃々諤々/鍔;刀のツバ/鰐;わに/壑;たに・あな/學;「学」の旧字/斈;「学」の異体字/樂;「楽」の旧字(人名用漢字)/
がくあじさい /額紫陽花/
がくい /学位/
がくいき /学位記/
がくいきじゅよしき /学位記授与式/
がくいしんさ /学位審査/
がくいじゅよきこう /学位授与機構/
がくいじゅよしき /学位授与式/
がくいめい /学位名/
がくいり /額入り/
がくいろんぶん /学位論文/
がくいん /学院/楽員/
がくいんだい /学院大/
がくいんない /学院内/
がくえん /学園/
がくえんさい /学園祭/
がくえんさいご /学園祭後/
がくえんとし /学園都市/
がくえんとしせん /学園都市線/
がくえんふんそう /学園紛争/
がくえんまえ /学園前/
がくえんまええきげしゃ /学園前駅下車/
がくえんもの /学園物/
がくおん /楽音/
がくかんせつ /顎関節/
がくかんせつしょう /顎関節症/
がくかんせつだっきゅう /顎関節脱臼/
がくがい /学外/
がくがいしゃ /学外者/
がくきょうかい /学協会/
がくぎょ /鰐魚/
がくぎょう /学業/
がくぎょうじょう /学業上/
がくぎょうせいせき /学業成績/
がくぎょうふしん /学業不振/
がくぐん /学群/
がくげい /学芸/
がくげいいん /学芸員/
がくげいかい /学芸会/
がくげいだい /学芸大/
がくげいだいがく /学芸大学/
がくげいだいがくえき /学芸大学駅/
がくげいだいふぞく /学芸大付属/
がくげいぶ /学芸部/
がくげいぶんこ /学芸文庫/
がくげき /楽劇/
がくこつ /顎骨/
がくさい /学際;interdiscipline/学祭;学園祭/学才/楽才/
がくさいか /学際化/
がくさいこうりゅう /学際交流/
がくさいてき /学際的/
がくさいぶんや /学際分野/
がくさいりょういき /学際領域/
がくさん /学参;学習参考書/
がくざら /額皿/
がくし /学士/学資/楽師/
がくしいじょう /学士以上/
がくしいん /学士院/
がくしかい /学士会/
がくしかいかん /学士会館/
がくしかいかんぶんかん /学士会館分館/
がくしき /学識/楽式;楽曲の形式/学指揮/
がくしきけいけんしゃ /学識経験者/
がくしきしゃ /学識者/
がくしにゅうがく /学士入学/
がくしにゅうがくせいど /学士入学制度/
がくしほけん /学資保険/
がくしゃ /学者/学舎/
がくしゃけい /学者系/
がくしゃたち /学者達/
がくしゃない /学者内/
がくしゃはだ /学者肌/
がくしゅ /楽手/
がくしゅう /学習/学修;学び修める/
がくしゅうあるごりずむ /学習アルゴリズム/
がくしゅういん /学習院/
がくしゅういんしょとうか /学習院初等科/
がくしゅういんだい /学習院大/
がくしゅういんだいがく /学習院大学/
がくしゅうかい /学習会/
がくしゅうかいすう /学習回数/
がくしゅうかがく /学習科学/
がくしゅうかてい /学習過程/
がくしゅうかのう /学習可能/
がくしゅうかのうせい /学習可能性/
がくしゅうかん /学習観/
がくしゅうかんきょう /学習環境/
がくしゅうかんじ /学習漢字/
がくしゅうがた /学習型/
がくしゅうきかい /学習機械/
がくしゅうきかん /学習期間/
がくしゅうきこう /学習機構/
がくしゅうきのう /学習機能/
がくしゅうきょくせん /学習曲線/
がくしゅうけい /学習系/
がくしゅうけいすう /学習係数/
がくしゅうけっか /学習結果/
がくしゅうけんきゅう /学習研究/
がくしゅうけんきゅうしゃ /学習研究社;[企業名]/
がくしゅうこうか /学習効果/
がくしゅうご /学習後/
がくしゅうさいくる /学習サイクル/
がくしゅうさんこうしょ /学習参考書/
がくしゅうさんぷる /学習サンプル/
がくしゅうしつ /学習室/
がくしゅうしどう /学習指導/
がくしゅうしどうようりょう /学習指導要領/
がくしゅうしゃ /学習者/
がくしゅうしゃじしん /学習者自身/
がくしゅうしゅうりょうご /学習終了後/
がくしゅうしょうがい /学習障害/
がくしゅうしんりがく /学習心理学/
がくしゅうじ /学習時/
がくしゅうじかん /学習時間/
がくしゅうじてん /学習辞典/
がくしゅうじゅく /学習塾/
がくしゅうじょう /学習上/
がくしゅうじょうきょう /学習状況/
がくしゅうじょうけん /学習条件/
がくしゅうじょうほう /学習情報/
がくしゅうずかん /学習図鑑/
がくしゅうずみ /学習済み/
がくしゅうせいぎょ /学習制御/
がくしゅうせっと /学習セット/
がくしゅうせつ /学習説/
がくしゅうそうだん /学習相談/
がくしゅうそく /学習則/
がくしゅうそくど /学習速度/
がくしゅうちゅう /学習中/
がくしゅうちょう /学習帳/
がくしゅうづくえ /学習机/
がくしゅうないよう /学習内容/
がくしゅうのうりょく /学習能力/
がくしゅうはん /学習班/
がくしゅうひょうげん /学習表現/
がくしゅうふのう /学習不能/
がくしゅうぶぶん /学習部分/
がくしゅうほう /学習法/
がくしゅうほうしき /学習方式/
がくしゅうほうほう /学習方法/
がくしゅうもんだい /学習問題/
がくしゅうよう /学習用/
がくしゅうりつ /学習率/
がくしゅうりょういき /学習領域/
がくしゅうりょく /学習力/
がくしゅうりろん /学習理論/
がくしゅうれい /学習例/
がくしょ /楽所/楽書/
がくしょう /楽章/学生/学匠/楽匠/
がくしょく /学食/学殖/
がくしん /学振/学術振興会;※abbrev/学術審議会;※abbrev/
がくしんけんきゅういん /学振研究員/
がくじ /学事/
がくじぶ /学事部/
がくじゅつ /学術/
がくじゅつかいぎ /学術会議/
がくじゅつかつどう /学術活動/
がくじゅつけい /学術系/
がくじゅつけんきゅう /学術研究/
がくじゅつけんきゅうとし /学術研究都市/
がくじゅつこうえんかい /学術講演会/
がくじゅつざっし /学術雑誌/
がくじゅつし /学術誌/
がくじゅつしょ /学術書/
がくじゅつしんぎかい /学術審議会/
がくじゅつしんこう /学術振興/
がくじゅつじょう /学術上/
がくじゅつじょうほう /学術情報/
がくじゅつだんたい /学術団体/
がくじゅつてき /学術的/
がくじゅつてきかち /学術的価値/
がくじゅつどうこう /学術動向/
がくじゅつはかせ /学術博士/
がくじゅつぶんか /学術文化/
がくじゅつもくてき /学術目的/
がくじゅつよう /学術用/
がくじゅつようご /学術用語/
がくじゅつようごしゅう /学術用語集/
がくじゅつりよう /学術利用/
がくじゅつろんぶん /学術論文/
がくじょう /学情/学術情報センター/
がくじょうもう /学情網/
がくじん /楽人/
がくせい /学生/学制/楽聖/
がくせい> /学生;-結婚,-会館/
がくせいいん /学生員/
がくせいうんどう /学生運動/
がくせいえんごかい /学生援護会/
がくせいか /学生課/
がくせいかい /学生会/
がくせいかいいん /学生会員/
がくせいかいかん /学生会館/学生会舘;異体字/
がくせいかばん /学生鞄/
がくせいかん /学生間/
がくせいがかり /学生係/
がくせいがわ /学生側/
がくせいきしゅくしゃ /学生寄宿舎/
がくせいきょういく /学生教育/
がくせいけっこん /学生結婚/
がくせいけん /学生券/
がくせいげきだん /学生劇団/
がくせいさいご /学生最後/
がくせいさんか /学生参加/
がくせいしき /学生指揮/
がくせいしつ /学生室/
がくせいしゅくしゃ /学生宿舎/
がくせいしょう /学生証/
がくせいしょうばんごう /学生証番号/
がくせいしょくどう /学生食堂/
がくせいしょくん /学生諸君/
がくせいしんぶん /学生新聞/
がくせいじしん /学生自身/
がくせいじだい /学生時代/
がくせいじだいいらい /学生時代以来/
がくせいじちかい /学生自治会/
がくせいじっけん /学生実験/
がくせいじっしゅう /学生実習/
がくせいすう /学生数/
がくせいずもう /学生相撲/
がくせいせいかつ /学生生活/
がくせいせんしゅけん /学生選手権/
がくせいせんばつ /学生選抜/
がくせいたいしょう /学生対象/
がくせいたち /学生達/
がくせいちゅう /学生中/
がくせいなかま /学生仲間/
がくせいばんごう /学生番号/
がくせいひかえしつ /学生控室/
がくせいひとり /学生一人/
がくせいびんらん /学生便覧/
がくせいふう /学生風/
がくせいふく /学生服/
がくせいぶ /学生部/
がくせいぶかい /学生部会/
がくせいぶちょう /学生部長/
がくせいぼしゅう /学生募集/
がくせいむき /学生向/
がくせいやきゅう /学生野球/
がくせいやきゅうきょうかい /学生野球協会/
がくせいよう /学生用/
がくせいりょう /学生寮/
がくせいりょうきん /学生料金/
がくせいわりびき /学生割引/
がくせき /学籍/
がくせきばんごう /学籍番号/
がくせきぼ /学籍簿/
がくせつ /学説/楽節/
がくせつし /学説史/
がくせつじょう /学説上/
がくぜん /愕然/
がくそ /楽所/
がくそう /額装/学僧/楽想/学窓/楽箏;雅楽器。三弦の一/学聡/
がくそく /学則/
がくそつ /学卒/
がくたい /楽隊/
がくだいこ /楽太鼓;雅楽の太鼓の一、また総称/
がくだん /楽団/楽壇/
がくだんいん /楽団員/
がくち /学知/
がくちょう /学長/楽長/楽調/
がくちょうしつ /学長室/
がくてき /学的/
がくてん /楽典/
がくでん /学田/
がくと /学徒/学都/
がくとう /学頭/学統;学問の系統/咢筒/
がくとく /学徳/
がくとどういん /学徒動員/
がくとへい /学徒兵/
がくどう /学童;pupil/学堂;school/楽堂;音楽堂/学道/額堂;神社で、絵馬を掛ける場所/
がくどうそかい /学童疎開/
がくどうほいく /学童保育/
がくどうほいくしょ /学童保育所/
がくない /学内/
がくないかいかく /学内改革/
がくないがい /学内外/
がくないせん /学内線/
がくないびん /学内便/
がくにん /学人;仏教の修行者/楽人;雅楽の奏者/
がくねん /学年/
がくねんてき /学年的/
がくねんべつ /学年別/
がくねんまつ /学年末/
がくの /嶽野/
がくのはな /額の花/
がくは /学派/楽派;音楽の流派。「フランドル-,ウィーン-,国民-」/
がくばす /学バス/
がくばつ /学閥/
がくひ /学費/岳飛;南宋の武将/
がくひめんじょ /学費免除/
がくびわ /楽琵琶;雅楽器。三弦の一/
がくふ /楽譜/学府/岳父/
がくふう /学風/
がくふうりば /楽譜売場/
がくふか /楽譜化/
がくふがた /楽譜型/
がくふきごう /楽譜記号/
がくふしゅう /楽譜集/
がくふしゅっぱんしゃ /楽譜出版社/
がくふじょう /楽譜上/
がくふにゅうりょく /楽譜入力/
がくふにんしき /楽譜認識/
がくふや /楽譜屋/
がくふよう /楽譜用/
がくぶ /学部/
がくぶがくせい /学部学生/
がくぶがくせいじだい /学部学生時代/
がくぶきょういく /学部教育/
がくぶじだい /学部時代/
がくぶじむしつ /学部事務室/
がくぶせい /学部生/
がくぶそつ /学部卒/
がくぶだんかい /学部段階/
がくぶち /額縁/
がくぶちょう /学部長/
がくぶない /学部内/
がくへん /萼片/がく片/
がくほう /学報/
がくぼう /学帽/
がくぼく /学僕/
がくむ /学務/
がくむか /学務課/
がくめい /学名/
がくめん /額面/楽面/
がくめんかかく /額面価格/
がくめんかぶ /額面株/
がくめんじょう /額面上/
がくめんてき /額面的/
がくめんどおり /額面通り/
がくめんはっこう /額面発行/
がくめんわれ /額面割れ/
がくもん /学問/
がくもんかん /学問観/
がくもんじょ /学問所/
がくもんじょう /学問上/
がくもんぜんぱん /学問全般/
がくもんたいけい /学問体系/
がくもんたんきゅう /学問探求/
がくもんてき /学問的/
がくもんてきぎょうせき /学問的業績/
がくもんてきこうりゅう /学問的交流/
がくもんてきたいど /学問的態度/
がくもんのじゆう /学問の自由;憲法23条/
がくもんのすすめ /学問のすゝめ;(1872-76) 福沢諭吉/
がくもんぶんや /学問分野/
がくもんめん /学問面/
がくもんりょういき /学問領域/
がくや /楽屋/嶽野/
がくやうら /楽屋裏/
がくやおち /楽屋落ち/
がくゆう /学友/
がくゆうかい /学友会/
がくゆうかいひ /学友会費/
がくゆうきょうかい /楽友協会/
がくよう /岳陽/
がくようひん /学用品/
がくらん /学ラン/学らん/
がくり /学理/楽理/
がくりょう /学寮/
がくりょうい /学寮委/
がくりょうせん /学寮専/
がくりょく /学力/
がくりょくぶそく /学力不足/
がくるい /学類/
がくれい /学齢/
がくれき /学歴/
がくれきさしょう /学歴詐称/
がくれきしゃかい /学歴社会/
がくれきじまん /学歴自慢/
がくれきじゅうし /学歴重視/
がくれきふもん /学歴不問/
がくれん /学連/
がくろく /岳麓/
がくわり /学割/
がくわりうんちん /学割運賃/
がけ /崖/掛け/垳/
がけい /雅兄/芽型/
がけくずれ /崖崩れ;崖の崩落/
がけした /崖下/
がけっぷち /崖っ縁/崖っ淵/
がけん /我見/
がげき /画劇/
がげん /雅言/
がこう /画工/画稿/
がこうそう /鵞口瘡/
がご /雅語/
がごう /雅号/
がさ /傘/笠/
がさい /画才/
がさいれ /ガサ入れ;強制捜査/
がさくちゅう /画策中/
がさん /画賛/画讃/臥蚕;眠っているカイコ/
がさんび /臥蚕眉/
がざい /画材/
がざいてん /画材店/
がざいや /画材屋/
がし /餓死/賀詞/画師/画紙/樫/菓子/
がししゃ /餓死者/
がしつ /画質/画室/
がしつこうじょう /画質向上/
がしつちょうせい /画質調整/
がしつてき /画質的/
がしつひかく /画質比較/
がしつれっか /画質劣化/
がしゅ /雅趣/画趣/
がしゅう /画集/我執/賀州;加賀 or 伊賀/
がしゅん /賀春/
がしょ /賀書/
がしょう /賀正/画商/臥床/雅称/
がしら /頭/
がしんしょうたん /臥薪嘗胆/
がじゅん /雅馴/
がじょう /牙城/賀状/画帖/芽条/
がじょえんかんこう /雅叙園観光/
がじん /雅人/画人/牙人;仲買人/
がじんかって /我侭勝手/
がす /瓦斯/
がすあっせつ /ガス圧接;gas pressure welding/
がすあつ /ガス圧/
がすえそ /ガス壊疽;[医]gas gangrene/
がすか /ガス化/
がすかくさん /ガス拡散/
がすかようゆうろ /ガス化溶融炉/
がすかん /ガス管/
がすがいしゃ /ガス会社/
がすがま /ガス釜/
がすきき /ガス機器/
がすきぐ /ガス器具/
がすけつ /ガス欠;[口](<gas ガソリン)燃料切れ/
がすしき /ガス式/
がすしつ /ガス室/
がすじゅう /ガス銃/
がすじょう /ガス状/
がすじょうせいうん /ガス状星雲/
がすせん /ガス栓/
がすだい /ガス代/ガス台/
がすだん /ガス弾;gas bomb/
がすちゅうどく /ガス中毒/
がすでん /ガス田;天然ガス/
がすとう /ガス灯/ガス燈/
がすぬき /ガス抜き/
がすばくはつ /ガス爆発/
がすぶろ /ガス風呂/
がすぶんせき /ガス分析/
がすもれ /ガス漏れ/
がすようせつ /ガス溶接;gas welding/
がすりょうきん /ガス料金/
がすろ /ガス炉/
がせい /画聖/
がせき /瓦石/
がせつ /我説/
がせんし /画仙紙/
がぜん /俄然/瓦全/
がそ /画素/
がそう /画層/画僧/我相/芽層/
がそかん /画素間/
がそごと /画素毎/
がそすう /画素数/
がそち /画素値/
がそない /画素内/
がそみつど /画素密度/
がそりんしゃ /ガソリン車/
がそりんぜい /ガソリン税/
がそりんだい /ガソリン代/
がぞう /画像/
がぞうあっしゅく /画像圧縮/
がぞういがい /画像以外/
がぞうおうよう /画像応用/
がぞうか /画像化/
がぞうかん /画像間/
がぞうけいしき /画像形式/
がぞうけんきゅうしつ /画像研究室/
がぞうけんきゅうじょ /画像研究所/
がぞうけんさく /画像検索/
がぞうこうがく /画像工学/
がぞうこうがっか /画像工学科/
がぞうしゅうふく /画像修復/
がぞうしょり /画像処理/
がぞうしょりしつ /画像処理室/
がぞうしょりそうち /画像処理装置/
がぞうしんだん /画像診断/
がぞうじょう /画像上/
がぞうじょうほう /画像情報/
がぞうせいせい /画像生成/
がぞうてき /画像的/
がぞうでんしがっかい /画像電子学会/
がぞうでんそう /画像伝送/
がぞうにゅうりょく /画像入力/
がぞうにゅうりょくよう /画像入力用/
がぞうにんしき /画像認識/
がぞうひょうじ /画像表示/
がぞうぶ /画像部/
がぞうめん /画像面/
がぞうりかい /画像理解/
がぞく /雅俗/
がぞくせっちゅうたい /雅俗折衷体/
がぞくようがくしんしょ /雅俗幼学新書/
がた /方/型/形/潟/難/
がたおち /がた落ち/
がたこう /形鋼/型鋼/
がたさ /難さ/
がたな /刀/
がたり /語り/
がだい /画題/
がだん /画壇/
がち /雅致/勝ち/
がちしょう /賀知章/
がちょう /画調/鵞鳥/画帳/鵝鳥;「鵞」の本字/
がちりん /月輪/
がっ /合/
がっか /学科/学課;lesson/
がっかい /学会;†society.「-発表」/学界;†academe.「-の動静」/楽界/
がっかいいん /学会員/
がっかいかいいん /学会会員/
がっかいかいひ /学会会費/
がっかいかつどう /学会活動/
がっかいかんけい /学会関係/
がっかいきかんちゅう /学会期間中/
がっかいきょうさい /学会共催/
がっかいけいしき /学会形式/
がっかいし /学会誌/
がっかいしかく /学会資格/
がっかいしけいさい /学会誌掲載/
がっかいしゅっせき /学会出席/
がっかいしょう /学会賞/
がっかいじむきょく /学会事務局/
がっかいじょう /学会上/
がっかいなど /学会等/
がっかいはっこう /学会発行/
がっかいはっぴょう /学会発表/
がっかいはっぴょうろんぶん /学会発表論文/
がっかいまえ /学会前/
がっかいめい /学会名/
がっかいろんぶん /学会論文/
がっかがい /学科外/
がっかごと /学科毎/
がっかしけん /学科試験/
がっかせん /顎下腺/
がっかぜんきょういん /学科全教員/
がっかそつぎょうしゃ /学科卒業者/
がっかちょう /学科長/
がっかどくじ /学科独自/
がっかない /学科内/
がっかべつ /学科別/
がっかめんじょ /学科免除/
がっかもく /学科目/
がっかん /学館/学環/学監/楽官/
がっき /楽器/学期/
がっきいがい /楽器以外/
がっきえんそう /楽器演奏/
がっきえんそうか /楽器演奏家/
がっきおん /楽器音/
がっきかん /楽器間/
がっきこゆう /楽器固有/
がっきずき /楽器好き/
がっきそうしゃ /楽器奏者/
がっきてん /楽器店/
がっきはくぶつかん /楽器博物館/
がっきへんせい /楽器編成/
がっきほう /楽器法/
がっきほんらい /楽器本来/
がっきまつ /学期末/
がっきめい /楽器名/
がっきや /楽器屋/
がっきゅう /学級/学究/
がっきゅういいん /学級委員/
がっきゅういいんちょう /学級委員長/
がっきゅうかい /学級会/
がっきゅうき /学休期/
がっきゅうはだ /学究肌/
がっきゅうぶんこ /学級文庫/
がっきゅうへいさ /学級閉鎖/
がっきゅうほうかい /学級崩壊/
がっきょく /楽曲/
がっきょくこうせい /楽曲構成/
がっく /学区/楽句/
がっくうてんし /月宮天子/
がっくがい /学区外/
がっくこう /学区校/
がっくない /学区内/
がっけい /学系/学兄/
がっけん /学研;[企業名]学習研究社/
がっけんとし /学研都市/
がっけんとしせん /学研都市線/
がっこう /学校/學校/
がっこうい /学校医/
がっこういがい /学校以外/
がっこううんえい /学校運営/
がっこうかんけいしゃ /学校関係者/
がっこうかんり /学校管理/
がっこうがい /学校外/
がっこうがえり /学校帰り/
がっこうがわ /学校側/
がっこうきゅうぎょうきかん /学校休業期間/
がっこうきゅうしょく /学校給食/
がっこうきょういく /学校教育/
がっこうきょういくばんぐみ /学校教育番組/
がっこうきょういくほう /学校教育法/
がっこうきょうし /学校教師/
がっこうぎょうじ /学校行事/
がっこうぐん /学校群/
がっこうけんしん /学校検診/
がっこうさい /学校祭/
がっこうしき /学校式/
がっこうしきちない /学校敷地内/
がっこうしてい /学校指定/
がっこうしゅうへん /学校周辺/
がっこうしんぶん /学校新聞/
がっこうじむ /学校事務/
がっこうすいせん /学校推薦/
がっこうせいかつ /学校生活/
がっこうせいど /学校制度/
がっこうたんい /学校単位/
がっこうちゅう /顎口虫/
がっこうちゅうしゃじょう /学校駐車場/
がっこうちょう /学校長/
がっこうとしょかん /学校図書館/
がっこうない /学校内/
がっこうほうじん /学校法人/
がっこうめい /学校名/
がっこうれい /学校令/
がっこつ /顎骨/
がっさい /合財/合切/
がっさいぶくろ /合切袋/
がっさく /合作/
がっさつ /合冊/
がっさん /合算/月山/
がっしゅう /合衆/
がっしゅうこく /合衆国/
がっしゅうこくけんぽう /合衆国憲法/
がっしゅうこくせいふ /合衆国政府/
がっしゅく /合宿/
がっしゅくけいしき /合宿形式/
がっしゅくさき /合宿先/
がっしゅくじょ /合宿所/
がっしゅくちゅう /合宿中/
がっしょう /合唱;chorus/合掌;なまんだぶ/合焦;focusing/合従;-連衡/
がっしょうきょく /合唱曲/
がっしょうきょくしゅう /合唱曲集/
がっしょうしどう /合唱指導/
がっしょうたいかい /合唱大会/
がっしょうだん /合唱団/
がっしょうだんいん /合唱団員/
がっしょうづくり /合掌造り;[建築] 白川郷・五箇山/
がっしょうひねり /合掌捻り/
がっしょうぶ /合唱部/
がっしょうれんこう /合従連衡/
がっしょうれんしゅう /合唱練習/
がっせい /合生/
がっせん /合戦/
がっそう /合奏/合葬/
がっそうきょうそうきょく /合奏協奏曲/
がっそうきょく /合奏曲/
がっそうだん /合奏団/
がったい /合体/合體;「体」旧字/
がったいご /合体後/
がったいじ /合体字/
がったいほうほう /合体方法/
がったいまえ /合体前/
がったいよう /合体用/
がったいわざ /合体技/
がっち /合致/
がっちゃく /合着/
がって /勝手/
がってつ /合綴/
がってん /合点/月天/合點/
がってんし /月天子/
がっとげん /ガット弦/
がっぴ /月日/
がっぴつ /合筆/
がっぴょう /合評/
がっぴょうかい /合評会/
がっぺい /合併/
がっぺいご /合併後/
がっぺいごう /合併号/
がっぺいしゅうごう /合併集合/
がっぺいしょう /合併症/
がっぺいしょり /合併処理/
がっぺいじ /合併時/
がっぺいぞうだいごう /合併増大号/
がっぽう /合邦/
がっぽん /合本/
がつ /月/歹/
がつお /鰹/
がつころ /月頃/
がつごう /月号/
がつすえ /月末/
がつちゅう /月中/
がつど /月度/
がつばん /月版/
がつぶん /月分/
がつへん /歹偏;[部首]/
がつまつ /月末/
がてん /合点/
がでんいんすい /我田引水/
がと /画図/賀戸/
がとう /餓島;ガダルカナル島/臥榻;bed/
がどりにうむ /Gd/Gadolinium/
がな /仮名/
がに /蟹/
がにまた /蟹股/ガニ股/がに股/
がにゅうどう /我入道/
がね /金/鐘/
がはく /画伯/
がばん /画板/
がひつ /画筆/
がひん /訝賓/
がび /蛾眉;美しい眉/峨眉;-山/
がびさん /峨眉山;中国四川省の山/
がびょう /画鋲/臥病/
がふ /画布/画譜/楽府/
がふう /画風/
がふく /画幅/
がぶのみ /がぶ飲み/ガブ飲み/
がぶん /雅文/
がぶんたい /雅文体/
がへい /画餅/
がべい /画餅/
がぺん /鵞ペン/
がほ /牙保/
がほう /画報/画法/芽胞/
がぼう /画舫/
がま /蒲;[植物]cattail/蟇;[動物]がまがえる/釜;(連濁) 湯を沸かすかま/窯;(連濁) 器等を焼くかま/鎌;(連濁) 草などを切る刃物/蝦蟇;=蟇/蝦蟆;=蝦蟇/
がまがえる /蝦蟇/
がまぐち /がま口/蝦蟇口/
がまごうり /蒲郡/
がまごおり /蒲郡/
がまもく /ガマ目/Typales/
がまん /我慢/
がまんくらべ /我慢比べ/
がまんじる /我慢汁;[卑]/
がみ /雅味/髪/紙/神/上/髮;「髪」の旧字(人名用漢字)/
がむしゃら /我武者羅/
がめい /画名/雅名/
がめん /画面/
がめんいちばんうえ /画面一番上/
がめんいっぱい /画面一杯/
がめんかいぞうど /画面解像度/
がめんかだん /画面下段/
がめんかん /画面間/
がめんがい /画面外/
がめんけいしき /画面形式/
がめんこうしん /画面更新/
がめんこうせい /画面構成/
がめんさいず /画面サイズ/
がめんさつえい /画面撮影/
がめんした /画面下/
がめんしゃしん /画面写真/
がめんしゅつりょく /画面出力/
がめんしょうきょ /画面消去/
がめんじゅう /画面中/
がめんじょう /画面上/
がめんじょうぶ /画面上部/
がめんせいぎょ /画面制御/
がめんせっけい /画面設計/
がめんぜんたい /画面全体/
がめんちゅう /画面中/
がめんちゅうおう /画面中央/
がめんちゅうおううえ /画面中央上/
がめんちゅうおうぶ /画面中央部/
がめんてき /画面的/
がめんてまえ /画面手前/
がめんない /画面内/
がめんにゅうりょく /画面入力/
がめんはし /画面端/
がめんはば /画面幅/
がめんひょうじ /画面表示/
がめんひょうじよう /画面表示用/
がめんびょうが /画面描画/
がめんぶんかつ /画面分割/
がめんみぎ /画面右/
がも /賀茂/
がもう /蒲生/
がもん /衙門/
がゆう /雅遊/
がよい /通い/
がようし /画用紙/
がよく /我欲/
がら /柄/殻/瓦落/
がらあき /がら空き/ガラ空き/
がらあわせ /柄合わせ/柄合せ/
がらおち /瓦落落ち/
がらがらへび /ガラガラ蛇;rattlesnake/がらがら蛇/
がらく /雅楽/
がらくたぶんこ /我楽多文庫;[文学史]/
がらす /硝子/烏/鴉/
がらすいた /ガラス板/
がらすえ /ガラス絵/
がらすかん /ガラス管/
がらすき /がら空き;NB:「がらあき」と同形/
がらすこうげい /ガラス工芸/
がらすごし /ガラス越し/
がらすざら /ガラス皿/
がらすしつ /ガラス質/
がらすせい /ガラス製/
がらすせんい /ガラス繊維;glass fiber/
がらすたい /硝子体/ガラス体/
がらすだま /ガラス玉/
がらすど /ガラス戸/硝子戸/
がらすばり /ガラス張り;-の国会/
がらすびん /ガラス瓶/硝子瓶/
がらすまど /ガラス窓/硝子窓/
がらすめん /ガラス面/ガラス綿;glass wool/
がらすよう /ガラス用/
がらっと /ガラっと/
がらみ /搦み;接尾辞。/
がらもの /柄物;-のパンティ/
がらん /伽藍/
がらんじん /伽藍神/
がらんどう /伽藍堂/
がらんはいち /伽藍配置/
がり /我利/
がりうむ /Ga/Gallium/
がりがりもうじゃ /我利我利亡者/
がりばん /ガリ版/がり版/
がりべん /ガリ勉/
がりゅう /我流/画竜;=がりょう/
がりょう /臥竜;在野/画竜;-点睛/雅量/画料/
がりょうてんせい /画竜点睛/画龍点睛/
がりょく /画力/
がりれいへんかん /ガリレイ変換/
がりん /芽鱗/
がれーせん /ガレー船;galley/
がれき /瓦礫/
がろう /画廊/餓狼/
がろうきっさ /画廊喫茶/
がろうでんせつ /餓狼伝説/
がろん /画論/
がわ /側/川/河/皮/革/巛;「川」の異体字/
がわいた /側板/
がわら /瓦/河原/
がわり /代わり;(連濁)/
がん /願/癌/雁/頑;頑固/顔/顏;「顔」の旧字/岩;岩石/嵒;(いわ)/巌;いわお/巖;「巌」の旧字/丸;一丸/岸;接岸/眼;眼帯/龕;壁龕/贋;贋物/偐;≒贋/鴈;≒雁/鳫;「鴈」の異体字/玩;玩具/翫;賞翫/元;元祖/阮/含;含蓄/頷;うなず・く/厳;?/嚴;「厳」の旧字(人名用漢字)/貫/
がんあつ /眼圧/
がんい /含意/願意/⊃/
がんいりょう /癌医療/
がんえん /岩塩/顔淵;顔回/
がんか /眼科/眼下/眼窩/癌化/がん化/ガン化/
がんかい /眼科医/岩塊/眼界/顔回;孔子の弟子/
がんかけ /願掛け/
がんかよう /眼科用/
がんきゅう /眼球/
がんきゅううんどう /眼球運動/
がんきゅうたん /眼球譚/
がんきゅうない /眼球内/
がんきょう /眼鏡/頑強/
がんきょうせい /頑強性/
がんきん /元金/眼筋/
がんぎ /雁木/
がんぎょう /元慶;年号(877-885)/
がんくつ /巌窟/岩窟/
がんくつおう /巌窟王/
がんくび /雁首/
がんぐ /玩具/頑愚/
がんぐうりば /玩具売場/
がんぐせんもんてん /玩具専門店/
がんぐてん /玩具店/
がんぐばこ /玩具箱/
がんぐや /玩具屋/
がんけい /眼形/眼径/
がんけん /眼瞼/頑健/癌研/
がんけんしん /癌検診/ガン検診/がん検診/
がんけんせい /頑健性/
がんこ /頑固/
がんこいってつ /頑固一徹/
がんこう /眼光/雁行/眼孔/
がんこうしはい /眼光紙背/
がんこうしゅてい /眼高手低/
がんこもの /頑固者/
がんさ /眼差/
がんさい /岩滓/
がんさいぼう /癌細胞/がん細胞/ガン細胞/
がんさく /贋作/
がんさつ /贋札/
がんざい /丸剤/
がんし /眼視/
がんしき /眼識/
がんしつ /眼疾/
がんしぼう /癌死亡/
がんしゃ /顔射;[卑]/
がんしゅ /願主/癌腫/
がんしゅう /含羞/
がんしょ /願書/雁書/
がんしょう /岩礁/岩床/岩漿/翫賞/
がんしょきぼう /願書希望/
がんしょく /顔色/
がんしん /眼振/
がんじ /元治/雁字/
がんじがらめ /雁字搦め/
がんじつ /元日/
がんじつよう /元日用/
がんじょう /頑丈/
がんじょうせい /頑丈性/
がんじょうにんげん /頑丈人間/
がんじろう /鴈治郎/
がんじん /鑑真/
がんすい /含水/
がんすいたんそ /含水炭素;炭水化物/
がんせい /眼精;-疲労/眼睛;ひとみ/
がんせいひろう /眼精疲労/
がんせき /岩石/
がんせきがく /岩石学/
がんせきけん /岩石圏;lithosphere/
がんせん /頑癬/
がんぜ /頑是;-無い(=幼く無邪気)/
がんぜん /眼前/
がんそ /元祖/
がんそう /含嗽/
がんそてんさい /元祖天才/
がんぞう /贋造/
がんたい /眼帯/
がんたろう /巌太郎/
がんたん /元旦;NB:元日の朝/
がんたんれいはい /元旦礼拝/
がんだい /岩大/
がんだて /願立て/
がんだれ /厂/雁垂;[部首]/
がんちく /含蓄/
がんちゅう /眼中/
がんちょう /元朝/
がんちりょう /癌治療/がん治療/ガン治療/
がんつう /眼痛/
がんてい /眼底/
がんていしゃしん /眼底写真/
がんていしゅっけつ /眼底出血/
がんとくせん /岩徳線/
がんどう /龕灯/
がんどうがえし /強盗返し/
がんねん /元年/
がんねんしき /元年式/
がんねんど /元年度/
がんのすけ /雁之助/
がんばり /頑張り/
がんばりや /頑張り屋/
がんばん /岩盤/
がんぱい /眼杯/
がんぱく /雁帛/
がんびょう /眼病/
がんぴ /雁皮/
がんぴし /雁皮紙/
がんぶつ /贋物;fake/玩物;toy/
がんぶつそうし /玩物喪志/
がんぷく /眼福/
がんぺい /眼柄/贋幣/
がんぺき /岸壁/岩壁/巌壁/
がんほけん /癌保険/ガン保険/
がんぼう /願望/顔貌/眼房/
がんぽん /元本/
がんま /γ;gamma/Γ;Gamma/
がんません /γ線/ガンマ線/
がんみ /玩味/含味/
がんみつとう /含蜜糖;黒砂糖など/
がんめい /頑迷/頑冥/
がんめいころう /頑迷固陋/
がんめいふれい /頑冥不霊/
がんめん /顔面/
がんめんきん /顔面筋/
がんめんしんけい /顔面神経/
がんめんしんけいつう /顔面神経痛/
がんめんしんけいまひ /顔面神経麻痺;[医]facial paralysis/
がんめんそうはく /顔面蒼白/
がんもう /願望/
がんもく /眼目/
がんもどき /雁擬き/
がんもん /願文/雁門/
がんやく /丸薬/
がんゆ /含油/
がんゆう /含有/
がんゆうりつ /含有率/
がんゆうりょう /含有量/
がんよう /顔容/
がんよくせい /癌抑制/がん抑制/
がんよぼう /癌予防/ガン予防/
がんらい /元来/
がんり /元利/
がんりき /眼力/願力/
がんりゅうじま /巌流島/
がんりょう /顔料/含量/
がんりょく /眼力/
がんれつ /雁列/
がんろう /玩弄/
がんろうぶつ /玩弄物/
き /気/木/黄/樹;(字義:立っている木)/奇/記/期/器/機/基/忌/生/鬼/貴/旗/危/着/来/騎/紀;ジュラ-/季/既/規/軌/帰/企/己/起/杞;杞憂/祈;祈祷/圻/棄;棄権/弃;「棄」の異体字/輝;輝度/揮;指揮/揆;一揆/癸;みずのと/幃;とばり/諱;いみな/愧;慚愧/餽;おく・る/窺;うかが・う/槻;つき/亀/龜;「亀」の旧字/耆;伯耆/鰭;ひれ/詭;詭弁/跪;跪拝/旡/曁/毅;毅然/毀;毀損/燬;や・く/幾;幾何/畿;近畿/饑;饑饉/飢;飢餓/几;床几/机;机上/肌;はだ/熙/煕;「熙」の異体字1/熈;「熙」の異体字2/羇;(身を寄せる) 羇旅/羈;(たづな) 羈旅/覊;「羈」の異体字/匱/櫃;ひつ/瞶/饋/伎;歌舞伎/妓;舞妓/岐;岐路/跂/汽;汽車/愾;敵愾心(てきがいしん)/气;きがまえ/氣;「気」の旧字(人名用漢字)/喜;よろこ・ぶ/嬉;うれ・しい/僖;≒喜/憙;≒喜/熹;(もえる)/禧;(さいわい)/希;希望/稀;稀覯本/唏/晞/欷;歔欷/欹;そばだ・てる/棋;将棋/棊;「棋」の異体字/碁;ご/其;その/箕;み/朞;(ひとめぐり)/淇;(川の名)/祺;(さいわい)/稘/騏;騏驥/麒;麒麟/冀;こいねがう/驥;騏驥(駿馬)/寄;寄付/碕/剞/竒;「奇」の異体字/崎/嵜;「崎」の異体字/掎;掎角/畸;畸形/綺;綺麗/徽;徽章/祁/卉;花卉/喟;喟然/屓;贔屓/悸;動悸/暉;落暉/枳;からたち/榿;はんのき/麾;麾下/虧;虧月/覬/譏;そし・る/逵/馗;鍾馗/姫;美姫/城;岩城/酒;御神酒/噐;「器」の異体字/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/皈;「帰」の異体字/歸;「帰」の旧字/聞;※動詞語幹?/倚;※誤読?/猗;※誤読?/
き> /貴/黄;黄信号,黄ピーマン,黄ニラ/希/稀/奇;(prominent)奇作,奇句,(strange)奇獣/着/
きー /χ;chi/Χ;Chi/
きーきょく /キー局;テレビ局の親局/
きーせん /妓生/
きーち /キー値/
きーるん /基隆/
きあ /騎亜/
きあい /気合/気合い/木藍/
きあいまけ /気合負け/
きあけ /忌明け/
きあたり /気当たり/
きあつ /気圧/
きあつけい /気圧計/
きあつはいち /気圧配置/
きあん /起案/几案;机のこと NB:planの意味はない/机案;=几案/
きい /紀伊/奇異/貴意/忌諱/城井;姓/
きいかつうら /紀伊勝浦/
きいけ /紀伊家/
きいさんち /紀伊山地;地名,近畿/
きいすいどう /紀伊水道/
きいたなべ /紀伊田辺/
きいたふう /利いた風/
きいち /喜一/輝一/喜市/
きいちご /木苺/木莓;=木苺/
きいちばいいち /帰一倍一/
きいちほう /帰一法/
きいちほうげん /鬼一法眼/
きいちろう /喜一郎/
きいっぽん /生一本/
きいつ /帰一/
きいと /生糸/
きいとん /喜頓/
きいはんとう /紀伊半島/
きいはんとうおき /紀伊半島沖/
きいはんとうなんぶ /紀伊半島南部/
きいれ /喜入/
きいろ /黄色/
きいろせん /黄色線/
きいろぼん /黄色本/
きいん /起因/棋院/基因/気韻/
きいんげん /起因源/
きいんせいどう /気韻生動/
きう /気宇/祈雨/喜雨/
きうえ /木植/
きうえはら /木上原/
きうけ /気受け/
きうそうだい /気宇壮大/
きうち /木内/
きうつ /気鬱/
きうつり /気移り/季移り;[俳諧]/
きうま /木馬;林業用の橇/
きうら /木浦/木裏;⇔木表/
きうん /機運;†chance.「-に乗じる」/気運;†trend.「-が高まる」/
きえ /帰依/気恵/消え/
きえい /気鋭/機影/帰営/
きえき /気液/
きえこ /喜恵子/
きえしゃ /帰依者/
きえつ /喜悦/
きえん /機縁/奇縁/気炎/気焔/
きえんさん /希塩酸/
きえんばんじょう /気炎万丈/
きおい /気負い/紀尾井/
きおう /既往/棋王/
きおうしょう /既往症/
きおうじんじゃ /鬼王神社/
きおうせん /棋王戦/
きおうれき /既往歴/
きおく /記憶/
きおくあいまい /記憶曖昧/
きおくいき /記憶域/
きおくいち /記憶位置/
きおくかのう /記憶可能/
きおくかんり /記憶管理/
きおくくうかん /記憶空間/
きおくくらす /記憶クラス/
きおくけいしき /記憶形式/
きおくこうぞう /記憶構造/
きおくしゅだん /記憶手段/
きおくしょうがい /記憶障害/
きおくしょく /記憶色/
きおくじゅつ /記憶術/
きおくじょう /記憶上/
きおくせんめい /記憶鮮明/
きおくそうしつ /記憶喪失/
きおくそうち /記憶装置/
きおくそし /記憶素子/
きおくちがい /記憶違い/
きおくないよう /記憶内容/
きおくのうりょく /記憶能力/
きおくばいたい /記憶媒体/
きおくばしょ /記憶場所/
きおくぶ /記憶部/
きおくぶつ /記憶物/
きおくほじ /記憶保持/
きおくほじどうさ /記憶保持動作/
きおくぼ /記憶薄;?/
きおくようりょう /記憶容量/
きおくようりょうさいだい /記憶容量最大/
きおくりょう /記憶量/
きおくりょういき /記憶領域/
きおくりょく /記憶力/
きおくれ /気後れ/気遅れ;=気後れ/
きおち /気落ち/気落/
きおも /気重/
きおもて /木表;⇔木裏/
きおん /気温/基音/気音/
きおんさ /気温差/
きおんじょうしょう /気温上昇/
きか /幾何/帰化/気化/麾下/貴家/貴下/奇貨;-居くべし/旗下;≒麾下/机下/奇禍;accident/季夏/貴課/
きかい /機械;†machine/機会;†opportunity/器械;†instrument/奇怪/喜界;地名/貴会/気塊/棋界/毀壊/
きかいあぶら /機械油/
きかいあみ /機械編み;⇔手編み/
きかいいん /既会員/
きかいうちゅうがっか /機械宇宙学科/
きかいうんどう /器械運動/
きかいおん /機械音/
きかいか /機械化/機械科/
きかいかこうか /機械加工科/
きかいかどく /機械可読/
きかいかどくけいしき /機械可読形式/
きかいかんそう /機械乾燥/
きかいがく /機械学/
きかいがくしゅう /機械学習/
きかいがっかい /機械学会/
きかいきんとう /機会均等/
きかいぎけん /機械技研/
きかいぎじゅつけんきゅうしょ /機械技術研究所/
きかいぎじゅつしゃ /機械技術者/
きかいけい /機械系/
きかいけいさん /機械計算/
きかいけん /機械研/機械研究所;※abbrev/
きかいけんきゅうしょ /機械研究所/
きかいけんきゅうじょ /機械研究所/
きかいこう /機械工/
きかいこうがく /機械工学/
きかいこうがくか /機械工学科/
きかいこうがくせんこう /機械工学専攻/
きかいこうがっか /機械工学科/
きかいこうぎょう /機械工業/
きかいこうさく /機械工作/
きかいご /機械語/
きかいざいりょうがく /機械材料学/
きかいしき /機械式/
きかいしきとけい /機械式時計/
きかいしつ /機械室/
きかいしゅぎ /機会主義/
きかいしょり /機械処理/
きかいしんこうかいかん /機械振興会館/
きかいしんどう /機械振動/
きかいじゅちゅう /機械受注/
きかいじょうほう /機械情報/
きかいせいぎょ /機械制御/
きかいせいず /機械製図/
きかいせいめいたい /機械生命体/
きかいせっけい /機械設計/
きかいそうおん /機械騒音/
きかいそうち /機械装置/
きかいそしき /機械組織/
きかいたいそう /器械体操/
きかいちのう /機械知能/
きかいちのうこうがくか /機械知能工学科/
きかいてき /機械的/
きかいてききょうど /機械的強度/
きかいどけい /機械時計/
きかいない /機械内/
きかいぱるぷ /機械パルプ/
きかいひよう /機会費用/
きかいぶひん /機械部品/
きかいぶんめい /機械文明/
きかいほんやく /機械翻訳/
きかいめいれい /機械命令/
きかいや /機械屋/
きかいよう /機械用/
きかいりょう /機械量/
きかいろん /機械論/
きかがく /幾何学/
きかがくてき /幾何学的/
きかがくもよう /幾何学模様/
きかき /気化器/
きかきゅうすうてき /幾何級数的/
きかく /企画/規格/企劃/
きかくあん /企画案/
きかくか /企画課/規格化/
きかくかいはつ /企画開発/
きかくかいはつぶ /企画開発部/
きかくかいはつほんぶ /企画開発本部/
きかくかさぎょう /規格化作業/
きかくかん /企画官/
きかくがい /規格外/
きかくがいひん /規格外品/
きかくきっぷ /企画切符/
きかくしつ /企画室/
きかくしゃ /企画者/
きかくしゅうだん /企画集団/
きかくしゅし /企画主旨/
きかくしょ /企画書/規格書/
きかくしょう /企画賞/
きかくしんこう /企画進行/
きかくじたい /企画自体/規格自体/
きかくじゅんきょ /規格準拠/
きかくじょう /規格上/
きかくせい /企画性/
きかくせきにんしゃ /企画責任者/
きかくたんとうしゃ /企画担当者/
きかくだおれ /企画倒れ/
きかくだんかい /企画段階/
きかくちゅう /企画中/
きかくちょうさしつ /企画調査室/
きかくてん /企画展/
きかくてんじ /企画展示/
きかくとう /規格等/
きかくとういつ /規格統一/
きかくとうしょ /企画当初/
きかくないよう /規格内容/
きかくなど /規格等/
きかくばん /企画盤/企画版/規格判;A3,B4など/
きかくひょう /規格表/規格票/
きかくひん /規格品/
きかくぶ /企画部/
きかくぶちょう /企画部長/
きかくぶつ /企画物/
きかくぶつき /企画部付/
きかくぶづけ /企画部付/
きかくりょく /企画力/
きかけいじょう /幾何形状/
きかげき /喜歌劇/
きかこうがく /幾何光学/
きかしき /気化式/
きかしょくぶつ /帰化植物/
きかじょうほう /幾何情報/
きかじん /帰化人/
きかすうれつ /幾何数列/
きかた /着方/
きかつ /飢渇/
きかてき /幾何的/
きかでーた /幾何データ/
きかどうぶつ /帰化動物/
きかねつ /気化熱/
きかへいきん /幾何平均/
きかほせい /幾何補正/
きかわ /木川;姓/
きかん /期間/機関/基幹/帰還/器官/季刊/既刊/気管/旗艦;flagship/軌間/奇観/貴官/帰艦/帰館/亀鑑;模範/汽罐;boiler/貴艦;your ship/器管;pipe?/貴簡;your mail/饋還/
きかん> /季刊/
きかんいにんじむ /機関委任事務/
きかんえんちょう /期間延長/
きかんかい /饋還会/
きかんき /利かん気/
きかんく /機関区/
きかんけい /器官系;[生物]organ system/
きかんげんてい /期間限定/
きかんこう /期間工/
きかんこうざ /基幹講座/
きかんご /帰還後/
きかんごと /機関毎/
きかんさんぎょう /基幹産業/
きかんし /機関誌;magazine/機関紙;paper/気管支/季刊誌;quarterly/機関士/
きかんしえん /気管支炎/
きかんしかくちょうしょう /気管支拡張症;[医]bronchial ectasia(BE)/
きかんしきょう /気管支鏡;[医]bronchoscope/
きかんしぜんそく /気管支喘息;[医]bronchial asthma(BA)/
きかんしつ /機関室/
きかんしはいえん /気管支肺炎;[医]bronchial pneumonia/
きかんしゃ /機関車/
きかんしゃこうかん /機関車交換/
きかんしゅ /機関手/
きかんしょくどうか /気管食道科/
きかんじゅう /機関銃/
きかんすう /奇関数/
きかんちゅう /期間中/
きかんちょう /機関長/
きかんていし /期間停止/
きかんてき /基幹的/
きかんてん /旗艦店;flagship shop/
きかんとうしか /機関投資家/
きかんない /期間内/
きかんぶ /機関部/
きかんぶん /既刊分/
きかんへい /帰還兵/
きかんほう /機関砲/
きかんほうほう /帰還方法/
きかんぼう /聞かん坊/利かん坊/
きかんまえ /期間前/
きかんまんりょう /期間満了/
きかんめい /機関名/
きかんもう /基幹網/
きが /飢餓/気賀/起臥/帰臥/
きがい /危害/気概/気愾;?/
きがいしゅうしゅく /期外収縮/
きがえ /着替え/着替/
きがかり /気掛かり/気掛り/気がかり/
きがかん /飢餓感/
きがく /器楽/貴学/
きがくきょく /器楽曲/
きがしら /木頭/
きがじょうたい /飢餓状態/
きがじんこう /飢餓人口/
きがす /希ガス/木ガス/
きがた /木型/木方/
きがね /気兼ね/気兼/
きがまえ /気構え/
きがみ /生紙/
きがらちゃ /黄枯茶/
きがる /気軽/
きがわ /木川/
きがん /祈願/奇岩/
きがんじょ /祈願所/
きがんじょうじゅ /祈願成就/
きき /機器/危機/鬼気/嬉々/器機;=機器/記紀;古事記・日本書紀/毀棄/忌諱/嬉嬉/喜々/気気/輝輝/効き/窺基/奇奇/帰期/飢鬼/喜気/汽機/起期/騏驥/奇気/記旗/諱忌/奇鰭/暉暉/
ききあし /利き足/
ききあわせ /聞合せ/
ききいしき /危機意識/
ききいっぱつ /危機一髪/
ききうで /利き腕/利腕/
ききおう /騏鬼翁/
ききおさめ /聞き納め/
ききおぼえ /聞き覚え/
ききかいかい /奇々怪々/奇奇怪怪/
ききかいひのうりょく /危機回避能力/
ききかた /聞き方/
ききかん /危機感/
ききかんり /危機管理/
ききがき /聞書/聞き書き/聞書き/
ききがわ /機器側/
きききりん /樹木希林/
ききけん /機器研/
ききけんきゅうじょ /機器研究所/
ききこうせい /機器構成/
ききこうにゅう /機器購入/
ききこみ /聞き込み/
ききごこち /聞き心地/
ききごたえ /聞き応え/
ききざけ /利き酒/利酒/
ききしょ /聞書/
ききしようりょう /機器使用料/
ききしんわ /記紀神話/
ききじぎょうぶ /機器事業部/
ききじぎょうほんぶ /機器事業本部/
ききじょうず /聞き上手/
ききじょうたい /危機状態/
ききすう /機器数/
ききすて /聞き捨て/
ききずて /聞き捨て/
ききせまる /鬼気迫る/
ききだっしゅつ /危機脱出/
ききちがえ /聞き違え/
ききつたえ /聞き伝え/
ききて /聞き手;話の-/聴き手;音楽の-/利き手;dominant hand/
ききてき /危機的/
ききてきじょうきょう /危機的状況/
ききてきじょうきょうか /危機的状況下/
ききてんじかい /機器展示会/
ききとり /聞き取り;dictee/聴き取り/聞取り/聴取り/
ききとりちょうさ /聞き取り調査/
ききどころ /聴き所/聞き所/利き所/
ききぶ /機器部/
ききぶんせき /機器分析/
ききべた /聞き下手/
ききまちがい /聞き間違い/
ききみみ /聞き耳/聞耳/利き耳/
ききみょうみょう /奇奇妙妙/奇々妙々/
ききめ /効き目/利き目;≒効き目/効目/利目/效;「効」の旧字/
ききもの /聞き物/聴きもの/
ききゃく /棄却/
ききゃくすう /棄却数/
ききゃくほう /棄却法/
ききゃくりつ /棄却率/
ききゃくるい /鰭脚類/
ききやく /聞き役/
ききゅう /気球/希求/危急/帰休/企及/冀求;=希求/
ききゅうそんぼう /危急存亡/
ききゅうほう /希求法/
ききょ /寄居/起居/
ききょう /桔梗/帰郷/帰京/気胸/奇矯/棄教/帰敬/
ききょういろ /桔梗色/
ききょうもく /キキョウ目/Campanulales/
ききょく /貴局/器局;才能/危局/棋局/棊局;=棋局/鰭棘;ヒレのトゲ/枳棘;トゲのある木や人/
ききょらい /帰去来/
ききよう /聞き様/
ききるい /機器類/
ききわけ /聞き分け/聞分け/
ききん /基金/飢饉/寄金/饑饉;=飢饉/
ききんぞく /貴金属/
きぎ /木々/樹々/機宜/嬉戯/気気/
きぎく /黄菊/
きぎけん /機技研/
きぎしつ /基技室/
きぎぬ /生絹/
きぎょ /綺語/
きぎょう /企業/起業;-する/機業;織物業/鬼形/起行/
きぎょうあんない /企業案内/
きぎょうか /起業家;会社を作る人/企業家;会社を作り、または経営する人/
きぎょうかいかく /企業改革/
きぎょうかいけい /企業会計/
きぎょうかいけいげんそく /企業会計原則/
きぎょうかつどう /企業活動/
きぎょうかん /企業間/
きぎょうがいよう /企業概要/
きぎょうがわ /企業側/
きぎょうくみあい /企業組合/
きぎょうけいえい /企業経営/
きぎょうけいえいしゃ /企業経営者/
きぎょうけいれつ /企業系列/
きぎょうけんがく /企業見学/
きぎょうけんきゅう /企業研究/
きぎょうけんきゅうしゃ /企業研究者/
きぎょうけんきん /企業献金/
きぎょうこうこく /企業広告/
きぎょうごと /企業毎/
きぎょうさま /企業様/
きぎょうしせい /企業姿勢/
きぎょうしゃかい /企業社会/
きぎょうしゃてい /企業舎弟/
きぎょうしゅうえき /企業収益/
きぎょうしゅうだん /企業集団/
きぎょうじょうほう /企業情報/
きぎょうじん /企業人/
きぎょうせきにん /企業責任/
きぎょうせつめい /企業説明/
きぎょうそしき /企業組織/
きぎょうぞう /企業像/
きぎょうたい /企業体/
きぎょうとうち /企業統治/
きぎょうどりょく /企業努力/
きぎょうない /企業内/
きぎょうないきょういく /企業内教育/
きぎょうないしつぎょう /企業内失業/
きぎょうねんかん /企業年鑑/
きぎょうねんきん /企業年金/
きぎょうばいしゅう /企業買収/
きぎょうひみつ /企業秘密/
きぎょうぶもん /企業部門/
きぎょうぶんか /企業文化/
きぎょうべつ /企業別/
きぎょうほうもん /企業訪問/
きぎょうめい /企業名/
きぎょうゆうち /企業誘致/
きぎょうようざいさん /企業用財産/
きぎょうりねん /企業理念/
きぎょうりんり /企業倫理/
きぎょうろんり /企業論理/
きぎれ /木切れ/
きく /菊/規矩/起句/崎嶇;けわしい/危懼/椈;ぶな/鞫;(ただす)/鞠;まり/掬;すく・う/
きくあな /菊穴;[卑]/
きくあわせ /菊合せ/菊合わせ/
きくい /喜久井/
きくいし /菊石;アンモナイトの化石/
きくいずみ /喜久泉/
きくいただき /菊戴/
きくいちもんじ /菊一文字/
きくいちょう /喜久井町/
きくいも /菊芋/
きくえい /菊栄/
きくお /喜久雄/喜久男/菊雄/菊男/紀久男/
きくおか /菊岡/
きくか /菊科/キク科/菊鹿/
きくかせき /菊花石/
きくかもん /菊花紋/
きくかわ /菊川/掬川/
きくがわ /菊川/
きくこ /喜久子/菊子/貴久子/起久子/
きくごろう /菊五郎/
きくさと /喜久里/
きくざ /菊座/
きくざけ /菊酒/
きくじ /喜久治/
きくじゅつ /規矩術;stereotomy/
きくじゅんじょう /規矩準縄/
きくじん /麹塵/
きくすい /菊水/
きくすいまる /菊水丸/
きくず /木屑/
きくずみ /菊炭/
きくずれ /着崩れ/
きくぞう /木久蔵/
きくた /菊田/
きくち /菊池;†サンズイ/菊地;†ツチヘン/
きくちかん /菊池寛/
きくちよ /菊千代/
きくづき /菊月/
きくづくり /菊作り;刀/
きくとうだい /菊灯台/
きくな /菊名/菊菜/
きくなえき /菊名駅/
きくなかん /菊名間/
きくならく /聞くならく/
きくに /喜国/
きくにんぎょう /菊人形/
きくね /菊音/
きくの /菊野/
きくのすけ /菊之助/
きくのはな /菊の花/
きくのり /菊海苔/
きくはら /菊原/
きくばり /気配り/気くばり/
きくばん /菊判/
きくひめ /菊姫/
きくひめしゅぞう /菊姫酒造/
きくびし /菊菱/
きくま /菊間/
きくまさ /菊政/
きくまさむね /菊政宗/
きくみ /菊見/
きくみみ /聞く耳/
きくもく /キク目/Asterales/
きくもくぐん /キク目群/
きくもん /菊門;[卑]/
きくや /菊屋/
きくゆうかい /菊友会/
きくよう /菊陽/
きくらげ /木耳/
きくん /貴君/
きぐ /器具/危惧/機具;機械と器具/危ぐ/
きぐう /奇遇/寄寓;寄迹、寓居/
きぐすり /生薬/
きぐち /木口/
きぐつ /木靴/
きぐびひん /器具備品/
きぐみ /木組み/気組み/
きぐらい /気位/
きぐるみ /着ぐるみ/着包み/
きぐろう /気苦労/
きけい /奇形/貴兄/畸形;=奇形/奇景;景勝/詭計;ペテン/奇計;奇抜な計略/畸型;=奇形/畸計/
きけいぎょ /奇形魚/
きけいしき /木形式/
きけいじ /奇形児/
きけつ /帰結/既決/
きけつしゅう /既決囚/
きけもの /利け者/
きけん /危険/棄権/気圏/貴顕/
きけんうんてん /危険運転/
きけんかいひ /危険回避/
きけんかいひのうりょく /危険回避能力/
きけんきゅう /危険球/
きけんきゅうしつ /貴研究室/
きけんこうい /危険行為/
きけんし /危険視/
きけんしそう /危険思想/
きけんしゃ /棄権者/
きけんしんし /貴顕紳士/
きけんじょうほう /危険情報;外務省の-/
きけんじんぶつ /危険人物/
きけんすいいき /危険水域/
きけんせい /危険性/
きけんせいだい /危険性大/
きけんせきにん /危険責任/
きけんちたい /危険地帯/
きけんど /危険度/
きけんはん /危険犯/
きけんび /危険日/
きけんふたん /危険負担/
きけんぶい /危険部位/
きけんぶつ /危険物/
きけんぶつとりあつかいしゃ /危険物取扱者/
きけんぶんし /危険分子/
きけんぼうし /危険防止/
きけんりつ /危険率/
きけんりょういき /危険領域/
きげき /喜劇/
きげきえいが /喜劇映画/
きげきじん /喜劇人/
きげきつい /機撃墜/
きげきてき /喜劇的/
きげつ /虧月;欠けゆく月。⇔盈月/亀月;?/
きげん /期限/起源/機嫌/紀元/奇幻/危言;高尚な言葉/奇言;奇抜な言葉/
きげんがい /期限外/
きげんぎれ /期限切れ/期限切/
きげんご /期限後/紀元後/
きげんせつ /紀元節;2.11(現・建国記念日)/起源説/
きげんぜん /紀元前/
きげんぜんご /紀元前後/
きげんそ /稀元素/希元素;rare element/
きげんそう /起源層/
きげんつき /期限付き/
きげんない /期限内/
きげんなおし /機嫌直し/
きげんまえ /期限前/
きげんろん /起源論/
きこ /騎虎/旗鼓/紀子;人名/
きこう /機構/紀行/気候/寄稿;†contribute.「論文を-する」/寄港;†call.「軍艦が-する」/気功/起工/機工/奇行/帰港;†「母港への-」/機甲/気孔/貴公/貴校/騎行/季候/稀覯/帰航;†帰港する航路。「-の途」/起稿/機巧/寄航;≒寄港/騎甲/奇効/希覯/奇功/奇巧/
きこうおんだん /気候温暖/
きこうかい /機甲界/
きこうがく /機構学/気候学;climatology/
きこうぐんだん /機甲軍団/
きこうけんきゅうぶ /機構研究部/
きこうし /貴公子/
きこうしき /起工式/
きこうしすてむ /気候システム/
きこうしすてむけんきゅうせんたー /気候システム研究センター/
きこうしだん /機甲師団/
きこうしゃ /寄稿者/
きこうじょう /機構上/
きこうせんたー /気候センター/
きこうぞう /木構造/
きこうたい /気候帯/
きこうち /寄港地/寄航地/
きこうてき /気候的;climatic/機構的;mechanic/
きこうでん /乞巧奠/
きこうぶたい /機甲部隊/
きこうぶん /紀行文/
きこうぶんがく /紀行文学/
きこうへんどう /気候変動;climate change/
きこうぼん /稀覯本/
きこうもの /紀行物/
きこうりょうへい /機甲猟兵/
きこえ /聞こえ/聞え/
きこえよがし /聞こえよがし/
きこく /帰国/貴国/鬼哭/枳穀/
きこくきねん /帰国記念/
きこくご /帰国後/
きこくしじょ /帰国子女/
きこくしゅうしゅう /鬼哭啾啾/
きこくじ /帰国時/
きこくとどけ /帰国届/
きこくび /帰国日/
きこくびん /帰国便/
きこくほうこく /帰国報告/
きこくよう /帰国用/
きこし /木越/
きこつ /気骨;不屈の精神/奇骨;風変わりで優れた人格/
きこない /木古内/
きこなし /着こなし/
きこり /樵/樵夫/
きこん /既婚/気根/機根/
きこんしゃ /既婚者/
きこんじょし /既婚女子/
きこんじょせい /既婚女性/
きこんだんせい /既婚男性/
きこんれき /既婚歴/
きご /季語/木子/綺語;飾った言葉/奇語;面白い言葉/寄語/基語/
きごう /記号/揮毫/〆;しめ/ヶ;か/…;.../‥;../〓;げた/―;dash/‐;hyphen/‖;||/♂;おす/♀;めす/※;こめじるし/〒;ゆうびん/℃;せっし/°;degree/′;minute/″;second/¢;cent/£;pond/§;ss/¶;paragraph/†;dagger/‡;ddagger/Å;angstrom/‰;permil/Ц;→cyrillic/♪;おんぷ/♯;sharp/♭;flat/☆;ほし/★/○;まる/●/◎/□;→しかく/■/◇/◆/△;→さんかく/▲/▽/▼/→;→やじるし/←/↑/↓/ヽ;→おなじ/ヾ/ゝ/ゞ/〃/仝/々/゛;だくてん/゜;はんだくてん/“;``/”/´;→accent/｀/¨/＾/∪;→math,「すうがくきごう」/∩/∧/∨/¬/∞/∝/∽/∠/⌒/≡/≒/≠/≦/≧/≪/≫/∴/∵/∫/×/÷/±/（;→かっこ/）/〔/〕/［/］/｛/｝/〈/〉/《/》/「/」/『/』/【/】/＋;NB:全角英数モードで入力可能/−;minus/＝/＜/＞/＃;number/＊/＠/／/＼/〜/￥/＄/％/＆/、/。/，/．/・/：/；/？/！/‘/’/｜;pipe/〇;漢数字のゼロ/ー;長音/￣/＿/
きごうか /記号化/
きごうがく /記号学/
きごうけい /記号系/
きごうした /記号下/
きごうしょり /記号処理/
きごうそうさ /記号操作/
きごうたんご /記号単語/
きごうていすう /記号定数/
きごうてき /記号的/
きごうにゅうりょく /記号入力/
きごうひょう /記号表/
きごうひょうげん /記号表現/
きごうほう /記号法/
きごうもーど /記号モード/
きごうるい /記号類/
きごうれつ /記号列/
きごうろん /記号論;semiotics/
きごうろんり /記号論理/
きごうろんりがく /記号論理学/
きごこち /着心地/
きごころ /気心/
きごし /木越/
きさ /蚶/吉舎/
きさい /記載/起債/鬼才/奇才/奇祭/騎西;地名/既済/
きさいじこう /記載事項/
きさいじこうへんこう /記載事項変更/
きさいち /私市;姓/
きさいないよう /記載内容/
きさいへんこう /記載変更/
きさいもれ /記載漏れ/
きさいらん /記載欄/
きさいれい /記載例/
きさかた /象潟/
きさかぶんきてん /木坂分岐点/
きさき /后/妃/気先/
きさく /気さく/奇策/喜作/既作/詭策/
きさご /細螺/
きささげ /楸/
きさつ /貴札/
きさぬき /木佐貫/
きさぶろう /喜三郎/
きさま /貴様/
きさらぎ /如月;陰暦2月/衣更着;=如月/更衣/
きさらづ /木更津/
きさらづこうせん /木更津高専/
きさらづじんく /木更津甚句;[民謡]千葉/
きさわ /木沢/
きさん /起算/帰山/帰参/
きさんじ /気散じ/
きさんてん /起算点/
きさんび /起算日/
きざ /気障/起坐/跪坐/刻/
きざい /機材;machinery/器材;instruments/基剤/器財;ware/
きざいしゃ /機材車/
きざいじょうほう /機材情報/
きざいだん /貴財団/
きざいはんばい /器材販売/
きざき /木崎/稀崎/
きざきこ /木崎湖/
きざくら /黄桜/
きざくらしゅぞう /黄桜酒造/
きざけ /生酒/
きざさ /季笹/
きざし /兆し/兆/萌/
きざはし /階/
きざみ /刻み/刻/
きざみあし /刻み足/
きざみこんぶ /刻み昆布/
きざみのり /刻み海苔/
きざみめ /刻み目/
きざら /木皿/
きざわり /気障り/
きざんかん /機山館/
きし /岸/騎士;knight/棋士;将棋のプロ/旗幟;日中の戦国武将が陣地に掲げる旗。「-を鮮明にする」/貴誌/貴紙/起死;resurrection 「-回生」/貴志;地名/気死/奇士/愧死/来住;?/
きしかいせい /起死回生/
きしかたゆくすえ /来し方行く末;past and future/
きしかわ /貴志川/
きしかわせん /貴志川線/
きしかん /既視感/既弛緩/
きしがみ /岸上/
きしがわ /貴志川/
きしけいこ /岸恵子/
きしじま /岸島/
きしせんめい /旗幟鮮明;自分の立場をはっきりさせること/
きしたに /岸谷;姓/
きしだ /岸田/
きしだぎきょくしょう /岸田戯曲賞/
きしだん /騎士団/
きしつ /気質;disposition/基質;matrix,substrate/器質;organ/気室/
きしつか /器質化/
きしつせい /器質性;-障害/
きしつてき /器質的/気質的/
きしつてきしょうがい /器質的障害/
きしどう /騎士道/
きしどうものがたり /騎士道物語;roman de cavalerie/
きしね /岸根/
きしの /岸野/
きしば /岸場/
きしべ /岸辺/岸部;姓/
きしぼじん /鬼子母神/
きしま /杵島/
きしみ /軋み/
きしめん /棊子麺/
きしもじん /鬼子母神/
きしもと /岸本/
きしゃ /記者/汽車/貴社/帰社/喜捨;寄付/騎射;馬上で弓を射ること. 武芸の一/
きしゃえき /汽車駅/
きしゃかいけん /記者会見/
きしゃかいけんしりょう /記者会見資料/
きしゃかいけんじょう /記者会見場/
きしゃがいしゃ /汽車会社/
きしゃく /希釈/稀釈/
きしゃくえき /希釈液/
きしゃくちゅう /希釈中/
きしゃくらぶ /記者クラブ/
きしゃせき /記者席/
きしゃだん /記者団/
きしゃちん /汽車賃/
きしゃはっぴょう /記者発表/
きしやじま /岸屋島/
きしゅ /機種/騎手;rider.「競馬の-」/旗手;standard-bearer.「時代の-」/機首/期首;⇔期末/寄主;[生物]host.⇔寄生者/気腫;[医]emphysema/貴種/奇手/期種/鬼手/起首/
きしゅいぞん /機種依存/
きしゅいぞんせい /機種依存性/
きしゅいぞんぶぶん /機種依存部分/
きしゅいぞんもじ /機種依存文字/
きしゅう /奇襲/紀州;和歌山周辺/貴州;(Giuzhou) 地名,中国/既習;learnt/奇習;strange custom.「山村の-」/季秋;陰暦九月/既収/貴酬/箕帚/奇臭/羇愁/
きしゅういぬ /紀州犬/
きしゅううめ /紀州梅/
きしゅうこうか /奇襲効果/
きしゅうこうげき /奇襲攻撃/
きしゅうじ /紀州路/
きしゅうてつどう /紀州鉄道/
きしゅうてん /起終点/
きしゅうわざ /奇襲技/
きしゅかん /機種間/
きしゅがっこう /騎手学校/
きしゅく /寄宿;-学校/岐宿;地名,長崎/鬼宿;[二十八宿]/耆宿;秀でた老人/
きしゅくしゃ /寄宿舎/
きしゅくせい /寄宿生/
きしゅくりょう /寄宿料/
きしゅこうしん /機種更新/
きしゅごと /機種毎/
きしゅせんたく /機種選択/
きしゅせんてい /機種選定/
きしゅつ /既出/
きしゅとくてい /機種特定/
きしゅはんべつ /機種判別/
きしゅへん /機種変/
きしゅへんこう /機種変更/
きしゅべつ /機種別/
きしゅめい /機種名/騎手名/
きしゅよう /機種用/
きしゅりゅうりたん /貴種流離譚/
きしゅん /季春/
きしょ /期初/貴所;you/奇書;(内容的に)珍しい本/寄書;手紙・原稿などを寄せる/稀書;入手困難な本/希書;=稀書/貴書;your letter/
きしょう /気象/起床/希少/稀少;=希少/気性/記章;badge/徽章;≒記章/奇勝/起請/旗章;flag/毀傷/氣象;「気」旧字/
きしょう> /希少;(rare) -性,-種,-金属/稀少;=希少/
きしょうえいせい /気象衛星/
きしょうかち /希少価値/稀少価値/
きしょうがく /気象学/
きしょうがくしゃ /気象学者/
きしょうがっかい /気象学会/
きしょうきょうかい /気象協会/
きしょうきんぞく /希少金属/
きしょうけいほう /気象警報/
きしょうけん /気象研/
きしょうけんきゅうじょ /気象研究所/
きしょうしゃ /希少車/
きしょうしゅ /希少種/
きしょうじかん /起床時間/
きしょうじょうけん /気象条件/
きしょうじょうほう /気象情報/
きしょうせい /希少性/
きしょうだい /気象台/
きしょうだいがっこう /気象大学校/
きしょうちょう /気象庁/
きしょうてんけつ /起承転結/
きしょうてんごう /起承転合/
きしょうなん /気性難/
きしょうぼり /起請彫り/
きしょうぼん /希少本/
きしょうまえがき /起請前書/
きしょうもん /起請文/
きしょうよほうし /気象予報士/
きしょうりきがく /気象力学/
きしょく /気色/機織/貴職/喜色/寄食/旗色/
きしょくまんめん /喜色満面/
きしり /軋り/
きしろ /木城/
きしわだ /岸和田/
きしわだいずみ /岸和田和泉/
きしわだし /岸和田市/
きしわだしみん /岸和田市民/
きしん /鬼神/寄進/紀信;人名/貴信/貴紳/帰心/忌辰/
きしんごう /黄信号/
きしんせん /姫神線/
きしんへいだん /機神兵団/
きじ /記事/生地/雉/木地/棄児/奇事/素地;陶器の-/
きじいじょう /記事以上/
きじいぜん /記事以前/
きじきさい /記事記載/
きじく /基軸;-通貨/機軸;新-/
きじくつうか /基軸通貨/
きじぐん /記事群/
きじけいさい /記事掲載/
きじごと /記事毎/
きじさんしょう /記事参照/
きじじたい /記事自体/
きじすう /記事数/
きじせんたく /記事選択/
きじぜんたい /記事全体/
きじぜんぱん /記事全般/
きじぜんぶ /記事全部/
きじちゅう /記事中/
きじつ /期日/忌日/記実/枳実/
きじつしてい /期日指定/
きじつぜん /期日前/
きじつぜんとうひょう /期日前投票/
きじつない /期日内/
きじつぶん /記実文/
きじとうこう /記事投稿/
きじとうこうしゃ /記事投稿者/
きじないよう /記事内容/
きじなど /記事等/
きじばと /雉鳩/
きじばんごう /記事番号/
きじぶぶん /記事部分/
きじほんたい /記事本体/
きじま /木島/貴島/木嶋/
きじまだいら /木島平/
きじめい /記事名/
きじもと /雉本/
きじゃく /着尺/
きじゃくし /木杓子/
きじや /木地屋/
きじゅ /喜寿;77歳/耆儒/
きじゅう /機銃/奇獣/騎銃/寄住/器什/帰従/帰住/
きじゅうき /起重機/
きじゅうぐん /機銃群/
きじゅうそうしゃ /機銃掃射/
きじゅつ /記述;†description.「-試験」/奇術;magic/既述;†既に述べた。「-の通り」/
きじゅつかのう /記述可能/
きじゅつぐん /記述群/
きじゅつけいしき /記述形式/
きじゅつげんご /記述言語/
きじゅつげんごがく /記述言語学;descriptive linguistics/
きじゅつこうもく /記述項目/
きじゅつご /記述後/
きじゅつし /記述子/奇術師/
きじゅつしき /記述式/
きじゅつしきしけん /記述式試験/
きじゅつしきもんだい /記述式問題/
きじゅつしゃ /記述者/
きじゅつじょう /記述上/
きじゅつせい /記述性/
きじゅつてき /記述的/
きじゅつとうけいがく /記述統計学/
きじゅつないよう /記述内容/
きじゅつのうりょく /記述能力/
きじゅつぶ /奇術部/記述部/
きじゅつぶぶん /記述部分/
きじゅつぶんぽう /記述文法;[言語]descriptive grammar.⇔規範文法/
きじゅつほう /記述法/
きじゅつほうほう /記述方法/
きじゅつもんだい /記述問題/
きじゅつよう /記述用/
きじゅつようしき /記述様式/
きじゅつらん /記述欄/
きじゅつりょう /記述量/
きじゅつりょく /記述力/
きじゅつりろん /記述理論/
きじゅつれい /記述例/
きじゅん /基準;†standard.「判定-」/規準;†criterion.「行為の-」/帰順/
きじゅんいち /基準位置/
きじゅんおん /基準音/
きじゅんか /基準化/規準化/
きじゅんかがく /基準価額/
きじゅんき /規準器/
きじゅんきかん /基準期間/
きじゅんけい /基準系/
きじゅんこう /基準項/
きじゅんしゃ /基準車/
きじゅんしゅうはすう /基準周波数/
きじゅんしょ /基準書/
きじゅんしんごう /基準信号/
きじゅんしんどう /基準振動;[物理]normal vibration/
きじゅんせん /基準線/
きじゅんち /基準値/
きじゅんちか /基準地価;benchmark land price. <国土利用計画法/
きじゅんちょう /基準長/
きじゅんてき /規準的/
きじゅんてん /基準点/
きじゅんない /基準内/
きじゅんひょうほん /基準標本;[生物]type specimen/
きじゅんふく /基準服/
きじゅんへんこう /基準変更/
きじゅんほう /基準法/
きじゅんめん /基準面/
きじゅんやっきょく /基準薬局/
きじょ /機序/鬼女/貴女/
きじょう /騎乗/机上/機上/気丈/軌条/木城;地名/騎上/
きじょうい /騎乗位/
きじょういらい /騎乗依頼/
きじょうきかい /騎乗機会/
きじょうぎじゅつ /騎乗技術/
きじょうていし /騎乗停止/
きじょうていししょぶん /騎乗停止処分/
きじょうのくうろん /机上の空論/
きじょうば /騎乗馬/
きじょうぶ /気丈夫/
きじょうゆ /生醤油/
きじらん /記事欄/
きじりょう /記事量/
きじるし /キ印/き印/
きじん /鬼神/奇人/貴人/畸人;=奇人/
きじんぶ /基人部/
きじんへんじん /奇人変人/畸人變人/
きす /鱚/木須/
きすい /汽水;河口等の薄い塩水/既遂/気水;steam-water.「-分離器」/
きすいいき /気水域/
きすいこ /汽水湖;brackish lake/
きすう /奇数/基数/帰趨/機数/
きすうかい /奇数回/
きすうし /基数詞;[文法]cardinal numeral/
きすうじ /奇数時/
きすうばん /奇数番/
きすうぶ /基数部/
きすうぺーじ /奇数頁/
きすうほう /記数法/
きすが /貴家;きか? さすが?/
きすき /木次/
きすきせん /木次線/
きすぎ /来生/
きすみ /木栖/
きず /傷/瑕;(字義:玉についた傷=欠点)「栄誉に瑕がつく」「玉に瑕」/疵;(字義:かすり傷=損傷)「製品の疵」/木酢;(木になる)柑橘類から作る酢/生酢;割ってない酢/岐津;地名,岐阜/痍;(字義:平らな切り傷)/
きずあと /傷跡/傷痕/
きずい /奇瑞/気随;-気儘/
きずいきまま /気随気儘/
きずいしょう /黄水晶;citrine/
きずいせん /黄水仙;jonquil/
きずかい /気遣い;※仮名遣い「きづかい」/
きずき /杵築/
きずきがみ /生漉紙/
きずくり /木造;※仮名遣い「きづくり」/
きずぐすり /傷薬/
きずぐち /傷口/
きずな /絆/紲;≒絆/
きずもの /傷物/疵物/
きせ /黄瀬/木瀬/吉瀬/
きせい /規制;restrict/帰省/既成;†existing.「-概念」/寄生/奇声/既製;†ready-made.「-服」/棋聖/気勢/期成/規正;rectify/期生/紀勢/規整/祈誓/棋勢/
きせいいがい /規制以外/
きせいかいじょ /規制解除/
きせいかざん /寄生火山/
きせいかんわ /規制緩和/
きせいがいねん /既成概念/
きせいきょうか /規制強化/
きせいきんり /規制金利/
きせいくいき /規制区域/
きせいぐみ /帰省組/
きせいこん /寄生根/
きせいご /規制後/
きせいさき /帰省先/
きせいさきじゅうしょ /帰省先住所/
きせいしゃ /規制車/
きせいしょくぶつ /寄生植物/
きせいじ /帰省時/
きせいじじつ /既成事実/
きせいじぬし /寄生地主/
きせいじゅう /寄生獣/
きせいせいとう /既成政党/
きせいせいぶつ /寄生生物/
きせいせん /棋聖戦/
きせいそくど /規制速度/
きせいたいしょう /規制対象/
きせいたいしょうがい /規制対象外/
きせいたいしょうしゃ /規制対象車/
きせいち /規制値/
きせいちいき /規制地域/
きせいちいきない /規制地域内/
きせいちゅう /寄生虫/帰省中/
きせいちゅうしょう /寄生虫症;[医]/
きせいてきごう /規制適合/
きせいてっぱい /規制撤廃/
きせいどうとく /既成道徳/
きせいどうにゅう /規制導入/
きせいないよう /規制内容/
きせいはんたい /規制反対/
きせいひょうしき /規制標識/
きせいひん /既製品/既成品/
きせいふく /既製服/
きせいほう /規制法/
きせいほんせん /紀勢本線/
きせいまえ /規制前/
きせいめいがら /規制銘柄/
きせいようりょう /寄生容量/
きせいらっしゅ /帰省ラッシュ/
きせかえにんぎょう /着せ替え人形/
きせき /奇跡;†miracle/軌跡;†locus/奇蹟;=奇跡/貴石/輝石/奇石/帰責/鬼籍/碁石;棋石/基石/貴戚;貴族、その親戚/帰籍/棋石;碁石/寄迹;身を寄せる、寄寓する/
きせきじゆう /帰責事由/
きせきてき /奇跡的/
きせせん /紀勢線/
きせつ /季節/既設/奇説/気節;気概と節操/
きせつうんてん /季節運転/
きせつかん /季節感/
きせつかんぜい /季節関税/
きせつがい /季節外/
きせつがら /季節柄/
きせつげんてい /季節限定/
きせつごと /季節毎/
きせつしゃ /季節車/
きせつぞう /季節増/
きせつちょうせい /季節調整/
きせつてき /季節的/
きせつはずれ /季節外れ/
きせつふう /季節風/
きせつへんどう /季節変動/
きせつよう /季節用/
きせつれっしゃ /季節列車/
きせと /黄瀬戸/
きせのん /Xe/Xenon/
きせる /煙管/
きせん /汽船/基線/棋戦/貴賤/機先/機船/黄線/帰線/帰船/帰仙/
きせんいでん /帰先遺伝/
きせんちょう /基線長/
きぜつ /気絶/奇絶/
きぜつじ /気絶時/
きぜつち /気絶値/
きぜわ /生世話/
きぜん /毅然/喟然;嘆息する様子/
きそ /基礎/起訴/木曽/木曾;「曽」異体字/木祖/稀疎/
きそ> /基礎;-科学,-物理学/
きそう /起草/気相/奇想/基層;-文化/帰巣/寄贈;=きぞう/吉左右/貴僧/竸/
きそうかん /気送管/
きそうきょく /奇想曲/
きそうご /基層語/
きそうせい /帰巣性/
きそうてんがい /奇想天外/
きそうてんがいしゃ /奇想天外社/
きそうほんのう /帰巣本能/
きそえいご /基礎英語/
きそえんしゅう /基礎演習/
きそかいせき /基礎解析/
きそかがく /基礎科学/
きそかがっか /基礎科学科/
きそかもく /基礎科目/
きそがいねん /基礎概念/
きそがくりょく /基礎学力/
きそがため /基礎固め/
きそがわ /木曽川/
きそきょういく /基礎教育/
きそきょうよう /基礎教養/
きそぎじゅつ /基礎技術/
きそぎじゅつけんきゅう /基礎技術研究/
きそぎじゅつへん /基礎技術編/
きそぎほう /基礎技法/
きそく /規則/気息/羈束/
きそくいはん /規則違反/
きそくえんえん /気息奄奄/気息奄々/
きそくか /規則化/
きそくかいせい /規則改正/
きそくがた /規則型/
きそくこうい /羈束行為/
きそくごうせい /規則合成/
きそくしゅう /規則集/
きそくしょ /規則書/
きそくじょう /規則上/
きそくせい /規則性/
きそくちゅうしゅつ /規則抽出/
きそくてき /規則的/
きそくどうし /規則動詞;[文法]tie-tied-tied/
きそくへんか /規則変化/
きそくへんこう /規則変更/
きそくめい /規則名/
きそくもんだい /規則問題/
きそくりょく /羈束力/
きそくんれん /基礎訓練/
きそけい /基礎系/
きそけしょう /基礎化粧/
きそけしょうひん /基礎化粧品/
きそけん /基礎研/
きそけんきゅう /基礎研究/
きそけんきゅうしつ /基礎研究室/
きそけんきゅうしょ /基礎研究所/
きそけんきゅうじょ /基礎研究所/
きそけんきゅうぶ /基礎研究部/
きそこう /基礎工/基礎項/
きそこうがく /基礎工学/
きそこうがくぶ /基礎工学部/
きそこうがくるい /基礎工学類/
きそこうざ /基礎講座/
きそこうじ /基礎工事/
きそこうじょ /基礎控除/
きそこまこうげん /木曽駒高原/
きそさぎょう /基礎作業/
きそざき /木曾岬/
きそしけん /基礎試験/
きそしょくひん /基礎食品/
きそしりょう /基礎資料/
きそじ /木曽路/
きそじじつ /起訴事実/
きそじっけん /基礎実験/
きそじょう /起訴状/
きそじょうほうがく /基礎情報学/
きそすう /奇素数/
きそすうがく /基礎数学/
きそすうがくせんしょ /基礎数学選書/
きそせつ /基礎節/
きそそうさ /基礎操作/
きそたい /基礎体/
きそたいおん /基礎体温/
きそたいしゃ /基礎代謝/
きそたいしゃりょう /基礎代謝量/
きそたいりょく /基礎体力/
きそたに /木曽谷/
きそだに /木曽谷/
きそちしき /基礎知識/
きそちゅう /基礎中/
きそつ /既卒/
きそつしゃ /既卒者/
きそづけ /基礎付け/
きそてき /基礎的/
きそてきがいねん /基礎的概念/
きそてきけんきゅう /基礎的研究/
きそてきこうさつ /基礎的考察/
きそてきちしき /基礎的知識/
きそてん /基礎点/
きそとう /基礎棟/
きそねんきん /基礎年金/
きそば /生蕎麦;蕎麦粉だけで作ったソバ/
きそひょう /基礎票/
きそふくしま /木曽福島/木曾福島/
きそふくしまえき /木曽福島駅/
きそぶし /木曾節;[民謡]長野. 「ヨイヨイヨイ」/
きそぶぶん /基礎部分/
きそぶんけん /基礎文献/
きそへん /基礎編/
きそべんぎしゅぎ /起訴便宜主義/
きそほうていしき /基礎方程式/
きそほうていしきけい /基礎方程式系/
きそや /基礎屋/
きそゆうよ /起訴猶予/
きそようご /基礎用語/
きそりょく /基礎力/
きそりろん /基礎理論/
きそれんしゅう /基礎練習/
きそろん /基礎論/
きそろんけんきゅうかい /基礎論研究会/
きそろんてき /基礎論的/
きそん /既存/毀損/帰村/
きそんてん /既存店/
きぞう /寄贈/寄蔵/
きぞうひん /寄贈品/
きぞく /帰属/貴族/
きぞくいしき /帰属意識/
きぞくいん /貴族院/
きぞくかいきゅう /貴族階級/
きぞくかんけい /帰属関係/
きぞくしゃかい /貴族社会/
きぞくしゅぎ /貴族主義/
きぞくてき /貴族的/
きぞめ /着初め/
きぞん /既存/
きぞんしゃりょう /既存車両/
きぞんせつび /既存設備/
きぞんせん /既存線/
きぞんばん /既存盤/
きた /北/喜多/木田/喜田/
きた> /北/
きたあいき /北相木/
きたあいづ /北会津/
きたあきた /北秋田/
きたあげお /北上尾/
きたあずみ /北安曇/
きたあだち /北足立/
きたあまべ /北海部/
きたあめりか /北アメリカ/
きたあめりかたいりく /北アメリカ大陸/
きたあやせ /北綾瀬/
きたありま /北有馬/
きたい /期待/機体/気体/稀代/北井/基体/危殆/奇態/奇体/奇胎;[医]/鬼胎;心配/
きたいいじょう /期待以上/
きたいかん /期待感/
きたいがい /期待外/
きたいきょうど /機体強度/
きたいけいじょう /機体形状/
きたいさく /期待作/
きたいさんそ /気体酸素/
きたいじゅうりょう /機体重量/
きたいじょう /気体状/
きたいずみ /北泉/
きたいせきにん /危殆責任/
きたいぞく /期待族;暴走行為の見物人たちのことをいうらしい。/
きたいたみ /北伊丹/
きたいだい /期待大/
きたいち /期待値/
きたいちがらす /北一硝子/
きたいっき /北一輝/
きたいていすう /気体定数;[化学]8.3143J／K・mol/
きたいてん /期待点/
きたいど /期待度/
きたいどおり /期待通り/
きたいはずれ /期待外れ/
きたいはん /危殆犯/
きたいはんぶん /期待半分/
きたいば /期待馬/
きたいばらき /北茨城/
きたいばらぎし /北茨城市/
きたいぶんし /気体分子/
きたいぼ /期待薄;?/
きたうおぬま /北魚沼/
きたうち /北内/
きたうら /北浦/
きたうらわ /北浦和/
きたうわ /北宇和/
きたえ /鍛え/
きたえかた /鍛え方/
きたえき /北駅/
きたえだ /北枝/
きたお /北尾/
きたおおさか /北大阪/
きたおおさかきゅうこう /北大阪急行/
きたおおさかきゅうこうせん /北大阪急行線/
きたおおじ /北大路/
きたおおじえき /北大路駅/
きたおおつか /北大塚/
きたおか /北岡/
きたおかざき /北岡崎/
きたおく /北奥/
きたおね /北尾根/
きたおり /北折/
きたかいがん /北海岸/
きたかいきせん /北回帰線/
きたかしま /北鹿島/
きたかすかべ /北春日部/
きたかぜ /北風/
きたかぜこぞう /北風小僧/
きたかた /喜多方/北方/
きたかたかん /喜多方間/
きたかたらーめん /喜多方ラーメン/
きたかちどき /北勝閧/
きたかつしか /北葛飾/
きたかつらぎ /北葛城/
きたかべ /北壁/
きたかまくら /北鎌倉/
きたかみ /北上/
きたかみがわ /北上川/
きたかみせん /北上線/
きたかるいざわ /北軽井沢/
きたかわ /北川/
きたかわち /北河内/
きたかわべ /北川辺/
きたかん /北館/
きたかんとう /北関東/
きたかんとうちく /北関東地区/
きたかんとうばん /北関東版/
きたかんばら /北蒲原/
きたがき /北垣/
きたがた /北方/
きたがわ /北側/北川/喜多川/北河/
きたがわうたまろ /喜多川歌麿/
きたがわしゃせん /北側斜線/
きたがわちょう /北川町/
きたきつね /北狐/
きたきゅうしゅう /北九州/
きたきゅうしゅうきねん /北九州記念/
きたきゅうしゅうくうこう /北九州空港/
きたきゅうしゅうこうじょう /北九州工場/
きたきゅうしゅうし /北九州市/
きたきゅうしゅうしえい /北九州市営/
きたきゅうしゅうしない /北九州市内/
きたきゅうしゅうせん /北九州線/
きたきりすずめ /着た切り雀/
きたきんき /北近畿/
きたく /帰宅/寄託/北区/貴宅/
きたくかん /北区間/
きたくご /帰宅後/
きたくしゃ /寄託者/
きたくじ /帰宅時/
きたくじかん /帰宅時間/
きたくちゅう /帰宅中/
きたくとちゅう /帰宅途中/
きたくぶ /帰宅部/
きたくまえ /帰宅前/
きたくみん /北区民/
きたくりはま /北久里浜/
きたくわだ /北桑田/
きたぐち /北口/
きたぐに /北国/
きたぐんま /北群馬/
きたけ /着丈/木竹;木石/
きたこう /北港/
きたこうじ /北小路/
きたこし /北越;姓/
きたこま /北巨摩/
きたこまぐん /北巨摩郡/
きたこまつ /北小松/
きたごう /北郷/
きたさいたま /北埼玉/
きたさく /北佐久/
きたさわとうげ /北沢峠/
きたざと /北里/
きたざとだいがく /北里大学/
きたざわ /北沢/北澤/
きたざわびじゅつかん /北澤美術館/
きたしおばら /北塩原/
きたしが /北志賀/
きたしたら /北設楽/
きたしながわえき /北品川駅/
きたしなの /北信濃/
きたしょく /北食/
きたしらかわ /北白川/
きたしらかわのみや /北白川宮/
きたしんち /北新地/
きたじま /北島/北嶋/喜多嶋/
きたじまさぶろう /北島三郎/
きたじょう /喜多條/
きたすぎ /北杉/
きたすな /北砂/
きたせん /北線/
きたせんじゅ /北千住/
きたせんじゅえき /北千住駅/
きたせんぞく /北千束/
きたせんだい /北仙台/
きたせんり /北千里/
きたそうま /北相馬/
きたぞの /北園/
きたたいせいよう /北大西洋/
きたたいせいようじょうやくきこう /北大西洋条約機構;NATO (North Atlantic Treaty Organisation)/
きたたいへいよう /北太平洋/
きたたかき /北高来/
きたたかぎ /北高来/
きたたちばな /北橘/
きたたに /北谷/
きたたま /北多摩/
きただ /北田/
きただい /北代/
きただいとう /北大東/
きただけ /北岳/
きたちく /北地区/
きたちしま /北千島/
きたちょうせん /北朝鮮/
きたちょうせんかんこう /北朝鮮観光/
きたちょうせんせき /北朝鮮籍/
きたつがる /北津軽/
きたつる /北都留/
きたとしま /北豊島/
きたとだ /北戸田/
きたど /北戸/
きたどの /北殿/
きたなか /北中/
きたなかぐすく /北中城/
きたならしの /北習志野/
きたならしのえき /北習志野駅/
きたに /木谷/
きたにほん /北日本/
きたにほんがくせい /北日本学生/
きたね /北根/
きたの /北野/
きたのうみ /北の湖/
きたのかた /北の方/
きたのせん /北野線/
きたのたけし /北野武/
きたのてんまんぐう /北野天満宮/
きたのまる /北の丸/
きたはし /北橋/
きたはた /北波多/
きたはちおうじ /北八王子/
きたはっこうだ /北八甲田/
きたはま /北浜/
きたはら /北原/
きたはらはくしゅう /北原白秋/
きたはんきゅう /北半球/
きたはんぶん /北半分/
きたばたけ /北畠/北畑/
きたばやし /北林/
きたひろしま /北広島/
きたひろしまし /北広島市/
きたべっぷ /北別府/
きたほ /北穂/
きたほだか /北穂高/
きたほっかいどう /北北海道/
きたまえぶね /北前船/
きたまくら /北枕/
きたまち /北町/
きたまちぶぎょう /北町奉行/
きたまつ /北松/
きたまつど /北松戸/
きたまど /北窓/
きたまわり /北回り/
きたみ /北見/喜多見/
きたみざわ /北見沢/
きたみち /北道/
きたみまき /北御牧/
きたむき /北向き/
きたむら /北村/喜多村/
きたむらやま /北村山/
きたむろ /北牟婁/
きため /北目/
きためまち /北目町/
きたもうこ /北蒙古/
きたもと /北本/
きたもとし /北本市/
きたもり /北森/
きたもりお /北杜夫/
きたもろかた /北諸県/
きたもん /北門/
きたや /北谷/
きたやま /北山/
きたやまさ /北山佐/
きたやまどの /北山殿;金閣／足利義満/
きたやまぶんか /北山文化/
きたゆき /北行/
きたよーろっぱ /北ヨーロッパ/
きたより /北寄り/
きたら /喜多羅/
きたりゅう /喜多流/
きたる /来る/
きたろう /鬼太郎;[漫画]「ゲゲゲの-」/喜多郎;(ミュージシャン)/喜太郎;名/
きたわき /北脇/
きたん /奇譚/忌憚;-なきご意見を/綺譚;≒綺譚/
きたんかいきょう /紀淡海峡/
きたんさく /木探索/
きだ /木田/喜田;姓/貴田/段/
きだい /稀代/希代/基台/機台/季題/気大/貴台/
きだいがく /貴大学/
きだおれ /着倒れ/
きだち /木太刀/木立ち;boscage/木質/
きだて /気立て/気だて/気立/
きだまり /木田余/
きだん /奇談/綺談/気団/基壇/綺譚;=きたん/
きち /基地/吉/既知/機知;wit/機智;=機知/危地/貴地/窺知/
きちあと /基地跡/
きちえもん /吉右衛門/
きちかん /奇置換/
きちがい /気違い/気狂い/
きちがいざた /気違い沙汰/
きちきょく /基地局/
きちく /鬼畜/
きちくべいえい /鬼畜米英/
きちじ /吉事/
きちじつ /吉日/
きちじま /吉島/
きちじょう /吉祥/吉上/
きちじょうじ /吉祥寺/
きちじょうじえき /吉祥寺駅/
きちじょうじてん /吉祥寺店/
きちじょうじとうきゅう /吉祥寺東急/
きちじょうじょし /吉祥女子/
きちじょうそう /吉祥草/
きちじょうてん /吉祥天/
きちすう /吉数/
きちせい /既知性/
きちぞう /吉蔵/
きちてん /既知点/
きちない /基地内/
きちのすけ /吉之助/
きちぼうくう /基地防空/
きちむ /吉夢/
きちゃ /黄茶/
きちゃく /帰着/
きちゅう /期中/機中/忌中/基柱/
きちゅうはく /機中泊/
きちょ /貴著/
きちょう /貴重/基調/記帳/機長/帰朝/几帳/帰庁/綺帳/
きちょうえんぜつ /基調演説/
きちょうこうえん /基調講演/
きちょうひん /貴重品/
きちょうめん /几帳面/
きちれい /吉例/
きちろう /吉郎/
きちん /木賃/
きちんやど /木賃宿/
きっか /菊花/菊華/橘花/
きっかい /奇っ怪/
きっかけ /切っ掛け/
きっかこうこう /菊華高校/
きっかしょう /菊花賞/
きっかしょうば /菊花賞馬/
きっかもん /菊花紋/
きっかわ /吉川/菊川/
きっかわもとはる /吉川元春/
きっきゅうじょ /鞠躬如/
きっきょ /拮据/
きっきょう /吃驚/吉凶/喫驚;=吃驚/
きっきん /喫緊/吃緊/
きっくつ /佶屈/
きっこう /拮抗/亀甲/
きっこうかっこ /亀甲括弧/〔/〕/
きっこうがた /亀甲形/
きっこうきん /拮抗筋/
きっこうけい /亀甲型/
きっこうしばり /亀甲縛り/
きっこうでん /乞巧奠/
きっこうまん /亀甲萬/
きっさ /喫茶/
きっさき /切っ先/切先/切尖/
きっさしつ /喫茶室/
きっさてん /喫茶店/
きっしょ /吉書/
きっしょう /吉祥/
きっしょういん /吉祥院/
きっしょうてんにょ /吉祥天女/
きっしょく /喫食/
きっすい /生粋/喫水/吃水;=喫水/
きっすいせん /喫水線/
きっせき /詰責/
きっせん /吉仙/
きっそう /吉相/吉左右/
きっそうこん /吉草根/
きっそうさん /吉草酸/
きったか /橘高/
きったて /切立/
きったはった /切った張った/
きったんもじ /契丹文字/
きっちょう /吉兆/
きっちょむ /吉四六;名/
きっつけ /切付/
きって /切手/
きってしゅうしゅう /切手収集/
きってだい /切手代/
きってどうふう /切手同封/
きっと /屹度;(当て字) for sure.「-うまく行く」/吉都;地名/急度;(当て字) =屹度/吃度;?/
きっぷ /切符/気風/気っ風/
きっぷうりば /切符売場/
きっぷだい /切符代/
きっぷはいけん /切符拝見/
きっぽう /吉報/吉方/
きつ /詰/喫/吉/橘;柑橘類/拮;拮抗/佶;佶屈/桔/乞/吃;吃音/屹;屹立/訖;おわる/迄;まで/
きつえん /喫煙/
きつえんいがい /喫煙以外/
きつえんか /喫煙可/喫煙家/
きつえんかのう /喫煙可能/
きつえんき /喫煙期/
きつえんきせい /喫煙規制/
きつえんぐ /喫煙具/
きつえんけん /喫煙権/
きつえんこーなー /喫煙コーナー/
きつえんこうい /喫煙行為/
きつえんしつ /喫煙室/
きつえんしゃ /喫煙者;smoker/喫煙車;smoking carriage/
きつえんしゃがわ /喫煙者側/
きつえんしゃりつ /喫煙者率/
きつえんしゃりょう /喫煙車両/
きつえんしゅうかん /喫煙習慣/
きつえんしょ /喫煙所/
きつえんじ /喫煙時/
きつえんじょ /喫煙所/
きつえんじょいがい /喫煙所以外/
きつえんせいげん /喫煙制限/
きつえんせき /喫煙席/
きつえんちゅう /喫煙中/
きつえんは /喫煙派/
きつえんばしょ /喫煙場所/
きつえんふか /喫煙不可/
きつえんほうほう /喫煙方法/
きつえんもんだい /喫煙問題/
きつえんりつ /喫煙率/
きつえんりょう /喫煙量/
きつえんれき /喫煙歴/
きつおん /吃音/
きつかわ /橘川/
きつき /杵築/
きつけ /着付け;和服の-/気付け;-薬/気付/気附/
きつけぐすり /気付け薬/
きつご /吃語/
きつぜん /屹然/
きつつき /啄木鳥/
きつと /吉都/
きつとせん /吉都線/
きつね /狐/
きつねいろ /狐色/
きつねうどん /狐饂飩/
きつねけん /狐拳/
きつねそば /狐蕎麦/
きつねつき /狐憑き/
きつねづか /狐塚/
きつねのまごか /キツネノマゴ科/Acanthaceae/
きつねび /狐火/
きつねものがたり /狐物語/
きつむ /吉夢;=きちむ/
きつもん /詰問/
きつりつ /屹立/
きつりん /吉林/
きつるばみ /黄橡/
きつれがわ /喜連川/
きづ /木津/岐津/
きづかい /気遣い/氣遣い;旧字/
きづかれ /気疲れ/
きづがわ /木津川/
きづき /杵築/木月/木築/
きづく /気附/
きづくり /木造/木造り/
きづけ /気付/気附/
きづた /木蔦/
きづち /木槌/
きづまり /気詰まり/気詰り/
きて /来手;嫁の―がない/
きてい /規定;†rules/規程;†一連の規定。「服務-」/既定;†fixed.「-路線」/基底;base/旗亭/汽艇/
きていいじょう /規定以上/
きていえんぎ /規定演技/
きていか /規定化/
きていかいすう /規定回数/
きていかんすう /基底関数/
きていがい /規定外/
きていぎ /既定義/
きていこう /基底項/
きていじかん /規定時間/
きていじょう /規定上/
きていじょうたい /基底状態/
きていすういじょう /規定数以上/
きていそう /基底層/
きていだせき /規定打席/
きていだせきすう /規定打席数;[野球] NB:試合数×3.1/
きていだせきとうたつ /規定打席到達/
きていち /既定値/規定値/
きていとうきゅうかいすう /規定投球回数/
きていないよう /規定内容/
きていはんい /規定範囲/
きていひ /既定費/
きていぶん /基底文/
きていまく /基底膜/
きていまくじょう /基底膜上/
きていもく /奇蹄目/
きていりょう /規定量/
きているい /奇蹄類/
きていれい /基底例/
きていろせん /既定路線/規定路線/
きてき /汽笛/
きてれつ /奇天烈/
きてん /起点;†start.⇔終点。「国道の-」/基点;†base.「グリッドの-」/機転;「-が利く」/貴店/輝点/気転;=機転/
きでら /紀寺/
きでん /貴殿/機電/記伝/起電/紀伝/
きでんたい /紀伝体/
きでんりょく /起電力/
きと /帰途/企図/
きとう /気筒/祈祷/亀頭/帰投/帰島/鬼頭;人名/紀藤/木藤/木頭/貴答/
きとうし /祈祷師/
きとうしょ /祈祷書/
きとうすう /気筒数/
きとく /奇特/危篤/既得/
きとくけん /既得権/
きとくけんえき /既得権益/
きど /輝度/木戸/城戸/鬼怒/喜怒/希土/
きどあいらく /喜怒哀楽/
きどう /起動;start/機動;mobile.「-部隊」/軌道;orbit/気道;[解剖]airways/綺堂;人名,岡本-/鬼道;[仏教]餓鬼道/棋道;囲碁将棋の道/詭道;不正な手段/奇道;珍しい方法/奇童;極めて賢い子/
きどうおん /起動音/
きどうかんきょう /起動環境/
きどうかんすう /軌道関数;[物理]orbital function/
きどうかんたい /機動艦隊/
きどうがめん /起動画面/
きどうきょうか /軌道強化/
きどうけいさつ /機動警察/
きどうけいじょう /軌道形状/
きどうご /起動後/
きどうしき /軌道敷/
きどうしゃ /気動車/機動車/軌道車/
きどうしゅうせい /軌道修正/
きどうしゅうりょう /起動終了/
きどうじ /起動時/
きどうじかん /起動時間/
きどうじき /軌道敷/
きどうじどうしゃ /軌道自動車/
きどうじゅんい /起動順位/
きどうじょう /軌道上/
きどうじょうけん /起動条件/
きどうせい /機動性/
きどうせいぎょ /軌道制御/
きどうせんし /機動戦士/
きどうたい /機動隊/
きどうたいいん /機動隊員/
きどうちゅう /起動中/
きどうちょくご /起動直後/
きどうてき /機動的/
きどうてん /軌道点/
きどうでんりゅう /起動電流/
きどうとちゅう /起動途中/
きどうはんけい /軌道半径/
きどうぶたい /機動部隊/
きどうへいき /機動兵器/
きどうほう /軌道法/起動法/
きどうほうほう /起動方法/
きどうまえ /起動前/
きどうよう /起動用/
きどうようそ /軌道要素/
きどうらく /着道楽/
きどうりょく /機動力/
きどく /既読/奇特/
きどくきじ /既読記事/
きどぐち /木戸口/
きどけいさん /輝度計算/
きどこうばい /輝度勾配/
きどころ /木所/
きどごめん /木戸御免/
きどしんごう /輝度信号/
きどせん /木戸銭/木戸錢;「銭」旧字/
きどちょうせい /輝度調整/
きどで /木戸出/
きどり /気取り/木取り/
きどりや /気取り屋/
きどるい /希土類/
きどわき /木戸脇/
きない /機内/畿内/
きないご /畿内語/
きないし /機内誌/
きないしょく /機内食/
きないはく /機内泊/
きないはんばい /機内販売/
きなが /気長/
きながし /着流し/
きなぐさみ /気慰み/
きなこ /黄粉/黄な粉/
きなこもち /黄な粉餅/
きなさ /鬼無里/
きなし /木梨/
きなべ /汽鍋/
きなり /生成り/
きなん /貴男/紀南/危難/
きにち /忌日/帰日/
きにゅう /記入/
きにゅうしゃ /記入者/
きにゅうじょう /記入上/
きにゅうばしょ /記入場所/
きにゅうび /記入日/
きにゅうほう /記入法/
きにゅうほうほう /記入方法/
きにゅうみす /記入ミス/
きにゅうもれ /記入漏れ/
きにゅうらん /記入欄/
きにゅうれい /記入例/
きにゅうれいさんしょう /記入例参照/
きにょう /鬼繞/
きにら /黄韮;中華食材/黄ニラ/
きにん /貴人/帰任/
きにんぐち /貴人口;[茶道]/
きにんご /帰任後/
きにんだたみ /貴人畳;[茶道]/
きにんだて /貴人点/
きぬ /絹/衣/帛/
きぬいと /絹糸/
きぬうんも /絹雲母/
きぬえ /絹枝/
きぬおり /絹織/
きぬおりもの /絹織物/
きぬかつぎ /衣被;[料理]皮ごと茹でた里芋/衣被ぎ/
きぬかわ /衣川/
きぬがさ /衣笠/
きぬがわ /鬼怒川/
きぬがわおんせん /鬼怒川温泉/
きぬぎぬ /衣々;朝の別れ/後朝;=衣々/衣衣/
きぬけ /気抜け/
きぬげ /絹毛/
きぬごし /絹漉し/絹ごし/
きぬさや /絹莢/
きぬじ /絹地/
きぬずれ /衣擦れ;「―の音」/
きぬた /砧/碪;=砧/
きぬたこつ /砧骨;[解剖](中耳の)incus/
きぬのみち /絹の道/
きぬばり /絹針/絹張り/
きぬもの /絹物/
きぬや /絹屋/
きぬわた /絹綿/
きね /杵/木根/
きねしま /杵嶋/
きねずみ /木鼠/
きねづか /杵柄/
きねや /杵屋/
きねん /記念/祈念;pray/紀年/
きねんかい /記念会/
きねんかいかん /記念会館/
きねんかん /記念館/
きねんきって /記念切手/
きねんきっぷ /記念切符/
きねんきょうぎじょう /記念競技場/
きねんきょく /記念局/
きねんぎょうじ /記念行事/
きねんけん /記念券/
きねんこうえん /記念公園/記念公演/
きねんこうどう /記念講堂/
きねんさい /記念祭/祈年祭;=としごいのまつり/
きねんさつえい /記念撮影/
きねんさつえいよう /記念撮影用/
きねんし /記念誌/
きねんしきてん /記念式典/
きねんしゃしん /記念写真/
きねんしゅっぱん /記念出版/
きねんしょくじゅ /記念植樹/
きねんじぎょう /記念事業/
きねんじゅ /記念樹/
きねんじょうしゃけん /記念乗車券/
きねんたいかい /記念大会/
きねんはいとう /記念配当/
きねんひ /記念碑/
きねんひてきけっさく /記念碑的傑作/
きねんひん /記念品/
きねんひんだい /記念品代/
きねんび /記念日/
きねんぶつ /記念物/
きねんろんぶんしゅう /記念論文集/
きの /木野/紀;姓/
きのう /機能/昨日/帰納/帰農/既納;⇔未納/気嚢/
きのういがい /機能以外/
きのうかいぜん /機能改善/
きのうかいふく /機能回復/
きのうかいふくくんれん /機能回復訓練/
きのうかくちょう /機能拡張/
きのうかくちょうばん /機能拡張版/
きのうかん /機能間/
きのうがいよう /機能概要/
きのうがくしゅう /帰納学習/
きのうきょう /昨日今日/
きのうきょうか /機能強化/
きのうぐん /機能群/
きのうげんざい /昨日現在/
きのうげんてい /機能限定/
きのうこうじょう /機能向上/
きのうご /機能語;[言語]function word/
きのうごと /機能毎/
きのうしゅぎ /機能主義/
きのうしょうかい /機能紹介/
きのうしょうがい /機能障害/
きのうしよう /機能仕様/
きのうしようしょ /機能仕様書/
きのうじゅうし /機能重視/
きのうじょう /機能上/
きのうすいろん /帰納推論/
きのうせい /機能性/
きのうせいげん /機能制限/
きのうせいしょくひん /機能性食品/
きのうせっけい /機能設計/
きのうせってい /機能設定/
きのうせつめい /機能説明/
きのうたんい /機能単位/
きのうち /木内/木之内/城内/
きのうついか /機能追加/
きのうつき /機能付/
きのうていし /機能停止/
きのうていり /帰納定理/
きのうてき /機能的;functional/帰納的;recursive/
きのうてきかんすう /帰納的関数/
きのうてきすいろん /帰納的推論/
きのうてきせいしつ /機能的性質/
きのうてきていぎ /帰納的定義/
きのうてん /機能点/
きのうとし /機能都市/
きのうひょうげん /機能表現/
きのうび /機能美/
きのうふか /機能付加/
きのうふぜん /機能不全/
きのうぶい /機能部位/
きのうぶそく /機能不足/
きのうぶんか /機能分化/
きのうぶんさん /機能分散/
きのうぶんせき /機能分析/
きのうべつ /機能別/
きのうほう /帰納法/
きのうほうのかてい /帰納法の仮定/
きのうほうふ /機能豊富/
きのうほかん /機能補完/
きのうまんさい /機能満載/
きのうめん /機能面/
きのうゆにっと /機能ユニット/
きのうようきゅう /機能要求/
きのうよそく /機能予測/
きのうろんり /帰納論理/
きのうろんりがく /帰納論理学/
きのうわせい /機能和声/
きのえ /甲;[十干]1/木江/
きのえいぬ /甲戌/
きのえうま /甲午/
きのえき /木野駅/
きのえさる /甲申/
きのえたつ /甲辰/
きのえとら /甲寅/
きのえね /甲子/
きのかわ /紀の川;地名/紀ノ川/
きのくに /紀伊國/
きのくにや /紀伊国屋/紀伊國屋;「国」旧字 (書店名はこちらが正式)/紀之國屋;?/
きのくにやしょてん /紀伊國屋書店/紀伊国屋書店;※「紀伊國屋書店」が正式/
きのこ /茸/蕈/菌/木の子/
きのこがり /茸狩り/茸狩/
きのこぐも /茸雲;これはあまり見たくない/
きのこじる /茸汁/キノコ汁/きのこ汁/
きのこめし /茸飯/
きのこるい /茸類/きのこ類/
きのさき /城崎/城ノ崎/
きのした /木下/木ノ下/木の下/樹下/
きのしたけいすけ /木下恵介/
きのしたとうきちろう /木下藤吉郎/
きのしたりげん /木下利玄;(1886-1925) 歌人/
きのせい /気の所為/気のせい/
きのつらゆき /紀貫之/
きのと /乙;[十干]2/
きのとい /乙亥/
きのとう /乙卯/
きのとうし /乙丑/
きのととり /乙酉/
きのとひつじ /乙未/
きのとみ /乙巳/
きのとものり /紀友則;ひさかたの 光のどけき 春の日に しづ心なく 花のちるらむ/
きのどく /気の毒/
きのね /木の根/
きのはら /木之原/
きのぼり /木登り/
きのぼりうお /木登魚/
きのみ /木の実/
きのみきのまま /着の身着の儘/着の身着の侭/
きのみや /来宮/
きのめ /木の芽/
きのめあえ /木の芽和え/
きのもと /木ノ本/木之元/
きのり /気乗り/
きのりうす /気乗り薄/
きは /際/
きはい /跪拝/
きはいち /既配置/
きはく /希薄/気迫/稀薄;=希薄/気魄;≒気迫/
きはくか /希薄化/
きはた /木幡/
きはだ /木肌;birk/黄蘗;[植物]ミカン科/黄肌;[魚]キハダマグロ/檗;=黄蘗/蘗;「檗」の異体字/木膚;=木肌/
きはだいろ /黄蘗色/
きはだまぐろ /黄肌鮪/
きはち /喜八/
きはちじょう /黄八丈/
きはちろう /喜八郎/
きはっぴょう /既発表/
きはつ /揮発;volatilise.「アルコールの-」/既発;⇔未発/輝発;?/
きはつせい /揮発性/
きはつせいぶん /揮発成分/
きはつばい /既発売/
きはつゆ /揮発油/揮發油;「発」旧字/
きはつゆぜい /揮発油税/
きはら /木原/樹原/
きはらせん /木原線/
きはらみちこ /木原美智子/
きはん /規範/帰帆/帰阪/軌範;Norm(独)/羈絆/機搬/
きはんいしき /規範意識/
きはんか /規範化/
きはんがく /規範学;⇔経験科学/
きはんけいざいがく /規範経済学/
きはんせい /規範性/
きはんせん /機帆船/
きはんてき /規範的/
きはんぶんぽう /規範文法;[言語]prescriptive grammar.⇔記述文法/
きはんほうそく /規範法則/
きはんりょく /既判力/
きはんりろん /規範理論/
きば /牙/騎馬/木場/
きばい /木灰/
きばえき /木場駅/
きばく /起爆/
きばくざい /起爆剤/
きばくしょく /起爆色/
きばくそうち /起爆装置/
きばくてん /起爆点/
きばくやく /起爆薬/
きばこ /木箱/
きばしら /木柱/
きばせん /騎馬戦/
きばたい /騎馬隊/
きばたらき /気働き/気ばたらき/
きばち /木鉢/
きばつ /奇抜/
きばほうめん /木場方面/
きばみんぞく /騎馬民族/
きばや /気早/
きばらい /既払い/
きばらし /気晴らし/気晴し/
きばん /基盤;†base.「社会-」/基板;†board.「PCの-」/機番/
きばんがい /基板外/
きばんこうかん /基盤交換/
きばんごう /記番号;(concat "http:\057\057www.boj.or.jp\057announcements\057education\057oshiete\057money\057c14.htm\057")/
きばんし /生半紙/
きばんじょう /基板上/基盤上/
きばんせいび /基盤整備/
きばんてきぎじゅつ /基盤的技術/
きばんめい /基板名/
きばんや /基板屋/基盤屋/
きばんよう /基盤用/
きひ /忌避/基肥/貴妃/
きひざい /忌避剤/
きひつ /起筆/
きひょう /起票/
きひろ /帰広/
きひん /気品/貴賓/気稟;生まれつきの気質/
きひんしつ /貴賓室/
きひんせき /貴賓席/
きび /機微/黍/稷;=黍/吉備;山陽地方/驥尾;-に付す/綺靡;あでやか/
きびき /忌引/忌引き/
きびす /踵/
きびたき /黄鶲/
きびだんご /黍団子/吉備団子/
きびつじんじゃ /吉備津神社/
きびなご /黍魚子/
きびのまきび /吉備真備/
きびもち /黍餅/
きびゅうほう /帰謬法/
きびょう /奇病/
きびょうし /黄表紙/
きびん /機敏/
きびんせい /機敏性/
きふ /寄付/寄附/棋譜/貴腐;-ワイン/基布/
きふう /気風/棋風/
きふきん /寄付金/寄附金/
きふく /起伏/帰服/
きふこうい /寄付行為/
きふじん /貴婦人/貴夫人/
きふだ /木札/
きふね /貴船/
きふねぐち /貴船口/
きふほう /記譜法;(music) notation/
きぶ /基部/
きぶかわ /貴生川/
きぶく /忌服/
きぶくれ /着膨れ/着脹れ/
きぶさい /気塞い/
きぶし /木歩士/
きぶしねんど /木節粘土/
きぶっせい /気ぶっせい/
きぶつ /器物/木仏/奇物/
きぶつそんかい /器物損壊/
きぶつそんかいざい /器物損壊罪/
きぶつはそん /器物破損/
きぶとり /着太り/
きぶね /貴船/
きぶねじんじゃ /貴船神社/
きぶもん /貴部門/
きぶん /気分/紀文/奇聞/
きぶんいっしん /気分一新/
きぶんしだい /気分次第/
きぶんそうかい /気分爽快/
きぶんてき /気分的/
きぶんてんかん /気分転換/
きぶんや /気分屋/
きぶんよし /気分良/
きへい /騎兵/奇兵/機兵/喜平/
きへいたい /騎兵隊;cavalry/奇兵隊;[日本史]/
きへき /奇癖/
きへん /木偏;「桜」の偏/机辺/
きべら /木箆/木ベラ/木べら/
きべん /詭弁/
きほう /貴方/気泡/既報/記法/季報/木方/紀宝/気胞/機鋒/危峰/
きほうさま /貴方様/
きほうざい /起泡剤/
きほく /輝北/
きほん /基本/
きほんおん /基本音;fundamental tone/
きほんかい /基本解/
きほんかいろ /基本回路/
きほんかかく /基本価格/
きほんかんすう /基本関数/
きほんがいねん /基本概念/
きほんがく /基本額/
きほんがた /基本型/
きほんきのう /基本機能/
きほんきゅう /基本給/
きほんきょうぎ /基本教義/
きほんきょうよう /基本教養/
きほんぎじゅつ /基本技術/
きほんくかく /基本区画/
きほんけい /基本形/
きほんけいかく /基本計画/
きほんけん /基本権/
きほんげんそく /基本原則/
きほんげんり /基本原理/
きほんこうしき /基本公式/
きほんこうせい /基本構成/
きほんこうぞう /基本構造/
きほんこうもく /基本項目/
きほんこころえ /基本心得/
きほんご /基本語/
きほんごい /基本語彙;[言語]fundamental vocabulary/
きほんごうい /基本合意/
きほんさーびす /基本サービス/
きほんさんぽう /基本算法/
きほんざいさん /基本財産/
きほんしき /基本式/
きほんしせい /基本姿勢/
きほんしそう /基本思想/
きほんしゅうき /基本周期/
きほんしゅうはすう /基本周波数/
きほんしょく /基本色/
きほんしよう /基本仕様/
きほんしんどう /基本振動;[物理]fundamental vibration/
きほんじこう /基本事項/
きほんじょうほう /基本情報/
きほんすんぽう /基本寸法/
きほんず /基本図/
きほんせいしつ /基本性質/
きほんせいしん /基本精神/
きほんせいのう /基本性能/
きほんせっけい /基本設計/
きほんせってい /基本設定/
きほんせん /基本線/
きほんせんぽう /基本戦法/
きほんせんりゃく /基本戦略/
きほんそうさ /基本操作/
きほんそしきけい /基本組織系/
きほんそふと /基本ソフト;[情報]operating system/
きほんたんい /基本単位/
きほんたんご /基本単語/
きほんち /基本値/
きほんちしき /基本知識/
きほんちゅう /基本中/
きほんていすう /基本定数/
きほんていり /基本定理/
きほんてき /基本的/
きほんてきぎもん /基本的疑問/
きほんてきけんり /基本的権利/
きほんてきしせい /基本的姿勢/
きほんてきじょうけん /基本的条件/
きほんてきじんけん /基本的人権/
きほんてきちしき /基本的知識/
きほんてきもんだい /基本的問題/
きほんてきわくぐみ /基本的枠組/
きほんてん /基本点/
きほんてんすう /基本点数/
きほんとくせい /基本特性/
きほんとっきょ /基本特許/
きほんどうさ /基本動作/
きほんにんしき /基本認識/
きほんは /基本波/
きほんば /基本場/
きほんぶ /基本部/
きほんぶぶん /基本部分/
きほんぶんけい /基本文型/
きほんへんかん /基本変換/
きほんへんせい /基本編成/
きほんほう /基本法/
きほんほうしん /基本方針/
きほんほうそく /基本法則/
きほんぼいん /基本母音/
きほんもんだい /基本問題/
きほんようご /基本用語/
きほんようごしゅう /基本用語集/
きほんようそ /基本要素/
きほんよそう /基本予想/
きほんりねん /基本理念/
きほんりゅうし /基本粒子/
きほんりょう /基本料/
きほんりょういき /基本領域/
きほんりょうきん /基本料金/
きほんりょうきんぶん /基本料金分/
きほんわざ /基本技/
きぼ /規模/鬼簿/
きぼう /希望/欺罔/既望;陰暦16日/企望/
きぼうか /希望価/
きぼうかかく /希望価格/
きぼうがおか /希望ヶ丘/
きぼうきんがく /希望金額/
きぼうこうりかかく /希望小売価格/
きぼうこすう /希望個数/
きぼうさっすう /希望冊数/
きぼうしゃ /希望者/
きぼうしゃぜんいん /希望者全員/
きぼうしゃたすう /希望者多数/
きぼうしゃぼしゅう /希望者募集/
きぼうじゅん /希望順/
きぼうたいしょく /希望退職/
きぼうたすう /希望多数/
きぼうちょうさ /希望調査/
きぼうてき /希望的/
きぼうてきかんそく /希望的観測/
きぼうてきよそう /希望的予想/
きぼうとしょ /希望図書/
きぼうにちじ /希望日時/
きぼうにんずう /希望人数/
きぼうねだん /希望値段/
きぼうばいか /希望売価/
きぼうび /希望日/
きぼうほう /喜望峰/
きぼうまいすう /希望枚数/
きぼかくだい /規模拡大/
きぼく /亀卜/
きぼし /木星/
きぼしゅくしょう /規模縮小/
きぼつ /鬼没/
きぼね /気骨/
きぼり /木彫り/
きまえ /気前/
きまかせ /気任せ/
きまぐれ /気紛れ/気まぐれ/
きまじめ /生真面目/
きまた /木俣/
きまち /木町/
きまちどおり /木町通/
きまつ /期末/
きまつこうさ /期末考査/
きまつざんだか /期末残高/
きまつしけん /期末試験/
きまつてあて /期末手当;bonus!/
きまつてすと /期末テスト/
きまつはいとう /期末配当/
きまま /気儘/気まま/
きまめ /生豆/黄豆/
きまよい /気迷い/
きまり /決まり/決り/
きまりごと /決まり事/
きまりじ /決まり字;百人一首で、札を特定出来る文字/
きまりて /決まり手;[相撲]「只今の-は」/決り手;[相撲]/極り手;[相撲]<rare>/
きまりもんく /決まり文句/
きみ /君/気味/黄身/公/希美/貴美/喜美/生美/辟/黄み/鬼魅/
きみあき /公明/
きみいがい /君以外/
きみいでら /紀三井寺/
きみえ /君枝/君江/貴美江/希己枝/
きみお /公男/公雄/喜三男/喜三雄;名/
きみか /公佳/
きみがよ /君が代/
きみこ /貴美子/季実子/季美子/公子/君子/喜美子/紀美子/きみ子/
きみしぐれ /黄身時雨;和菓子/
きみしま /君島/君嶋/
きみじか /気短/
きみじしん /君自身/
きみじま /君島/君嶋/
きみず /黄身酢/
きみた /君田/
きみたか /公高/君孝/公尚/
きみたち /君達/
きみち /季道/
きみつ /機密;†secret.「国家-」/気密;†airtight.「-室」/君津/
きみつぐん /君津郡/
きみつしつ /気密室/
きみつじこう /機密事項/
きみつじょうほう /機密情報/
きみつせい /気密性;airtight/機密性;secrecy/
きみつひ /機密費/
きみつぶんしょ /機密文書/
きみとし /公稔/
きみどり /黄緑/木緑;人名?/
きみどりいろ /黄緑色/
きみなお /公尚/
きみのり /公紀/公典/
きみひこ /公彦/仁彦/
きみひと /公人/
きみひろ /公博/公宏/公裕/公広/
きみゃく /気脈/
きみやす /公保/
きみやま /君山/
きみょう /奇妙/帰命/
きみょうきてれつ /奇妙奇天烈/奇妙きてれつ;very strange/
きみょうちょうらい /帰命頂礼/
きみよ /君代/
きみら /君等/
きみわる /気味悪/
きみん /棄民/飢民/
きむ /帰無/金/
きむいるそん /金日成/
きむすめ /生娘/
きむち /沈菜/
きむら /木村/木邑/
きむらしょうのすけ /木村庄之助/
きむらもとお /木村資生/
きむらや /木村屋/
きめ /木目/肌理/決め/
きめい /記名/記銘/貴名/記明/
きめいがっき /気鳴楽器;管楽器など/
きめいしき /記名式/
きめいしきうらがき /記名式裏書/
きめいしゃさい /記名社債/
きめいとうひょう /記名投票/
きめうち /決め打ち/
きめかた /決め方/
きめごと /決め事/
きめぜりふ /決め台詞/
きめたおし /極め倒し/
きめだし /極め出し/
きめだま /決め球/
きめつけ /決め付け/
きめて /決め手/
きめん /鬼面/貴面/
きめんがに /鬼面蟹/
きも /肝;肝臓/胆;胆嚢/
きもあえ /肝和え/
きもいり /肝いり/肝煎/肝煎り/
きもう /起毛/欺罔/
きもうとかく /亀毛兎角/
きもすい /肝吸/
きもだめし /肝試し/
きもち /気持/気持ち/
きもったま /肝っ玉/
きもつき /肝付/
きもと /木本/木元/樹本/
きもの /着物/
きものすがた /着物姿/
きものや /着物屋/
きもべつ /喜茂別/
きもぽん /肝ポン/
きもん /鬼門/奇問/旗門;[SKI]/奇門/気門/
きもんすう /旗門数/
きもんとんこう /奇門遁甲/
きゃ /脚/伽/迦/
きゃく /客/脚/却/卻;「却」の異体字/攫;さら・う/
きゃくあし /客足/
きゃくあしらい /客あしらい/
きゃくあつかい /客扱い/
きゃくい /客位/
きゃくいり /客入り/
きゃくいん /客員/脚韻/
きゃくいんきょうじゅ /客員教授/
きゃくいんけんきゅういん /客員研究員/
きゃくうけ /客受け/
きゃくえん /客演/
きゃくおうたい /客応対/
きゃくかしゃく /客貨車区/
きゃくがわ /客側/
きゃくご /客語/
きゃくさき /客先/脚先/
きゃくさま /客様/
きゃくし /客死/
きゃくしき /脚式/格式/
きゃくしつ /客室/脚質/
きゃくしつがかり /客室係/
きゃくしつがわ /客室側/
きゃくしつじょうむいん /客室乗務員/
きゃくしつない /客室内/
きゃくしゃ /客車/客舎/
きゃくしゃか /客車化/
きゃくしゃれっしゃ /客車列車/
きゃくしょう /客星/
きゃくしょうばい /客商売/
きゃくしょく /脚色/
きゃくじん /客人/客神/
きゃくすじ /客筋/
きゃくせい /客星/
きゃくせき /客席/
きゃくせん /客船/脚線/
きゃくせんび /脚線美/
きゃくぜん /客膳/
きゃくぜんいん /客全員/
きゃくそう /客層/客僧;旅の坊さん/
きゃくたい /客体/
きゃくだたみ /客畳;[茶道]/
きゃくだね /客種/
きゃくちゅう /脚注/客注/脚註/
きゃくでん /客殿/客電;客席の照明/
きゃくとり /客取り/
きゃくど /客土/
きゃくどうし /客同士/
きゃくどめ /客止め/
きゃくひき /客引き/
きゃくぶ /脚部/
きゃくぶふあん /脚部不安/
きゃくぶん /客分/
きゃくほん /脚本/
きゃくほんか /脚本家/
きゃくま /客間/
きゃくゆそう /客輸送/
きゃくよう /客用/
きゃくよせ /客寄せ/客寄/
きゃくよせぱんだ /客寄せパンダ/
きゃくらい /客来/
きゃくりょく /脚力/
きゃしゃ /華奢/花車/
きゃたつ /脚立/
きゃっか /却下/脚下;あしもと/
きゃっかん /客観/
きゃっかんか /客観化/
きゃっかんし /客観視/
きゃっかんしゅぎ /客観主義/
きゃっかんせい /客観性/
きゃっかんてき /客観的/
きゃっかんてききじゅん /客観的基準/
きゃっかんてきじじつ /客観的事実/
きゃっかんてきじょうきょう /客観的状況/
きゃっかんてきたいしょう /客観的対象/
きゃっかんてきたちば /客観的立場/
きゃっかんてきはんだん /客観的判断/
きゃっかんてきひょうか /客観的評価/
きゃっかんてきひょうかほう /客観的評価法/
きゃっかんてきようそ /客観的要素/
きゃっかんひょうか /客観評価/
きゃっかんろん /客観論/
きゃっき /客気/
きゃっこう /脚光/
きゃっしゅふろーけいさんしょ /キャッシュフロー計算書;財務諸表の1つ/
きゃっぷ /∩;cap/
きゃつ /彼奴/
きゃのんはんばい /キヤノン販売/
きゃのんほう /キャノン砲/
きゃはん /脚絆/
きゃべつばたけ /キャベツ畑/
きゃら /伽羅/
きゃらいろ /伽羅色/
きゃらくたーしょうひん /キャラクター商品;character goods/
きゃらめるあじ /キャラメル味/
きゃりあぐみ /キャリア組/
きゃん /侠;お-/
きゃんせるまち /キャンセル待ち/
きゃんせるりょう /キャンセル料/
きゃんぷじょう /キャンプ場/
きゃんぷち /キャンプ地/
きゃんぺーんきかん /キャンペーン期間/
きゃんぺーんちゅう /キャンペーン中/
きや /木屋/紀谷/
きやく /規約/既約;irreducible.「-分数」/既訳;translated.「-の詩」/奇薬/
きやくいはん /規約違反/
きやくけい /既約形/
きやくじゅんきょ /規約準拠/
きやくじょう /規約上/
きやくたこうしき /既約多項式/
きやくぶんすう /既約分数/
きやくへんこう /規約変更/
きやす /喜安/
きやすさ /気安さ/
きやすめ /気休め/
きやせ /着痩せ/
きやま /木山/基山/
きやまち /木屋町/
きやみ /気病み/
きやむ /喜屋武/
きやり /木遣り;-唄/
きやん /喜屋武/
きゅーば /玖瑪/
きゅう /急/旧/灸/級/球/給/休/九/宮/仇;仇敵/究;研究/鳩;はと/久;永久/柩;霊柩車/疚;やま・しい/丘/蚯;蚯蚓(みみず)/糾;糾弾/赳/弓/窮;窮地/穹;蒼穹/躬;躬行/求;要求/救;救助/裘;かわごろも/逑;(つれあい)/及;遡及/吸;吸収/汲;く・む/笈;おい/岌;(たかい)/烋/恷;「烋」の異体字/貅/摎/樛/翕;(あつ・まる)/歙;(す・う)/皀/邱;おか/臼;臼歯/朽;不朽/泣;号泣/嗅;嗅覚/糺;糺弾/鬮;くじ/舊;「旧」の旧字/９/扱;?/
きゅう> /旧/急;急接近,急浮上,急停車/九/
きゅうあい /求愛/
きゅうあいき /旧愛機/
きゅうあいこうどう /求愛行動/
きゅうあく /旧悪/
きゅうあん /久安;年号(1145-1151)/
きゅうい /球威/級位/九位/
きゅういん /吸引/吸飲/
きゅういんしき /吸引式/
きゅういんそうち /吸引装置/
きゅういんてき /吸引的/
きゅういんりょく /吸引力/
きゅうえき /旧駅/
きゅうえきめい /旧駅名/
きゅうえん /救援/休園/休演/球宴;(プロ野球の)オールスター戦/休煙/旧縁/旧怨/求縁/吸煙/
きゅうえんかつどう /救援活動/
きゅうえんき /救援機/
きゅうえんしゅつじょう /球宴出場/
きゅうえんとうしゅ /救援投手/
きゅうえんぶっし /救援物資/
きゅうえんよう /救援用/
きゅうおん /吸音/球音/旧恩/
きゅうおんざい /吸音材/
きゅうおんせい /吸音性/
きゅうおんとくせい /吸音特性/
きゅうおんめん /吸音面/
きゅうおんりつ /吸音率/
きゅうおんりょく /吸音力/
きゅうか /休暇/旧家/球果/急下/毬果/急火/求家/
きゅうかーぶ /急カーブ/
きゅうかい /休会/球界/求解/旧懐/
きゅうかいうら /九回裏/
きゅうかいぐん /旧海軍/
きゅうかいぜんたい /球界全体/
きゅうかいそく /旧快速/
きゅうかいちゅう /休会中/
きゅうかいどう /旧街道/
きゅうかいひ /旧会費/
きゅうかいふっき /球界復帰/
きゅうかく /嗅覚/球殻/吸角;医療具/
きゅうかくだい /急拡大/
きゅうかくど /急角度/
きゅうかこう /急下降/
きゅうかざん /休火山/
きゅうかせいど /休暇制度/
きゅうかそく /急加速/
きゅうかそくじ /急加速時/
きゅうかぞく /旧華族/
きゅうかちゅう /休暇中/
きゅうかつ /久闊;ご無沙汰/裘葛;-を易う(=一年経つ)/
きゅうかな /旧仮名/
きゅうかなづかい /旧仮名遣い/
きゅうかねがい /休暇願/
きゅうかぶ /旧株/
きゅうかむら /休暇村/
きゅうかん /休館/休刊/急患/吸汗/旧館/休閑/旧慣/
きゅうかんごう /休刊号/
きゅうかんじ /旧漢字/
きゅうかんせい /吸汗性/
きゅうかんち /休閑地/
きゅうかんちゅう /休刊中/休館中/
きゅうかんちょう /九官鳥/
きゅうかんび /休館日;図書館の-/休刊日;新聞の-/休肝日;酒を飲まぬ日/
きゅうかんりにん /旧管理人/
きゅうが /休芽/
きゅうがく /休学/
きゅうがくとどけ /休学届/
きゅうがた /旧型/
きゅうがたきゃくしゃ /旧型客車/
きゅうがたこくでん /旧型国電/
きゅうがたしゃ /旧型車/
きゅうがたしゃりょう /旧型車両/
きゅうがたでんしゃ /旧型電車/
きゅうがたひん /旧型品/
きゅうがたよう /旧型用/
きゅうき /吸気;⇔呼気/給気;air charge.「エンジンの-」/旧記/
きゅうきおん /吸気音/
きゅうきかく /旧規格/
きゅうきがわ /吸気側/
きゅうきけい /吸気系/
きゅうきしゅ /旧機種/
きゅうきていこう /吸気抵抗/
きゅうきてき /求基的/
きゅうきゃく /旧客/
きゅうきゅう /救急/汲々/急求;?/
きゅうきゅうい /救急医/
きゅうきゅういりょう /救急医療/
きゅうきゅういりょうたいせい /救急医療体制/
きゅうきゅうきゅうめいし /救急救命士/
きゅうきゅうしてい /救急指定/
きゅうきゅうしていびょういん /救急指定病院/
きゅうきゅうしゃ /救急車/
きゅうきゅうそせいほう /救急蘇生法/
きゅうきゅうたい /救急隊/
きゅうきゅうたいいん /救急隊員/
きゅうきゅうにょりつりょう /急急如律令/
きゅうきゅうはんそう /救急搬送/
きゅうきゅうばこ /救急箱/
きゅうきゅうばんそうこう /救急絆創膏/
きゅうきゅうびょういん /救急病院/
きゅうきょ /急遽/旧居/鳩居/急きょ/
きゅうきょう /旧教/究竟;=くっきょう/窮境;pinch/
きゅうきょうさんけんしょこく /旧共産圏諸国/
きゅうきょうしょくいん /旧教職員/
きゅうきょうようぶ /旧教養部/
きゅうきょく /究極/窮極/
きゅうきょくせん /急曲線/
きゅうきょくちょうじん /究極超人/
きゅうきょくてき /究極的/
きゅうきょくりろん /究極理論/
きゅうきょひつよう /急遽必要/
きゅうきん /球菌/給金/
きゅうぎ /球技/球戯;†(ビリヤードなど)/
きゅうぎじゅつ /旧技術/
きゅうぎじょう /球技場/
きゅうぎゅう /九牛;-の一毛/
きゅうぎゅうのいちもう /九牛の一毛;取るに足りないもの/
きゅうぎょう /休業/
きゅうぎょうちゅう /休業中/
きゅうぎょうほしょう /休業補償/
きゅうくつ /窮屈/
きゅうぐ /弓具/
きゅうぐんき /旧軍機/
きゅうぐんじん /旧軍人/
きゅうけい /休憩/球形/求刑/弓形/球茎/宮刑/急啓/
きゅうけいご /休憩後/
きゅうけいしつ /休憩室/
きゅうけいしゃ /急傾斜/
きゅうけいしゃち /急傾斜地/
きゅうけいじ /休憩時/
きゅうけいじかん /休憩時間/
きゅうけいじょ /休憩所/
きゅうけいちゅう /休憩中/
きゅうけいばしょ /休憩場所/
きゅうけいりょう /休憩料/
きゅうけつ /吸血/給血/宮闕/灸穴/
きゅうけつき /吸血鬼/
きゅうけつこんちゅう /吸血昆虫/
きゅうけつせいぶつ /吸血生物/
きゅうけんぽう /旧憲法/
きゅうけんぽうか /旧憲法下/
きゅうげき /急激/旧劇/急劇;=急激/
きゅうげん /急減/給源/
きゅうげんあん /旧原案/
きゅうげんそく /急減速/
きゅうこ /舅姑/旧故/
きゅうこう /急行/休講/休校/吸光/旧交/休耕/休航/救荒/旧稿/躬行/九江;中国の都市/
きゅうこううんてん /急行運転/
きゅうこうか /急降下/
きゅうこうかばくげき /急降下爆撃/
きゅうこうがた /急行型/
きゅうこうくかん /急行区間/
きゅうこうぐん /急行軍/
きゅうこうけい /急行系/
きゅうこうけん /急行券/
きゅうこうさくもつ /救荒作物/
きゅうこうざ /旧講座/
きゅうこうしゃりょう /急行車両/
きゅうこうしゅうかいどう /旧甲州街道/
きゅうこうしょく /急行色/
きゅうこうせん /急行線/
きゅうこうそう /旧構想/
きゅうこうだい /九工大/久工大/九州工業大学;※abbrev/
きゅうこうだいじょうほうこう /九工大情報工/
きゅうこうち /休耕地/
きゅうこうちゅう /休耕中/
きゅうこうつがる /急行津軽/
きゅうこうていしゃえき /急行停車駅/
きゅうこうでん /休耕田/
きゅうこうでんしゃ /急行電車/
きゅうこうとうかい /急行東海/
きゅうこうど /吸光度/
きゅうこうばい /急勾配/
きゅうこうび /休稿日/
きゅうこうびん /急行便/
きゅうこうよう /急行用/
きゅうこうようしゃりょう /急行用車両/
きゅうこうりつ /休講率/
きゅうこうりょうきん /急行料金/
きゅうこうれっしゃ /急行列車/
きゅうこく /救国/急告/
きゅうこくてつ /旧国鉄/
きゅうこくどう /旧国道/
きゅうこくめい /旧国名/
きゅうこん /球根/求婚/窮困/
きゅうこんしゃ /求婚者/
きゅうご /救護/
きゅうごう /糾合/鳩合;≒糾合/
きゅうごく /旧国/
きゅうごしせつ /救護施設;<生活保護法38/
きゅうごしょ /救護所/
きゅうごしらえ /急拵え/
きゅうごだいし /旧五代史;二十四史/
きゅうごはん /救護班/
きゅうさい /救済/休載/旧債/
きゅうさいかん /救済観/
きゅうさいがっぺい /救済合併/
きゅうさいきかん /救済機関/
きゅうさいさく /救済策/
きゅうさいしゃ /救済者/
きゅうさいせいど /救済制度/
きゅうさいそち /救済措置/
きゅうさいちゅう /休載中/
きゅうさいぶん /休載分/
きゅうさいぼう /嗅細胞;[生物]olfactory cell/
きゅうさか /急坂/
きゅうさく /旧作/久作/窮策/
きゅうさつ /旧札/
きゅうさんだい /九産大/
きゅうさんわ /旧三和/
きゅうざか /急坂/
きゅうざひょう /球座標/
きゅうざぶろう /究三郎/
きゅうし /休止/急死/給紙/臼歯/球史;野球の歴史/九紫;[陰陽道]/九死;-に一生を得る/灸師/急使/旧師/宮址/旧址/窮死/旧史;⇔新史/急駛/弓矢/仇視/旧詩/急施/
きゅうしあげ /急仕上げ/
きゅうしかく /休止核/
きゅうしがい /旧市街/
きゅうしき /旧式/旧識/
きゅうしきかん /休止期間/
きゅうしじょうたい /休止状態/
きゅうしせん /休止線/
きゅうしそう /休止相/
きゅうしち /久七/
きゅうしちゅう /休止中/
きゅうしつ /吸湿/宮室/
きゅうしつざい /吸湿剤/
きゅうしつせい /吸湿性/
きゅうしない /旧市内/
きゅうしひん /休止品/
きゅうしふ /休止符/
きゅうしほうほう /給紙方法/
きゅうしゃ /厩舎/旧車/急斜/鳩舎/廐舎/柩車/
きゅうしゃめい /旧社名/
きゅうしゃめん /急斜面/
きゅうしゅ /旧主/鳩首/級酒/九首/
きゅうしゅう /九州/吸収/急襲/旧習/
きゅうしゅうあさひほうそう /九州朝日放送/
きゅうしゅうおうだん /九州横断/
きゅうしゅうかくち /九州各地/
きゅうしゅうかのう /吸収可能/
きゅうしゅうかん /九州間/
きゅうしゅうがっぺい /吸収合併/
きゅうしゅうきた /九州北/
きゅうしゅうけいすう /吸収係数/
きゅうしゅうげいこうだい /九州芸工大/
きゅうしゅうげいじゅつこうかだいがく /九州芸術工科大学/
きゅうしゅうこう /九州工/
きゅうしゅうこうぎょうだい /九州工業大/
きゅうしゅうこうぎょうだいがく /九州工業大学/
きゅうしゅうこうぞう /吸収構造/
きゅうしゅうこうだい /九州工大/
きゅうしゅうさん /九州産/
きゅうしゅうさんぎょうだいがく /九州産業大学/
きゅうしゅうさんち /九州山地/
きゅうしゅうさんば /九州産馬/
きゅうしゅうざい /吸収剤/
きゅうしゅうしぶ /九州支部/
きゅうしゅうしゅっしんしゃ /九州出身者/
きゅうしゅうしんかんせん /九州新幹線/
きゅうしゅうじゅうかんどう /九州縦貫道/
きゅうしゅうじん /九州人/
きゅうしゅうせい /吸収性/
きゅうしゅうせん /吸収線/
きゅうしゅうせんりょう /吸収線量/
きゅうしゅうぜんいき /九州全域/
きゅうしゅうぜんど /九州全土/
きゅうしゅうそうち /吸収装置/
きゅうしゅうそしき /吸収組織/
きゅうしゅうたい /吸収帯/
きゅうしゅうだい /九州大/
きゅうしゅうだいがく /九州大学/
きゅうしゅうだいひょう /九州代表/
きゅうしゅうだんじ /九州男児/
きゅうしゅうちく /九州地区/
きゅうしゅうちほう /九州地方/
きゅうしゅうちゅう /吸収中/
きゅうしゅうちゅうぶ /九州中部/
きゅうしゅうでんりょく /九州電力;[企業名]/
きゅうしゅうとっきゅう /九州特急/
きゅうしゅうない /九州内/
きゅうしゅうなんぶちほう /九州南部地方/
きゅうしゅうにゅうぎょう /九州乳業/
きゅうしゅうねつ /吸収熱/
きゅうしゅうばしょ /九州場所/
きゅうしゅうばん /九州版/
きゅうしゅうぶんかつ /吸収分割/
きゅうしゅうべん /九州弁/
きゅうしゅうほうほう /吸収方法/
きゅうしゅうほうめん /九州方面/
きゅうしゅうほくぶ /九州北部/
きゅうしゅうまつした /九州松下/
きゅうしゅうまつしたでんき /九州松下電器;[企業名]/
きゅうしゅうもう /吸収毛/
きゅうしゅうやまぐち /九州山口/
きゅうしゅうよう /吸収用/
きゅうしゅうりつ /吸収率/
きゅうしゅうりょく /吸収力/
きゅうしゅうりょこう /九州旅行/
きゅうしゅつ /救出/休出/
きゅうしゅつさくせん /救出作戦/
きゅうしゅん /急峻/球春;野球の始まる春/
きゅうしょ /急所/究所/
きゅうしょう /旧称/求償/急症/
きゅうしょうがつ /旧正月/
きゅうしょうけん /求償権/
きゅうしょく /給食/求職;apply/休職;leave/
きゅうしょくいん /旧職員/
きゅうしょくかつどう /求職活動/
きゅうしょくしつ /給食室/
きゅうしょくしゃ /求職者/
きゅうしょくせんたー /給食センター/
きゅうしょくちゅう /求職中/
きゅうしょくとうばん /給食当番/
きゅうしょくひ /給食費/
きゅうしょくみんち /旧植民地/
きゅうしょくや /給食屋/
きゅうしろう /久四郎/
きゅうしん /休診/急伸;「株価が-する」/急進;「-派」/球審/求心/丘疹/旧臣/急診/球心/急信/
きゅうしんかじょ /求心花序/
きゅうしんけい /嗅神経;[解剖]olfactory nerve/
きゅうしんしゅぎ /急進主義;radicalism/
きゅうしんじん /旧新人/
きゅうしんせい /求心性/
きゅうしんせいしんけい /求心性神経/
きゅうしんてき /急進的/求心的/
きゅうしんは /急進派/
きゅうしんび /休診日/
きゅうしんりょく /求心力/
きゅうじ /給餌/給仕/球児/旧字/九字/旧時/旧辞/灸治/救治/
きゅうじたい /旧字体/
きゅうじだい /旧時代/
きゅうじつ /休日/
きゅうじつうんきゅう /休日運休/
きゅうじつしゅっきん /休日出勤/
きゅうじつしんりょう /休日診療/
きゅうじつとうばんい /休日当番医/
きゅうじつへんじょう /休日返上/
きゅうじつまえ /休日前/
きゅうじゅ /久寿;年号(1154-1156)/
きゅうじゅう /九十/
きゅうじゅうしょ /旧住所/
きゅうじゅつ /弓術/救恤/
きゅうじょ /救助/宮女/
きゅうじょう /球場/休場/球状/窮状/宮城/弓場/球上/弓状/宮場/九条/
きゅうじょうがわ /球場側/
きゅうじょうしょう /急上昇/
きゅうじょうしょうちゅう /急上昇中/
きゅうじょうしようりょう /球場使用料/
きゅうじょうじゅう /球場中/
きゅうじょうない /球場内/
きゅうじょうひ /嗅上皮;olfactory epithelium/
きゅうじょうほう /旧情報/
きゅうじょうまえ /球場前/
きゅうじょかつどう /救助活動/
きゅうじょしゃ /救助者/
きゅうじょたい /救助隊/
きゅうじょたいいん /救助隊員/
きゅうじょほう /救助法/
きゅうじょよう /救助用/
きゅうじょようせい /救助要請/
きゅうじょりょう /救助料/
きゅうじん /求人/旧人/吸塵/窮盡/
きゅうじんかつどう /求人活動/
きゅうじんこうこく /求人広告/
きゅうじんじょうほう /求人情報/
きゅうじんじょうほうし /求人情報誌/
きゅうじんばいりつ /求人倍率/
きゅうじんひょう /求人票/
きゅうじんぼしゅう /求人募集/
きゅうじんるい /旧人類/
きゅうす /急須/
きゅうすい /給水/吸水/汲水;みずくみ/
きゅうすいがかり /給水係/
きゅうすいしせつ /給水施設/
きゅうすいしゃ /給水車/
きゅうすいじょ /給水所/
きゅうすいせい /吸水性/
きゅうすいせいげん /給水制限/
きゅうすいせつび /給水設備/
きゅうすいとう /給水塔/
きゅうすいりょう /給水量/
きゅうすう /級数/
きゅうすうてんかい /級数展開/
きゅうすうわ /級数和/
きゅうず /旧図/
きゅうせい /急性/旧姓/急逝/旧制/九星/救世/球聖/
きゅうせいかいはくずいえん /急性灰白髄炎;[医]/
きゅうせいかんえん /急性肝炎/
きゅうせいき /急性期/九世紀/
きゅうせいきょう /救世教/
きゅうせいぐん /救世軍/
きゅうせいけん /旧政権/
きゅうせいこうこうせい /旧制高校生/
きゅうせいしゅ /救世主/
きゅうせいじゅつ /九星術/
きゅうせいちゅうがく /旧制中学/
きゅうせいちゅうどく /急性中毒;⇔慢性中毒/
きゅうせいちょう /急成長/
きゅうせいど /旧制度/
きゅうせいどう /急制動/
きゅうせいどくせい /急性毒性/
きゅうせいひん /旧製品/
きゅうせいびょう /急性病/
きゅうせいふ /旧政府/
きゅうせいりょく /旧勢力/
きゅうせかい /旧世界/
きゅうせき /旧跡/求積/休戚;喜びと悲しみ/
きゅうせだい /旧世代/
きゅうせっき /旧石器/
きゅうせっきじだい /旧石器時代/
きゅうせっきん /急接近/
きゅうせってい /旧設定/
きゅうせつ /旧説/急設/
きゅうせん /休戦/急戦/旧線/弓箭/求仙/
きゅうせんかい /急旋回/
きゅうせんきょうてい /休戦協定/
きゅうせんどう /球泉洞/
きゅうせんぽう /急先鋒/
きゅうぜん /翕然/
きゅうぜんじつ /休前日/
きゅうそ /窮鼠/泣訴/
きゅうそう /急送/給送/穹蒼/九索/
きゅうそうがっき /弓奏楽器/
きゅうそうしゅこく /旧宗主国/
きゅうそく /急速/休息/球速/吸息/
きゅうそくじゅうでん /急速充電/
きゅうそくじょ /休息所/
きゅうそだい /窮措大/
きゅうそれん /旧ソ連/
きゅうぞう /急増/旧蔵/急造/吸蔵;[化学]occlusion/久蔵;人名/九蔵/
きゅうぞうちゅう /急増中/
きゅうたい /球体/旧態/裘代/
きゅうたいいぜん /旧態依然/
きゅうたいけい /球体系/
きゅうたいせい /旧体制/
きゅうたいぜん /旧態然/
きゅうたいりく /旧大陸/
きゅうたく /旧宅/
きゅうたま /九玉/
きゅうたろう /久太郎/
きゅうたん /急湍/
きゅうだい /及第/旧題/九大/久大/九州大学;※abbrev/
きゅうだいがわ /九大側/
きゅうだいせん /久大線/
きゅうだいてん /及第点/
きゅうだいにっぽんていこく /旧大日本帝国/
きゅうだいほんせん /久大本線/
きゅうだいまえ /九大前/
きゅうだん /球団/糾弾/糺弾;=糾弾/糾彈;旧字/糺彈;旧字/給弾;feed/
きゅうだんか /球団歌/
きゅうだんかくちょう /球団拡張/
きゅうだんかんけいしゃ /球団関係者/
きゅうだんがわ /球団側/
きゅうだんき /球団旗/
きゅうだんこうほう /球団広報/
きゅうだんしん /球団新/
きゅうだんしんきろく /球団新記録/
きゅうだんじむしょ /球団事務所/
きゅうだんべつ /球団別/
きゅうだんめい /球団名/
きゅうち /窮地/旧知/旧地/九地;⇔九天/
きゅうちしん /求知心/
きゅうちゃき /給茶器/
きゅうちゃく /吸着/
きゅうちゃくおん /吸着音/
きゅうちゃくざい /吸着剤/
きゅうちゃくりょく /吸着力/
きゅうちゅう /宮中/吸虫;[生物]fluke/
きゅうちゅうぎ /九柱戯;Kegel(独)/
きゅうちゅうぼうじゅうだいじけん /宮中某重大事件/
きゅうちゅうりょうり /宮中料理/
きゅうちゅうるい /吸虫類;[生物]fluke/
きゅうちょ /旧著/
きゅうちょう /級長/急潮/窮鳥/急調/
きゅうちょうし /急調子/
きゅうちょうそん /旧町村/
きゅうちょうてき /求頂的/
きゅうつい /急追/
きゅうつう /窮通/
きゅうつうしん /旧通信/
きゅうてい /宮廷/休廷/
きゅうていがか /宮廷画家/
きゅうていこくかいぐん /旧帝国海軍/
きゅうていこくだいがく /旧帝国大学/
きゅうていご /宮廷語/
きゅうていし /急停止/
きゅうていしゃ /急停車/
きゅうていたいりょ /九鼎大呂/
きゅうていひ /宮廷費/
きゅうていりょうり /宮廷料理/
きゅうてき /仇敵/旧敵/
きゅうてん /急転/九天/灸点/急轉/
きゅうてんかい /急展開/
きゅうてんちょっか /急転直下/
きゅうてんぽ /急テンポ;quick tempo/
きゅうでん /宮殿/給電/九電;[略語][企業名]九州電力/給田/休電/
きゅうと /旧都/
きゅうとう /給湯/急騰/旧冬/旧套/
きゅうとうおう /旧東欧/
きゅうとうかいどう /旧東海道/
きゅうとうかん /給湯管/
きゅうとうき /給湯器/
きゅうとうしつ /給湯室/
きゅうとうじょ /旧唐書;二十四史 (くとうじょ)/
きゅうとうどく /旧東独/
きゅうとそう /旧塗装/
きゅうとちょう /旧都庁/
きゅうどう /弓道/旧道/求道/球道/
きゅうどうかく /九同角/
きゅうどうしゃ /求道者/
きゅうどうしん /求道心/
きゅうどうじょう /弓道場/
きゅうどうてき /求道的/
きゅうどうぶ /弓道部/
きゅうない /球内/
きゅうなん /救難/急難/
きゅうにし /旧西/
きゅうにほんかいぐん /旧日本海軍/
きゅうにほんぐん /旧日本軍/
きゅうにほんぐんじん /旧日本軍人/
きゅうにゅう /吸入/
きゅうにゅうき /吸入器/
きゅうにゅうはいき /吸入排気/
きゅうにゅうりょう /吸入量/
きゅうねつ /吸熱/急熱/
きゅうねつはんのう /吸熱反応;[化学]endothermic reaction/
きゅうねん /旧年/九年/
きゅうねんちゅう /旧年中/
きゅうは /旧派/急派/
きゅうはい /朽廃/九拝/
きゅうはいき /給排気/
きゅうはいきけい /吸排気系/給排気系/
きゅうはいすいせつび /給排水設備/
きゅうはく /窮迫;hardship/急迫;urgency/休泊;休息・宿泊/休拍;[音楽]/
きゅうはちこう /旧八高/
きゅうはっしん /急発進/
きゅうはん /旧版/急坂/旧藩/
きゅうはんどる /急ハンドル/
きゅうはんぼん /求版本/
きゅうば /急場/九馬/
きゅうばい /急売/
きゅうばく /旧幕/
きゅうばつ /救抜/
きゅうばん /吸盤/旧版;きゅうはん/旧盤/
きゅうばんしき /吸盤式/
きゅうひ /給費/厩肥/
きゅうひがしがわしょこく /旧東側諸国/
きゅうひき /九匹/
きゅうひしつ /旧皮質/
きゅうひせい /給費生/
きゅうひつ /休筆/
きゅうひつちゅう /休筆中/
きゅうひん /救貧/
きゅうひんいん /救貧院/
きゅうび /鳩尾/九尾/
きゅうびのねこ /九尾の猫/
きゅうびょう /急病/
きゅうびょうにん /急病人/
きゅうびん /急便/
きゅうぴっち /急ピッチ/
きゅうふ /給付/休符/旧譜/宮阜/
きゅうふう /旧風/
きゅうふがく /給付額/
きゅうふきん /給付金/
きゅうふじょう /急浮上/
きゅうふすいじゅん /給付水準/
きゅうぶれーき /急ブレーキ/
きゅうぶん /旧聞/給分/
きゅうへい /旧弊/弓兵/
きゅうへん /急変/
きゅうべえ /久兵衛/
きゅうべつ /級別/
きゅうほう /旧法/急報/臼砲/
きゅうほうしき /旧方式/
きゅうほうじ /久宝寺/
きゅうぼ /急募/
きゅうぼう /窮乏/
きゅうぼくふんしょう /朽木糞牆/
きゅうぼん /旧盆/
きゅうま /久馬/
きゅうまんしゅう /旧満州/
きゅうみん /休眠/窮民/救民/
きゅうみんが /休眠芽/
きゅうみんちゅう /休眠中/
きゅうみんぽう /旧民法/
きゅうむ /急務/
きゅうむいん /厩務員/
きゅうめい /救命/究明/旧名/糾明/糺明/求明/及明/窮命/
きゅうめいきゅうきゅうし /救命救急士/
きゅうめいぐ /救命具/
きゅうめいし /救命士/
きゅうめいしょう /旧名称/
きゅうめいちゅう /究明中/
きゅうめいてい /救命艇/
きゅうめいどうい /救命胴衣/
きゅうめいぶい /救命ブイ;life buoy/
きゅうめいぼーと /救命ボート/
きゅうめいりつ /救命率/
きゅうめかません /旧目蒲線/
きゅうめん /球面/
きゅうめんしゅうさ /球面収差/
きゅうめんじょう /球面上/球面状/
きゅうめんは /球面波/
きゅうもん /宮門/糺問/
きゅうや /久弥/
きゅうやく /旧約;†Old Testament.「-聖書」/旧訳;†old translation/
きゅうやくせいしょ /旧約聖書/
きゅうやくせいしょがく /旧約聖書学/
きゅうゆ /給油/
きゅうゆう /旧友;old friend/級友;classmate/
きゅうゆぐち /給油口/
きゅうゆしゃ /給油車/
きゅうゆしょ /給油所/
きゅうゆじ /給油時/
きゅうゆじょ /給油所/
きゅうゆちゅう /給油中/
きゅうよ /給与/窮余/窮餘;「余」旧字/
きゅうよう /休養/急用/球陽/給養/休用;?/
きゅうようあけ /休養明/
きゅうようきかん /休養期間/
きゅうようせんげん /休養宣言/
きゅうようち /休養地/
きゅうようちゅう /休養中/
きゅうようび /休養日/
きゅうようまえ /休養前/
きゅうよか /給与課/
きゅうよけいさん /給与計算/
きゅうよさべつ /給与差別/
きゅうよしょとく /給与所得/
きゅうよしょとくこうじょ /給与所得控除/
きゅうよしょとくしゃ /給与所得者/
きゅうよすいじゅん /給与水準/
きゅうよたいけい /給与体系/
きゅうよふりこみ /給与振込/
きゅうらい /旧来/救癩/
きゅうらいがた /旧来型/
きゅうらぎ /厳木/
きゅうらく /急落/及落;及第と落第/
きゅうり /胡瓜/究理/窮理/
きゅうりうお /胡瓜魚/
きゅうりがく /窮理学/
きゅうりゅう /急流/穹窿;dome/九龍;(jiu long) 地名,香港/九竜;=九龍/九流/
きゅうりょう /給料/丘陵/旧領/休漁/
きゅうりょうち /丘陵地/
きゅうりょうてあて /給料手当/
きゅうりょうどろぼう /給料泥棒/
きゅうりょうび /給料日/
きゅうりょうびまえ /給料日前/
きゅうりょうまえ /給料前/
きゅうりょうめいさいしょ /給料明細書/
きゅうれい /急冷/
きゅうれき /旧暦/
きゅうろう /旧臘/
きゅうろせん /旧路線/
きゅうろばん /九路盤/
きゅうわ /九羽/
きゅうわり /九割/
きゅうわりいじょう /九割以上/
きゅりうむ /Cm/Curium/
きゆう /杞憂/既有/嬉遊/喜憂/
きょ /虚/巨/居/挙/去/許/拠;拠点/據;「拠」の旧字/遽;急遽/醵;醵出/拒;拒否/渠;暗渠/距;距離/炬;炬火/秬;くろきび/苣;萵苣(ちしゃ)/鉅/鋸;のこぎり/倨;倨傲/踞;蹲踞/墟;廃墟/嘘;うそ/歔;歔欷/筥;はこ/擧;「挙」の旧字1/舉;「挙」の旧字2/
きょ> /虚;(⇔実) 虚解,虚空間,虚時間/
きょあく /巨悪/
きょい /虚位/
きょう /今日/京/強/狂/経/教/興/凶/境/橋/協/卿/郷;故郷/共/供;提供/拱;(こまね・く)拱門/兄;兄弟/況;状況/况;「況」の異体字/劫;(漢音) 永劫/刧;「劫」の異体字/竟;畢竟/鏡;三面鏡/亨;とおる/享;享受/恐;恐怖/跫;跫音/鞏;鞏固/脅;脅迫/恊;「協」の異体字/競;競争/竸;「競」の異体字/兢;(びくびくする)戦々兢々/匡;(ただ・す)匡正/筐;筐体/筺;「筐」の異体字/兇;兇悪/胸;胸部/匈;匈奴/恟/洶/響;音響/饗;饗宴/嚮;嚮導/僑;華僑/喬;喬木/矯;矯正/蕎;蕎麦(そば)/嬌;愛嬌/轎;こし/驕;驕慢/夾;夾雑物/侠;任侠/峡;峡谷/峽;「峡」の旧字(人名用漢字)/挟;挟撃/挾;「挟」の旧字/狭;狭隘/狹;「狭」の旧字(人名用漢字)/筴;めどぎ/篋;はこ/莢;(さや)薬莢/陜/羌/姜;生姜/香;香車/馨;かおり/杏;(あんず)杏仁/叶;かな・う/叫;絶叫/怯;卑怯/恭;恭順/驚;驚愕/梗;桔梗/矜;矜持/荊;いばら/廾/徼/抂/梟;ふくろう/竅;あな/經;「経」の旧字/誑;たぶら・かす/亰;「京」の異体字/鍄/皀/頃;ころ/繦;すき/襁;襁褓/彊;つよい/僵;たおれる/疆;新疆/炯;(呉音) 炯眼/烱;「炯」の異体字/棘;?/
きょう> /強;強酸性,強アルカリ性,強磁性体/京;京料理,京野菜,京街道/共/
きょうあい /狭隘/
きょうあく /凶悪/兇悪/強悪;とても悪い/梟悪/
きょうあくはん /凶悪犯/
きょうあくはんざい /凶悪犯罪/
きょうあす /今日明日/
きょうあすじゅう /今日明日中/
きょうあつ /強圧/
きょうあん /教案/
きょうい /脅威;†menace.「敵の-」/驚異;†wonder.「-の成果」/胸囲/強意/教委;[略語]教育委員会/
きょういく /教育/
きょういくいいんかい /教育委員会/
きょういくいいんかいがわ /教育委員会側/
きょういくいいんちょう /教育委員長/
きょういくいっぱん /教育一般/
きょういくか /教育課/
きょういくかい /教育界/
きょういくかいかく /教育改革/
きょういくかつどう /教育活動/
きょういくかてい /教育課程;curriculum/教育過程;†educational process/
きょういくかんきょう /教育環境/
きょういくかんけい /教育関係/
きょういくかんじ /教育漢字/
きょういくがかり /教育係/
きょういくがく /教育学/
きょういくがくかんけい /教育学関係/
きょういくがくけんきゅうか /教育学研究科/
きょういくがくせんもん /教育学専門/
きょういくがくぶ /教育学部/
きょういくがんぐ /教育玩具/
きょういくきかん /教育機関/
きょういくきき /教育機器/
きょういくきほんほう /教育基本法/
きょういくぎじゅつ /教育技術/
きょういくぎじゅつてき /教育技術的/
きょういくぎほう /教育技法/
きょういくぎむ /教育義務/
きょういくぎょうせい /教育行政/
きょういくくんれん /教育訓練/
きょういくくんれんきゅうふせいど /教育訓練給付制度/
きょういくけい /教育系/
きょういくけいたい /教育形態/
きょういくけん /教育権/教育県/
きょういくけんきゅう /教育研究/
きょういくけんきゅうきかん /教育研究機関/
きょういくけんきゅうじょせい /教育研究助成/
きょういくげんご /教育言語/
きょういくげんば /教育現場/
きょういくこうか /教育効果/
きょういくこうがく /教育工学/
きょういくこうがくかいはつ /教育工学開発/
きょういくこうむいんとくれいほう /教育公務員特例法/
きょういくし /教育史/教育誌/
きょういくしえん /教育支援/
きょういくしえんかんきょう /教育支援環境/
きょういくしきん /教育資金/
きょういくしじょう /教育市場/
きょういくしせつ /教育施設/
きょういくしどうようりょう /教育指導要領/
きょういくしゃ /教育者/
きょういくしゃかいがく /教育社会学;educational sociology/
きょういくしゃしんしょ /教育社新書/
きょういくしゅっぱん /教育出版/
きょういくしょう /教育省/教育相;†大臣/
きょういくしょく /教育職/
きょういくしんり /教育心理/
きょういくしんりがく /教育心理学;educational psychology/
きょういくじしん /教育自身/
きょういくじっしゅう /教育実習/
きょういくじょう /教育上/
きょういくじょうきょう /教育状況/
きょういくじょうほう /教育情報/
きょういくじょうもんだい /教育上問題/
きょういくすいじゅん /教育水準/
きょういくせいさく /教育政策/
きょういくせいど /教育制度/
きょういくぜんぱん /教育全般/
きょういくそうかん /教育総監/
きょういくそうだん /教育相談/
きょういくそうだんじょ /教育相談所/
きょういくたいせい /教育体制/
きょういくだい /教育大/
きょういくだいがくまえ /教育大学前/
きょういくちゅう /教育中/
きょういくちょう /教育長/
きょういくちょくご /教育勅語/
きょういくてき /教育的/
きょういくてきいぎ /教育的意義/
きょういくてきけんち /教育的見地/
きょういくてきこうか /教育的効果/
きょういくてきしどう /教育的指導/
きょういくてきはいりょ /教育的配慮/
きょういくてつがく /教育哲学/
きょういくてれび /教育テレビ;NHK/
きょういくない /教育内/
きょういくないよう /教育内容/
きょういくにゅうもん /教育入門/
きょういくはくしょ /教育白書/
きょういくばんぐみ /教育番組/
きょういくひ /教育費/
きょういくひょうか /教育評価/
きょういくぶ /教育部/
きょういくぶんせき /教育分析/
きょういくぶんや /教育分野/
きょういくほう /教育法/
きょういくほうしき /教育方式/
きょういくほうしん /教育方針/
きょういくほうそう /教育放送/
きょういくほうほう /教育方法/
きょういくほうほうろん /教育方法論/
きょういくまま /教育ママ/
きょういくめん /教育面/
きょういくもくてき /教育目的/
きょういくもんだい /教育問題/
きょういくよう /教育用/
きょういくようけいさんき /教育用計算機/
きょういくようけいさんきせんたー /教育用計算機センター/
きょういくろーん /教育ローン/
きょういくろん /教育論/
きょういぞん /共依存;codependence/
きょういち /恭一/京一/
きょういちにち /今日一日/
きょういちろう /恭一郎/
きょういてき /驚異的;surprising/脅威的;menacing/
きょういも /京芋;里芋の一種/
きょういろん /脅威論/
きょういん /教員/
きょういんこうぼ /教員公募/
きょういんさいようしけん /教員採用試験/
きょういんめんきょ /教員免許/
きょういんようせい /教員養成/
きょうう /強雨/
きょううん /強運/凶運/
きょうえい /共栄/競泳/鏡映;[数学]mirror/競映;映画の-/胸泳/
きょうえいがくえん /共栄学園/
きょうえいけん /共栄圏/
きょうえいしょくぶつ /共栄植物;[園芸]companion plants/
きょうえいたんかー /共栄タンカー/
きょうえいどう /共栄堂/
きょうえいみずぎ /競泳水着/
きょうえいもじ /鏡映文字/
きょうえき /共益/共役;※きょうやくの誤り?/
きょうえきけん /共益権/
きょうえきこうばいほう /共役勾配法/
きょうえきさいけん /共益債権/
きょうえきひ /共益費/
きょうえきひよう /共益費用/
きょうえつ /恐悦/
きょうえん /共演;†costar/競演;†compete/饗宴;banquet/狂宴;orgy/協演;†guest/嬌艶/
きょうえんき /強塩基/
きょうえんさく /共演作/
きょうえんしゃ /共演者/
きょうえんばん /共演盤/
きょうおう /饗応/供応;=饗応/狂王/胸奥/響応;打てば響く/響應;旧字/
きょうおん /跫音;あしおと/強音;forte/
きょうおんな /京女/
きょうか /強化;†strengthen/教科;subject/教化;†civilise/狂歌/供花/鏡花;人名,泉-/橋架/凶禍/莢果/
きょうか> /強化;(strengthen) -ガラス,-米,-合宿/
きょうかい /協会;†society/教会;†church/境界/教誨/胸懐/協會;旧字/疆界;地域の境界/
きょうかいいん /協会員/教会員/強化委員/
きょうかいいんかい /強化委員会/
きょうかいいんちょう /強化委員長/
きょうかいおんがく /教会音楽/
きょうかいかいちょう /協会会長/
きょうかいかんぶ /協会幹部/
きょうかいがわ /協会側/
きょうかいけん /境界研/
きょうかいし /教誨師/
きょうかいしき /教会式/
きょうかいしゅさい /協会主催/
きょうかいしょくいん /協会職員/
きょうかいじょう /境界上/
きょうかいじょうけん /境界条件/
きょうかいせい /境界性/
きょうかいせいじんかくしょうがい /境界性人格障害/
きょうかいせき /京懐石/
きょうかいせきぶん /境界積分/
きょうかいせん /境界線/
きょうかいせんぽう /教会旋法/
きょうかいそう /境界層/
きょうかいち /境界値/
きょうかいちょう /協会長/教会長/
きょうかいどう /教会堂/京街道/
きょうかいない /教会内/境界内/
きょうかいふきん /境界付近/
きょうかいぶんや /境界分野/
きょうかいへん /協会編/境界辺/
きょうかいへんこう /境界変更/
きょうかいめん /境界面/
きょうかいもんだい /境界問題/
きょうかいようそ /境界要素/
きょうかいようそほう /境界要素法/
きょうかいりゅう /境界流/
きょうかいりょう /境界量/
きょうかいりょういき /境界領域/
きょうかいれい /境界例/
きょうかがくしゅう /強化学習/
きょうかがっしゅく /強化合宿/
きょうかがらす /強化ガラス;tampered glass/
きょうかく /胸郭/侠客/狭角;⇔広角/夾角;二辺―相等/匡郭/胸膈/脅嚇/
きょうかさく /強化策/
きょうかざい /強化剤/
きょうかしゅうかん /強化週間/
きょうかしょ /教科書/
きょうかしょきじゅつ /教科書記述/
きょうかしょくひん /強化食品/
きょうかしょけんてい /教科書検定/
きょうかしょじけん /教科書事件/
きょうかしょそうどう /教科書騒動/
きょうかしょたい /教科書体/
きょうかしょちょうさかん /教科書調査官/
きょうかしょてき /教科書的/
きょうかしょもんだい /教科書問題/
きょうかすいげつ /鏡花水月/
きょうかたびら /経帷子/
きょうかつ /恐喝/
きょうかつざい /恐喝罪/
きょうかでんげん /強化電源/
きょうかね /京兼/
きょうかばん /強化版/
きょうかふく /強化服/
きょうかべ /京壁/
きょうかまい /強化米/
きょうかようとしょ /教科用図書/
きょうかりょく /強火力/
きょうかん /教官/共感/叫喚/経巻/胸管/凶漢/郷関/胸間/兇漢;=凶漢/郷貫/驕悍/峡間/
きょうかんかいぎ /教官会議/
きょうかんかく /共感覚;ランボー独特の-/
きょうかんかくてきひゆ /共感覚的比喩/
きょうかんしつ /教官室/
きょうかんじごく /叫喚地獄/
きょうかんふくいんしょ /共観福音書/
きょうかんめい /教官名/
きょうが /恭賀/狂画/
きょうがい /境涯/境界/驚駭/
きょうがく /驚愕/教学/共学/
きょうがくこう /共学校/
きょうがし /京菓子/
きょうがしま /経が島/
きょうがしんねん /恭賀新年/
きょうがせ /京ヶ瀬/
きょうがね /京兼/
きょうがのこむすめどうじょうじ /京鹿子娘道成寺/
きょうがま /京釜/
きょうがんい /強含意/
きょうき /狂気/凶器/狂喜;「-乱舞」/驚喜;おどろきよろこぶ/強記;博覧-/狭軌/侠気/共起/兇器/強毅/彊毅/
きょうきか /狭軌化/
きょうきじゅんびしゅうごうざい /凶器準備集合罪/
きょうきせん /狭軌線/
きょうきゃく /橋脚/
きょうきゅう /供給/匡救/
きょうきゅうかじょう /供給過剰/
きょうきゅうかた /供給過多/
きょうきゅうかんすう /供給関数/
きょうきゅうがわ /供給側/
きょうきゅうきょくせん /供給曲線/
きょうきゅうけいたい /供給形態/
きょうきゅうけいやく /供給契約/
きょうきゅうげん /供給源/
きょうきゅうさき /供給先/
きょうきゅうしゃ /供給者/
きょうきゅうばいたい /供給媒体/
きょうきゅうもう /供給網/
きょうきゅうもと /供給元/
きょうきゅうりょく /供給力/
きょうきょ /僑居;寓居、僑寓/
きょうきょう /恐々/兢々/
きょうきらんぶ /狂喜乱舞/
きょうきん /胸筋;[解剖](むね)pectoral muscle/胸襟;「-を開く」/頬筋;[解剖](ほお)buccinator muscle/
きょうぎ /協議/競技/教義;dogma/狭義;⇔広義/経木/供犠/
きょうぎいいん /協議委員/
きょうぎいいんちょう /競技委員長/
きょうぎかい /協議会;council/競技会;competition/
きょうぎかいし /競技開始/
きょうぎかいじょう /競技会場/
きょうぎがく /教義学;dogmatics/
きょうぎきそく /競技規則/
きょうぎさんか /競技参加/
きょうぎしっかく /競技失格/
きょうぎしゃ /競技者/競技車/
きょうぎしゅうりょう /競技終了/
きょうぎしゅうりょうご /競技終了後/
きょうぎじこう /協議事項/
きょうぎじょう /競技場/
きょうぎじょうない /競技場内/
きょうぎじんこう /競技人口/
きょうぎせい /競技性/
きょうぎせつめい /競技説明/
きょうぎぜんじつ /競技前日/
きょうぎそうこう /競技走行/
きょうぎたいかい /競技大会/
きょうぎたんとう /競技担当/
きょうぎちゅう /協議中/競技中/
きょうぎちょくぜん /競技直前/
きょうぎないよう /競技内容/
きょうぎにってい /競技日程/
きょうぎほうほう /競技方法/
きょうぎまあじゃん /競技麻雀/
きょうぎめい /競技名/
きょうぎゅうびょう /狂牛病/
きょうぎょう /協業/競業/
きょうぎょうきんし /競業禁止/
きょうぎょうしんしょう /教行信証/
きょうぎょうひし /競業避止/
きょうぎよう /競技用/
きょうぎようしゃりょう /競技用車両/
きょうぎりえん /協議離縁/
きょうぎりこん /協議離婚/
きょうく /教区/狂句/恐懼/
きょうくう /胸腔/
きょうくん /教訓/
きょうぐ /教具/狂愚/
きょうぐう /境遇/僑寓;僑居、寓居/
きょうけ /教化/京家;[日本史]藤原氏-/
きょうけい /恭敬/共形/教計/
きょうけいせい /共形性/
きょうけいば /共形場/
きょうけいばりろん /共形場理論/
きょうけつ /供血/
きょうけん /強健/強権/強肩/狂犬/鏡検/教権/恭謙/
きょうけんしゅぎ /教権主義;clericalism/
きょうけんたいせい /強権体制/
きょうけんてき /強権的/
きょうけんびょう /狂犬病/
きょうげき /京劇/挟撃/矯激/挾撃;旧字/
きょうげべつでん /教外別伝/
きょうげん /狂言/
きょうげんかた /狂言方/
きょうげんき /狂言記;全200番。1660-/
きょうげんきご /狂言綺語/
きょうげんざい /今日現在/
きょうげんし /狂言師/
きょうげんぼん /狂言本/
きょうげんまわし /狂言回し/
きょうこ /強固/京子/恭子/今日子/杏子/響子/享子/香子/教子/協子/鞏固/
きょうこう /強行;†force.「-突破」/強硬;†hard-line.「-姿勢」/恐慌;panic/教皇;Pope/胸腔/凶行/強攻;†forced attack.「敵陣を-する」/興行;※こうぎょう?/胸甲/凶荒;凶作/恐惶;-謹言/向後/
きょうこうきんげん /恐惶謹言/
きょうこうぐん /強行軍/
きょうこうけいはく /恐惶敬白/
きょうこうさいけつ /強行採決/
きょうこうさく /強硬策/強攻策/
きょうこうしせい /強硬姿勢/
きょうこうしゅだん /強行手段/
きょうこうしょう /強硬症;catalepsy/
きょうこうじょうたい /恐慌状態/
きょうこうせいしょうがい /恐慌性障害/
きょうこうせん /京工繊/
きょうこうせんだい /京工繊大/
きょうこうちょう /教皇庁;Curia/
きょうこうは /強硬派;タカ派/強行派;?/
きょうこうほうき /強行法規/
きょうこく /峡谷/強国/郷国/教国/狭谷;?/
きょうこつ /頬骨;ほおぼね/胸骨/侠骨/軽忽;かるはずみ./
きょうことば /京言葉/
きょうこのごろ /今日この頃/今日此頃/
きょうこは /狂虎派/
きょうご /教護/
きょうごいん /教護院;現・児童自立支援施設/
きょうごう /競合/強豪/校合/強剛/
きょうごうがくしゅう /競合学習/
きょうごうせいひん /競合製品/
きょうごうたしゃ /競合他社/
きょうごうてき /競合的/
きょうごうてん /競合店/
きょうごうどうし /強豪同士/
きょうごうりょく /競合力/
きょうごうろせん /競合路線/
きょうごく /京極/
きょうさ /教唆/
きょうさい /共済/共催/恐妻/凶歳/境栽;[園芸]border planting/
きょうさいか /恐妻家/
きょうさいくみあい /共済組合/
きょうさいけんきゅうかい /共催研究会/
きょうさいねんきん /共済年金/
きょうさく /狭窄/共作;collaborate.「アルバムを-する」/競作;vie.「コンテストで-する」/凶作/警策/
きょうさくきょく /共作曲/
きょうさくだいぜんしゅう /競作大全集/
きょうさつ /恐察/
きょうさはん /教唆犯/
きょうさん /協賛/共産/強酸/京産/
きょうさんかいいん /協賛会員/
きょうさんがっかい /協賛学会/
きょうさんがっかいいん /協賛学会員/
きょうさんがわ /共産側/
きょうさんきぎょう /協賛企業/
きょうさんけん /共産圏/
きょうさんしゅぎ /共産主義/
きょうさんしゅぎしゃ /共産主義者/
きょうさんしゅぎたいせい /共産主義体制/
きょうさんしゅぎてき /共産主義的/
きょうさんせい /強酸性/
きょうさんせん /京産戦/
きょうさんだい /京産大/京都産業大学;※abbrev/
きょうさんちゅうごく /共産中国/
きょうさんとう /共産党/
きょうさんとういん /共産党員/
きょうさんとうかんけいしゃ /共産党関係者/
きょうさんとうこうにん /共産党公認/
きょうさんとうせんげん /共産党宣言/
きょうざい /教材/共在;coexistence/
きょうざいけんきゅう /教材研究/
きょうざいひ /教材費/
きょうざつ /夾雑/
きょうざつぶつ /夾雑物/
きょうざぶろう /恭三郎/
きょうざめ /興醒め/興覚め/
きょうし /教師/供試/狂死/狂詩/教使/教旨/郷試;科挙の一次試験/享祀/
きょうしありがくしゅう /教師あり学習;[情報]supervised learning/
きょうしいっぱん /教師一般/
きょうしがわ /教師側/
きょうしき /京職/胸式;-呼吸/
きょうしきこきゅう /胸式呼吸/
きょうしきょく /狂詩曲/
きょうししんごう /教師信号/
きょうしつ /教室/狂疾/
きょうしつがい /教室外/
きょうしつすう /教室数/
きょうしなし /教師なし/
きょうしなしがくしゅう /教師なし学習;[情報]unsupervised learning/
きょうしゃ /強者/香車/狂者/驕奢/狭斜;-の巷(=遊里)/
きょうしやく /教師役/
きょうしゅ /教主/興趣/強取/拱手;-傍観/凶手/強手/兇手/
きょうしゅう /教習/郷愁/強襲/嬌羞/共終/
きょうしゅうかん /郷愁感/
きょうしゅうしゃ /教習車/
きょうしゅうしょ /教習所/
きょうしゅうじかん /教習時間/
きょうしゅうじょ /教習所/
きょうしゅうせい /教習生/教習制/
きょうしゅうちゅう /教習中/
きょうしゅうないよう /教習内容/
きょうしゅく /恐縮/強縮/
きょうしゅつ /供出/
きょうしゅぼうかん /拱手傍観/
きょうしょ /教書/校書/挟書/競書/郷書/
きょうしょう /狭小/京商/協商/胸章/夾鐘;[音楽]/嬌笑/強将/
きょうしょうてん /共焦点/
きょうしょく /教職/共食/強食/
きょうしょくいん /教職員/
きょうしょくかてい /教職課程/
きょうしよう /教師用/
きょうしろう /狂四郎/
きょうしん /共振/狂信/強震/狭心/驕心/強心/
きょうしんか /共進化/
きょうしんかい /共進会/
きょうしんかいろ /共振回路/
きょうしんき /共振器/
きょうしんけい /強震計/共振系/
きょうしんざい /強心剤/
きょうしんしゃ /狂信者/
きょうしんしゃしゅうだん /狂信者集団/
きょうしんしゅうはすう /共振周波数/
きょうしんしょう /狭心症/
きょうしんしんどう /共振振動/
きょうしんてき /狂信的/
きょうじ /教示/矜持;pride/共時/脇侍/凶事/経師/矜恃;=矜持/挟持;助力/香箸/香匙/享持;≒享有/恭二;人名/恭司/恭治/享治/鏡次/狂児/挾持;「挟」旧字/
きょうじく /橋軸/
きょうじせい /強磁性;ferromagnetic/共時性;synchronicity/
きょうじせいたい /強磁性体/
きょうじせいど /教示制度/
きょうじたい /共時態;[言語]synchronie. ⇔通時態/
きょうじつ /凶日/
きょうじてき /共時的/
きょうじば /強磁場/
きょうじま /京嶋/
きょうじゃく /強弱/怯弱/
きょうじゃくあくせんと /強弱アクセント;[言語]stress accent. 英語など/
きょうじゃくきごう /強弱記号;[音楽]p,ff,dim.など/
きょうじゃくひょうご /強弱標語/
きょうじゃくほう /強弱法/
きょうじや /経師屋/
きょうじゅ /教授/享受/
きょうじゅう /今日中/凶獣/
きょうじゅうごう /共重合/
きょうじゅかい /教授会/
きょうじゅけん /享受権/
きょうじゅしつ /教授室/
きょうじゅしゃ /教授者/
きょうじゅじん /教授陣/
きょうじゅせんせい /教授先生/
きょうじゅたち /教授達/
きょうじゅつ /供述/
きょうじゅつきょひけん /供述拒否権/
きょうじゅつしょ /供述書/
きょうじゅつちょうしょ /供述調書/
きょうじゅつろくしゅしょ /供述録取書/
きょうじゅどの /教授殿/
きょうじゅほう /教授法;didactics/
きょうじゅん /恭順/
きょうじょ /共助/狂女/
きょうじょう /橋上/教条/教場/凶状/兇状/
きょうじょうえき /橋上駅/
きょうじょうえきしゃ /橋上駅舎/
きょうじょうしゅぎ /教条主義/
きょうじょうしゅぎしゃ /教条主義者/
きょうじょうしゅぎてき /教条主義的/
きょうじょうてき /教条的/
きょうじん /強靭/狂人/強靱;「靭」異体字/凶刃/兇刃/
きょうじんたち /狂人達/
きょうす /香車/
きょうすい /胸水/供水/狂酔/
きょうすいびょう /恐水病;rabies(狂犬病)/
きょうすけ /恭介/京介/恭輔/京助/恭助/
きょうず /京津/
きょうせい /強制;force/矯正/共生/嬌声/教生;教育実習生/強請;ゆすり/強勢;[言語]stress/共棲/凶星/強盛/叫声/匡正/狭正/嬌聲/
きょうせい> /強制;-参加,-加入,-労働/
きょうせいいん /矯正院/
きょうせいかいしゅう /強制改宗/
きょうせいかんき /強制換気/
きょうせいきぐ /矯正器具/
きょうせいきょういく /矯正教育/
きょうせいきょく /矯正局/
きょうせいけいばい /強制競売/
きょうせいげんしょう /共生現象/
きょうせいこうい /強制行為/
きょうせいざい /矯正剤/
きょうせいしか /矯正歯科/
きょうせいしっこう /強制執行/
きょうせいしゅうよう /強制収容/
きょうせいしゅうようじょ /強制収容所/
きょうせいしゅうりょう /強制終了/
きょうせいしょぶん /強制処分/
きょうせいしりょく /矯正視力/
きょうせいしんどう /強制振動/
きょうせいじゅつ /矯正術;[医]/
きょうせいせいかつ /共生生活/
きょうせいせいぶつ /共生生物/
きょうせいせんたく /強制選択/
きょうせいそうかん /強制送還/
きょうせいそうさ /強制捜査/
きょうせいそち /強制措置/
きょうせいたいきょ /強制退去/
きょうせいだいしっこう /強制代執行/
きょうせいちょうよう /強制徴用/
きょうせいつうようりょく /強制通用力/
きょうせいていし /強制停止/
きょうせいてき /強制的/
きょうせいてんか /強制添加/
きょうせいにんち /強制認知/
きょうせいはいき /強制排気/
きょうせいはっこう /強制発光/
きょうせいほう /強制法/
きょうせいほけん /強制保険/
きょうせいほご /矯正保護/
きょうせいりこう /強制履行/
きょうせいりょうがえ /強制両替/
きょうせいりょく /強制力/
きょうせいれんこう /強制連行/
きょうせいろうどう /強制労働/
きょうせいわいせつ /強制猥褻/
きょうせいわぎ /強制和議/
きょうせき /共石/
きょうせつ /教説/
きょうせら /京セラ/
きょうせん /胸腺/共線/
きょうぜん /饗膳/
きょうそ /教祖/
きょうそう /競争;†competition.「価格-」/競走;†race.「100m-」/強壮/狂騒/競漕/狂想;=狂騒。「-曲」/狂躁;orgy/凶相/強壯;「壮」旧字/
きょうそうあいて /競争相手/
きょうそうかかく /競争価格/
きょうそうきょく /協奏曲;concerto/狂想曲;rhapsody/狂騒曲;=狂想曲/
きょうそうきょくふう /協奏曲風/
きょうそうけいやく /競争契約/
きょうそうげきか /競争激化/
きょうそうげんり /競争原理/
きょうそうこうきょうきょく /協奏交響曲/
きょうそうご /競走後/
きょうそうざい /強壮剤/
きょうそうしけん /競争試験/
きょうそうしゃ /競争者/
きょうそうしゃかい /競争社会/
きょうそうしん /競争心/
きょうそうせいせき /競走成績/競争成績;?/
きょうそうたいけい /競走体系/
きょうそうちゅう /競走中/
きょうそうちゅうし /競走中止/競争中止;?/
きょうそうにゅうさつ /競争入札/
きょうそうば /競走馬/競争馬;?/
きょうそうばいばい /競争売買/
きょうそうほう /競争法/
きょうそうめい /競走名/
きょうそうよう /競争用/
きょうそうりつ /競争率/
きょうそうりょく /競争力/
きょうそく /教則/脇息/
きょうそくびでお /教則ビデオ/
きょうそくほん /教則本/
きょうそくぼん /教則本/
きょうそさま /教祖様/
きょうそん /共存/
きょうぞう /胸像;bust/鏡像;mirror image/経蔵/享三/
きょうぞうだんかい /鏡像段階;[精医]stade du miroir (Lacanの用語)/
きょうぞうてん /鏡像点/
きょうぞめ /京染/
きょうぞん /共存/
きょうぞんかのう /共存可能/
きょうぞんきょうえい /共存共栄/
きょうぞんほう /共存法/
きょうぞんほうほう /共存方法/
きょうたい /筐体/狂態/嬌態/
きょうたいいき /狭帯域/
きょうたく /供託/教卓/
きょうたくきん /供託金/
きょうたくしょ /供託所/供託書/
きょうたくじょ /供託所/
きょうたくほう /供託法/
きょうたる /京樽/
きょうたろう /京太郎/
きょうたん /驚嘆/
きょうだ /強打/怯懦/
きょうだい /兄弟/強大/鏡台/橋台/京大/兄妹/姉弟/姉妹/兄姉/京都大学;※abbrev/
きょうだいあい /兄弟愛/
きょうだいか /強大化/
きょうだいかいかん /京大会館/
きょうだいかけん /京大化研/
きょうだいかん /兄弟間/
きょうだいがた /京大型/
きょうだいがわ /京大側/
きょうだいき /兄弟機/
きょうだいきけん /京大基研/
きょうだいけいざい /京大経済/
きょうだいけいざいがくぶ /京大経済学部/
きょうだいげんか /兄弟喧嘩/兄妹喧嘩/
きょうだいこう /京大工/
きょうだいしまい /兄弟姉妹/
きょうだいじん /京大陣/
きょうだいじんぶんけん /京大人文研/
きょうだいすうり /京大数理/
きょうだいすうりけん /京大数理研/
きょうだいせい /京大生/
きょうだいせいきょう /京大生協/
きょうだいせきとり /兄弟関取/
きょうだいたいけつ /兄弟対決/
きょうだいてん /兄弟店/
きょうだいで /京大出/
きょうだいどうし /兄弟同士/
きょうだいない /京大内/
きょうだいにんげんかんきょう /京大人間環境/
きょうだいのうがくぶ /京大農学部/
きょうだいびょういん /京大病院/
きょうだいぶん /兄弟分/
きょうだいぼうさいけん /京大防災研/
きょうだいまいこんくらぶ /京大マイコンクラブ/
きょうだいよしだ /京大吉田/
きょうだいり /京大理/
きょうだいりがくぶ /京大理学部/
きょうだいろ /京大炉/
きょうだしゃ /強打者/
きょうだる /京樽/
きょうだん /教団/教壇/凶弾/兇弾/兇彈/
きょうだんいん /教団員/
きょうだんかん /教団間/
きょうだんきょうそ /教団教祖/
きょうだんほんぶ /教団本部/
きょうち /境地/協治/
きょうちくとう /夾竹桃/
きょうちゅう /胸中/
きょうちゅうじゃく /強中弱/
きょうちょ /共著/
きょうちょう /強調;†emphasise/協調;†cooperate/共聴/凶兆/
きょうちょううんてん /協調運転/
きょうちょうがた /協調型/
きょうちょうけいさん /協調計算/
きょうちょうこうどう /協調行動/
きょうちょうさぎょう /協調作業/
きょうちょうしょり /協調処理/
きょうちょうせい /協調性/
きょうちょうてき /協調的/
きょうちょうどうさ /協調動作/
きょうちょうぶんさん /協調分散/
きょうちょうほう /強調法/
きょうちょうほうしき /協調方式/
きょうちょうもじ /強調文字/
きょうちょうもんだいかいけつ /協調問題解決/
きょうちょうゆうし /協調融資;cofinance/
きょうちょく /強直/
きょうちょしゃ /共著者/
きょうちょしゃめい /共著者名/
きょうちょしょ /共著書/
きょうぢゅう /今日中/
きょうつい /胸椎/
きょうつう /共通/胸痛/
きょうつういき /共通域/
きょうつういちじ /共通一次/
きょうつういちじしけん /共通一次試験/
きょうつううんよう /共通運用/
きょうつうか /共通化/共通課/
きょうつうかいすうけん /共通回数券/
きょうつうかんかく /共通感覚/
きょうつうがいねん /共通概念/
きょうつうきかく /共通規格/
きょうつうきやく /共通規約/
きょうつうけいしき /共通形式/
きょうつうけん /共通券/
きょうつうけんかい /共通見解/
きょうつうげんご /共通言語/
きょうつうこう /共通項/
きょうつうこうぞう /共通構造/
きょうつうこうもく /共通項目/
きょうつうご /共通語/
きょうつうごか /共通語化/
きょうつうしゅうごう /共通集合/
きょうつうしよう /共通仕様/
きょうつうせい /共通性/
きょうつうせいさく /共通政策/
きょうつうせっけい /共通設計/
きょうつうせん /共通線/
きょうつうちしき /共通知識/
きょうつうてき /共通的/
きょうつうてん /共通点/
きょうつうにんしき /共通認識/
きょうつうのうぎょうせいさく /共通農業政策/
きょうつうぶ /共通部/
きょうつうぶひん /共通部品/
きょうつうぶぶん /共通部分/
きょうつうぶぶんしき /共通部分式/
きょうつうぶん /共通分/
きょうつうようそ /共通要素/
きょうづか /経塚/京塚/
きょうづくえ /経机/
きょうづせん /京津線/
きょうづつ /経筒/
きょうてい /協定/競艇/教程/胸底;-を明かす/筐底;-に秘す/協提/
きょうていかかく /協定価格/
きょうていがっこう /競艇学校/
きょうていしょ /協定書/
きょうていじょう /競艇場/強定常/
きょうていせかいじ /協定世界時/
きょうてき /強敵/狂的/
きょうてん /経典;†/教典;†/狂癲/
きょうてんどうち /驚天動地/
きょうでん /強電/敬田;[仏教]/
きょうでんかいしつ /強電解質;[化学]strong electrolyte/
きょうでんけい /強電系/
きょうでんしゃ /共電社/
きょうと /京都/教徒/
きょうといがい /京都以外/
きょうといちりつげいだい /京都市立芸大/
きょうとう /教頭/共闘/鏡筒/郷党/驚倒/京濤/
きょうとうぶ /鏡筒部/
きょうとうほ /橋頭堡/
きょうとえき /京都駅/
きょうとえきちか /京都駅地下/
きょうとえきほうめん /京都駅方面/
きょうとえきまえ /京都駅前/
きょうとおうしょう /京都王将/
きょうとかいかん /京都会館/
きょうとかいさい /京都開催/
きょうとかた /京都方/
きょうとかん /京都間/
きょうとがくえん /京都学園/
きょうとがくえんだいがく /京都学園大学/
きょうとがわ /京都側/
きょうときねん /京都記念/
きょうときょういくだいがく /京都教育大学/
きょうとぎおん /京都祇園/
きょうとぎていしょ /京都議定書/
きょうとく /享徳;年号(1452-1455)/京徳/
きょうとぐち /京都口/
きょうとぐん /京都郡/
きょうとけい /京都系/
きょうとけいばじょう /京都競馬場/
きょうとこうせんだい /京都工繊大/
きょうとこうつう /京都交通/
きょうとごしょ /京都御所/
きょうとさんぎょうだい /京都産業大/
きょうとさんぎょうだいがく /京都産業大学/
きょうとし /京都市/
きょうとしいき /京都市域/
きょうとしえい /京都市営/
きょうとしがい /京都市街/
きょうとしこうつうきょく /京都市交通局/
きょうとしでん /京都市電/
きょうとしない /京都市内/
きょうとしょう /京都賞/
きょうとしょしだい /京都所司代/
きょうとしんぶん /京都新聞/
きょうとしんぶんはい /京都新聞杯/
きょうとじゅう /京都中/
きょうとじょしだいがく /京都女子大学/
きょうとじん /京都人/
きょうとせらみっく /京都セラミック/
きょうとせん /京都線/
きょうとたいしょうてん /京都大賞典/
きょうとたきぎのう /京都薪能/
きょうとだい /京都大/
きょうとだいがく /京都大学/
きょうとだいしょうがい /京都大障害/
きょうとちゃく /京都着/
きょうとてん /京都店/
きょうとふ /京都府/
きょうとふけい /京都府警/
きょうとふだいひょう /京都府代表/
きょうとふない /京都府内/
きょうとふほくぶ /京都府北部/
きょうとふみん /京都府民/
きょうとふりつ /京都府立/
きょうとふりついかだいがく /京都府立医科大学/
きょうとふりつだいがく /京都府立大学/
きょうとべん /京都弁/
きょうとほうめん /京都方面/
きょうとまるぜん /京都丸善/
きょうとみなみ /京都南/
きょうとむき /京都向き/
きょうど /強度/郷土/匈奴/強弩/彊弩/
きょうどう /共同;†共にすること。「-経営」「-利用」/協同;†協力し合うこと。「-組合」「産学-」/協働;†協力して働くこと/経堂/共働;[生物]coaction/教導/鏡胴/嚮導/
きょうどう> /共同;-地,-購入,-訓練/
きょうどううんこう /共同運行;†「バスの-」/共同運航;†「フェリーの-」/
きょうどうえき /共同駅/
きょうどうかいそん /共同海損/
きょうどうかいはつ /共同開発/
きょうどうかんり /共同管理/
きょうどうききん /共同基金/
きょうどうきぎょうたい /共同企業体/
きょうどうくみあい /協同組合/共同組合;?/
きょうどうけいえい /共同経営/
きょうどうけんきゅう /共同研究/
きょうどうけんきゅうしゃ /共同研究者/
きょうどうげんそう /共同幻想/
きょうどうこう /共同溝/
きょうどうこうい /共同行為/
きょうどうこうげき /共同攻撃/
きょうどうこうにゅう /共同購入/
きょうどうさぎょう /共同作業/協同作業/
きょうどうさくせん /共同作戦/
きょうどうしっぴつしゃ /共同執筆者/
きょうどうしゃかい /共同社会/
きょうどうしゅっし /共同出資/
きょうどうしょく /教導職/
きょうどうじっけんしゃ /共同実験者/
きょうどうじゅうたく /共同住宅/
きょうどうじゅしょう /共同受賞/
きょうどうせい /共同性/
きょうどうせいかつ /共同生活/
きょうどうせいかつじょう /共同生活上/
きょうどうせいさく /共同制作/共同製作/
きょうどうせいさくしゃ /共同制作者/
きょうどうせいはん /共同正犯/
きょうどうせいめい /共同声明/
きょうどうせきゆ /共同石油;[企業名]/
きょうどうせっけいしゃ /共同設計者/
きょうどうせんげん /共同宣言/
きょうどうせんせん /共同戦線/
きょうどうそうぞく /共同相続/
きょうどうそしょう /共同訴訟/
きょうどうたい /共同体/協同体/
きょうどうたんぽ /共同担保/
きょうどうだいひょう /共同代表/
きょうどうだいり /共同代理/
きょうどうちょさくぶつ /共同著作物/
きょうどうつうしん /共同通信/
きょうどうつうしんしゃ /共同通信社/
きょうどうつうしんはい /共同通信杯/
きょうどうていとう /共同抵当/
きょうどうばぬし /共同馬主/
きょうどうひこくにん /共同被告人/
きょうどうふほうこうい /共同不法行為/
きょうどうべんじょ /共同便所/
きょうどうほいくしょ /共同保育所/
きょうどうほしょう /共同保証/
きょうどうほちょう /共同歩調/
きょうどうぼうぎ /共同謀議/
きょうどうぼきん /共同募金/
きょうどうやく /共同訳/
きょうどうよくじょう /共同浴場/
きょうどうりよう /共同利用/
きょうどうりよういいんかい /共同利用委員会/
きょうどうりようか /共同利用化/
きょうどうりようかのう /共同利用可能/
きょうどうりようがかり /共同利用掛/
きょうどうりようがた /共同利用型/
きょうどうりようしせつ /共同利用施設/
きょうどけいさん /強度計算/
きょうどげいのう /郷土芸能/
きょうどさ /強度差/
きょうどし /郷土史;†local history/郷土誌;†topography/
きょうどしか /郷土史家/
きょうどしょく /郷土色/
きょうどていか /強度低下/
きょうどぶんぷ /強度分布/
きょうどまり /今日泊/
きょうどりょうり /郷土料理/
きょうな /京菜/
きょうなんちょう /境南町/
きょうにん /杏仁;アンズのタネ。「-豆腐」/
きょうにんぎょう /京人形/
きょうにんどうふ /杏仁豆腐;あんにんどうふ/
きょうねつ /狂熱/
きょうねん /享年/凶年/
きょうねんし /強撚糸/
きょうの /京野/
きょうのすけ /恭之助;名/
きょうは /教派/
きょうはく /脅迫;threat/強迫;coerce.「-観念」/強拍;[音楽]downbeat ⇔弱拍/
きょうはくかんねん /強迫観念/
きょうはくこうい /強迫行為;[精医]compulsive act/
きょうはくざい /脅迫罪/
きょうはくしゃ /脅迫者/
きょうはくしんけいしょう /強迫神経症;[精医]compulsive neurosis/
きょうはくじょう /脅迫状/
きょうはくせい /強迫性/
きょうはくせいしょうがい /強迫性障害/
きょうはくてき /脅迫的/
きょうはくでんわ /脅迫電話/
きょうはくぶん /脅迫文/
きょうはつ /今日初/
きょうはつばい /今日発売/
きょうはん /共犯/教範/橋畔/
きょうはんかんけい /共犯関係/
きょうはんしゃ /共犯者/
きょうばい /競売/
きょうばいじょ /競売所/
きょうばいせい /競売制/
きょうばいせん /強焙煎/
きょうばし /京橋/
きょうばしえき /京橋駅/
きょうばしけいはん /京橋京阪/
きょうばん /響板/夾板/
きょうばんちゃ /京番茶/
きょうひしょう /強皮症/
きょうび /今日日/
きょうふ /恐怖/教父/京麩/
きょうふう /強風/京風/狂風/矯風;悪風を正す/驚風;[漢方]子供の痙攣/
きょうふうじ /強風時/
きょうふうちゅういほう /強風注意報/
きょうふえいが /恐怖映画/
きょうふかん /恐怖感/
きょうふがく /教父学;patrology/
きょうふくぶ /胸腹部/
きょうふしょう /恐怖症/
きょうふしょうせつ /恐怖小説/
きょうふしょうてき /恐怖症的/
きょうふしん /恐怖心/
きょうふせいじ /恐怖政治/
きょうふたいけん /恐怖体験/
きょうふてつがく /教父哲学/
きょうふもの /恐怖物/
きょうぶ /胸部/
きょうぶしょう /教部省/
きょうぶん /狂文/凶聞/
きょうぶんさん /共分散/
きょうぶんさんぎょうれつ /共分散行列/
きょうへい /強兵/恭平/京平/恭兵/
きょうへき /胸壁/
きょうへん /共編/共変;covariant.「-テンソル」/凶変/兇変/
きょうへんか /強変化/
きょうへんせい /共変性/
きょうへんちょう /共変調/
きょうへんどう /共変動/
きょうへんびぶん /共変微分/
きょうべん /教鞭/強弁/
きょうほ /競歩/享保;年号(1716-1736)/
きょうほう /享保;年号(1716-36)/教法/凶報/
きょうほうのかいかく /享保の改革;[日本史]享保1-延享2(1716-45),徳川吉宗/
きょうほん /教本/経本/狂奔/
きょうぼう /凶暴;†ferocious. 残忍かつ乱暴。「-な男」/狂暴;†violent. 狂ったように暴れる。「-化する」/共謀/強暴;†強くかつ荒々しい/兇暴;=凶暴/教坊/
きょうぼうきょうどうせいはん /共謀共同正犯/
きょうぼうさ /狂暴さ/
きょうぼうしゃ /共謀者/
きょうぼうせい /凶暴性/
きょうぼく /喬木;⇔灌木/経木/
きょうま /京間/
きょうまい /京舞/供米/
きょうまく /胸膜;[解剖]pleura/強膜;[解剖](目の)sclera/莢膜;[生物](細菌の)theca/鞏膜;=強膜/
きょうまくえん /胸膜炎;[医]pleurisy/
きょうまる /京丸/
きょうまん /驕慢/
きょうみ /興味/
きょうみいじょう /興味以上/
きょうみざい /矯味剤/
きょうみしんしん /興味津々/興味津津/
きょうみたいしょう /興味対象/
きょうみとうげ /京見峠/
きょうみはんぶん /興味半分/
きょうみぶかい /興味深い/
きょうみほんい /興味本位/
きょうむ /教務/凶夢/
きょうむか /教務課/
きょうむかかり /教務係/
きょうむがかり /教務係/
きょうむしょくいん /教務職員/
きょうむら /京村/
きょうむらさき /京紫/
きょうめい /共鳴/嬌名/響鳴/
きょうめいおん /共鳴音/
きょうめいきゅうしゅう /共鳴吸収/
きょうめいしつ /共鳴室/
きょうめいじょうけん /共鳴条件/
きょうめいせきぶん /共鳴積分/
きょうめいたい /共鳴体/
きょうめいばん /共鳴板/
きょうめん /鏡面/共面/
きょうめんかこう /鏡面加工/
きょうめんしあげ /鏡面仕上げ/
きょうめんはんしゃ /鏡面反射/
きょうもう /狂妄/
きょうもと /京本/
きょうもとまさき /京本政樹/
きょうもん /経文/狂文/教門/拱門;arch/
きょうや /京哉/
きょうやき /京焼;京都の焼物/
きょうやく /共役/共訳/協約/供役;?/
きょうやくきょく /共役極/
きょうやくけんぽう /協約憲法/
きょうやくこうばいほう /共役勾配法/
きょうやくこうぶんし /共役高分子/
きょうやくさようそ /共役作用素/
きょうやくしゃ /共訳者/
きょうやくしょ /協約書/
きょうやさい /京野菜/
きょうゆ /教諭/
きょうゆう /共有/享有/梟雄/侠勇/亨有;?/
きょうゆう> /共有;-地,-ファイル/
きょうゆうか /共有化/
きょうゆうかのう /共有可能/
きょうゆうきこう /共有機構/
きょうゆうけつごう /共有結合/
きょうゆうざいさん /共有財産;common property. 「(国民|夫婦)の-」/
きょうゆうしげん /共有資源/
きょうゆうしゃ /共有者/
きょうゆうせい /共有性/共優性/
きょうゆうぜん /京友禅/
きょうゆうたい /共有体/
きょうゆうち /共有地/
きょうゆうちょさくけん /共有著作権/
きょうゆうてん /共有点/
きょうゆうでんたい /強誘電体/
きょうゆうば /共有場/
きょうゆうぶつ /共有物/
きょうゆうぶんさん /共有分散/
きょうゆうへんすう /共有変数/
きょうゆうりょういき /共有領域/
きょうゆうれい /共有例/
きょうよ /供与/
きょうよう /教養/共用/供用/強要/孝養/
きょうようか /共用化/
きょうようかてい /教養課程/
きょうようがくぶ /教養学部/
きょうようき /共用機/
きょうようきき /共用機器/
きょうようくかん /共用区間/
きょうようざい /強要罪/
きょうようしつ /共用室/
きょうようしょ /教養書/
きょうようしょうせつ /教養小説/
きょうようじ /共用時/
きょうようじかん /供用時間/
きょうようじだい /教養時代/
きょうようたい /共用体/
きょうようとう /教養棟/
きょうようひ /共用費/
きょうようひん /共用品/
きょうようぶ /教養部/
きょうようぶつ /共用物/
きょうようぶぶん /共用部分;⇔専有部分/
きょうようぶん /共用分/
きょうらい /向来/敬礼/
きょうらく /享楽/京洛/
きょうらくしゅぎ /享楽主義;hedonism/
きょうらくてき /享楽的/
きょうらん /狂乱/供覧/供卵/
きょうり /郷里/教理/胸裡/
きょうりき /経力/強力/
きょうりきこ /強力粉/
きょうりきこむぎこ /強力小麦粉/
きょうりつ /共立/
きょうりつしゅっぱん /共立出版;[出版社名]/
きょうりつしゅっぱんしゃ /共立出版社;[出版社名]/
きょうりつじょし /共立女子/
きょうりつじょしこうこう /共立女子高校/
きょうりつじょしたんきだいがく /共立女子短期大学/
きょうりつせん /京立戦/
きょうりつでんし /共立電子/
きょうりつでんしさんぎょう /共立電子産業;[企業名]/
きょうりもんどうしょ /教理問答書/
きょうりゅう /恐竜/恐龍/
きょうりゅうえいが /恐竜映画/
きょうりゅうじだい /恐竜時代/
きょうりゅうせんしゃ /恐竜戦車/
きょうりゅうせんたい /恐竜戦隊/
きょうりゅうだいきこう /恐竜大紀行/
きょうりゅうてん /恐竜展/
きょうりゅうものがたり /恐竜物語/
きょうりょう /橋梁/狭量/
きょうりょうり /京料理/
きょうりょく /協力/強力/
きょうりょくかいいん /協力会員/
きょうりょくかんけい /協力関係/
きょうりょくこ /強力粉/
きょうりょくこうざ /協力講座/
きょうりょくこうどう /協力行動/
きょうりょくしゃ /協力者/
きょうりょくしゃぼしゅうちゅう /協力者募集中/
きょうりょくたい /協力隊/
きょうりょくたいせい /協力体制/
きょうりょくてき /協力的/
きょうりょくてん /協力店/
きょうりょくむひ /強力無比/
きょうりん /杏林/
きょうれい /教令/強冷/
きょうれき /教歴/
きょうれつ /強烈/
きょうれん /教練/狂恋/教錬;?/
きょうれんけつ /強連結/
きょうろ /狭路/
きょうろう /拱廊/
きょうろく /享禄;年号(1528-1532)/
きょうろん /経論/
きょうわ /協和;concord/共和;-国/興和/享和;年号(1801-1804)/
きょうわおん /協和音/
きょうわおんてい /協和音程/
きょうわかん /協和感/
きょうわぎんこう /協和銀行/
きょうわこく /共和国/
きょうわこくはい /共和国杯/
きょうわさいたま /協和埼玉/
きょうわしゅぎ /共和主義/
きょうわせい /共和制/共和政/協和性/
きょうわせいたい /共和政体/
きょうわてき /協和的/
きょうわとう /共和党/
きょうわはっこう /協和発酵/
きょうわれき /共和暦;[世界史]calendrier republicain/
きょうわん /峡湾/
きょえい /虚栄/巨影/
きょえいしん /虚栄心/
きょおく /巨億/
きょおんげん /虚音源/
きょか /許可/許嫁;「いいなずけ」とも/炬火/
きょかいきゅう /巨蟹宮;[十二宮]かに座(6.21-7.22)/
きょかえいぎょう /許可営業/
きょかき /許可機/
きょかこくち /許可告知/
きょかしょ /許可書/
きょかしょう /許可証/
きょかしんせい /許可申請/
きょかせい /許可制/
きょかせいど /許可制度/
きょかん /巨漢/居館/巨艦/
きょかんけつ /許冠傑/
きょかんりきし /巨漢力士/
きょがく /巨額/
きょがん /巨岩/炬眼/
きょき /歔欷/
きょきょじつじつ /虚々実々/虚虚実実/
きょきん /拠金/醵金/
きょぎ /虚偽/
きょぎひょうじ /虚偽表示/
きょぎょう /虚業/
きょぎょうか /虚業家/
きょく /曲/局/極/巨躯/棘;とげ/蕀;いばら/旭;旭日旗/亟;(すみやか)/勗;(つとめる)/洫;(みぞ)/跼;(かがむ)/
きょく> /曲;(acrobatic) 曲弾き,曲打ち,曲独楽/
きょくあて /局宛/
きょくあな /局アナ/
きょくい /極意/
きょくいがい /曲以外/
きょくいん /局員/
きょくう /極右/虚空/
きょくうた /曲歌/
きょくうち /曲打ち;acrobatic drumming. 「太鼓の-」/
きょくえん /曲宴/
きょくかい /曲解/
きょくかく /極角/
きょくかん /曲間/曲管/
きょくかんち /極寒地/
きょくがい /局外/
きょくがいしゃ /局外者/
きょくがいちゅうりつ /局外中立/
きょくがく /曲学/
きょくがくあせい /曲学阿世/
きょくがわ /局側/
きょくきぼ /局規模/
きょくぎ /曲技/
きょくぎめ /曲決め/
きょくけいしき /極形式/
きょくけん /極圏;=きょっけん/
きょくげい /曲芸/
きょくげいし /曲芸師/
きょくげん /極限/極言/局限/
きょくげんじょうきょう /極限状況/
きょくげんじょうたい /極限状態/
きょくげんち /極限値/
きょくげんほう /極限法/
きょくげんりゅう /極限流/
きょくこうしんくう /極高真空/
きょくこうせい /曲構成/
きょくごま /曲独楽/
きょくさ /極左/
きょくさく /曲作/
きょくざい /局在/
きょくざいか /局在化/
きょくざいせい /局在性/
きょくざいろん /局在論/
きょくざひょう /極座標/
きょくし /曲師/旭志/局紙/極至/
きょくしゃ /局舎/曲射/
きょくしゃほう /曲射砲/
きょくしゅう /曲集/
きょくしゅうろく /曲収録/
きょくしょ /局所/
きょくしょ> /局所;-[関変]数,-最適解/
きょくしょう /極小/極少/
きょくしょうか /極小化/
きょくしょうかい /極小解/
きょくしょうせい /極小性/
きょくしょうち /極小値/
きょくしょか /局所化/
きょくしょかい /局所解/
きょくしょかん /局所環/
きょくしょかんきょう /局所環境/
きょくしょきんじ /局所近似/
きょくしょさいてき /局所最適/
きょくしょさよう /局所作用/
きょくしょざひょうけい /局所座標系/
きょくしょし /局所視/
きょくしょせい /局所性/
きょくしょそくど /局所速度/
きょくしょたい /局所体/
きょくしょてき /局所的/
きょくしょひょうげん /局所表現/
きょくしょへんすう /局所変数/
きょくしょますい /局所麻酔;[医]局部麻酔/
きょくしょますいやく /局所麻酔薬/
きょくしん /極真/
きょくしんかいかん /極真会館/
きょくしんからて /極真空手/
きょくじ /曲事/
きょくじく /極軸/
きょくじたい /曲自体/
きょくじつ /旭日/
きょくじつき /旭日旗/
きょくじつしょう /旭日章/
きょくじつしょうてん /旭日昇天/
きょくじゅん /曲順/
きょくすい /曲水/
きょくすいのえん /曲水の宴/
きょくすう /曲数/局数/極数/
きょくせい /極性;†polarity.「電池の-」/極星;†polar star/
きょくせいとういつ /極性統一/
きょくせいとういつけい /極性統一形/
きょくせいぶんし /極性分子/
きょくせき /跼蹐/
きょくせつ /曲折;†紆余-/曲節;†phrase/曲説;†distort/
きょくせつご /曲折語/
きょくせん /曲線/局線/
きょくせんきんじ /曲線近似/
きょくせんこう /曲先行/
きょくせんざひょう /曲線座標/
きょくせんざひょうけい /曲線座標系/
きょくせんじょう /曲線上/
きょくせんぜんたい /曲線全体/
きょくせんたく /曲選択/
きょくせんつうかそくど /曲線通過速度/
きょくせんてき /曲線的/
きょくせんひょう /曲線標/
きょくせんび /曲線美/
きょくせんぶぶん /曲線部分/
きょくせんへん /曲線片/
きょくせんれつ /曲線列/
きょくぜんしゅう /曲全集/
きょくぜんたい /曲全体/
きょくそう /曲想/
きょくたい /極体/
きょくたん /極端/
きょくたんい /曲単位/
きょくたんか /極端化/
きょくたんじょう /曲誕生/
きょくだい /極大/
きょくだいか /極大化/
きょくだいげん /極大元/
きょくだいこ /曲太鼓/
きょくだいせい /極大性/
きょくだいち /極大値/
きょくだいてん /極大点/
きょくだん /曲弾/
きょくち /極地/局地/極致;美の-/極値;関数の-/
きょくちせん /局地戦/
きょくちせんそう /局地戦争;⇔総力戦/
きょくちてき /局地的/
きょくちぶんぷ /極値分布/
きょくちゅう /曲中/局中/
きょくちゅうはっと /局中法度/
きょくちょう /局長/曲調/
きょくちょうきゅう /局長級/
きょくちょうたんぱ /極超短波;ultra high frequency(UHF)/
きょくちょうだいり /局長代理/
きょくちょく /曲直/
きょくつき /曲付/
きょくてき /極的/
きょくてん /極点/
きょくてんせきち /跼天蹐地/
きょくとう /極東/曲頭/
きょくとうちいき /極東地域/
きょくとうほうそう /極東放送/
きょくど /極度/
きょくどうざん /旭道山/
きょくどめ /局留め/局留/局止め;?/
きょくない /局内/
きょくのり /曲乗り/
きょくは /棘波/
きょくはつ /局発/
きょくば /曲馬/
きょくばし /曲馬師/
きょくばだん /曲馬団/
きょくばん /局番/曲番/
きょくばんごう /曲番号/
きょくひ /棘皮/
きょくひつ /曲筆/
きょくび /極微/
きょくびき /曲弾き/
きょくふ /曲譜/
きょくふう /曲風/
きょくぶ /局部/
きょくぶてき /局部的/
きょくぶますい /局部麻酔/
きょくへいめん /曲平面/
きょくほう /局方;[略語]日本薬局方/
きょくほうしょうやく /局方生薬/
きょくほく /極北/
きょくほくしょご /極北諸語/
きょくむき /極向き/
きょくめ /曲目/
きょくめい /曲名/局名/
きょくめん /局面/曲面;curved surface/局免;[略語]無線局免許/
きょくめんきょ /局免許/
きょくめんじょう /曲面上/
きょくめんない /曲面内/
きょくめんへん /曲面片/
きょくもく /曲目/極目/
きょくもくひょう /曲目表/
きょくもち /曲持ち/
きょくや /極夜;⇔白夜/
きょくやく /曲約/
きょくよう /極洋/
きょくりつ /曲率/
きょくりつちゅうしん /曲率中心/
きょくりつはんけい /曲率半径/
きょくりょう /極量/
きょくりょく /極力/
きょくりょくちゅうい /極力注意/
きょくりょくはいじょ /極力排除/
きょくろん /極論/曲論/
きょけつ /虚血/
きょけつしんきん /虚血心筋/
きょけつせい /虚血性/
きょけつせいしんしっかん /虚血性心疾患/
きょけん /巨犬/
きょげい /巨鯨/
きょげつ /去月/
きょげん /虚言/
きょげんしょう /虚言症;[精医]mythomania/
きょげんへき /虚言癖/
きょこう /虚構/挙行/
きょこうせい /虚構性/
きょこうせんだん /虚航船団/
きょこうてき /虚構的/
きょこく /挙国/
きょこくいっち /挙国一致/
きょこつ /距骨/
きょこん /許婚/虚根/巨根/
きょご /虚語/
きょごう /倨傲/
きょさい /巨細/
きょさいぼう /巨細胞/
きょさつ /巨刹/
きょざい /巨財/巨材/
きょし /鋸歯/巨視/挙止/巨資/
きょしき /挙式/
きょしきび /挙式日/
きょしじょう /鋸歯状;serration/
きょしちょうざ /巨嘴鳥座;Tucana(Tuc)/
きょしつ /居室/
きょしつめんせき /居室面積/
きょしてき /巨視的/
きょしゅ /挙手/
きょしゅう /去就/虚舟/去秋;last autumn/
きょしゅつ /拠出/醵出;=拠出/
きょしゅつがく /拠出額/
きょしゅつきん /拠出金/
きょしゅん /去春/
きょしょ /居所/
きょしょう /巨匠/挙証/去声/裾礁/虚証;漢方で、体力・気力が衰え、顔色も悪く、疲れやすく、脈も弱々しい状態。/
きょしょうせきにん /挙証責任/
きょしょうてん /虚焦点;[光学]virtual focus/
きょしょく /虚飾/拒食/巨食/
きょしょくしょう /拒食症/
きょしん /虚心/巨神/許慎/
きょしんたんかい /虚心坦懐/
きょしんへい /巨神兵/
きょしんへいき /虚心平気/
きょじ /挙示/虚辞/虚字/
きょじつ /虚実/
きょじゃく /虚弱/
きょじゃくしゃ /虚弱者/
きょじゃくじ /虚弱児/
きょじゃくたいしつ /虚弱体質/
きょじゅ /巨樹/
きょじゅう /居住/巨獣/
きょじゅうく /居住区/
きょじゅうくうかん /居住空間/
きょじゅうけん /居住権/
きょじゅうしゃ /居住者/
きょじゅうしょうめいしょ /居住証明書/
きょじゅうじょうけん /居住条件/
きょじゅうせい /居住性/
きょじゅうち /居住地/
きょじゅうちいき /居住地域/
きょじゅうぶ /居住部/
きょじょう /居城/許状/
きょじん /巨人/巨神/虚人/
きょじんぐん /巨人軍/
きょじんしょう /巨人症;[医]/
きょじんせん /巨人戦/
きょじんだせん /巨人打線/
きょじんのほし /巨人の星/
きょじんはんしんせん /巨人阪神戦/
きょすう /虚数/
きょすうかい /虚数解/
きょすうたんい /虚数単位/
きょすうぶ /虚数部/
きょすうぶぶん /虚数部分/
きょせい /去勢/巨星/虚勢/去声;きょしょう/
きょせき /巨石/
きょせきぶんか /巨石文化;megalithic culture/
きょせつ /虚説/
きょせん /巨泉/巨船/
きょぜつ /拒絶/
きょぜつしょう /拒絶症;[精医]/
きょぜつしょうしょ /拒絶証書/
きょぜつはんのう /拒絶反応/
きょぜつりつ /拒絶率/
きょぜん /遽然/
きょそ /挙措/
きょそく /虚足/
きょぞう /虚像/巨像;†colossus.「アポロ-」/巨象;†huge elephant/虚象;?/
きょぞうほう /虚像法/
きょた /許多/
きょたい /巨体/
きょたく /居宅/
きょたん /去痰/虚誕/
きょたんやく /去痰薬/
きょだい /巨大/
きょだいあり /巨大蟻/
きょだいか /巨大化/
きょだいかがく /巨大科学/
きょだいきかい /巨大機械/
きょだいけんちく /巨大建築/
きょだいこくてん /巨大黒点/
きょだいさんぎょう /巨大産業/
きょだいしじょう /巨大市場/
きょだいじしん /巨大地震/
きょだいせんかん /巨大戦艦/
きょだいとし /巨大都市;megalopolis/
きょだいわくせい /巨大惑星/
きょだく /許諾/
きょだくしょ /許諾書/
きょだくはんい /許諾範囲/
きょだつ /虚脱/
きょだつかん /虚脱感/
きょだつじょうたい /虚脱状態/
きょだん /鋸断/
きょちゅうちょうてい /居中調停/
きょっかい /曲解/極海;polar-sea/
きょっかん /極冠/極官/
きょっきゅう /曲球/
きょっけい /極刑/
きょっけん /極圏/
きょっこう /極光/旭光/
きょてん /拠点/
きょてんかん /拠点間/
きょてんびょういん /拠点病院/
きょでん /虚伝/
きょとう /巨頭/巨塔/挙党/
きょどう /挙動/
きょどうふしん /挙動不審/
きょどうへんか /挙動変化/
きょなん /鋸南/
きょにゅう /巨乳/
きょにんか /許認可/
きょにんかけん /許認可権/
きょにんかじぎょう /許認可事業/
きょねん /去年/
きょねんいじょう /去年以上/
きょねんくれ /去年暮/
きょねんすえ /去年末/
きょねんぜんはん /去年前半/
きょねんどうよう /去年同様/
きょねんまつ /去年末/
きょねんゆうしょう /去年優勝/
きょはく /巨擘/
きょひ /拒否/巨費/許否;OK or not/
きょひうんどう /拒否運動/
きょひかん /拒否感/
きょひけん /拒否権/
きょひはんのう /拒否反応/
きょふ /巨富/
きょぶ /虚部/
きょぶん /虚聞/
きょへい /挙兵/
きょへん /巨編/巨篇/
きょほ /巨歩/
きょほう /巨峰/巨砲/虚報/
きょぼく /巨木/
きょまん /巨万/
きょむ /虚無/虚夢;⇔正夢/
きょむかん /虚無感/
きょむしゅぎ /虚無主義;nihilism/
きょむそう /虚無僧/
きょむてき /虚無的;nihilistic/
きょめい /虚名/
きょもう /虚妄/
きょゆう /許由;隠者の代表格/
きょゆうそうほ /許由巣父;栄進や高位を嫌うたとえ/
きょよう /許容/挙用/
きょようおうりょく /許容応力;[建築]破壊を免れ得る最大応力/
きょようかのう /許容可能/
きょようげんど /許容限度/
きょようごさ /許容誤差/
きょようせい /許容性/
きょようそくど /許容速度/
きょようど /許容度/
きょようにゅうりょく /許容入力/
きょようはんい /許容範囲/
きょようはんいない /許容範囲内/
きょようりょう /許容量/
きょらい /去来/
きょらいしょう /去来抄;向井去来/
きょり /距離/巨利/
きょりえんちょう /距離延長/
きょりかん /距離感/
きょりかんかく /距離感覚/
きょりかんすう /距離関数/
きょりがいねん /距離概念/
きょりがぞう /距離画像/
きょりくうかん /距離空間/
きょりけい /距離計/
きょりけいそく /距離計測/
きょりけいれんどうしき /距離計連動式/
きょりさ /距離差/
きょりしゃくど /距離尺度/
きょりすう /距離数/
きょりそう /距離走/
きょりち /距離値/
きょりちかく /距離知覚/
きょりてき /距離的/
きょりてきせい /距離適性/
きょりひょうじ /距離表示/
きょりふあん /距離不安/
きょりへんかん /距離変換/
きょりめん /距離面/
きょりゅう /居留/去留/
きょりゅうち /居留地/
きょりゅうみん /居留民/
きょれい /虚礼/
きょれいはいし /虚礼廃止/
きょんじゅ /慶州/
きよ /寄与/喜代/喜世/季代/毀誉/奇与/寄予/清/
きよあき /清明/清昭/清朗/
きよい /清井/
きよう /器用/起用/紀要/機用/紀陽/貴陽/記要/
きようぎんこう /紀陽銀行/
きようけん /崎陽軒/
きようど /器用度/
きようびんぼう /器用貧乏/
きようほう /起用法/
きようやく /稀用薬/
きようら /清浦/
きよえ /清栄/
きよおか /清岡/
きよか /清佳/
きよかず /清和/清一/
きよかわ /清川/
きよがき /清書/
きよき /清木/
きよくに /清久仁/
きよくら /清倉/
きよこ /清子/聖子/喜代子/紀代子/貴代子/希代子/希世子/
きよさと /清里/
きよさとか /清里化/
きよさとこうげん /清里高原/
きよざわ /清沢/
きよし /清/淳/潔/澄/清志/清司/清史/喜代志/潔司/喜好/清茂/僖良/
きよしげ /清重/清滋/
きよしろう /清志郎/清志朗/
きよじ /喜代治/
きよす /清洲/
きよすみ /清住/
きよずり /清刷り/清刷/
きよせ /清瀬/木寄せ;[彫刻]/
きよたか /清隆/清貴/清孝/清高/清天/
きよたき /清滝/清竜/
きよたけ /清武/
きよたに /清谷/
きよだ /清田/
きよつか /清塚/
きよつぐ /清次/
きよと /清人/
きよとし /清利/
きよぬま /浄沼/
きよね /清音/
きよの /清野/
きよのぶ /清信/
きよのり /清典/
きよはら /清原/
きよはらい /清祓/
きよはらえ /清祓/
きよはらのふかやぶ /清原深養父;夏の夜は まだ宵ながら あけぬるを 雲のいづこに 月やどるらむ/
きよはらのもとすけ /清原元輔;ちぎりきな かたみに袖を しぼりつつ 末の松山 波こさじとは/
きよはる /清治/清晴/
きよひこ /清彦/
きよひと /清人/
きよひめ /清姫/
きよひら /清衡/
きよひろ /清宏/清博/恭弘/
きよぶき /清拭き/
きよぶん /寄与分/
きよほうへん /毀誉褒貶/
きよまさ /清正;名/
きよまつ /清松/
きよみ /清美/清見/喜代美/聖美/紀代美/貴予美/
きよみがた /清見潟/
きよみず /清水/
きよみずでら /清水寺/
きよみずやき /清水焼;京焼の一/
きよもと /清元/
きよもとぶし /清元節;[浄瑠璃]/
きよもり /清盛;人名,平-/
きよゆき /清之/聖之/
きよら /清ら/
きよらか /清らか/
きよりつ /寄与率/
きよわ /気弱/
きら /綺羅/吉良/
きらーさいぼう /キラー細胞;[生物]killer cell/
きらい /機雷/嫌い/帰来/記頼/
きらいげん /機雷原/
きらいほう /鬼雷砲/
きらく /気楽/喜楽/帰洛/
きらずり /雲母刷/
きらびき /雲母引/
きらぼし /綺羅星/キラ星/きら星/
きらめき /煌めき/
きらら /雲母/
きららがみ /雲母紙/
きらわれもの /嫌われ者/
きらん /貴覧/
きり /桐/霧/錐/切り/切/棋理/雰;≒霧/
きりあい /斬り合い/
きりあげ /切り上げ/切上げ/
きりあぶら /桐油/
きりあめ /霧雨;=きりさめ/
きりいし /切石/
きりいちよう /桐一葉/
きりうじ /切蛆/
きりうり /切り売り/切売り/
きりえ /切り絵/切絵/
きりえず /切絵図/
きりおとし /切り落とし;(-肉)/切落/
きりか /霧化/
きりかえ /切り替え/切替/切替え/切り換え/切換/切換え/
きりかえき /切替器/
きりかえし /切り返し/
きりかえじ /切替時/
きりかき /切り欠き/
きりかけ /切掛/
きりかた /切り方/
きりかぶ /切り株/切株/檮/
きりかみ /切紙/切髪/
きりかみでんじゅ /切紙伝授/
きりが /霧賀/
きりがみ /切り紙/
きりきず /切り傷/切傷/斬傷/
きりきり /吉里吉里/
きりきりじん /吉里吉里人/
きりきりまい /きりきり舞い/
きりぎし /切岸/
きりぎりす /蟋蟀/蛬/螽斯/
きりくず /切りくず/
きりくずし /切り崩し/
きりくち /切り口/切口/
きりぐち /切り口/
きりぐも /霧雲/
きりこ /切子/桐子/切り子/
きりこうじょう /切り口上/切口上/
きりこみ /切り込み/切込み/切込/斬り込み/
きりこみたいちょう /切込隊長/切り込み隊長/
きりこんぶ /切り昆布/
きりごま /切り胡麻/
きりさきじゃっく /切り裂きジャック;Jack the Ripper/
きりさげ /切り下げ;通貨-/切下げ/
きりさと /霧里/
きりさめ /霧雨/
きりざい /桐材/
きりしたん /切支丹/吉利支丹/
きりしま /霧島/桐島/桐嶋/
きりしまやま /霧島山/
きりじょう /霧状/
きりすて /切り捨て/切捨て/切捨/
きりすと /基督/
きりすときょう /キリスト教/基督教/
きりすときょうこく /キリスト教国/
きりすときょうと /キリスト教徒/
きりすとしゃ /キリスト者/
きりずみ /切り炭/切炭/
きりた /桐田/
きりたけ /桐竹;浄瑠璃の家名/
きりたっぷ /霧多布/
きりたに /桐谷/
きりたんぽ /切りたんぽ/
きりだし /切り出し/切出し/
きりだしかた /切り出し方/
きりつ /規律/起立/紀律;≒規律/
きりつじゅうし /規律重視/
きりつせいちょうせつしょうがい /起立性調節障害/
きりつたすう /起立多数/
きりつぼ /桐壺/桐壷;「壺」異体字/
きりづま /切妻/
きりづまづくり /切妻造り;[建築] 正面から見て ∧ の形の屋根/切妻造/
きりづまはふ /切妻破風;[建築]/
きりづまやね /切妻屋根;[建築]/
きりづみ /霧積/
きりと /桐戸/
きりとおし /切り通し/切通/切通し/
きりとり /切り取り/切取り/切取/
きりとりせん /切り取り線/切取り線/
きりどおし /切り通し/切通/切通し/
きりどおしざか /切通坂/
きりなみ /霧浪/
きりにしき /起利錦/
きりぬき /切り抜き/切抜き/
きりぬきちょう /切り抜き帳/切抜き帳/
きりの /桐野/
きりのう /切能/
きりは /切刃/切り刃/切羽/切り羽/
きりはた /切畑/
きりはら /桐原/
きりはり /切り貼り/
きりばこ /霧箱;[物理]cloud chamber/
きりばな /切り花/切花/
きりばり /切り貼り/切り張り/
きりひとは /桐一葉/
きりび /切り火/鑽り火/
きりふ /切符/切斑/
きりふき /霧吹き/
きりふだ /切り札/切札/
きりふだてき /切札的/
きりふりこうげん /霧降高原/
きりぶち /桐渕/
きりぼし /切干し/
きりぼしだいこん /切干し大根/
きりみ /切り身/切身/
きりみせ /切見世/
きりもち /切り餅/切餅/
きりもと /桐本/
きりもどし /切り戻し/
きりもみ /錐揉み/
きりもり /切り盛り/切盛り/
きりゃく /機略/
きりや /桐谷/
きりやま /桐山/
きりゅう /気流/桐生;地名/霧生/寄留/旗旒;旗と吹流し/
きりゅういん /鬼龍院/
きりゅうえき /桐生駅/
きりゅうだいいち /桐生第一/
きりょ /羇旅/羈旅;=羇旅/
きりょう /器量/帰寮/着料/
きりょうじん /器量人/
きりょく /気力/棋力/氣力/
きりるもじ /キリル文字;абвгд… →cyrillic,Cyrillic/
きりわけ /切り分け/
きりん /麒麟/
きりんかん /麒麟館/
きりんざ /麒麟座;Camelopardalis(Cam)/
きりんじ /麒麟児/
きりんてい /麒麟亭/
きりんびーる /麒麟麦酒/
きるい /帰塁/
きるかえあすてるか /キルカエアステル科/Circaeasteraceae/
きれ /切れ/喜連/裂/切/
きれあじ /切れ味/
きれい /綺麗/奇麗/
きれいごと /綺麗事/
きれいずき /綺麗好き/
きれいどころ /綺麗所/
きれぎれ /切れ切れ/
きれじ /裂地/布地;=裂地/切れ痔/切れ字/切字/切れ地/
きれっぱし /切れっ端/
きれつ /亀裂/奇列/
きれなが /切れ長/
きれはし /切れ端/
きれま /切れ間/
きれまけ /切れ負け/
きれめ /切れ目/
きれもの /切れ者/切れ物;刃物など/
きれん /喜連/
きろ /帰路;return path.「-に就く」/岐路;branch.「人生の-」/kilo;[SI接頭語]K,10^3/
きろう /棄老/
きろく /記録/
きろくいん /記録員/
きろくえいが /記録映画/
きろくかい /記録会/
きろくがかり /記録係/
きろくがた /記録型/
きろくき /記録機/
きろくぎじゅつ /記録技術/
きろくけいしき /記録形式/
きろくし /記録紙/
きろくしゃ /記録者/
きろくしゅう /記録集/
きろくしんごう /記録信号/
きろくじかん /記録時間/
きろくじゅりつ /記録樹立/
きろくじょうほう /記録情報/
きろくせい /記録性/
きろくぜんしゅう /記録全集/
きろくたっせい /記録達成/
きろくてき /記録的/
きろくないよう /記録内容/
きろくばいたい /記録媒体/
きろくひょう /記録表/
きろくぶ /季肋部/
きろくぶぶん /記録部分/
きろくほうこく /記録報告/
きろくほうしき /記録方式/
きろくほかんじょ /記録保管所/
きろくみつど /記録密度/
きろくめん /記録面/
きろくやぶり /記録破り/
きろくよう /記録用/
きろぐらむ /瓩/
きろすう /キロ数/
きろめーとる /粁/
きろりっとる /竏/
きろわっとじ /キロワット時;kWh/
きわ /際/紀和/奇話/
きわく /木枠/
きわこ /貴和子/
きわた /木棉/
きわだ /黄蘗/黄肌/
きわまりづき /極月/
きわみ /極み/
きわむ /究/
きわめ /極め/窮め/
きわめいん /極印/
きわめがき /極書/
きわめつき /極め付き/極めつき/
きわめつけ /極めつけ/極め付け/
きわめて /極めて/
きわめふだ /極札/
きわもの /際物/
きをつけ /気を付け/
きん /金/菌/禁/筋/近/均/磬;銅鉢/襟;えり/衿;えり/噤;つぐ・む/斤;600g/欣;欣喜雀躍/欽;欽定/芹;せり/听;pond,pound/忻;(よろこぶ)/掀;(あげる)/釿;(おの)/禽;禽獣/檎;(林檎)/擒;とりこ/謹;謹慎/勤;通勤/僅;僅差/懃;慇懃/瑾;瑕瑾/覲/饉;飢饉/巾;頭巾/錦;錦糸/琴;木琴/緊;緊縛/窘;たしな・める/箘;(しのだけ)/箟;「箘」の異体字/衾;同衾/釁;ちぬ・る/鈞;30斤/今;古今/Au/Gold/
きん> /禁;禁煙,禁帯出,禁転載/筋;-紡錘,-トレ,-ジス,-萎縮症/
きんあ /金鴉/
きんあか /金赤/
きんあつ /禁圧/
きんい /近位/近医/金位;carat/
きんいき /禁域/
きんいぎょくしょく /錦衣玉食/
きんいしゅくしょう /筋萎縮症;[医]筋ジスなど/
きんいち /欣一;名/欽一/金一/錦一/
きんいっぷう /金一封/
きんいつ /均一/
きんいつうんちん /均一運賃/
きんいつか /均一化/
きんいつくかん /均一区間/
きんいつせい /均一性/
きんいつりょうきん /均一料金/
きんいろ /金色/
きんいん /金員/金印/近因/
きんいんちょくしょ /金印勅書/
きんうん /金運/
きんうんどう /筋運動/
きんうんも /金雲母/
きんえい /近影/近詠/
きんえき /菌液/
きんえん /禁煙/近縁/筋炎/禁苑/
きんえんうんどう /禁煙運動/
きんえんか /禁煙化/
きんえんかんけい /近縁関係/
きんえんがいらい /禁煙外来/
きんえんくいき /禁煙区域/
きんえんしつ /禁煙室/
きんえんしてい /禁煙指定/
きんえんしていせき /禁煙指定席/
きんえんしゃ /禁煙車/禁煙者/
きんえんしゃりょう /禁煙車両/
きんえんしゅ /近縁種/
きんえんじゆうせき /禁煙自由席/
きんえんじょ /禁煙所/
きんえんせき /禁煙席/
きんえんせんげん /禁煙宣言/
きんえんばしょ /禁煙場所/
きんえんひょうじ /禁煙表示/
きんえんれい /禁煙令/
きんおうむけつ /金甌無欠/
きんか /金貨/金華/金花/近火;近所の火事/槿花/
きんかい /近海/金塊/琴海/金海/欣快/禁戒/勤快/
きんかいぎょ /近海魚/
きんかいもの /近海物/
きんかいわかしゅう /金槐和歌集;源実朝/
きんかぎょくじょう /金科玉条/
きんかく /金閣/巾幗/
きんかくし /金隠し/
きんかくじ /金閣寺/
きんかくびょう /菌核病;[植物]/
きんかさん /金華山/
きんかざん /金華山/
きんかん /近刊/金管;brass.「-楽器」/金柑;[植物]kumquat/金環;annulus.「-日蝕」/金冠;gold crown/金橘/
きんかんがっき /金管楽器/
きんかんごじゅうそう /金管五重奏/
きんかんしょく /金環蝕/金環食/
きんかんそうしゃ /金管奏者/
きんかんにっしょく /金環日食/
きんかんばん /金看板/
きんが /謹賀/
きんがいしんたく /金外信託/
きんがく /金額/勤学/
きんがくかんさん /金額換算/
きんがくけいさん /金額計算/
きんがくしてい /金額指定/
きんがくていど /金額程度/
きんがくてき /金額的/
きんがくへんかん /金額返還/
きんがしんねん /謹賀新年/
きんがま /錦窯/
きんがみ /金紙/
きんがん /近眼/
きんがんきょう /近眼鏡/
きんき /近畿/禁忌/金気/錦旗/欣喜;-雀躍/金器/琴棋/近幾;?/
きんきいがい /近畿以外/
きんきがくせい /近畿学生/
きんきけん /近畿圏/
きんきご /近畿語/
きんきしゃりょう /近畿車輛/近畿車両/
きんきしょが /琴棋書画/
きんきじどうしゃどう /近畿自動車道/
きんきじゃくやく /欣喜雀躍/
きんきだい /近畿大/
きんきだいがく /近畿大学/
きんきちほう /近畿地方/
きんきてつどう /近畿鉄道/
きんきどう /近畿道/
きんきにほん /近畿日本/
きんきにほんてつどう /近畿日本鉄道/
きんきばん /近畿版/
きんきゅう /緊急/
きんきゅういりょう /緊急医療/
きんきゅうえんじょ /緊急援助/
きんきゅうかいぎ /緊急会議/
きんきゅうかいひ /緊急回避/
きんきゅうこうどう /緊急行動/
きんきゅうこくち /緊急告知/
きんきゅうしゃりょう /緊急車両/
きんきゅうしゅうかい /緊急集会/
きんきゅうしゅじゅつ /緊急手術/
きんきゅうじ /緊急時/
きんきゅうじたい /緊急事態/
きんきゅうじどうしゃ /緊急自動車/
きんきゅうじれんらく /緊急時連絡/
きんきゅうせい /緊急性/
きんきゅうそうこう /緊急走行/
きんきゅうそち /緊急措置/
きんきゅうたいさく /緊急対策/
きんきゅうたいさくほんぶ /緊急対策本部/
きんきゅうたいほ /緊急逮捕/
きんきゅうだっしゅつ /緊急脱出/
きんきゅうつうほう /緊急通報/
きんきゅうていし /緊急停止/
きんきゅうてはい /緊急手配/
きんきゅうど /緊急度/
きんきゅうにゅういん /緊急入院/
きんきゅうはっしん /緊急発進/
きんきゅうひなん /緊急避難/
きんきゅうひなんてき /緊急避難的/
きんきゅうふじょう /緊急浮上/
きんきゅうほうそう /緊急放送/
きんきゅうよう /緊急用/
きんきゅうれんらく /緊急連絡/
きんきょ /近居;[新語](親などと)近くに住むこと。(「同居」からの造語)/
きんきょう /近況/禁教/
きんきょうほうこく /近況報告/
きんきょく /琴曲/
きんきょり /近距離/
きんきょりきゃく /近距離客/
きんきょりゆそう /近距離輸送/
きんきょりろせん /近距離路線/
きんきん /僅々;わずか/近々;ちかぢか/欣々;gladly/
きんぎゅうきゅう /金牛宮;[十二宮]おうし座(4.20-5.20)/
きんぎょ /金魚/
きんぎょう /近業/
きんぎょうり /金魚売り/
きんぎょく /金玉/
きんぎょくきん /金玉均/
きんぎょすくい /金魚掬い;お祭り/
きんぎょそう /金魚草/
きんぎょだま /金魚玉/
きんぎょばち /金魚鉢/
きんぎょや /金魚屋/
きんぎょよう /金魚用/
きんぎん /金銀/
きんぎんか /金銀花/
きんぎんざいほう /金銀財宝/
きんぎんどう /金銀銅/
きんく /禁句/勤苦/金句;金章-/金口;=こんく/
きんぐち /金口/
きんぐん /筋群/禁軍/
きんけい /近景/謹啓/金鶏/筋系/錦鶏/
きんけいちょう /金鶏鳥/
きんけつ /金欠/
きんけつびょう /金欠病/
きんけん /金券/近県/金権;-政治/勤倹/金研/金属材料研究所;※abbrev/
きんけんしょうぶ /勤倹尚武/
きんけんしょっぷ /金券ショップ/
きんけんせいじ /金権政治/
きんけんたいしつ /金権体質/
きんけんや /金券屋/
きんげん /金言/謹厳;stern.「-実直」/謹言;「恐惶-」/
きんげんじっちょく /謹厳実直/
きんげんせんい /筋原繊維/
きんげんだい /近現代/
きんげんだいきょく /近現代曲/
きんげんてい /金原亭/
きんこ /金庫/禁固/禁錮;=禁固/金粉/今古;いまむかし/近古;鎌倉・室町時代/金鼓/金海鼠/
きんこう /近郊/均衡/金工/金鉱/金口/欣幸/金坑/金鉤/
きんこうか /均衡化/近郊化/
きんこうがた /近郊型/
きんこうくかん /近郊区間/
きんこうけい /近交系/
きんこうざいせい /均衡財政/
きんこうだい /金工大/
きんこうでんしゃ /近郊電車/
きんこうとし /近郊都市/
きんこうどう /金港堂/
きんこうぼくぜつ /金口木舌/
きんこうもくぜつ /金口木舌;オピニオン・リーダー/
きんこうよさん /均衡予算/
きんこうりろん /均衡理論/
きんこうろん /均衡論/
きんこかぶ /金庫株/
きんこく /謹告/近国/
きんこけい /禁固刑/
きんこつ /筋骨/
きんこつりゅうりゅう /筋骨隆々/筋骨隆隆/
きんこばん /金庫番/
きんこん /菌根/
きんこんいちばん /緊褌一番/
きんこんしき /金婚式;50周年/
きんご /金吾/
きんごう /金剛/近郷/
きんごく /近国;⇔遠国/禁獄/
きんごろう /金語楼/
きんさ /僅差/金砂/
きんさく /近作/金策/金作/
きんさつ /禁札/
きんさん /菌傘;[生物]pileus/
きんざ /金座/
きんざい /近在/
きんざいけん /金材研/
きんざん /金山/
きんざんじみそ /径山寺味噌/
きんし /禁止/近視/菌糸;hypha/錦糸;-町/金糸;gold thread/金枝;-玉葉/金鵄;-勲章/金史;二十一史/金紫;金印紫綬/
きんし> /禁止;-事項,-薬物/
きんしかんやく /筋弛緩薬/
きんしがん /近視眼/
きんしがんてき /近視眼的/
きんしきかん /禁止期間/
きんしきそく /禁止規則/
きんしぎょくよう /金枝玉葉/
きんしくいき /禁止区域/
きんしくかん /禁止区間/
きんしくんしょう /金鵄勲章/
きんしこうもく /禁止項目/
きんししょぶん /禁止処分/
きんししんごう /禁止信号/
きんしじこう /禁止事項/
きんしじゃく /金糸雀/
きんしじょう /金市場/
きんしたまご /錦糸卵/金糸卵/
きんしだい /禁止台/
きんしちいき /禁止地域/
きんしちょう /錦糸町/
きんしつ /均質/琴瑟;-相和す/
きんしつか /均質化/
きんしつせい /均質性/
きんしないよう /禁止内容/
きんしへん /金枝篇;The Golden Bough,1936,Frazer/
きんしほう /禁止法/
きんしぼん /禁止本/
きんしまえ /禁止前/
きんしゃ /金砂/禽舎/
きんしゃち /金鯱/
きんしゃちしょう /金鯱賞/
きんしゅ /禁酒/筋腫/金種/金主/
きんしゅう /錦繍/金繍/菌褶/
きんしゅうしゅく /筋収縮/
きんしゅきんえん /禁酒禁煙/
きんしゅく /緊縮/
きんしゅくざいせい /緊縮財政/
きんしゅほう /禁酒法/
きんしゅれい /禁酒令/
きんしょ /禁書/謹書/琴書/
きんしょう /僅少/金賞/金消;[略語]金銭消費賃貸(いわゆるローン)/金将;[将棋]/金章;「-金句」/近称;[文法]⇔遠称/筋少;[固有名詞][略語]筋肉少女帯/擒縦/
きんしょうけん /金証券/
きんしょうしょ /金証書/
きんしょく /金食/
きんしようご /禁止用語/
きんしれい /禁止令/
きんしろう /金四郎/
きんしん /近親/謹慎/近臣/近信/
きんしんけっこん /近親結婚/
きんしんこうはい /近親交配;[生物]inbreeding/
きんしんこん /近親婚/
きんしんしゃ /近親者/
きんしんしゅうこう /錦心繍口/
きんしんそうかん /近親相姦/
きんしんぞうお /近親憎悪/
きんじ /近似/≒/近時;recent/金地/金字/近侍;valet/近事/欣二/金次/金治/欽司/禁児/
きんじ> /近似;-解,-関数/
きんじかい /近似解/
きんじかいほう /近似解法/
きんじがね /金地金/
きんじき /禁色/
きんじきょくせん /近似曲線/
きんじきん /金地金/
きんじく /近軸/
きんじくこうせん /近軸光線/
きんじさ /近時差/
きんじし /金獅子/
きんじしき /近似式/
きんじししょう /金獅子賞;ベネチア映画祭/
きんじす /筋ジス;筋ジストロフィー/
きんじすとろふぃー /筋ジストロフィー;[医]進行性-/
きんじせいど /近似精度/
きんじち /近似値/
きんじつ /近日/
きんじつちゅう /近日中/
きんじつてん /近日点/
きんじつてんいどう /近日点移動/
きんじつはつばい /近日発売/
きんじつはつばいかいし /近日発売開始/
きんじて /禁じ手/
きんじてき /近似的/
きんじとう /金字塔/
きんじど /近似度/
きんじほう /近似法/
きんじほうていしき /近似方程式/
きんじゅ /近習/
きんじゅう /近習/禽獣/近什/
きんじょ /近所/
きんじょう /金城/禁城/今上/近状/錦上/謹上/
きんじょうてっぺき /金城鉄壁/
きんじょうてんのう /今上天皇/
きんじょうとうち /金城湯池/
きんじょがっぺき /近所合壁/
きんじょづきあい /近所付き合い/
きんじょめいわく /近所迷惑/
きんじりろん /近似理論/
きんじれつ /近似列/
きんじろう /金次郎/
きんじん /金人/
きんす /金子/
きんすじ /金筋/
きんすなご /金砂子/
きんせい /近世/金星/禁制/謹製;NB:「謹しんで製す」であり、謙譲語。人様が作ったものに言うのは不適切/均整/均斉;≒均整/
きんせいご /近世語/
きんせいし /近世史/
きんせいしょく /金星食/
きんせいせき /菫青石;iolite/
きんせいたい /禁制帯/
きんせいだいみょう /近世大名/
きんせいてき /近世的/
きんせいひん /禁制品/
きんせいぶつ /禁制物/
きんせいぶんがく /近世文学/
きんせき /金石/
きんせきがい /近赤外/
きんせきがいせん /近赤外線;[物理]near-inflared ray ⇔遠赤外線/
きんせきぶん /金石文/
きんせつ /近接/
きんせつかく /近接覚/
きんせつきょり /近接距離/
きんせつさつえいじ /近接撮影時/
きんせつさよう /近接作用/
きんせつせん /近接線/
きんせつてん /近接点/
きんせつば /近接場/
きんせつぶ /近接部/
きんせん /金銭/琴線/金線;gold wire/謹選/
きんせんい /筋繊維;[生物]muscle fibre/筋線維;=筋繊維/
きんせんうん /金銭運/
きんせんか /金盞花/
きんせんかんかく /金銭感覚/
きんせんさいけん /金銭債権/
きんせんさいむ /金銭債務/
きんせんしんたく /金銭信託/
きんせんすいとうぼ /金銭出納簿/
きんせんてき /金銭的/
きんせんてきひょうか /金銭的評価/
きんせんてきよゆう /金銭的余裕/
きんせんてきりえき /金銭的利益/
きんせんてきりゆう /金銭的理由/
きんせんとうろくき /金銭登録機;cash register. レジ/
きんせんとれーど /金銭トレード/
きんせんふたん /金銭負担/
きんせんめん /金銭面/
きんせんもんだい /金銭問題/
きんぜい /禁制/
きんぜつ /禁絶/
きんぜん /欣然/
きんそう /筋層/巾箱/
きんそうば /金相場/
きんそく /禁則/禁足/緊束/
きんそくしょり /禁則処理/
きんそくじこう /禁則事項/
きんそくち /禁足地/
きんそくれい /禁足令/
きんそしき /筋組織;[生物]muscular tissue/
きんぞう /金蔵/金造/
きんぞく /金属/勤続/
きんぞくいおん /金属イオン;[化学]metal ion/
きんぞくえん /金属塩/
きんぞくおん /金属音/
きんぞくかこう /金属加工/
きんぞくかこうぎょう /金属加工業/
きんぞくかん /金属缶/
きんぞくきじだい /金属器時代/
きんぞくくず /金属屑/
きんぞくけい /金属系/
きんぞくけつごう /金属結合/
きんぞくげんし /金属原子/
きんぞくこうがく /金属工学/
きんぞくこうぎょう /金属工業/
きんぞくこうさく /金属工作/
きんぞくこうたく /金属光沢/
きんぞくざいしつ /金属材質/
きんぞくざいりょう /金属材料/
きんぞくざいりょうけんきゅうじょ /金属材料研究所/
きんぞくしゃ /勤続者/
きんぞくすいそかぶつ /金属水素化物/
きんぞくせい /金属製/金属性/
きんぞくせっけん /金属石鹸/
きんぞくせってん /金属接点/
きんぞくせん /金属線/
きんぞくたんちき /金属探知機/
きんぞくてき /金属的/
きんぞくでんきょく /金属電極/
きんぞくないほう /金属内包/
きんぞくねんすう /勤続年数/
きんぞくばっと /金属バット/
きんぞくばん /金属板/
きんぞくひまく /金属皮膜/
きんぞくひろう /金属疲労/
きんぞくびりゅうし /金属微粒子/
きんぞくふん /金属粉/
きんぞくぶ /金属部/
きんぞくぶぶん /金属部分/
きんぞくへん /金属片/
きんぞくぼう /金属棒/
きんた /金太/
きんたい /勤怠/近体/
きんたいしゅつ /禁帯出/
きんたいひょう /勤怠表/
きんたま /金玉/
きんたろう /金太郎/
きんたろうあめ /金太郎飴/
きんたん /金丹/
きんだ /勤惰/
きんだい /近代/近大/金大/
きんだい> /近代;-文学,-美術,-科学/
きんだいいぜん /近代以前/
きんだいえいが /近代映画/
きんだいおんがく /近代音楽/
きんだいか /近代化/
きんだいかいが /近代絵画/
きんだいかがく /近代科学/
きんだいかがくしゃ /近代科学社;[出版社名]/
きんだいかこうじ /近代化工事/
きんだいき /近代機/
きんだいきゅうしゅう /近大九州/
きんだいけいざいがく /近代経済学/
きんだいけんちく /近代建築;modern architecture/
きんだいげき /近代劇/
きんだいこっか /近代国家/
きんだいご /近代語/
きんだいごうりしゅぎ /近代合理主義/
きんだいごしゅ /近代五種/
きんだいごしゅきょうぎ /近代五種競技;[スポーツ]modern pentathlon. 馬術・フェンシング・射撃・水泳・クロスカントリー/
きんだいさんぎょう /近代産業/
きんだいし /近代詩;poesie moderne/近代史;modern history/
きんだいしゃかい /近代社会/
きんだいしゅぎ /近代主義;modernism/
きんだいしょうぎ /近代将棋;[雑誌名]/
きんだいしょうせつ /近代小説/
きんだいじん /近代人/
きんだいせいぶつがく /近代生物学/
きんだいせん /近大戦/
きんだいち /金田一/
きんだいちきょうすけ /金田一京助/
きんだいちこうすけ /金田一耕助/
きんだいちはるひこ /金田一春彦/
きんだいてき /近代的/
きんだいとし /近代都市/
きんだいにほん /近代日本/
きんだいのうほう /近代農法/
きんだいびじゅつ /近代美術/
きんだいぶんがく /近代文学/
きんだいぶんめい /近代文明/
きんだいまあじゃん /近代麻雀/
きんだいみんしゅしゅぎ /近代民主主義/
きんだか /金高/
きんだく /欣諾/
きんだち /公達/
きんだみ /金彩/
きんだん /禁断/禁男/金談/
きんだんしょうじょう /禁断症状/
きんだんのかじつ /禁断の果実/
きんち /近地/
きんちさん /禁治産/
きんちさんしゃ /禁治産者/
きんちてん /近地点/
きんちゃ /金茶/
きんちゃく /巾着/近着/
きんちゃくきり /巾着切り/
きんちゅう /禁中/
きんちょ /近著/
きんちょう /緊張/金打/謹聴/金長/金鳥/禽鳥/禁鳥/謹聽;「聴」旧字/
きんちょうかん /緊張感/
きんちょうかんけい /緊張関係/
きんちょうぎみ /緊張気味/
きんちょうせい /緊張性/
きんちょうびょう /緊張病;[精医]catatonia/
きんちょく /謹直/
きんつば /金鍔/
きんつま /金妻/
きんて /禁手/
きんてい /謹呈/欽定/緊締;きつく締める/
きんていけんぽう /欽定憲法;⇔民定憲法/
きんていやくせいしょ /欽定訳聖書/
きんてき /金的/
きんてつ /近鉄/金鉄/
きんてついがせん /近鉄伊賀線/
きんてつえんせん /近鉄沿線/
きんてつおおさかせん /近鉄大阪線/
きんてつきゅうだん /近鉄球団/
きんてつきょうとせん /近鉄京都線/
きんてつげきじょう /近鉄劇場/
きんてつしらこえき /近鉄白子駅/
きんてつせん /近鉄線/
きんてつたんばばしえき /近鉄丹波橋駅/
きんてつとっきゅう /近鉄特急/
きんてつなごや /近鉄名古屋/
きんてつなごやせん /近鉄名古屋線/
きんてつなら /近鉄奈良/
きんてつならせん /近鉄奈良線/
きんてつなんばせん /近鉄難波線/
きんてつひがしおおさかせん /近鉄東大阪線/
きんてつふう /近鉄風/
きんてつようろうせん /近鉄養老線/
きんてつよっかいち /近鉄四日市/
きんてつよっかいちえき /近鉄四日市駅/
きんてん /近点/均霑/均沾/
きんてんさい /禁転載/
きんでい /金泥/
きんでん /筋電/金殿/
きんでんぎょくろう /金殿玉楼/
きんでんけい /筋電計/
きんでんず /筋電図/
きんでんせい /均田制/
きんと /筋斗/
きんとう /均等/近東/公任/金湯;金城湯池/
きんとうか /均等化/
きんとうぶんかつ /均等分割/
きんとうわり /均等割/均等割り/
きんとうわりつけ /均等割付/
きんとき /金時/
きんときまめ /金時豆/
きんとれ /筋トレ/
きんとん /金団/
きんど /金土/
きんどう /金道/金藤/
きんどけい /金時計/
きんどにち /金土日/
きんなみ /金並/
きんなら /緊那羅/
きんにく /筋肉/
きんにくけい /筋肉系/
きんにくしつ /筋肉質/
きんにくしょうじょたい /筋肉少女帯/
きんにくそしき /筋肉組織/
きんにくぞうきょうざい /筋肉増強剤/
きんにくちゅうしゃ /筋肉注射/
きんにくつう /筋肉痛/
きんにくりょう /筋肉量/
きんにっせい /金日成/
きんねこ /金猫/
きんねん /近年/
きんねんちゅう /近年中/
きんねんまれ /近年稀/
きんのう /勤皇/金納/
きんのすけ /金之助/
きんのたまご /金の卵/
きんはんげん /禁反言/
きんば /金馬/金歯/
きんばえ /金蠅/
きんばく /緊縛/
きんばつ /禁伐/
きんばり /金張り/
きんばん /勤番/
きんぱ /金波/
きんぱい /金杯/金牌/金盃/
きんぱく /緊迫/金箔/謹白/金帛/窘迫/
きんぱくか /緊迫化/
きんぱくかん /緊迫感/
きんぱち /金八/
きんぱちせんせい /金八先生/
きんぱつ /金髪/
きんぱら /金原/
きんひん /経行/
きんびょうぶ /金屏風/
きんぴ /金肥/金皮/
きんぴか /金ぴか/
きんぴょう /勤評/
きんぴら /金平/
きんぴらごぼう /金平牛蒡/
きんぴん /金品/
きんふたん /筋負担/
きんぶすま /金襖/
きんぶち /金縁/
きんぶん /金文/均分/
きんぶんしょうしょ /今文尚書/
きんぷう /金風/
きんぷん /金粉/
きんべん /勤勉/
きんぺいばい /金瓶梅/
きんぺき /金碧/
きんぺん /近辺/
きんぺんじゅうみん /近辺住民/
きんほんい /金本位/
きんほんいせい /金本位制/
きんぼ /欽慕/
きんぼう /近傍/
きんぼうがた /近傍型/
きんぼうけい /近傍系/
きんぼうこう /近傍項/
きんぼうすい /筋紡錘/
きんぼうば /近傍場/
きんぼし /金星/
きんぼたん /金ボタン;学ランの-/
きんぽ /金浦/
きんぽう /金峰/禁法/
きんぽうげ /金鳳花/
きんぽうげあか /キンポウゲ亜科/Rununculoideae/
きんぽうげか /キンポウゲ科/Ranunculaceae/
きんぽうげしょくぶつるい /Ranales/
きんぽうげもく /キンポウゲ目/Ranunculales/
きんぽうげもくぐん /キンポウゲ目群/Ranunculales/
きんぽくうこう /金浦空港/
きんま /木馬;きうま/蒟醤/
きんまく /筋膜/
きんまんか /金満家/
きんみつ /緊密/
きんみゃく /金脈/
きんみらい /近未来/
きんみらいてき /近未来的/
きんむ /勤務/
きんむい /勤務医/
きんむきそく /勤務規則/
きんむく /金無垢/
きんむけいたい /勤務形態/
きんむさき /勤務先/
きんむじかん /勤務時間/
きんむじかんちゅう /勤務時間中/
きんむじかんない /勤務時間内/
きんむじょうけん /勤務条件/
きんむたいけい /勤務体系/
きんむたいせい /勤務体制/
きんむち /勤務地/
きんむちゅう /勤務中/
きんむひょう /勤務表/
きんむび /勤務日/
きんむりょくしょう /筋無力症/
きんめ /金眼/斤目/
きんめい /金明/
きんめいちく /金明竹/
きんめいちょう /金明町/
きんめいてんのう /欽明天皇/
きんめだい /金目鯛/
きんめだりすと /金メダリスト/
きんめだる /金メダル/
きんめっき /金メッキ/金鍍金/
きんもーる /金モール;gold lace (<mogol ポルトガル語)/
きんもくせい /金木犀/
きんもじ /金文字/
きんもつ /禁物/
きんもん /禁門/金文/金紋/
きんや /禁野/欣也/欽也/謹也/欣哉/金弥/
きんやっかん /金約款/
きんゆ /禁輸/
きんゆう /金融/
きんゆうかい /金融界/
きんゆうかんけい /金融関係/
きんゆうかんわ /金融緩和/
きんゆうがい /金融街/
きんゆうがいしゃ /金融会社/
きんゆうきかん /金融機関/
きんゆうきかんめい /金融機関名/
きんゆうききたいおうかいぎ /金融危機対応会議/
きんゆうきょうこう /金融恐慌/
きんゆうぎょう /金融業/
きんゆうぎょうせい /金融行政/
きんゆうこうがく /金融工学;financial engineering/
きんゆうこうこ /金融公庫/
きんゆうさい /金融債/
きんゆうさいせいいいんかい /金融再生委員会/
きんゆうさいせいほう /金融再生法/
きんゆうさきものとりひき /金融先物取引/
きんゆうしえん /金融支援/
きんゆうしさん /金融資産/
きんゆうしじょう /金融市場/
きんゆうしほん /金融資本;financial capital/
きんゆうしょうひん /金融商品/
きんゆうしょうひんはんばいほう /金融商品販売法;金融サービス法/
きんゆうしんぶん /金融新聞/
きんゆうせいさく /金融政策/
きんゆうたんとうだいじん /金融担当大臣/
きんゆうちょう /金融庁/
きんゆうどう /金融道/
きんゆうはせいしょうひん /金融派生商品;デリバティブ/
きんゆうもちかぶがいしゃ /金融持ち株会社/
きんよう /金曜/緊要/
きんようしゅう /金葉集/
きんようしんや /金曜深夜/
きんようどよう /金曜土曜/
きんようび /金曜日/
きんようわかしゅう /金葉和歌集/
きんよく /禁欲/金欲/
きんよくしゅぎ /禁欲主義/
きんよくてき /禁欲的;ascetic/
きんらい /近来/
きんらめ /金ラメ/
きんらん /金襴;-緞子/金蘭;[植物]helleborine/
きんらんせんり /金蘭千里/
きんらんそう /金蘭荘/
きんらんで /金襴手/
きんらんどんす /金襴緞子/
きんり /金利/禁裏/
きんりせいさく /金利政策;interest policy.「ゼロ-」/
きんりゅう /金竜/
きんりょう /斤量/禁漁/金陵/禁猟/
きんりょうき /禁漁期/禁猟期/
きんりょうく /禁猟区/禁漁区/
きんりょうさ /斤量差/
きんりょく /筋力/金力/
きんりょくてき /筋力的/
きんりん /近隣/錦林/
きんりんこく /近隣国/
きんりんしゃこ /錦林車庫/
きんりんしゃこまえ /錦林車庫前/
きんりんしょこく /近隣諸国/
きんりんじゅうみん /近隣住民/
きんりんちいき /近隣地域/
きんる /金縷/近流/
きんるい /菌類/
きんるざいく /金鏤細工/
きんれい /禁令/金鈴/
きんれんか /金蓮花/
きんろう /勤労/金狼/
きんろういよく /勤労意欲/
きんろうか /勤労課/
きんろうかんしゃ /勤労感謝/
きんろうかんしゃのひ /勤労感謝の日;11.23 旧・新嘗祭/
きんろうがくせい /勤労学生/
きんろうしゃ /勤労者/
きんろうしゃぜんたい /勤労者全体/
きんろうしょとく /勤労所得/
きんろうじょうけん /勤労条件/
きんろうてき /勤労的/
きんろうぶ /勤労部/
きんわ /謹話/
ぎ /義;義理/儀;儀式/魏;中国国名/疑/議/偽/技/着/妓;芸妓/伎;伎芸/誼;(よしみ)交誼/宜;適宜/萓/戯;遊戯/戲;「戯」の旧字(人名用漢字)/犠;犠牲/犧;「犠」の旧字/蟻;(あり)蟻走感/嶬/曦;(ひかり)/礒;(いそ)/羲;伏羲 (「義」とは別字)/艤;艤装/欺;詐欺/擬;模擬/祇;神祇/巍;巍然/沂/祁/僞;「偽」の旧字(人名用漢字)/気;(連濁)男気/木;(連濁)拍子木/城;(連濁)宮城/
ぎ> /義;(仮の) 義兄弟,義指,義子,義勢/偽;(ニセの) 偽花,偽君子,偽文書/擬;(似た・似せた) 擬陽性,擬羊皮紙/
ぎあく /偽悪/
ぎあひ /ギア比/
ぎあん /議案/
ぎあんいちらん /議案一覧/
ぎあんしょ /議案書/
ぎいち /義一/
ぎいん /議員/議院;chamber/偽印/
ぎいんかんれん /議員関連/
ぎいんきそく /議院規則/
ぎいんしょうげんほう /議院証言法/
ぎいんすう /議員数/
ぎいんていすう /議員定数/
ぎいんないかくせい /議院内閣制/
ぎいんねんきん /議員年金/
ぎいんほうしゅう /議員報酬/
ぎいんりっぽう /議員立法/
ぎえん /義援;「義捐」の当て字/義捐/
ぎえんきん /義援金;「義捐金」の一般化した当て字/義捐金/
ぎおう /祇王/
ぎおん /祇園/擬音/
ぎおんご /擬音語/
ぎおんしょうじゃ /祇園精舎/
ぎおんちょう /祇園町/
ぎおんどうふ /祇園豆腐/
ぎおんばやし /祇園囃子/
ぎおんひょうげん /擬音表現/
ぎおんまつり /祇園祭/
ぎか /技科;[略語]技術科学(大学)/技家;[略語]技術家庭(科)/偽果;[植物]false fruit. (リンゴのように)子房以外が果実のようになるもの/偽花;[植物](菊のように)花の集まりが一つの花のように見えるもの/
ぎかい /議会/
ぎかいかいさんけん /議会解散権/
ぎかいしゅぎ /議会主義;parliamentarism/
ぎかいせい /議会制;parliamentary system/
ぎかいせいじ /議会政治;parliamentary government/
ぎかく /擬革/
ぎかくし /擬革紙;leather paper/
ぎかだい /技科大/
ぎかん /技官/議官/技管;[略語]技術管理/
ぎが /戯画/儀我/偽画/巍峨/giga;[SI接頭語]G,10^9/
ぎがか /戯画化/
ぎがく /伎楽/
ぎがてき /戯画的/
ぎがん /義眼/
ぎき /儀軌/義気/
ぎきょ /義挙/
ぎきょう /義侠/偽経;偽作の経典/
ぎきょうしん /義侠心/
ぎきょうだい /義兄弟/
ぎきょく /戯曲/
ぎきょくか /戯曲化/
ぎきょくしゅう /戯曲集/
ぎきん /義金/
ぎぎ /疑義;suspicion/擬議;consideration/魏魏/
ぎぎゃく /戯謔/
ぎく /疑懼/
ぎくん /義訓/
ぎぐん /義軍/
ぎけい /義兄/偽計/
ぎけいき /義経記/
ぎけつ /議決/
ぎけつきかん /議決機関/
ぎけつけん /議決権/
ぎけつけんしゅるいかぶしき /議決権種類株式/
ぎけん /技研/
ぎけんかぶしきがいしゃ /技研株式会社/
ぎけんこうかい /技研公開/
ぎけんこうぎょう /技研工業/
ぎげ /義解/
ぎげい /技芸/伎芸/
ぎげいてん /伎芸天/
ぎこ /擬古/
ぎこう /技巧;skill.「-的」/技工;handcraft.「-士」/
ぎこうし /技工士/
ぎこうしゃ /技工社/
ぎこうてき /技巧的/
ぎこうは /技巧派/
ぎこてんしゅぎ /擬古典主義/
ぎこぶん /擬古文/
ぎこものがたり /擬古物語/
ぎごく /疑獄/
ぎごしょく /魏呉蜀/
ぎさく /偽作/戯作/
ぎさん /蟻酸/
ぎし /技師;engineer/技士;(資格名を作る)/義歯/義姉/義士/義肢/義子;養子など/擬死/偽史/魏史;-倭人伝/岸/
ぎしき /儀式/
ぎしきてき /儀式的/
ぎしちょう /技師長/
ぎしほ /技師補/
ぎしゅ /義手/技手/
ぎしゅう /蟻集/
ぎしょ /偽書/魏書;二十一史/義疏/戯書/
ぎしょう /偽証/偽称/宜昌/擬傷/
ぎしょうざい /偽証罪/
ぎしょうだに /棋将谷/
ぎしわじんでん /魏志倭人伝/
ぎしん /疑心/義心/
ぎしんあんき /疑心暗鬼/
ぎしんごう /偽信号/
ぎしんなんぼくちょうじだい /魏晋南北朝時代;(中国:220-360)/
ぎじ /議事/疑似/擬似;≒疑似/擬餌;lure/
ぎじ> /疑似/擬似/
ぎじえ /疑似餌/擬似餌;[釣り]lure/
ぎじえさ /擬似餌/
ぎじかがく /疑似科学/擬似科学;=疑似科学/
ぎじきかん /議事機関/
ぎじご /疑似語/
ぎじしき /擬似式/
ぎじじんかく /疑似人格/
ぎじせいめい /疑似生命/
ぎじせかい /擬似世界/
ぎじたいけん /疑似体験/
ぎじてき /擬似的/疑似的;=擬似的/
ぎじとう /擬似頭/
ぎじどう /議事堂/
ぎじはん /疑似半/
ぎじばり /疑似針/擬餌鉤/
ぎじぶっしつ /疑似物質/
ぎじへんすう /疑似変数/擬似変数/
ぎじめいれい /疑似命令/
ぎじゅく /義塾/
ぎじゅつ /技術/
ぎじゅついいん /技術委員/
ぎじゅついいんかい /技術委員会/
ぎじゅついじ /技術維持/
ぎじゅついてん /技術移転/
ぎじゅついてんきかん /技術移転機関/
ぎじゅついん /技術院/
ぎじゅつか /技術科;†(教科)「中学校の-」/技術課;†(division)「国交省の-」/技術家;†technician/
ぎじゅつかいせつ /技術解説/
ぎじゅつかいはつ /技術開発/
ぎじゅつかいはつきこう /技術開発機構/
ぎじゅつかいはつしつ /技術開発室/
ぎじゅつかいはつじょう /技術開発上/
ぎじゅつかいはつぶ /技術開発部/
ぎじゅつかいはつほんぶ /技術開発本部/
ぎじゅつかがくだいがく /技術科学大学/
ぎじゅつかくしん /技術革新/
ぎじゅつかてい /技術家庭/
ぎじゅつかん /技術館/
ぎじゅつかんりぶ /技術管理部/
ぎじゅつがかり /技術係/
ぎじゅつがく /技術学/
ぎじゅつがっこう /技術学校/
ぎじゅつきかくしつ /技術企画室/
ぎじゅつきじゅん /技術基準/技術規準/
ぎじゅつきばん /技術基盤/
ぎじゅつきょういく /技術教育/
ぎじゅつきょうしつ /技術教室/
ぎじゅつきょうりょくぶ /技術協力部/
ぎじゅつけい /技術系/
ぎじゅつけんきゅう /技術研究/
ぎじゅつけんきゅうしつ /技術研究室/
ぎじゅつけんきゅうしょ /技術研究所/
ぎじゅつけんきゅうじょ /技術研究所/
ぎじゅつけんきゅうぶ /技術研究部/
ぎじゅつこうしゅうかい /技術講習会/
ぎじゅつこうじょう /技術向上/
ぎじゅつこうりゅう /技術交流/
ぎじゅつし /技術士;Professional Engineer/技術史;history of technology/技術誌;technography, technical magazine/
ぎじゅつしえん /技術支援/
ぎじゅつしつ /技術室/
ぎじゅつしどう /技術指導/
ぎじゅつしゃ /技術者/技術社/
ぎじゅつしゃかい /技術社会/
ぎじゅつしゃきょうかい /技術者協会/
ぎじゅつしゃむけ /技術者向け/
ぎじゅつしゅたい /技術主体/
ぎじゅつしゅっぱん /技術出版;[出版社名]/
ぎじゅつしょ /技術書/
ぎじゅつしょく /技術職/技術色/
ぎじゅつしりょう /技術資料/
ぎじゅつじっしょうき /技術実証機/
ぎじゅつじょう /技術上/
ぎじゅつじょうほう /技術情報/
ぎじゅつじん /技術陣/
ぎじゅつすいしんぶ /技術推進部/
ぎじゅつすいじゅん /技術水準/
ぎじゅつせん /技術選/技術戦/
ぎじゅつせんしゅけん /技術選手権/
ぎじゅつせんもん /技術専門/
ぎじゅつたいけい /技術体系/
ぎじゅつたいこく /技術大国/
ぎじゅつたんとう /技術担当/
ぎじゅつたんとうしゃ /技術担当者/
ぎじゅつだいにぶ /技術第二部/
ぎじゅつちしき /技術知識/
ぎじゅつちょう /技術庁/技術長/
ぎじゅつちょうさ /技術調査/
ぎじゅつていけい /技術提携/
ぎじゅつてき /技術的/
ぎじゅつてきかいけつさく /技術的解決策/
ぎじゅつてきけっかん /技術的欠陥/
ぎじゅつてきけんきゅう /技術的研究/
ぎじゅつてきこうさつ /技術的考察/
ぎじゅつてきしゅだん /技術的手段/
ぎじゅつてきしんぽ /技術的進歩/
ぎじゅつてきすいじゅん /技術的水準/
ぎじゅつてきそくめん /技術的側面/
ぎじゅつてきちしき /技術的知識/
ぎじゅつてきないよう /技術的内容/
ぎじゅつてきもんだい /技術的問題/
ぎじゅつてきもんだいてん /技術的問題点/
ぎじゅつてきよういん /技術的要因/
ぎじゅつてきりゆう /技術的理由/
ぎじゅつてん /技術展/
ぎじゅつとうかつぶ /技術統括部/
ぎじゅつどうこう /技術動向/
ぎじゅつどうこうちょうさ /技術動向調査/
ぎじゅつにんてい /技術認定/
ぎじゅつのうりょく /技術能力/
ぎじゅつはってん /技術発展/
ぎじゅつはっぴょう /技術発表/
ぎじゅつばたけ /技術畑/
ぎじゅつひょうろん /技術評論/
ぎじゅつひょうろんしゃ /技術評論社;[出版社名]www.gihyo.co.jp/
ぎじゅつぶ /技術部/
ぎじゅつぶぎじゅつか /技術部技術課/
ぎじゅつぶそく /技術不足/
ぎじゅつぶでんき /技術部電気/
ぎじゅつぶもん /技術部門/
ぎじゅつぶんかかい /技術分科会/
ぎじゅつぶんけん /技術文献/
ぎじゅつぶんしょ /技術文書/
ぎじゅつぶんしょさくせい /技術文書作成/
ぎじゅつへい /技術兵/
ぎじゅつへんちょう /技術偏重/
ぎじゅつほうこく /技術報告/
ぎじゅつほうこくしょ /技術報告書/
ぎじゅつほさいん /技術補佐員/
ぎじゅつほぞん /技術保存/
ぎじゅつほんぶ /技術本部/
ぎじゅつほんぶちょう /技術本部長/
ぎじゅつむけ /技術向け/
ぎじゅつめん /技術面/
ぎじゅつや /技術屋/
ぎじゅつよう /技術用/
ぎじゅつようご /技術用語/
ぎじゅつようそ /技術要素/
ぎじゅつらん /技術欄/
ぎじゅつりっこく /技術立国/
ぎじゅつりょう /技術料/
ぎじゅつりょく /技術力/
ぎじゅつれんらくかい /技術連絡会/
ぎじゅつろん /技術論/
ぎじゅつろんぶん /技術論文/
ぎじゅんじょ /擬順序/
ぎじょ /妓女;芸妓・遊女/祇女;平家物語の人名/伎女;≒妓女/
ぎじょう /議場/議定/戯場/儀仗/儀杖/技情/
ぎじょうへい /儀杖兵/
ぎじようし /議事要旨/
ぎじらんすう /疑似乱数/
ぎじらんすうはっせい /疑似乱数発生/
ぎじろく /議事録/
ぎじろくちゅう /議事録中/
ぎじん /擬人;prosopopee/義人;man of justice/
ぎじんか /擬人化/
ぎじんてき /擬人的/
ぎじんほう /擬人法/
ぎせい /犠牲;sacrifice/擬制;fiction/擬声;-語/擬製;imitation/儀制;儀式と制度/義勢;bluff/
ぎせいご /擬声語/
ぎせいしほん /擬制資本/
ぎせいしゃ /犠牲者/
ぎせいだ /犠牲打/
ぎせいてき /犠牲的/
ぎせいふらい /犠牲フライ;[野球]sacrifice fly/
ぎせき /議席/妓籍/
ぎせきすう /議席数/
ぎせきはいぶん /議席配分/
ぎせん /擬戦;simulated war/義戦;war for justice/岐セン;[企業名]/義戰;「戦」旧字/
ぎぜつ /義絶/
ぎぜん /偽善/巍然/
ぎぜんしゃ /偽善者/
ぎぜんてき /偽善的/
ぎぜんてきこうい /偽善的行為/
ぎそう /偽装;camouflage/艤装;船の-/擬装;≒偽装/儀装;-馬車/義爪;pick/
ぎそうかん /蟻走感/
ぎそうけいかく /偽装計画/
ぎそうけっこん /偽装結婚/
ぎそうしんじゅう /偽装心中/
ぎそく /義足/偽足;[生物]pseudopod/儀則/擬足;=偽足/
ぎそくるい /偽足類/
ぎぞう /偽造/
ぎぞうこうさく /偽造工作/
ぎぞく /義賊/
ぎたい /擬態/義体/
ぎたいご /擬態語/
ぎたいほう /擬態法/
ぎたん /義丹/技短/
ぎだ /犠打/
ぎだい /議題/技大/
ぎだゆう /義太夫/
ぎだゆうぶし /義太夫節;[浄瑠璃]/
ぎだゆうぼん /義太夫本/
ぎちょう /議長/
ぎちょうしめい /議長指名/
ぎちょうてき /議長的/
ぎちょうやく /議長役/
ぎっくりごし /ぎっくり腰/
ぎっしゃ /牛車/
ぎっちょう /毬杖;さぎちょうではこれを３つ立てます/
ぎつう /技通/
ぎてい /義弟/議定/
ぎていしょ /議定書/
ぎてん /偽典/儀典/疑点/
ぎとう /蟻塔/
ぎどうさんしのはは /儀同三司母;忘れじの ゆくすゑまでは かたければ 今日をかぎりの いのちともがな/
ぎなん /岐南/
ぎにんしん /偽妊娠/擬妊娠;?/
ぎぬ /衣/
ぎねん /疑念/
ぎねんごう /偽年号/
ぎねんりん /偽年輪/
ぎのう /技能/
ぎのうきょういく /技能教育/
ぎのうけんてい /技能検定/
ぎのうし /技能士;職業能力開発促進法に基づく技能検定合格者/
ぎのうしゃ /技能者/
ぎのうしょう /技能賞/
ぎのうしょく /技能職/
ぎのうてき /技能的/
ぎのざ /宜野座/
ぎのわん /宜野湾/
ぎはん /偽版/
ぎひ /犠飛;[野球]犠牲フライ/
ぎひつ /偽筆/
ぎひょう /技評/儀表/戯評/
ぎふ /岐阜/義父/
ぎふえき /岐阜駅/
ぎふけん /岐阜県/
ぎふこうこう /岐阜高校/
ぎふこうせん /岐阜高専/
ぎふし /岐阜市/
ぎふだい /岐阜大/
ぎふだいがく /岐阜大学/
ぎふぢょうちん /岐阜提灯/
ぎふとけん /ギフト券/
ぎふとよう /ギフト用/
ぎふながらがわ /岐阜長良川/
ぎふはしま /岐阜羽島/
ぎふはしまえき /岐阜羽島駅/
ぎふべん /岐阜弁/
ぎふほうそう /岐阜放送/
ぎふぼ /義父母/
ぎふん /義憤/
ぎぶつ /偽物/
ぎぶつほう /擬物法/
ぎぶん /戯文/
ぎぶんしょ /偽文書/
ぎへい /義兵/
ぎべん /擬娩;[文化人類学]couvade/
ぎほう /技法/技報;技術報告(誌)/
ぎほうどう /技報堂/
ぎぼ /義母/
ぎぼし /擬宝珠/
ぎまい /義妹/
ぎまん /欺瞞/欺慢;ばかにして欺く/
ぎみ /気味/君;(連濁) [父母兄弟姉妹親]君/
ぎみん /義民/
ぎむ /義務/
ぎむか /義務化/
ぎむかん /義務感/
ぎむきょういく /義務教育/
ぎむきょういくがっこう /義務教育学校/
ぎむきょういくきかん /義務教育期間/
ぎむしゃ /義務者/
ぎむづけ /義務付け/義務づけ/
ぎむてき /義務的/
ぎめい /偽名/
ぎもう /欺罔/
ぎもん /疑問/
ぎもんけい /疑問形/
ぎもんけいようし /疑問形容詞/
ぎもんし /疑問視;-する/疑問詞;[文法]interrogative/
ぎもんしゅ /疑問手/
ぎもんせつ /疑問節/
ぎもんだいめいし /疑問代名詞/
ぎもんていき /疑問提起/
ぎもんてん /疑問点/
ぎもんひょうかい /疑問氷解/
ぎもんふ /疑問符;？/
ぎもんふくし /疑問副詞;[文法]interrogative adverb. eg.how,wie,comment,どう/
ぎもんぶん /疑問文/
ぎゃ /伽/
ぎゃく /逆/虐/瘧;おこり(malaria)/謔;諧謔/
ぎゃく> /逆/
ぎゃくい /逆位;[生物]inversion/
ぎゃくいそう /逆位相/
ぎゃくいぞん /逆依存/
ぎゃくいち /逆位置/
ぎゃくうん /逆運/
ぎゃくうんどうがく /逆運動学/
ぎゃくえん /逆縁/
ぎゃくえんこん /逆縁婚;[文化人類学]levirate/
ぎゃくえんざん /逆演算/
ぎゃくえんすい /逆円錐/
ぎゃくかいせき /逆解析/
ぎゃくかいてん /逆回転/
ぎゃくかくさん /逆拡散/
ぎゃくかのう /逆可能/
ぎゃくかんすう /逆関数/
ぎゃくがくしゅう /逆学習/
ぎゃくがわ /逆側/
ぎゃくがわせ /逆為替/
ぎゃくきでんあつ /逆起電圧/
ぎゃくきでんりょく /逆起電力/
ぎゃくぎょうれつ /逆行列/
ぎゃくぎれ /逆ギレ/
ぎゃくけい /逆形/
ぎゃくげん /逆元/
ぎゃくげんしょう /逆現象/
ぎゃくこう /逆光/逆向/
ぎゃくこうか /逆効果/
ぎゃくこうせん /逆光線/
ぎゃくこうりゃく /逆攻略/
ぎゃくごさ /逆誤差/
ぎゃくさいせい /逆再生/
ぎゃくさつ /虐殺/
ぎゃくさつげんば /虐殺現場/
ぎゃくさつこうい /虐殺行為/
ぎゃくさつじけん /虐殺事件/
ぎゃくさつすう /虐殺数/
ぎゃくさべつ /逆差別/
ぎゃくさよう /逆作用/
ぎゃくさん /逆算/
ぎゃくさんかく /逆三角/
ぎゃくさんかくかんすう /逆三角関数/
ぎゃくさんかくけい /逆三角形/
ぎゃくさんかっけい /逆三角形/
ぎゃくさんしょう /逆参照/
ぎゃくざや /逆鞘/
ぎゃくし /虐使/
ぎゃくしべん /逆止弁/
ぎゃくしめい /逆指名/
ぎゃくしゃせん /逆車線/
ぎゃくしゃぞう /逆写像/
ぎゃくしゅ /逆修/
ぎゃくしゅう /逆襲/
ぎゃくしん /逆進/逆臣/逆心/
ぎゃくしんぐる /逆シングル;[野球]/
ぎゃくしんせい /逆進性/
ぎゃくしんぜい /逆進税/
ぎゃくしんとう /逆浸透/
ぎゃくじきょく /逆磁極/
ぎゃくじせい /逆磁性/
ぎゃくじゅうじ /逆十字/
ぎゃくじゅうでん /逆充電/
ぎゃくじゅん /逆順/
ぎゃくじょう /逆上/
ぎゃくすいへい /逆水平/
ぎゃくすう /逆数/
ぎゃくすうがく /逆数学/
ぎゃくせい /虐政/逆成;backformation/
ぎゃくせいせっけん /逆性石鹸/
ぎゃくせいせつ /逆正接/
ぎゃくせがわ /逆瀬川/
ぎゃくせつ /逆説/逆接/
ぎゃくせつすいみん /逆説睡眠/
ぎゃくせつてき /逆説的/
ぎゃくせんでん /逆宣伝/
ぎゃくそう /逆走/逆相/逆送/
ぎゃくそうかん /逆相関/
ぎゃくそうだ /逆操舵/
ぎゃくそこ /逆底/
ぎゃくぞう /逆像/
ぎゃくぞく /逆賊/
ぎゃくたい /虐待/
ぎゃくたいし /虐待死/
ぎゃくたん /逆探/
ぎゃくたんち /逆探知/
ぎゃくだんそう /逆断層/
ぎゃくちょう /逆潮/逆調;⇔順調/
ぎゃくちょうりゅう /逆潮流/
ぎゃくて /逆手/
ぎゃくてまえ /逆手前/
ぎゃくてん /逆転/
ぎゃくてんおう /逆転王/
ぎゃくてんかのう /逆転可能/
ぎゃくてんがち /逆転勝ち/
ぎゃくてんげき /逆転劇/
ぎゃくてんしゃ /逆転写/
ぎゃくてんしゃこうそ /逆転写酵素/
ぎゃくてんしょうり /逆転勝利/
ぎゃくてんそう /逆転層/逆転送/
ぎゃくてんまけ /逆転負け/逆転負/
ぎゃくてんまんるい /逆転満塁/
ぎゃくてんゆうしょう /逆転優勝/
ぎゃくでんあつ /逆電圧/
ぎゃくでんぱ /逆伝播/
ぎゃくでんぱん /逆伝搬/
ぎゃくと /逆徒/
ぎゃくとくせい /逆特性/
ぎゃくはんのう /逆反応/
ぎゃくばり /逆張り/
ぎゃくぱたーん /逆パターン/
ぎゃくひ /逆比/
ぎゃくひぶ /逆日歩/
ぎゃくひれい /逆比例/
ぎゃくびき /逆引き/逆引/
ぎゃくふぃるた /逆フィルタ/
ぎゃくふう /逆風/
ぎゃくふんしゃ /逆噴射/
ぎゃくへいほう /逆平方/
ぎゃくへん /逆片/逆辺/
ぎゃくへんかん /逆変換/
ぎゃくほうこう /逆方向/
ぎゃくぽーらんどきほう /逆ポーランド記法/
ぎゃくむき /逆向き/
ぎゃくめ /逆目/
ぎゃくもど /逆戻/
ぎゃくもどり /逆戻り/
ぎゃくもんだい /逆問題/
ぎゃくゆにゅう /逆輸入/
ぎゃくゆにゅうしゃ /逆輸入車/
ぎゃくゆにゅうばん /逆輸入版/
ぎゃくゆにゅうひん /逆輸入品/
ぎゃくよう /逆用/
ぎゃくり /逆理/
ぎゃくりゅう /逆流/
ぎゃくりゅうせいしょくどうえん /逆流性食道炎/
ぎゃくりよう /逆利用/
ぎゃっきょう /逆境/
ぎゃっこう /逆行;†go back.「時代に-する」/逆光;†backlight.「-の写真」/
ぎゃっこうじ /逆光時/
ぎゃっこうせん /逆光線/
ぎゃっこうほせい /逆光補正/
ぎゃんぶるせい /ギャンブル性/
ぎやく /偽薬/
ぎゅう /牛/
ぎゅういんばしょく /牛飲馬食/
ぎゅうえき /牛疫/
ぎゅうかく /牛角/
ぎゅうかわ /牛革/
ぎゅうぎゅうづめ /ぎゅうぎゅう詰め/ギュウギュウ詰め/
ぎゅうご /牛後/
ぎゅうし /牛脂/
ぎゅうしゃ /牛舎/牛車/
ぎゅうしんてい /牛心亭/
ぎゅうじ /牛耳/
ぎゅうじょ /牛女;彦星と七夕姫/
ぎゅうすじ /牛筋/牛スジ/
ぎゅうたん /牛タン/
ぎゅうたんや /牛タン屋/
ぎゅうてつ /牛鉄/
ぎゅうとう /牛刀/牛痘/
ぎゅうどん /牛丼/
ぎゅうどんや /牛丼屋/
ぎゅうなべ /牛鍋/
ぎゅうなべや /牛鍋屋/
ぎゅうにく /牛肉/
ぎゅうにくせつ /牛肉説/
ぎゅうにゅう /牛乳/
ぎゅうにゅうせっけん /牛乳石鹸/
ぎゅうにゅうぱっく /牛乳パック/
ぎゅうにゅうびん /牛乳ビン/牛乳壜/
ぎゅうにゅうや /牛乳屋/
ぎゅうば /牛馬/
ぎゅうひ /牛皮/求肥/
ぎゅうひれ /牛ヒレ/
ぎゅうふん /牛糞/
ぎゅうほ /牛歩/
ぎゅうほせんじゅつ /牛歩戦術/
ぎゅうめし /牛飯/
ぎゅうもつ /牛モツ/
ぎゅうもも /牛モモ/
ぎゅうらく /牛酪/牛楽/
ぎゆう /義勇/
ぎゆうぐん /義勇軍/
ぎゆうへい /義勇兵/
ぎょ /魚/御/漁/禦;防御/馭;馭者/圄/圉/
ぎょーざ /餃子/
ぎょい /御意/御衣/
ぎょいこう /御衣香/
ぎょう /行/業/御宇/仰;仰天/凝;凝固/形;形相/尭;尭舜/堯;「尭」の旧字(人名用漢字)/暁;通暁/曉;「暁」の旧字(人名用漢字)/僥;僥倖/嶢;たかい/澆;そそぐ/翹;連翹/蟯;蟯虫/驍;驍勇/痙;(呉音)/繞;?/
ぎょうあん /暁闇/
ぎょういこう /行以降/
ぎょういち /行位置/
ぎょううん /暁雲/
ぎょうかい /業界/凝塊/
ぎょうかいうら /業界裏/
ぎょうかいおおて /業界大手/
ぎょうかいがわ /業界側/
ぎょうかいがん /凝灰岩/
ぎょうかいくっし /業界屈指/
ぎょうかいさいへん /業界再編/
ぎょうかいし /業界紙/業界誌/
ぎょうかいしんぶん /業界新聞/
ぎょうかいじょうほう /業界情報/
ぎょうかいじん /業界人/
ぎょうかいすじ /業界筋/
ぎょうかいぜんたい /業界全体/
ぎょうかいだんたい /業界団体/
ぎょうかいない /業界内/
ぎょうかいはつ /業界初/
ぎょうかいひょうじゅん /業界標準/
ぎょうかいびょう /業界病/
ぎょうかいようご /業界用語/
ぎょうかく /行革/仰角/
ぎょうかん /行間/
ぎょうかんかく /行間隔/
ぎょうかんちょうせい /行間調整/
ぎょうが /仰臥/
ぎょうがい /仰臥位/
ぎょうがく /行学;[仏教]修行と学問/
ぎょうき /行基/
ぎょうきょう /業況;-報告/
ぎょうぎ /行儀/凝議/
ぎょうくぎり /行区切り/
ぎょうけい /行刑/行啓/
ぎょうけいるいしんしょぐうれい /行刑累進処遇令/
ぎょうけつ /凝結/凝血/
ぎょうけつすい /凝結水/
ぎょうこ /凝固/
ぎょうこう /行幸;天皇の外出/僥倖;luck/暁光/
ぎょうこつ /行乞;-の雲水/
ぎょうこてん /凝固点/
ぎょうこてんこうか /凝固点降下/
ぎょうこねつ /凝固熱;[化学]heat of solidification/
ぎょうさ /業作/
ぎょうさい /業際/
ぎょうさくじょ /行削除/
ぎょうざ /餃子/
ぎょうざや /餃子屋/
ぎょうし /凝視/仰視/凝脂/
ぎょうした /行下/
ぎょうしてい /行指定/
ぎょうしてん /凝視点/
ぎょうしゃ /業者/業社/
ぎょうしゃかん /業者間/
ぎょうしゃはいそう /業者配送/
ぎょうしゃめい /業者名/
ぎょうしゅ /業種/
ぎょうしゅう /凝集/凝聚;=凝集/
ぎょうしゅうせい /凝集性/
ぎょうしゅうりょく /凝集力/
ぎょうしゅく /凝縮/
ぎょうしゅくど /凝縮度/
ぎょうしゅくねつ /凝縮熱;[化学]heat of condensation/
ぎょうしゅべつ /業種別/
ぎょうしょ /行書/
ぎょうしょう /行商/驍将/
ぎょうしょうにん /行商人/
ぎょうしょく /暁色/
ぎょうしょたい /行書体/
ぎょうしんせい /暁新世;[地質年代]Palaeocene. 6430-5500万年前/
ぎょうじ /行事/行司;相撲の-/
ぎょうじゃ /行者/
ぎょうじゅう /行住/
ぎょうじゅうざが /行住坐臥/行住座臥/
ぎょうじょう /行状/行上/
ぎょうじよてい /行事予定/
ぎょうじん /行人/
ぎょうすう /行数/
ぎょうすうせいげん /行数制限/
ぎょうずい /行水/
ぎょうせい /行政/暁星/
ぎょうせいいん /行政院/
ぎょうせいかいかく /行政改革/
ぎょうせいかん /行政官/
ぎょうせいかんちょう /行政官庁/
ぎょうせいかんりちょう /行政管理庁/
ぎょうせいがく /行政学/
ぎょうせいがわ /行政側/
ぎょうせいきかん /行政機関/
ぎょうせいく /行政区/
ぎょうせいくいきない /行政区域内/
ぎょうせいくかく /行政区画/
ぎょうせいくぶん /行政区分/
ぎょうせいけん /行政権/
ぎょうせいこうい /行政行為/
ぎょうせいこくさい /暁星国際/
ぎょうせいざいさん /行政財産/
ぎょうせいしどう /行政指導/
ぎょうせいしょく /行政職/
ぎょうせいしょし /行政書士/
ぎょうせいしょぶん /行政処分/
ぎょうせいじけん /行政事件/
ぎょうせいじけんそしょうほう /行政事件訴訟法/
ぎょうせいじむ /行政事務/
ぎょうせいじょう /行政上/
ぎょうせいじょうほう /行政情報/
ぎょうせいそしき /行政組織/
ぎょうせいそしょう /行政訴訟/
ぎょうせいたんい /行政単位/
ぎょうせいだいしっこう /行政代執行/
ぎょうせいだいしっこうほう /行政代執行法/
ぎょうせいちく /行政地区/
ぎょうせいちょう /行政庁/
ぎょうせいてつづき /行政手続/
ぎょうせいてつづきほう /行政手続法/
ぎょうせいとうきょく /行政当局/
ぎょうせいのうりょく /行政能力/
ぎょうせいはん /行政犯/
ぎょうせいばつ /行政罰/
ぎょうせいひょうか /行政評価/
ぎょうせいひょうかきょく /行政評価局/
ぎょうせいふ /行政府/
ぎょうせいふふくしんさほう /行政不服審査法/
ぎょうせいぶんしょ /行政文書/
ぎょうせいほう /行政法/
ぎょうせいめいれい /行政命令/
ぎょうせいめん /行政面/
ぎょうせいもくてき /行政目的/
ぎょうせき /業績/凝析/
ぎょうせきあっか /業績悪化/
ぎょうせきしゅぎ /業績主義;⇔属性主義/
ぎょうせきしょ /業績書/
ぎょうせきふしん /業績不振/
ぎょうせきよそう /業績予想/
ぎょうせん /暁泉/
ぎょうせんとう /行先頭/
ぎょうぜん /凝然/
ぎょうぜんご /行前後/
ぎょうそう /形相/行草/
ぎょうそうにゅう /行挿入/
ぎょうぞう /行三/
ぎょうたい /業態/凝滞/
ぎょうたいべつ /業態別/
ぎょうたん /行端/
ぎょうたんい /行単位/
ぎょうだ /行田/
ぎょうだし /行田市/
ぎょうちゃく /凝着/
ぎょうちゅう /蟯虫/行中/
ぎょうつう /暁通/
ぎょうてん /仰天/暁天/
ぎょうとう /行頭/
ぎょうとく /行徳/
ぎょうとくえき /行徳駅/
ぎょうどう /行道/
ぎょうない /行内/
ぎょうにんべん /行人偏;「彷」の偏/
ぎょうねん /行年/
ぎょうはんい /行範囲/
ぎょうばんごう /行番号/
ぎょうぶ /刑部/行歩/
ぎょうぶしょう /刑部省;[律令制]八省/
ぎょうぶんかつ /行分割/
ぎょうへんしゅう /行編集/
ぎょうほう /行法/
ぎょうほうこう /行方向/
ぎょうぼう /仰望/
ぎょうまつ /行末/
ぎょうまつもじ /行末文字/
ぎょうむ /業務/暁霧/
ぎょうむか /業務課/
ぎょうむかいぜんめいれい /業務改善命令/
ぎょうむかんり /業務管理/
ぎょうむき /業務機/
ぎょうむしっこうしゃ /業務執行者/
ぎょうむしっこうしゃいん /業務執行社員/
ぎょうむしりょう /業務資料/
ぎょうむじかん /業務時間/
ぎょうむじょう /業務上/
ぎょうむじょうおうりょう /業務上横領/
ぎょうむじょうかしつ /業務上過失/
ぎょうむちゅう /業務中/
ぎょうむていけい /業務提携/
ぎょうむていし /業務停止/
ぎょうむどくせん /業務独占/
ぎょうむないよう /業務内容/
ぎょうむはつめい /業務発明/
ぎょうむはんい /業務範囲/
ぎょうむぶ /業務部/
ぎょうむほうこく /業務報告/
ぎょうむぼうがい /業務妨害/
ぎょうむぼうがいざい /業務妨害罪/
ぎょうむめいれい /業務命令/
ぎょうむもくてき /業務目的/
ぎょうむもくひょう /業務目標/
ぎょうむよう /業務用/
ぎょうむれんらく /業務連絡/
ぎょうめ /行目/
ぎょうゆう /驍勇/
ぎょうよう /杏葉/
ぎょうよく /楽欲/
ぎょうりつ /凝立/
ぎょうれつ /行列/
ぎょうれつえんざん /行列演算/
ぎょうれつがた /行列型/
ぎょうれつけいさん /行列計算/
ぎょうれつしき /行列式/
ぎょうれつせき /行列積/
ぎょうれつち /行列値/
ぎょうれつひょうげん /行列表現/
ぎょうれつりろん /行列理論/
ぎょえい /魚影/御影/
ぎょえん /御苑/魚塩/
ぎょか /御歌/魚蝦/
ぎょかい /魚介/魚貝/魚会/
ぎょかいるい /魚介類/
ぎょかく /漁獲/
ぎょかくりょう /漁獲量/
ぎょかん /御感/
ぎょがん /魚眼/
ぎょがんせき /魚眼石/
ぎょがんれんず /魚眼レンズ/
ぎょき /漁期/御忌/
ぎょきょう /漁協/漁況/
ぎょぎょう /漁業/
ぎょぎょうかんれん /漁業関連/
ぎょぎょうきょうどうくみあい /漁業協同組合/
ぎょぎょうくみあい /漁業組合/
ぎょぎょうけん /漁業権/
ぎょぎょうしげん /漁業資源/
ぎょぎょうそうぎょう /漁業操業/
ぎょぎょうほう /漁業法/
ぎょく /玉/漁区/嶷;(たかい)/閠;「閏」(うるう)の異体字,?/魚鼓/
ぎょく> /玉;(splendid) 玉酒,玉璽,玉門/
ぎょくおん /玉音/
ぎょくおんほうそう /玉音放送;[日本史]朕深ク世界ノ大勢ト帝国ノ現状トニ鑑ミ…/
ぎょくがん /玉顔/
ぎょくさい /玉砕/
ぎょくざ /玉座/
ぎょくしょう /玉将/玉漿/
ぎょくじ /玉璽/
ぎょくずい /玉髄/
ぎょくせい /玉成/
ぎょくせき /玉石/
ぎょくせきこんこう /玉石混淆/玉石混交/
ぎょくせん /玉泉/
ぎょくせんどう /玉泉洞/
ぎょくたい /玉体/
ぎょくだい /玉台/玉代/
ぎょくとう /玉東/玉頭/
ぎょくはい /玉杯/
ぎょくはく /玉帛/
ぎょくひ /玉臂;美人の肘。「一双の-」/
ぎょくへん /玉篇/
ぎょくもん /玉門/
ぎょくもんかん /玉門関/
ぎょくよう /玉葉;金枝-/
ぎょくりんじ /玉林寺/
ぎょくろ /玉露/
ぎょくろう /玉楼/
ぎょぐ /漁具/
ぎょぐん /魚群/
ぎょぐんたんちき /魚群探知機/
ぎょけい /魚形/御慶/
ぎょけいすいらい /魚形水雷;魚雷/
ぎょげんき /魚玄機/
ぎょこ /魚鼓/
ぎょこう /漁港/魚膠/
ぎょこうない /漁港内/
ぎょさん /魚山/
ぎょざ /御座/
ぎょし /御史/御旨/御寝/漁史;鴎外-/魚翅/
ぎょしゃ /御者/馭者;=御者/漁者;fisherman/
ぎょしゃざ /馭者座;Auriga(Aur)/
ぎょしゃだい /御者台/
ぎょしゅ /魚種/
ぎょしゅう /漁舟/
ぎょしょう /魚礁/魚醤/漁礁/
ぎょしょく /漁色/
ぎょしん /魚信/御寝/
ぎょじ /御璽/
ぎょじょう /漁場/
ぎょすい /魚水/
ぎょせい /御製/
ぎょせん /漁船/御撰/
ぎょそう /魚層/魚艙/魚倉/魚巣/
ぎょそん /漁村/
ぎょぞく /魚族/
ぎょたい /魚体/魚袋/
ぎょたく /魚拓/魚柝/
ぎょたん /魚探/
ぎょだい /御題/
ぎょちょう /魚鳥/
ぎょちょうどめ /魚鳥止め/
ぎょちょうひ /魚腸肥/
ぎょっかん /玉冠/
ぎょっき /玉器/
ぎょっけい /玉茎/
ぎょっこう /玉稿/玉鉤/
ぎょてい /魚梯/
ぎょでん /魚田/
ぎょと /魚肚/
ぎょとうゆ /魚灯油/
ぎょどう /魚道/魚動/
ぎょにく /魚肉/
ぎょにくせいひん /魚肉製品/
ぎょのう /魚脳/
ぎょのうちょうちん /魚脳提灯/
ぎょはん /魚飯/
ぎょば /漁場/
ぎょばん /魚板/
ぎょひ /魚肥/
ぎょひょう /魚鰾/
ぎょび /魚尾/
ぎょびょう /魚苗/
ぎょふ /漁夫/御府/魚符/
ぎょふく /魚腹/
ぎょふん /魚粉/
ぎょぶつ /御物/
ぎょべつ /魚鼈/
ぎょほう /漁法/
ぎょぼく /魚木/
ぎょみ /魚味/
ぎょみん /漁民/
ぎょめい /御名/
ぎょめいぎょじ /御名御璽/
ぎょもう /漁網/魚網/
ぎょもくえんせき /魚目燕石/
ぎょもつ /御物/
ぎょもん /魚文/魚紋/
ぎょゆ /魚油/
ぎょらい /魚雷/
ぎょらいてい /魚雷艇/
ぎょらいはっしゃかん /魚雷発射管/
ぎょらん /魚卵/魚籃/
ぎょらんかんのん /魚籃観音/
ぎょりゅう /魚龍/魚竜/
ぎょりょう /漁猟/御綾/魚綾/
ぎょりょうしゃくば /魚竜爵馬/
ぎょりん /魚鱗/
ぎょりんがかり /魚鱗懸り/魚鱗懸かり/
ぎょりんずさつ /魚鱗図冊/
ぎょりんせん /魚鱗癬/
ぎょるい /魚類/
ぎょるいじだい /魚類時代/
ぎょれい /魚麗/
ぎょれん /魚連/
ぎょろ /魚魯/
ぎょろう /漁労/漁撈;=漁労/魚蝋/
ぎょろめ /ぎょろ目/
ぎよう /儀容/偽葉;[植物]phyllode/
ぎようせい /偽陽性;†疾患にかかっていないのに陽性/疑陽性;†陽性に近い/擬陽性;†陽性に近い/
ぎらい /儀礼/
ぎり /義理/斬り/切/切り/
ぎりしあ /希臘;Gresia/
ぎりしあご /ギリシア語;ελληνικη/
ぎりしあしんわ /ギリシア神話/
ぎりしあてつがく /ギリシア哲学/
ぎりしゃ /希臘/
ぎりしゃご /ギリシャ語;ανερριφω κυβοσ/
ぎりしゃしんわ /ギリシャ神話/
ぎりしゃじん /ギリシャ人/
ぎりしゃせいきょうかい /ギリシャ正教会/
ぎりしゃてつがく /ギリシャ哲学/
ぎりしゃもじ /ギリシャ文字;αβγδε… →greek,Greek/
ぎりだて /義理立て/
ぎりちょこ /義理チョコ/
ぎりにんじょう /義理人情/
ぎりょう /技量/議了/技倆/
ぎりょうぶそく /技量不足/
ぎれ /裂/切/
ぎれい /儀礼/
ぎれいてき /儀礼的/
ぎれつ /義烈/
ぎれん /議連;議員連盟/技連/
ぎろう /妓楼/
ぎろん /議論/
ぎろんいぜん /議論以前/
ぎろんがい /議論外/
ぎろんけっか /議論結果/
ぎろんさんかしゃ /議論参加者/
ぎろんしゅうりょう /議論終了/
ぎろんじ /議論時/
ぎろんじょうきょう /議論状況/
ぎろんぜんたい /議論全体/
ぎろんちゅう /議論中/
ぎろんてき /議論的/
ぎろんひゃくしゅつ /議論百出/
ぎろんぶそく /議論不足/
ぎわ /際/羲和/
ぎわく /疑惑/
ぎわだん /義和団;[世界史] -事件/
ぎわだんじけん /義和団事件;[世界史](1900)/
ぎわん /義腕/
ぎん /銀/吟/岑;みね/垠/崟;(山の険しい様子)/憖;なまじ/Ag/Silver/斤/
ぎんいち /銀一/
ぎんいちろう /銀一郎/
ぎんいろ /銀色/
ぎんいろしゃ /銀色車/
ぎんうち /銀打/
ぎんえい /吟詠/
ぎんえいでん /銀英伝;銀河英雄伝説/
ぎんえん /銀塩/
ぎんえんしゃしん /銀塩写真/
ぎんか /銀貨/銀花/
ぎんかい /銀塊/
ぎんかいしょく /銀灰色/
ぎんかく /銀閣/
ぎんかくじ /銀閣寺/
ぎんかくじみち /銀閣寺道/
ぎんかん /銀漢;天の川/
ぎんが /銀河/
ぎんがうちゅう /銀河宇宙/
ぎんがえいゆうでんせつ /銀河英雄伝説/
ぎんがえんばん /銀河円盤/
ぎんがけい /銀河系/
ぎんがけいない /銀河系内/
ぎんがざひょう /銀河座標/
ぎんがだん /銀河団/
ぎんがちゅうしん /銀河中心/
ぎんがつうしん /銀河通信/
ぎんがていこく /銀河帝国/
ぎんがてつどう /銀河鉄道/
ぎんがてつどうのよる /銀河鉄道の夜;(1941)宮沢賢治/
ぎんがぶんぷ /銀河分布/
ぎんがまる /銀河丸/
ぎんがみ /銀紙/
ぎんがめん /銀河面/
ぎんき /銀器/
ぎんきょう /銀鏡/
ぎんきょうはんのう /銀鏡反応/
ぎんぎつね /銀狐/
ぎんぎょ /銀魚/
ぎんこう /銀行/吟行/銀鉱/銀坑/銀鉤/
ぎんこういん /銀行員;banker/銀行印/
ぎんこうか /銀行家/
ぎんこうかい /銀行界/
ぎんこうかぶ /銀行株/
ぎんこうかん /銀行間/銀交換/
ぎんこうがわ /銀行側/
ぎんこうぎょうむ /銀行業務/
ぎんこうけい /銀行系/
ぎんこうけん /銀行券/
ぎんこうこうざ /銀行口座/
ぎんこうごうとう /銀行強盗/
ぎんこうしんよう /銀行信用/
ぎんこうぜい /銀行税/
ぎんこうだん /銀行団/
ぎんこうちょきん /銀行貯金/
ぎんこうてがた /銀行手形;bank draft/
ぎんこうとりひき /銀行取引/
ぎんこうふつうこうざ /銀行普通口座/
ぎんこうふりかえ /銀行振替/
ぎんこうふりこみ /銀行振込/
ぎんこうほう /銀行法/
ぎんこうめい /銀行名/
ぎんこうよきん /銀行預金/
ぎんこんしき /銀婚式;25周年/
ぎんざ /銀座/
ぎんざいっちょうめ /銀座一丁目/
ぎんざえき /銀座駅/
ぎんざかん /銀座間/
ぎんざがい /銀座街/
ぎんざせん /銀座線/
ぎんざちか /銀座地下/
ぎんざどおり /銀座通/
ぎんざばし /銀座橋/
ぎんざほうめん /銀座方面/
ぎんざまつざかや /銀座松坂屋/
ぎんざまつや /銀座松屋/
ぎんざみつこし /銀座三越/
ぎんざん /銀山/
ぎんし /銀糸/
ぎんしゃ /銀砂/
ぎんしゃり /銀シャリ/銀舎利;白い御飯/
ぎんしゅ /銀朱/
ぎんしょう /銀賞/吟唱/銀将/銀章/吟誦/吟嘯/
ぎんしょく /銀燭/
ぎんしょっき /銀食器/
ぎんじ /銀次/銀二;名/銀地/銀字/
ぎんじょう /吟醸/
ぎんじょうしゅ /吟醸酒/
ぎんす /銀子/
ぎんすいしょう /銀水晶/
ぎんすじ /銀筋/
ぎんすなご /銀砂子/
ぎんずいしょう /銀水晶/
ぎんせい /銀製/吟声/銀星/
ぎんせかい /銀世界/
ぎんせつ /銀雪;silvery snow/
ぎんせん /銀泉/銀線/銀川/銀銭/
ぎんぞう /銀蔵/
ぎんだま /銀玉/
ぎんだまでっぽう /銀玉鉄砲/
ぎんだら /銀鱈/
ぎんでい /銀泥/
ぎんどけい /銀時計/
ぎんなん /銀杏/
ぎんねこ /銀猫;ラファエロ/
ぎんねず /銀鼠/
ぎんねずみ /銀鼠/
ぎんのさじ /銀の匙;silver spoon. 幸運の印/
ぎんはくしょく /銀白色/
ぎんば /銀歯/
ぎんばん /銀盤/
ぎんばんしゃしん /銀板写真;daguerreotype/
ぎんぱ /銀波/
ぎんぱい /銀杯/銀盃/
ぎんぱく /銀箔/
ぎんぱつ /銀髪/
ぎんぶち /銀縁;-眼鏡/
ぎんぶら /銀ブラ;銀座の散歩/銀ぶら/
ぎんぷん /銀粉/
ぎんぷんちょう /銀粉蝶/
ぎんべえ /銀兵衛/
ぎんほんい /銀本位/
ぎんぼし /銀星/
ぎんぽ /銀宝/
ぎんまく /銀幕/
ぎんみ /吟味/
ぎんむく /銀無垢/
ぎんめだりすと /銀メダリスト/
ぎんめだる /銀メダル/
ぎんめっき /銀鍍金/銀メッキ/
ぎんめん /銀面/
ぎんもくせい /銀木犀/
ぎんもじ /銀文字/
ぎんゆう /吟遊/
ぎんゆうしじん /吟遊詩人/
ぎんよく /銀翼/
ぎんらん /銀蘭/
ぎんりょうそう /銀竜草;[植物]/
ぎんりん /銀鱗/銀輪/銀鈴/
ぎんれい /銀嶺/銀鈴/
く /苦/区/句/九/躯;体躯/駆;駆動/駈;「駆」の旧字(人名用漢字)/驅;「駆」の旧字/嶇;崎嶇/區;「区」の旧字/狗;良狗/駒;こま/拘;拘置(こうち)/劬/怐;おそ・れる/枸;枸櫞酸/煦;あたた・める/鉤;かぎ/吼;獅子吼/孔;(呉音) あな/倶;倶楽部/貢;年貢/惧;危惧/懼;「惧」の異体字/瞿;おそ・れる/衢;ちまた/矩;規矩/吁;alas!/柧/窶;やつ・れる/来;(動詞活用形)/玖;(呉音)/垢;(呉音)垢穢/紅;(慣用音)真紅/鳩;(呉音) はと/桍;(呉音)/供;(呉音)供養/口;(呉音)口説/工;(呉音)石工/久;(呉音)久遠/宮;(呉音)宮内庁/庫;(呉音)庫裏/功;(呉音)功徳/９/
く> /九/区;-境,-制,-議会/
くーにゃん /姑娘/
くーぽんけん /クーポン券/
くーりー /苦力/
くい /杭/悔い/句意/杙;≒杭 (原義:牛馬を繋ぐクイ)/悔/久井/九位/
くいあげ /食い上げ/
くいあらため /悔い改め/
くいあわせ /食い合わせ/食い合せ/食合せ/
くいいじ /食い意地/
くいうち /杭打ち/
くいき /区域/
くいきそ /杭基礎/
くいきない /区域内/
くいきわり /区域割/
くいけ /食い気/
くいしろ /食い代/
くいしんぼう /食いしん坊/
くいずばんぐみ /クイズ番組/
くいぜ /杭/株;-を守る/
くいぞめ /食い初め/
くいたん /杭端/
くいだおれ /食い倒れ/
くいだめ /食い溜め/
くいちがい /食い違い/
くいで /食い出/
くいとう /杭頭/
くいどうらく /食道楽/食い道楽/喰い道楽/
くいな /水鶏/秧鶏/
くいにげ /食い逃げ/
くいのこし /食い残し/
くいぶち /食い扶持/食扶持/
くいぶん /食い分/
くいほうだい /食い放題/喰い放題/
くいもの /食い物/喰い物/
くいものや /食い物屋/
くいん /庫院/
くう /空/腔;(慣用音)口腔/φ;phi(空集合、の意)/劫;?/刧;「劫」の異体字,?/
くうあつ /空圧/
くうい /空位/空尉/
くういき /空域/
くうかい /空海/空界/空回/
くうかぶ /空株/
くうかん /空間/
くうかんおんきょう /空間音響/
くうかんかいぞうど /空間解像度/
くうかんかんかく /空間感覚/
くうかんきどう /空間軌道/
くうかんきょり /空間距離/
くうかんげいじゅつ /空間芸術;Raumkunst. 建築・彫刻など。⇔時間芸術/
くうかんこうりつ /空間効率/
くうかんしゅうはすう /空間周波数/
くうかんじく /空間軸/
くうかんじょう /空間上/
くうかんせい /空間性/
くうかんぜんたい /空間全体/
くうかんそうごさよう /空間相互作用/
くうかんち /空閑地/
くうかんちゅう /空間中/
くうかんてき /空間的/
くうかんでんか /空間電荷;[物理]space charge/
くうかんでんぱん /空間伝播/
くうかんない /空間内/
くうかんにんしき /空間認識/
くうかんは /空間波/
くうかんひずみ /空間歪/
くうかんぶんかつ /空間分割/
くうかんほう /空間法/
くうかんりょういき /空間領域/
くうかんろん /空間論/
くうが /空牙/
くうがん /空観/
くうき /空気/
くうきあっしゅくき /空気圧縮機/
くうきあつ /空気圧/
くうきあな /空気穴/
くうきおせん /空気汚染/
くうきかいめん /空気界面/
くうきかんげき /空気間隙/
くうきかんせん /空気感染/
くうきげん /空気源/
くうきこうかん /空気交換/
くうきじゅう /空気銃/
くうきせいじょうき /空気清浄機/空気清浄器/
くうきせいどう /空気制動/
くうきそう /空気層/
くうきちゅう /空気中/
くうきていこう /空気抵抗/
くうきでんち /空気電池;air battery/
くうきにんぎょう /空気人形/
くうきふじょうしき /空気浮上式/
くうきみつど /空気密度/
くうきょ /空虚/
くうきりきがく /空気力学;aerodynamics/
くうきりゅう /空気流/
くうきりょく /空気力/
くうぎょう /空行/
くうくうじゃくじゃく /空空寂寂/空々寂々/
くうくうばくばく /空空漠漠/空々漠々/
くうぐん /空軍/
くうぐんき /空軍機/
くうぐんきち /空軍基地/
くうけい /空閨/
くうけん /空拳/
くうげき /空隙/
くうげん /空言/
くうこう /空港/空孔;vacancy/
くうこうえき /空港駅/
くうこうかん /空港間/
くうこうきゅうこう /空港急行/
くうこうけんせつ /空港建設/
くうこうこうだん /空港公団/
くうこうしょくいん /空港職員/
くうこうしようりょう /空港使用料/
くうこうせん /空港線/
くうこうぜい /空港税/
くうこうちゃく /空港着/
くうこうない /空港内/
くうこうはつ /空港発/
くうこうはんたいは /空港反対派/
くうこうよていち /空港予定地/
くうこうりようきゃく /空港利用客/
くうこうりようりょう /空港利用料/
くうこうれんらく /空港連絡/
くうこく /空谷/
くうご /空語;内容をともなわない言葉/
くうさ /空佐/
くうさい /空際/
くうさつ /空撮/
くうし /空士/
くうしつ /空室/
くうしつじょうきょう /空室状況/
くうしつりつ /空室率/
くうしゃ /空車/
くうしゅう /空襲/
くうしゅうけいほう /空襲警報/
くうしゅうごう /空集合/
くうしょ /空所/
くうしょう /空将/
くうじ /空自/
くうじゃく /空寂/
くうせい /空制/
くうせき /空席/
くうせきあんない /空席案内/
くうせきじょうきょう /空席状況/
くうせつ /空説/空節/
くうせん /空戦/
くうぜん /空前/
くうぜんぜつご /空前絶後/
くうそ /空疎/
くうそう /空想/空曹/
くうそうか /空想家/
くうそうかがくしょうせつ /空想科学小説/
くうそうきょり /空走距離/
くうそうじょう /空想上/
くうそうてき /空想的/
くうそうてきしゃかいしゅぎ /空想的社会主義/
くうそうへき /空想癖/
くうそくぜしき /空即是色/
くうたい /空諦;[仏教]/
くうたいくう /空対空/
くうたいち /空対地/
くうだん /空談/
くうち /空地/
くうちゅう /空中/
くうちゅうけん /空中権;[法]/
くうちゅうさつえい /空中撮影/
くうちゅうしゃしん /空中写真/
くうちゅうせん /空中戦/空中線/
くうちゅうせんかん /空中戦艦/
くうちゅうせんでんりょく /空中線電力/
くうちゅうていえん /空中庭園/
くうちゅうぶつ /空中物/
くうちゅうぶらんこ /空中ブランコ/
くうちゅうぶんかい /空中分解/
くうちゅうほこう /空中歩行/
くうちゅうゆうえい /空中遊泳/
くうちゅうようさい /空中要塞/
くうちゅうろうかく /空中楼閣/
くうちょう /空調/空腸/
くうちょうおん /空調音/
くうちょうき /空調機/
くうちょうせつび /空調設備/
くうちょうそうおん /空調騒音/
くうちょうよう /空調用/
くうてい /空挺/
くうていだん /空挺団/
くうていぶたい /空挺部隊/
くうてがた /空手形;=からてがた/
くうてん /空転/
くうてんがわ /空転側/
くうてんじ /空転時/
くうてんぼうし /空転防止/
くうでん /空電/
くうとりひき /空取引/
くうどう /空洞/
くうどうか /空洞化/
くうどうかげんしょう /空洞化現象/
くうにゅうりょく /空入力/
くうねんぴ /空燃費/
くうはく /空白/　;全角スペース/
くうはくぎょう /空白行/
くうはくち /空白地/
くうはくぶぶん /空白部分/
くうはくもじ /空白文字/
くうばく /空爆/空漠/
くうばくちゅう /空爆中/
くうひ /空費/空飛/
くうびん /空便/
くうふく /空腹/
くうふくかん /空腹感/
くうふくじ /空腹時/
くうぶん /空文/
くうほう /空砲/空胞/空包/
くうぼ /空母/
くうぼうそう /空乏層/
くうぼせん /空母戦/
くうむ /空無/
くうめい /空名/
くうもじ /空文字/
くうもじれつ /空文字列/
くうや /空也;(903-972),僧侶/空夜;lonely night/
くうやくわず /食うや食わず/
くうゆ /空輸/
くうらん /空欄/
くうり /空理/
くうりき /空力/
くうりきかねつ /空力加熱;aerodynamic heating/
くうりきせいのう /空力性能/
くうりく /空陸/
くうりくうろん /空理空論/
くうりすと /空リスト/
くうりょくてき /空力的/
くうれい /空冷/
くうれいしき /空冷式/
くうれつ /空列/
くうろ /空路/
くうろん /空論/
くえ /九会;[仏教]/九絵/垢穢/柵/
くえい /区営/
くえき /苦役/駆役;追い立てて使う/
くえん /枸櫞/
くえんさん /枸櫞酸/クエン酸/
くおん /久遠/
くおんじつじょう /久遠実成/
くか /久賀/探湯/
くかい /句会/区会/苦界/苦海/
くかいぎいん /区会議員/
くかく /区画/区劃/
くかくず /区画図/
くかくせいり /区画整理/
くかた /久方/
くかたち /探湯/誓湯/
くかつよう /ク活用;形容詞の活用形態/
くかん /区間/躯幹/苦艱/
くかんうんてん /区間運転/
くかんえんちょう /区間延長/
くかんかいそく /区間快速/
くかんがい /区間外/
くかんきゅうこう /区間急行/
くかんきょり /区間距離/
くかんごと /区間毎/
くかんしき /区間式/
くかんたんしゅく /区間短縮/
くかんちょう /区間長/
くかんてき /区間的/
くかんとっきゅう /区間特急/
くかんない /区間内/
くかんぶんかつ /区間分割/
くかんへんこう /区間変更/
くかんゆうしょう /区間優勝/
くかんれっしゃ /区間列車/
くが /陸/久我/玖珂/玖賀/
くがい /区外/苦界/公界/
くがいそう /九蓋草/
くがく /苦学/
くがくせい /苦学生/
くがたち /探湯/誓湯/
くがつ /九月/９月/9月/長月;※連想,旧暦/
くがつひめ /九月姫/
くがみらくづめ /苦髪楽爪/
くがやま /久我山/
くがよしこ /久我美子/
くがら /句柄/
くき /茎/久喜/九鬼/莖/
くきざき /茎崎/
くきしゅうぞう /九鬼周造;(1888-1941)哲学者。『「いき」の構造』/
くきまきひげ /茎巻鬚/
くきもと /久木元/
くきゅう /区急/
くきょう /苦境/句境/
くぎ /釘/区議/供犠/
くぎあな /釘穴/
くぎうち /釘打/釘打ち/
くぎかい /区議会/
くぎかくし /釘隠し/
くぎし /釘師/
くぎせん /区議選/
くぎちょうせい /釘調整/
くぎづけ /釘付け/
くぎどめ /釘止め/
くぎに /釘煮/
くぎぬき /釘抜き/釘貫;簡素な柵/
くぎの /久木野/
くぎみや /釘宮/
くぎもと /釘本/
くぎょう /苦行/公卿/恭敬/
くぎり /区切り/区切/句切り/句切/
くぎりかた /区切り方/
くぎりし /区切り子/
くぎれ /句切れ/
くぎん /苦吟/
くく /区々/九九/区区/煦々/
くくりぞめ /纐/
くぐ /莎草/
くぐい /鵠/
くぐつ /傀儡/裹/
くぐつし /傀儡師/傀儡子;=傀儡師/
くぐつまわし /傀儡回し/
くぐつめ /傀儡女/
くぐの /久々野/
くぐりど /潜り戸/
くけい /矩形/区系;[生物]region/
くけいいき /矩形域/
くけいしつ /矩形室/
くけいは /矩形波/
くけいはんい /矩形範囲/
くけいばん /矩形板/
くけいまど /矩形窓/
くけいりょういき /矩形領域/
くけつ /口訣/
くけん /区検;[略語]区検察庁/
くけんさつちょう /区検察庁/
くげ /公家/公卿/久下/
くげがた /公家方/
くげぬま /鵠沼/
くげん /苦言/苦患/
くこ /枸杞/
くこう /句稿/
くこうぞう /句構造/
くこうぞうきそく /句構造規則/
くこうぞうぶんぽう /句構造文法/
くご /供御/箜篌;ハープ様の古楽器/
くごう /久郷/口業;[仏教]/
くごにん /供御人/
くごほう /ク語法;老ゆ→老いらく/く語法/
くさ /草/種/艸/日;?/
くさい /ξ;xi/Ξ;Xi/
くさいきれ /草いきれ/
くさいもの /臭い物/
くさいろ /草色/
くさうお /草魚/
くさえんじゅ /草槐/
くさお /草尾/
くさか /日下/久坂/
くさかい /草皆/草開/
くさかべ /日下部/
くさかり /草刈/草刈り/草苅/
くさかりがま /草刈り鎌/
くさかりき /草刈機/
くさかりば /草刈り場/
くさかんむり /草冠/
くさがき /草垣/
くさがみ /草上/
くさき /草木/
くさく /句作/
くさぐさ /種々/種種/
くさけいば /草競馬/
くさずもう /草相撲/
くさせんり /草千里/
くさぞうし /草双紙/
くさたいかい /草大会/
くさたけ /草丈/
くさだんご /草団子/
くさち /草地/
くさつ /草津/
くさつおんせん /草津温泉/
くさつこうげん /草津高原/
くさつごう /草津号/
くさつし /草津市/
くさつしてん /草津支店/
くさつしらね /草津白根/
くさつせん /草津線/
くさつどうろ /草津道路/
くさつぶし /草津節;[民謡]「チョイナチョイナ」/
くさつほうめん /草津方面/
くさとり /草取り/
くさなぎ /草薙/
くさなぎきゅうじょう /草薙球場/
くさなぎのつるぎ /草薙剣/
くさの /草野/
くさのしんぺい /草野心平;詩人。『定本蛙』/
くさのね /草の根/
くさのねみんしゅしゅぎ /草の根民主主義;grass-roots democracy/
くさのは /草の葉;Leaves of Grass(1855-1892), Whitman/
くさは /草葉/
くさはら /草原/
くさば /草場/草葉;-の陰/
くさばな /草花/
くさばのかげ /草葉の陰;-で喜んでおります/
くさび /楔/
くさびがた /楔形/
くさびがたもじ /楔形文字;シュメール/
くさびら /茸/菌/草片/
くさぶえ /草笛/
くさぶし /草臥し/
くさま /草間/日馬/
くさまくら /草枕/
くさみ /臭み/
くさみけし /臭み消し/
くさむしり /草毟り/
くさむら /叢/草叢/
くさめ /嚔/
くさもち /草餅/
くさや /草屋/
くさやきゅう /草野球/
くさやなぎ /草柳/
くさやね /草屋根;[建築]/
くさよもぎ /藾/
くさり /鎖/鏈/
くさりあみ /鎖編み/
くさりかたびら /鎖帷子/
くさりがま /鎖鎌/
くさりじょう /鎖状/
くされ /腐れ;-極道,-縁/
くされえん /腐れ縁/
くされげどう /腐れ外道/
くさわい /種/
くさわけ /草分け/草分/
くざい /句材/
くし /串/駆使/櫛/口四;[仏教]妄語・綺語・悪口・両舌/句誌/苦死/苦使;≒酷使/口詩/酒/髪/梳;くしけずる?/
くしー /ξ;xi/Ξ;Xi/
くしあげ /串揚げ/
くしかつ /串カツ/
くしがた /櫛形/櫛型/
くしがはま /櫛ケ浜/
くしきの /串木野/
くしくも /奇しくも/
くしくらげ /櫛水母/
くしげ /櫛笥/
くしさし /串刺/
くしざし /串刺し/串刺/くし刺し/
くしだ /櫛田/串田/
くしだんご /串団子/
くしてい /区指定/
くしなだひめ /奇稲田姫/
くしはら /串原/櫛原/
くしびき /櫛引/
くしま /串間/久嶋/
くしまうみ /久島海/
くしめ /櫛目/
くしもと /串本/
くしもとぶし /串本節;[民謡]和歌山/
くしゃ /倶舎/
くしゃみ /嚔/
くしゃろん /倶舎論/
くしやき /串焼き/串焼/
くしやま /串山/
くしゅう /句集/
くしょ /区処/
くしょう /苦笑/
くしら /串良/
くしりょうり /串料理/
くしろ /釧路;地名,北海道/釧;古墳時代の腕輪/
くしろえき /釧路駅/
くしろこうせん /釧路高専/
くしろしつげん /釧路湿原/
くしろしつげんえき /釧路湿原駅/
くしん /苦心/苦辛/
くしんさんたん /苦心惨憺/
くしんだん /苦心談/
くじ /久慈/籤;lottery/鬮;≒籤/公事/九字;[仏教]臨兵闘者皆陳列在前/九時/籖;「籤」の異体字/
くじうん /籤運/くじ運/
くじかた /公事方/
くじかたおさだめがき /公事方御定書/
くじしょう /久慈商/
くじせん /久慈線/
くじびき /籤引き/くじ引き/
くじまと /鬮的/
くじゃく /孔雀/
くじゃくざ /孔雀座;Pavo(Pav)/
くじゃくみょうおう /孔雀明王/
くじゅ /口授/
くじゅう /苦渋/苦汁/久住/
くじゅうくり /九十九里/
くじゅうくりはま /九十九里浜/
くじょ /駆除/
くじょう /苦情/九条/宮絛/
くじょうしゃこ /九条車庫/
くじょうしょり /苦情処理/
くじょうやま /九条山/
くじょほう /駆除法/
くじら /鯨/鯀;?/
くじらあぶら /鯨油/
くじらい /鯨井/
くじらおか /鯨岡/
くじらざ /鯨座;Cetus(Cet)/
くじらじゃく /鯨尺/
くじらじる /鯨汁/
くじらひげ /鯨鬚/
くじらまく /鯨幕/
くじらりょうり /鯨料理/
くじん /苦参/
くす /楠/樟/玖珠;地名,大分/
くすいこ /公出挙;[律令制]国による出挙/
くすう /句数/
くすおか /楠岡/
くすこ /薬子/
くすし /薬師/
くすだ /楠田/
くすだま /薬玉/くす玉/
くすね /薬煉/天鼠矢/藥煉/
くすのき /楠/楠木/樟/
くすのきあか /クスノキ亜科/Lauroideae/
くすのきか /クスノキ科/Lauraceae/
くすのきまさしげ /楠木正成/楠正成/
くすのせ /楠瀬/
くすのは /樟葉/
くすのはえき /樟葉駅/
くすのもり /楠ノ森;姓/
くすはら /楠原/
くすび /鐃/
くすみ /楠見/
くすもと /楠本/楠元/
くすやま /楠山/
くすり /薬/藥/
くすりうり /薬売り/
くすりがけ /釉掛け/釉掛/
くすりし /薬師/
くすりづけ /薬漬け/
くすりのつかさ /典薬寮;[律令制]/薬司;[律令制]/
くすりばこ /薬箱/
くすりぶくろ /薬袋/
くすりぶろ /薬風呂/
くすりみず /薬水/
くすりや /薬屋/
くすりゆ /薬湯;やくとう/
くすりゆび /薬指/
くすんごぶ /九寸五分/
くず /屑/葛/
くずいと /屑糸/
くずいも /葛芋/
くずう /葛生/
くずおか /葛岡/
くずかご /屑籠/屑篭;「籠」異体字/
くずきじ /屑記事/
くずきり /葛切り/葛切/
くずこ /葛粉/
くずごめ /屑米/
くずしがき /崩し書き/
くずしじ /崩し字/
くずてつ /屑鉄/
くずてつや /屑鉄屋/
くずは /楠葉/葛葉/
くずはら /葛原/
くずひろい /屑拾い/
くずまい /屑米/
くずまき /葛巻/
くずみ /久住/
くずもち /葛餅/
くずもの /屑物/
くずや /屑屋/
くずゆ /葛湯/
くずりゅう /九頭竜/
くずりゅうがわ /九頭竜川/
くずりゅうこ /九頭竜湖/
くずれ /崩れ/
くせ /癖/曲/救世;[仏教]救済。(観世音)菩薩。/久世;地名/
くせい /区政/
くせげ /癖毛/くせ毛/
くせごと /曲事/
くせつ /苦節/
くせなおし /癖直し/
くせぼさつ /救世菩薩/
くせまい /曲舞/
くせもの /曲者/癖者;<rare> =曲者/
くせん /苦戦/
くせんちゅう /苦戦中/
くせんてい /駆潜艇/
くせんひっし /苦戦必至/
くぜ /久世/久瀬/
くぜち /口説/
くぜつ /口説/口舌/
くそ /糞/屎/
くそ> /糞;糞力,糞度胸,糞真面目/
くそう /九相;[仏教]『-詩絵巻』/九想;[仏教]/
くそがき /糞餓鬼/糞ガキ/
くそたれ /糞垂れ;うんこを垂れる人/
くそぢから /糞力/クソ力/
くそどきょう /糞度胸/
くそばえ /糞蠅;-も羽ばたき/
くそぶくろ /糞袋;人間/
くそまじめ /糞真面目/クソ真面目/
くそみそ /糞味噌/
くそむし /糞虫/
くたい /躯体/苦諦/
くたかけ /鶏/
くたにやき /九谷焼/
くたばりぞこない /くたばり損ない/
くたびれもうけ /草臥れ儲け;骨折り損の-/
くたんもん /狗蜑門/
くだ /管/
くだい /句題/
くだぎつね /管狐/
くだけ /砕け/
ください /下さい/
くだされたく /被下度/
くだされもの /下され物/
くだしぐすり /下し薬/
くだしぶみ /下文/
くだたま /管玉/
くだばしら /管柱/
くだまつ /下松/
くだもの /果物/
くだものないふ /果物ナイフ/
くだものや /果物屋/
くだら /百済/百濟/
くだらご /百済語/
くだり /下り/件/条/
くだりげぎょ /降り懸魚/
くだりざか /下り坂/
くだりせん /下り線/
くだりむね /降り棟/
くだん /九段/件/
くだんきた /九段北/
くだんこうこう /九段高校/
くだんした /九段下/
くだんしたえき /九段下駅/
くち /口/
くちあたり /口当たり/口当り/
くちいがい /口以外/
くちいれ /口入れ/
くちいれや /口入れ屋;女衒など/
くちうつし /口移し/
くちうら /口裏/口占/
くちえ /口絵/
くちおも /口重/
くちかず /口数/
くちかせ /口枷/
くちがき /口書/
くちがため /口固め/
くちがたり /口語り/
くちがね /口金/
くちがる /口軽/
くちき /朽木/朽ち木/口木/
くちきき /口利き/
くちきり /口切り/
くちく /駆逐/苦竹;=にがたけ=真竹/
くちくかん /駆逐艦/
くちくせんしゃ /駆逐戦車/
くちぐせ /口癖/口ぐせ/
くちぐち /口々/
くちぐるま /口車/
くちげんか /口喧嘩/
くちことば /口詞/口言葉/
くちこみ /口コミ/
くちごたえ /口答え/
くちさき /口先/吻/
くちざわり /口触り/
くちしのぎ /口凌ぎ/
くちじお /口塩/
くちじゃみせん /口三味線/
くちじょうず /口上手/
くちすう /口数/
くちすぎ /口過ぎ/
くちせん /口銭/
くちぞえ /口添え/
くちた /口田/
くちたっしゃ /口達者/
くちだし /口出し/
くちだっしゃ /口達者/
くちづけ /口づけ/口付け;kiss/
くちづたえ /口伝え/
くちづて /口伝て/口伝/
くちとり /口取/
くちど /口疾/
くちどけ /口溶け/
くちどめ /口止め/
くちどめりょう /口止め料/
くちなおし /口直し/
くちなし /梔子/梔/山梔子/口無し;死人に-/
くちなしいろ /梔子色/
くちならし /口慣らし/
くちなわ /蛇/
くちぬの /口布/
くちのつ /口之津/
くちのは /口の端/朽葉/
くちのまち /口ノ町/
くちは /朽葉/
くちはっちょう /口八丁;-手八丁/
くちはっちょうてはっちょう /口八丁手八丁/
くちば /朽葉/朽ち葉/
くちばいろ /朽葉色/
くちばし /嘴/喙/
くちばや /口早/
くちぱく /口パク/
くちひげ /口髭/髭/
くちび /口火/
くちびょうし /口拍子/
くちびる /唇/脣;=唇/口唇/
くちふうじ /口封じ/
くちぶえ /口笛/
くちぶり /口振り/口ぶり/
くちへん /口偏/
くちへんとう /口返答/
くちべた /口下手/
くちべに /口紅/
くちべらし /口減らし/
くちほど /口程/口ほど/
くちまえ /口前/
くちまかせ /口任せ/
くちまね /口真似/
くちむろ /口むろ/
くちもと /口元/口許/
くちゃ /苦茶/
くちやくそく /口約束/
くちゅう /駆虫/苦衷/
くちゅうざい /駆虫剤/
くちゅうやく /駆虫薬;antiparasitic/
くちょう /口調/区長/句調;俳句の-/
くちよごし /口汚し/
くちよせ /口寄せ/
くちわ /口和/
くちわき /口脇/
くちわる /口悪/
くっき /崛起/
くっきょう /屈強/究竟/倔強;=屈強/
くっきょく /屈曲/
くっきょくしき /屈曲式/
くっきょくは /屈曲波/
くっきょくぶ /屈曲部/
くっきん /屈筋/
くっこうせい /屈光性/
くっさく /掘削/掘鑿/
くっさくき /掘削機/
くっさめ /嚔/
くっし /屈指/
くっしゃろこ /屈斜路湖/
くっしん /屈伸/掘進/
くっせい /屈性/
くっせつ /屈折/
くっせついじょう /屈折異常/
くっせつけい /屈折計;refractometer/
くっせつご /屈折語;[言語]inflectional language/
くっせつしき /屈折式/
くっせつりつ /屈折率/
くっそう /屈葬/
くったく /屈託/
くっちせい /屈地性/
くっちゃん /倶知安/
くっぷく /屈服/屈伏/
くつ /靴/沓;≒靴/履;≒靴/鞋;≒靴/屈;前屈/掘;発掘/窟;洞窟/倔/崛;崛起/
くつあと /靴跡/
くつう /苦痛/
くつおと /靴音/
くつかけ /沓掛/
くつかぶり /沓冠;最初と最後の字/
くつかむり /沓冠;=くつかぶり/
くつかわ /沓川/
くつがた /沓形/靴型/
くつき /朽木/
くつこ /口籠/
くつこうぶり /沓冠;=くつかぶり/
くつさわ /沓沢/
くつざわ /沓澤/沓沢/
くつした /靴下/くつ下/沓下/
くつしたどめ /靴下留め/
くつじゅう /屈従/
くつじょく /屈辱/
くつじょくせん /屈辱戦/
くつじょくてき /屈辱的/
くつじょくど /屈辱度/
くつずれ /靴擦れ/
くつぞこ /靴底/
くつてん /靴店/
くつね /狐/
くつばこ /靴箱/
くつばみ /轡/
くつひも /靴紐/
くつみ /久津見/九津見/
くつみがき /靴磨き/
くつや /靴屋/
くつわ /轡/銜/
くつわだ /轡田/
くつわむし /轡虫;がちゃがちゃ/
くづめらくがみ /苦爪楽髪/
くてん /句点;「。」/区点;-コード/九天;-の高き/
くてんこーど /区点コード/
くで /湫/
くでん /口伝/
くとう /苦闘/句読/久東/
くとうじょ /旧唐書;二十四史/
くとうてん /句読点/
くとうてんきごう /句読点記号/
くとうほう /句読法/
くど /苦土;酸化マグネシウム. (<Bittererde)/
くどう /駆動/工藤/宮藤/久道/区道/
くどうおん /駆動音/
くどうかいろ /駆動回路/
くどうかん /駆動艦/
くどうがた /駆動型/
くどうがわ /駆動側/
くどうけい /駆動系/
くどうげん /駆動源/
くどうし /句動詞/
くどうじかん /駆動時間/
くどうじく /駆動軸;モーターの-/
くどうそうち /駆動装置/
くどうてん /駆動点/
くどうぶ /駆動部/
くどうぶぶん /駆動部分/
くどうほうしき /駆動方式/
くどうめん /駆動面/
くどうりつ /駆動率/
くどうりょく /駆動力/
くどうりん /駆動輪/
くどお /久遠/
くどき /口説き/
くどきかた /口説き方/
くどきぶし /口説節;俗謡/
くどきもんく /口説き文句/
くどく /功徳/
くどせっかい /苦土石灰/
くどやま /九度山/
くどん /瞿曇;Gotama/
くない /区内/宮内/工内/苦無/
くないきょう /宮内卿/
くないしょう /宮内省/
くないちょう /宮内庁/
くながい /婚/
くなこく /狗奴国/
くなしり /国後/
くなり /九那里/
くなん /苦難/
くに /国/邦/訓;=くん/圀;「国」の異体字/國;「国」の旧字(人名用漢字)/六合;地名/久邇/
くにあき /邦明/邦昭/国昭/国明/
くにい /国井/國井/
くにいっき /国一揆/
くにいり /国入り/
くにうみ /国生み/
くにえだ /国枝/國枝/
くにお /邦夫/邦雄/邦男/国男/国夫/国雄/國雄/邦生/久仁雄/邦央/
くにおもて /国表/
くにかず /邦和/
くにかた /國方/
くにかね /国包/
くにがえ /国替/国替え/
くにがまえ /国構え/
くにがみ /国頭/
くにがら /国柄/
くにがろう /国家老/
くにがわ /国側/
くにきだ /国木田/
くにきだどっぽ /国木田独歩/
くにきょうかい /国協会/
くにく /苦肉;敵をだますために自身を傷つけること/狗肉/
くにくのさく /苦肉の策/
くにぐに /国々/
くにこ /邦子/久仁子/くに子/都子/
くにこう /国高/
くにことば /国言葉/
くにさか /国坂/
くにさき /国東/
くにさだ /国貞/國貞/
くにさわ /国沢/
くにざかい /国境/
くにざね /国実/
くにざむらい /国侍/
くにしげ /国重/
くにしま /国島/
くにしゅどう /国主導/
くにじ /邦次/
くにじま /国島/
くにじゅう /国中/
くにせん /国線/
くにぜんたい /国全体/
くにたいこう /国対抗/
くにたち /国立/
くにたちおんがくだいがく /国立音楽大学/
くにたちおんだい /国立音大/
くにたちかん /国立間/
くにたちこうこう /国立高校/
くにたちし /国立市/
くにたちしない /国立市内/
くにたちてん /国立店/
くにたみ /国民/国人/
くにだ /国田/
くにつかみ /国津神/国つ神/地祇/
くにつつみ /国つ罪/
くにつな /国綱/
くにづくり /国造り/
くにてがた /国手形/
くにとみ /国富/
くにとも /国友/國友/邦朋/
くにとり /国取り/
くにとりものがたり /国盗物語/
くになまり /国訛り/国訛/
くになり /邦成/
くにのとこたちのみこと /国常立尊;神様/
くにのぶ /国信/
くにのみや /久邇宮/
くにのみやつこ /国造/
くにはま /国浜/
くにはる /邦治/邦明/
くにばんごう /国番号/
くにひこ /邦彦/国彦/國彦/
くにひさ /邦久/国久/
くにひと /邦仁/
くにひろ /国広/邦洋/邦宏/国博/訓弘/
くにびと /国人/
くにふじ /國藤/
くにふみ /邦文/
くにぶり /国振り/国風/
くにべつ /国別/
くにべつたいこうせん /国別対抗戦/
くにまさ /国政/邦匡/
くにまつ /國松/
くにまつり /国祭;賀茂神社/
くにみ /国見/
くにみがおか /国見ヶ丘/
くにみだけ /国見岳/
くにみつ /国光/國光/州光;名/
くにむね /國宗/
くにもち /国持/
くにもと /国本/
くにものがたり /国物語/
くにやき /国焼/
くにやしょてん /国屋書店/
くにやす /国安/國安/国泰/
くにゆき /邦之/
くにゆずり /国譲り/
くによし /国吉/國吉/邦義/國義/
くぬが /陸/
くぬぎ /櫟/椚/橡/檪/功刀/櫪/椡/椢/椪/栩/功力;??/
くねつ /苦熱/
くねん /九年/
くねんぼ /九年母;ミカン科/
くの /久野/
くのいち /くノ一/
くのう /苦悩/久能/功能;[仏教]/
くのうざん /久能山/
くのぎ /櫟/
くのくら /玄倉/
くのじてん /くの字点/
くのへ /九戸/
くはい /苦杯/
くはら /久原/
くば /久場/玖場/
くひ /句碑/
くび /首/頸;=頚 (字義:「首」は頭を含むが「頸」は含まない)/頚;=頸/馘;解雇/馘首/
くびおけ /首桶/
くびかざり /首飾り/首飾/頸飾り/珞/
くびかせ /首枷/
くびき /軛/頚城;地名,新潟/
くびきり /首切り/首切/
くびくくり /首縊り/
くびさ /首差/
くびしめ /首締/
くびじっけん /首実検/
くびす /踵/跟/
くびすじ /首筋/
くびぞくちょう /狗尾続貂/
くびったけ /首っ丈/首ったけ/
くびっぴき /首っ引き/
くびつり /首吊り;-自殺/首吊/
くびづか /首塚/
くびなが /首長/
くびながりゅう /首長竜/
くびなげ /首投げ/
くびね /首根/
くびねっこ /首根っこ/首根っ子;首筋/
くびひき /首引;(狂言)/首引き/
くびひねり /首捻り/
くびふり /首振り/
くびまわり /首回り;[服飾]/頸廻り/
くびら /宮毘羅/
くびれ /括れ/
くびわ /首輪/
くふう /工夫/句風/
くふうしだい /工夫次第/
くぶ /区部;「区」で呼ばれる地域。「東京都-」(23区内のこと)/九分/
くぶくりん /九分九厘/
くぶん /区分/
くぶんしつ /区分室/
くぶんしょゆう /区分所有/
くぶんず /区分図/
くぶんせん /区分線/
くぶんてき /区分的/
くぶんでん /口分田/
くぶんほう /区分法/
くへ /柵/
くへんとう /苦扁桃/
くべつ /区別/
くべつなし /区別無し/
くほう /句法/
くほんぶつ /九品仏/
くぼ /久保/窪/凹/玖保/
くぼう /公方/久宝/
くぼかわ /窪川/久保川/
くぼがみ /久保上/
くぼき /久保木/
くぼさわ /久保沢/
くぼしょてん /久保書店/
くぼた /久保田/窪田/
くぼたうつぼ /窪田空穂;歌人/
くぼたとしのぶ /久保田利伸/
くぼち /窪地/くぼ地/
くぼづか /窪塚;姓/
くぼでら /久保寺/窪寺/
くぼの /窪野/
くぼや /窪谷/
くぼやま /久保山/
くま /熊;bear/隈;-なく/球磨/久万/
くまい /熊井/
くまいざさ /九枚笹/
くまいし /熊石/
くまいでん /供米田/
くまがい /熊谷/
くまがいぐみ /熊谷組;[企業名]/
くまがね /熊ヶ根/
くまがや /熊谷/
くまがやこう /熊谷工/
くまがわ /球磨川/
くまくす /熊楠/
くまくら /熊倉/
くまぐす /熊楠/
くまげ /熊毛/
くまげら /熊啄木鳥/
くまこう /熊公/
くまさか /熊坂/
くまさき /熊崎/
くまさわ /熊沢/
くまざさ /熊笹/隈笹/
くまざわ /熊沢/
くまぜみ /熊蝉/
くまそ /熊襲/
くまたか /熊鷹/
くまだ /熊田/隈田/
くまだい /熊大/
くまつづら /熊葛/
くまつづらか /クマツヅラ科/
くまで /熊手/
くまとり /熊取/
くまどり /隈取り/
くまなく /隈無く/隈なく/
くまねこ /熊猫/
くまの /熊野/
くまのい /熊胆/熊の胆/
くまのかいどう /熊野街道/
くまのがわ /熊野川/
くまのじんじゃ /熊野神社/
くまのせん /熊野線/
くまのなだ /熊野灘/
くまのもうで /熊野詣で/
くまはち /熊八/
くまばち /熊蜂/
くまもと /熊本/隈本;人名/
くまもとえきまえ /熊本駅前/
くまもとかん /熊本間/
くまもとけん /熊本県/
くまもとけんしょくいん /熊本県職員/
くまもとこくぜいきょく /熊本国税局/
くまもとご /熊本語/
くまもとし /熊本市/
くまもとしえい /熊本市営/
くまもとしない /熊本市内/
くまもとしりつ /熊本市立/
くまもとじょう /熊本城/
くまもとだい /熊本大/
くまもとだいがく /熊本大学/
くまもとでんてつ /熊本電鉄/
くまもとでんぱこうせん /熊本電波高専/
くまもとべん /熊本弁/
くまやま /熊山/
くまらじゅう /鳩摩羅什;(344-413) Kumarajiva/
くまんばち /熊ん蜂/
くみ /組/苦味/与/久美/公美/
くみあい /組合/
くみあいいん /組合員/
くみあいいんいがい /組合員以外/
くみあいいんしょう /組合員証/
くみあいかつどう /組合活動/
くみあいかんけい /組合関係/
くみあいけいやく /組合契約/
くみあいひ /組合費/
くみあいれんごうかい /組合連合会/
くみあげ /組み上げ/組上げ/九美上/
くみあわせ /組み合わせ/組合せ/組み合せ/
くみあわせろん /組合せ論/
くみいれ /組入れ/
くみいん /組員/
くみうた /組歌/
くみえ /久美恵/
くみおき /汲み置き;-の水/汲置き/
くみかえ /組み換え/組み替え/組換え/組替え/
くみかた /組み方/
くみがしら /組頭/
くみきょく /組曲/
くみきょくばん /組曲版/
くみこ /久美子/公美子/クミ子/玖海子/
くみこみ /組み込み/組込/
くみこみかた /組み込み方/
くみこみかんすう /組み込み関数;[電算]built-in function/
くみこみがた /組み込み型/
くみこみじ /組込時/
くみした /組下/
くみしゃしん /組写真/
くみたい /組対/
くみたいそう /組体操/
くみたて /組立/組み立て/組立て/
くみたてこう /組立工/
くみたてしき /組立式/
くみたてじょほう /組立除法/
くみたてせつめいしょ /組立説明書/
くみたてたんい /組立単位/
くみだし /汲み出し/
くみちがい /組み違い/
くみちょう /組長/
くみつ /口密/
くみつけ /組付/組み付け/組付け/
くみて /組み手/組手/
くみてがた /組手形/
くみとり /汲み取り/
くみとりしき /汲み取り式/
くみとりべんじょ /汲み取り便所/
くみはば /組幅/
くみはま /久美浜/
くみはん /組版/組み版/
くみはんじ /組版時/
くみばん /組版/
くみひも /組紐/
くみみほん /組見本/
くみめい /組名/
くみもの /組物/
くみやしき /組屋敷/
くみやま /久御山/
くみわけ /組み分け/組分け;grouping/
くみん /区民/
くみんかいかん /区民会館/
くみんぜい /区民税/
くむら /久村/
くめ /久米/粂/
くめあい /久米愛/
くめい /区名/苦鳴/
くめうた /久米歌/
くめうち /粂内/
くめがわ /久米川/
くめじま /久米島/
くめた /久米田/
くめだ /久米田/
くめなん /久米南/
くめの /粂野/
くめのせんにん /久米の仙人/
くめひろし /久米宏/
くめん /工面/
くも /雲/蜘蛛/蜘/
くもあし /雲脚/
くもあひ /雲合/
くもい /雲井/雲居/
くもいのかり /雲井の雁;[源氏物語]/
くもおとこ /蜘蛛男/
くもかすみ /雲霞/
くもがくれ /雲隠れ/雲隠/
くもがた /雲形/
くもがたじょうぎ /雲形定規/雲型定規/
くもがみ /雲紙/
くもきり /雲霧/
くもすけ /雲助/
くもつ /供物/貢物/
くもとりやま /雲取山/
くものい /雲乃井/
くものいと /蜘蛛の糸;芥川/
くものうえ /雲の上;-のお方/
くものうえびと /雲の上人;[文語]殿上人/
くものこ /蜘蛛の子;-を散らす/
くものす /蜘蛛の巣/クモの巣/
くもま /雲間/
くもまく /蜘蛛膜/くも膜/クモ膜/
くもまくかしゅっけつ /蜘蛛膜下出血/クモ膜下出血/
くもゆき /雲行き/雲行/
くもり /曇り/曇/
くもりごえ /曇り声/
くもりぞら /曇り空/
くもりどめ /曇り止め/
くもん /苦悶/公文/久門/
くもんしき /公文式/
くもんじょ /公文所/
くやく /旧訳/
くやくしょ /区役所/
くやくしょどおり /区役所通り/
くやし /悔し/
くやしなき /悔し泣き/
くやしなみだ /悔し涙/
くやしまぎれ /悔し紛れ/
くやま /久山/
くやみ /悔やみ/悔み/
くやみごと /悔み言/
くゆう /区有/
くゆうち /区有地/
くよう /供養/九曜/
くようさい /供養祭/
くようせい /九曜星;七曜と羅ゴ・計都/
くようとう /供養塔/
くら /蔵/倉/鞍;saddle/庫/藏;「蔵」の旧字(人名用漢字)/峅;(谷)/
くらあく /暗悪/
くらい /位/
くらいあんとがわ /クライアント側/
くらいし /倉石/
くらいだおれ /位倒れ/
くらいどり /位取り/
くらいまけ /位負け/
くらいり /蔵入/
くらいれ /倉入/
くらうち /蔵内/
くらうつし /倉移/
くらうど /蔵人/
くらかけ /倉掛/
くらかげ /鞍掛/
くらかた /倉方/倉片/
くらがえ /鞍替え/鞍替/
くらがり /闇/暗がり/
くらがりとうげ /暗峠;地名,/
くらき /倉木;姓/
くらく /苦楽/
くらくえんぐち /苦楽園口/
くらげ /海月/水母/鮓;NB:別訓「すし」/
くらさ /暗さ/
くらさき /倉崎/
くらさわ /倉沢/
くらざらえ /蔵浚え/
くらし /暮らし/暮し/
くらしき /倉敷/
くらしきし /倉敷市/
くらしきりょう /倉敷料/
くらしげ /倉重/倉茂/
くらした /蔵下/
くらしっくおんがく /クラシック音楽;classical music/
くらしな /倉品/
くらしぶり /暮らし振り/
くらしま /倉島/
くらしむき /暮らし向き/暮し向き/
くらすかい /クラス会;同窓会/
くらすがえ /クラス替え/
くらすたーばくだん /クラスター爆弾/
くらすべつ /クラス別/
くらた /倉田/蔵田/鞍田/
くらたけ /倉岳/
くらたや /蔵田家/
くらだし /蔵出し/庫出し;<rare>/
くらち /倉知/
くらづくり /蔵造り/
くらて /鞍手/
くらてぐん /鞍手郡/
くらとみ /倉富/
くらに /倉荷/
くらにしょうけん /倉荷証券/
くらの /蔵野/
くらのうち /蔵之内/
くらのすけ /内蔵助/
くらはし /倉橋/
くらはら /倉原/
くらばらい /蔵払い/
くらびらき /蔵開き/
くらふとし /クラフト紙/
くらぶ /倶楽部/
くらぶいん /クラブ員/倶楽部員/
くらぶかつどう /クラブ活動;club activities/
くらぶけい /クラブ系/
くらぶち /倉淵/
くらべ /倉部/
くらべもの /比べ物/較べ物/
くらぼね /鞍橋/
くらま /鞍馬/蔵間/
くらまい /蔵米/
くらまえ /蔵前/藏前/
くらまえかん /蔵前間/
くらまえこくぎかん /蔵前国技館/
くらまごけ /鞍馬苔/
くらません /鞍馬線/
くらまた /倉又/
くらまち /蔵町/
くらまてんぐ /鞍馬天狗/
くらまやま /鞍馬山/
くらめ /暗め/
くらもち /倉持/
くらもと /蔵元/倉本/蔵本/倉元/
くらもとまさひろ /倉本昌弘/
くらやしき /蔵屋敷/
くらやみ /暗闇/
くらよし /倉吉/
くらら /苦参/
くらわたし /倉渡し/
くらんど /蔵人/
くり /栗/庫裏/庫裡/涅/繰/繰り/
くりーにんぐし /クリーニング師;国家資格/
くりーにんぐや /クリーニング屋/
くりーむいろ /クリーム色;淡黄色/
くりーむじょう /クリーム状/
くりーむに /クリーム煮;鷄の-/
くりあげ /繰り上げ/繰上げ/
くりあげとうせん /繰り上げ当選/繰上げ当選/
くりあん /栗餡/栗あん/
くりいし /栗石/
くりいれ /繰入/繰入れ/
くりいれがく /繰入額/
くりいろ /栗色;焦茶色/涅色;黒(褐)色/
くりうめ /栗梅/
くりお /栗生/
くりかえ /繰替え/
くりかえし /繰り返し/繰返し/繰りかえし/々;漢字/ゝ;ひらがな/ゞ;ひらがな、濁点つき/ヽ;カタカナ/ヾ;カタカナ、濁点つき。「スヾ(スズ)」/〃;文単位/仝;同上/
くりかた /栗形/
くりかのこ /栗鹿の子/
くりから /倶利伽羅/倶利迦羅/
くりからもんもん /倶利迦羅紋紋;入れ墨/
くりき /功力/
くりきんとん /栗金団/
くりげ /栗毛/
くりここくさい /栗子国際/
くりこし /繰越/繰り越し/繰越し/
くりこしがく /繰越額/
くりこしきん /繰越金/
くりこしそんえき /繰越損益/
くりことば /繰り言葉/繰言葉/
くりこま /栗駒/
くりごと /繰り言/繰言/
くりごはん /栗御飯/栗ご飯/
くりさげ /繰下げ/
くりさわ /栗沢/
くりしま /栗島/
くりす /栗栖/
くりすますしょうせん /クリスマス商戦/
くりすますろーずあか /クリスマスローズ亜科/Helleboroideae/
くりた /栗田/栗太/
くりっくかん /クリック感/
くりつ /区立/栗津/
くりつとしょかん /区立図書館/
くりど /繰り戸/
くりねずみ /栗鼠/
くりの /栗野/
くりのべ /繰延/繰り延べ/繰延べ/
くりのべかんじょう /繰延勘定/
くりのべしさん /繰延資産;創立費、試験研究費、新株発行費用など、一度に計上せずに数年間かけて費用として計上する費用/
くりはし /栗橋/
くりはま /久里浜/
くりはまおき /久里浜沖/
くりはら /栗原/久利原/
くりはらこまき /栗原小巻/
くりはらでんてつ /栗原電鉄/
くりはらん /栗葉蘭/
くりばやし /栗林/
くりひろい /栗拾い/
くりぷとん /Kr/Krypton/
くりまんじゅう /栗饅頭/
くりみあせんそう /クリミア戦争/
くりめし /栗飯/
くりもと /栗本/栗源/
くりもとしんいちろう /栗本慎一郎/
くりもどし /繰戻/
くりや /厨/廚/
くりやがわ /厨川/栗谷川/
くりやま /栗山/
くりやまむら /栗山村/
くりゅう /九龍/
くりょ /苦慮/
くりようかん /栗羊羹/
くりん /九輪/九厘/
くる /久留/
くるい /狂い/
くるいざき /狂い咲き/狂咲/
くるいじに /狂い死に/
くるしまぎれ /苦し紛れ/
くるしみ /苦しみ/
くるす /来須/
くるすがわ /来栖川;姓/
くるすの /栗栖野/
くるとし /来る年/
くるひ /来る日/
くるびょう /佝僂病;[医]rickets/
くるぶし /踝/
くるま /車/俥;人力車/
くるまいがい /車以外/
くるまいす /車椅子/車イス/車いす/
くるまいぞんしゃかい /車依存社会/
くるまいちだいぶん /車一台分/
くるまいど /車井戸/
くるまえび /車海老/車エビ/車蝦/
くるまかんけい /車関係/
くるまかんれん /車関連/
くるまがえし /車返し/
くるまがわ /車側/
くるまこうにゅうじ /車購入時/
くるまさんぎょう /車産業/
くるまざ /車座/
くるまざき /車折/
くるまざっし /車雑誌/
くるましゃかい /車社会/
くるまじ /車路/
くるまじたい /車自体/
くるまぜんたい /車全体/
くるまたに /車谷/
くるまだ /車田/
くるまだい /車代/
くるまちん /車賃/
くるまつうがく /車通学/
くるまづか /車塚/
くるまとう /車糖/
くるまどうし /車同士/車同志;?/
くるまどおり /車通り/
くるまどめ /車止め/車止/
くるまぶんか /車文化/
くるまへん /車偏/
くるまや /車屋/
くるまやど /車宿/
くるまやま /車山/
くるまゆうせん /車優先/
くるまゆり /車百合/
くるまよい /車酔い/車酔/
くるまよう /車用/
くるまよせ /車寄せ/
くるまりよう /車利用/
くるみ /胡桃/久留味/包み/
くるみいろ /胡桃色/
くるみざわ /胡桃沢/
くるみどうふ /胡桃豆腐/
くるみもく /クルミ目/Juglandales/
くるみわり /胡桃割り/
くるみわりにんぎょう /胡桃割り人形;Shchelkunchik/
くるめ /久留米/
くるめこうぎょうだい /久留米工業大/
くるめこうぎょうだいがく /久留米工業大学/
くるめこうだい /久留米工大/
くるめし /久留米市/
くるり /枢/
くるる /枢/
くるわ /郭/廓/曲輪/
くるわことば /郭言葉/
くれ /呉/暮れ/塊/暮/
くれーしゃげき /クレー射撃/
くれーぷや /クレープ屋/
くれーむしょり /クレーム処理/
くれおーるご /クレオール語;creole/
くれがし /某/
くれがた /暮れ方/
くれぐれ /呉々;-も/暮々/呉呉/
くれし /呉市/
くれじっとがいしゃ /クレジット会社/
くれじっとけっさい /クレジット決済/
くれせん /呉線/
くれたけ /呉竹/
くれたぶんめい /クレタ文明/
くれっしぇんど /cresc/crescendo;次第に強く/
くれない /紅/
くれないぞめ /紅染/
くれないのぶた /紅の豚;[アニメ](1992)宮崎駿/
くれはかがく /呉羽化学;[企業名]/
くれはとり /呉織/
くればやし /紅林/暮林/
くれむつ /暮六つ/
くれよんしゃ /クレヨン社/
くろ /黒/畔/玄/
くろ> /黒;黒塗り,黒マジック,黒歌鳥/
くろーんびょう /クローン病;[医]Crohn's disease/
くろあげは /黒揚羽/
くろあめ /黒飴/
くろあん /黒餡/黒あん/
くろいあめ /黒い雨;井伏鱒二,1965-66/
くろいきり /黒い霧/
くろいし /黒石/
くろいそ /黒磯/
くろいそえき /黒磯駅/
くろいつふぇるとやこぶびょう /クロイツフェルトヤコブ病;Creutzfeldt-Jakob disease(CJD). 狂牛病/
くろいと /黒糸/
くろいぬ /黒犬/
くろいろ /黒色/
くろいわ /黒岩/
くろいわるいこう /黒岩涙香/
くろう /苦労/
くろうさま /苦労様/
くろうしょう /苦労性/
くろうじ /黒氏/
くろうたどり /黒歌鳥;blackbird singing in the dead of night.../
くろうだん /苦労談/
くろうと /玄人/
くろうとげい /玄人芸/
くろうとしこう /玄人志向;www.kuroutoshikou.com/
くろうとすじ /玄人筋/
くろうとはだし /玄人跣/
くろうど /蔵人/
くろうどどころ /蔵人所/
くろうどどころのべっとう /蔵人所別当/
くろうどのごい /蔵人の五位/
くろうどのとう /蔵人頭/
くろうどのべん /蔵人弁/
くろうどまち /蔵人町/
くろうにん /苦労人/
くろうばなし /苦労話/
くろうま /黒馬/
くろうめもどきもく /クロウメモドキ目/Rhamnales/
くろうるし /黒漆/
くろうんも /黒雲母/
くろえ /黒江/
くろおとこ /黒男/
くろおび /黒帯/
くろかび /黒黴/黒カビ/黒かび/
くろかみ /黒髪/
くろかみちょう /黒髪町/
くろかわ /黒川/黒河/黒革/
くろかわぐん /黒川郡/
くろがしら /黒頭/
くろがそ /黒画素/
くろがね /鉄/黒鉄/黒銀/鐵;「鉄」旧字/
くろがも /黒鴨/
くろき /黒木/
くろぎ /黒木/
くろくま /黒熊/
くろくも /黒雲/
くろぐろ /黒々/
くろけい /黒系/
くろげ /黒毛/
くろげわぎゅう /黒毛和牛/
くろげわしゅ /黒毛和種;和牛の品種。高級/
くろこ /黒子/
くろこげ /黒焦げ/
くろこしょう /黒胡椒;black pepper/
くろこま /黒駒/
くろご /黒子/黒衣/
くろごま /黒胡麻/
くろごめ /玄米/黒米/
くろさ /黒さ/
くろさか /黒坂/
くろさき /黒崎/
くろさわ /黒沢/黒澤/
くろさわあきら /黒澤明;人名,映画監督/黒沢明/
くろざとう /黒砂糖/
くろしお /黒潮/
くろしおおんせん /黒潮温泉/
くろしかく /■/
くろしかげ /黒鹿毛/
くろしま /黒島/
くろしょうぞく /黒装束/
くろしろ /黒白/
くろしんじゅ /黒真珠/
くろじ /黒字/黒地/
くろじがく /黒字額/
くろじけっさん /黒字決算/
くろじとうさん /黒字倒産/
くろじはば /黒字幅/
くろじゅす /黒襦子/
くろす /黒須;姓/
くろすいしょう /黒水晶/
くろすそう /クロス装/
くろすみ /黒住;姓/
くろず /黒酢/
くろずみ /黒住;姓/
くろせ /黒瀬;姓/
くろせがわ /黒瀬川/
くろせん /黒線/
くろた /黒田;姓/
くろたき /黒滝/
くろたてじま /黒縦縞/
くろだ /黒田;姓/
くろだい /黒鯛/
くろだきよたか /黒田清隆/
くろだけ /黒岳/
くろだな /黒棚/
くろだに /黒谷/
くろだぶし /黒田節;[民謡]「酒は飲めぇ飲め」/
くろだま /黒玉/
くろだんしゃく /黒男爵/
くろち /黒地/
くろちく /黒竹/
くろちゃ /黒茶/
くろちゃいろ /黒茶色/
くろぢ /黒地/
くろつち /黒土/
くろつるばみ /黒橡/
くろづか /黒塚/
くろづくり /黒作り;イカの塩辛、墨入り/
くろづる /黒鶴/
くろてん /黒貂/
くろでんわ /黒電話/
くろとう /黒糖/
くろとかげ /黒蜥蜴/
くろとり /黒鳥/
くろど /黒戸/
くろぬり /黒塗り/畔塗り;水田の畔を固める/
くろねこ /黒猫/
くろねずみ /黒鼠/
くろの /黒野;姓/
くろは /黒羽/
くろば /黒羽/
くろばこ /黒箱/
くろばね /黒羽/
くろばん /黒番/
くろぱん /黒パン;brown bread/
くろひげ /黒髭/
くろひめ /黒姫/
くろひめこうげん /黒姫高原/
くろひょう /黒豹/
くろひりつ /黒比率/
くろびーる /黒ビール;dark beer/
くろびかり /黒光り/
くろびし /黒菱/
くろびょうし /黒表紙/
くろふく /黒服/
くろふじょう /黒不浄/
くろふね /黒船/
くろぶさ /黒房/
くろぶし /踝/
くろぶた /黒豚/
くろぶち /黒縁;「-の眼鏡」/黒斑;黒いまだら/黒駁;馬の毛色/
くろべ /黒部/
くろべがわ /黒部川/
くろべきょうこくてつどう /黒部峡谷鉄道/
くろべこ /黒部湖/
くろほね /黒保根/
くろほん /黒本/
くろぼし /黒星/●/★/
くろぼしびょう /黒星病;[植物]/
くろまく /黒幕/
くろまじゅつ /黒魔術/
くろます /黒鱒;black bass/
くろまつ /黒松/
くろまつない /黒松内/
くろまにょんじん /クロマニョン人/
くろまほう /黒魔法/
くろまめ /黒豆/
くろまる /黒丸/●/
くろみ /黒み/
くろみかずら /黒御鬘/
くろみさ /黒ミサ/
くろみす /黒御簾;歌舞伎などの囃子方の席/
くろみつ /黒蜜/
くろみや /黒宮/
くろむ /Cr/Chromium/
くろむぎ /黒麦/
くろむぎしゅ /黒麦酒/
くろむらさき /黒紫/
くろむらさきいろ /黒紫色/
くろめ /黒目/黒眼/
くろめがち /黒目勝ち/
くろめがね /黒眼鏡/
くろも /黒藻/
くろもじ /黒文字/
くろもの /黒物/
くろもよう /黒模様/
くろもん /黒門/
くろや /黒屋/
くろやき /黒焼き/黒焼;イモリの-/
くろやなぎ /黒柳/
くろやなぎてつこ /黒柳徹子;人名/
くろやま /黒山/
くろゆめ /黒夢/
くろゆり /黒百合/
くろよんだむ /黒四ダム;黒部川第四発電所ダム。日本最大/
くろらく /黒楽/
くろろ /枢/
くろわく /黒枠/
くろわし /黒鷲/
くろん /句論/
くろんぼう /黒ん坊/
くわ /鍬/桑/钁/久和/
くわい /慈姑/
くわいろ /桑色/
くわえ /加え/銜え/
くわえたばこ /銜えタバコ/
くわおり /桑折/
くわかど /桑門/
くわがた /鍬形/
くわがたいし /鍬形石/
くわがたむし /鍬形虫/
くわき /桑木/
くわけ /区分け/
くわこ /桑子/
くわこう /桑港/
くわご /桑蚕/
くわずぎらい /食わず嫌い/
くわせもの /食わせ者/食わせ物/
くわぞめ /桑染/
くわた /桑田/
くわたに /桑谷;姓/
くわだ /桑田/
くわだて /企て/企/
くわちゃ /桑茶/
くわづる /桑鶴/
くわな /桑名/
くわなえき /桑名駅/
くわの /桑野/
くわはた /桑畑/
くわはら /桑原/
くわばら /桑原/
くわばらくわばら /桑原桑原/
くわばらたけお /桑原武夫;評論家/
くわむら /桑村/
くわもと /桑本/
くわやま /桑山/
くわり /区割り/桑理/
くん /君/訓/勲;勲章/勳;「勲」の旧字(人名用漢字)/薫;薫陶/熏;「薫」の異体字/燻;燻製/醺;酒の香り/裙/桾/葷;葷酒/皸;あかぎれ/皹;「皸」の異体字/
くんい /勲位/
くんいく /訓育;教え育てる/薫育;感化して成長させる/
くんえん /燻煙;†いぶす/薫煙;†良い香りの煙/
くんえんざい /燻煙剤/
くんおん /君恩/
くんか /君家/訓化;教え導く/薫化;徳で感化する/
くんかい /訓戒;諭し戒める/訓解;文を解き明かす/
くんがな /訓仮名/
くんき /勲記/
くんげん /訓言/
くんこ /訓詁/
くんこう /勲功/薫香/君公;君主/君侯;諸侯・宰相/
くんこく /訓告/君国/
くんし /君子/
くんしゃく /勲爵/訓釈/
くんしゅ /君主/葷酒;「ネギ、ニラの類いと酒」の意味/
くんしゅこく /君主国/
くんしゅせい /君主制/君主政/
くんしゅどうとく /君主道徳/
くんしゅろん /君主論/
くんしょう /勲章/
くんしらん /君子蘭/
くんしん /君臣/
くんじ /訓示/訓辞/
くんじきてい /訓示規定/
くんじゅ /群衆/
くんじょう /燻蒸/薫蒸/
くんずほぐれつ /組んず解れつ/
くんせい /燻製/薫製;=燻製/
くんせん /薫染/
くんそく /君側/
くんだり /下/下り/
くんちゅう /訓注/訓註/
くんちょう /君寵/
くんづけ /君付け/君付/
くんてん /訓点/
くんてんご /訓点語/
くんてんしりょう /訓点資料/
くんてんぼん /訓点本/
くんでん /訓電/
くんとう /薫陶/勲等/
くんどう /訓導/
くんどく /訓読/
くんねっぷ /訓子府/
くんねっぷちょう /訓子府町/
くんのう /君王/
くんぷ /君父/
くんぷう /薫風/
くんみん /君民/
くんみんせいおん /訓民正音/
くんめい /君命/
くんもう /訓蒙/
くんやん /崑央/
くんゆ /訓諭/
くんよみ /訓読み/
くんりん /君臨/
くんれい /訓令/
くんれいしき /訓令式/
くんれん /訓練/
くんれんうんてん /訓練運転/
くんれんか /訓練科/
くんれんし /訓練士/
くんれんしだい /訓練次第/
くんれんしょ /訓練所/
くんれんじょ /訓練所/
くんれんじょう /訓練場/
くんれんせい /訓練生/
くんれんちゅう /訓練中/
くんれんど /訓練度/
くんれんぶそく /訓練不足/
くんれんよう /訓練用/
くんわ /訓話/
ぐ /愚/具;味噌汁の-/惧;危惧/颶;颶風/倶/禺/弘;(呉音)弘誓/壺;(呉音の一つ)/壷;「壺」の異体字/虞;虞犯/麌;(おじか)/狗;天狗/
ぐあい /具合/具合い/工合/
ぐあむとう /グアム島;地名,Guam/
ぐあん /愚案/具案/
ぐいのみ /ぐい飲み/
ぐう /宮/偶;偶然/寓;寓話/遇;遭遇/隅;一隅/嵎/藕;はす/
ぐうい /寓意/
ぐういん /偶因/
ぐうえい /偶詠/
ぐうえん /宮宛/
ぐうかく /隅角/
ぐうかん /偶感/
ぐうかんすう /偶関数/
ぐうき /偶奇/
ぐうきせい /偶奇性/
ぐうきょ /寓居;僑居、僑寓/
ぐうげん /寓言/
ぐうご /偶語/
ぐうさく /偶作/
ぐうじ /宮司/
ぐうじん /偶人/
ぐうすう /偶数/
ぐうすうかい /偶数回/
ぐうすうけた /偶数桁/
ぐうすうじ /偶数時/
ぐうすうづき /偶数月/
ぐうすうばんごう /偶数番号/
ぐうすうび /偶数日/
ぐうすうびょう /偶数秒/
ぐうすうぺーじ /偶数頁/
ぐうすうほん /偶数本/
ぐうせい /偶成/
ぐうぜん /偶然/
ぐうぜんせい /偶然性/
ぐうぜんてき /偶然的/
ぐうぜんはっけん /偶然発見/
ぐうぞう /偶像/
ぐうぞうか /偶像化;建国者の-/
ぐうぞうし /偶像視/
ぐうぞうすうはい /偶像崇拝/
ぐうちかん /偶置換/
ぐうていもく /偶蹄目/
ぐうているい /偶蹄類/
ぐうのね /ぐうの音/
ぐうはつ /偶発/
ぐうはつさいむ /偶発債務/
ぐうはつてき /偶発的/
ぐうもく /寓目/
ぐうゆ /寓喩/
ぐうゆう /偶有/
ぐうゆうせい /偶有性/
ぐうりょく /偶力/
ぐうれつ /偶列/
ぐうわ /寓話/
ぐうわてき /寓話的/
ぐかく /具格;[文法]instructive/
ぐかんしょう /愚管抄;慈円/
ぐがん /具眼/
ぐきょ /愚挙/
ぐけい /愚兄/愚形/愚計/
ぐけん /愚見/
ぐげん /具現/
ぐげんか /具現化/
ぐこう /愚行/愚考/愚公/供香/
ぐさ /種/草/
ぐさい /愚妻/供祭/
ぐさく /愚策/愚作/
ぐざい /具材/ξ;xi/Ξ;Xi/
ぐし /愚姉/串/
ぐしかみ /具志頭/
ぐしかわ /具志川/
ぐしけん /具志堅/
ぐしゃ /愚者/
ぐしょ /愚書/具書/
ぐしょう /具象/
ぐしょうか /具象化/
ぐしょうが /具象画/
ぐしょうこう /具象項/
ぐしょうせい /具象性/
ぐしょうてき /具象的;⇔抽象的/
ぐしん /具申/供進/愚神/
ぐしんらいさん /愚神礼讃;Moriae encomium, 1511, Erasmus/
ぐじょ /愚女/
ぐじょう /郡上/
ぐじょうはちまん /郡上八幡/
ぐじん /愚人/
ぐすくべ /城辺/
ぐすり /薬/
ぐず /愚図;当て字/
ぐずぐず /愚図愚図;当て字/
ぐせ /癖/
ぐせい /愚生/
ぐせつ /愚説/
ぐせぼさつ /救世菩薩/
ぐぜい /弘誓/
ぐそ /糞/
ぐそう /愚僧/
ぐそく /具足/愚息/
ぐそくかい /具足戒/
ぐたい /具体/
ぐたいあん /具体案/
ぐたいおんがく /具体音楽/
ぐたいか /具体化/
ぐたいけい /具体形/
ぐたいさく /具体策/
ぐたいせい /具体性/
ぐたいてき /具体的/
ぐたいてきいけん /具体的意見/
ぐたいてきぎろん /具体的議論/
ぐたいてきこうい /具体的行為/
ぐたいてきこうどう /具体的行動/
ぐたいてきさぎょう /具体的作業/
ぐたいてきしゅだん /具体的手段/
ぐたいてきしゅほう /具体的手法/
ぐたいてきしょうこ /具体的証拠/
ぐたいてきじじつ /具体的事実/
ぐたいてきじれい /具体的事例/
ぐたいてきすうち /具体的数値/
ぐたいてきたいけん /具体的体験/
ぐたいてきたいしょう /具体的対象/
ぐたいてきていあん /具体的提案/
ぐたいてきないよう /具体的内容/
ぐたいてきほうほう /具体的方法/
ぐたいてきもんだい /具体的問題/
ぐたいてきれい /具体的例/
ぐたいめい /具体名/
ぐたいれい /具体例/
ぐたいろん /具体論/
ぐち /愚痴/口/
ぐちょく /愚直/
ぐちん /具陳/
ぐつ /靴/
ぐてい /愚弟/
ぐとう /愚答/
ぐどう /求道/
ぐどん /愚鈍/
ぐねつむこう /グネツム綱/
ぐのう /愚能/
ぐのこっちょう /愚の骨頂/
ぐはん /虞犯/
ぐはんしゃ /虞犯者/
ぐび /具備/
ぐびじん /虞美人/
ぐびじんそう /虞美人草/
ぐふ /愚夫/愚父/愚婦/
ぐふう /颶風/
ぐふとくく /求不得苦/
ぐぶ /供奉/弘布/
ぐぶつ /愚物/
ぐほう /求法/
ぐぼ /愚母/
ぐまい /愚昧/愚妹/
ぐみ /組/茱/萸/胡頽子/茱萸/
ぐみん /愚民/
ぐみんせいさく /愚民政策/
ぐもん /愚問/
ぐもんぐとう /愚問愚答/
ぐもんじほう /求聞持法/
ぐゆう /具有/
ぐら /蔵/倉/鞍/
ぐらい /位/
ぐらたんざら /グラタン皿/
ぐらにゅーとう /グラニュー糖;(granulated sugar) さらさらのお砂糖/
ぐらびあし /グラビア誌/
ぐらふか /グラフ化/
ぐらふし /グラフ誌/
ぐらふりろん /グラフ理論;graph theory/
ぐらみーしょう /グラミー賞/
ぐらむ /瓦;gramme/
ぐらむすう /グラム数/
ぐり /栗/
ぐりーんしゃ /グリーン車/
ぐりあさいぼう /グリア細胞;[生物]glia cell/
ぐりむどうわ /グリム童話/
ぐるーう゛かん /グルーヴ感/
ぐるーぶかん /グルーブ感/
ぐるーぷきぎょう /グループ企業/
ぐるーぷめい /グループ名/
ぐるい /狂い/
ぐるかへい /グルカ兵;(Gurkha) ネパール人の傭兵。勇猛さで高名/
ぐるぐるまき /グルグル巻き/ぐるぐる巻き/
ぐるたみんさん /グルタミン酸/
ぐるたみんさんなとりうむ /グルタミン酸ナトリウム;[化学]C5H8O4Na/
ぐるま /車/
ぐるみ /包み/
ぐるめ /包/
ぐるり /周/
ぐれ /昏/
ぐれーじ /グレー地/
ぐれごりうすれき /グレゴリウス暦;NB:現代の暦法/
ぐれごりおせいか /グレゴリオ聖歌;Gregorian chant/
ぐれごりおれき /グレゴリオ暦;=グレゴリウス暦/
ぐれつ /愚劣/
ぐれん /紅蓮/
ぐれんたい /愚連隊/
ぐれんな /紅蓮奈/
ぐろ /黒/
ぐろーばるか /グローバル化/
ぐろう /愚弄/愚老/
ぐろん /愚論/
ぐわい /具合/
ぐん /郡;†county/群;†むれ/軍;army/羣;「群」の異体字/麕;(鹿の一種)のろ/
ぐん> /軍;軍司令部,軍管区,軍本部/郡;郡会,郡代,郡参事(会)/
ぐんい /軍医/
ぐんいち /軍一/
ぐんえい /群栄/軍営/
ぐんえき /軍役/
ぐんか /軍歌/軍靴/群化/
ぐんかく /軍拡/群鶴/
ぐんかん /軍艦/軍鑑/
ぐんかんき /軍艦旗/
ぐんかんく /軍管区/
ぐんかんけい /軍関係/
ぐんかんどり /軍艦鳥/
ぐんかんぶ /軍艦部/
ぐんかんまき /軍艦巻き;イクラの-/軍艦巻/
ぐんがく /軍学/軍楽/
ぐんがくしゃ /軍学者/
ぐんがくたい /軍楽隊/
ぐんき /軍記;「-物語」/軍旗/軍機;軍部の機密/軍規;軍隊の規則。「-違反」/軍紀;軍隊の紀律。「-を紊す」/
ぐんきしゅくせい /軍規粛正;軍紀?/
ぐんきもの /軍記物;平家物語、太平記など/
ぐんきものがたり /軍記物語/
ぐんきょ /群居/
ぐんぎ /群議/
ぐんけ /郡家/
ぐんけい /軍鶏/
ぐんけいさつ /軍警察/
ぐんけん /軍犬/
ぐんこう /軍港/軍功/
ぐんこく /軍国/
ぐんこくか /軍国化/
ぐんこくしゅぎ /軍国主義/
ぐんこくしゅぎしゃ /軍国主義者/
ぐんこん /群婚;=集団婚/
ぐんさい /軍才/
ぐんさん /軍産/
ぐんさんふくごうたい /軍産複合体/
ぐんざん /群山/
ぐんし /軍師/軍士/軍使/軍史/
ぐんしきん /軍資金/
ぐんしけい /軍師型/
ぐんしゅう /群集/群衆/群聚/
ぐんしゅうしんり /群集心理/
ぐんしゅく /軍縮/
ぐんしゅくかいぎ /軍縮会議;Conference on Disarmament/
ぐんしょ /群書/軍書/
ぐんしょう /群小/
ぐんしょく /軍職/
ぐんしょるいじゅう /群書類従;古文献の叢書。塙保己一・編。全1680巻(1779-1819)/
ぐんしれいかん /軍司令官/
ぐんしれいぶ /軍司令部/
ぐんしん /軍神/群臣/
ぐんじ /軍事/郡司/軍二/群司/
ぐんじえいせい /軍事衛星;antisatellite(ASAT)/
ぐんじえんじょ /軍事援助/
ぐんじか /軍事化/
ぐんじかいにゅう /軍事介入/
ぐんじかがく /軍事科学/
ぐんじかんけい /軍事関係/
ぐんじきみつ /軍事機密/
ぐんじきょういく /軍事教育/
ぐんじこうどう /軍事行動/
ぐんじこっか /軍事国家/
ぐんじさいばん /軍事裁判/
ぐんじさくせん /軍事作戦/
ぐんじさんぎょう /軍事産業/
ぐんじしせつ /軍事施設/
ぐんじしょうとつ /軍事衝突/
ぐんじしんりゃく /軍事侵略/
ぐんじじょうしき /軍事常識/
ぐんじせいけん /軍事政権/
ぐんじせんもんか /軍事専門家/
ぐんじそしき /軍事組織/
ぐんじそち /軍事措置/
ぐんじたいこく /軍事大国/
ぐんじてき /軍事的/
ぐんじてきりゆう /軍事的理由/
ぐんじどうめい /軍事同盟;日独伊三国-,中朝-/
ぐんじひ /軍事費/
ぐんじほうてい /軍事法廷/
ぐんじもくてき /軍事目的/
ぐんじもんだい /軍事問題/
ぐんじゅ /軍需/
ぐんじゅけいき /軍需景気/
ぐんじゅこうじょう /軍需工場/
ぐんじゅさんぎょう /軍需産業/
ぐんじゅひん /軍需品/
ぐんじょう /群青/群生/
ぐんじょういろ /群青色/
ぐんじょうしょく /群青色/
ぐんじよう /軍事用/
ぐんじりょく /軍事力/
ぐんじん /軍人/軍陣/
ぐんじんしょうぎ /軍人将棋/
ぐんじんちょくゆ /軍人勅諭/
ぐんすい /軍帥/
ぐんすう /群数/
ぐんせい /群生;colony/軍政;military rule/軍制;military system/群星;star cluster/群棲;flock/
ぐんせいか /軍政下/
ぐんせき /軍籍/
ぐんせん /軍船/
ぐんぜい /軍勢/
ぐんぜさんぎょう /グンゼ産業;[企業名]/
ぐんぜんたい /群全体/
ぐんそう /軍曹/軍装/
ぐんそうどの /軍曹殿/
ぐんそく /軍足/
ぐんそくど /群速度/
ぐんそしき /軍組織/
ぐんそつ /軍卒/
ぐんぞう /群像/
ぐんぞく /軍属/
ぐんたい /軍隊/群体/
ぐんたいしき /軍隊式/
ぐんたいはけん /軍隊派遣/
ぐんだい /群大/郡代/
ぐんだり /軍荼利/
ぐんだん /軍団/群団/軍談/
ぐんだんこうそう /軍団抗争/
ぐんだんちょう /軍団長/
ぐんちえん /群遅延/
ぐんちゅう /軍中/
ぐんちゅうおう /軍中央/
ぐんちょう /郡長/軍長/
ぐんて /軍手/
ぐんてい /軍偵/
ぐんていすう /群定数/
ぐんと /軍都/
ぐんとう /群島/軍刀/群盗/
ぐんとうきょく /軍当局/
ぐんない /郡内/
ぐんば /軍馬/
ぐんばい /軍配/
ぐんばつ /軍閥/
ぐんぱつ /群発/
ぐんぱつじしん /群発地震/
ぐんぱつせい /群発性/
ぐんび /軍備/
ぐんびかくだい /軍備拡大/
ぐんぴ /軍費/
ぐんぴょう /軍兵/軍票/群氷/
ぐんぶ /軍部;military/郡部;郡のつく地域/群舞/
ぐんぷ /軍夫/
ぐんぷく /軍服/
ぐんぼう /軍帽/
ぐんぽう /軍法/群峰/
ぐんぽうかいぎ /軍法会議/
ぐんま /群馬/
ぐんまけん /群馬県/
ぐんまけんじん /群馬県人/
ぐんまだい /群馬大/
ぐんまだいがく /群馬大学/
ぐんまちょう /群馬町/
ぐんみん /軍民/
ぐんむ /軍務/
ぐんむかん /軍務官/
ぐんむきょくちょう /軍務局長/
ぐんめいれい /軍命令/
ぐんもう /群盲/
ぐんもん /軍門/
ぐんやく /軍役/
ぐんゆう /群雄/群游/
ぐんゆうかっきょ /群雄割拠/
ぐんよう /軍用/
ぐんようき /軍用機/
ぐんようきん /軍用金/
ぐんようけん /軍用犬/
ぐんようしゃ /軍用車/
ぐんようち /軍用地/
ぐんらく /群落/
ぐんりつ /軍律/
ぐんりゃく /軍略/
ぐんりゅうせい /群流星/
ぐんりょ /軍旅/
ぐんれい /軍令/
ぐんれいぶ /軍令部/
ぐんれいぶそうちょう /軍令部総長/
ぐんれいぶちょう /軍令部長/
ぐんれき /軍歴;大統領の-詐称/
ぐんろん /群論/
ぐんろんにゅうもん /群論入門/
け /毛/気/家/卦;八卦/褻;ハレと-/ヶ;「個」の略字/蹴;(動詞活用形)/怪;物の怪/恠;「怪」の異体字/袈;袈裟/懸;(慣用音)懸念/化;(呉音)化粧/仮;(呉音)/花;(呉音)/華;(呉音)/掛;(呉音)/乖;(呉音) 乖離/迦;(呉音) 釈迦/假;「仮」の旧字/氣;「気」の旧字(人名用漢字)/祁;?/消;動詞語幹?/
けーきざら /ケーキ皿/
けーきづくり /ケーキ作り/
けーきや /ケーキ屋/
けーすべつ /ケース別/
けーてん /Ｋ点;スキージャンプの基準点/
けあがり /蹴上がり/
けあげ /蹴上/蹴上げ/
けあし /毛足/
けあな /毛穴/毛孔/
けい /刑;punishment/形;form/型;model/系/計/軽/経;経由/京;10^16/茎;くき/径;半径/頸;くび/頚;「頸」の異体字/継/繼;「継」の旧字/奚;なんぞ/渓;渓流/溪;「渓」の旧字/蹊;鼠蹊部/谿;たに/鶏;にわとり/鷄;「鶏」の旧字(人名用漢字)/慧;慧眼/恵;恩恵/惠;「恵」の旧字(人名用漢字)/炯;炯眼/烱;「炯」の異体字/絅;(着物の一種)/冏;けいがまえ/迥;とおい/勍;つよい/黥;いれずみ/圭;土圭/珪;珪酸/硅;硅酸(=珪酸)/桂;桂馬/畦;あぜ/罫;罫線/鮭;さけ/奎;二十八宿の一つ/挂;か・ける/閨;閨房/剄;くびきる/勁;つよい/痙;痙攣/脛;すね/莖;「茎」の旧字/輕;「軽」の旧字/徑;「径」の旧字1/逕;「径」の旧字2/經;「経」の旧字/契;契約/挈/楔;くさび/敬;敬意/警;警備/謦;謦咳/馨;かおり/磬;きん/繋;繋船/啓;啓蒙/綮;肯綮/蛍;ほたる/螢;「蛍」の旧字/煢;ひとり/兮;(助辞)/盻;にらむ/頃;ころ/傾;傾向/競;競馬/卿;王卿/境;境内/荊;いばら/夐;はるか/憬;憧憬/枅/檠;ゆだめ/瓊;たま/笄;こうがい/醯/係;関係/兄;愚兄/慶;慶事/憩;休憩/掲;掲載/携;提携/景;光景/稽;滑稽/詣;参詣/憇;「憩」の異体字/攜;「携」の異体字/冂;(けいがまえ)/匸;(かくしがまえ)/彑;(けいがしら)/佳;?/掛;?/
けい#まい /計#1枚/計#2枚/計#3枚/
けい> /計/軽;軽喫茶,軽音楽,軽営倉/経;経口,経腹,経粘膜/
けいあい /敬愛/
けいあつ /傾圧/
けいあつたいき /傾圧大気/
けいあん /慶安;年号(1648-1652)/桂庵;口入れ屋/慶庵;口入れ屋/
けいあんおふれがき /慶安御触書/
けいい /経緯/敬意/軽易/慶伊/
けいいぎ /経緯儀/
けいいち /圭一/啓一/恵一/敬一/慶一/桂一/佳一/螢一/蛍一/
けいいちろう /啓一郎/圭一郎/敬一郎/圭一朗/
けいいど /経緯度/
けいいん /契印/
けいうん /慶雲;年号(703-708)/
けいえい /経営/警衛/形影/継泳/
けいえいあっか /経営悪化/
けいえいかだい /経営課題/
けいえいかつどう /経営活動/
けいえいかんり /経営管理/
けいえいがく /経営学/
けいえいがくぶ /経営学部/
けいえいがっか /経営学科/
けいえいがわ /経営側/
けいえいきかくしつ /経営企画室/
けいえいきき /経営危機/
けいえいきばん /経営基盤/
けいえいきぼ /経営規模/
けいえいけい /経営系/
けいえいけいざいがく /経営経済学/
けいえいけん /経営権/
けいえいこうがく /経営工学/
けいえいこうがっか /経営工学科/
けいえいしげん /経営資源/
けいえいしゃ /経営者/
けいえいしゃがわ /経営者側/
けいえいしゅほう /経営手法/
けいえいしゅわん /経営手腕/
けいえいじょう /経営上/
けいえいじょうきょう /経営状況/
けいえいじょうたい /経営状態/
けいえいじん /経営陣/
けいえいせいせき /経営成績/
けいえいせきにん /経営責任/
けいえいせんりゃく /経営戦略/
けいえいたい /経営体/
けいえいたいしつ /経営体質/
けいえいてき /経営的/
けいえいてきかんてん /経営的観点/
けいえいとうけいがく /経営統計学/
けいえいとうごう /経営統合/
けいえいどりょく /経営努力/
けいえいなん /経営難/
けいえいはたん /経営破綻/
けいえいふしん /経営不振/
けいえいぶんせき /経営分析/
けいえいぶんや /経営分野/
けいえいほうしん /経営方針/
けいえいぼたい /経営母体/
けいえいりねん /経営理念/
けいえいりょく /経営力/
けいえん /敬遠/閨怨/
けいえんげき /軽演劇/
けいえんさく /敬遠策/
けいえんじだい /桂園時代;1903-12/
けいおう /京王/慶應/慶応;年号(1865-1868)/
けいおういなだつつみ /京王稲田堤/
けいおうかく /京王閣/
けいおうぎじゅく /慶應義塾/慶応義塾/
けいおうぎじゅくじょし /慶應義塾女子/
けいおうぎじゅくだい /慶應義塾大/慶応義塾大/
けいおうぎじゅくだいがく /慶應義塾大学/慶応義塾大学/
けいおうぐち /京王口/
けいおうけいそく /慶応計測/慶應計測/
けいおうしょうなんふじさわ /慶應湘南藤沢/
けいおうしんじゅく /京王新宿/
けいおうしんじゅくえき /京王新宿駅/
けいおうしんせん /京王新線/
けいおうせい /慶應生/
けいおうせん /京王線/
けいおうせんえんせん /京王線沿線/
けいおうせんしんじゅく /京王線新宿/
けいおうたま /京王多摩/
けいおうだい /慶応大/慶應大/
けいおうだいがく /慶応大学/慶應大学/
けいおうていと /京王帝都/
けいおうていとでんてつ /京王帝都電鉄/
けいおうはい /京王杯/
けいおうはちおうじ /京王八王子/
けいおうひよし /慶応日吉/慶應日吉/
けいおうびん /京王便/
けいおうふじさわ /慶応藤沢/慶應藤沢/
けいおうみた /慶應三田/
けいおうりこう /慶応理工/
けいおん /軽音/
けいおんがく /軽音楽/
けいおんがくぶ /軽音楽部/
けいおんき /警音器/
けいか /経過/桂花/京華/計科/圭花/軽過/
けいかい /警戒/軽快/啓開/
けいかいかん /軽快感/
けいかいくいき /警戒区域/
けいかいけいほう /警戒警報/
けいかいしょく /警戒色/
けいかいしん /警戒心/
けいかいせん /警戒線/
けいかいせんげん /警戒宣言/
けいかいそうち /警戒装置/
けいかいたいせい /警戒態勢/
けいかいでんしゃ /軽快電車/
けいかおん /経過音/
けいかかんさつ /経過観察/
けいかきろく /経過記録/
けいかく /計画/圭角/経過句/計畫;「画」旧字/形覚/
けいかくがい /計画外/
けいかくけいざい /計画経済/
けいかくけいざいか /計画経済下/
けいかくけんきゅうじょ /計画研究所/
けいかくしつ /計画室/
けいかくしょ /計画書/
けいかくじ /計画時/
けいかくじょうきょう /計画状況/
けいかくせい /計画性/
けいかくせん /計画線/
けいかくだんかい /計画段階/
けいかくちゅう /計画中/
けいかくちゅうし /計画中止/
けいかくちょうしょ /計画調書/
けいかくてき /計画的/
けいかくとうさん /計画倒産/
けいかくどおり /計画通り/
けいかくひょう /計画表/
けいかくぶ /計画部/
けいかくぶんべん /計画分娩/
けいかくほう /計画法/
けいかくろせんず /計画路線図/
けいかげき /軽歌劇;operetta/
けいかご /経過後/
けいかしつ /軽過失/
けいかしょうぎょう /京華商業/
けいかじかん /経過時間/
けいかじょし /京華女子/
けいかせつめい /経過説明/
けいかそち /経過措置/
けいかほうこく /経過報告/
けいかぼく /珪化木/
けいかりし /経過利子/
けいかん /景観/警官/頚管/鶏冠;とさか/桂冠;-詩人/渓間/荊冠/鶏姦/
けいかんしじん /桂冠詩人;poet laureat/
けいかんじょうれい /景観条例/
けいかんせき /鶏冠石/
けいかんたい /警官隊/
けいかんたち /警官達/
けいかんほう /景観法/
けいかんもの /警官物/
けいが /慶賀/
けいがい /形骸/境外/謦咳;-に接する/競買/傾蓋/荊芥/
けいがいか /形骸化/
けいがいぎんが /系外銀河/
けいがく /経学/啓学/
けいがくしゅっぱん /啓学出版;[出版社名]/
けいがん /慧眼/炯眼/鶏眼;魚の目/
けいき /景気/契機/計器/掲記/慶喜/刑期/継起/軽機/圭樹;人名/恵輝/
けいきあっか /景気悪化/
けいきかいふく /景気回復/
けいきかんじゅう /軽機関銃/
けいきざい /軽機材/
けいきじゅんかん /景気循環/
けいきたいさく /景気対策/
けいきち /啓吉/
けいきづけ /景気付け/
けいきていめい /景気低迷/
けいきどう /経気道/
けいきどうこう /景気動向/
けいきどうこうしすう /景気動向指数;[経済]Diffusion Index(DI)/
けいきはんだん /景気判断/
けいきひこう /計器飛行/
けいきへい /軽騎兵/
けいきへんどう /景気変動;economic fluctuations/
けいきゅう /京急/警急/
けいきゅうかまたえき /京急蒲田駅/
けいきゅうかみおおおか /京急上大岡/
けいきゅうくうこうせん /京急空港線/
けいきゅうくりはまえき /京急久里浜駅/
けいきゅうせん /京急線/
けいきゅうせんない /京急線内/
けいきゅうひば /軽裘肥馬/
けいきょ /軽挙/
けいきょう /景況/景教/
けいきょうかん /景況感/
けいきょうちょうさ /景況調査/
けいきょく /荊棘/
けいきょもうどう /軽挙妄動/
けいきん /頸筋/
けいきんぞく /軽金属/
けいぎ /経義;経書の意味/
けいく /警句/
けいくうぼ /軽空母/
けいぐ /敬具/刑具/
けいぐん /鶏群;-の一鶴/
けいけい /軽々;-に/炯々;きらきら。「眼光-」/烱々;「炯」の異体字/軽軽/
けいけつ /経血/経穴/
けいけつせき /鶏血石/
けいけつりょう /経血量/
けいけん /経験/敬虔/經驗;旧字/
けいけんあり /経験有/
けいけんかがく /経験科学/
けいけんしき /経験式/
けいけんしゃ /経験者/
けいけんしゃだん /経験者談/
けいけんしゃゆうぐう /経験者優遇/
けいけんしゅぎ /経験主義/敬虔主義/
けいけんしゅぎてき /経験主義的/
けいけんじょう /経験上/
けいけんずみ /経験済/
けいけんそく /経験則/
けいけんだん /経験談/
けいけんち /経験値/
けいけんちぶそく /経験値不足/
けいけんてき /経験的/
けいけんてきじじつ /経験的事実/
けいけんてきにんしき /経験的認識/
けいけんてん /経験点/
けいけんねんすう /経験年数/
けいけんば /経験馬/
けいけんぶそく /経験不足/
けいけんほうふ /経験豊富/
けいけんろん /経験論/
けいげつ /桂月/
けいげん /軽減/
けいげんか /軽減化/
けいこ /稽古/恵子/慶子/圭子/桂子/啓子/佳子/敬子/景子/華子/蛍子/奎子/珪子/
けいこう /傾向/蛍光/経口;-薬/携行/鶏口;-牛後/径行;直情-/馨香/螢光;「蛍」旧字/
けいこうえいが /傾向映画/
けいこうかん /蛍光管/
けいこうかんせん /経口感染;病原菌が口→消化管から侵入する感染方法/
けいこうがくえん /啓光学園/
けいこうぎょう /軽工業/
けいこうざい /蛍光剤/
けいこうしきそ /蛍光色素/
けいこうしょく /蛍光色/
けいこうせい /傾向性;tendency/
けいこうせんしょく /蛍光染色/
けいこうせんりょう /蛍光染料/
けいこうぞうはくざい /蛍光増白剤/
けいこうたい /蛍光体/
けいこうてき /傾向的;tendentious,left-wing/
けいこうてんのう /景行天皇/
けいこうとう /蛍光灯/蛍光燈/螢光灯/
けいこうとうか /蛍光灯下/
けいこうとうよ /経口投与/
けいこうとりょう /蛍光塗料/
けいこうはちょう /蛍光波長/
けいこうひにんやく /経口避妊薬/
けいこうぶっしつ /蛍光物質;fluorescent material,phosphor/
けいこうめん /蛍光面/
けいこうやく /経口薬/
けいこく /警告/渓谷/経国;-済民/傾国;遊女/溪谷;「渓」旧字/谿谷;別字(=渓谷)/
けいこくおん /警告音/
けいこくきじ /警告記事/
けいこくさいみん /経国済民;略して経済/
けいこくしょく /警告色/
けいこくそうち /警告装置/
けいこくてつどう /渓谷鉄道/
けいこくとう /警告灯/警告燈;「灯」旧字/
けいこくぶん /警告文/
けいこごと /稽古事/
けいこしょにち /稽古初日/
けいこだい /稽古台/
けいこちゅう /稽古中/
けいこつ /脛骨;[解剖]tibia. スネの骨/頚骨;クビの骨/軽忽;=きょうこつ/
けいこつけっせつ /脛骨結節/
けいこねっしん /稽古熱心/
けいこはじめ /稽古始め/
けいこば /稽古場/
けいこび /稽古日/
けいこぼん /稽古本/
けいご /敬語/警固/警護;≒警固/啓吾/圭悟/警語/
けいごう /契合/
けいごうきん /軽合金/
けいごしゃ /警護車/
けいごしょ /警固所/
けいごよう /警護用/
けいさい /掲載/
けいさいきかん /掲載期間/
けいさいきじ /掲載記事/
けいさいきぼうしゃ /掲載希望者/
けいさいきょか /掲載許可/
けいさいこうもく /掲載項目/
けいさいごう /掲載号/
けいさいさくひん /掲載作品/
けいさいざっし /掲載雑誌/
けいさいざっしめい /掲載雑誌名/
けいさいし /掲載誌;†(magazine)/掲載紙;†(newspaper)/
けいさいしめい /掲載誌名/
けいさいしゃ /掲載者/
けいさいじ /掲載時/
けいさいじゅん /掲載順/
けいさいじょうほう /掲載情報/
けいさいちゅう /掲載中/
けいさいねんがっぴ /掲載年月日/
けいさいはんい /掲載範囲/
けいさいぶん /掲載分/
けいさいほうほう /掲載方法/
けいさいよてい /掲載予定/
けいさいるい /茎菜類/
けいさぎょう /軽作業/
けいさく /啓作/計策/
けいさつ /警察/
けいさつい /警察医/
けいさついがい /警察以外/
けいさつかん /警察官/
けいさつかんけい /警察関係/
けいさつかんけいしゃ /警察関係者/
けいさつかんしょくむしっこうほう /警察官職務執行法/
けいさつがっこう /警察学校/
けいさつがわ /警察側/
けいさつきこう /警察機構/
けいさつぎょう /警察業/
けいさつぎょうむ /警察業務/
けいさつけん /警察犬;police dog/警察権;police power/
けいさつざた /警察沙汰/
けいさつしゃりょう /警察車両/
けいさつしょ /警察署/
けいさつしょちょう /警察署長/
けいさつだいがっこう /警察大学校/
けいさつちょう /警察庁/
けいさつてちょう /警察手帳/
けいさつとうきょく /警察当局/
けいさつほう /警察法/
けいさつほんぶ /警察本部/
けいさつむせん /警察無線/
けいさつや /警察屋/
けいさつようご /警察用語/
けいさつよびたい /警察予備隊/
けいさつりょく /警察力/
けいさん /計算/経産/珪酸/≧/÷/±/×/＋/＝/≠/＜/≦/＞/
けいさんえん /珪酸塩/
けいさんかいすう /計算回数/
けいさんかがく /計算科学;†computational SCIENCE/計算化学;†computational CHEMISTRY/
けいさんかてい /計算過程/
けいさんかのう /計算可能/
けいさんかのうせい /計算可能性/
けいさんかんむり /卦算冠;[部首]/
けいさんがい /計算外/
けいさんがいねん /計算概念/
けいさんき /計算機/計算器/
けいさんきいがい /計算機以外/
けいさんきえんしゅう /計算機演習/
けいさんきかい /計算機械/
けいさんきかいはつ /計算機開発/
けいさんきかがく /計算機科学;†computational science/計算幾何学;computational geometry/計算機化学;†computational chemistry/
けいさんきかがくしゃ /計算機科学者/
けいさんきかがっか /計算機科学科/
けいさんきかんきょう /計算機環境/
けいさんきかんけい /計算機関係/
けいさんきかんり /計算機管理/
けいさんきかんりしゃ /計算機管理者/
けいさんきかんれん /計算機関連/
けいさんきがく /計算機学/
けいさんきがっか /計算機学科/
けいさんきがわ /計算機側/
けいさんききょういく /計算機教育/
けいさんきぎじゅつ /計算機技術/
けいさんきげんご /計算機言語/
けいさんきげんごがく /計算機言語学/
けいさんきこう /計算機構/
けいさんきこうがく /計算機工学/
けいさんきこうせい /計算機構成/
けいさんきしげん /計算機資源/
けいさんきしつ /計算機室/
けいさんきしょり /計算機処理/
けいさんきしようりょう /計算機使用料/
けいさんきじっけん /計算機実験/
けいさんきじょう /計算機上/
けいさんきせいぎょ /計算機制御/
けいさんきそく /計算規則/
けいさんきない /計算機内/
けいさんきないぶ /計算機内部/
けいさんきのう /計算機能/
けいさんきぼ /計算規模/
けいさんきや /計算機屋/
けいさんきよう /計算機用/
けいさんきりよう /計算機利用/
けいさんぎ /計算木/
けいさんぎじゅつ /計算技術/
けいさんけい /計算系/
けいさんけっか /計算結果/
けいさんけっかひょうじ /計算結果表示/
けいさんげんごがく /計算言語学/
けいさんこうりつ /計算効率/
けいさんこんきょ /計算根拠/
けいさんご /計算後/
けいさんしき /計算式/
けいさんしつ /計算室/
けいさんしゃ /計算者/
けいさんしょ /計算書/
けいさんしょう /経産省/経産相;†大臣/
けいさんしょり /計算処理/
けいさんじ /計算時/
けいさんじかん /計算時間/
けいさんじゃく /計算尺/
けいさんじょう /計算上/
けいさんじょうけん /計算条件/
けいさんすうがく /計算数学/
けいさんずく /計算尽く/
けいさんせい /計算性/
けいさんせいど /計算精度/
けいさんそくど /計算速度/
けいさんだい /京産大/
けいさんち /計算値/
けいさんちゅう /計算中/
けいさんてき /計算的/
けいさんてじゅん /計算手順/
けいさんどりる /計算ドリル/
けいさんのうりょく /計算能力/
けいさんぶつりがく /計算物理学/
けいさんぷ /経産婦/
けいさんほう /計算法/
けいさんほうしき /計算方式/
けいさんほうほう /計算方法/
けいさんもんだい /計算問題/
けいさんや /計算屋/
けいさんよう /計算用/
けいさんりきがく /計算力学/
けいさんりきがくけんきゅう /計算力学研究/
けいさんりょう /計算量/
けいさんりょうりろん /計算量理論/
けいさんりょく /計算力/
けいさんりろん /計算理論/
けいさんれい /計算例/
けいさんれつ /計算列/
けいさんれんしゅう /計算練習/
けいさんろん /計算論/
けいさんろんてきがくしゅう /計算論的学習/
けいざい /経済/軽罪/
けいざいいぞん /経済依存/
けいざいえんじょ /経済援助/
けいざいか /経済化/経済家/
けいざいかい /経済界/
けいざいかくさ /経済格差/
けいざいかつどう /経済活動/
けいざいかんきょう /経済環境/
けいざいかんけい /経済関係/
けいざいかんねん /経済観念;金銭感覚/
けいざいがく /経済学/
けいざいがくかんれん /経済学関連/
けいざいがくしゃ /経済学者/
けいざいがくしょう /経済学賞/
けいざいがくせんこう /経済学専攻/
けいざいがくてき /経済学的/
けいざいがくぶ /経済学部/
けいざいがくぶせい /経済学部生/
けいざいがっか /経済学科/
けいざいきかくちょう /経済企画庁;NB:2001年1月の中央省庁再編で内閣府に再編された/
けいざいきぼ /経済規模/
けいざいきょうこう /経済恐慌/
けいざいきょうりょく /経済協力/
けいざいきょうりょくかいはつきこう /経済協力開発機構;Organisation for Economic Co-operation and Development(OECD) www.oecd.org/
けいざいけい /経済系/
けいざいけん /経済圏/
けいざいけんきゅうしょ /経済研究所/
けいざいげんしょう /経済現象/
けいざいげんそく /経済原則;economic principle/
けいざいげんろん /経済原論/
けいざいこうい /経済行為/
けいざいこうか /経済効果/
けいざいこうぞう /経済構造/
けいざいこうりつ /経済効率/
けいざいさんぎょう /経済産業/
けいざいさんぎょうしょう /経済産業省;NB:通商産業省と科学技術庁が2001年1月の中央省庁再編で再編されたもの/
けいざいさんぎょうだいじん /経済産業大臣/
けいざいざい /経済財/
けいざいざいせいしもんかいぎ /経済財政諮問会議;www.keizai-shimon.go.jp/
けいざいざいせいせいさくたんとうだいじん /経済財政政策担当大臣/
けいざいざいせいはくしょ /経済財政白書/
けいざいざっし /経済雑誌/
けいざいし /経済史;economic history/経済誌;business magazine/経済紙;business paper/
けいざいしえん /経済支援/
けいざいしっせい /経済失政/
けいざいしゃかい /経済社会/
けいざいしゃかいりじかい /経済社会理事会/
けいざいしゅぎ /経済主義;economism/
けいざいしょう /経済省/経財相/経済相;†大臣/
けいざいしんりゃく /経済侵略/
けいざいじょう /経済上/
けいざいじょうきょう /経済状況/
けいざいじょうせい /経済情勢/
けいざいじょうたい /経済状態/
けいざいじん /経済人/
けいざいじんるいがく /経済人類学;economic anthropology/
けいざいすいいき /経済水域;排他的-/
けいざいせい /経済性/
けいざいせいさい /経済制裁/
けいざいせいさく /経済政策/
けいざいせいちょう /経済成長/
けいざいせいちょうりつ /経済成長率/
けいざいせかい /経済世界/
けいざいせんそう /経済戦争/
けいざいたいこく /経済大国/
けいざいたいこくにっぽん /経済大国日本/
けいざいたいさく /経済対策/
けいざいたんい /経済単位;economic unit/
けいざいだんたい /経済団体/
けいざいだんたいれんごうかい /経済団体連合会;経団連 www.keidanren.or.jp/
けいざいちょう /経済庁/
けいざいちょうさ /経済調査/
けいざいちりがく /経済地理学;economic geography/
けいざいてき /経済的/
けいざいてきあつりょく /経済的圧力/
けいざいてきいぞん /経済的依存/
けいざいてきえんじょ /経済的援助/
けいざいてきかち /経済的価値/
けいざいてきかんきょう /経済的環境/
けいざいてきかんてん /経済的観点/
けいざいてききばん /経済的基盤/
けいざいてきこうか /経済的効果/
けいざいてきじじょう /経済的事情/
けいざいてきじりつ /経済的自立/
けいざいてきそんがい /経済的損害/
けいざいてきどくりつ /経済的独立/
けいざいてきはってん /経済的発展/
けいざいてきひつようせい /経済的必要性/
けいざいてきふたん /経済的負担/
けいざいてきよゆう /経済的余裕/
けいざいてきりえき /経済的利益/
けいざいてきりゆう /経済的理由/
けいざいとうけい /経済統計/
けいざいとうせい /経済統制;economic control/
けいざいとっく /経済特区/
けいざいどうゆうかい /経済同友会;www.doyukai.or.jp/
けいざいなんみん /経済難民/
けいざいはくしょ /経済白書/
けいざいはってん /経済発展/
けいざいひょう /経済表;Tableau economique,1758,Quesnay/
けいざいふうさ /経済封鎖/
けいざいふっこう /経済復興/
けいざいぶ /経済部/
けいざいぶろっく /経済ブロック;economic bloc/
けいざいほう /経済法/
けいざいほうこく /経済報告/
けいざいまさつ /経済摩擦/
けいざいめん /経済面/
けいざいもんだい /経済問題/
けいざいらん /経済欄/
けいざいりょく /経済力/
けいざいりろんじょう /経済理論上/
けいざいれん /経済連;[略語]経済農業協同組合連合会/
けいざいろん /経済論/
けいざぶろう /啓三郎/
けいし /軽視/警視/桂枝;cinnamon/兄姉/継子/京師/刑死/継嗣/罫紙/圭司;人名/啓史/圭史/啓示/景士/経始/
けいしき /形式;form/型式;model/
けいしきいがい /形式以外/
けいしきか /形式化/
けいしきかん /形式感/
けいしききじゅつ /形式記述/
けいしきけい /形式系/
けいしきけんさ /型式検査/
けいしきげんご /形式言語/
けいしきげんごりろん /形式言語理論/
けいしきこん /形式婚/
けいしきしてい /形式指定/
けいしきしゅぎ /形式主義/
けいしきしゅぎてき /形式主義的/
けいしきしゅほう /形式手法/
けいしきしよう /形式仕様/
けいしきじょう /形式上/
けいしきすう /形式数/
けいしきず /形式図/
けいしきせい /形式性/
けいしきたいけい /形式体系/
けいしきち /形式知/
けいしきてき /形式的/
けいしきてきしゅほう /形式的手法/
けいしきてきしよう /形式的仕様/
けいしきてきそうさ /形式的操作/
けいしきてきたいけい /形式的体系/
けいしきてきほうほう /形式的方法/
けいしきにんてい /型式認定/形式認定/
けいしきばんごう /形式番号/型式番号/
けいしきび /形式美/
けいしきぶんぽう /形式文法/
けいしきへんかん /形式変換/
けいしきへんこう /形式変更/
けいしきべつ /形式別/
けいしきめい /形式名/
けいしきめいし /形式名詞;[文法]formal noun. eg.「急ぐことはない」の「こと」/
けいしきろん /形式論/
けいしきろんり /形式論理/
けいしきろんりがく /形式論理学/
けいしきろんりてき /形式論理的/
けいしせい /警視正/
けいしそうかん /警視総監/
けいしちょう /警視庁;東京都の警察本部 NB:国の機関は警察庁/
けいしつ /形質/憩室;[医]diverticulum/軽質/継室;後妻/閨室;bedroom/
けいしついでん /形質遺伝/
けいしつさいぼう /形質細胞;[生物]plasma cell/
けいしつゆ /軽質油/
けいしゃ /傾斜/鶏舎/軽車/珪砂/
けいしゃかく /傾斜角/
けいしゃけい /傾斜計/
けいしゃち /傾斜地/
けいしゃてき /傾斜的/
けいしゃはいてん /傾斜配点/
けいしゃほう /傾斜法/
けいしゃほうこう /傾斜方向/
けいしゃめん /傾斜面/
けいしゃりょう /軽車両/
けいしゅ /景趣/警手/
けいしゅう /慶州/閨秀/軽舟/慶周/
けいしゅく /慶祝/痙縮/
けいしゅつ /掲出/
けいしょ /経書/
けいしょう /継承/敬称/警鐘/軽傷;†軽いケガ。「-を負う」/軽症;†軽い症状。「-の風邪」/景勝;-地/形象;image/形勝/景象/卿相/
けいしょうか /形象化/
けいしょうかいそう /継承階層/
けいしょうかんけい /継承関係/
けいしょうきのう /継承機能/
けいしょうけん /継承権/
けいしょうしゃ /継承者/
けいしょうじゅんい /継承順位/
けいしょうせい /継承性/
けいしょうぞくせい /継承属性/
けいしょうち /景勝地/
けいしょうもじ /形象文字/
けいしょうりゃく /敬称略/
けいしょく /軽食/
けいしょくほう /警職法/
けいしょくや /軽食屋/
けいしん /京津/敬神/敬信/恵信/京神/軽信/軽震/茎針/
けいしんせん /京津線/
けいじ /刑事/掲示;notice/啓示;revelation/慶事/計時;時間の計測/経時;時間の経過/継時;連続した時間/繋辞;[言語]copula/形而/兄事/圭司;人名/啓二/啓司/敬二/啓治/圭二/敬司/敬治/慶治/恵司/啓次/桂治/圭児/景示/
けいじか /形而下/
けいじがわ /刑事側/
けいじきかん /掲示期間/
けいじきょく /刑事局/
けいじこくそ /刑事告訴/
けいじこくはつ /刑事告発/
けいじさいばん /刑事裁判/
けいじしゅうきょう /啓示宗教/
けいじしょぶん /刑事処分/
けいじじけん /刑事事件/
けいじじょう /形而上;metaphysical/刑事上;criminal/
けいじじょうがく /形而上学/
けいじじょうがくてき /形而上学的/
けいじすう /掲示数/
けいじせいさく /刑事政策/
けいじせきにん /刑事責任/
けいじそしょう /刑事訴訟/
けいじそしょうきそく /刑事訴訟規則/
けいじそしょうほう /刑事訴訟法/
けいじちゅう /掲示中/
けいじつ /頃日/
けいじてき /経時的;時間の経過による./刑事的;criminal/継時的;時間的に連続した./
けいじてつづき /刑事手続/
けいじどうしゃ /軽自動車/
けいじどうしゃきょうかい /軽自動車協会/
けいじどうしゃぜい /軽自動車税/
けいじどうしゃわく /軽自動車枠/
けいじはん /刑事犯/
けいじばつ /刑事罰/
けいじばん /掲示板/
けいじひこくにん /刑事被告人/
けいじへんか /経時変化/
けいじべんごにん /刑事弁護人/
けいじほしょう /刑事補償/
けいじもの /刑事物/
けいじやく /刑事役/
けいじゅ /圭樹/継受/
けいじゅう /軽重/
けいじゅん /軽巡/
けいじょう /形状/計上/経常/京城/刑場/啓上/警乗/敬譲/
けいじょうがく /計上額/
けいじょうきおく /形状記憶/
けいじょうきおくごうきん /形状記憶合金;[科技]memory metal/
けいじょうけいそく /形状計測/
けいじょうけってい /形状決定/
けいじょうけんきゅう /経常研究/
けいじょうごさ /形状誤差/
けいじょうしゅうし /経常収支/
けいじょうそんしつ /経常損失/
けいじょうてき /形状的/
けいじょうにんしき /形状認識/
けいじょうひ /経常費/
けいじょうみゃく /頚静脈/頸静脈/
けいじょうめい /形状名/
けいじょうようしゃ /軽乗用車/
けいじょうりえき /経常利益/
けいじょうりえきりつ /経常利益率/
けいじょし /係助詞/
けいじよう /掲示用/
けいじろう /慶次郎/啓二郎/圭二郎/圭次郎/恵二郎/啓次朗/
けいす /磬子;お堂の中で置いて使う鐘/
けいすい /軽水/型推/
けいすいろ /軽水炉/
けいすう /係数;coefficient/計数;count/計數;「数」旧字/
けいすうかん /計数管/
けいすうかんかく /計数感覚;利益感覚/
けいすうき /計数器/
けいすうぎょうれつ /係数行列/
けいすうぐん /係数群/
けいすうこうがくか /計数工学科/
けいすうこうがっか /計数工学科/
けいすうたい /係数体/
けいすうち /係数値/
けいすうひょうじ /計数表示/
けいすうりつ /計数率/
けいすけ /啓介/圭介/佳祐/敬介/圭祐/啓祐/啓輔/啓助/佳佑/慶輔/惠介/景介/啓典/桂輔/慶裕/
けいず /系図/
けいずい /頸髄/
けいずかい /窩主買/系図買/
けいせい /形成;formation/形勢;situation.「-不利」/京成;東京・成田。「-電鉄」/傾城/経世;govern.「-済民」/警世;warn.「-の書」/痙性/形声;-文字/刑政/警醒/傾性;disposition/景星;lucky star/
けいせいうえの /京成上野/
けいせいえんせん /京成沿線/
けいせいおおくぼえき /京成大久保駅/
けいせいおしあげ /京成押上/
けいせいか /経世家/
けいせいかてい /形成過程/
けいせいき /形成期/
けいせいげか /形成外科/
けいせいさいみん /経世済民/
けいせいしゃ /形成者/
けいせいしゅじゅつ /形成手術/
けいせいしゅだん /形成手段/
けいせいじゅつ /形成術/
けいせいせきや /京成関屋/
けいせいせん /京成線/
けいせいせんない /京成線内/
けいせいそう /形成層/
けいせいたかさご /京成高砂/
けいせいちば /京成千葉/
けいせいつだぬま /京成津田沼/
けいせいでんてつ /京成電鉄/
けいせいなりた /京成成田/
けいせいはい /京成杯/
けいせいはんだん /形勢判断/
けいせいふなばし /京成船橋/
けいせいほう /形成法/
けいせいほうしき /形成方式/
けいせいほうほう /形成方法/
けいせいほんせん /京成本線/
けいせいもじ /形声文字/
けいせいりょく /形成力/
けいせき /形跡/珪石/
けいせつ /蛍雪/螢雪/
けいせつのこう /蛍雪の功;苦学した成果/
けいせん /罫線/経線/係船/繋船;=係船/恵泉/─/│/┌/┐/┘/└/├/┬/┤/┴/┼/━/┃/┏/┓/┛/┗/┣/┳/┫/┻/╋/┠/┯/┨/┷/┿/┝/┰/┥/┸/╂/
けいせんきのう /罫線機能/
けいせんしゃ /軽戦車/
けいせんそへん /罫線素片/─│┌┐┘└├┬┤┴┼━┃┏┓┛┗┣┳┫┻╋┠┯┨┷┿┝┰┥┸╂;罫線素片一覧/─/│/┌/┐/┘/└/├/┬/┤/┴/┼/━/┃/┏/┓/┛/┗/┣/┳/┫/┻/╋/┠/┯/┨/┷/┿/┝/┰/┥/┸/╂/
けいせんひょう /罫線表/
けいせんもじ /罫線文字/
けいせんわく /罫線枠/
けいぜつ /鶏舌/
けいそ /ケイ素/珪素/刑訴;[法][略語]刑事訴訟(法)/硅素/形素/Si/Silicon/
けいそう /形相/軽装/係争/計装/勁草/珪藻/慶早/継走/軽躁/
けいそういん /形相因;アリストテレス/
けいそうしょぼう /勁草書房/
けいそうしょり /係争処理/
けいそうじこう /係争事項/
けいそうせん /慶早戦/
けいそうちゅう /係争中/
けいそうど /珪藻土;diatom earth. 珪藻の堆積物/軽鬆土;細粒の火山灰土/
けいそうぶつ /係争物/
けいそく /計測/
けいそくかのう /計測可能/
けいそくき /計測器/計測機;†measuring MACHINE/
けいそくぎけん /計測技研/
けいそくこうがっか /計測工学科/
けいそくしゃ /計測者/
けいそくしゅほう /計測手法/
けいそくじ /計測時/
けいそくじどうせいぎょ /計測自動制御/
けいそくじどうせいぎょがっかい /計測自動制御学会/
けいそくせん /鶏足山/
けいそくち /計測値/
けいそくちてん /計測地点/
けいそくてん /計測点/
けいそくど /計速度/
けいそくふかのう /計測不可能/
けいそくほう /計測法/
けいそくほうほう /計測方法/
けいそくよう /計測用/
けいそくりょう /計測量/
けいそくりろん /計測理論/
けいそつ /軽率/軽卒;†低位|軽装の兵卒/輕率;「軽」旧字/
けいそほう /刑訴法/
けいそん /恵存/
けいぞう /形像/恵贈/敬三;人名/恵三/啓三/圭三/慶三/恵造/佳三/経三/
けいぞく /継続/係属/繼續/
けいぞくかのう /継続可能/
けいぞくきんむ /継続勤務/
けいぞくぎょう /継続行/
けいぞくけんさ /継続検査/
けいぞくご /継続後/
けいぞくしよう /継続使用/
けいぞくしんぎ /継続審議;法案は-となった/
けいぞくしんせい /継続申請/
けいぞくじかん /継続時間/
けいぞくせい /継続性/
けいぞくそう /継続相/
けいぞくちえきけん /継続地役権/
けいぞくちゅう /継続中/
けいぞくてき /継続的/
けいぞくとうこう /継続投稿/
けいぞくはん /継続犯/
けいぞくひ /継続費/
けいぞくぶん /継続分/
けいぞくりつ /継続率/
けいぞくりょく /継続力/
けいぞん /恵存/桂損/
けいた /慶太/圭太/
けいたい /携帯/形態;form/形体;feature/継体;跡継ぎ/敬体;ですます体/
けいたい> /携帯;(portable) -ゲーム機,-トイレ/
けいたいか /携帯化/
けいたいがく /形態学/
けいたいがた /携帯型/
けいたいき /携帯機/
けいたいけいせい /形態形成/
けいたいじょうほうたんまつ /携帯情報端末/
けいたいせい /携帯性/
けいたいそ /形態素/
けいたいそかいせき /形態素解析/
けいたいたんまつ /携帯端末/
けいたいてき /形態的/
けいたいてんのう /継体天皇/
けいたいでんわ /携帯電話/
けいたいはいざら /携帯灰皿/
けいたいばんごう /携帯番号/
けいたいひん /携帯品/
けいたいぶんか /形態分化/
けいたいへんか /形態変化/
けいたいべつ /形態別/
けいたいもしゃ /形態模写/
けいたいよう /携帯用/
けいたいようはいざら /携帯用灰皿/
けいたいろん /形態論/
けいたいろんてき /形態論的/
けいたく /恵沢/
けいだ /慶田/
けいだい /境内/慶大/継代/掲題/
けいだいきょうじゅ /慶大教授/
けいだいじょう /慶大情/
けいだんれん /経団連/
けいちつ /啓蟄;[二十四節気]3.6頃/経膣/
けいちゅう /傾注/閨中/契沖;(1640-1701) 国学者/
けいちょう /慶弔/傾聴/軽重/慶長;年号(1596-1615)/茎頂/軽佻;-浮薄/計帳/敬重;敬い重んじる/敬弔;謹んで弔う/憩潮/
けいちょうきん /慶弔金/
けいちょうのえき /慶長の役;[日本史]朝鮮出兵(1597)/
けいちょうふはく /軽佻浮薄/
けいちょうぶんれつそしき /茎頂分裂組織/
けいちょうよう /慶弔用/
けいつい /頚椎;異体字/頸椎/
けいてい /兄弟/係蹄;loop/径庭;隔たり/逕庭;=径庭/
けいていしゃ /兄弟車/
けいてき /警笛/
けいてん /経典;(特に儒教の)賢人の書/啓典;(唯一神の)啓示の書/慶典;祝賀の式典/
けいてんあいじん /敬天愛人/
けいでんき /継電器/
けいと /毛糸/慶人/
けいとう /系統/傾倒/継投/鶏頭;-牛後/恵投/鷄頭;「鶏」旧字/
けいとううんよう /系統運用/
けいとうか /系統化/
けいとうぐん /系統群/
けいとうさく /継投策/
けいとうしっぱい /継投失敗/
けいとうじゅ /系統樹/
けいとうず /系統図/
けいとうせい /系統性/
けいとうてき /系統的/
けいとうてきぶんるい /系統的分類/
けいとうはっせい /系統発生/
けいとうばんごう /系統番号/
けいとうべつ /系統別/
けいとうめい /系統名/
けいとうれんけい /系統連系/
けいとうろん /系統論/
けいとくくうこう /啓徳空港/
けいとくちん /景徳鎮/
けいとざんぐつ /軽登山靴/
けいとせい /計都星/
けいとだま /毛糸玉/
けいとら /軽トラ/
けいとらっく /軽トラック/
けいど /軽度;⇔重度/経度;⇔緯度/傾度;かたむき/
けいどう /傾動/
けいどうみゃく /頚動脈/頸動脈/
けいどほうこう /経度方向/
けいない /系内/
けいなわ /京奈和/
けいなん /慶南/荊南;[中国史]十国の一(907-963)/
けいにく /鶏肉/
けいにりん /軽二輪/
けいにりんしゃ /軽二輪車/
けいねん /経年/
けいねんへんか /経年変化/
けいねんれっか /経年劣化/
けいのじょう /蛍之丞/
けいはい /珪肺/軽輩/
けいはく /軽薄/敬白/
けいはくたんしょう /軽薄短小/
けいはつ /啓発/
けいはん /京阪/
けいはんえんせん /京阪沿線/
けいはんがわ /京阪側/
けいはんごじょうえき /京阪五条駅/
けいはんさんじょう /京阪三条/
けいはんざい /軽犯罪/
けいはんざいほう /軽犯罪法/
けいはんざいほういはん /軽犯罪法違反/
けいはんしん /京阪神/
けいはんしんちく /京阪神地区/
けいはんしんほうめん /京阪神方面/
けいはんせん /京阪線/
けいはんたんばばし /京阪丹波橋/
けいはんたんばばしえき /京阪丹波橋駅/
けいはんでんしゃ /京阪電車/
けいはんでんてつ /京阪電鉄/
けいはんとっきゅう /京阪特急/
けいはんな /京阪奈/
けいはんはい /京阪杯/
けいはんほんせん /京阪本線/
けいば /競馬/
けいばい /競売/啓培/
けいばいぶっけん /競売物件/
けいばうんえい /競馬運営/
けいばおう /競馬王/
けいばかい /競馬会/
けいばかいせつしゃ /競馬解説者/
けいばかんけい /競馬関係/
けいばかんけいしゃ /競馬関係者/
けいばぎょうかい /競馬業界/
けいばく /繋縛/
けいばけんきゅう /競馬研究/
けいばしきほう /競馬四季報/
けいばしょしんしゃ /競馬初心者/
けいばしんぶん /競馬新聞/
けいばじっきょう /競馬実況/
けいばじょう /競馬場/
けいばじょうまえ /競馬場前/
けいばせんもんし /競馬専門紙/競馬専門誌/
けいばせんよう /競馬専用/
けいばちゅうけい /競馬中継/
けいばつ /刑罰/閨閥/警抜/
けいばつけん /刑罰権/
けいばにんき /競馬人気/
けいばはくぶつかん /競馬博物館/
けいばばんぐみ /競馬番組/
けいばばんぐみひょう /競馬番組表/
けいばほう /競馬法;[法]/競馬報;?/
けいばよそう /競馬予想/
けいばれき /競馬歴/
けいひ /経費/桂皮/荊扉/
けいひこうき /軽飛行機/
けいひさくげん /経費削減/
けいひせつげん /経費節減/
けいひせつやく /経費節約/
けいひつ /警蹕/
けいひょうほう /景表法;[法][略語]景品表示法/
けいひよさん /経費予算/
けいひん /景品/京浜/
けいひんきゅうこう /京浜急行/
けいひんきゅうこうえんせん /京浜急行沿線/
けいひんきゅうこうせん /京浜急行線/
けいひんきゅうこうでんてつ /京浜急行電鉄/
けいひんこうかん /景品交換/
けいひんこうかんじょ /景品交換所/
けいひんせん /京浜線/
けいひんちく /京浜地区/
けいひんとうほく /京浜東北/
けいひんとうほくせん /京浜東北線/
けいひんひょうじほう /景品表示法;不当景品類及び不当表示防止法/
けいび /警備/軽微/
けいびいん /警備員/
けいびき /罫引/
けいびしゃりょう /警備車両/
けいびじょう /警備上/
けいびたい /警備隊/
けいびたいいん /警備隊員/
けいびてい /警備艇/
けいびへい /警備兵/
けいびん /軽便/慧敏/
けいびんてつどう /軽便鉄道/
けいふ /系譜/継父/
けいふうまる /啓風丸/
けいふか /軽負荷/
けいふく /敬服/慶福/京福/
けいふくでんてつ /京福電鉄/
けいふず /系譜図/
けいふぼ /継父母/
けいふん /鶏糞/軽粉/
けいぶ /警部/頸部/頚部/軽侮/
けいぶつ /景物/
けいぶつし /景物詩/
けいぶほ /警部補/
けいぶん /慶文/
けいぶんしゃ /勁文社;[出版社名] NB:2002年倒産/
けいべつ /軽蔑/
けいべつご /軽蔑語/
けいべつてき /軽蔑的/
けいべん /軽便/
けいほ /警保/
けいほう /警報/刑法/
けいほういはん /刑法違反/
けいほうおん /警報音/
けいほうかいじょ /警報解除/
けいほうき /警報機/警報器/
けいほうこう /径方向/
けいほうじょう /刑法上/
けいほうそうち /警報装置/
けいほうはん /刑法犯/
けいほきょく /警保局/
けいほく /京北/
けいほくせん /京北線/
けいぼ /継母/敬慕/景慕/
けいぼう /警棒/警防/閨房/圭膀/
けいま /桂馬/
けいまい /兄妹/
けいみょう /軽妙/
けいみょうしゃだつ /軽妙洒脱/
けいみん /傾眠/
けいむ /警務/刑務/
けいむいん /警務員/
けいむかん /刑務官/
けいむしょ /刑務所/
けいむぶ /警務部/
けいめい /啓明/鶏鳴/経明/
けいめいがくえん /啓明学園/
けいめいくとう /鶏鳴狗盗;くだらぬ芸(でも役に立つ)/
けいめん /軽免/
けいめんきょ /軽免許/
けいもう /啓蒙/
けいもううんどう /啓蒙運動/
けいもうかつどう /啓蒙活動/
けいもうざっし /啓蒙雑誌/
けいもうしそう /啓蒙思想/
けいもうしょ /啓蒙書/
けいもうてき /啓蒙的/
けいやく /契約/
けいやくか /契約課/
けいやくかいじょ /契約解除/
けいやくかんけい /契約関係/
けいやくきかん /契約期間/
けいやくきかんまんりょう /契約期間満了/
けいやくきん /契約金/
けいやくこうかい /契約更改/
けいやくこうしょう /契約交渉/
けいやくご /契約後/
けいやくさき /契約先/
けいやくしゃ /契約者/
けいやくしゃいん /契約社員/
けいやくしょ /契約書/
けいやくじ /契約時/
けいやくじこう /契約事項/
けいやくじょう /契約上/
けいやくせい /契約制/
けいやくせいりつ /契約成立/
けいやくせつ /契約説;社会-/
けいやくちゅう /契約中/
けいやくていけつ /契約締結/
けいやくないよう /契約内容/
けいやくのしっぱい /契約の失敗;[経済]contract failure/
けいやくはき /契約破棄/
けいやくひ /契約費/
けいやくび /契約日/
けいやくぶん /契約分/
けいやくほう /契約法/
けいやくほうほう /契約方法/
けいやくまんりょう /契約満了/
けいやくやっかん /契約約款/
けいやくりょう /契約料/契約量/
けいゆ /経由/軽油/
けいゆう /経由/系由/
けいゆうびん /経由便/
けいゆしゃ /軽油車/
けいゆぜい /軽油税/
けいゆち /経由地/
けいゆびん /経由便/
けいよ /恵与/刑余/
けいよう /形容/掲揚/茎葉/京葉;東京・千葉/繋養/
けいようく /形容句/
けいようぐち /京葉口/
けいようご /形容語/
けいようし /形容詞/
けいようしてき /形容詞的/
けいようじ /掲揚時/
けいようせん /京葉線/
けいようせんとうきょうえき /京葉線東京駅/
けいようせんない /京葉線内/
けいようせんまいはまえき /京葉線舞浜駅/
けいようたい /茎葉体/
けいようどうし /形容動詞/
けいようどうろ /京葉道路/
けいようぶ /茎葉部/
けいようむじゅん /形容矛盾/
けいよん /軽四;軽四輪自動車/
けいよんりん /軽四輪/
けいら /警邏/警ら/軽羅;軽い薄衣/
けいらく /経絡/京洛/
けいらん /鶏卵/
けいり /経理/計理;≒経理.「-士」/刑吏;executioner/警吏;policeman/
けいりか /経理課/
けいりかちょう /経理課長/
けいりがかり /経理係/経理掛/
けいりきん /経理金/
けいりく /刑戮/
けいりし /計理士/
けいりしょり /経理処理/
けいりじょう /経理上/
けいりたんとう /経理担当/
けいりつ /刑律/
けいりてき /経理的/
けいりひかえ /経理控/
けいりぶ /経理部/
けいりぶじょうほう /経理部情報/
けいりぶもん /経理部門/
けいりゃく /計略/経略/
けいりゅう /渓流/係留/繋留;=係留/掛留;[音楽]/稽留;留まる・滞る/憩流;潮流が止まること/谿流;=渓流/
けいりゅうおん /継留音/
けいりゅうざお /渓流竿/
けいりゅうづり /渓流釣り/
けいりょう /軽量;lightweight/計量;measure/
けいりょうか /軽量化;「PCの-」/計量化;measure.「リスクの-」/
けいりょうかっぷ /計量カップ;200cc/
けいりょうき /計量器/
けいりょうきゅう /軽量級/
けいりょうけいざいがく /計量経済学;econometrics/
けいりょうけん /計量研/
けいりょうこうしゅつりょく /軽量高出力/
けいりょうじょうほう /計量情報/
けいりょうすぷーん /計量スプーン/
けいりょうせい /軽量性/
けいりょうてき /計量的/
けいりょうてんそる /計量テンソル/
けいりょうば /軽量馬/
けいりょうほう /計量法/
けいりん /競輪/桂林/経綸/
けいりんおう /競輪王/
けいりんかい /競輪界/
けいりんじょう /競輪場/
けいりんせんしゅ /競輪選手/
けいりんどう /啓林堂/
けいるい /係累/繋累;≒係累/
けいれい /敬礼/
けいれき /経歴/
けいれきしょ /経歴書/
けいれつ /系列/勁烈/
けいれつか /系列化/
けいれつがいしゃ /系列会社/
けいれつきぎょう /系列企業/
けいれつきょく /系列局/
けいれつこうか /系列効果/
けいれつしせつ /系列施設/
けいれつてき /系列的/
けいれつてん /系列店/
けいれつない /系列内/
けいれん /痙攣/
けいれんせい /痙攣性/
けいろ /経路/毛色/径路;こみち/
けいろう /敬老/
けいろうどう /軽労働/
けいろうのひ /敬老の日;九月の第三月曜日/
けいろがい /経路外/
けいろく /鶏肋/
けいろしてい /経路指定/
けいろじょう /経路上/
けいろじょうほう /経路情報/
けいろじょうほうこうかん /経路情報交換/
けいろすう /経路数/
けいろせいぎょ /経路制御/
けいろせきぶん /経路積分/
けいろせってい /経路設定/
けいろせんたく /経路選択/
けいろたんさく /経路探索/
けいろちょう /経路長/
けいろひょう /経路表/
けいろへんこう /経路変更/
けいわ /計和/
けいわんしょうこうぐん /頸腕症候群/
けう /稀有/希有/
けうら /毛裏/
けおり /毛織/毛織り/
けおりもの /毛織物/
けかえし /蹴返し/
けが /怪我;(当て字)/
けがい /化外/
けがに /毛蟹/
けがにん /怪我人;(当て字)/けが人/ケガ人/
けがれ /穢れ;(特に禁忌的な不浄をいう)/汚れ;NB:「よごれ」と同形/穢/
けがわ /毛皮/
けがわや /毛皮屋/
けぎ /化儀/
けぎょう /加行/
けぎらい /毛嫌い/
けげん /怪訝/化現/
けこ /花籠;仏具/
けこう /花香/華香/
けこみ /蹴込/蹴込み;階段の垂直な板/
けご /毛蚕/
けごろも /毛衣/裘/
けごん /華厳/華嚴;旧字/
けごんぎょう /華厳経/
けごんしゅう /華厳宗/
けごんじ /華厳寺;鈴虫寺,京都/
けごんのたき /華厳滝/
けさ /今朝/袈裟/畩;=袈裟/
けさがけ /袈裟懸け/
けさがた /今朝方/
けさがため /袈裟固め/
けさき /毛先/
けさぎり /袈裟切り/
けさほど /今朝程/
けし /罌粟;hoppy/芥子;=罌粟 NB:「からし」とも/消し/
けしいん /消印/
けしからぬ /怪しからぬ/
けしからん /怪しからん/
けしき /景色;view/気色;-ばむ/
けしこみ /消込/消し込み/
けしごむ /消しゴム/
けしずみ /消し炭/消炭/
けしずみいろ /消し炭色/
けしずみぐろ /消し炭黒/
けしつぶ /芥子粒/
けして /決して/
けしぼん /芥子本/
けしむらさき /滅紫/
けしもく /ケシ目/Papaverales/Rhoeadales/
けしもくぐん /ケシ目群/
けしょう /化粧/化生/
けしょういた /化粧板/
けしょうがけ /化粧掛け/化粧掛/
けしょうごうはん /化粧合板/
けしょうしつ /化粧室/
けしょうじお /化粧塩/
けしょうすい /化粧水/
けしょうせっけん /化粧石鹸/
けしょうだい /化粧台/
けしょうだち /化粧裁ち/
けしょうだな /化粧棚/
けしょうだんす /化粧箪笥;dresser/
けしょうなおし /化粧直し/
けしょうばこ /化粧箱/
けしょうばん /化粧板/
けしょうひん /化粧品/
けしょうひんがいしゃ /化粧品会社/
けしょうひんはんばい /化粧品販売/
けしょうひんや /化粧品屋/
けしょうまわし /化粧回し;[相撲]/
けしょうめん /化粧面/
けしょうりょうほう /化粧療法/
けしん /化身/
けじらみ /毛虱/
けすじ /毛筋/
けずね /毛脛/
けずりくず /削り屑;鉛筆の-/
けずりぶし /削り節/
けせん /気仙/
けせんぬま /気仙沼/
けそう /懸想/
けそうびと /懸想人/
けそうぶみ /懸想文/
けぞめ /毛染め/
けぞり /毛剃り/
けた /桁/
けたい /懈怠/化体/仮諦;[仏教]/
けたいくそ /卦体糞;けったくそ/
けたいち /桁位置/
けたおち /桁落ち/
けたか /気高/
けたぐり /蹴手繰り/
けたごと /桁毎/
けたすう /桁数/
けたすうぶん /桁数分/
けたちがい /桁違い/
けたはずれ /桁外れ/けた外れ/
けたばし /桁橋/
けたひょうじ /桁表示/
けため /桁目/
けたゆき /桁行/
けだかい /気高い/
けだし /蓋し/
けだま /毛玉/
けだもの /獣/
けち /吝/
けちえん /結縁/
けちみゃく /血脈/
けちょう /怪鳥/
けちんぼう /けちん坊/
けっか /結果/欠課/結跏;-趺坐/闕下/決河/
けっかい /結界/決壊;ダムの-/血塊/決潰;=決壊/欠壊;欠けて壊れる/
けっかおーらい /結果オーライ/
けっかく /結核/欠格/
けっかくきん /結核菌/
けっかくしょう /結核症/
けっかくじこう /欠格事項/
けっかくよぼうほう /結核予防法/
けっかご /結果後/
けっかさくせい /結果作成/
けっかさんしょう /結果参照/
けっかしき /結果式/
けっかしだい /結果次第/
けっかせきにん /結果責任/
けっかそくほう /結果速報/
けっかてき /結果的/
けっかてきかじゅうはん /結果的加重犯/
けっかはっぴょう /結果発表/
けっかはっぴょうご /結果発表後/
けっかはんてい /結果判定/
けっかふざ /結跏趺坐/
けっかほうこく /結果報告/
けっかまち /結果待ち/
けっかよそう /結果予想/
けっかりすと /結果リスト/
けっかろん /結果論/
けっかろんてき /結果論的/
けっかん /血管/欠陥/欠巻/穴間/缺陷/
けっかんかくちょう /血管拡張/
けっかんけい /血管系;vascular system/
けっかんしゃ /欠陥車/
けっかんしゅ /血管腫/
けっかんしょうがい /血管障害/
けっかんしょうひん /欠陥商品/
けっかんじゅうたく /欠陥住宅/
けっかんない /血管内/
けっかんひん /欠陥品/
けっかんへき /血管壁/
けっき /決起/血気/蹶起/
けっきざかり /血気盛り/
けっきしゅうかい /決起集会/
けっきゅう /血球/結球/
けっきょ /穴居/
けっきょく /結局/
けっきん /欠勤/
けっく /結句/
けっけいもじ /楔形文字/
けっこう /結構/決行/血行/欠航/結好/欠行/
けっこう> /結構/
けっこうかいてき /結構快適/
けっこうかんたん /結構簡単/
けっこうこうか /結構高価/
けっこうごうか /結構豪華/
けっこうしぜん /結構自然/
けっこうしょうがい /血行障害/
けっこうしょく /血紅色/
けっこうたいへん /結構大変/
けっこうだいたん /結構大胆/
けっこうちょうほう /結構重宝/
けっこうひさん /結構悲惨/
けっこうび /決行日/
けっこうびん /欠航便/
けっこうふべん /結構不便/
けっこうへいき /結構平気/
けっこうべんり /結構便利/
けっこうまえ /結構前/
けっこうむかし /結構昔/
けっこうめんどう /結構面倒/
けっこうわだい /結構話題/
けっこん /結婚/血痕/
けっこんあいて /結婚相手/
けっこんいわい /結婚祝/結婚祝い/
けっこんかん /結婚観/
けっこんがんぼう /結婚願望/
けっこんきねん /結婚記念/
けっこんきねんび /結婚記念日/
けっこんご /結婚後/
けっこんさぎ /結婚詐欺/
けっこんさんぎょう /結婚産業/
けっこんしき /結婚式/
けっこんしきじょう /結婚式場/
けっこんしきん /結婚資金/
けっこんしょうかいじょ /結婚紹介所/
けっこんじ /結婚時/
けっこんじき /結婚時期/
けっこんせいかつ /結婚生活/
けっこんぜんご /結婚前後/
けっこんそうだん /結婚相談/
けっこんそうだんじょ /結婚相談所/
けっこんたいしょく /結婚退職/
けっこんてきれいき /結婚適齢期/
けっこんとうしょ /結婚当初/
けっこんねんれい /結婚年齢/
けっこんばなし /結婚話/
けっこんひよう /結婚費用/
けっこんひろうえん /結婚披露宴/
けっこんほうどう /結婚報道/
けっこんまえ /結婚前/
けっこんものがたり /結婚物語/
けっこんゆびわ /結婚指輪/
けっこんりつ /結婚率/
けっこんれき /結婚歴/
けっさい /決済;†settle.「注文の-」/決裁;†decide.「部長の-」/潔斎/
けっさいけん /決裁権/
けっさいしょ /決裁書/
けっさいせい /決済性/
けっさいせいよきん /決済性預金/
けっさいせんもんぎんこう /決済専門銀行/
けっさいび /決裁日/
けっさいほうほう /決済方法/
けっさいようよきん /決済用預金/
けっさく /傑作/結索/結紮;けっさつ?/
けっさくしゅう /傑作集/
けっさくすいり /傑作推理/
けっさくせん /傑作選/傑作撰/
けっさくば /傑作馬/
けっさつ /結紮/
けっさつじゅつ /結紮術/
けっさん /決算/
けっさんい /決算委/
けっさんき /決算期/
けっさんこうこく /決算公告/
けっさんしょ /決算書/
けっさんじょう /決算上/
けっさんたんしん /決算短信/
けっさんひょう /決算表/
けっさんび /決算日/
けっさんほうこく /決算報告/
けっさんほうこくしょ /決算報告書/
けっし /決死/傑士/血祀/
けっしきそ /血色素/
けっしけん /決死圏/
けっしたい /決死隊/
けっしつ /欠失/
けっして /決して/
けっしゃ /結社/
けっしゅ /血腫/
けっしゅう /結集/血臭/
けっしゅつ /傑出/
けっしょ /血書/闕所;[日本史](鎌倉・室町時代の)没収/欠所;[日本史](江戸時代の)没収/
けっしょう /決勝/結晶/血漿;[医]plasma/血症;(語の一部) シトルリン-,低酸素-/血笑/結漿/
けっしょうかがく /結晶化学;crystal chemistry/
けっしょうがく /結晶学;crystallography/
けっしょうがた /結晶型/
けっしょうけい /結晶系;crystal system. 結晶の分類/結晶形;crystal form. 結晶の外形/
けっしょうけっか /決勝結果/
けっしょうこうがく /結晶光学;crystal optics/
けっしょうこうし /結晶格子;[化学]crystal lattice/
けっしょうこうぞう /結晶構造/
けっしょうしつ /結晶質/
けっしょうしゅうりょうご /決勝終了後/
けっしょうしんしゅつ /決勝進出/
けっしょうじく /結晶軸;[化学]/
けっしょうすい /結晶水/
けっしょうせかい /結晶世界/
けっしょうせき /結晶石/
けっしょうせん /決勝戦/
けっしょうたいかい /決勝大会/
けっしょうだ /決勝打/
けっしょうだん /決勝弾/
けっしょうてん /決勝点/
けっしょうとーなめんと /決勝トーナメント/
けっしょうにってい /決勝日程/
けっしょうばん /血小板/
けっしょうばんゆけつ /血小板輸血/
けっしょうび /決勝日/
けっしょうぶんかくせいざい /血漿分画製剤/
けっしょうへんがん /結晶片岩;crystalline schist/
けっしょうほんるいだ /決勝本塁打/
けっしょうめん /結晶面;[化学]crystal face/
けっしょく /血色/欠食/
けっしょくじどう /欠食児童/
けっしん /決心/結審/
けっせい /結成/血清/
けっせいかんえん /血清肝炎/
けっせいしき /結成式/
けっせいじ /結成時/
けっせいせいぶん /血清成分/
けっせいちゅうしゃ /血清注射/
けっせいりゆう /結成理由/
けっせいりょうほう /血清療法/
けっせき /欠席/結石/血石/
けっせきさいばん /欠席裁判/
けっせきしゃ /欠席者/
けっせきとどけ /欠席届/
けっせきにっすう /欠席日数/
けっせきはんけつ /欠席判決/
けっせつ /結節/
けっせつてん /結節点;node/
けっせん /決戦;†/血栓/結線/血戦/決選;†「-投票」/決戰;「戦」旧字/
けっせんしょう /血栓症;[医]/
けっせんじ /結線時/
けっせんじょうほう /結線情報/
けっせんず /結線図/
けっせんたいかい /決戦大会/
けっせんとうひょう /決選投票/
けっせんへんあつき /結線変圧器/
けっそう /血相/傑僧/
けっそうこん /纈草根/
けっそく /結束/欠測/
けっそくりょく /結束力/
けっそん /欠損/
けっそんがく /欠損額/
けっそんきん /欠損金;[会計]loss/
けっそんしょう /欠損症/
けっそんち /欠損値/
けったく /結託/
けったん /血痰/
けっちゃく /決着/結着;「-剤」/
けっちゃくざい /結着剤/
けっちゅう /血中/桀紂/
けっちゅうさんそのうど /血中酸素濃度/
けっちょう /結腸/
けっちん /血沈/
けってい /決定/
けっていあん /決定案/
けっていかのう /決定可能/
けっていかのうせい /決定可能性/
けっていき /決定機/決定木/
けっていきこう /決定機構/
けっていきじゅん /決定基準/
けっていぎ /決定木/
けっていけい /決定系/
けっていけいすう /決定係数/
けっていけん /決定権/
けっていけんげん /決定権限/
けっていこう /決定稿/
けっていご /決定後/
けっていしえん /決定支援/
けっていしゃ /決定者/
けっていしゅほう /決定手法/
けっていじ /決定時/
けっていじこう /決定事項/
けっていじょうきょう /決定状況/
けっていせい /決定性/
けっていせん /決定戦/
けっていせんりゃく /決定戦略/
けっていそしき /結締組織/
けっていだ /決定打/
けっていてき /決定的/
けっていてきしゅんかん /決定的瞬間/
けっていばん /決定版/決定番/
けっていひょう /決定表/
けっていふかのう /決定不可能/
けっていふかのうせい /決定不可能性/
けっていほう /決定法/
けっていほうしき /決定方式/
けっていほうほう /決定方法/
けっていもんだい /決定問題/
けっていよういん /決定要因/
けっていりょく /決定力/
けっていりろん /決定理論/
けっていろん /決定論/
けっていろんしゃ /決定論者/
けっていろんてき /決定論的/
けってき /闕腋/
けってん /欠点/缺點/
けっとう /血統/決闘/血糖/結党/
けっとうがんりゅうじま /決闘巌流島/
けっとうざい /決闘罪/
けっとうしょ /血統書/
けっとうじてん /血統辞典/血統事典/
けっとうじょう /決闘状/
けっとうず /血統図/
けっとうち /血糖値/
けっとうてき /血統的/
けっとうひょうか /血統評価/
けっぱい /欠配/
けっぱく /潔白/
けっぱつ /結髪/
けっぱん /血判/血斑/
けっぱんじょう /血判状/
けっぴょう /結氷/
けっぴん /欠品/
けっぴんちゅう /欠品中/
けっぷん /血粉/
けっぺい /血餅/
けっぺき /潔癖/
けっぺきしょう /潔癖症/潔癖性/
けっぽう /血泡/欠報/
けっぽん /欠本/
けつ /欠/決/血/穴/尻/傑;豪傑/杰;「傑」の異体字/桀;桀紂/偈;(げ)/碣;(いしぶみ)墓碣/竭;(つきる)/夬;(わける)/訣;訣別/决;「決」の異体字/抉;えぐ・る/刔;えぐ・る/缺;「欠」の旧字/蕨;わらび/厥;(その)/獗;猖獗/蹶;蹶起/闕;闕員(=欠員)/歇;間歇/結;完結/桔;桔梗/頡/纈;ゆはた/襭;(つまばさむ)/頁;ぺーじ/潔;清潔/亅/孑;孑孑(ぼうふら)/訐;(あばく)/譎;(いつわる)/
けつあつ /血圧/
けつあつけい /血圧計/
けつあつじょうしょう /血圧上昇/
けつあつそくていよう /血圧測定用/
けつい /決意/
けついん /欠員/闕員/
けつえき /血液/
けつえきかんせん /血液感染/
けつえきがた /血液型/
けつえきぎんこう /血液銀行;blood bank/
けつえきけい /血液系/
けつえきけんさ /血液検査/
けつえきさいぼう /血液細胞/
けつえきせいざい /血液製剤/
けつえきちゅう /血液中/
けつえきのうかんもん /血液脳関門;[医]blood-brain barrier/
けつえきはんのう /血液反応/
けつえきびょう /血液病/
けつえきりょう /血液量/
けつえん /血縁/結縁/
けつえんかんけい /血縁関係/
けつおう /傑王/
けつがん /頁岩/
けつぎ /決議/決疑;-論/決義;?/
けつぎあん /決議案/
けつぎぶん /決議文/
けつぎろん /決疑論/
けつげん /結言/
けつご /結語/
けつごう /結合/欠号/
けつごうえねるぎー /結合エネルギー/
けつごうおん /結合音/
けつごうかじゅう /結合荷重/
けつごうがた /結合型/
けつごうきこう /結合機構/
けつごうけい /結合系/
けつごうけいじょう /結合形状/
けつごうけいすう /結合係数/
けつごうし /結合子/
けつごうしき /結合織/
けつごうじょうたい /結合状態/
けつごうじょうほう /結合情報/
けつごうすい /結合水/
けつごうすう /結合数/
けつごうせい /結合性/
けつごうそく /結合則/
けつごうそしき /結合組織/
けつごうたい /結合体/
けつごうたんぱくしつ /結合蛋白質/
けつごうち /結合値/
けつごうていすう /結合定数/
けつごうてき /結合的/
けつごうてすと /結合テスト/
けつごうど /結合度/
けつごうぶ /結合部/
けつごうほう /結合法/
けつごうほうそく /結合法則/
けつごうみゃく /結合脈/
けつごうもう /結合網/
けつごうよう /結合用/
けつごうりつ /結合律/
けつごうりょく /結合力/
けつじ /欠字/結辞/闕字/
けつじつ /結実/
けつじゅう /結集/
けつじょ /欠如/欠除;remove/闕如;=欠如/
けつじょう /欠場/楔状/結縄/決定/
けつじょうもじ /楔状文字/結縄文字/
けつじん /傑人/
けつぜい /血税/
けつぜん /決然/蹶然;跳ね起きる様子/孑然;抜きん出る様子/
けつぞう /結像/
けつぞうきょり /結像距離/
けつぞうめん /結像面/
けつぞく /血族/
けつだん /決断/結団/
けつにく /血肉/
けつにょう /血尿/
けつね /狐/
けつばん /欠番/
けつび /結尾/
けつぶつ /傑物/
けつぶん /結文/
けつべつ /決別/訣別;=決別/
けつべん /血便/
けつぼう /欠乏/欠亡;(主に[法]) 「社員の-」/
けつぼうしょう /欠乏症/
けつぼうせい /欠亡性/
けつまく /結膜/
けつまくえん /結膜炎/
けつまつ /結末/
けつみゃく /血脈/
けつめい /血盟/結盟/決明/
けつめいし /決明子/
けつゆうびょう /血友病/
けつゆうびょうかんじゃ /血友病患者/
けつらく /欠落/
けつらくぶぶん /欠落部分/
けつりゅう /血流/血瘤/
けつりゅうおん /血流音/
けつりゅうりょう /血流量/
けつりょう /結了/血量/
けつるい /血涙/
けつれい /欠礼/
けつれつ /決裂/
けつろ /結露/血路/
けつろたいさく /結露対策/
けつろぼうし /結露防止/
けつろん /結論/
けつろんしき /結論式/
けつろんてき /結論的/
けつろんぶ /結論部/
けづか /毛塚/
けづくろい /毛繕い/
けづな /毛綱/
けづめ /距/蹴爪/
けづや /毛艶/
けと /化土/
けとう /毛唐/
けとば /言葉/
けどう /化導/
けどういん /祁答院/
けない /家内/化内/
けなげ /健気/
けなしだいら /毛無平/
けなみ /毛並み/毛並/
けに /化尼/
けにん /化人/
けぬき /毛抜き;tweezer/鑷/毛抜/
けねん /懸念/
けねんざいりょう /懸念材料/
けのび /蹴伸び;水泳の練習/
けはい /気配/
けはいね /気配値/
けはえぐすり /毛生え薬/
けはひ /化粧/気配/
けば /毛羽/
けばり /毛鉤/
けびいし /検非違使/
けびき /毛引き/罫引/
けびきおどし /毛引縅/
けびきがみ /罫引紙/
けびょう /仮病/
けふぇうすざ /ケフェウス座;Cepheus(Cep)/
けぶ /煙/烟;「煙」の異体字/
けぶつ /化仏/
けぶり /気振り/
けほう /化法/
けぼうき /毛箒/
けぼうし /毛帽子/
けぼうず /毛坊主/
けぼり /毛彫/
けまうち /毛馬内/
けまり /蹴鞠/
けみがわ /検見川/
けみがわはま /検見川浜/
けむ /煙/烟;「煙」の異体字/
けむし /毛虫/
けむり /煙/烟;「煙」の異体字/
けもの /獣/獸;「獣」の旧字(人名用漢字)/
けものぞく /獣族/
けものへん /獣偏/
けものみち /獣道/
けもん /仮門/
けやき /欅/槻/
けやりむし /毛槍虫/
けら /螻蛄/
けらい /家来/
けらく /快楽/
けらば /螻蛄羽;[建築]切妻の端/
けらまれっとう /慶良間列島;地名/
けり /鳧/蹴り/
けりょう /仮令/家領/
けれんみ /外連味/ケレン味/
けろくろ /蹴轆轤/
けわい /化粧/
けん /件/券/県/剣/兼/権/拳/軒/腱/圏/研/犬/間;6尺/乾;[八卦]陽陽陽/建;建築/健;健康/鍵;鍵盤/嫌;嫌悪/謙;謙譲/慊/歉/賢;賢者/堅;堅実/樫;かし/慳;邪慳/鰹;かつお/倹;倹約/検;検査/険;険悪/験;経験/鹸;石鹸/嶮;嶮岨/臉/瞼;まぶた/儉;「倹」の旧字(人名用漢字)/檢;「検」の旧字(人名用漢字)/險;「険」の旧字(人名用漢字)/驗;「験」の旧字(人名用漢字)/劍;「剣」の旧字(人名用漢字)/劔;「剣」の旧字2/劒;「剣」の旧字3/剱;「剣」の旧字4/釼;「剣」の異体字/絹;(きぬ)絹糸/娟/涓/狷;狷介/羂;わな/鵑;杜鵑/巻;巻雲/倦;倦怠/惓;≒倦/捲;席捲/劵;「券」の旧字/卷;「巻」の旧字(人名用漢字)/圈;「圏」の旧字(人名用漢字)/椦;(幽霊文字?)/眷;眷属/綣/蜷;にな/見;見物/俔/硯;(すずり)硯水/筧;かけい/懸;懸命/縣;「県」の旧字(人名用漢字)/遣;派遣/譴;譴責/謇/蹇;あしなえ/喧;喧騒/愃/暄;あたたかい/諠;諠譁(=喧嘩)/萱;かや/權;「権」の旧字/顴;(頬骨)/献;文献/獻;「献」の旧字/絢;絢爛/監;(呉音) 監督/憲;憲法/牽;牽引/肩;双肩/繭;(まゆ) 絹糸/凵;(かんにょう)/妍;-を競う/幵;(たいら)/愆;(たがう)/甄/繝;繧繝/虔;敬虔/騫;閔子騫/黔;(くろい)/顕;顕著/顯;「顕」の旧字(人名用漢字)/搴;(ぬく)/眩;(漢音) 眩暈/鉉;(漢音) つる/擧;「挙」の旧字,?/舉;「挙」の異体字,?/
けん> /県;県西部,県議会/嫌/兼/
けんあい /眷愛/兼愛/
けんあく /険悪/
けんあん /懸案/検案/
けんあんしょ /検案書/
けんあんじこう /懸案事項/
けんい /権威/健胃/
けんいか /権威化/
けんいき /圏域/県域/
けんいしゃ /権威者/
けんいしゅぎ /権威主義/
けんいしゅぎてき /権威主義的/
けんいすじ /権威筋/
けんいち /健一/賢一/憲一/謙一/研一/建一/堅一/剣一/乾一/
けんいちろう /健一郎/謙一郎/健一朗/顕一郎/
けんいてき /権威的/
けんいやく /健胃薬/
けんいん /牽引/検印/
けんいんしゃ /牽引車/
けんいんじ /牽引時/
けんいんそうち /牽引装置/
けんいんやく /牽引役/
けんいんりょく /牽引力/
けんいんれっしゃ /牽引列車/
けんうん /巻雲/絹雲;=巻雲/
けんえい /県営/兼営/建永;年号(1206-1207)/献詠/顕栄/
けんえき /検疫/権益/
けんえきかくほ /権益確保/
けんえきかん /検疫官/
けんえきしゃ /権益者/
けんえきしょ /検疫所/
けんえきじょ /検疫所/
けんえきほう /検疫法/
けんえつ /検閲/憲悦/
けんえつかん /検閲官/
けんえつさくじょ /検閲削除/
けんえつせいど /検閲制度/
けんえん /嫌煙/犬猿/倦厭;飽き飽き/嫌厭;嫌い厭う/
けんえんうんどう /嫌煙運動/
けんえんか /嫌煙家/
けんえんけん /嫌煙権/
けんえんしゃ /嫌煙者/
けんえんだんたい /嫌煙団体/
けんえんは /嫌煙派/
けんお /嫌悪/嫌惡;「悪」旧字/
けんおう /県央/賢王/
けんおうどう /圏央道/
けんおかん /嫌悪感/
けんおん /検温/建音/
けんおんき /検温器/
けんおんけん /建音研/
けんか /喧嘩/県下/献花/県花/堅果;nut/鹸化;[化学]saponify/
けんかい /見解/県会/狷介/研開/
けんかいぎいん /県会議員/
けんかうり /喧嘩売/
けんかく /剣客/懸隔/見覚/
けんかこうろん /喧嘩口論/
けんかごし /喧嘩腰/
けんかしょくぶつ /顕花植物/
けんかじょうず /喧嘩上手/
けんかだい /献花台/
けんかだいいち /県下第一/
けんかべつ /喧嘩別/
けんかまつり /喧嘩祭り/喧嘩祭/
けんかよつ /喧嘩四つ;[相撲]/
けんかりょうせいばい /喧嘩両成敗/
けんかわかれ /喧嘩別れ;前の男と-/
けんかん /建艦/顕官/兼官/
けんが /懸河/懸下/
けんがい /圏外/県外/懸崖/遣外/
けんがく /見学/建学/研学/兼学/
けんがくかい /見学会/
けんがくしゃ /見学者/
けんがくじかん /見学時間/
けんがくほうこく /見学報告/
けんがくまえ /見学前/
けんがみね /剣ヶ峰/
けんがん /検眼/
けんき /嫌気/建機;建設機械/嫌忌/顕貴/
けんきざい /嫌忌剤/
けんきせい /嫌気性/
けんきせいきん /嫌気性菌/
けんきせいせっちゃくざい /嫌気性接着剤/
けんきち /健吉/賢吉/
けんきゃく /健脚/剣客/
けんきゅう /研究/建久;年号(1190-1199)/
けんきゅうい /研究医/
けんきゅういいんかい /研究委員会/
けんきゅういん /研究員;researcher/研究院;institute/
けんきゅうか /研究科;course/研究家;researcher/
けんきゅうかい /研究会/
けんきゅうかいいん /研究会員/
けんきゅうかいいんかい /研究科委員会/
けんきゅうかいかいさい /研究会開催/
けんきゅうかいかつどう /研究会活動/
けんきゅうかいかんじ /研究会幹事/
けんきゅうかいきょうさい /研究会共催/
けんきゅうかいけいしき /研究会形式/
けんきゅうかいし /研究会誌/
けんきゅうかいしりょう /研究会資料/
けんきゅうかいとうろく /研究会登録/
けんきゅうかいはっぴょう /研究会発表/
けんきゅうかいはつ /研究開発/
けんきゅうかいはつか /研究開発課/
けんきゅうかいはつきこう /研究開発機構/
けんきゅうかいはつしつ /研究開発室/
けんきゅうかいはつしょく /研究開発職/
けんきゅうかいはつせいか /研究開発成果/
けんきゅうかいはつどうこう /研究開発動向/
けんきゅうかいはつどりょく /研究開発努力/
けんきゅうかいはつのうりょく /研究開発能力/
けんきゅうかいはつひ /研究開発費/
けんきゅうかいはつぶ /研究開発部/
けんきゅうかいはつほんぶ /研究開発本部/
けんきゅうかいはつもくてき /研究開発目的/
けんきゅうかいほうこく /研究会報告/
けんきゅうかいほっそく /研究会発足/
けんきゅうかいめい /研究会名/
けんきゅうかいれんごう /研究会連合/
けんきゅうかだい /研究課題/
けんきゅうかちょう /研究科長/
けんきゅうかちょうしつ /研究科長室/
けんきゅうかつどう /研究活動/
けんきゅうかのう /研究可能/
けんきゅうかのうせい /研究可能性/
けんきゅうかん /研究官/
けんきゅうかんきょう /研究環境/
けんきゅうがくえんとし /研究学園都市/
けんきゅうき /研究機/
けんきゅうきかん /研究機関/研究期間/
けんきゅうきばん /研究基盤/
けんきゅうきょうぎかい /研究協議会/
けんきゅうきょうりょくか /研究協力課/
けんきゅうきょうりょくがかり /研究協力掛/
けんきゅうきよう /研究紀要/
けんきゅうぎょうせき /研究業績/
けんきゅうぐるーぷ /研究グループ/
けんきゅうけい /研究系/
けんきゅうけいかく /研究計画/
けんきゅうけいひ /研究経費/
けんきゅうけっか /研究結果/
けんきゅうこうえんかい /研究講演会/
けんきゅうこうりゅう /研究交流/
けんきゅうさっし /研究冊子/
けんきゅうし /研究史/
けんきゅうしえん /研究支援/
けんきゅうしえんかんきょう /研究支援環境/
けんきゅうししん /研究指針/
けんきゅうしせつ /研究施設/
けんきゅうしつ /研究室/
けんきゅうしつがい /研究室外/
けんきゅうしつけんがく /研究室見学/
けんきゅうしつちょくつう /研究室直通/
けんきゅうしつない /研究室内/
けんきゅうしつめい /研究室名/
けんきゅうしつりょこう /研究室旅行/
けんきゅうしどう /研究指導/
けんきゅうしゃ /研究者/研究社;[出版社名]www.kenkyusha.co.jp/
けんきゅうしゃかん /研究者間/
けんきゅうしゃしゅっぱん /研究社出版;[出版社名]/
けんきゅうしゃすう /研究者数/
けんきゅうしゃそうご /研究者相互/
けんきゅうしゃたち /研究者達/
けんきゅうしゃばんごう /研究者番号/
けんきゅうしゃほんにん /研究者本人/
けんきゅうしゃようせい /研究者養成/
けんきゅうしゅうかい /研究集会/
けんきゅうしゅにん /研究主任/
けんきゅうしょ /研究所;lab/研究書;study/
けんきゅうしょう /研究賞/
けんきゅうしょうかい /研究紹介/
けんきゅうしょく /研究職/
けんきゅうしょだい /研究所第/
けんきゅうしょちょう /研究所長/
けんきゅうしょめい /研究所名/
けんきゅうしょれんごう /研究所連合/
けんきゅうしりょう /研究資料/
けんきゅうしん /研究心/
けんきゅうじょ /研究所/
けんきゅうじょう /研究上/
けんきゅうじょうきょう /研究状況/
けんきゅうじょうほう /研究情報/
けんきゅうじょうほうこうかん /研究情報交換/
けんきゅうじょがい /研究所外/
けんきゅうじょしゅ /研究助手/
けんきゅうじょせい /研究助成/
けんきゅうじょない /研究所内/
けんきゅうじれい /研究事例/
けんきゅうせい /研究生/
けんきゅうせいか /研究成果/
けんきゅうせいかつ /研究生活/
けんきゅうせいかはっぴょう /研究成果発表/
けんきゅうせいさく /研究制作/
けんきゅうせん /研究船/
けんきゅうぜんぱん /研究全般/
けんきゅうそくほう /研究速報/
けんきゅうそしき /研究組織/
けんきゅうたいしょう /研究対象/
けんきゅうたいせい /研究体制/
けんきゅうだい /研究第/
けんきゅうだいざい /研究題材/
けんきゅうだいひょう /研究代表/
けんきゅうだいひょうしゃ /研究代表者/
けんきゅうだいもく /研究題目/
けんきゅうだんかい /研究段階/
けんきゅうちーむ /研究チーム/
けんきゅうちゅう /研究中/
けんきゅうてじゅん /研究手順/
けんきゅうとう /研究棟/
けんきゅうとうろん /研究討論/
けんきゅうとうろんかい /研究討論会/
けんきゅうとじょう /研究途上/
けんきゅうどうこう /研究動向/
けんきゅうないよう /研究内容/
けんきゅうなかま /研究仲間/
けんきゅうにっし /研究日誌/
けんきゅうねっしん /研究熱心/
けんきゅうのうりょく /研究能力/
けんきゅうはいけい /研究背景/
けんきゅうはっぴょう /研究発表/
けんきゅうはっぴょうかい /研究発表会/
けんきゅうはん /研究班/
けんきゅうはんい /研究範囲/
けんきゅうひ /研究費/
けんきゅうひそうがく /研究費総額/
けんきゅうひん /研究品/
けんきゅうぶ /研究部/
けんきゅうぶそく /研究不足/
けんきゅうぶもん /研究部門/
けんきゅうぶんかかい /研究分科会/
けんきゅうぶんや /研究分野/
けんきゅうほうこう /研究方向/
けんきゅうほうこく /研究報告/
けんきゅうほうこくかい /研究報告会/
けんきゅうほうこくしょ /研究報告書/
けんきゅうほうしん /研究方針/
けんきゅうほうほう /研究方法/
けんきゅうほんぶ /研究本部/
けんきゅうもくてき /研究目的/
けんきゅうもくひょう /研究目標/
けんきゅうよう /研究用/
けんきゅうりょういき /研究領域/
けんきゅうれい /研究例/
けんきゅうれんらくかい /研究連絡会/
けんきゅうろ /研究炉/
けんきゅうろんぶん /研究論文/
けんきょ /謙虚/検挙/
けんきょう /県境/検鏡/牽強/
けんきょうい /県教委;県教育委員会/
けんきょうかい /県協会/
けんきょうちゅう /検鏡中/
けんきょうふかい /牽強付会;こじつけ/牽強附会/
けんきょしゃ /検挙者/
けんきょじ /検挙時/
けんきょりつ /検挙率/
けんきん /献金/兼勤/
けんぎ /県議/建議;proposal/嫌疑/剣技/
けんぎかい /県議会/
けんぎせん /県議選/
けんぎゅう /牽牛/犬牛/
けんぎゅうせい /牽牛星/
けんぎょう /兼業/検校/顕教;⇔密教/
けんぎょうしゅふ /兼業主婦/
けんぎょうのうか /兼業農家/
けんぐ /賢愚/
けんぐん /建軍;軍隊を創設すること/
けんけい /県警/賢兄/
けんけいおんがくたい /県警音楽隊/
けんけつ /献血/欠缺/
けんけつかいすう /献血回数/
けんけつしゃ /献血車/
けんけつまえ /献血前/
けんけんがくがく /喧喧諤諤;※喧喧囂囂(けんけんごうごう)と侃侃諤諤(かんかんがくがく)の混成語/喧々諤々;※喧喧囂囂(けんけんごうごう)と侃侃諤諤(かんかんがくがく)の混成語/
けんけんごうごう /喧々囂々;多くの人々が口々に騒がしい/喧喧囂囂/
けんけんひきゅう /蹇蹇匪躬;君主につくし私利をかえりみない/
けんけんふくよう /拳拳服膺;心して忘れず守る/
けんげき /剣戟;†剣(つるぎ)と戟(ほこ)。それらを武器に切り合う戦い。「-の響き」/剣劇;†ちゃんばら/
けんげきじん /剣劇人/
けんげん /権限/顕現/権原;[法](title)権利の源泉/建言/乾元;年号(1302-1303)/献言/
けんげんいじょう /権限委譲/
けんげんがい /権限外/
けんげんしゅうちゅう /権限集中/
けんげんしょ /建言書/
けんげんない /権限内/
けんこ /眷顧/腱固/
けんこう /健康/軒昂;意気-/権衡;平均/兼行;昼夜-/堅硬/箝口;口をつぐむ,発言を封ずる,カンコウとも/堅甲;堅い甲殻/驗效/
けんこういじ /健康維持/
けんこううん /健康運/
けんこうかがく /健康科学/
けんこうかんり /健康管理/
けんこうきぐ /健康器具/
けんこうこうか /健康効果/
けんこうこつ /肩甲骨/肩胛骨;=肩甲骨/
けんこうざっし /健康雑誌/
けんこうしこう /健康志向/
けんこうしょうに /健康小児/
けんこうしょく /健康食/
けんこうしょくひん /健康食品/
けんこうしんだん /健康診断/
けんこうじゅうたく /健康住宅;意味はよくわかりません/
けんこうじょう /健康上/
けんこうじょうたい /健康状態/
けんこうせい /嫌光性/
けんこうぜんたい /健康全体/
けんこうそうだん /健康相談/
けんこうぞうしん /健康増進/
けんこうぞうしんほう /健康増進法/
けんこうたい /健康体/
けんこうちゃ /健康茶/
けんこうちょうさ /健康調査/
けんこうてき /健康的/
けんこうひがい /健康被害/
けんこうび /健康美/
けんこうほう /健康法/
けんこうほけん /健康保険/
けんこうほけんくみあい /健康保険組合/
けんこうほけんしょう /健康保険証/
けんこうほけんせいど /健康保険制度/
けんこうほけんほう /健康保険法/
けんこうぼん /健康本/
けんこうめん /健康面/
けんこうもんだい /健康問題/
けんこうやれん /県高野連/
けんこうらんど /健康ランド/
けんこく /建国/圏谷;Kar/懸谷/
けんこくきねんのひ /建国記念の日;2.11 旧・紀元節/
けんこくきねんび /建国記念日/
けんこくとうじ /建国当時/
けんこつ /顴骨;=頬骨/
けんこん /乾坤;-一擲/
けんこんいってき /乾坤一擲;のるかそるかの勝負をする/
けんご /堅固/謙語/健吾;人名/謙吾/研吾/健悟/憲吾/健五/顕吾/建悟/
けんごう /剣豪/堅剛/喧囂/
けんごし /牽牛子/
けんごしづかこふん /牽牛子塚古墳/
けんさ /検査/
けんさい /賢妻/賢才/県際/県債/
けんさいん /検査員/検査院/
けんさかん /検査官/
けんさき /剣先/
けんさきげん /検査期限/
けんさきじゅん /検査基準/
けんさく /検索/研削/献策;計画を上に提案する/建策;計画を立てる/羂索;[仏教]仏具の一種/憲作;名/憲冊;名/
けんさくえんじん /検索エンジン/
けんさくかのう /検索可能/
けんさくきのう /検索機能/
けんさくけっか /検索結果/
けんさくこうもく /検索項目/
けんさくご /検索語/
けんさくさぎょう /検索作業/
けんさくしき /検索式/
けんさくしすてむ /検索システム/
けんさくしゅほう /検索手法/
けんさくしょり /検索処理/
けんさくじ /検索時/
けんさくじゅんい /検索順位/
けんさくじょうけん /検索条件/
けんさくたいしょう /検索対象/
けんさくたんまつ /検索端末/
けんさくちゅう /検索中/
けんさくばん /研削盤/
けんさくふぉーむ /検索フォーム/
けんさくふのう /検索不能/
けんさくほう /検索法/
けんさくほうほう /検索方法/
けんさくまど /検索窓;[新語]サーチエンジンの-/
けんさくめいれい /検索命令/
けんさくもじれつ /検索文字列/
けんさくよう /検索用/
けんさくれい /検索例/
けんさけっか /検査結果/
けんさこうてい /検査工程/
けんさこうもく /検査項目/
けんさしゃ /検査者/
けんさしょうめい /検査証明/
けんさしょけん /検査所見/
けんさしようしょ /検査仕様書/
けんさじ /検査時/
けんさじょ /検査所/
けんさじょう /検査場/
けんさそうち /検査装置/
けんさたいしょう /検査対象/
けんさだい /検査代/
けんさつ /検察;prosecution.「-官」/検札;切符を拝見/賢察;お察し。「ご-」/
けんさつかん /検察官/
けんさつがわ /検察側/
けんさつきょく /検察局/
けんさつしんさかい /検察審査会/
けんさつちょう /検察庁/
けんさてすうりょう /検査手数料/
けんさにゅういん /検査入院/
けんさひょう /検査票/
けんさひよう /検査費用/
けんさび /検査日/
けんさふよう /検査不要/
けんさぶ /検査部/
けんさほう /検査法/
けんさほうこく /検査報告/
けんさぼ /検査簿/
けんさまえ /検査前/
けんさやく /検査薬;test drug.「妊娠-」/検査役;inspector.「総会-」/
けんさようし /検査用紙/
けんさん /研鑽/県産/建盞/
けんざい /建材/健在;alive.「まだまだ-だ」/顕在;explicit.「問題の-化」/
けんざいか /顕在化/
けんざかい /県境/
けんざぶろう /健三郎/
けんざん /見参/剣山/検算/乾山/験算;=検算/
けんざんやき /乾山焼/
けんし /剣士/犬歯/検死/検視;≒検死/検屍;=検死/絹糸/県史/繭糸/研紙/研資/献詞/堅紙/賢史/
けんしかいぼう /検死解剖/
けんしかん /検屍官/検死官/
けんしき /見識/
けんしきしゃ /見識者/
けんしゃ /県社/見者/検車/
けんしゃく /検車区/献酌/
けんしゅ /犬種/堅守/券種/賢主/
けんしゅう /研修/検収/兼修/献酬/
けんしゅうい /研修医/
けんしゅういん /研修員/
けんしゅうかい /研修会/
けんしゅうかいかん /研修会館/
けんしゅうこ /検修庫/
けんしゅうしつ /研修室/
けんしゅうしゃいん /研修社員/
けんしゅうしょ /研修所/
けんしゅうじょ /研修所/
けんしゅうせい /研修生/
けんしゅうちゅう /研修中/
けんしゅうひ /研修費/
けんしゅうぶ /研修部/
けんしゅうりょこう /研修旅行/
けんしゅつ /検出/顕出/
けんしゅつかのうせい /検出可能性/
けんしゅつき /検出器/
けんしゅつきこう /検出機構/
けんしゅつこうりつ /検出効率/
けんしゅつしやく /検出試薬/
けんしゅつじ /検出時/
けんしゅつのうりょく /検出能力/
けんしゅつふかのう /検出不可能/
けんしゅつほう /検出法/
けんしゅつほうほう /検出方法/
けんしゅつりつ /検出率/
けんしょ /見所/賢所;=かしこどころ/険所/嶮所;≒険所/
けんしょう /検証/懸賞/憲章;charter.「国連-」/顕彰;功を知れ渡らせる/健勝/顕正;[仏教]真理を顕す/肩章;epaulet/見性/腱鞘;-炎/兼掌/剣匠/顕賞;功を明らかにし賞する/謙称/
けんしょうあん /憲章案/
けんしょうえん /腱鞘炎/
けんしょうかのう /検証可能/
けんしょうきん /懸賞金/
けんしょうけい /検証系/
けんしょうけっか /検証結果/
けんしょうしえん /検証支援/
けんしょうしき /顕彰式/
けんしょうしゅだん /検証手段/
けんしょうじっけん /検証実験/
けんしょうじょうけん /検証条件/
けんしょうじょうぶつ /見性成仏/
けんしょうば /顕彰馬/
けんしょうふかのう /検証不可能/
けんしょうぶつ /検証物/
けんしょうほう /検証法/
けんしょうほうしき /検証方式/
けんしょうほうほう /検証方法/
けんしょうもんだい /懸賞問題/検証問題/
けんしょうろんぶん /懸賞論文/
けんしょく /兼職/顕職/
けんしん /検診;†examine.「内科-」/健診;†健康診断。「定期-」/献身/検針;†meter check.「ガスの-」/謙信/見神/堅信;[キリスト教]confirmation.「-の秘跡」/検真/献進/剣心/健晋/
けんしんてき /献身的/
けんしんてきどりょく /献身的努力/
けんじ /堅持/検事/顕示/献辞/検字/謙辞/賢治/健二/健治/健司/賢二/健次/憲司/研二/憲治/賢司/健児/謙二/憲二/賢次/謙治/建治;年号(1275-1278)/研治/謙司/賢児/剣持/建司/健之/健士/拳児/憲嗣;名/健爾/顕二/憲志/健至/研児/研仁/
けんじかん /検事官/
けんじがわ /検事側/
けんじきょく /検事局/
けんじせい /検事正/
けんじそうちょう /検事総長/
けんじちょう /検事長/
けんじつ /堅実/兼日/
けんじゃ /賢者/
けんじゃく /間尺/
けんじゃのいし /賢者の石/
けんじゅ /犬儒/
けんじゅう /拳銃/
けんじゅがくは /犬儒学派/
けんじゅつ /剣術/
けんじょ /賢女/
けんじょう /献上/健常/謙譲/見城/堅城/喧擾/
けんじょうがし /献上菓子/
けんじょうきん /献上金/
けんじょうけい /謙譲形/
けんじょうご /謙譲語/
けんじょうしゃ /健常者/
けんじょうじ /健常児/
けんじょうひょうげん /謙譲表現/
けんじょうれい /県条例/
けんじろう /健次郎/健二郎/研二郎/顕次郎/
けんじん /賢人/県人/賢臣/堅陣/
けんじんかい /県人会/
けんすい /懸垂/建水;(茶道具)/硯水/
けんすいしき /懸垂式/
けんすう /件数/軒数/間数/検数/
けんすけ /健介/謙介/健輔/研介/堅助/
けんず /検図/
けんずいし /遣隋使/
けんせい /牽制/権勢/憲政/剣聖/県西/県勢/県政/
けんせいあくそうきゅう /牽制悪送球/
けんせいきゅう /牽制球/
けんせいし /牽制死/
けんせいしょうこうぐん /権勢症候群/
けんせいだい /顕生代/
けんせいぶ /県西部/
けんせき /譴責/
けんせきうん /巻積雲/絹積雲;=巻積雲/
けんせつ /建設/兼摂/
けんせつあと /建設跡/
けんせついよく /建設意欲/
けんせつか /建設課/
けんせつかりかんじょう /建設仮勘定;[会計]勘定科目。建設中の建物等への支出。 building under construction/
けんせつがいしゃ /建設会社/
けんせつきかい /建設機械/
けんせつぎょう /建設業/
けんせつぎょうしゃ /建設業者/
けんせつぎょうほう /建設業法/
けんせつけいかく /建設計画/
けんせつげんば /建設現場/
けんせつこうがくけい /建設工学系/
けんせつこうじ /建設工事/
けんせつこうほち /建設候補地/
けんせつしきん /建設資金/
けんせつしょう /建設省;NB:2001年1月の中央省庁再編で国土交通省に再編された/建設相;†大臣/
けんせつせん /建設線/
けんせつだいじん /建設大臣/
けんせつちゅう /建設中/
けんせつちゅうし /建設中止/
けんせつてき /建設的/
けんせつてきいけん /建設的意見/
けんせつてきひはん /建設的批判/
けんせつとじょう /建設途上/
けんせつとちゅう /建設途中/
けんせつはいざい /建設廃材/
けんせつはんたい /建設反対/
けんせつひ /建設費/
けんせつひよう /建設費用/
けんせつまえ /建設前/
けんせつよう /建設用/
けんせつりそく /建設利息/
けんせん /健羨/
けんぜい /県税/
けんぜつ /懸絶/
けんぜみ /研ゼミ/
けんぜん /健全/顕然/建前;たてまえ?/
けんぜんいちにょ /剣禅一如/拳禅一如/
けんぜんか /健全化/
けんぜんけいえい /健全経営/
けんぜんせい /健全性/
けんそ /険阻/嶮岨;=険阻/倹素/
けんそう /喧騒/喧噪;=喧騒/剣槍/賢崇;名/険相/建掃/
けんそううん /巻層雲/
けんそく /検測/検束/
けんそん /謙遜/
けんそんご /謙遜語/
けんぞう /建造/健三;人名/謙三/賢三/健蔵/健造/研造/剣三/
けんぞうちゅう /建造中/
けんぞうひ /建造費/
けんぞうぶつ /建造物/
けんぞく /眷属/眷族/
けんた /健太/
けんたい /倦怠/検体;sample/献体;body donation/兼帯;掛け持ち/肩帯/剣帯/謙退/
けんたいかい /県大会/
けんたいかん /倦怠感/
けんたいき /倦怠期/
けんたいとうろく /献体登録/
けんたうるすざ /ケンタウルス座;Centaurus(Cen)/
けんたろう /健太郎/謙太郎/謙多郎/謙太朗/
けんたん /健啖/兼担/県短/検痰/
けんたんか /健啖家/
けんたんぶん /兼担分/
けんだい /見台/県大;県立大学/兼題/建大/賢台/
けんだいひょう /県代表/
けんだか /権高/
けんだく /懸濁/
けんだくえき /懸濁液/
けんだっぱ /乾闥婆/
けんだま /けん玉/剣玉/拳玉/
けんち /検知/見地;point of view/検地;「太閤-」/見知;=検知/
けんちき /検知器/
けんちく /建築/
けんちくおんきょう /建築音響/
けんちくか /建築家/
けんちくかんけい /建築関係/
けんちくがく /建築学/
けんちくがくじょう /建築学上/
けんちくがくせんこう /建築学専攻/
けんちくがっか /建築学科/
けんちくがっかい /建築学会/
けんちくきじゅんほう /建築基準法/
けんちくきょうてい /建築協定/
けんちくぎょう /建築業/
けんちくけい /建築系/
けんちくけいかく /建築計画/
けんちくけんきゅうじょ /建築研究所/
けんちくげんば /建築現場/
けんちくこうがく /建築工学/
けんちくこうじ /建築工事/
けんちくこうぞう /建築構造/
けんちくこうぞうかいせき /建築構造解析/
けんちくざい /建築材/
けんちくし /建築士/建築史/
けんちくしかい /建築士会/
けんちくしほう /建築士法/
けんちくしゅじ /建築主事;建築指導課のお偉いさん/
けんちくせっけい /建築設計/
けんちくせつびし /建築設備士;国家資格(建築士法)/
けんちくせん /建築線/
けんちくちゅう /建築中/
けんちくてき /建築的/
けんちくてん /建築展/
けんちくねん /建築年/
けんちくひ /建築費/
けんちくぶ /建築部/
けんちくぶつ /建築物/
けんちくほうき /建築法規/
けんちくめんせき /建築面積;建物の占める地面の面積。法的には「建築物の外壁又はこれに代わる柱の中心線で囲まれた部分の水平投影面積」/
けんちくや /建築屋/
けんちくようしき /建築様式/
けんちげん /検知限/
けんちじ /県知事/
けんちじせん /県知事選/
けんちちょう /検地帳/
けんちゃ /献茶/
けんちゅう /絹紬/検注/繭紬;=絹紬/
けんちょ /顕著/
けんちょう /県庁/堅調/建長;年号(1249-1256)/県鳥/健聴;⇔聾/懸吊/検聴/
けんちょうしゃ /健聴者/
けんちょうしょざいち /県庁所在地/
けんちょうじ /健聴耳/
けんちょうまえ /県庁前/
けんちんじる /巻繊汁/けんちん汁/
けんてい /検定/献呈/賢弟/
けんていいけん /検定意見/
けんていいん /検定員/
けんていがいきょうかしょ /検定外教科書/
けんていきじゅん /検定基準/
けんていきょうかしょ /検定教科書/
けんていご /検定後/
けんていごうかく /検定合格/
けんていしけん /検定試験/
けんていしゅもく /検定種目/
けんていせいど /検定制度/
けんていないよう /検定内容/
けんていび /検定日/
けんていふ /献呈譜/
けんていほう /検定法/
けんていほうしき /検定方式/
けんていほうほう /検定方法/
けんていまえ /検定前/
けんていりょう /検定料/
けんていりょく /検定力/
けんてき /硯滴/
けんてつ /建鉄/賢哲/建鐵;「鉄」旧字/
けんてん /圏点/
けんてんし /権天使;principalities/
けんでん /喧伝/
けんでんき /検電器/
けんと /県都/健人/憲人/建都;平安-/
けんとう /検討/健闘/見当/拳闘/献灯/県東/軒灯/賢答/喧鬧/
けんとういいんかい /検討委員会/
けんとうか /拳闘家/
けんとうかい /検討会/
けんとうかいし /検討開始/
けんとうかだい /検討課題/
けんとうきょく /県当局/
けんとうけっか /検討結果/
けんとうざいりょう /検討材料/
けんとうし /遣唐使/
けんとうしき /見当識;orientation/
けんとうしゃ /検討者/
けんとうずみ /検討済み/
けんとうせん /遣唐船;[日本史]/
けんとうたいしょう /検討対象/
けんとうだんかい /検討段階/
けんとうちがい /見当違い/
けんとうちゅう /検討中/
けんとうはずれ /見当外れ/
けんとうぶ /県東部/
けんとうれい /検討例/
けんとく /乾徳;進んでやまぬ徳/建徳;年号(1370-1372)/見得/
けんとくこう /謙徳公;あはれとも いふべき人は 思ほえで 身のいたづらに なりぬべきかな/
けんとし /ケント紙/
けんどう /剣道/県道;-207号線/権道;必要悪的措置/
けんどうしき /献堂式/
けんどうじょう /剣道場/
けんどうぶ /剣道部/
けんどうわき /県道脇/
けんどじゅうらい /捲土重来/
けんどちょうらい /捲土重来/捲土重來;「来」旧字/
けんどん /慳貪/
けんない /圏内/県内/
けんないがい /県内外/
けんなく /見惑;=けんわく/
けんなん /県南/剣難;刀で襲われる/険難;trouble/
けんなんぶ /県南部/
けんにょう /検尿/
けんにん /兼任/検認/堅忍/建仁;年号(1201-1204)/
けんにんふばつ /堅忍不抜/
けんのう /権能/献納/
けんのん /剣呑;当て字/険難/険呑/
けんはんしゃ /腱反射/
けんば /犬馬/
けんばいき /券売機/
けんばく /懸瀑/
けんばん /鍵盤/見番;置屋の組合/検番/鍵板;?/
けんばんがっき /鍵盤楽器/
けんばんがっきそうしゃ /鍵盤楽器奏者/
けんばんごと /鍵盤毎/
けんばんすう /鍵盤数/
けんぱ /検波/
けんぱい /献杯/献盃/
けんぱき /検波器/
けんぱく /建白/絹帛/
けんぱくしょ /建白書/
けんぱくどうい /堅白同異/
けんぱご /検波後/
けんぱしゅつりょく /検波出力/
けんぱぶ /検波部/
けんひ /県費/
けんび /顕微/兼備/
けんびきょう /顕微鏡/
けんびきょうざ /顕微鏡座;Microscopium(Mic)/
けんびし /剣菱/
けんぴ /県費;県の歳費/建碑/
けんぴつ /健筆/
けんぴょう /堅氷/懸氷/
けんぴん /検品/
けんぶ /剣舞/兼部/
けんぶち /剣淵/
けんぶつ /見物/
けんぶつがわ /見物側/
けんぶつき /見物記/
けんぶつきゃく /見物客/
けんぶつちゅう /見物中/
けんぶつにん /見物人/
けんぶつばしょ /見物場所/
けんぶりっじだいがく /ケンブリッジ大学;Cambridge University. www.cam.ac.uk/
けんぶん /見聞/検分/見分;≒検分/
けんぶんろく /見聞録/
けんぷ /絹布/賢婦/乾符/
けんぷう /検封/
けんぷじん /賢夫人/
けんべつ /県別/軒別/
けんべん /検便/
けんぺい /憲兵/権柄/兼併/
けんぺいたい /憲兵隊/
けんぺいりつ /建蔽率/建ぺい率/建坪率;=建蔽率/
けんぺん /券片/権変/
けんほく /県北/
けんほくぶ /県北部/
けんぼ /賢母/
けんぼう /健忘/権謀/絹紡/
けんぼうし /絹紡糸/
けんぼうしょう /健忘症/
けんぼうじゅっすう /権謀術数/
けんぼく /県木/
けんぽ /健保;健康保険/健歩;てくてく/兼補/
けんぽう /憲法;constitution/拳法;(格闘技)/剣法/建保;年号(1213-1219)/肩峰/剣鋒/
けんぽうあん /憲法案/
けんぽういはん /憲法違反/
けんぽういん /憲法院/
けんぽうか /憲法下/拳法家/
けんぽうかいしゃく /憲法解釈/
けんぽうかいせい /憲法改正/
けんぽうかいせいろんしゃ /憲法改正論者/
けんぽうがく /憲法学/
けんぽうがくしゃ /憲法学者/
けんぽうきねんび /憲法記念日/
けんぽうさいばんしょ /憲法裁判所/
けんぽうじゅうしちじょう /憲法十七条;[日本史]604/
けんぽうだいきゅうじょう /憲法第九条/
けんぽうちつじょ /憲法秩序/
けんぽうはんだん /憲法判断/
けんぽうはんれいしゅう /憲法判例集/
けんぽうもんだい /憲法問題/
けんぽく /県北/
けんぽん /絹本/献本/
けんま /研磨/研摩/
けんまき /研磨機/
けんまく /剣幕/権幕/劍幕/
けんまこくげき /肩摩轂撃/
けんまこん /研磨痕/
けんまざい /研磨剤/
けんみ /検見/
けんみつ /顕密/
けんみん /県民/建民/
けんみんかいかん /県民会館/
けんみんし /遣明使;[日本史]/
けんみんせい /県民性/
けんみんぜい /県民税/
けんむ /兼務/建武;年号(1334-1336)/
けんめ /件目/
けんめい /件名/懸命/賢明/県名/
けんめいしゅぎ /顕名主義/
けんめん /券面/
けんめんちょうしょ /検面調書/
けんもち /堅持/剣持/犬持/
けんもつ /監物/献物/
けんもん /見聞/検問/権門/
けんもんしょ /検問所/
けんもんじょ /検問所/
けんや /賢也/健弥/顕也/
けんやく /倹約/
けんやくか /倹約家/
けんやくせい /検約性/
けんゆう /県有/
けんゆうかん /健友館/
けんゆうしゃ /硯友社;[文学]尾崎紅葉の結社/
けんゆうち /県有地/
けんよう /兼用/険要/顕揚;名を揚げる/顕要;高く重要な地位/建窯;福建省の名窯/
けんようしゃ /兼用車/
けんようしゅ /兼用種/
けんようすい /懸壅垂/
けんらん /絢爛/
けんらんごうか /絢爛豪華/
けんり /権利/
けんりおち /権利落ち/権利落/
けんりか /権利化/
けんりかくとく /権利獲得/
けんりかくほ /権利確保/
けんりかぶ /権利株/
けんりかんけい /権利関係/
けんりがいねん /権利概念/
けんりきかん /権利期間/
けんりきん /権利金/
けんりこうし /権利行使/
けんりしち /権利質/
けんりしゃ /権利者/
けんりしゅたい /権利主体/
けんりしゅちょう /権利主張/
けんりしょ /権利書/
けんりしょうてん /権利章典;[世界史](1689)the Bill of Rights/
けんりしんがい /権利侵害/
けんりじょうやく /権利条約/
けんりせい /権利性/
けんりちゅう /権利中/
けんりつ /県立/建立/
けんりつ> /県立/
けんりつうらわこうこう /県立浦和高校/
けんりつき /権利付/
けんりつこうこう /県立高校/
けんりつだい /県立大/
けんりつだいがく /県立大学/
けんりつとしょかん /県立図書館/
けんりのうりょく /権利能力/
けんりはっせい /権利発生/
けんりほうき /権利放棄/
けんりもんだい /権利問題/
けんりゃく /建暦;年号(1121-1213)/
けんりゅう /剣竜/劍竜;「剣」旧字/
けんりゅうけい /検流計/
けんりょ /賢慮/
けんりょう /検量/見料/
けんりょうしつ /検量室/
けんりょうせん /検量線/
けんりょく /権力/
けんりょくあらそい /権力争い/
けんりょくか /権力下/
けんりょくかんけい /権力関係/
けんりょくがわ /権力側/
けんりょくこうそう /権力抗争/
けんりょくしゃ /権力者/
けんりょくしゅうちゅう /権力集中/
けんりょくてき /権力的/
けんりょくとうそう /権力闘争;血みどろの-/
けんりよう /券利用/
けんりりょう /権利料/
けんるい /堅塁/
けんれい /県令/
けんれいもんいん /建礼門院/
けんれいもんいんうきょうのだいぶ /建礼門院右京大夫/
けんれいもんいんうきょうのだいぶしゅう /建礼門院右京大夫集/
けんれん /県連/研連/眷恋/拳攣/
けんれんはん /牽連犯/
けんろう /堅牢/
けんろうせい /堅牢性/
けんろく /兼六/
けんろくえん /兼六園/
けんろん /圏論/
けんろんてき /圏論的/
けんわ /健和/
けんわく /見惑;[仏教]⇔思惑(しわく)/
けんわんちょくひつ /懸腕直筆/
げ /下/外/毛/気/偈;[仏教](gatha)/夏;(呉音)夏至/解;(呉音)解熱/觧;「解」の異体字/牙;(呉音) きば/睨;(呉音) にら・む/拐;(呉音) 誘拐/
げーじりゅうし /ゲージ粒子;gauge particle/
げーとぼーるじょう /ゲートボール場/
げーむか /ゲーム化/
げーむき /ゲーム機/
げーむさ /ゲーム差/
げーむせい /ゲーム性/
げーむちゅう /ゲーム中/
げーむのりろん /ゲームの理論;theory of games. 「囚人のジレンマ」など/
げーむめい /ゲーム名/
げーむよう /ゲーム用/
げーむりろん /ゲーム理論;theory of games.囚人のジレンマなど/
げい /芸/鯨;捕鯨/黥;(いれずみ)/迎;送迎/倪;端倪/猊;猊下/睨;睥睨/貎;(しし)/霓;にじ/麑;(かのこ)/藝;「芸」の旧字(人名用漢字)/囈;(たわごと)/皃;?/
げいいき /芸域/
げいいん /鯨飲/
げいいんばしょく /鯨飲馬食/
げいか /猊下/
げいかい /芸界/
げいかく /芸格/
げいきょう /芸境/
げいぎ /芸妓/
げいげき /迎撃/
げいげきき /迎撃機/
げいげきみさいる /迎撃ミサイル/
げいこ /芸子/稽古/藝子;「芸」旧字/
げいこうだい /芸工大/
げいご /囈語/
げいごう /迎合/
げいごと /芸事/
げいざ /猊座/
げいしゃ /芸者/迎車/
げいしゃやく /芸者役/
げいしゅう /芸州/
げいしゅん /迎春/
げいしょうぎ /芸娼妓/
げいじゅつ /芸術/藝術;「芸」旧字/
げいじゅついん /芸術院/
げいじゅついんしょう /芸術院賞;日本芸術院/
げいじゅつおんがく /芸術音楽/
げいじゅつか /芸術家/
げいじゅつかたち /芸術家達/
げいじゅつかつどう /芸術活動/
げいじゅつかんけい /芸術関係/
げいじゅつがく /芸術学;science of art/
げいじゅつがっこう /芸術学校/
げいじゅつけんきゅうしょ /藝術研究所/
げいじゅつけんきゅうじょ /藝術研究所/
げいじゅつげきじょう /芸術劇場/
げいじゅつこうい /芸術行為/
げいじゅつこうがくぶ /芸術工学部/
げいじゅつさい /芸術祭/
げいじゅつさくひん /芸術作品/
げいじゅつざ /芸術座;[文学史]/
げいじゅつし /芸術誌/
げいじゅつしじょうしゅぎ /芸術至上主義/
げいじゅつせい /芸術性/
げいじゅつだいがく /芸術大学/
げいじゅつてき /芸術的/
げいじゅつてきかち /芸術的価値/
げいじゅつひひょう /芸術批評/
げいじゅつひん /芸術品/
げいじゅつび /芸術美/
げいじゅつりょうほう /芸術療法;[精医]art therapy/
げいじゅつろん /芸術論/
げいせい /芸西/
げいせつ /迎接/
げいたいかい /芸大会/
げいたっしゃ /芸達者/
げいたん /芸短/
げいだい /芸大/
げいだん /芸談/
げいとう /芸当/藝當;旧字/
げいどう /芸道/
げいにく /鯨肉/
げいにん /芸人/
げいのう /芸能/芸濃;地名,三重/
げいのうかい /芸能界/
げいのうかいいり /芸能界入/
げいのうかつどう /芸能活動/
げいのうかんけい /芸能関係/
げいのうきょく /芸能局/
げいのうしゃかい /芸能社会/
げいのうじん /芸能人/
げいのうせいかつ /芸能生活/
げいのうめん /芸能面/
げいのうやましろぐみ /芸能山城組/
げいは /鯨波/
げいひん /迎賓/
げいひんかん /迎賓館/
げいび /芸備/
げいびけい /猊鼻渓/
げいびせん /芸備線/
げいふう /芸風/
げいぶん /芸文/
げいほく /芸北/
げいめい /芸名/
げいゆ /鯨油/
げいれき /芸歴/
げいん /外印;太政官のハンコ/
げか /外科/
げかい /外科医/下界/下回/外界;がいかい?/
げかぎじゅつ /外科技術/
げかしつ /外科室/
げかしゅじゅつ /外科手術/
げかしゅじゅつてき /外科手術的/
げかてき /外科的/
げかびょうとう /外科病棟/
げかん /下巻/下疳;[医]chancre/下官;下級役人/外官;地方官/解官;免官/下浣;月の下旬/下澣;=下浣/
げかんぱん /下甲板;lower deck.⇔上甲板/
げき /劇/激/撃/外記/檄;-を飛ばす/戟;剣戟/隙;間隙/屐;きぐつ/闃/鷁;あおさぎ/郤/鬩;せめ・ぐ/逆;逆鱗/
げき> /激/
げきあせ /激汗/
げきあま /激甘/
げきえいが /劇映画/
げきえつ /激越/
げきおん /激音/
げきおんがく /劇音楽/
げきか /激化/劇化/
げきかい /劇界/
げきから /激辛/
げきが /劇画/
げきがし /劇画誌/
げきくうかん /劇空間/
げきけん /撃剣/
げきげん /激減/
げきこう /激昂/
げきこみ /激混/
げきご /激語/
げきさい /撃砕/
げきさく /劇作/
げきさくか /劇作家;dramatist/
げきさっか /劇作家/
げきさん /激賛/
げきざる /外記猿;歌舞伎などの演目/
げきし /劇詩/
げきしゃ /激写/
げきしゅ /鷁首/
げきしゅう /激臭/劇臭/
げきしょ /激暑/劇暑/
げきしょう /劇症;[医]fulminant. 「-肝炎」/激賞;praise/激症;[医] =劇症/激奨;recommend/
げきしょうかんえん /劇症肝炎;[医]fulminant hepatitis/
げきしょうがた /劇症型/
げきしょく /激職/
げきしん /激震/撃針/
げきじゃく /激弱/
げきじょう /劇場/激情/撃攘/
げきじょうか /激情家/
げきじょうがい /劇場街/
げきじょうがた /劇場型/
げきじょうがたはんざい /劇場型犯罪;theatrical crime/
げきじょうこうえん /劇場公演/
げきじょうこうかい /劇場公開/
げきじょうこうかいじ /劇場公開時/
げきじょうこうかいばん /劇場公開版/
げきじょうない /劇場内/
げきじょうばん /劇場版/
げきじょうよう /劇場用/
げきじょうようさくひん /劇場用作品/
げきじん /激甚/
げきじんさいがい /激甚災害/
げきす /鷁首/
げきせん /激戦/
げきせんく /激戦区/
げきぜつ /鴃舌/
げきぜん /闃然/
げきそう /激走/
げきぞう /激増/
げきたい /撃退/
げきたいほう /撃退法/
げきたく /撃柝/
げきだん /劇団/劇壇/劇談/
げきだんいん /劇団員/
げきだんしき /劇団四季/
げきだんしょぞく /劇団所属/
げきちゅう /劇中/
げきちゅうか /劇中歌/
げきちゅうげき /劇中劇/
げきちょう /外記丁/
げきちん /撃沈/
げきちんは /撃沈破/
げきつい /撃墜/
げきついおう /撃墜王/
げきついすう /撃墜数/
げきつう /激痛/劇通/劇痛/
げきてき /劇的/
げきてきこうか /劇的効果/
げきてつ /撃鉄/
げきとう /激闘/
げきとつ /激突/
げきとつし /激突死/
げきど /激怒/
げきどう /激動/
げきどうき /激動期/
げきどく /劇毒/
げきなみだ /激涙/
げきは /撃破/
げきはく /激白/
げきはつ /激発/
げきはつぶつはれつざい /激発物破裂罪/
げきばん /劇伴/
げきひょう /劇評/
げきひょうらん /劇評欄/
げきぶつ /劇物/
げきぶん /檄文/
げきへん /激変/
げきむ /激務/劇務/
げきめつ /撃滅/
げきやく /劇薬/
げきやす /激安/
げきやすこうくうけん /激安航空券/
げきやすてん /激安店/
げきやば /激ヤバ;[口]/
げきょう /外教;仏教以外の宗教/
げきりゅう /激流/
げきりょく /撃力/
げきりん /逆鱗/
げきれい /激励/
げきれつ /激烈/劇烈;=激烈/
げきろう /激浪/
げきろん /激論/
げぎ /外儀/
げぎょ /懸魚/
げくう /外宮/
げぐう /外宮/
げけつ /下血/
げげ /解夏/
げこ /下戸/
げこう /下校/下向/還向/
げこうご /下校後/
げこうじ /下校時/
げこうちゅう /下校中/
げこく /下刻/
げこくじょう /下剋上/
げこん /下根/
げごく /下獄/
げさく /戯作/外戚/下作/下策/
げさくしゃ /戯作者/
げさくにん /下作人/
げざ /下座/
げざい /下剤/
げざおんがく /下座音楽;歌舞伎の-/
げざかな /下肴/下魚/
げざん /下山/
げし /夏至;[二十四節気]6.22頃/
げしき /景色/
げしゃ /下車/
げしゃいん /下車印/
げしゃえき /下車駅/
げしゃく /外戚/
げしゃじ /下車時/
げしゃぜんとむこう /下車前途無効/
げしゃとほ /下車徒歩/
げしゅく /下宿/
げしゅくさき /下宿先/
げしゅくせい /下宿生/
げしゅくにん /下宿人/
げしゅくや /下宿屋/
げしゅにん /下手人/
げしょ /下書/外書/
げしょう /化粧/
げじ /下知/
げじく /牙軸/
げじげじ /蚰蜒/
げじじょう /下知状/
げじゅ /偈頌/
げじゅん /下旬/
げじゅんぶん /下旬分/
げじゅんへん /下旬編/
げじょ /下女/
げじょう /下城/下乗/
げじん /外陣/
げす /下衆/下司;≒下衆/下種;=下衆/
げすい /下水/
げすいかん /下水管/
げすいこうじ /下水工事/
げすいしょり /下水処理/
げすいしょりしせつ /下水処理施設/
げすいしょりじょう /下水処理場/
げすいどう /下水道/
げすいどうかん /下水道管/
げすいどうきょうかいし /下水道協会誌/
げすいどうきょく /下水道局/
げすいどうしせつ /下水道施設/
げすいどうしょり /下水道処理/
げすいどうせいび /下水道整備/
げすいどうほう /下水道法/
げすいどうりょうきん /下水道料金/
げすとじん /ゲスト陣/
げすとよう /ゲスト用/
げせわ /下世話/
げせん /下船/下賎;「賤」異体字/下賤/牙籤;象牙の小札/
げそう /下僧/
げそく /下足/
げそくばこ /下足箱/
げそくばん /下足番/
げた /下駄/〓/
げたばき /下駄履き/
げたばこ /下駄箱/
げたん /下端/
げだい /外題/
げだつ /解脱/
げだん /下段/
げだんこうげき /下段攻撃/
げち /下知/
げちじょう /下知状/
げっか /月下/激化/
げっかこう /月下香/
げっかひょうじん /月下氷人/
げっかびじん /月下美人/
げっかん /月間/月刊/
げっかん> /月刊/
げっかんあさひ /月刊朝日/
げっかんげんご /月刊言語/
げっかんし /月刊誌/
げっかんしゅうけい /月間集計/
げっかんてんもん /月刊天文/
げっかんよていひょう /月間予定表/
げっきゅう /月給/月球/
げっきゅうぎ /月球儀;moon globe/
げっきゅうせい /月給制/
げっきん /月琴/
げっけい /月経/月計/月桂/月卿/
げっけいかん /月桂冠/
げっけいこんなんしょう /月経困難症;[医]dysmenorrhea/
げっけいじゅ /月桂樹/
げっけいつう /月経痛/
げっけいふじゅん /月経不順;irregular mense/
げっこう /月光/激昂/激高;=激昂/
げっこうかめん /月光仮面/
げっこうちゅう /月光蟲/
げっさん /月産/
げっし /齧歯/齧齒;「歯」旧字/
げっしもく /齧歯目/
げっしゃ /月謝/
げっしゅう /月収/
げっしゅつ /月出/
げっしゅつたい /月出帯/
げっしょ /月初/
げっしょう /月商/月照/
げっしょく /月食;lunar eclispse/月蝕;=月食/月色;moonlight/
げっしょくじ /月食時/
げっしるい /齧歯類/げっ歯類/
げっすいきん /月水金/
げっすう /月数/
げっせかい /月世界/
げっせき /月夕;花朝-/
げっそう /月相/
げったん /月旦/
げったんひょう /月旦評/
げっちょうせき /月長石;moonstone/
げっとう /月桃;ショウガ科の多年草/
げっぴょう /月表/月評/
げっぷ /月賦/
げっぺい /月餅/
げっぽ /月歩;日進-/
げっぽう /月報;monthly report.「全集の-」/月俸;salary/
げつ /月/齧;齧歯類/囓;「齧」の異体字/蘖;ひこばえ/
げつうん /月暈;lunar halo/
げつえい /月影/
げつか /月火/
げつかすい /月火水/
げつかん /月間/
げつがく /月額/
げつがくりょうきん /月額料金/
げつげつかすいもくきんきん /月月火水木金金;[俗]働きづめ/
げつご /月後/
げつじ /月次/
げつど /月度/
げつない /月内/
げつぶん /月分/
げつまえ /月前/
げつまつ /月末/
げつまつしょり /月末処理/
げつまつじつ /月末日/
げつまつはつばい /月末発売/
げつめい /月明/
げつめん /月面/
げつめんじょう /月面上/
げつめんとし /月面都市/
げつめんなんちゃくりく /月面軟着陸/
げつもく /月木/
げつや /月夜/
げつよ /月余/
げつよう /月曜/
げつよういこう /月曜以降/
げつようごご /月曜午後/
げつようび /月曜日/
げつようびごろ /月曜日頃/
げつようよる /月曜夜/
げつらい /月来/
げつり /月利/
げつりん /月輪/
げつれい /月例;monthly/月齢;lunar age/
げつれいかい /月例会/
げつれいきょうぎかい /月例競技会/
げつれいけいざいほうこく /月例経済報告/
げつれいひょうじ /月齢表示/
げつれいほうこく /月例報告/
げて /下手/
げてもの /下手物/
げてん /下天/外典/
げとう /夏油/
げどう /外道/下道;地名/
げどく /解毒/
げどくざい /解毒剤/
げなん /下男/
げに /実に/
げにん /下人/解任/
げねつ /解熱/
げねつざい /解熱剤/
げはん /下阪/
げば /下馬/
げばひょう /下馬評/
げばぼう /ゲバ棒;<Gewalt/
げひ /下卑/
げひん /下品/
げび /下卑/
げぶみ /解文/
げぶん /外文/
げへん /下編/下篇/
げほう /外法;外道,⇔内法,内道/
げぼく /下僕/
げめん /外面/
げもん /解文/
げや /下野/下屋;[建築]母屋から差し出す小屋根/
げらく /下落/
げらくはば /下落幅/
げらくりつ /下落率/
げらずり /ゲラ刷り;(<galley)/ゲラ刷/
げり /下痢/
げりどめ /下痢止め;止瀉薬/
げりべん /下痢便/
げりゃく /下略/
げりらせん /ゲリラ戦/
げりらてき /ゲリラ的/
げるか /ゲル化/
げるかざい /ゲル化剤/
げるじょう /ゲル状/
げるちん /ゲル沈/
げるまにうむ /Germanium/Ge/
げるまんごは /ゲルマン語派;Germanic/
げれつ /下劣/
げろ /下呂/
げろう /外郎/下郎/下臈/
げろうことば /下郎言葉/
げろおんせん /下呂温泉/
げろかん /下呂間/
げん /現/言/減/源;発生-/原;-住民/元/弦;string/絃;楽器の絃(=弦)/舷;ふなべり/験;-を担ぐ/軒;(連濁)/幻;幻覚/監;(太宰府等の官名)/限;限度/眼;(呉音)開眼/厳;厳密/嚴;「厳」の旧字(人名用漢字)/儼;≒厳/玄;玄関/呟;つぶや・く/痃/眩;眩暈/衒;衒学/諺;(ことわざ)俚諺/偐;(呉音)≒贋/彦;ひこ/顏;「顔」の旧字/訝;怪訝/广;(まだれ)/愿/芫/嫌;(呉音)機嫌/
げん> /現/原;原作,原詩,原光景/減;減塩,減農薬,減音程/元;?/
げんあつ /減圧/
げんあつき /減圧器/
げんあつしょう /減圧症/
げんあつていし /減圧停止/
げんあん /原案/現案;†現在のプラン/
げんあんどおり /原案通り/
げんい /原意/
げんいち /現位置/元一/源一/
げんいちろう /源一郎/
げんいん /原因/減員;⇔増員/現員/
げんいんかいめい /原因解明/
げんいんきゅうめい /原因究明/
げんいんちょうさ /原因調査/
げんいんついきゅう /原因追及/
げんいんふめい /原因不明/
げんいんぶっしつ /原因物質/
げんいんぶんせき /原因分析/
げんうん /眩暈/
げんえい /幻影/元永;年号(1118-1120)/
げんえいきゃく /幻影脚/
げんえき /現役/原液/減益/
げんえきいんたい /現役引退/
げんえきいんたいご /現役引退後/
げんえきき /現役機/
げんえきさいきょう /現役最強/
げんえきさいご /現役最後/
げんえきさいた /現役最多/
げんえきさいねんちょう /現役最年長/
げんえきじだい /現役時代/
げんえきじょしこうせい /現役女子高生/
げんえきせんしゅ /現役選手/
げんえきだいひょう /現役代表/
げんえきば /現役馬/
げんえきふっき /現役復帰/
げんえん /減塩/減煙/原猿/
げんえんしょうゆ /減塩醤油/
げんえんしょく /減塩食/
げんえんじょうゆ /減塩醤油/
げんえんるい /原猿類;[生物]prosimian/
げんおう /元応;年号(1319-1321)/玄奥/
げんおん /原音/現音/
げんおんじょう /原音場/
げんおんせい /原音声/
げんおんてい /減音程/
げんか /原価;†cost/現下;for the time being/減価;†「-償却」/現価;†current price.「債券の-」/言下;promptly/厳科;severe penalty/喧嘩;(連濁)/絃歌/弦歌;=絃歌/原歌/
げんかい /限界/厳戒/玄海;地名/言海/幻怪/諺解/顕界/幻界/幻海/
げんかい> /限界;(marginal) -効用,-便益/
げんかいいっぱい /限界一杯/
げんかいいん /現会員/
げんかいかかく /限界価格/
げんかいこうど /限界高度/
げんかいこうよう /限界効用/
げんかいしき /原価意識/
げんかいじ /限界時/
げんかいせん /限界線/
げんかいそうこう /限界走行/
げんかいそくど /限界速度/
げんかいたいせい /厳戒態勢/
げんかいち /限界値/
げんかいちいか /限界値以下/
げんかいちいじょう /限界値以上/
げんかいてん /限界点/
げんかいとくせい /限界特性/
げんかいない /限界内/
げんかいなだ /玄界灘/玄海灘/
げんかいひよう /限界費用/
げんかいりょういき /限界領域/
げんかく /厳格/幻覚/
げんかくざい /幻覚剤/
げんかくしゅぎ /厳格主義/
げんかくしょうじょう /幻覚症状/
げんかくせい /幻覚性/
げんかくせいぶつ /原核生物/
げんかけいさん /原価計算/
げんかし /原歌詞/
げんかしゅぎ /原価主義;[会計]cost basis/
げんかしょうきゃく /減価償却/
げんかしょうきゃくひ /減価償却費/
げんかしょうきゃくりつ /減価償却率/
げんかしょうきゃくるいけいがく /減価償却累計額/
げんかつぎ /験担ぎ/ゲン担ぎ/
げんかほう /原価法/
げんかわれ /原価割れ/
げんかん /玄関/厳寒/減感;⇔増感/阮咸;中国の弦楽器/
げんかんきょう /現環境/
げんかんきん /現換金/
げんかんぐち /玄関口/
げんかんさき /玄関先/
げんかんさりょうほう /減感作療法;[医]アレルギーの治療法/
げんかんすう /原関数/
げんかんとく /現監督/
げんかんばらい /玄関払い/
げんかんばん /玄関番/
げんかんまえ /玄関前/
げんかんまっと /玄関マット/
げんかんりにん /現管理人/
げんが /原画/
げんがい /言外/限外/
げんがく /減額/弦楽/衒学/絃楽/
げんがくがっそう /弦楽合奏/
げんがくさんじゅうそうきょく /弦楽三重奏曲/
げんがくしじゅうそう /弦楽四重奏/
げんがくしじゅうそうきょく /弦楽四重奏曲/
げんがくしじゅうそうだん /弦楽四重奏団/
げんがくてき /衒学的/
げんがしゅう /原画集/
げんがぞう /原画像/
げんがっき /弦楽器/絃楽器/
げんがっきぐん /弦楽器群/
げんがっきそうしゃ /弦楽器奏者/
げんがっきょく /弦楽曲/
げんがてん /原画展/
げんき /元気/元亀;年号(1570-1573)/原器;メートル-/原基;rudiment/
げんきいっぱい /元気一杯/
げんきかい /現棋界/
げんきじるし /元気印/
げんきっこ /元気っ子/
げんきはつらつ /元気溌剌/
げんきもの /元気者/
げんきゃく /減却/
げんきゅう /言及/減給/元久;年号(1204-1206)/原級/
げんきょ /原拠/
げんきょう /現況/元凶/
げんきょうほうこく /現況報告/
げんきょく /原曲/限局/元曲;雑劇/原局/減極/
げんきょくせい /限局性/
げんきょくどおり /原曲通り/
げんきよし /元気良/
げんきん /現金/厳禁/
げんきんいがい /現金以外/
げんきんか /現金化/
げんきんかいいん /現金会員/
げんきんかきとめ /現金書留/
げんきんかんじょう /現金勘定/
げんきんけっさい /現金決済/
げんきんしゅうにゅう /現金収入/
げんきんしょうひん /現金賞品/
げんきんすいとうちょう /現金出納帳/
げんきんとうし /現金投資/
げんきんとりひき /現金取引/
げんきんばらい /現金払い/現金払/
げんきんふうとう /現金封筒/
げんきんゆそうしゃ /現金輸送車/
げんきんよきん /現金預金/
げんぎ /原義/玄義;幽玄な真理/
げんぎょ /言語/懸魚/
げんぎょう /現業/
げんぎょうきかん /現業機関/
げんぎょうぶもん /現業部門/
げんぎん /現銀/
げんく /原句/
げんくう /源空/
げんくうこう /現空港/
げんくん /元勲/厳君/
げんけい /原型;†prototype.「資本主義の-」/原形;†original form.「-をとどめない」/現計/減刑/元型;archetype (Jungの用語)/減軽;「刑罰の-」/現形;current form/厳刑;⇔寛刑/
げんけいかく /現計画/
げんけいしつ /原形質/
げんけいしつまく /原形質膜/
げんけいしつれんらく /原形質連絡/
げんけん /原研/原券/
げんけんぽう /現憲法/
げんげつ /限月;[経済]先物の決済月/弦月;(crescent) ゆみはりづき/
げんげんご /原言語/
げんこ /拳固/儼乎/
げんこう /現行;current/原稿/元寇/減光/言行;words and deeds/減耗/元弘;年号(1331-1334)/弦高/原口;[生物]blastopore/元亨;年号(1321-1324)/元后/原鉱/
げんこう> /現行;-価格,-機種,-法規/
げんこういっち /言行一致/
げんこういらい /原稿依頼/
げんこうがた /現行型/
げんこうきしゅ /現行機種/
げんこうけい /原光景;[精医]幼少時に見た両親の性交/
げんこうけんぽう /現行憲法/
げんこうさくせい /原稿作成/
げんこうしめきり /原稿締切/
げんこうしゃ /玄光社;[出版社名]写真。www.genkosha.co.jp/
げんこうしゃくしょ /元亨釈書/
げんこうしゃしゅ /現行車種/
げんこうしょうひん /現行商品/
げんこうそうふさき /原稿送付先/
げんこうにゅうりょく /原稿入力/
げんこうはん /現行犯/
げんこうはんたいほ /現行犯逮捕/
げんこうはんにん /現行犯人/
げんこうばん /現行版/
げんこうひょうじゅん /現行標準/
げんこうひん /現行品/
げんこうほう /現行法/
げんこうほうか /現行法下/
げんこうほうき /現行法規/
げんこうほうきそうらん /現行法規総覧/
げんこうほうしき /現行方式/
げんこうほうそう /現行放送/
げんこうめい /原稿名/
げんこうよう /原稿用/
げんこうようし /原稿用紙/
げんこうりょう /原稿料/
げんこうりょうしゅうにゅう /原稿料収入/
げんこうろく /言行録/
げんこく /原告/現国;[略語]現代国語/厳酷/玄穀/
げんこくがわ /原告側/
げんこくだん /原告団/
げんこつ /拳骨/
げんこん /現今/眼根/
げんこんたん /原根端/
げんご /言語/原語;original language/源吾/源後/幻語/源語/諺語/玄語/
げんごいぞん /言語依存/
げんごう /元号/減号/
げんごうほう /元号法/
げんごうんよう /言語運用/
げんごおん /言語音/
げんごか /言語化/
げんごかいせき /言語解析/
げんごかくとく /言語獲得/
げんごかつどう /言語活動/
げんごかてい /言語過程/
げんごかん /言語感/
げんごかんかく /言語感覚/
げんごかんきょう /言語環境/
げんごがいねん /言語概念/
げんごがく /言語学/
げんごがくしゃ /言語学者/
げんごがくだいじてん /言語学大辞典/
げんごがくてき /言語学的/
げんごきこう /言語機構/
げんごきごう /言語記号/
げんごきじゅつ /言語記述/
げんごきのう /言語機能/
げんごきはん /言語規範/
げんごきょういく /言語教育/
げんごくうかん /言語空間/
げんごけい /言語系/
げんごけいせい /言語形成/
げんごけん /言語研/
げんごけんきゅう /言語研究/
げんごけんきゅうかい /言語研究会/
げんごけんきゅうしょ /言語研究所/
げんごけんきゅうじょ /言語研究所/
げんごげーむ /言語ゲーム;[哲学]language game. (cf. Wittgenstein)/
げんごげいじゅつ /言語芸術/
げんごげんしょう /言語現象/
げんごこうい /言語行為;speech act/
げんごこうざ /言語講座/
げんごこうぞう /言語構造/
げんごこうどう /言語行動/
げんごし /言語史/
げんごしゅうとくのうりょく /言語習得能力/
げんごしょうがい /言語障害/
げんごしょり /言語処理/
げんごしょりけい /言語処理系/
げんごしよう /言語仕様/言語使用/
げんごしようしゃ /言語使用者/
げんごしようしょ /言語仕様書/
げんごしようじょう /言語仕様上/
げんごしんりがく /言語心理学/
げんごじたい /言語自体/
げんごじっけん /言語実験/
げんごじょう /言語上/
げんごじょうほう /言語情報/
げんごせいかつ /言語生活/
げんごせいせい /言語生成/
げんごせかい /言語世界/
げんごせっけい /言語設計/
げんごせっけいしゃ /言語設計者/
げんごせんよう /言語専用/
げんごぜんたい /言語全体/
げんごぜんぱん /言語全般/
げんごぞく /言語族/
げんごたいけい /言語体系/
げんごちしき /言語知識/
げんごちゅうすう /言語中枢/
げんごちりがく /言語地理学;linguistic geography/
げんごていぎ /言語定義/
げんごてき /言語的/
げんごてきちしき /言語的知識/
げんごてきひょうげん /言語的表現/
げんごてつがく /言語哲学;philosophy of language (cf.Wittgenstein)/
げんごとう /言語島/
げんごにゅうもん /言語入門/
げんごのうりょく /言語能力/
げんごはったつ /言語発達/
げんごばん /原語版/言語版/
げんごひょうげん /言語表現/
げんごぶんか /言語文化/
げんごぶんせき /言語分析;[哲学]linguistic analysis/
げんごへんか /言語変化/
げんごべつ /言語別/
げんごめい /言語名/
げんごもんだい /言語問題/
げんごや /言語野/言語屋/
げんごよう /言語用/
げんごりかい /言語理解/
げんごりょうほう /言語療法/
げんごりょうほうし /言語療法士;speech therapist/
げんごりろん /言語理論/
げんごろう /源五郎/
げんごろうまる /源五郎丸/
げんごろん /言語論/
げんさい /減債/減殺/現妻/幻妻/衒妻/
げんさいききん /減債基金/
げんさいばん /原裁判/
げんさいぼう /原細胞/
げんさきとりひき /現先取引/
げんさく /原作/減作/
げんさくしゃ /原作者/
げんさくしょうせつ /原作小説/
げんさくちゅう /原作中/
げんさくどうぶつ /原索動物/
げんさくひん /原作品/
げんさくぼん /原作本/
げんさくまんが /原作漫画/
げんさつ /減殺;=げんさい/
げんさん /原産/減算;subtract/減産;output cut.「原油の-」/
げんさんき /減算器/
げんさんごうせい /減算合成/
げんさんち /原産地/
げんさんちしょうめいしょ /原産地証明書/
げんざい /現在/原罪/
げんざいいち /現在位置/
げんざいかいしゅうちゅう /現在改修中/
げんざいかいちくちゅう /現在改築中/
げんざいかいはつちゅう /現在開発中/
げんざいかんりょう /現在完了/
げんざいぎょう /現在行/
げんざいぎろん /現在議論/
げんざいけい /現在形/
げんざいけいかくちゅう /現在計画中/
げんざいけんとうちゅう /現在検討中/
げんざいげんいん /現在原因/
げんざいさいしん /現在最新/
げんざいしこう /現在施行/
げんざいしこうちゅう /現在試行中/
げんざいしょぞく /現在所属/
げんざいしよう /現在使用/
げんざいしようちゅう /現在使用中/
げんざいしんこうけい /現在進行形/
げんざいしんこうちゅう /現在進行中/
げんざいじこく /現在時刻/
げんざいじせい /現在時制/
げんざいじゅんびちゅう /現在準備中/
げんざいせこう /現在施行/
げんざいせってい /現在設定/
げんざいせんたくちゅう /現在選択中/
げんざいだか /現在高/
げんざいち /現在地/現在値/
げんざいちょうさちゅう /現在調査中/
げんざいてもと /現在手元/
げんざいにっぽん /現在日本/
げんざいはつばい /現在発売/
げんざいはつばいちゅう /現在発売中/
げんざいふつう /現在不通/
げんざいぶんし /現在分詞/
げんざいほう /現在法/
げんざいまで /現在迄/
げんざいみしよう /現在未使用/
げんざいもんだい /現在問題/
げんざいやく /現在約/
げんざいらいにちちゅう /現在来日中/
げんざいりょう /原材料/
げんざいりょうひ /原材料費/
げんざいりょこうちゅう /現在旅行中/
げんざぶろう /源三郎/
げんざん /減算/
げんざんかいろ /減算回路/
げんざんき /減算器/
げんざんけっか /減算結果/
げんし /原子;atom/原始;primitive/原資;capital/幻視;hallucination/減資;capital reduction/原紙;base paper/原詩;original poem/元始/元史;二十一史/元祀/
げんし> /原始;(primitive,proto-) -惑星,-共産制/
げんしかく /原子核/
げんしかくこうがく /原子核工学/
げんしかくこうがっか /原子核工学科/
げんしかくぶつりがく /原子核物理学/
げんしかくほうかい /原子核崩壊/
げんしかくゆうごう /原子核融合;atomic fusion/
げんしかんすう /原始関数/
げんしきごう /原子記号/
げんしきのうてき /原始帰納的/
げんしきょうさんせい /原始共産制/
げんしきょうどうたい /原始共同体/
げんしけい /原子系/
げんしげんご /原始言語/
げんしさい /元始祭;1.3/
げんししき /原子式/原始式/
げんししつりょうたんい /原子質量単位/
げんししゃかい /原始社会/
げんしじ /原子時/
げんしじだい /原始時代/原史時代/
げんしじん /原始人/
げんしすう /原子数/
げんしせい /原始星;[天文]protostar/
げんしせつ /原子説/
げんしたいようけい /原始太陽系/
げんしだん /原子団/
げんしち /源七/
げんしちょうしゃ /現市庁舎/
げんしつ /玄室/原質/言質;げんち/
げんしてき /原始的/
げんしとう /原始島/
げんしどけい /原子時計/
げんしはんけい /原子半径/
げんしばくだん /原子爆弾/
げんしばんごう /原子番号/
げんしびょう /原子病/
げんしぶっきょう /原始仏教/
げんしぶつりがく /原子物理学/
げんしぶんし /原子分子/
げんしほうかい /原子崩壊/
げんしみつど /原子密度/
げんしもけい /原子模型/
げんしゃ /減車/
げんしゃかい /現社会/
げんしゃく /現尺/
げんしゃちょう /現社長/
げんしゃほう /現写法/
げんしゅ /厳守/元首/原種/原酒/
げんしゅう /減収/幻臭/現収/
げんしゅく /厳粛/減縮/
げんしゅしょう /現首相/
げんしゅつ /現出/幻出/
げんしょ /原書/原初/厳暑/
げんしょう /現象/減少/現症;present illness/
げんしょうかい /現象界;[哲学]Erscheinungswelt/
げんしょうかてい /減少過程/
げんしょうかんすう /減少関数/
げんしょうがく /現象学/
げんしょうけいこう /減少傾向/
げんしょうじたい /現象自体/
げんしょうてき /現象的/
げんしょうてんのう /元正天皇/
げんしょうぶん /減少分/
げんしょうめん /現象面/
げんしょうりつ /減少率/
げんしょうりょう /減少量/
げんしょうろん /現象論/
げんしょうろんてき /現象論的/
げんしょく /現職/原色;primary colours/減色;colour subtraction/減食;diet reduction/
げんしょくきょういく /現職教育/
げんしょくけいかん /現職警官/
げんしょくばん /原色版/
げんしょばん /原書版/
げんしりきこうがっか /原子力工学科/
げんしりょう /原子量/原資料/
げんしりょく /原子力/
げんしりょくいいんかい /原子力委員会/
げんしりょくきほんほう /原子力基本法/
げんしりょくけんきゅうしょ /原子力研究所/
げんしりょくこうがく /原子力工学/
げんしりょくさんぎょう /原子力産業/
げんしりょくじだい /原子力時代/
げんしりょくせつび /原子力設備/
げんしりょくせん /原子力船/
げんしりょくねんりょう /原子力燃料/
げんしりょくはくしょ /原子力白書/
げんしりょくはつでん /原子力発電/
げんしりょくはつでんしょ /原子力発電所/
げんしりん /原始林/
げんしろ /原子炉/
げんしろう /源四郎/
げんしろぶつりがく /原子炉物理学/
げんしろん /原子論/
げんしわくせい /原始惑星;[天文]protoplanet/
げんしん /原信/原審/現身/
げんしんごう /原信号/元信号/
げんじ /源氏/元治;年号(1864-1865)/言辞/現時/原字/源治/現示/玄二/
げんじえ /源氏絵/
げんじっかい /現実解/
げんじつ /現実/
げんじつおん /現実音/
げんじつか /現実化/
げんじつかい /現実界;[精医]le reel/
げんじつかん /現実感/
げんじつげんそく /現実原則/
げんじつしゃかい /現実社会/
げんじつしゅぎ /現実主義/
げんじつしゅぎしゃ /現実主義者/
げんじつせい /現実性/
げんじつせかい /現実世界/
げんじつたい /現実態/
げんじつてき /現実的/
げんじつてきたいおう /現実的対応/
げんじつとうひ /現実逃避/
げんじつとうひちゅう /現実逃避中/
げんじつにんしき /現実認識/
げんじつは /現実派/
げんじつばなれ /現実離れ;-した計画/
げんじつみ /現実味/
げんじつもんだい /現実問題/
げんじつろせん /現実路線/
げんじつろん /現実論/
げんじてきしょうひ /衒示的消費/
げんじてん /現時点/
げんじな /源氏名/
げんじばこ /源氏箱/
げんじほう /限時法/
げんじものがたり /源氏物語/
げんじものがたりえまき /源氏物語絵巻/
げんじゃく /減弱/
げんじゅう /厳重/現住/幻獣/
げんじゅうかい /幻獣界/
げんじゅうきょ /現住居/
げんじゅうしょ /現住所/
げんじゅうしょち /現住所地/
げんじゅうじてん /幻獣辞典/
げんじゅうち /現住地/
げんじゅうちゅうい /厳重注意/
げんじゅうみん /原住民/
げんじゅうろう /幻十郎/
げんじゅつ /幻術/
げんじょう /現状;†(state) 「-維持」/原状;†(original state) 「-回復」/現場;site/玄奘;=三蔵法師/現成;[仏教]実現/
げんじょういじ /現状維持/
げんじょういじは /現状維持派/
げんじょうかいせつ /現状解説/
げんじょうかいぜん /現状改善/
げんじょうかいふく /原状回復/
げんじょうかくにん /現状確認/
げんじょうきょう /現状況/
げんじょうこうあん /現成公案;[仏教]/
げんじょうさいだい /現状最大/
げんじょうさんぞう /玄奘三蔵/
げんじょうたい /現状態/
げんじょうちょうさ /現状調査/
げんじょうついにん /現状追認/
げんじょうにんしき /現状認識/
げんじょうはあく /現状把握/
げんじょうふざいしょうめい /現場不在証明;alibi/
げんじょうふっき /現状復帰/
げんじょうぶんせき /現状分析/
げんじょうほうこく /現状報告/
げんじょうほうこくしょ /現状報告書/
げんじょうほぞん /現場保存/
げんじょうもんだい /現状問題/
げんじょうようにん /現状容認/
げんじろう /源二郎/
げんじん /原人/眩人/幻人/減尽/
げんじんかん /原腎管/
げんすい /減衰/元帥/減水/
げんすいき /減衰器/
げんすいきょくせん /減衰曲線/
げんすいしんどう /減衰振動/
げんすいじかん /減衰時間/
げんすいじょうすう /減衰定数/
げんすいていすう /減衰定数/
げんすいとくせい /減衰特性/
げんすいは /減衰波/
げんすいばく /原水爆/
げんすいばくきんし /原水爆禁止/
げんすいりつ /減衰率/
げんすいりょう /減衰量/
げんすいりょく /減衰力/
げんすいりょくちょうせい /減衰力調整/
げんすう /減数/現数/元数/
げんすうぶんれつ /減数分裂/
げんすん /原寸/
げんすんだい /原寸大/
げんず /原図/
げんずけい /原図形/
げんせ /現世/
げんせい /厳正/現世;=げんせ/原生;-林/現生;-人類/現勢/現姓/
げんせいかえん /原生花園/
げんせいけん /現政権/
げんせいじんるい /現生人類/
げんせいだい /原生代;[地質年代]Proterozoic. 25-5.4億年前/
げんせいど /現制度/
げんせいどうぶつ /原生動物/
げんせいひん /現製品/
げんせいもくぶ /原生木部/
げんせいりん /原生林/
げんせき /原石/原籍/言責/
げんせつ /言説/
げんせりやく /現世利益/
げんせん /厳選/源泉/原潜/言泉/
げんせんかぜい /源泉課税/
げんせんそざい /厳選素材/
げんせんちょうしゅう /源泉徴収/
げんせんちょうしゅうぜい /源泉徴収税/
げんせんちょうしゅうひょう /源泉徴収票/
げんせんぶんり /源泉分離/
げんせんぶんりかぜい /源泉分離課税/
げんぜい /減税/
げんぜいこうか /減税効果/
げんぜん /厳然/現前/儼然;=厳然/
げんそ /元素/原素;<rare> =元素/
げんそう /幻想/玄宗;(685-762)唐の皇帝/舷窓/現送/
げんそうきょく /幻想曲/
げんそうこうきょうきょく /幻想交響曲/
げんそうてき /幻想的/
げんそうぶんがく /幻想文学/
げんそきごう /元素記号/
げんそく /原則/減速/舷側/
げんそくがわ /減速側/
げんそくきんえん /原則禁煙/
げんそくご /減速後/
げんそくざい /減速材/減速剤/
げんそくしゃせん /減速車線/
げんそくじ /減速時/
げんそくちゅう /減速中/
げんそくてき /原則的/
げんそくど /減速度/
げんそくひ /減速比/
げんそくほうこう /減速方向/
げんそくまえ /減速前/
げんそくむりょう /原則無料/
げんそくりょく /減速力/
げんそくろん /原則論/
げんそぶんせき /元素分析/
げんそん /現存/減損/玄孫/厳存/
げんそんかいけい /減損会計;asset-impairment accounting/
げんそんざい /現存在;[哲学]Dasein/
げんぞう /現像;develop.「写真の-」/原像;original image.「近代人の-」／[数学]inverse image/幻像;phantom.「蜃気楼の-」/
げんぞうえき /現像液/
げんぞうおんど /現像温度/
げんぞうしょ /現像所/
げんぞうしょり /現像処理/
げんぞうじかん /現像時間/
げんぞうじょうけん /現像条件/
げんぞうよう /現像用/
げんぞく /還俗/
げんぞん /現存/
げんた /源太/元太/玄太/
げんたい /減退/原隊/原態/
げんたいいん /現隊員/
げんたいけん /原体験/
げんたいせい /現体制/
げんたつ /厳達/
げんたろう /玄太郎/厳太郎/
げんたん /減反/
げんたんい /原単位;basic unit/
げんたんか /原単価/
げんだ /源田/
げんだい /現代/原題/
げんだい> /現代;-文学,-教育,-ギリシャ語/
げんだいえいご /現代英語/
げんだいおんがく /現代音楽/
げんだいおんがくか /現代音楽家/
げんだいか /現代化;modernisation/
げんだいかがく /現代科学/現代化学/
げんだいかな /現代仮名/
げんだいかなづかい /現代仮名遣い/現代仮名遣/
げんだいがっき /現代楽器/
げんだいきょうようぶんこ /現代教養文庫/
げんだいきょく /現代曲/
げんだいけんちく /現代建築/
げんだいげいじゅつ /現代芸術/
げんだいげき /現代劇/
げんだいこくご /現代国語/
げんだいこくごじてん /現代国語辞典/
げんだいご /現代語/
げんだいごやく /現代語訳/
げんだいさっか /現代作家/
げんだいさっきょくか /現代作曲家/
げんだいし /現代史/現代詩/
げんだいしそう /現代思想/
げんだいしそうにゅうもん /現代思想入門/
げんだいしゃかい /現代社会/
げんだいしゅぎ /現代主義;modernism/
げんだいしょうせつ /現代小説/
げんだいしょかん /現代書館/
げんだいしょどう /現代書道/
げんだいじん /現代人/
げんだいすうがく /現代数学/
げんだいすうがくしゃ /現代数学社/
げんだいせいかつ /現代生活/
げんだいせん /現代戦/
げんだいちゅうごく /現代中国/
げんだいちゅうごくご /現代中国語/
げんだいっこ /現代っ子/
げんだいてき /現代的/
げんだいてつがく /現代哲学/
げんだいとし /現代都市/
げんだいにほんご /現代日本語/
げんだいにほんじん /現代日本人/
げんだいばん /現代版/
げんだいひょう /現代表/
げんだいひょうき /現代表記/
げんだいびじゅつ /現代美術/
げんだいびじゅつかん /現代美術館/
げんだいびょう /現代病/
げんだいふう /現代風/
げんだいぶつり /現代物理/
げんだいぶつりがく /現代物理学/
げんだいぶん /現代文/
げんだいぶんがく /現代文学/
げんだいぶんめい /現代文明/
げんだいへん /現代編/
げんだいめい /原題名/
げんだいもの /現代物/
げんだいようご /現代用語/
げんだか /現高/
げんだんかい /現段階/
げんち /現地/言質/玄地/
げんちいり /現地入り/
げんちか /現地化/
げんちかかく /現地価格/
げんちかかりいん /現地係員/
げんちがし /現地貸/
げんちこうじょう /現地工場/
げんちご /現地語/
げんちしゅうごう /現地集合/
げんちしゅくはく /現地宿泊/
げんちしゅさい /現地主催/
げんちしゅざい /現地取材/
げんちじかん /現地時間/
げんちじょうほう /現地情報/
げんちじん /現地人/
げんちせいさん /現地生産/
げんちせいふ /現地政府/
げんちちょうさ /現地調査/
げんちちょうたつ /現地調達/
げんちつうか /現地通貨/
げんちづま /現地妻/
げんちてはい /現地手配/
げんちてん /現地点/
げんちとうちゃく /現地到着/
げんちはつ /現地発/
げんちほうじん /現地法人/
げんちゃ /原チャ/
げんちゃり /原チャリ/
げんちゅう /元中;年号(1384-1392)/原虫/原注;原著者の付けた注釈/原註/
げんちょ /原著/
げんちょう /幻聴/弦長/現調/
げんちょさくしゃ /原著作者/
げんちょさくぶつ /原著作物/
げんちょしゃ /原著者/
げんちょしょ /原著書/
げんちょろんぶん /原著論文/
げんちよみ /現地読み/
げんちりょこうしゃ /現地旅行社/
げんちろくおん /現地録音/
げんつき /原付/
げんつきいっしゅ /原付一種/
げんつきしゃ /原付車/
げんつきじどうしゃ /原付自動車/
げんつきにしゅ /原付二種/
げんつきめんきょ /原付免許/
げんてい /限定/舷梯/
げんてい> /限定/
げんていかいじょ /限定解除/
げんていかいじょしけん /限定解除試験/
げんていくうかん /限定空間/
げんていし /限定詞;[文法]determiner/限定子;[情報]qualifier/
げんていしゃ /限定車/
げんていしゅ /限定酒/
げんていしょうにん /限定承認/
げんていしょうひん /限定商品/
げんていしょく /限定色/
げんていじょうけん /限定条件/
げんていじょうぞう /限定醸造/
げんていせいさん /限定生産/
げんていせきにんのうりょく /限定責任能力/
げんていそうぞく /限定相続/
げんていつき /限定付/
げんていてき /限定的/
げんていてんぽ /限定店舗/
げんていはつばい /限定発売/
げんていはんばい /限定販売/
げんていばん /限定版;limited edition/限定盤;limited disk/
げんていひん /限定品/
げんていめんきょ /限定免許/
げんていゆにゅう /限定輸入/
げんてん /原点;†origin.「-に立ち帰る」/減点;†deduct.「-対象」/原典;†original.「-を参照する」/
げんてんかいき /原点回帰/
げんてんしき /減点式/
げんてんしゅぎ /原典主義/
げんてんすう /減点数/
げんてんちょうか /減点超過/
げんてんのう /現天皇/
げんてんばん /原典版/
げんてんほう /減点法/
げんとう /厳冬/幻燈/幻灯/舷灯;(船の)sidelight/
げんとうき /厳冬期/
げんとうきよう /厳冬期用/
げんとうしゅ /現当主/
げんとく /玄徳/元徳;年号(1329-1331)/験徳/
げんとして /厳として/
げんど /限度/
げんどう /言動/原動/
げんどうき /原動機/
げんどうきつき /原動機付/
げんどうふいっち /言動不一致/
げんどうりょく /原動力/
げんどがく /限度額/
げんな /元和;年号(1615-24)/
げんない /源内/
げんなおし /験直し/
げんなま /現生/現ナマ/
げんに /現に/
げんにほんご /現日本語/源日本語/
げんにん /現任/現認/元仁;年号(1224-1225)/
げんのう /玄能;sledgehammer/玄翁;=玄能／=源翁/源翁;(1329-1400)僧侶/玄応/言翁;?/
げんのうやく /減農薬/
げんのうやくさいばい /減農薬栽培/
げんのしょうこ /現の証拠/
げんはけい /原波形/
げんはんけつ /原判決/
げんば /現場/玄蕃/
げんばかんとく /現場監督/
げんばがわ /現場側/
げんばく /原爆/玄麦/
げんばくいりょうほう /原爆医療法/
げんばくしょう /原爆症/
げんばくしりょうかん /原爆資料館/
げんばくとうか /原爆投下/
げんばくどーむ /原爆ドーム/
げんばけんしょう /現場検証/
げんばしゃしん /現場写真/
げんばしゅぎ /現場主義/
げんばつ /厳罰/
げんばつか /厳罰化/
げんばふきん /現場付近/
げんばふっき /現場復帰/
げんばん /原版/原盤/
げんぱい /減配/
げんぱく /玄白;名/
げんぱつ /原発/
げんぱつおき /原発沖/
げんぱつけんせつ /原発建設/
げんぱつじこ /原発事故/
げんぱつすいしんは /原発推進派/
げんぱつせいめんえきふぜんしょうこうぐん /原発性免疫不全症候群/
げんぱつそう /原発巣;[医]primary focus/
げんぱつはんたい /原発反対/
げんぱつもんだい /原発問題/
げんぱん /原版/
げんひしつ /原皮質/
げんびん /減便/
げんぴ /原皮/元妃/厳秘/
げんぴょう /原票/
げんぴん /現品/原品;もとの品/
げんふうけい /原風景/
げんぶ /玄武/
げんぶがん /玄武岩/
げんぶつ /現物/原物/
げんぶつかぶ /現物株/
げんぶつきゅうよ /現物給与/
げんぶつしきゅう /現物支給/
げんぶつしゅっし /現物出資/
げんぶつとりひき /現物取引/
げんぶん /原文/元文;年号(1736-1741)/言文/
げんぶんいっち /言文一致/
げんぶんいっちうんどう /言文一致運動/
げんぶんいっちたい /言文一致体/
げんぶんそう /弦分奏/
げんぷ /厳父/原譜/現夫/
げんぷう /厳封/
げんぷく /元服/
げんぺい /源平/
げんぺいじだい /源平時代/
げんぺいせいすいき /源平盛衰記/
げんぺいとうきつ /源平藤橘/
げんぺいとうまでん /源平討魔伝;[ゲーム]ナムコ/
げんぼ /原簿/
げんぼく /原木/
げんぼん /原本/
げんぽう /減法;-/減俸/現法/
げんぽん /原本/
げんま /減摩/幻魔/玄馬/
げんまい /玄米/
げんまいしょく /玄米食/
げんまいちゃ /玄米茶/
げんまいぱん /玄米パン/
げんまき /弦巻/
げんまたいせん /幻魔大戦/
げんまつ /原末/
げんまん /拳万;指切り-/
げんみつ /厳密/
げんみつかい /厳密解/
げんみつせい /厳密性/
げんみょう /玄妙/
げんむ /幻夢/幻梦;「夢」異体字/
げんむせんき /幻夢戦記/
げんめ /限目/
げんめい /言明/厳命/
げんめいがっき /弦鳴楽器;バイオリン、ピアノなど/
げんめいてんのう /元明天皇/
げんめつ /幻滅/減滅;減ってなくなる/
げんめん /減免/原綿/
げんめんがく /減免額/
げんめんそち /減免措置/
げんもう /減耗/原毛/
げんもく /眩目/
げんもけい /原模型/
げんもん /厳門/
げんや /原野/幻夜/
げんやくいん /現役員/
げんやしょうほう /原野商法/
げんゆ /原油/
げんゆう /現有/
げんゆうき /現有機/
げんゆうしゃりょう /現有車両/
げんゆうせつび /現有設備/
げんゆうひん /現有品/
げんゆかかく /原油価格/
げんゆだか /原油高/
げんゆりゅうしゅつ /原油流出/
げんよう /現用/幻妖/原葉/幻幼;?/
げんようたい /原葉体/
げんようへいき /現用兵器/
げんり /原理/
げんりいがい /原理以外/
げんりけん /原理研/
げんりけんきゅう /原理研究/
げんりげんそく /原理原則/
げんりげんそくてき /原理原則的/
げんりしゅぎ /原理主義/
げんりしゅぎしゃ /原理主義者/
げんりしゅぎてき /原理主義的/
げんりじょう /原理上/
げんりず /原理図/
げんりつ /厳律/
げんりてき /原理的/
げんりゃく /元暦;年号(1184-1185)/
げんりゅう /源流/原流;=源流/
げんりゅうすい /源流水/
げんりゅうち /限流値/
げんりょう /原料/減量/限量;quantify/
げんりょうか /減量化/限量化;quantify/
げんりょうし /限量子/
げんりょく /減力/
げんろう /元老/
げんろういん /元老院/
げんろく /元禄;年号(1688-1704)/
げんろくずし /元禄寿司/
げんろせん /現路線/
げんろん /言論/原論/
げんろんじゆう /言論自由/
げんろんだんあつ /言論弾圧/
げんろんとうせい /言論統制/
げんろんのじゆう /言論の自由;憲法21条/
げんろんぶん /原論文/
げんわ /元和;年号(1615-1624)/
げんわかやま /現和歌山/
げんわく /幻惑/眩惑/
げんわくてき /幻惑的/
こ /子/小/個/故/古/粉/弧;arc/湖/庫/戸/固/箇;(助数詞) =個/个;(助数詞) =個,箇/ヶ;(助数詞) 「個」の略字/仔;動物の子/児/兒;「児」の旧字(人名用漢字)/娘;当て字/女/呼;呼称/乎;断乎/姑;しゅうとめ/枯;枯死/胡;胡弓/鈷;独鈷/估/沽;沽券/怙;依怙贔屓/罟;あみ/蛄;螻蛄(けら)/詁;訓詁/鴣;鷓鴣(しゃこ)/糊;のり/瑚;珊瑚/楜/葫;にんにく/蝴;蝴蝶/餬;餬口/凅;こおる/涸;涸渇/痼;しこり/錮;禁錮/孤;lone/狐;fox/菰;こも/呱;呱々(赤子の泣き声)/柧;さかづき/觚;操觚/虎;とら/乕;「虎」の異体字/琥;琥珀/虍;とらかんむり/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/壺;つぼ/壷;「壺」の異体字/雇;雇用/顧;顧問/鼓/皷;「鼓」の異体字/瞽;めくら/扈;跋扈/滬;上海の略称/袴;はかま/誇;誇示/跨;また・ぐ/刳;えぐ・る/夸/桍/瓠;瓢箪/胯;また/冴;さ・える/冱;「冴」の異体字/拠;根拠/股;また/賈;書賈/滸;水滸伝/箍;たが/蠱;蠱惑的/辜;無辜/粐;NB:幽霊字の一つ/己;自己/杞;(呉音) 杞憂/去;(呉音)去年(こぞ)/虚;(呉音)虚空/炬;(慣用音)炬燵/木;木立/黄;黄金色/来;動詞活用形?/⌒;arc/濃;動詞語幹?/濾;動詞語幹?/
こ> /小;small/子;(child) 子羊,子ライオン,子メーター/仔;(動物の子) 仔猫/故;late/古;(old) 古伊万里/孤;(lone) 孤月,孤蝶/
こーかさす /高加索/
こーすじょう /コース上/
こーすりょうり /コース料理/
こーちじん /コーチ陣/
こーつ /刻子/
こーとし /コート紙/
こーどか /コード化/
こーどしんこう /コード進行/
こーどふ /コード譜/
こーどへんかん /コード変換/
こーひー /珈琲/
こーひーてん /珈琲店/コーヒー店/
こーひーまめ /コーヒー豆/珈琲豆/
こーひーや /コーヒー屋/
こーらすぶ /コーラス部/
こーりゃん /高粱;kaoliang/
こーるしじょう /コール市場/
こーるてん /コール天/
こーんゆ /コーン油/
こあきない /小商い/
こあくつ /小圷/
こあくとう /小悪党/
こあくま /小悪魔/
こあくまてき /小悪魔的/
こあげ /小揚/
こあざ /小字/
こあし /小足/
こあじ /小アジ/小味;⇔大味/小鰺/
こあたま /小頭/
こあたり /小当たり/小当り/
こあな /小穴/
こあみ /小網/
こあみちょう /小網町/
こあゆ /小鮎/
こあら /古荒/
こい /恋/故意/鯉/濃/古意/湖衣/請い/戀;「恋」の旧字/
こいうた /恋歌/恋唄/
こいうらない /恋占い/
こいえ /小家/
こいおおき /恋多き/
こいかぜ /恋風/
こいがくぼ /恋ヶ窪/
こいがたき /恋敵/
こいがわ /鯉川/
こいき /小粋/小意気/
こいくち /濃口/濃い口;-醤油/
こいくちしょうゆ /濃口醤油/濃い口醤油/
こいぐち /鯉口/
こいけ /小池/菰池/
こいけだ /小池田/
こいこ /恋子/
こいこく /鯉濃/
こいごころ /恋心/
こいし /小石/礫/恋し/
こいしかわ /小石川/
こいしわら /小石原/
こいじ /恋路/
こいずみ /小泉/古泉/
こいずみきょうこ /小泉今日子/
こいずみやくも /小泉八雲/
こいそ /小磯/
こいた /小板/
こいち /小市/
こいちじかん /小一時間/
こいちゃ /濃茶/
こいづま /恋妻/
こいてき /故意的/
こいで /小出/
こいと /小糸/
こいとせいさくしょ /小糸製作所;[企業名]/
こいなか /恋仲/
こいにょうぼう /恋女房/
こいぬ /子犬/仔犬/小犬/
こいぬざ /小犬座;Canis Minor(CMi)/
こいぬま /鯉沼/濃沼/
こいねこ /恋猫/
こいねず /濃鼠/
こいのたきのぼり /鯉の滝登り/
こいのぼり /鯉幟/
こいのやまい /恋の病;lovesick/
こいはん /故意犯/
こいひとよ /恋一夜/
こいひめ /湖衣姫/
こいびと /恋人/
こいびとしょうほう /恋人商法/
こいびとたち /恋人達/
こいびとどうし /恋人同士/恋人同志;?/
こいびとやく /恋人役/
こいぶち /鯉淵/鯉渕/
こいぶみ /恋文/
こいぶみよこちょう /恋文横丁/
こいほう /古医方/
こいまり /古伊万里/
こいむらさき /濃紫/
こいむらさきいろ /濃紫色/
こいめ /濃い目/濃いめ/
こいも /小芋/子芋/
こいものがたり /恋物語/
こいもよう /恋模様/
こいやみ /恋病み/
こいわ /小岩/
こいわい /小岩井/
こいわずらい /恋煩い/恋患い;恋の病/
こいん /雇員/
こいんたい /古印体/
こう /公/項/考;考案/孝;孝行/功;功罪/劫;永劫／[囲碁]/甲/香/口/校/行/高/広/硬/厚/工/江/港/稿/後/好/光/孔/膏/綱;つな/鋼;はがね/講;講座/侯;†侯爵/候;†候補/鉱;鉱山/抗/航/斯う/乞/国府;こくふ/向/巧;巧拙/降;降板/絳;あか/酵;発酵/哮;咆哮/吼;ほ・える/拘;拘束/佝;佝僂病/怐;(おろか)/鉤;かぎ/鈎;「鉤」の異体字/勾;勾配/宏;宏大/浤/紘;八紘一宇/肱;ひじ/砿;「礦」の異体字/昿;「曠」の異体字/絋;(わた)/弘;弘法/交;交差/効;効果/絞;絞殺/郊;郊外/鮫;さめ/傚;(ならう)/咬;咬合/效;「効」の旧字/狡;狡猾/皎;(しろい)/蛟;(みずち)蛟竜/佼;立正佼成会/餃;餃子(ぎょうざ)/鵁/耕;耕作/畊;「耕」の異体字/耗;消耗/更;更新/梗;脳梗塞/哽;(むせる)/峺;(さえぎる)/荒;荒野/慌;恐慌/縞;しま/敲;推敲/犒;ねぎら・う/稾;「稿」の異体字/鎬;しのぎ/槁;(かれる)/塙;はなわ/藁;わら/嚆;嚆矢/垢;(あか)歯垢/后;皇后/詬;(はずかしめる)/逅;邂逅/幸;幸福/倖;(≒幸)僥倖/睾;睾丸/恒;恒星/恆;「恒」の旧字(人名用漢字)/亙;わた・る(人名用漢字)/亘;(「亙」との混同から)わた・る/構;構造/溝;海溝/購;購入/媾;媾合/搆;(かまえる)/篝;かがり/冓/覯;稀覯本/遘;(あう)/坑;炭坑/杭;くい/亢;亢進/伉/吭;(のどぶえ)/頏;(くび)/控;控除/腔;腔腸動物/倥/啌/椌/箜;箜篌/紅;紅一点/虹;(にじ)虹彩/扛;(あげる)/矼;(とびいし)/缸;(かめ)/肛;肛門/訌;(みだれる)/鴻;鴻鵠/桁;けた/絎;く・ける/攻;攻撃/攷;論攷/洪;洪水/哄;哄笑/閧/鬨;とき/岬;みさき/匣;はこ/呷;あお・る/狎;な・れる/胛;肩胛骨/閘;閘門/浩;浩大/皓/晧;「皓」の異体字/窖;あなぐら/誥;(つげる)/靠;(もたれる)/皇;皇帝/凰;鳳凰(ほうおう)/徨;彷徨/惶;恐惶/湟;(ほり)/煌;きら・めく/蝗;いなご/遑;いとま/鍠/隍;(からぼり)/晃;晃々(≒煌々)/幌;ほろ/滉;(ひろい)/恍;恍惚/晄;「晃」の異体字(人名用漢字)/洸/絖;ぬめ/胱;膀胱/昂;昂然/仰;信仰/貢;貢献/槓;槓杆/熕;砲熕/袷;あわせ/恰;恰好/閤;太閤/蛤;はまぐり/峇;(ほらあな)/洽;(あまねし)/鴿;はと/康;健康/糠;糟糠(の妻)/慷;慷慨/鱇;鮟鱇/喉;(のど)咽喉/猴;猿猴/盍;(なんぞ)/溘;溘焉/闔/黄;黄河/壙;(あな)/廣;「広」の旧字(人名用漢字)/曠;曠野/礦;(あらがね)/簧;した(reed)/鑛;「鉱」の旧字/黌;(まなびや)/叩;叩頭/釦;ぼたん/扣;(ひかえる)/肯;肯定/肴;(さかな)酒肴/淆;混淆/肓;病膏肓/皐;皐月(さつき)/皋;「皐」の異体字/杲;(あきらか)/昊;(なつぞら)/槹/寇;元寇/冦;「寇」の異体字/蚣;蜈蚣/撹;「攪」の異体字/興;振興/巷;(ちまた)巷間/庚;かのえ/衡;平衡/膠;膠着/嫦/汞;(水銀)昇汞/烋/爻;(八卦の各ライン)/磽/纐;纐纈(こうけち)/羔;(こひつじ)/耿/薨;薨去/鏗/尻;しり/岡;おか/崗;「岡」の異体字/剛/棡;(ゆずりは)/格;(慣用音)格子/神;神戸/嵩;(かさ) 動詞語幹?/昴;ぼう,すばる?/頁;けつ,ページ?/河;か,かわ?/衝;しょう?/湊;そう?/
こう# /高#0/高#2/
こう> /高/公;公設,公教育,公経済/抗/好/広/後/
こうあ /興亜/
こうあせきゆ /興亜石油;[企業名]/
こうあっしつ /高圧室/
こうあっしゅく /高圧縮/
こうあつ /高圧/降圧/光圧/
こうあつがす /高圧ガス;high-pressure gas/
こうあつざい /降圧剤/
こうあつせん /高圧線/
こうあつそうでんせん /高圧送電線/
こうあつちょくりゅう /高圧直流/
こうあつてき /高圧的/
こうあつでんせん /高圧電線/
こうあつでんりゅう /高圧電流/
こうあつぶぶん /高圧部分/
こうあん /考案/公安/公案;禅の-/弘安;年号(1278-88)/康安;年号(1361-1362)/甲案/
こうあんいいんかい /公安委員会/
こうあんかん /公安官/
こうあんかんけいしゃ /公安関係者/
こうあんきょく /公安局/
こうあんしつ /公安室/
こうあんしゃ /考案者/
こうあんじょうれい /公安条例/
こうあんちゅう /考案中/
こうあんちょうさちょう /公安調査庁/
こうあんてんのう /孝安天皇/
こうあんとうきょく /公安当局/
こうい /行為/好意;†favor.「-を寄せる」/厚意;†kindness.「ご-に感謝します」/高位/好位/更衣/校医/皇位/攻囲/校尉/校異/口胃/
こういき /広域;broad/高域;high/
こういきか /広域化/
こういきかがく /広域科学/
こういききょうちょう /高域強調/
こういきぎょうせい /広域行政/
こういきこうえんまえ /広域公園前/
こういきさいせい /高域再生/
こういきせいぶん /高域成分/
こういきとくせい /高域特性/
こういきぶんさんかんきょう /広域分散環境/
こういきれんごう /広域連合;4つある地方公共団体の組合のうちのひとつ。地方自治法第284条。/
こういけいしょう /皇位継承/
こういしつ /更衣室/
こういしゃ /行為者/
こういしょう /後遺症/
こういじたい /行為自体/
こういじょ /更衣所/
こういぜい /行為税/
こういち /好位置/浩一/公一/光一/幸一/耕一/孝一/宏一/晃一/弘一/功一/康一/興一/孝市/剛一/高一/好一/幸市/巧一/航一/鉱一/康市/晃市/耿一/興市/講一/高１/高1/
こういちゅう /行為中/
こういちろう /浩一郎/幸一郎/光一郎/耕一郎/康一郎/公一郎/鴻一郎/興一郎/晃一朗/幸一朗/宏一良/
こういっつい /好一対/
こういってん /紅一点/
こういつ /後逸/
こういてき /好意的/
こういど /高緯度/
こういどちたい /高緯度地帯/
こういのうりょく /行為能力/
こういろ /香色/
こういん /公印/行員;bank clerk/工員;worker/光陰/後印/拘引/後胤/荒淫/勾引;[法]/皇胤;天皇の後胤/
こういんしょう /好印象/
こういんじょう /勾引状/
こうう /降雨/項羽/
こううじ /降雨時/
こううつざい /抗鬱剤/抗うつ剤/
こううつやく /抗鬱薬/抗うつ薬/
こううりょう /降雨量/
こううりん /後右輪/
こううん /幸運/好運;≒幸運/耕耘/行雲/航運/皇運/光暈/
こううんかく /光雲閣/
こううんき /耕耘機/耕運機;=耕耘機 NB:常用漢字での代用表記。「耘」は雑草を取ること/
こううんじ /幸運児/
こううんてんだい /高運転台/
こううんふうん /幸運不運/
こううんりゅうすい /行雲流水/
こうえ /香会/黄衣/
こうえい /光栄/公営/後衛;arriere-garde.⇔前衛/後裔;descendant. ≒末裔/康永;年号(1342-1345)/光影/
こうえいきぎょう /公営企業/
こうえいきぎょうたい /公営企業体/
こうえいきょう /好影響/
こうえいけいば /公営競馬/
こうえいしごく /光栄至極/
こうえいじゅうたく /公営住宅/
こうえいとばく /公営賭博/
こうえいば /公営馬/
こうえいへい /紅衛兵/
こうえいろん /公営論/
こうえき /公益/交易/公役;兵役など/
こうえきかつどう /公益活動/
こうえきしせつ /公益施設/
こうえきしちや /公益質屋/
こうえきしんたく /公益信託/
こうえきじぎょう /公益事業/
こうえきじょうけん /交易条件/
こうえきせい /公益性/
こうえきほうじん /公益法人/
こうえつ /校閲/光悦;本阿弥光悦/
こうえつしゃ /校閲者/
こうえつぼん /光悦本/
こうえねけん /高エネ研/高エネルギー研究所;※abbrev/高エネルギー物理学研究所;※abbrev/
こうえねるぎー /高エネルギー/
こうえん /公園;park/講演;†lecture.「作家の-」/公演;†performance.「劇団の-」/後援/高遠/好演;good performance/口演;narrate/光塩;学校名/高塩;地名/後縁/宏遠;-な理想/紅炎;prominence/紅焔;=紅炎/光炎;light and fire/光焔;=光炎.「-万丈長し」/講筵;講義の席/巧演;skillful play/香煙/香烟;「煙」異体字/溘焉;sudden/
こうえんかい /講演会/後援会/
こうえんかいご /講演会後/
こうえんかいさんか /講演会参加/
こうえんかいすう /公演回数/
こうえんかつどう /講演活動/
こうえんがわ /公園側/
こうえんききゅう /好塩基球/
こうえんきぼう /講演希望/
こうえんきょくもく /公演曲目/
こうえんけいしき /講演形式/
こうえんけんすう /講演件数/
こうえんしゃ /講演者/後援者/
こうえんしゃきん /講演謝金/
こうえんしゅう /講演集/
こうえんしゅうりょうご /講演終了後/
こうえんしりょう /講演資料/
こうえんじ /高円寺/
こうえんじえき /高円寺駅/
こうえんじかん /講演時間/公演時間/
こうえんじゅん /講演順/
こうえんじょうほう /公演情報/
こうえんじょしがくいん /光塩女子学院/
こうえんせいびか /公園整備課/
こうえんだいめい /講演題名/
こうえんだいもく /講演題目/
こうえんちゅう /公演中/
こうえんちゅうし /公演中止/
こうえんちょう /公園町/
こうえんでびゅー /公園デビュー/
こうえんない /公園内/
こうえんないよう /講演内容/公演内容/
こうえんはっぴょう /講演発表/
こうえんび /公演日/講演日/
こうえんまえ /公園前/
こうえんめい /公演名/
こうえんりょう /講演料/
こうえんろんぶんしゅう /講演論文集/
こうお /好悪/
こうおう /康応;年号(1389-1390)/
こうおつ /甲乙/
こうおつつけ /甲乙付/
こうおつへい /甲乙丙/
こうおつへいてい /甲乙丙丁/
こうおん /高温/高音;high note/恒温;isothermal/構音;articulation. =調音/喉音;[音声学]guttural/口音;[音声学]oral/硬音;[音声学]fortis/厚恩/皇恩/高恩/
こうおんあつ /高音圧/
こうおんいき /高音域/
こうおんがわ /高温側/高音側/
こうおんき /高温期/
こうおんきょうちょう /高音強調/
こうおんこうあつ /高温高圧/
こうおんしつ /高音質/好音質;?/
こうおんしょうがい /構音障害;[医]dysphemia(吃りなど)/
こうおんじ /高温時/
こうおんすい /高温水/
こうおんせいぶん /高音成分/
こうおんそう /恒温槽/
こうおんちょうでんどう /高温超伝導/
こうおんど /高温度/
こうおんどうぶつ /恒温動物/
こうおんぶ /高音部/
こうか /効果/高価/校歌/硬化/降下/高架/硬貨/工科/公課/紅花/考課/光華/校下/降嫁/晃華/弘化;年号(1844-1848)/紅霞/高歌/黄禍/功科/膠化/甲賀/孔果/
こうかーど /好カード/
こうかい /公開/後悔/航海/更改/高階/公会/降灰/公海;⇔領海/黄海;Huang Hai/紅海;Red Sea/江海;川と海/香会/鋼塊;ingot/叩解/狡獪/後回;?/
こうかい> /公開;-質問状,-裁判,-鍵/
こうかいか /公開可/
こうかいかいつけ /公開買付/
こうかいかいゆう /降海回遊/
こうかいかぎ /公開鍵/
こうかいかぎあんごう /公開鍵暗号/
こうかいかのう /公開可能/
こうかいかんすう /高階関数/
こうかいがいしゃ /公開会社/
こうかいがた /降海型/
こうかいき /航海記/
こうかいきょか /公開許可/
こうかいきんし /公開禁止/
こうかいぎ /公会議/
こうかいこうえんかい /公開講演会/
こうかいこうざ /公開講座/
こうかいご /公開後/
こうかいさいばん /公開裁判/
こうかいさくひん /公開作品/
こうかいし /航海士/
こうかいしじょう /公開市場/
こうかいしじょうそうさ /公開市場操作/
こうかいしせつ /公開施設/
こうかいしつもん /公開質問/
こうかいしつもんじょう /公開質問状/
こうかいしょけい /公開処刑/
こうかいしょけいじょう /公開処刑場/
こうかいじ /公開時/
こうかいじゅぎょう /公開授業/
こうかいじゅつ /航海術;navigation/
こうかいじゅんび /公開準備/
こうかいじょう /公開状/
こうかいじょうほう /公開情報/
こうかいずみ /公開済/
こうかいせいげん /公開制限/
こうかいぞうど /高解像度/
こうかいたいきょく /公開対局/
こうかいちゅう /公開中/航海中/
こうかいちょう /航海長/
こうかいちょくぜん /公開直前/
こうかいてん /高回転/
こうかいてんいき /高回転域/
こうかいてんがた /高回転型/
こうかいてんじ /高回転時/
こうかいとうじ /公開当時/
こうかいとうろん /公開討論/
こうかいどう /公会堂/
こうかいなまほうそう /公開生放送/
こうかいにっし /航海日誌/
こうかいはん /航海班/
こうかいばん /公開版/
こうかいび /公開日/
こうかいほう /航海法/
こうかいほうそう /公開放送/
こうかいほうてい /公開法廷/
こうかいほうほう /公開方法/
こうかいまえ /公開前/
こうかいもんだい /公開問題/
こうかいよてい /公開予定/
こうかいれんしゅう /公開練習/
こうかいろくおん /公開録音/
こうかいろくが /公開録画/
こうかいろんり /高階論理/
こうかえき /高架駅/
こうかおん /効果音/
こうかおんてき /効果音的/
こうかか /高架化/
こうかかいゆう /降河回遊/
こうかかく /高価格/
こうかかこうじ /高架化工事/
こうかかじぎょう /高架化事業/
こうかがく /光化学/
こうかがくえん /晃華学園/
こうかがくすもっぐ /光化学スモッグ;photochemical smog/
こうかき /効果器/
こうかきかえ /項書換え/
こうかきょう /高架橋/
こうかぎょ /降河魚/
こうかく /降格/広角/口角/甲殻/高角/紅鶴/光覚/交角/高閣/岬角/後覚/厚角/攻殻;『-機動隊』(アニメ)/
こうかくえん /口角炎/
こうかくがわ /広角側/
こうかくきどうたい /攻殻機動隊;[アニメ]/
こうかくけい /広角系/
こうかくさいぼう /厚角細胞/
こうかくじゅう /甲殻獣/
こうかくそしき /厚角組織/
こうかくてんのう /光格天皇/
こうかくど /高角度/
こうかくほう /高角砲/
こうかくりつ /高確率/
こうかくるい /甲殻類/甲殼類/
こうかくれんず /広角レンズ/
こうかこうじ /高架工事/
こうかした /高架下/
こうかしょう /効果小/硬化症;[医]/
こうかじ /硬化時/
こうかじかん /硬化時間/
こうかじぎょう /高架事業/
こうかじゅう /高荷重/
こうかじゅつ /硬化術/
こうかじょう /高架上/
こうかせん /高架線/
こうかせんろ /高架線路/
こうかぜつだい /効果絶大/
こうかそくど /降下速度/
こうかたんだい /工科短大/
こうかだい /効果大/
こうかだいがく /工科大学/
こうかっせい /高活性/
こうかつ /狡猾/口渇/広闊/
こうかてき /効果的/
こうかてきめん /効果覿面/
こうかどうろ /高架道路/
こうかはんてい /効果判定/
こうかばつぐん /効果抜群/
こうかひょう /考課表/
こうかふこうか /幸か不幸か/
こうかぶたい /降下部隊/
こうかぶぶん /高架部分/
こうかぶん /効果分/
こうかほう /降下法/
こうかみ /鴻上/
こうかもんいんのべっとう /皇嘉門院別当;灘波江の 芦のかりねの ひとよゆゑ みをつくしてや 恋ひわたるべき/
こうかゆ /硬化油/
こうかりょくよう /紅花緑葉/
こうかろりー /高カロリー/
こうかろん /黄禍論/
こうかん /交換/好感;favor/高官/鋼管/交歓;打ち解け合う/公館/公刊/巷間/交感;sympathy/好漢/皇漢;日本と中国/江漢;地名,長江・漢水/浩瀚/向寒/後患/光環;corona/校勘/肛姦;[卑]/槓杆;lever/槓桿;lever/
こうかんあいて /交換相手/
こうかんいがい /交換以外/
こうかんいじょう /交換以上/
こうかんえき /交換駅/
こうかんか /交換可/
こうかんかい /交換会;情報-/交歓会;party/
こうかんかかく /交換価格/
こうかんかのう /交換可能/
こうかんかんけい /交換関係/
こうかんがくせい /交換学生/
こうかんがた /交換型/
こうかんき /交換機/交換器/
こうかんきかん /交換期間/
こうかんきのう /交換機能/
こうかんきぼう /交換希望/
こうかんきょく /交換局/
こうかんけい /項関係/
こうかんけいしき /交換形式/
こうかんけん /交換研/
こうかんこうちん /交換工賃/
こうかんご /交換後/
こうかんしき /交換式/
こうかんしせつ /交換施設/
こうかんしゅ /交換手/
こうかんしゅだん /交換手段/
こうかんしょく /好感触/
こうかんしょり /交換処理/
こうかんしんけい /交感神経/
こうかんじ /交換時/
こうかんじかん /交換時間/
こうかんじき /交換時期/
こうかんじっけん /交換実験/
こうかんじゅし /交換樹脂/
こうかんじょ /交換所/
こうかんじょうけん /交換条件/
こうかんじょうやく /交換条約/
こうかんじり /交換尻;手形交換所での決済の差額。日本銀行の当座預金で決済/
こうかんずみ /交換済/
こうかんせいぎょ /交換制御/
こうかんせつび /交換設備/
こうかんだい /交換台/
こうかんちゅう /交換中/
こうかんちょくご /交換直後/
こうかんていど /交換程度/
こうかんてすうりょう /交換手数料/
こうかんとれーど /交換トレード/
こうかんど /高感度;†high-sensitive.「-フィルム」/好感度;†popularity.「芸能人の-」/
こうかんにっき /交換日記/
こうかんばいたい /交換媒体/
こうかんばり /交換針/
こうかんひりつ /交換比率/
こうかんひん /交換品/
こうかんひんど /交換頻度/
こうかんふよう /交換不要/
こうかんぶ /交換部/
こうかんぶひん /交換部品/
こうかんぶんごう /交換分合/
こうかんほう /交換法/
こうかんほうしき /交換方式/
こうかんほうそく /交換法則/
こうかんほうほう /交換方法/
こうかんまえ /交換前/
こうかんまく /交換膜/
こうかんもう /交換網/
こうかんよう /交換用/
こうかんりつ /交換率;†exchange ratio.「呼吸-」/交換律;†commutative law. a*b=b*a/
こうかんりゅうがく /交換留学/
こうかんりゅうがくせいど /交換留学制度/
こうかんりろん /交換理論/
こうかんれき /交換歴/
こうが /甲賀/黄河/高雅/光画/江河/
こうがい /郊外/公害/校外/口外/口蓋;[解剖]palate/梗概;synopsis/光害;light pollusion/鉱害;mine pollusion/笄;髪飾り/港外/構外/坑外/慷慨/慷概;?/
こうがいえき /郊外駅/
こうがいおん /口蓋音;[音声学]palatal/
こうがいがた /郊外型/
こうがいがわ /郊外側/
こうがいじ /紅孩児/
こうがいすい /口蓋垂;[解剖]uvular/
こうがいせん /郊外線/
こうがいそしょう /公害訴訟/
こうがいたいさく /公害対策/
こうがいてつどう /郊外鉄道/
こうがいてん /郊外店/
こうがいでんしゃ /郊外電車/
こうがいはん /口蓋帆;[解剖]velic/
こうがいびょう /公害病/
こうがいびる /笄蛭/
こうがいぼうし /公害防止/
こうがいもんだい /公害問題/
こうがいよう /郊外用/
こうがいわげ /笄髷/
こうがく /工学;engineering/光学;optics/高額/後学/向学/好学/皇学/溝壑/
こうがくいせいたい /光学異性体;[化学]enantiomer/
こうがくいん /工学院/
こうがくいんだい /工学院大/
こうがくいんだいがく /工学院大学/
こうがくか /工学科/
こうがくかい /工学会/
こうがくかてい /工学課程/
こうがくかんけい /光学関係/
こうがくがっか /工学学科/
こうがくきかい /光学器械/
こうがくきき /光学機器/
こうがくきそ /工学基礎/
こうがくきょうしつ /工学教室/
こうがくけい /光学系/工学系/
こうがくけいけんきゅうか /工学系研究科/
こうがくけいさん /工学計算/
こうがくけっしょう /光学結晶/
こうがくけん /工学研/
こうがくけんきゅう /工学研究/
こうがくけんきゅうか /工学研究科/
こうがくけんきゅうかい /工学研究会/
こうがくけんきゅうしつ /工学研究室/
こうがくけんきゅうしゃ /工学研究者/
こうがくけんきゅうしょ /工学研究所/
こうがくけんきゅうじょ /工学研究所/
こうがくけんびきょう /光学顕微鏡/
こうがくこう /工学校/
こうがくこうぎょう /光学工業/
こうがくこうざ /工学講座/
こうがくごうせい /光学合成/
こうがくし /工学士/
こうがくしき /光学式/
こうがくしゃ /工学社;[出版社名]雑誌『I／O』,www.kohgakusha.co.jp/工学者/好学社;[出版社名]絵本。www.kogakusha.com/
こうがくしゅうし /工学修士/
こうがくしょ /工学書/
こうがくしょうきん /高額賞金/
こうがくしょうひん /高額商品/
こうがくしょとくしゃ /高額所得者/
こうがくしん /向学心/
こうがくじ /光学事/
こうがくじっけん /工学実験/
こうがくじっけんしつ /工学実験室/
こうがくじょう /工学上/
こうがくせい /光学製/
こうがくせいのう /光学性能/
こうがくせっけい /光学設計/
こうがくせんこう /工学専攻/
こうがくせんこうしゅうし /工学専攻修士/
こうがくせんしゅう /工学専修/
こうがくてき /工学的;engineering/光学的;optic/
こうがくてききそ /工学的基礎/
こうがくてきそくてい /光学的測定/
こうがくてきほうほう /工学的方法/
こうがくとくせい /光学特性/
こうがくねん /高学年/
こうがくはかせ /工学博士/
こうがくはくし /工学博士/
こうがくぶ /工学部/
こうがくぶかい /工学部会/
こうがくぶかがく /工学部化学/
こうがくぶかがくけい /工学部化学系/
こうがくぶこうしゃ /工学部校舎/
こうがくぶしゅっしんしゃ /工学部出身者/
こうがくぶぜんたい /工学部全体/
こうがくぶちょう /工学部長/
こうがくぶてき /工学部的/
こうがくぶでんき /工学部電気/
こうがくぶない /工学部内/
こうがくぶひん /高額部品/
こうがくぶまえ /工学部前/
こうがくぼうえんきょう /光学望遠鏡/
こうがくめん /光学面/工学面/
こうがくや /工学屋/
こうがくようご /工学用語/
こうがくれき /高学歴/
こうがくろん /工学論/
こうがぐん /甲賀郡/
こうがしつ /高画質/
こうがしゃ /恒河沙;10^52(または10^56)/
こうがっか /工学科/工学課/
こうがっかい /工学会/
こうがぶ /光画部/
こうがぶんめい /黄河文明/
こうがりゅう /甲賀流/
こうがん /睾丸/厚顔;-無知/紅顔;rose cheek/
こうがんざい /抗癌剤/抗がん剤/抗ガン剤/
こうがんむち /厚顔無恥/
こうき /後期/後記/工期/高貴/好機/光輝/工機/好奇/香気/校旗/皇紀/降旗/綱紀/公器/興起/好気/康煕/紅旗/後気/広軌/衡機/好期/口器;[生物]trophi/校規/校紀/公起/康熈/弘毅/幸喜/光樹/浩貴/幸毅/好輝/高機/
こうき> /後期;-過程,-印象派/
こうきあつ /高気圧/
こうきかい /好機会/
こうきかく /高規格/
こうきかくじゅうたく /高規格住宅/
こうきかくどうろ /高規格道路/
こうきかてい /後期課程/
こうきがた /後期型/
こうきぎょう /公企業/
こうきしけん /後期試験/
こうきしゃ /後期車/
こうきしゅくせい /綱紀粛正/
こうきしん /好奇心/
こうきしんおうせい /好奇心旺盛/
こうきじてん /康煕字典/
こうきせい /好気性/
こうきせいきん /好気性菌/
こうきち /幸吉/孝吉/康吉/光吉/耕吉/厚吉/
こうきでん /弘徽殿;=こきでん/
こうきとじ /康煕綴じ/
こうきど /高輝度/
こうきにってい /後期日程/
こうきのう /高機能/
こうきのうか /高機能化/
こうきはかせかてい /後期博士課程/
こうきみつ /高気密/
こうきみつか /高気密化/
こうきゃく /後脚/
こうきゅう /高級/恒久/高給/後宮/考究;†考えきわめる/講究;†誰もが納得いくまで調べる/公休/鋼球/光球/降級;downgrade/降給;pay cut/硬球/好球;-必打/皇宮;=こうぐう/攻究/購求/
こうきゅう> /高級;-言語,-官僚,(ありとあらゆる商品名について)-時計/
こうきゅうえん /好救援/
こうきゅうか /高級化/
こうきゅうかん /高級感/
こうきゅうかんりょう /高級官僚/
こうきゅうき /高級機/
こうきゅうきしゅ /高級機種/
こうきゅうぎょ /高級魚/
こうきゅうげんご /高級言語/
こうきゅうこうぐ /高級工具/
こうきゅうざい /高級材/
こうきゅうし /高級紙/後臼歯/
こうきゅうしぼうさん /高級脂肪酸;[化学]higher fatty acid NB:炭素数の多い/
こうきゅうしゃ /高級車/
こうきゅうしょうふ /高級娼婦/
こうきゅうじゅうたく /高級住宅/
こうきゅうじゅうたくがい /高級住宅街/
こうきゅうじゅうたくち /高級住宅地/
こうきゅうじょうようしゃ /高級乗用車/
こうきゅうすいせい /高吸水性/
こうきゅうてき /恒久的/
こうきゅうてん /高級店/
こうきゅうとり /高給取り/
こうきゅうひん /高級品/
こうきゅうび /公休日/
こうきゅうぶらんど /高級ブランド/
こうきゅうへいわ /恒久平和/
こうきゅうほう /恒久法;⇔特措法/
こうきゅうりょうてい /高級料亭/
こうきゅうりょうり /高級料理/
こうきゅうろく /講究録/
こうきょ /皇居/薨去/溝渠/公許/鉤距/
こうきょう /公共/交響/好況/高教/鋼橋/広狭/口供/荒凶/
こうきょう> /公共;-事業,-選択/
こうきょういく /公教育/
こうきょうかい /公教会/
こうきょうがく /交響楽/
こうきょうがくだん /交響楽団/
こうきょうきかん /公共機関/
こうきょうきぎょうたい /公共企業体/
こうきょうきょく /交響曲/
こうきょうきょくぜんしゅう /交響曲全集/
こうきょうくみあい /公共組合/
こうきょうくみきょく /交響組曲/
こうきょうけいざいがく /公共経済学;public economics/
こうきょうけん /公共圏/
こうきょうけんちく /公共建築;public building. 公民館から議事堂まで/
こうきょうこうこく /公共広告/
こうきょうこうこくきこう /公共広告機構/
こうきょうこうつう /公共交通/
こうきょうこうつうきかん /公共交通機関/
こうきょうこうつうせいび /公共交通整備/
こうきょうさーびす /公共サービス;public service/
こうきょうざい /公共財/
こうきょうし /交響詩/
こうきょうしせつ /公共施設/
こうきょうしょくぎょうあんていじょ /公共職業安定所/
こうきょうしん /公共心/
こうきょうじぎょう /公共事業/
こうきょうじぎょうひ /公共事業費/
こうきょうせい /公共性/
こうきょうだんたい /公共団体/
こうきょうてき /公共的/交響的/
こうきょうてきだんしょう /交響的断章/
こうきょうてきりえき /公共的利益/
こうきょうとうし /公共投資/
こうきょうとしょかん /公共図書館/
こうきょうどぶんぷ /光強度分布/
こうきょうのふくし /公共の福祉/
こうきょうぶつ /公共物/
こうきょうぶもん /公共部門/
こうきょうほうそう /公共放送/
こうきょうようすいいき /公共用水域/
こうきょうようり /公教要理;[キリスト教]catechism/
こうきょうりょうきん /公共料金/
こうきょく /鉤曲/
こうきろく /好記録/
こうきん /抗菌/公金/拘禁/口琴/黄巾/咬筋/行金/
こうきんかっせいたん /抗菌活性炭/
こうきんざい /抗菌剤/抗菌材/
こうきんじょう /拘禁場/
こうきんせい /抗菌性/
こうきんのらん /黄巾の乱;[中国史]184/
こうきんり /高金利/
こうぎ /講義;lecture/抗議;protest/広義;⇔狭義/公儀;御上/厚誼;厚い親切/交誼;おつきあい/後戯;⇔前戯/公議/巧技;fine play/後魏;[中国史]→北魏/恒偽/好誼/高誼/
こうぎいん /工技院/工業技術院/
こうぎうんどう /抗議運動/
こうぎかもく /講義科目/
こうぎけいしき /講義形式/
こうぎけん /航技研/
こうぎこうどう /抗議行動/
こうぎしつ /講義室/
こうぎしゅうかい /抗議集会/
こうぎしりょう /講義資料/
こうぎじゅつぶ /光技術部/
こうぎじょう /抗議状/
こうぎせきぶん /広義積分/
こうぎたいしょう /抗議対象/
こうぎちゅう /講義中/
こうぎでも /抗議デモ/
こうぎとう /講義棟/
こうぎないよう /講義内容/
こうぎぶん /抗議文/
こうぎめい /講義名/
こうぎょ /香魚/
こうぎょう /工業/鉱業;mining/興業;†事業を興す。「殖産-」/興行;†show.「サーカスの-」/鋼業;steel industry/航業/功業/鴻業/
こうぎょうあいか /工業哀歌/
こうぎょうかい /工業会/興行界/
こうぎょうかがく /工業化学/
こうぎょうかぶ /工業株/
こうぎょうかんけい /興行関係/
こうぎょうがっこう /工業学校/
こうぎょうきかく /工業規格/
こうぎょうぎじゅつ /工業技術/
こうぎょうぎじゅついん /工業技術院/
こうぎょうぎんこう /興業銀行;industrial bank/
こうぎょうけい /工業系/
こうぎょうけいそく /工業計測/
こうぎょうけん /鉱業権/
こうぎょうこうこう /工業高校/
こうぎょうこうとうがっこう /工業高等学校/
こうぎょうこうとうせんもんがっこう /工業高等専門学校/
こうぎょうこく /工業国/
こうぎょうざいだん /鉱業財団/
こうぎょうしゃ /興行者/
こうぎょうしょゆうけん /工業所有権/
こうぎょうしょゆうけんほう /工業所有権法/
こうぎょうしんぶん /工業新聞/
こうぎょうしんぶんしゃ /工業新聞社/
こうぎょうせいせき /興行成績/興業成績/
こうぎょうせいひん /工業製品/
こうぎょうせき /好業績/
こうぎょうせんもんがっこう /工業専門学校/
こうぎょうだいがく /工業大学/
こうぎょうだんち /工業団地/
こうぎょうち /工業地/
こうぎょうちいき /工業地域/
こうぎょうちたい /工業地帯/
こうぎょうちょうさかい /工業調査会/
こうぎょうてき /工業的/興行的/興業的/
こうぎょうとし /工業都市/
こうぎょうはいきぶつ /工業廃棄物/
こうぎょうはいすい /工業廃水/
こうぎょうほう /鉱業法/
こうぎょうぼき /工業簿記;inductrial bookkeeping. ⇔商業簿記/
こうぎょうよう /工業用/
こうぎょうようすい /工業用水/
こうぎょうりっこく /工業立国/
こうぎょうりょく /工業力/
こうぎょうれんめい /工業連盟/
こうぎょく /紅玉/硬玉/鋼玉/
こうぎょくしゃ /攻玉社;私立学校/
こうぎょくてんのう /皇極天皇/
こうぎろく /講義録/
こうぎわ /髪際/
こうぎん /興銀/
こうく /校区/工区/鉱区/鉤矩/
こうくう /航空/口腔/高空/
こうくういどう /航空移動/
こうくういんとう /口腔咽頭/
こうくううちゅう /航空宇宙/
こうくううちゅうがっか /航空宇宙学科/
こうくううちゅうきょく /航空宇宙局/
こうくううんちん /航空運賃/
こうくうえいせい /口腔衛生;歯磨けよ/
こうくうかもつ /航空貨物/
こうくうかんけい /航空関係/
こうくうかんせい /航空管制/
こうくうかんせいかん /航空管制官/
こうくうがいしゃ /航空会社/
こうくうがいしゃがわ /航空会社側/
こうくうがっか /航空学科/
こうくうがん /口腔癌/
こうくうき /航空機/
こうくうきぎじゅつ /航空機技術/
こうくうきじこ /航空機事故/
こうくうきょうてい /航空協定/
こうくうきょく /航空局/
こうくうきよう /航空機用/
こうくうぎょうかい /航空業界/
こうくうぎょうせい /航空行政/
こうくうぎょらい /航空魚雷/
こうくうけん /航空券/
こうくうけんきゅうかい /航空研究会/
こうくうげか /口腔外科/
こうくうこうがっか /航空工学科/
こうくうこうげき /航空攻撃/
こうくうこうせん /航空高専/
こうくうこうつう /航空交通/
こうくうこうつうかんせい /航空交通管制;air traffic control(ATC)/
こうくうさい /航空祭/
こうくうざっし /航空雑誌/
こうくうしゃしん /航空写真/
こうくうじえいたい /航空自衛隊/
こうくうじこくひょう /航空時刻表/
こうくうじゆうか /航空自由化/
こうくうじょうほう /航空情報/
こうくうせいのう /高空性能/
こうくうせいびし /航空整備士/
こうくうせん /航空戦/
こうくうせんとう /航空戦闘/
こうくうたい /航空隊/
こうくうだいがっこう /航空大学校;国交省。www.kouku-dai.ac.jp/
こうくうない /口腔内/
こうくうひ /航空費/
こうくうびん /航空便/
こうくうぶ /航空部/
こうくうぶたい /航空部隊/
こうくうへいりょく /航空兵力/
こうくうほあんだいがっこう /航空保安大学校;国交省。www.kouho-dai.ac.jp/
こうくうほう /航空法/
こうくうほけん /航空保険/
こうくうぼかん /航空母艦/
こうくうむせん /航空無線/
こうくうゆうびん /航空郵便/
こうくうゆそう /航空輸送/
こうくうりきがく /航空力学/
こうくうろ /航空路/
こうくうろせん /航空路線/
こうくぜい /鉱区税/
こうくつ /後屈/
こうくり /高句麗/高勾麗/
こうくん /校訓/
こうぐ /工具/香具/耕具/校具/
こうぐいっしき /工具一式/
こうぐう /厚遇/皇宮/后宮/
こうぐうけいさつ /皇宮警察/
こうぐきぐびひん /工具器具備品/
こうぐし /香具師/
こうぐち /高口/坑口/
こうぐてん /工具店/
こうぐるい /工具類/
こうぐん /行軍/皇軍/蝗軍/
こうぐんしょうぎ /行軍将棋/
こうけい /光景/口径/後継/黄経/後傾/後景/後経/口形/好形/肯綮;-に中る/皇兄/項型/皇系/
こうけいき /好景気/後継機/
こうけいきしゅ /後継機種/
こうけいざい /公経済/
こうけいしつ /後形質;[生物]metaplasm/
こうけいしゃ /後継者/
こうけいしゃしゅ /後継車種/
こうけいしゃなん /後継者難/
こうけいしゃぶそく /後継者不足/
こうけいしゃもんだい /後継者問題/
こうけいそうさい /後継総裁/
こうけいば /後継馬/
こうけいひ /口径比;[写真]aperture ratio/
こうけち /纐纈/
こうけっか /好結果/
こうけっかくざい /抗結核剤/
こうけっせい /抗血清/
こうけっとう /高血糖/
こうけつ /高潔/硬結/纐纈/膏血/紅血/絞結/
こうけつあつ /高血圧/
こうけつあつしょう /高血圧症;[医]/
こうけん /貢献/後見/高検;[略語]高等検察庁/公権/工研/高見/効験/後件/光顕/硬券/後験/甲券/
こうけんかんとくにん /後見監督人/
こうけんしゃ /貢献者/
こうけんてんのう /孝謙天皇/
こうけんど /貢献度/
こうけんにゅうじょうけん /硬券入場券/
こうけんにん /後見人/
こうけんぶ /後件部/
こうけんりょく /公権力/
こうげ /高下/香華/
こうげーむ /好ゲーム/
こうげい /工芸/工藝;「芸」旧字/虹霓;=にじ/
こうげいがくぶ /工芸学部/
こうげいがし /工芸菓子/
こうげいさくもつ /工芸作物/
こうげいし /工芸史/
こうげいせんいだい /工芸繊維大/
こうげいちゃ /工芸茶/
こうげいてん /工芸展/
こうげいひん /工芸品/
こうげき /攻撃/
こうげきか /攻撃下/
こうげきかいし /攻撃開始/
こうげきかいすう /攻撃回数/
こうげきかのう /攻撃可能/
こうげきがた /攻撃型/
こうげきがわ /攻撃側/
こうげきき /攻撃機/
こうげききかい /攻撃機会/
こうげきけん /攻撃権/
こうげきこうどう /攻撃行動/
こうげきさき /攻撃先/
こうげきさんか /攻撃参加/
こうげきしゃ /攻撃者/
こうげきしゅだん /攻撃手段/
こうげきしょうどう /攻撃衝動/
こうげきじ /攻撃時/
こうげきじゅん /攻撃順/
こうげきじん /攻撃陣/
こうげきせい /攻撃性/
こうげきたい /攻撃隊/
こうげきだま /攻撃玉/
こうげきちゅう /攻撃中/
こうげきちょくぜん /攻撃直前/
こうげきてき /攻撃的/
こうげきてきせいかく /攻撃的性格/
こうげきにんむ /攻撃任務/
こうげきは /攻撃派/
こうげきはんてい /攻撃判定/
こうげきへり /攻撃ヘリ/
こうげきほう /攻撃法/
こうげきほうほう /攻撃方法/
こうげきまほう /攻撃魔法/
こうげきめいれい /攻撃命令/
こうげきめん /攻撃面/
こうげきもくひょう /攻撃目標/
こうげきよう /攻撃用/
こうげきよういん /攻撃要員/
こうげきりょく /攻撃力/
こうげきわざ /攻撃技/
こうげつ /香月/
こうげん /高原/光源/公言;declare.「-して憚らない」/抗原;antigen/膠原;collagen/荒原;moors/広言;boast.「-を吐く」/高言;≒広言/巧言;-令色/康元;年号(1256-1257)/鉤玄/抗言;protest/口減;?/
こうげんがく /考現学/
こうげんこうたいはんのう /抗原抗体反応;[医]antigen-antibody reaction/
こうげんさい /公現祭;キリスト教]the Epiphany (1.6)/
こうげんせんい /膠原線維/
こうげんてんのう /孝元天皇/
こうげんびょう /膠原病/
こうげんぶんぷ /抗原分布/
こうげんほうこう /光源方向/
こうげんれいしょく /巧言令色/
こうこ /公庫/考古;-学/好古;-趣味/江湖/好個;good/後顧;-の憂い/香粉/
こうこう /高校/航行/孝行/煌々;(きらきら光る)「星が-と輝く」/後攻/口腔/坑口/港口/工高;[略語]工業高校/皓々;(白く明るい)「月色-」/皎々;≒皓々/耿々;(明るい)「灯が-と輝く」/後行/後考/膏肓;病-に入る/硬鋼;hard steel/後項;⇔前項/鉱坑/浩浩;(broad)「-たる大海」/硬膏/交媾/鉤校/
こうこういこう /高校以降/
こうこういちねん /高校一年/
こうこういちねんせい /高校一年生/
こうこういらい /高校以来/
こうこうえんげきぶ /高校演劇部/
こうこうがい /硬口蓋/
こうこうがいおん /硬口蓋音/
こうこうがわ /高校側/
こうこうきゅうじ /高校球児/
こうこうきょうかしょ /高校教科書/
こうこうきょうし /高校教師/
こうこうぎょう /鉱工業/
こうこうぎょうせいさんしすう /鉱工業生産指数/
こうこうけっしょう /高校決勝/
こうこうさ /光行差/
こうこうしんがく /高校進学/
こうこうじ /高校時/
こうこうじだい /高校時代/
こうこうじだいいらい /高校時代以来/
こうこうじゅけん /高校受験/
こうこうじょし /高校女子/
こうこうすうがく /高校数学/
こうこうせい /高校生/好光性;photophilous.「-種子」/向光性;positive phototaxis.「向日葵の-」/後行性/
こうこうせいいか /高校生以下/
こうこうせいかつ /高校生活/
こうこうせいくらい /高校生位/
こうこうせいしょくん /高校生諸君/
こうこうせかいし /高校世界史/
こうこうせんしゅけん /高校選手権/
こうこうそつ /高校卒/
こうこうそつぎょう /高校卒業/
こうこうそつぎょうご /高校卒業後/
こうこうそつぎょうじ /高校卒業時/
こうこうちゅう /航行中/
こうこうちゅうたい /高校中退/
こうこうつうがく /高校通学/
こうこうてい /高高低/
こうこうていど /高校程度/
こうこうてんのう /光孝天皇/
こうこうど /高高度/高々度/
こうこうどひこう /高高度飛行/
こうこうない /口腔内/
こうこうにねんせい /高校二年生/
こうこうにゅうし /高校入試/
こうこうぶつり /高校物理/
こうこうまで /高校迄/
こうこうむすこ /孝行息子/
こうこうむすめ /孝行娘/
こうこうめい /高校名/
こうこうもの /孝行者/
こうこうや /好好爺/好々爺/
こうこうやきゅう /高校野球/
こうこうやきゅうかい /高校野球界/
こうこうりつ /高効率/
こうこがく /考古学/
こうこがくしゃ /考古学者/
こうこがくてき /考古学的/
こうこがくはくぶつかん /考古学博物館/
こうこく /広告;ad/公告;announce.「特許の-」/公国;principality.「モナコ-」/皇国;empire.「-史観」/興国;年号(1340-1346)/抗告;protest.「即時-」/鴻鵠;-の志/侯国;marquisate/廣告;「広」旧字/皇國;「国」旧字/
こうこくか /皇国化/
こうこくがいしゃ /広告会社/
こうこくきじ /広告記事/
こうこくきんし /広告禁止/
こうこくぎょう /広告業/
こうこくぎょうかい /広告業界/
こうこくぎょうしゃ /広告業者/
こうこくけいさい /広告掲載/
こうこくこうか /広告効果/
こうこくさいばんしょ /抗告裁判所/
こうこくざっし /広告雑誌/
こうこくしかん /皇国史観/皇國史観;「国」旧字/
こうこくしゃ /広告車/
こうこくしゃしん /広告写真/
こうこくしゅうにゅう /広告収入/
こうこくせんでんひ /広告宣伝費/
こうこくだいりぎょう /広告代理業/
こうこくちゅう /広告中/
こうこくとう /広告塔/
こうこくぬし /広告主/
こうこくばいたい /広告媒体/
こうこくばんぐみ /広告番組/
こうこくひ /広告費/
こうこくび /公告日/
こうこくふか /広告不可/
こうこくぶん /広告文/
こうこくまんが /広告漫画/
こうこくや /広告屋/
こうこくよう /広告用/
こうこくらん /広告欄/
こうこくりょう /広告料/
こうこくわく /広告枠/
こうこすと /高コスト/
こうこつ /恍惚/硬骨/甲骨/
こうこつかん /恍惚感/硬骨漢/
こうこつぎょ /硬骨魚/
こうこつぶん /甲骨文/
こうこつもじ /甲骨文字/
こうこん /後根/
こうご /交互/口語/向後/庚午/
こうごう /皇后/咬合;かみあわせ/香合;お香の容器/校合;=きょうごう/交合;sex/媾合;=交合/
こうごうせい /光合成/
こうごうへいか /皇后陛下/
こうごうんてん /交互運転/
こうごか /口語化/
こうごかん /高互換/
こうごき /小動き/
こうごきたい /乞御期待/
こうごけい /口語形/
こうごけいさん /交互計算/
こうごさよう /交互作用/
こうごし /口語詩;[文学]/
こうごたい /口語体/
こうごちょう /口語調/
こうごてき /口語的/
こうごねんじゃく /庚午年籍;[日本史](670) 戸籍/
こうごのうみんせんそう /甲午農民戦争;1894/
こうごひょうげん /口語表現/
こうごぶん /口語文/
こうごぶんぽう /口語文法/
こうごほう /口語法;口語文法/
こうごやく /口語訳/
こうさ /交差/考査/黄砂/公差/交叉/較差/甲佐;地名/巧詐/
こうさい /交際/高裁;高等裁判所/公債/光彩;luster.「-を放つ」/虹彩;[解剖]iris.「眼球の-」/後妻/香菜/香西/甲西/公済/高斎/口才/
こうさいえん /虹彩炎;[医]/
こうさいか /交際家/
こうさいかい /弘済会/
こうさいしょうしょ /公債証書/
こうさいせんげん /交際宣言/
こうさいどう /廣済堂/
こうさいひ /交際費/公債費/
こうさいびょういん /公済病院/
こうさいぼう /膠細胞/
こうさいりくり /光彩陸離/
こうさいりょう /交際料/
こうさいりんどう /弘西林道/
こうさか /高坂/香坂/神坂/上坂/幸坂/上阪/江坂/香阪/
こうさかしょ /交差箇所/
こうさき /神前/
こうさく /工作/交錯/耕作/幸作/耕筰;人名,山田-/鋼索/鉤索/
こうさくいん /工作員/
こうさくがく /工作学/
こうさくきかい /工作機械/
こうさくけん /耕作権/
こうさくしつ /工作室/
こうさくしゃ /工作社;[出版社名]/
こうさくしょ /工作所/
こうさくせいど /工作精度/
こうさくせつび /工作設備/
こうさくせん /工作船/
こうさくてつどう /鋼索鉄道/
こうさくぶつ /工作物/
こうさくよう /工作用/
こうさし /交差視/
こうさしょ /考査書/
こうさすう /交差数/
こうさちてん /交差地点/
こうさつ /考察/絞殺/高札/高察/
こうさつちゅう /考察中/
こうさつぶそく /考察不足/
こうさてん /交差点/交叉点/
こうさてんじょう /交差点上/
こうさてんてまえ /交差点手前/
こうさてんない /交差点内/
こうさてんふきん /交差点付近/
こうさてんめい /交差点名/
こうさはんてい /交差判定/
こうさぶ /交差部/
こうさほう /交差法/
こうさん /公算/降参/興産/好酸/抗酸/鉱産/恒産/考算/公散/高三/高３/高3/
こうさんか /抗酸化/
こうさんかさよう /抗酸化作用/
こうさんかざい /抗酸化剤;antioxydant/
こうさんかぶっしつ /抗酸化物質/
こうさんきゅう /好酸球/
こうさんきん /抗酸菌/
こうさんきんびょうけんきゅうじょ /抗酸菌病研究所/
こうさんぜい /鉱産税/
こうさんだい /公算大/
こうざ /講座/口座/高座;寄席の-/硬座/
こうざい /鋼材/功罪/香西/絞罪/
こうざいしっそく /高材疾足/
こうざいりょう /好材料/
こうざき /神崎/
こうざざんだか /口座残高/
こうざしゃ /硬座車/
こうざしゅっせき /講座出席/
こうざせい /講座制/
こうざちょう /講座長/
こうざつ /交雑/
こうざつぎょ /交雑魚/
こうざつしゅ /交雑種/
こうざは /講座派/
こうざばんごう /口座番号/
こうざひ /講座費/
こうざひきおとし /口座引き落とし/口座引落/
こうざふりかえ /口座振替/
こうざふりこみ /口座振込/
こうざぶろう /幸三郎/
こうざべつ /講座別/口座別/
こうざめい /講座名/口座名/
こうざめいぎ /口座名義/
こうざめいぎにん /口座名義人/
こうざめいしょう /口座名称/
こうざん /高山/鉱山/甲山/江山/後産;=あとざん/衡山;地名,五岳の一。南岳/恒山;地名,五岳の一。北岳/鑛山/
こうざんがくぶ /鉱山学部/
こうざんしょくぶつ /高山植物/
こうざんじ /高山寺/
こうざんせい /高山性/
こうざんたい /高山帯/
こうざんびょう /高山病/
こうざんりゅうすい /高山流水;素晴らしい演奏/
こうし /講師/行使/格子;grid/光子;photon/公私/子牛/孔子;春秋時代・魯の思想家/公司;gong si/厚志/公使/嚆矢;pioneer/仔牛/高士/公子;貴族の子供/孝子;孝行な子供/皇子;天皇の子供/後肢;hindlimb/後翅;hindwing/高師;[略語]高等師範学校/甲子/紅紫/犢;=子牛/考試/鉱滓/黄紙/後嗣/工師/皇嗣/更始/皓歯;白い歯/郊祀/講士/鉤止/合志;地名/
こうしあい /好試合/
こうしいん /考試院/
こうしえん /甲子園/
こうしえんいがい /甲子園以外/
こうしえんかいかいしき /甲子園開会式/
こうしえんきゅうじょう /甲子園球場/
こうしえんぐち /甲子園口/
こうしえんぐちえき /甲子園口駅/
こうしえんしゅつじょう /甲子園出場/
こうしえんたいかい /甲子園大会/
こうしかん /公使館/
こうしがら /格子柄/
こうしき /公式/硬式/講式/項式/
こうしき> /公式;(official) -大会,-サイト/
こうしきか /公式化/
こうしきかいとう /公式回答/
こうしききそく /公式規則/
こうしききろく /公式記録/
こうしききろくいん /公式記録員/
こうしきぎょうじ /公式行事/
こうしきけんかい /公式見解/
こうしきげんご /公式言語/
こうしきさいと /公式サイト/
こうしきしゃざい /公式謝罪/
こうしきしりょう /公式資料/
こうしきじあい /公式試合/
こうしきじょう /公式上/
こうしきせってい /公式設定/
こうしきせん /公式戦/
こうしきせんにってい /公式戦日程/
こうしきせんはつ /公式戦初/
こうしきつうち /公式通知/
こうしきてき /公式的/
こうしきはっぴょう /公式発表/
こうしきばん /公式版/
こうしきぶんしょ /公式文書/
こうしきぺーじ /公式ページ/
こうしきやきゅう /硬式野球/
こうしきれい /公式令/
こうしきれんしゅう /公式練習/
こうしぎょらい /光子魚雷/
こうしけご /孔子家語/
こうしけっしょう /高脂血症/
こうしけつごう /格子結合/
こうしけつしょう /高脂血症/
こうしこんどう /公私混同/
こうししゃれい /講師謝礼/
こうしじま /格子縞/
こうしじょう /格子状/
こうしじん /講師陣/
こうしせい /高姿勢/
こうしそうにく /行尸走肉/
こうしぞう /格子像/
こうしちょうりつ /高視聴率/
こうしつ /硬質/皇室/高質/後室/膠質/
こうしつか /硬質化/
こうしつかいぎ /皇室会議;NB:皇室典範で定める。10名中、皇族は2名のみ/
こうしつかんけい /皇室関係/
こうしつけいざいほう /皇室経済法/
こうしつごようたつ /皇室御用達/
こうしつざいさん /皇室財産/
こうしつせんよう /皇室専用/
こうしつてんぱん /皇室典範/
こうしつど /高湿度/
こうしつひ /皇室費/
こうしつようざいさん /皇室用財産/
こうしづくり /格子造り;[建築]/
こうしていすう /格子定数/
こうしてん /格子点/
こうしてんかんかく /格子点間隔/
こうしど /格子戸/
こうしはけん /講師派遣/
こうしびょう /孔子廟/
こうしぼう /高脂肪/
こうしまど /格子窓/
こうしゃ /公社/校舎/後者/降車/巧者/公舎/後車/稿者/
こうしゃか /公社化/
こうしゃく /公爵;duke. NB:公>侯>伯>子>男/講釈/侯爵;marquis/
こうしゃくし /講釈師/
こうしゃくふじん /公爵夫人/
こうしゃぐち /降車口/
こうしゃさい /公社債/
こうしゃじ /降車時/
こうしゃせんよう /降車専用/
こうしゃない /校舎内/
こうしゃほう /高射砲/
こうしゃりん /後車輪/
こうしゅ /攻守;†攻めと守り/甲種/好守;†good defence/公主;皇女/好手;†nice play(er)/絞首/工手;engineer/校主/巧手;≒好手/後手/鉤取;?/
こうしゅう /講習/公衆/口臭/広州/甲州/杭州/興収/抗州/後周;[中国史]五代の第5(951-960)/紅萩/
こうしゅうえいせい /公衆衛生/
こうしゅうえいせいがく /公衆衛生学/
こうしゅうえき /高収益/
こうしゅうおんど /江州音頭/
こうしゅうかい /講習会/
こうしゅうかいかいさい /講習会開催/
こうしゅうかいしりょう /講習会資料/
こうしゅうかいせん /公衆回線/
こうしゅうかいどう /甲州街道/
こうしゅうしつ /講習室/
こうしゅうしょ /後周書/
こうしゅうじょ /講習所/
こうしゅうせい /光周性/
こうしゅうせき /高集積/
こうしゅうせきか /高集積化/
こうしゅうそうしんけん /公衆送信権/
こうしゅうちゅう /講習中/
こうしゅうでんわ /公衆電話/
こうしゅうでんわかいせん /公衆電話回線/
こうしゅうでんわもう /公衆電話網/
こうしゅうといれ /公衆トイレ/
こうしゅうどうとく /公衆道徳/
こうしゅうにゅう /高収入/
こうしゅうは /高周波/
こうしゅうはがた /高周波型/
こうしゅうはすう /高周波数/
こうしゅうはすういき /高周波数域/
こうしゅうはせいぶん /高周波成分/
こうしゅうはねつれん /高周波熱錬/
こうしゅうはぶぶん /高周波部分/
こうしゅうはよう /高周波用/
こうしゅうべん /甲州弁/
こうしゅうべんじょ /公衆便所/
こうしゅうよくじょう /公衆浴場/
こうしゅうわん /杭州湾/
こうしゅかいそう /甲種回送/
こうしゅく /拘縮/
こうしゅけい /絞首刑/
こうしゅそう /攻守走/
こうしゅだい /絞首台/
こうしゅつ /後出/
こうしゅつよう /高出葉/
こうしゅつりょく /高出力/
こうしゅどうめい /攻守同盟/
こうしゅび /好守備/
こうしゅん /香春/
こうしょ /高所/公署/向暑/講書/購書/校書/高書/好処/公書/口書/
こうしょう /交渉/公称/高尚/考証/校章/公証/工商/鉱床/工廠/哄笑/口承/厚相/工匠/公章/公傷/咬傷/高承/公娼/行賞/高唱/後章/黄鐘;[音楽]/口誦/好尚/洪鐘/巧匠/康正;年号(1455-57)/光昭/
こうしょう> /公称;(表向き) -部数,-55000人, (nominal) -帯域幅/
こうしょうあいて /交渉相手/
こうしょうか /交渉可/
こうしょうかいし /交渉開始/
こうしょうかのう /交渉可能/
こうしょうがく /考証学/
こうしょうきょく /公証局/
こうしょうきょくく /鉤章棘句;読みにくい文章/
こうしょうけつれつ /交渉決裂/
こうしょうけん /交渉権/
こうしょうしだい /交渉次第/
こうしょうじ /光照寺/
こうしょうじゅつ /交渉術/
こうしょうせいりつ /交渉成立/
こうしょうち /公称値/
こうしょうちゅう /交渉中/
こうしょうてんのう /孝昭天皇/
こうしょうでんあつ /公称電圧/
こうしょうど /高照度/
こうしょうにん /公証人/交渉人/
こうしょうぶ /好勝負/
こうしょうまどぐち /交渉窓口/
こうしょうめん /考証面/
こうしょうようりょう /公称容量/
こうしょうりょく /交渉力/
こうしょきょうふしょう /高所恐怖症/
こうしょく /公職/好色/更埴;地名/交織/黄色/紅色/降職/後蜀;[中国史]十国の一(934-965)/
こうしょくいちだいおとこ /好色一代男/
こうしょくいちだいおんな /好色一代女/
こうしょくかん /好色漢/
こうしょくし /更埴市/
こうしょくせんきょほう /公職選挙法/
こうしょくついほう /公職追放/
こうしょくぼん /好色本/
こうしょとく /高所得/
こうしょとくしゃ /高所得者/
こうしょとくしゃそう /高所得者層/
こうしょとくそう /高所得層/
こうしりょく /光子力/
こうしろう /幸四郎/
こうしん /更新/行進;march/交信/後進;-国/亢進;心悸-/口唇/庚申;かのえさる/後身;⇔前身/功臣/高進;≒亢進/昂進;≒亢進/孝心/恒心;恒産なきもの-なし/恒真;tautology/貢進/紅唇/後晋;[中国史]五代の第3(936-946)/
こうしんあいて /交信相手/
こうしんえつ /甲信越/
こうしんかのう /交信可能/
こうしんがた /更新型/
こうしんき /口唇期;[精医]orale Phase (Freudの用語)/
こうしんきょく /行進曲/
こうしんくう /高真空/
こうしんげがき /江岑夏書/
こうしんこうじ /更新工事/
こうしんこく /後進国/
こうしんご /更新後/
こうしんしき /恒真式/
こうしんしけん /更新試験/
こうしんしゃ /更新車/
こうしんしゃりょう /更新車両/
こうしんしゅうき /更新周期/
こうしんしょり /更新処理/
こうしんじ /更新時/
こうしんじこく /更新時刻/
こうしんじゅつ /降神術;spiritualism/
こうしんじょ /興信所/
こうしんじょうほう /更新情報/
こうしんじょちょうさ /興信所調査/
こうしんすう /交信数/
こうしんせい /更新世;[地質年代]Pleistocene. 180-1万年前/恒真性/
こうしんぜんご /更新前後/
こうしんそうさ /更新操作/
こうしんち /更新値/
こうしんちぇっく /更新チェック/
こうしんちほう /甲信地方/
こうしんちゅう /更新中;under renewal/交信中;in communication/行進中;on the march/
こうしんづか /庚申塚/
こうしんていし /更新停止/
こうしんてき /後進的/
こうしんどう /高振動/
こうしんにっき /更新日記/
こうしんび /更新日/
こうしんめいだい /恒真命題/
こうしんようきゅう /更新要求/
こうしんらい /高信頼/
こうしんらいか /高信頼化/
こうしんらいせい /高信頼性/
こうしんりょう /香辛料/更新料/更新量/
こうしんりょく /向心力/
こうしんりれき /更新履歴/
こうしんれつ /口唇裂;兎唇など/
こうしんろく /興信録/
こうじ /工事/公示/麹/高次/小路/糀;=麹/好事;-魔多し/公事;⇔私事/後事;-を託す/柑子;みかん/好餌/交事/鉤餌/浩二/浩司/幸治/孝治/幸司/光司/幸二/康二/晃司/孝司/弘治;年号(1555-1558)/康治;年号(1142-1144)/耕司/康司/耕治/孝二/幸次/宏治/浩治/孝次/耕二/浩志/浩次/光二/公司/弘二/広治/弘司/康次/宏次/光次/幸志/恒治/功児/耕次/皓司/甲児/貢司/厚二/広二/虹児/浩仁/剛次/滉二/吼児/功志/晧司/香次/考爾/
こうじいぜん /工事以前/
こうじいろ /柑子色/
こうじうんちん /公示運賃/
こうじえん /広辞苑;国語辞典/
こうじか /工事課/
こうじかい /高磁界/
こうじかんけいしゃ /工事関係者/
こうじかんれん /工事関連/
こうじき /光磁気/
こうじきょく /航時局/
こうじきん /麹菌/
こうじく /光軸/向軸/
こうじくかん /工事区間/
こうじくがた /向軸型/
こうじくがわ /向軸側/
こうじくけんさ /光軸検査/
こうじくちょうせい /光軸調整/
こうじげん /高次元/
こうじげんくうかん /高次元空間/
こうじげんご /高次言語/
こうじげんば /工事現場/
こうじこう /高次項/
こうじこうぞう /高次構造/
こうじさいかい /工事再開/
こうじさいこく /公示催告/
こうじしゃ /工事車/
こうじしゃりょう /工事車両/
こうじしゅうりょう /工事終了/
こうじせっけい /工事設計/
こうじせっけいしょ /工事設計書/
こうじそうたつ /公示送達/
こうじたんにんしゃ /工事担任者/
こうじちか /公示地価/
こうじちゅう /工事中/
こうじつ /口実/好日/後日/
こうじつせい /向日性/
こうじつびきゅう /曠日弥久/
こうじてつづき /工事手続き/工事手続/
こうじないよう /工事内容/
こうじば /高磁場/
こうじひ /工事費/
こうじぶ /工事部/
こうじほうほう /公示方法/
こうじまえ /工事前/
こうじまおおし /好事魔多し/
こうじまち /麹町/
こうじまちがくえん /麹町学園/
こうじまちてん /麹町店/
こうじまちでぐち /麹町出口/
こうじもーど /高次モード/
こうじや /工事屋/
こうじゅ /口授/坑儒/皇寿;111歳/
こうじゅうしん /高重心/
こうじゅうりょく /高重力/
こうじゅく /黄熟/
こうじゅつ /後述;あとで述べる/口述;口頭で述べる/講述;lecture/公述;公聴会で意見を述べる/
こうじゅつしけん /口述試験/
こうじゅつにん /公述人/
こうじゅつひっき /口述筆記/
こうじゅん /降順/交詢/公準;postulate/孝順;親に逆らわない/恒順/後順/
こうじゅんい /高順位/
こうじゅんかん /好循環/
こうじゅんしゃ /交殉社/
こうじゅんど /高純度/
こうじょ /控除/皇女/公女/公序/孝女/後序/
こうじょう /向上/工場/口上/荒城/攻城/厚情/恒常/甲状/光条/交情/皇城/鉤縄/
こうじょうあと /工場跡/
こうじょういよく /向上意欲/
こうじょううら /工場裏/
こうじょうか /恒常化/
こうじょうがい /工場街/
こうじょうきんむ /工場勤務/
こうじょうぐん /工場群/
こうじょうけん /好条件/
こうじょうけんがく /工場見学/
こうじょうけんせつ /工場建設/
こうじょうこう /向上校/
こうじょうさく /向上策/
こうじょうざいだん /工場財団/
こうじょうしゅっか /工場出荷/
こうじょうしゅっかじ /工場出荷時/
こうじょうしょ /口上書/
こうじょうしん /向上心/
こうじょうじっしゅう /工場実習/
こうじょうせい /恒常性/
こうじょうせいしゅこうぎょう /工場制手工業;マニュファクチャー/
こうじょうせん /甲状腺/
こうじょうせんしゅ /甲状腺腫/
こうじょうせんほるもん /甲状腺ホルモン/
こうじょうちたい /工場地帯/
こうじょうちょう /工場長/
こうじょうちょくえいてん /工場直営店/
こうじょうてき /恒常的/
こうじょうど /向上度/
こうじょうない /工場内/
こうじょうなんこつ /甲状軟骨;[解剖]thyroid/
こうじょうのつき /荒城の月;土井晩翠／滝廉太郎 ♪春高楼の花の宴/
こうじょうはいすい /工場廃水/
こうじょうほう /工場法;労働基準法の前身/恒常法/
こうじょうりつ /向上率/
こうじょうろうどうしゃ /工場労働者/
こうじょうわたし /工場渡/
こうじょがく /控除額/
こうじょけい /控除計/
こうじょたいしょう /控除対象/
こうじょりつ /控除率/
こうじょりょうぞく /公序良俗/
こうじよう /工事用/
こうじよてい /工事予定/
こうじりょう /工事料/
こうじりん /広辞林/
こうじろ /神代/
こうじろう /幸次郎/康次郎/孝次郎/公二郎/宏次郎/広二郎/香次郎/
こうじん /公人/行人/幸甚/荒神/工人/後塵;-を拝する/高人;=こうにん/後人;⇔先人/後陣;rear guard/黄塵/紅塵/
こうじんぐち /荒神口/
こうじんしゃ /行人社/工人舎/
こうじんばし /荒神橋/
こうじんばんじょう /黄塵万丈/
こうじんぶつ /好人物/
こうすい /香水;perfume/降水;rainfall/硬水;hard water/幸水;(梨の品種)/鉱水;mineral water/交綏/
こうすいい /高水位/
こうすいおん /高水温/
こうすいかくりつ /降水確率/
こうすいじゅん /高水準/
こうすいじゅんげんご /高水準言語/
こうすいびん /香水瓶/
こうすいりょう /降水量/
こうすう /口数/工数/校数/項数/恒数/
こうすうかんり /工数管理/
こうすうてき /工数的/
こうすけ /康介/耕輔/耕助/康祐/幸輔/宏介/宏祐/功介/広介/廣祐/江介/
こうすたーと /好スタート/
こうず /構図/公図;登記所の-/好事;-家/神津;こうづ?/高津;こうづ?/国府津;こうづ?/
こうずい /洪水/
こうずいしんわ /洪水神話/
こうずか /好事家/
こうずけ /上野/
こうずけのすけ /上野介/
こうずしま /神津島/
こうずじま /神津島/
こうせ /興世/
こうせい /構成/公正;fair/校正;proofread.「新聞の-」/攻勢/後世;†coming ages.「-に伝える」/後生;†後進。「-恐るべし」/更生;†rebirth.「受刑者の-」/更正;†revision.「-申告」/厚生;welfare.「-労働省」/恒星/鋼製/広西;†中国・チワン族の自治区/江西;†中国南部の省/向性;[生物]tropism/較正;calibrate.「計器の-」/硬性/高声/好晴/抗生;antibiotic.「-物質」/校生;(複合用途)/甲西/佼成;立正-会/甦生;=そせい/江青/高生/幸生/耕生/行星;惑星/煌星/貢成/佼正;佼成?/
こうせいあん /構成案/
こうせいいん /構成員/
こうせいいんぜんいん /構成員全員/
こうせいおん /構成音/
こうせいか /厚生課/
こうせいかいしゃ /更生会社/
こうせいかひるい /Metachlamydeae/
こうせいかん /恒星間/
こうせいかんざいにん /更生管財人/
こうせいがく /構成学/
こうせいがくえん /佼成学園/
こうせいき /構成機/
こうせいきき /構成機器/
こうせいきごう /校正記号/
こうせいきそく /構成規則/
こうせいきょく /交声曲;cantata/
こうせいぎんこう /恒生銀行/
こうせいけい /恒星系/
こうせいけいかく /更生計画/
こうせいけいざいがく /厚生経済学/
こうせいけってい /更正決定/
こうせいげんり /構成原理/
こうせいこく /構成国/
こうせいさい /高精細/
こうせいさいけん /更生債権/
こうせいざい /抗生剤/
こうせいし /構成子/
こうせいしせつ /厚生施設/更生施設;<生活保護法38/
こうせいしゃ /校正者/構成者/恒星社;[出版社名]/鋼製車/
こうせいしゅぎ /構成主義/
こうせいしょう /厚生省;NB:2001年1月の中央省庁再編で環境省と厚生労働省に再編された/
こうせいしょうしょ /公正証書/
こうせいしん /公正心/
こうせいしんびょうやく /抗精神病薬/
こうせいしんやく /向精神薬;麻薬及び-取締法/
こうせいしんりがく /構成心理学;structural psychology/
こうせいじょう /構成上/
こうせいじんいん /構成人員/
こうせいず /構成図/恒星図/
こうせいずり /校正刷り/校正刷/
こうせいせい /公正性/
こうせいせき /好成績/
こうせいせつ /後成説;生物/
こうせいそ /構成素/
こうせいたんい /構成単位/
こうせいたんぽけん /更生担保権/
こうせいだいじん /厚生大臣/
こうせいだんかい /校正段階/
こうせいちゅう /校正中/更生中/
こうせいちょう /高成長/
こうせいてき /構成的/
こうせいてん /構成点/
こうせいとうき /更正登記/
こうせいとりひき /公正取引/
こうせいとりひきいいんかい /公正取引委員会/
こうせいど /高精度/
こうせいどうぶつ /後生動物/
こうせいどか /高精度化/
こうせいどけいさん /高精度計算/
こうせいにん /構成人/
こうせいねん /好青年/
こうせいねんきん /厚生年金/
こうせいねんきんかいかん /厚生年金会館/
こうせいねんきんききん /厚生年金基金/
こうせいのう /高性能/
こうせいのうか /高性能化/
こうせいのか /高性能化/
こうせいば /校正場/
こうせいひ /構成比/
こうせいひりつ /構成比率/
こうせいびょういん /厚生病院/
こうせいぶ /厚生部/構成部/
こうせいぶっしつ /抗生物質/
こうせいぶひん /構成部品/
こうせいぶんし /構成分子/
こうせいほう /構成法/校正法/
こうせいほうほう /構成方法/
こうせいまいすう /構成枚数/
こうせいもくぶ /後生木部/
こうせいよう /校正用/
こうせいようけん /構成要件/
こうせいようそ /構成要素/
こうせいりょく /構成力/
こうせいろうどう /厚生労働/
こうせいろうどうしょう /厚生労働省;NB:労働省、厚生省が2001年1月の中央省庁再編で再編されたもの/厚生労働相;†大臣/
こうせいろうどうだいじん /厚生労働大臣/
こうせいろん /構成論/
こうせき /功績/鉱石/航跡;船の-/光跡;蛍の-/口跡;言い方/行跡;behaviour/洪積/講席/鑛石;「鉱」旧字/
こうせきうん /高積雲/
こうせきせい /洪積世/
こうせきそう /洪積層/
こうせきだいち /洪積台地/
こうせつ /降雪/公設/巷説;rumour/巧拙/交接/高説;「ご-」/後節/講説;lecture/紅雪/
こうせついちば /公設市場/
こうせつき /交接器/
こうせつひしょ /公設秘書/
こうせつりょう /降雪量/
こうせん /光線/抗戦;resist/交戦;fight/好戦;bellicose/鉱泉/公選/鋼線/高専;[略語]高等専門学校/工専;[略語]工業専門学校/黄泉/交線;[数学]intersection line/口銭/工繊/工船/工銭/工業高等専門学校;※abbrev/
こうせんけん /交戦権/
こうせんこく /交戦国/
こうせんさく /鋼線索/
こうせんしゃ /交戦者/
こうせんしゅ /好選手/
こうせんじゅう /光線銃/
こうせんすい /鉱泉水/
こうせんせい /公選制/高専生/
こうせんそつぎょうしゃ /高専卒業者/
こうせんだい /工繊大/
こうせんちゅう /交戦中/
こうせんついせき /光線追跡/
こうせんついせきほう /光線追跡法/
こうせんてき /好戦的/
こうせんほう /公選法/
こうせんほういはん /公選法違反/
こうせんりょう /高線量/
こうぜい /行成/
こうぜいびょうし /行成表紙/
こうぜつ /口舌/後舌/高舌/
こうぜつぼいん /後舌母音;[音声学]back vowel. 「ウ」「オ」/
こうぜん /公然;open/浩然;-の気/昂然;proudly/皓然;clear/煌然;brilliant/紅髯/
こうぜんじ /光善寺/
こうぜんのき /浩然の気/
こうそ /酵素/控訴;[法]第二審への上訴 NB:第三審へのものは「上告」/公訴;[法]刑事訴訟/公租;tax/高祖/皇祖;天皇の祖先，特に天照大神と神武/江蘇;中国東部の省。Jiangsu (チャンスー)/貢租;年貢など/
こうそう /構想/高層/抗争/香草/高僧;high priest/好走/後送/後奏;postlude/航送/高宗;人名/紅藻;[植物]rhodophyceae/降霜/厚層/広壮/宏壮;=広壮/高燥;⇔低湿/公葬/鉱層/厚葬/皇宗;天皇の祖先/
こうそういいんかい /構想委員会/
こうそううん /高層雲/
こうそうがた /厚層型/
こうそうけいかく /構想計画/
こうそうけんちく /高層建築/
こうそうけんちくぶつ /高層建築物/
こうそうさせい /高操作性/
こうそうだんかい /構想段階/
こうそうちゅう /抗争中/
こうそうてんきず /高層天気図/
こうそうば /好走馬/
こうそうびる /高層ビル/
こうそうぼく /高草木/
こうそうるい /好走塁/
こうそきかん /控訴期間/
こうそききゃく /控訴棄却;†第二審への上訴の棄却/公訴棄却;†刑事訴訟そのものを無効とする/
こうそく /高速/拘束/光速;299792458m／s/校則/梗塞/光束;luminous flux/航測/高足/
こうそくあんていせい /高速安定性/
こうそくい /拘束衣/
こうそくいか /光速以下/
こうそくいき /高速域/
こうそくいじょう /光速以上/
こうそくうんてん /高速運転/
こうそくか /高速化/
こうそくかいつう /高速開通/
こうそくかいてん /高速回転/
こうそくかいほう /高速解法/
こうそくかしゅほう /高速化手法/
こうそくかたいおう /高速化対応/
こうそくかんそう /高速乾燥/
こうそくがた /高速型/
こうそくくかん /高速区間/
こうそくぐ /拘束具/
こうそくぐん /高速群/
こうそくけい /高速系/
こうそくけいさん /高速計算/
こうそくけんさく /高速検索/
こうそくこうつうきかん /高速交通機関/
こうそくこうべ /高速神戸/
こうそくさつえい /高速撮影/
こうそくしこう /高速思考/
こうそくしゃ /高速車/
こうそくしゃりょう /高速車両/
こうそくしょり /高速処理/
こうそくじ /高速時/
こうそくじどうしゃどう /高速自動車道/
こうそくじゅんこう /高速巡行/
こうそくじょうけん /拘束条件/
こうそくせい /高速性/拘束性/
こうそくせいのう /高速性能/
こうそくせん /高速船/高速線/
こうそくそうこう /高速走行/
こうそくそうこうじ /高速走行時/
こうそくそうこうちゅう /高速走行中/
こうそくぞうしょくろ /高速増殖炉/
こうそくたいきゅう /高速耐久/
こうそくたいりょうゆそう /高速大量輸送/
こうそくだい /高速代/
こうそくだん /高速弾/
こうそくちゅうせいし /高速中性子/
こうそくつうしん /高速通信/
こうそくてい /高速艇/
こうそくてつどう /高速鉄道/
こうそくてつどうもう /高速鉄道網/
こうそくてんそう /高速転送/
こうそくど /高速度/光速度/
こうそくどう /高速道/
こうそくどうけんせつ /高速道建設/
こうそくどうろ /高速道路/
こうそくどうろかんけい /高速道路関係/
こうそくどうろじょう /高速道路上/
こうそくどうろそうこう /高速道路走行/
こうそくどうろだい /高速道路代/
こうそくどうろもう /高速道路網/
こうそくどうろもんだい /高速道路問題/
こうそくどうろりょうきん /高速道路料金/
こうそくどさつえい /高速度撮影/
こうそくどしゃしん /高速度写真/
こうそくばす /高速バス/
こうそくばん /高速版/
こうそくびょうが /高速描画/
こうそくへんかん /高速変換/
こうそくめん /高速面/
こうそくもんだい /校則問題/
こうそくりょうきん /高速料金/
こうそくりょく /拘束力/
こうそくれっしゃ /高速列車/
こうそくろ /高速炉/
こうそくろせん /高速路線/
こうそけい /酵素系/
こうそこうか /公租公課/
こうそさいばんしょ /控訴裁判所/
こうそしつ /好素質/
こうそしゅいしょ /控訴趣意書/
こうそしん /控訴審/
こうそじこう /公訴時効/
こうそじじつ /公訴事実/
こうそつ /高卒/
こうそつしゃ /高卒者/
こうそつじょし /高卒女子/
こうそつていど /高卒程度/
こうそつまえ /高卒前/
こうそにん /控訴人/
こうそふ /高祖父/
こうそぼ /高祖母/
こうそん /皇孫/荒村/
こうぞ /楮/
こうぞう /構造/幸三/耕三/浩三/耕造/孝三/孝蔵/弘蔵/行三/肯三/
こうぞういせい /構造異性;[化学]structural isomer/
こうぞうか /構造化/
こうぞうかいかく /構造改革/
こうぞうかいかくとっく /構造改革特区;[時事]<構造改革特別区域法/
こうぞうかいせき /構造解析/
こうぞうかげんご /構造化言語/
こうぞうかぶんしょ /構造化文書/
こうぞうがた /構造型/
こうぞうきょうぎ /構造協議/
こうぞうけいさん /構造計算/
こうぞうけってい /構造決定/
こうぞうけん /構造研/
こうぞうけんきゅうしつ /構造研究室/
こうぞうげんごがく /構造言語学;linguistique structurale(仏)/
こうぞうこうがくけい /構造工学系/
こうぞうざい /構造材/
こうぞうしき /構造式/
こうぞうしゅぎ /構造主義/
こうぞうしゅぎてき /構造主義的/
こうぞうじたい /構造自体/
こうぞうじょう /構造上/
こうぞうじょうほう /構造情報/
こうぞうず /構造図/
こうぞうせい /構造性/
こうぞうせっけい /構造設計/
こうぞうせん /構造線/
こうぞうそうかん /構造相関/
こうぞうたい /構造体/
こうぞうたいちゅう /構造体中/
こうぞうてき /構造的/
こうぞうてきけっかん /構造的欠陥/
こうぞうてきせいやく /構造的制約/
こうぞうてきもんだい /構造的問題/
こうぞうど /構造土/
こうぞうにんしき /構造認識/
こうぞうふきょう /構造不況/
こうぞうぶつ /構造物/
こうぞうぶん /構造文/
こうぞうへいや /構造平野/
こうぞうへんこう /構造変更/
こうぞうや /構造屋/
こうぞうよう /構造用/
こうぞうりきがく /構造力学/
こうぞがみ /楮紙/
こうぞく /後続/皇族/航続/
こうぞくおん /後続音/
こうぞくかいぎ /皇族会議;旧皇室典範。皇族による会議/
こうぞくきょり /航続距離/
こうぞくし /後続子/
こうぞくしゃ /後続車/
こうぞくじかん /航続時間/
こうぞくせつ /後続節/
こうぞくは /後続波/
こうぞくば /後続馬/
こうぞくひ /皇族費/
こうぞくりょく /航続力/
こうぞくれっしゃ /後続列車/
こうた /小唄/小歌/幸田/晃太/恒太/
こうたい /交代/後退/抗体/交替;≒交代/剛体;ごうたい?/
こうたいあつ /高耐圧/
こうたいいき /広帯域/
こうたいいきじゅしんき /広帯域受信機/
こうたいか /抗体価/鋼体化/
こうたいがた /後退型/
こうたいごう /皇太后/
こうたいごうぐう /皇太后宮/
こうたいごうぐうしき /皇太后宮職/
こうたいし /皇太子/
こうたいしき /交代式;[数学]alternant/交替式/
こうたいしでんか /皇太子殿下/
こうたいしひ /皇太子妃/
こうたいしょう /好対照/
こうたいしょく /後退色/
こうたいせい /交代制/交替制/
こうたいそん /皇太孫/
こうたいだいにゅう /後退代入/
こうたいとう /後退灯/
こうたいは /後退波/
こうたいよう /向太陽/
こうたいよく /後退翼/
こうたく /光沢/光澤;「沢」旧字/
こうたくし /光沢紙/
こうたくみん /江沢民/
こうたけ /革茸/
こうたつ /公達/
こうたに /甲谷/
こうたり /神足/
こうたろう /光太郎/耕太郎/幸太郎/浩太郎/孝太郎/弘太郎/高太郎/廣太郎/晃太朗/輝太郎/
こうたん /後端/降誕/荒誕/浩歎/浩嘆/
こうたんさい /降誕祭/
こうたんせい /抗堪性;抵抗する能力,堪える能力/
こうたんぱく /高タンパク/
こうだ /巧打;[野球]巧みなバッティング/好打/叩打/幸田/神田/甲田/香田/國府田/国府田/行田/光田/好田/古宇田/黄田/
こうだい /広大/後代/浩大;≒広大/宏大;≒広大/高台/高大/工大;[略語]工業大学/航大;[略語]航空大学校/香台/洪大;huge/
こうだいさい /工大祭/
こうだいじ /高台寺/
こうだいむへん /広大無辺/
こうだえき /江田駅/
こうだおん /後打音/
こうだか /甲高/
こうだく /黄濁/
こうだしゃ /好打者/
こうだちょう /幸田町/
こうだて /劫立て;[囲碁]/
こうだまりこ /國府田マリ子/
こうだりつ /高打率/
こうだろはん /幸田露伴/
こうだん /公団/後段/講談/高段/講壇/巷談/降壇/光弾/降段/高談/
こうだんし /講談師/好男子/皇男子/
こうだんしゃ /講談社;[出版社名]www.kodansha.co.jp/高段者/
こうだんしゃしゅっぱん /講談社出版/
こうだんしゃしんしょ /講談社新書/
こうだんしゃばん /講談社版/
こうだんしゃぶんこ /講談社文庫/
こうだんしゃまんがしょう /講談社漫画賞/
こうだんせい /光弾性/
こうだんせん /公団線/
こうだんねつ /高断熱/
こうだんねつか /高断熱化/
こうだんねつじゅうたく /高断熱住宅/
こうだんぼん /講談本/
こうち /高知/耕地/高地;highland/河内/公知/拘置/巧緻/幸地/後置/高置/好地/狡知/巧遅/公地/狡智/
こうちえき /高知駅/
こうちえきまえ /高知駅前/
こうちがり /小内刈り/
こうちきほう /後置記法/
こうちく /構築/
こうちくかのう /構築可能/
こうちくかんきょう /構築環境/
こうちくぎじゅつ /構築技術/
こうちくし /構築子/
こうちくじ /構築時/
こうちくちゅう /構築中/
こうちくぶつ /構築物/
こうちくほう /構築法/
こうちくほうほう /構築方法/
こうちくよう /構築用/
こうちくれい /構築例/
こうちけん /高知県/
こうちけんじん /高知県人/
こうちこうこう /高知高校/
こうちこうみん /公地公民/
こうちし /後置詞/高知市/
こうちしき /後置式/
こうちしょ /拘置所/
こうちしょうぎょう /高知商業/
こうちすいそう /高置水槽;[建築]ビルの屋上などにあるタンク/
こうちせい /巧緻性/向地性/
こうちせいり /耕地整理/
こうちだい /高知大/
こうちだいがく /高知大学/
こうちのう /高知能/
こうちぶんけん /公知文献/
こうちほうめん /高知方面/
こうちゃ /紅茶/
こうちゃいろ /紅茶色/
こうちゃいんりょう /紅茶飲料/
こうちゃく /膠着/降着/
こうちゃくご /膠着語/
こうちゃくじょうたい /膠着状態/
こうちゃつうしん /紅茶通信/
こうちやま /河内山/
こうちゅう /口中/甲虫/校注/校註/工注/蝗虫;ばった/甲冑;かっちゅう?/
こうちゅうきゅう /好中球/
こうちゅうじつ /高忠実/
こうちゅうやく /口中薬;のど飴やうがい薬など/
こうちょ /好著/光緒/高著/
こうちょう /好調/校長/紅潮/公聴/高潮/高張/高調/硬調/弘長;年号(1261-1264)/腔腸/
こうちょうえき /高張液/
こうちょうかい /公聴会/
こうちょうしつ /校長室/
こうちょうじ /好調時/
こうちょうせんせい /校長先生/
こうちょうどうぶつ /腔腸動物/
こうちょうは /高調波/
こうちょうはせいぶん /高調波成分/
こうちょうはもんだい /高調波問題/
こうちょうりょく /高張力/抗張力/
こうちょく /硬直/交直/
こうちょくか /硬直化/
こうちょくじかん /硬直時間/
こうちょくせい /硬直性/
こうちょくりゅう /交直流/
こうちょくりゅうでんしゃ /交直流電車/
こうちょくりょうよう /交直両用/
こうちん /工賃/
こうちんぎん /高賃金/
こうつ /刻子/
こうつい /項対/
こうつう /交通/
こうつうあんぜん /交通安全/
こうつうあんぜんきょういく /交通安全教育/
こうつうあんぜんけいはつ /交通安全啓発/
こうつうあんぜんしゅうかん /交通安全週間/
こうつうあんない /交通案内/
こうつういじ /交通遺児/
こうつういはん /交通違反/
こうつうえいだん /交通営団/
こうつうかいかん /交通会館/
こうつうかがくかん /交通科学館/
こうつうかくめい /交通革命/
こうつうかんきょう /交通環境/
こうつうがかり /交通係/
こうつうきかくか /交通企画課/
こうつうきかん /交通機関/
こうつうきせい /交通規制/
こうつうきそく /交通規則/
こうつうきっぷ /交通切符/
こうつうきばん /交通基盤/
こうつうきょういく /交通教育/
こうつうきょく /交通局/
こうつうきょくはっこう /交通局発行/
こうつうきょくまえ /交通局前/
こうつうぎょうせい /交通行政/
こうつうけいかん /交通警官/
こうつうけいむしょ /交通刑務所/
こうつうけんきゅうしつ /交通研究室/
こうつうこうえん /交通公園/
こうつうこうきょうきかん /交通公共機関/
こうつうこうしゃ /交通公社/
こうつうこうどう /交通行動/
こうつうさいばんしょ /交通裁判所/
こうつうし /交通史/
こうつうしどうか /交通指導課/
こうつうしべん /交通至便/
こうつうしゃ /交通社/
こうつうしゃかい /交通社会/
こうつうしゅだん /交通手段/
こうつうしんごう /交通信号/
こうつうしんぶん /交通新聞/
こうつうじこ /交通事故/
こうつうじこししゃ /交通事故死者/
こうつうじじょう /交通事情/
こうつうじゃくしゃ /交通弱者/
こうつうじゅうたい /交通渋滞/
こうつうじゅよう /交通需要/
こうつうじゅんさ /交通巡査/
こうつうじょうきょう /交通状況/
こうつうじょうほう /交通情報/
こうつうせいげん /交通制限/
こうつうせいさく /交通政策/
こうつうせいり /交通整理/
こうつうせん /交通線/
こうつうせんそう /交通戦争/
こうつうぜんたい /交通全体/
こうつうたいけい /交通体系/
こうつうどうとく /交通道徳/
こうつうはく /交通博/
こうつうはくぶつかん /交通博物館/
こうつうはんそくきん /交通反則金/
こうつうひ /交通費/
こうつうひほじょ /交通費補助/
こうつうひょうしき /交通標識/
こうつうひろば /交通広場/
こうつうぶ /交通部/
こうつうほういはん /交通法違反/
こうつうほうき /交通法規/
こうつうもう /交通網/
こうつうもうせいび /交通網整備/
こうつうもんだい /交通問題/
こうつうようりょう /交通容量/
こうつうりょう /交通量/
こうつうりょうぞうか /交通量増加/
こうつごう /好都合/
こうづ /国府津/高津/
こうづき /香月/上月/神月/
こうづけ /上野/
こうづけのすけ /上野介/
こうづしま /神津島/
こうてい /工程;†process/皇帝/肯定/行程;†distance,stroke/高低/校庭/公邸/校訂/公定/高弟;your brother/黄帝;[中国史]/航程;船の-/皇弟;emperor's brother/校定/後庭/孝悌;[儒教]孝行/更訂/考訂/公廷/鉤悌/
こうていあくせんと /高低アクセント;[言語]pitch accent. 日本語など/
こうていいき /高低域/
こうていえき /口蹄疫;家畜伝染病/foot and mouse disease/
こうていえんぶきょく /皇帝円舞曲/
こうていかかく /公定価格/
こうていかんり /工程管理/
こうていさ /高低差/
こうていしゃ /校訂者/
こうていしょ /公定書/
こうていてい /高低低/
こうていてき /肯定的/
こうていてきひょうか /肯定的評価/
こうていは /肯定派/
こうていひょう /工程表/行程表;road map. 「中東和平の-」/
こうていぶあい /公定歩合/
こうていへいか /皇帝陛下/
こうていぺんぎん /皇帝ペンギン;emperor penguin/
こうてき /公的/好適/
こうてき> /公的;-年金,-機関,-扶助/
こうてききかん /公的機関/
こうてききせい /公的規制/
こうてききんゆう /公的金融/
こうてきけんきゅうきかん /公的研究機関/
こうてきざいげん /公的財源/
こうてきしかく /公的資格/
こうてきしきん /公的資金/
こうてきしきんちゅうにゅう /公的資金注入/
こうてきしゅ /好敵手/
こうてきせきにん /公的責任/
こうてきちつじょ /公的秩序/
こうてきねんきん /公的年金/
こうてきふじょ /公的扶助/
こうてきほいくせいど /公的保育制度/
こうてきほじょ /公的補助/
こうてつ /鋼鉄/更迭/
こうてつせい /鋼鉄製/
こうてん /好転/好天;good weather/交点/荒天;heavy weather/公転/後転/光点/後天/高点/皇天/好点/
こうてんきどう /公転軌道/
こうてんし /告天子/
こうてんしゅうき /公転周期/
こうてんせい /後天性/
こうてんせいめんえきふぜんしょうこうぐん /後天性免疫不全症候群;AIDS/
こうてんそくど /公転速度/
こうてんてき /後天的/
こうてんてきめんえき /後天的免疫/
こうで /小腕/
こうでい /拘泥/膠泥/
こうでら /香寺/
こうでん /香典/香奠;=香典/光電/公電/
こうでんあつ /高電圧/
こうでんあつか /高電圧化/
こうでんかん /光電管/
こうでんがえし /香典返し/
こうでんこうか /光電効果/
こうでんし /光電子/
こうでんしぞうばいかん /光電子増倍管/
こうでんしゃ /高電社/弘電社/
こうでんそくこう /光電測光/
こうでんち /光電池/
こうでんぱ /光電波/
こうでんへんかん /光電変換/
こうでんめん /光電面/
こうと /皇都/狡兎;狡兎死して走狗烹らる/
こうとう /高等/口頭/高騰/好投/喉頭/江東/勾当/後頭/口答/恒等/皇統/公党/紅灯/叩頭/高踏/降等/昂騰/
こうとう> /高等;-学校,-生物,研究員/
こうとういんとう /喉頭咽頭/
こうとうえん /喉頭炎/
こうとうおん /喉頭音;[音声学]glottal/
こうとうか /高等科/
こうとうかん /高等官/
こうとうかんすう /恒等関数/
こうとうがい /喉頭蓋;[解剖]epiglottis/
こうとうがっこう /高等学校/
こうとうがん /喉頭癌/
こうとうきょう /喉頭鏡;laryngoscope/
こうとうきょういく /高等教育/
こうとうぎじゅつ /高等技術/
こうとうく /江東区/
こうとうけいさつ /高等警察/
こうとうけんさつちょう /高等検察庁/
こうとうご /口頭語/
こうとうさいばんしょ /高等裁判所/
こうとうしき /恒等式/
こうとうしけん /口頭試験/
こうとうしはん /高等師範/
こうとうしはんがっこう /高等師範学校/
こうとうしもん /口頭試問/
こうとうしゃぞう /恒等写像/
こうとうしゅ /好投手/
こうとうしょうがっこう /高等小学校/
こうとうしょうぎょうがっこう /高等商業学校/
こうとうしょくぶつ /高等植物/
こうとうじょがっこう /高等女学校/
こうとうすうがく /高等数学;advanced mathematics/
こうとうせいぶつ /高等生物/
こうとうせんもんがっこう /高等専門学校/
こうとうだい /勾当台/
こうとうちゅうがっこう /高等中学校/
こうとうてき /高踏的/恒等的/
こうとうどうぶつ /高等動物/
こうとうはっぴょう /口頭発表/
こうとうふ /皇統譜/
こうとうぶ /高等部/後頭部/
こうとうへんかん /恒等変換/
こうとうべんむかん /高等弁務官;high commissioner. 「(国連)難民-(事務所),人権-」/
こうとうべんろん /口頭弁論/
こうとうべんろんきじつ /口頭弁論期日/
こうとうべんろんちょうしょ /口頭弁論調書/
こうとうほういん /高等法院/
こうとうむけい /荒唐無稽/
こうとうよう /後頭葉/
こうとく /高徳/孝徳/幸徳/光徳/神徳/公徳/康徳/行徳/
こうとくしゅうすい /幸徳秋水/
こうとくしん /公徳心/
こうとくせん /高徳線/
こうとくてん /高得点/
こうとくてんのう /孝徳天皇/
こうとりい /公取委/
こうど /高度/硬度/光度/黄土/耕土/荒土/公度/
こうどう /行動/講堂/公道;highway/香道;お香の芸道/坑道;pit/黄銅;=おうどう/黄道;ecliptic/孝道;[儒教]/高堂/皇道;天皇による統治/
こうどういがい /行動以外/
こうどうかがく /行動科学/
こうどうかん /講道館/弘道館;[日本史]水戸藩の藩校/
こうどうがく /行動学/
こうどうきじゅん /行動基準/
こうどうきちにち /黄道吉日/
こうどうきはん /行動規範/
こうどうきょり /行動距離/
こうどうけいかく /行動計画/
こうどうけっか /行動結果/
こうどうげんり /行動原理/
こうどうしゅぎ /行動主義/
こうどうしゅぎしゃ /行動主義者/
こうどうしゅたい /行動主体/
こうどうしょく /行動食/
こうどうしよう /公道仕様/
こうどうしんりがく /行動心理学/
こうどうじっけん /行動実験/
こうどうじゅうにきゅう /黄道十二宮/
こうどうじょう /行動上/
こうどうせいぎょ /行動制御/
こうどうせいぶつがく /行動生物学;ethology/
こうどうせいり /行動生理/
こうどうそうこう /公道走行/
こうどうそうこうかのう /公道走行可能/
こうどうそうこうふか /公道走行不可/
こうどうたい /黄道帯/
こうどうたいけい /行動体系/
こうどうちゅう /行動中/
こうどうてき /行動的/
こうどうにゅうもん /香道入門/
こうどうは /行動派/皇道派/
こうどうはんい /行動範囲/
こうどうはんけい /行動半径/
こうどうぱたーん /行動パターン/
こうどうふのう /行動不能/
こうどうよう /公道用/
こうどうようしき /行動様式/
こうどうよてい /行動予定/
こうどうりょうほう /行動療法/
こうどうりょく /行動力/
こうどか /高度化/
こうどきょういく /高度教育/
こうどきょくせん /光度曲線/
こうどく /購読;買って読む/講読;テクストを教える/鉱毒/
こうどくしゃ /購読者/講読者;lectureする人?/
こうどくしゃそう /購読者層/
こうどくそ /抗毒素/
こうどくちゅう /購読中/
こうどくりょう /購読料/
こうどくれき /購読歴/
こうどけい /光度計;photometer/高度計;altimeter/好時計;nice record/
こうどさ /高度差/
こうどじゅんのう /高度順応/
こうどじょうほうか /高度情報化/
こうどじょうほうかしゃかい /高度情報化社会/
こうどじょうほうしゃかい /高度情報社会/
こうどじょうほうつうしん /高度情報通信/
こうどせいちょう /高度成長/
こうどせいちょうき /高度成長期/
こうどそくてい /光度測定/高度測定/
こうどつうしん /高度通信/
こうどば /高度場/
こうどへんか /高度変化/
こうどりよう /高度利用/
こうない /校内/構内/口内/港内/坑内/
こうないえん /口内炎/
こうないがい /校内外/
こうないがわ /港内側/
こうないこうじ /構内工事/
こうないしゃせい /口内射精/
こうないびん /校内便/
こうないふみきり /構内踏切/
こうないほうそう /構内放送/
こうなご /小女子/
こうなん /江南/港南/甲南/硬軟/香南/後難/
こうなんく /港南区/
こうなんご /江南語/
こうなんじん /江南人/
こうなんだい /港南台/甲南大/
こうなんだいがく /甲南大学/
こうなんだいてん /港南台店/
こうなんちょう /甲南町/
こうに /高二/高２/高2/
こうにち /抗日/
こうにちうんどう /抗日運動/
こうにゅう /購入/
こうにゅういよく /購入意欲/
こうにゅうか /購入可/
こうにゅうかかく /購入価格/
こうにゅうかのう /購入可能/
こうにゅうがく /購入額/
こうにゅうきぼう /購入希望/
こうにゅうきぼうかかく /購入希望価格/
こうにゅうきぼうきんがく /購入希望金額/
こうにゅうきんがく /購入金額/
こうにゅうけいかく /購入計画/
こうにゅうけいろ /購入経路/
こうにゅうけんとう /購入検討/
こうにゅうこうほ /購入候補/
こうにゅうご /購入後/
こうにゅうさき /購入先/
こうにゅうしきん /購入資金/
こうにゅうしゃ /購入者/
こうにゅうしゃしゅ /購入車種/
こうにゅうじ /購入時/
こうにゅうじかかく /購入時価格/
こうにゅうじき /購入時期/
こうにゅうじてん /購入時点/
こうにゅうすうりょう /購入数量/
こうにゅうずみ /購入済/
こうにゅうたいしょう /購入対象/
こうにゅうち /購入地/
こうにゅうちょくご /購入直後/
こうにゅうてん /購入店/
こうにゅうとうしょ /購入当初/
こうにゅうとうじ /購入当時/
こうにゅうどうき /購入動機/
こうにゅうねんげつ /購入年月/
こうにゅうはんだん /購入判断/
こうにゅうひ /購入費/
こうにゅうひょう /購入票/
こうにゅうひよう /購入費用/
こうにゅうひん /購入品/
こうにゅうび /購入日/
こうにゅうぶつ /購入物/
こうにゅうほう /購入法/
こうにゅうほうほう /購入方法/
こうにゅうまえ /購入前/
こうにゅうもうしこみ /購入申込み/
こうにゅうもくてき /購入目的/
こうにゅうもと /購入元/
こうにゅうよてい /購入予定/
こうにゅうよやく /購入予約/
こうにん /公認/後任/高人/弘仁;年号(810-824)/降任/
こうにん> /公認;(certified) -球,-会計士/
こうにんかいけいし /公認会計士/
こうにんかんとく /後任監督/
こうにんきょうぎ /公認競技/
こうにんきろく /公認記録/
こうにんこう /公認校/
こうにんこうほ /公認候補/
こうにんしかく /公認資格/
こうにんしゃ /後任者/
こうにんしゃりょう /公認車両/
こうにんしんぱんいん /公認審判員/
こうにんじんじ /後任人事/
こうにんたいかい /公認大会/
こうにんてんのう /光仁天皇/
こうねい /康寧/
こうねつ /高熱/光熱/
こうねつすいりょう /光熱水料/
こうねつひ /光熱費/
こうねん /後年/光年/行年/高年/降年/
こうねんき /更年期/
こうねんきしょうがい /更年期障害/
こうねんさき /光年先/
こうねんしょうど /高燃焼度/
こうねんぴ /高燃費/
こうねんぽう /高年俸/
こうねんれい /高年齢/
こうねんれいそう /高年齢層/
こうの /河野/甲野/幸野/香野/
こうのいけ /鴻池/
こうのう /効能/功能;≒効能/後納/貢納/後脳;hindbrain/
こうのうがき /効能書き/
こうのうど /高濃度/
こうのうりつ /高能率/
こうのす /鴻巣/
こうのすけ /幸之助/
こうのだい /国府台/
こうのとり /鸛/
こうのもの /香の物/
こうのもろなお /高師直/
こうは /硬派/光波/
こうはい /後輩/交配/荒廃/高配/後背/降灰/光背/好配/興廃/向背/向拝/
こうはいい /後背位/
こうはいかぶ /後配株/
こうはいきん /広背筋/
こうはいしっち /後背湿地;[地学]back marsh. 「千曲川の-」/
こうはいしゅ /交配種;[生物]hybrid/
こうはいたち /後輩達/
こうはいち /後背地/
こうはいとう /高配当/
こうはいぶ /後背部/
こうはく /紅白/黄白/工博/厚薄/広博/
こうはくうたがっせん /紅白歌合戦/
こうはくじあい /紅白試合/
こうはた /光畑/
こうはっしん /好発進/
こうはつ /後発/好発/
こうはつうしん /光波通信/
こうはつたい /後発隊/
こうはつひん /後発品/
こうはません /興浜線/
こうはまみなみせん /興浜南線/
こうはら /香原/
こうはん /後半/広範/公判/鋼板/広汎;=広範/紅斑/孔版/鋼鈑/甲板/攪拌/撹拌;異体字/江畔/
こうはんい /広範囲/
こうはんいん /甲板員/
こうはんいんさつ /孔版印刷/
こうはんかいし /後半開始/
こうはんかいしちょくご /後半開始直後/
こうはんき /後半期/
こうはんきじつ /公判期日/
こうはんご /公判後/
こうはんじゅんび /公判準備/
こうはんせい /後半生/
こうはんせん /後半戦/
こうはんちゅう /公判中/
こうはんちょうしょ /公判調書/
こうはんてい /公判廷/
こうはんねん /後半年/
こうはんぶ /後半部/
こうはんぶぶん /後半部分/
こうはんめん /後半面/
こうば /工場/
こうばい /購買/勾配/紅梅/公売/黄梅/公倍/
こうばいいよく /購買意欲/
こうばいいろ /紅梅色/
こうばいくかん /勾配区間/
こうばいけいしゃ /勾配傾斜/
こうばいしゃ /購買者/
こうばいしょう /紅梅賞/
こうばいすう /公倍数/
こうばいそう /購買層/
こうばいたんとう /購買担当/
こうばいぶ /購買部/
こうばいほう /勾配法/
こうばいほうほう /購買方法/
こうばいよく /購買欲/
こうばいりつ /高倍率/勾配率/
こうばいりょく /購買力/
こうばいりょくへいか /購買力平価/
こうばいりょくへいかせつ /購買力平価説/
こうばく /広漠/荒漠/宏漠/
こうばこ /香箱/
こうばし /香箸/
こうばたい /好馬体/
こうばな /香花/
こうばん /交番/降板/鋼板/項番/降番/工番/甲板/
こうばんげき /降番劇/
こうばんじょう /甲板上/
こうひ /公費/工費/校費/皇妃/口碑/公比/公妃/后妃/侯妃/高批/高庇/高飛/黄扉/向日;??/
こうひさくげん /工費削減/
こうひしゅっちょう /公費出張/
こうひじゅう /高比重/
こうひじょせい /公費助成/
こうひすたみんざい /抗ヒスタミン剤/
こうひつ /硬筆/
こうひょう /好評/公表/講評/高評/降雹/公評/
こうひょうか /高評価/
こうひょうき /後氷期/
こうひょうきんし /公表禁止/
こうひょうけん /公表権/
こうひょうげん /項表現/
こうひょうち /公表値/
こうひょうはつばいちゅう /好評発売中/
こうひょうほうほう /公表方法/
こうひょうまえ /公表前/
こうひん /公賓/
こうひんい /高品位/
こうひんしつ /高品質/
こうひんしつか /高品質化/
こうひんど /高頻度/
こうび /交尾/後尾/後備/
こうびき /交尾期;mating season/交尾器;genitals/
こうびしゃ /後尾車/
こうびょうげんせい /高病原性/
こうびん /後便/幸便/
こうふ /交付;「書類の-」/公布;「法令の-」/甲府/工夫;「工場の-」(NB:「くふう」と同形)/江府/鉱夫;「鉱山の-」/坑夫;「炭坑の-」/弘布/
こうふあんやく /抗不安薬/
こうふう /校風/
こうふうせいげつ /光風霽月/
こうふえき /甲府駅/
こうふか /高負荷/
こうふかん /甲府間/
こうふきん /交付金/
こうふく /幸福/降伏/口福;yum/降服;≒降伏 (原義:服を脱ぐ)/口腹;「-の欲」/
こうふくかん /幸福感/
こうふくし /高福祉/
こうふくしこうふたん /高福祉高負担/
こうふくしこっか /高福祉国家/
こうふくじ /興福寺/洪福寺/
こうふくついきゅう /幸福追求/
こうふくど /幸福度/
こうふくまく /後腹膜/
こうふし /甲府市/
こうふしんせいしょ /交付申請書/
こうふじょうきょう /交付状況/
こうふちょう /好不調/
こうふび /公布日/
こうふぼんち /甲府盆地/
こうふみなみ /甲府南/
こうふん /興奮/口吻/昂奮;≒興奮/公憤/紅粉/亢奮;≒興奮/亢憤;?/
こうふんざい /興奮剤/
こうふんじょうたい /興奮状態/
こうふんせい /興奮性/
こうふんど /興奮度/
こうぶ /後部/光武/公武/荒蕪/
こうぶがったい /公武合体/
こうぶざせき /後部座席/
こうぶしゃりょう /後部車両/
こうぶせき /後部席/
こうぶだいがっこう /工部大学校/
こうぶつ /好物/鉱物/貢物/
こうぶつかせき /鉱物化石/
こうぶつがく /鉱物学;mineralogy/
こうぶつがくしゃ /鉱物学者/
こうぶつけい /鉱物系/
こうぶつずかん /鉱物図鑑/
こうぶつせい /鉱物性/
こうぶつや /鉱物屋/
こうぶつゆ /鉱物油/
こうぶり /冠/
こうぶん /構文;syntax/公文/行文;ecriture.「-流麗」/告文;=こうもん/後文;thereinafter/
こうぶんかい /高分解/
こうぶんかいせき /構文解析/
こうぶんかいせきき /構文解析器/
こうぶんかいせきぎ /構文解析木/
こうぶんかいせきほう /構文解析法/
こうぶんかいのう /高分解能/
こうぶんき /構文木/
こうぶんきそく /構文規則/
こうぶんぎ /構文木/
こうぶんこう /構文項/
こうぶんし /高分子/
こうぶんしかがく /高分子化学/
こうぶんしき /構文式/
こうぶんしけんきゅうじょ /高分子研究所/
こうぶんしざいりょう /高分子材料/
こうぶんしぶっしつ /高分子物質/
こうぶんしまく /高分子膜/
こうぶんしゃ /光文社;[出版社名]www.kobunsha.com/
こうぶんしゃぶんこ /光文社文庫/
こうぶんしょ /公文書/
こうぶんしょかん /公文書館/
こうぶんじょう /構文上/
こうぶんじょうほう /構文情報/
こうぶんていぎ /構文定義/
こうぶんてき /構文的/
こうぶんてんのう /弘文天皇/
こうぶんとう /構文糖;[電算]syntax sugar/
こうぶんどう /弘文堂;[出版社名]www.koubundou.co.jp/
こうぶんぷ /項分布/
こうぶんぼ /公分母/
こうぶんようそ /構文要素/
こうぶんろん /構文論/
こうぶんろんてき /構文論的/
こうぷれー /好プレー/
こうへい /公平/工兵/浩平/康平;年号(1058-1065)/耕平/幸平/恒平/高平/衡平/
こうへいいいんかい /公平委員会/
こうへいせい /公平性/
こうへいたい /工兵隊/
こうへいちょう /高平調/
こうへいほう /衡平法/
こうへいむし /公平無私/
こうへいれつ /高並列/
こうへき /後壁/厚壁/
こうへきさいぼう /厚壁細胞/
こうへきそしき /厚壁組織/
こうへん /後編/後篇/口辺/
こうへんきゅう /好返球/
こうへんさいぼう /孔辺細胞/
こうべ /神戸/頭/首/
こうべえいぎょうしょ /神戸営業所/
こうべえき /神戸駅/
こうべきいと /神戸生絲/
こうべぎゅう /神戸牛/
こうべこうじょう /神戸工場/
こうべこうそく /神戸高速/
こうべこうそくてつどう /神戸高速鉄道/
こうべし /神戸市/
こうべしえい /神戸市営/
こうべしこうつうきょく /神戸市交通局/
こうべしてん /神戸支店/
こうべしでん /神戸市電/
こうべしない /神戸市内/
こうべしみん /神戸市民/
こうべしょうせんだいがく /神戸商船大学/
こうべしんこうつう /神戸新交通/
こうべしんぶん /神戸新聞/
こうべしんぶんはい /神戸新聞杯/
こうべじょがくいん /神戸女学院/
こうべじょしだい /神戸女子大/
こうべせいこう /神戸製鋼/
こうべせいこうしょ /神戸製鋼所;[企業名]/
こうべせん /神戸線/
こうべそうごう /神戸総合/
こうべだい /神戸大/
こうべだいがく /神戸大学/
こうべだいこう /神戸大工/
こうべちゅうおう /神戸中央/
こうべちょう /神戸町/
こうべつ /項別/皇別/
こうべてん /神戸店/
こうべでんてつ /神戸電鉄/
こうべぶんか /神戸文化/
こうべべん /神戸弁/
こうべほうめん /神戸方面/
こうべや /神戸屋/
こうべん /抗弁/口弁/
こうべんけん /抗弁権/
こうほ /候補/好捕/黄埔;Huangpu/
こうほあん /候補案/
こうほいちらん /候補一覧/
こうほう /広報;†PR/工法/後方/公報;†official bulletin.「選挙-」/高峰/構法;[建築]/航法/公法;public law/弘報;≒広報/後報/康保;年号(964-968)/廣報;「広」旧字/
こうほういっき /後方一気/
こうほういっち /後方一致/
こうほうえんご /後方援護/
こうほうか /広報課/
こうほうかいてん /後方回転/
こうほうかくにん /後方確認/
こうほうかつどう /広報活動/
こうほうがかり /広報係/
こうほうきんむ /後方勤務/
こうほうぎじゅつ /航法技術/
こうほうけん /航法研/
こうほうごかんせい /後方互換性/
こうほうし /広報誌;†(雑誌)/広報紙;†(新聞)/公報紙;?/
こうほうしえん /後方支援/
こうほうしかい /後方視界/
こうほうしつ /広報室/
こうほうしゃ /広報車/後方車/
こうほうしりょう /広報資料/
こうほうじん /公法人/
こうほうたんとう /広報担当/
こうほうたんとうしゃ /広報担当者/
こうほうついそう /後方追走/
こうほうてき /広報的/
こうほうはいき /後方排気/
こうほうばんごう /公報番号/
こうほうぶ /広報部/
こうほうぶいん /広報部員/
こうほうぶつ /広報物/
こうほうぶもん /広報部門/
こうほきょく /候補曲/
こうほく /港北/江北/
こうほくく /港北区/
こうほぐん /候補群/
こうほさく /候補作/
こうほしゃ /候補者/候補車/
こうほしゃいがい /候補者以外/
こうほしゃすう /候補者数/
こうほせい /候補生/
こうほせつ /候補節/
こうほせんたく /候補選択/
こうほち /候補地/
こうほとうろく /候補登録/
こうほね /河骨/川骨;=河骨/
こうほば /候補馬/
こうほび /候補日/
こうほん /稿本/校本/広本/
こうぼ /公募/酵母/
こうぼう /工房/攻防/興亡/弘法/公房/光芒/香房/高望/好防/鉤芒/
こうぼうき /興亡記/
こうぼうし /興亡史/
こうぼうせん /攻防戦/
こうぼうだいし /弘法大師/
こうぼきん /酵母菌/
こうぼく /高木/香木/公僕/坑木/
こうぼくしかい /槁木死灰/
こうぼさい /公募債/
こうぼじんいん /公募人員/
こうぼろんぶん /公募論文/
こうま /子馬/仔馬;=子馬/小馬/好摩/黄麻/
こうまい /高邁/
こうまく /硬膜/
こうまざ /小馬座;Equules(Eqe)/
こうまし /黄麻紙/
こうまつがく /考末学/
こうまん /高慢/
こうみ /香味/小海/
こうみせん /小海線/
こうみつ /高密/
こうみつど /高密度/
こうみゃく /鉱脈/
こうみょう /巧妙/光明/高名/功名/
こうみょうか /巧妙化/
こうみょうしん /功名心/
こうみょうしんごん /光明真言;[密教]/
こうみょうじ /光明寺/弘明寺/
こうみりょう /香味料/
こうみん /公民/皇民/
こうみんかん /公民館/
こうみんきょういく /公民教育/
こうみんけん /公民権/
こうみんけんうんどう /公民権運動/
こうみんけんていし /公民権停止/
こうむ /公務/工務;-店/校務/
こうむいん /公務員/
こうむいんしけん /公務員試験/
こうむいんしゅくしゃ /公務員宿舎/
こうむいんほう /公務員法/
こうむいんもんだい /公務員問題/
こうむしっこうぼうがい /公務執行妨害/
こうむしょ /公務所/
こうむてん /工務店/
こうむぶ /工務部/公務部/
こうむら /高村/甲村/
こうめ /小梅/
こうめい /高名/公明/孔明;諸葛亮の字(あざな)/光明/校名/孝明/高明/工明/
こうめいいけ /光明池/
こうめいかい /工明会/
こうめいせいだい /公明正大/
こうめいせんきょ /公明選挙/
こうめいてい /孝明帝/
こうめいてんのう /孝明天皇/
こうめいとう /公明党/
こうめん /後面/垢面/
こうもう /紅毛/孔孟/鴻毛/咬耗/膏盲/噛耗;?/
こうもうへきがん /紅毛碧眼/
こうもく /項目/綱目/
こうもくあん /項目案/
こうもくごと /項目毎/
こうもくすう /項目数/
こうもくち /項目値/
こうもくちゅう /項目中/
こうもくてん /広目天/
こうもくない /項目内/
こうもくないよう /項目内容/
こうもくひょう /項目票/
こうもくべつ /項目別/
こうもくべつさくいん /項目別索引/
こうもくめい /項目名/
こうもつ /貢物/
こうもと /河本/甲本/孝本/
こうもり /蝙蝠/幸森/
こうもりがさ /蝙蝠傘/
こうもん /肛門;anus/黄門;中納言。「水戸-」/校門;school gate/閘門;lock gate/後門;⇔前門/告文/孔門;孔子の門下/孔紋/粫門;?/
こうもんか /肛門科/
こうもんかつやくきん /肛門括約筋/
こうもんき /肛門期;[精医]anale Phase (Freudの用語)/
こうもんさま /黄門様/
こうや /荒野;荒れた野原/曠野;広い野原/広野;=曠野/高野/紺屋;-の白袴/郊野;郊外の野原/幸也;人名/功也/甲夜/狗也/
こうやうち /高野内/
こうやがみ /高野紙/
こうやぎ /香焼/
こうやぎれ /高野切;書跡/
こうやく /公約/口約/膏薬/
こうやくいはん /公約違反/
こうやくすう /公約数/
こうやぐち /高野口/
こうやさい /後夜祭/
こうやさん /高野山/
こうやせん /交野線/
こうやだい /高野台/
こうやちょう /公冶長;[論語]5/
こうやどうふ /高野豆腐/
こうやばん /高野版/
こうやひじり /高野聖/
こうやま /高山/光山/
こうやまき /高野槙/
こうやれん /高野連/
こうゆ /香油/鉱油/香湯/膏腴/膏油/
こうゆう /交友/交遊/公有/校友/孔融/
こうゆうかんけい /交友関係/
こうゆうざいさん /公有財産/
こうゆうしょう /交遊抄/
こうゆうすいめん /公有水面/
こうゆうせんど /高優先度/
こうよ /公誉/
こうよう /高揚/効用/公用/紅葉;楓の-/黄葉;銀杏の-/広葉;broadleaf/昂揚/綱要/後葉;子孫/孝養/光洋/甲陽;地名,兵庫/江陽;中国の地名/行洋/衡陽;(Hengyang) 中国の都市/宏陽/
こうよう> /公用;-車,-印/
こうようえん /甲陽園/
こうようえんえき /甲陽園駅/
こうようかん /高揚感/
こうようご /公用語/
こうようざいさん /公用財産/
こうようしゃ /公用車/
こうようじゅ /広葉樹/硬葉樹;[植物]sclerophyll. オリーブなど/
こうようじゅりん /硬葉樹林/
こうようせいこう /光洋精工/
こうようせん /甲陽線/
こうようちょうしゅう /公用徴収/
こうようにん /公用人/
こうようぶん /公用文/
こうようりょう /高容量/
こうよく /高翼/
こうら /甲羅/甲良/
こうらい /高麗/後来/光来/
こうらいこうくう /高麗航空/
こうらいご /高麗語/
こうらいしば /高麗芝/
こうらいぢゃわん /高麗茶碗;井戸茶碗など/
こうらいにんじん /高麗人参/
こうらく /行楽/後楽/好楽;芸名/攻落/
こうらくえん /後楽園/
こうらくえんきゅうじょう /後楽園球場/
こうらくえんたいかい /後楽園大会/
こうらくえんゆうえんち /後楽園遊園地/
こうらくきゃく /行楽客/
こうらくしゃ /行楽車/
こうらくち /行楽地/
こうらくびより /行楽日和/
こうらくれっしゃ /行楽列車/
こうらぼし /甲羅干し;ビーチで-/
こうらん /高覧/紅蘭/香蘭/高欄;[建築]/攪乱/勾欄;手すり/鉤欄;=勾欄/攪亂;旧字/撹亂;異体字+旧字/撹乱;「攪」異体字/
こうらんけい /広卵形/
こうらんじょがっこう /香蘭女学校/
こうり /小売/小売り/高利/公理/行李/功利/公吏/氷;※仮名遣い「こおり」/冰;※仮名遣い「こおり」/
こうりえん /香里園/
こうりか /公理化/
こうりかかく /小売価格/
こうりがし /高利貸/
こうりき /高力/
こうりぎょう /小売業/
こうりけい /公理系/
こうりしゅぎ /功利主義/
こうりしょう /小売商/
こうりたいけい /公理体系/
こうりっち /好立地/
こうりつ /効率/公立/高率/後立/工率/
こうりつ> /公立/
こうりつか /効率化/
こうりつがっこう /公立学校/
こうりつがっこうきょういん /公立学校教員/
こうりつこう /公立校/公立高/
こうりつこうこう /公立高校/
こうりつこうじょう /効率向上/
こうりつしょうがっこう /公立小学校/
こうりつじゅうし /効率重視/
こうりつじょう /効率上/
こうりつせい /効率性/
こうりつだいがく /公立大学/
こうりつちゅうがく /公立中学/
こうりつちゅうがっこう /公立中学校/
こうりつてき /効率的/
こうりつとしょかん /公立図書館/
こうりつほいくえん /公立保育園/
こうりつほいくしょ /公立保育所/
こうりつよし /効率良/
こうりてき /功利的;utilitarian/公理的;axiomatic/
こうりてきしゅうごうろん /公理的集合論/
こうりてきほうほう /公理的方法/
こうりてん /小売店/
こうりてんしゅ /小売店主/
こうりてんぽ /小売店舗/
こうりね /小売値/
こうりまわり /高利回り/
こうりゃく /攻略/後略/康暦;年号(1379-1381)/
こうりゃくじょうほう /攻略情報/
こうりゃくちゅう /攻略中/
こうりゃくほう /攻略法/
こうりゃくほうほう /攻略方法/
こうりゃくぼん /攻略本/
こうりやま /郡山/
こうりやまえき /郡山駅/
こうりゅう /交流/興隆/拘留;[法]拘置する刑罰/勾留;[法]被疑者・被告人の拘禁/後流;伴流/紅龍/蛟龍/蛟竜;=こうりょう/幸流/亢竜;=こうりょう/
こうりゅうか /交流課/交流化/
こうりゅうかい /交流会/
こうりゅうかいかん /交流会館/
こうりゅうかんけい /交流関係/
こうりゅうがた /交流型/
こうりゅうき /交流機/
こうりゅうきき /交流機器/
こうりゅうぎょ /降流魚/
こうりゅうくかん /交流区間/
こうりゅうし /交流誌/
こうりゅうしゅうかい /交流集会/
こうりゅうしんごう /交流信号/
こうりゅうじ /広隆寺/
こうりゅうじあい /交流試合/
こうりゅうじょう /勾留状/
こうりゅうせん /交流戦/
こうりゅうせんよう /交流専用/
こうりゅうちく /交流地区/
こうりゅうでんか /交流電化/
こうりゅうでんかくかん /交流電化区間/
こうりゅうでんげん /交流電源/
こうりゅうでんしゃ /交流電車/
こうりゅうはつでんき /交流発電機/
こうりゅうばん /交流版/
こうりゅうほうしき /交流方式/
こうりょ /考慮/行旅/
こうりょう /香料/光量/綱領/荒涼/校了/考量;比較-/衡量;利益-/稿料/広陵;地名/公領/高粱/荒寥/口糧/蛟竜;-雲雨を得/亢竜;-悔いあり/広量/宏量/講料/
こうりょうし /光量子/
こうりょうせいぎょ /光量制御/
こうりょうぶそく /光量不足/
こうりょがい /考慮外/
こうりょく /効力/抗力/
こうりょしぼうにん /行旅死亡人/
こうりょじかん /考慮時間/
こうりょちゅう /考慮中/
こうりりえき /小売利益/
こうりろんてき /公理論的/
こうりん /降臨;天下る/後輪/光臨;お見えになる/光琳;尾形光琳/光輪;halo/
こうりんぎょ /硬鱗魚/
こうりんくどう /後輪駆動/
こうりんくどうしゃ /後輪駆動車/
こうりんじく /後輪軸/
こうりんせつ /降臨節/
こうりんは /光琳派/
こうりんぼう /香林坊/
こうるい /紅涙/柑類/降涙/
こうれい /恒例/高齢/好例/降霊/交霊/
こうれいか /高齢化/
こうれいかしゃかい /高齢化社会/
こうれいぎょうじ /恒例行事/
こうれいさい /皇霊祭/
こうれいしゃ /高齢者/
こうれいしゃふくし /高齢者福祉/
こうれいしゅっさん /高齢出産/
こうれいじゅつ /交霊術;necromancy/
こうれいてんのう /孝霊天皇/
こうれつ /後列/項列/
こうれべる /高レベル/
こうれん /拘攣/鉤連/
こうろ /航路;†sailing route.「定期-」/香炉;†incense burner/高炉;†blast-furnace.「製鉄所の-」/行路;†path.「人生-」/公路;†public road/紅炉;あかく燃える囲炉裏/香露;(熊本の焼酎名?)/鈩;「鑪」の異体字/
こうろう /功労/高楼/高樓/絳蝋/
こうろうい /公労委/
こうろうしゃ /功労者/
こうろうしょう /厚労省/功労賞/厚労相;†厚生労働大臣/
こうろうたて /功労盾/
こうろうほう /公労法/
こうろうむ /紅楼夢/
こうろかん /鴻臚館/
こうろく /公録/高禄/
こうろけん /航路権/
こうろさ /行路差/
こうろぜん /黄櫨染/
こうろひょうしき /航路標識/
こうろもう /航路網/
こうろん /口論/公論/硬論/高論/抗論/
こうろんおつばく /甲論乙駁/
こうわ /講話;†lecture.「作家の-」/講和;†peace.「-条約」/弘和;年号(1381-84)/康和;年号(1099-1104)/興和/高話;おはなし/
こうわかいぎ /講和会議/
こうわじょうやく /講和条約/
こうわほう /口話法/
こうわん /港湾/
こうわんしせつ /港湾施設/
こうわんとし /港湾都市/
こうん /孤雲/
こえ /声/肥/越/聲;「声」の旧字/
こえい /孤影/
こえいもん /虎衛門/
こえおけ /肥桶/
こえがかり /声掛り/
こえがら /声柄/
こえがわり /声変わり/声変り/
こえき /固液/
こえしつ /声質/
こえじ /越路/
こえずか /肥塚;※仮名遣い「こえづか」/
こえたご /肥担桶/
こえだ /小枝/
こえだか /声高/
こえだめ /肥溜め/肥だめ/
こえつぼ /肥壺/
こえづか /肥塚/
こえなかじま /越中島/
こえん /古園;古い庭園/故園;ふるさと/小縁/故縁/
こえんゆう /小円遊/
こおう /呼応/
こおうこんらい /古往今来/
こおとこ /小男/
こおどり /小躍り/
こおに /小鬼/
こおもて /小面/
こおり /氷/郡/桑折;地名,福島県/冰;「氷」の異体字/
こおりがし /氷菓子/
こおりざとう /氷砂糖/
こおりだ /凍田/
こおりづけ /氷漬け/
こおりづめ /氷詰め/
こおりどうふ /凍り豆腐;高野豆腐/
こおりぶぎょう /郡奉行/
こおりまくら /氷枕/
こおりみず /氷水/
こおりみつ /氷蜜/
こおりや /氷屋/
こおりやま /郡山/
こおろぎ /蟋蟀/蛩/
こおんな /小女/
こか /固化/古歌/糊化/瓠果/
こかいいん /子会員/
こかいがわ /小貝川/
こかく /顧客/古格/呼格;[文法]vocative/孤客/
こかげ /木陰/木蔭/小陰/小蔭/
こかじ /小鍛冶/
こかた /子方/
こかつ /枯渇/涸渇;=枯渇/
こかつじぼん /古活字本/
こかぶ /子株/
こかべ /小壁;[建築]/
こかわ /粉河/胡川/
こかん /股間/
こかんきょう /古環境/
こかんせつ /股関節/
こかんぶぶん /股間部分/
こかんぼん /古刊本/
こが /古賀/古河/古雅/古画/個我/
こがい /戸外/小貝;([部首]=貝偏)/小粥;人名/子飼い/庫外/蚕飼い/小買い/個飼い/
こがいしゃ /子会社;subsidiary/小会社;[法]資本金1億円以下かつ負債総額200億円以下/
こがいしゃか /子会社化/
こがいな /小腕/
こがお /小顔/
こがき /小書/小書き/
こがく /古楽/古学/
こがくれ /木隠れ/
こがしら /小頭/
こがた /小型/小形;=小型/
こがたか /小型化/
こがたかん /小型艦/
こがたき /小型機/
こがたけいさんき /小型計算機/
こがたけいりょう /小型軽量/
こがたけいりょうか /小型軽量化/
こがたけん /小型犬/
こがたげんてい /小型限定/
こがたこうせいのう /小型高性能/
こがたしゃ /小型車/
こがたじどうにりん /小型自動二輪/
こがたじょうようしゃ /小型乗用車/
こがたせんぱく /小型船舶/
こがたな /小刀/
こがたにりん /小型二輪/
こがたにりんしゃ /小型二輪車/
こがたばす /小型バス/
こがたばん /小型版/
こがたひこうき /小型飛行機/
こがっき /古楽器/子楽器;?/
こがね /黄金/小金/
こがねい /小金井/
こがねいし /小金井市/
こがねいろ /黄金色/
こがねづくり /黄金作り/
こがねはら /小金原/
こがねまる /小金丸/
こがねむし /黄金虫/
こがねもち /小金持ち/
こがまさお /古賀政男/
こがめ /子亀/
こがら /小柄/小雀/
こがらし /木枯らし;♪- - 寒い道/木枯し/凩;=木枯らし/木枯/
こがれじに /焦れ死に/
こがわ /古川/
こがわせ /小為替/
こがん /湖岸/孤雁/個眼;(複眼の)ommatidium/
こき /子機/呼気/古希;70歳/古稀;=古希/古期;ancient/古記;ancient document/古器;ancient pottery/子器;[生物]apothecium.菌類の生殖器/
こきいろ /濃色/
こきお /古希男/
こきおん /呼気音;[音声学]expiratory sound ⇔吸気音/
こきざみ /小刻み/
こきでん /弘徽殿;弘徽殿の女御/
こきでんのにょうご /弘徽殿の女御;[源氏物語]/
こきのう /子機能/
こきみ /小気味/
こきむらさき /濃紫/
こきむらさきいろ /濃紫色/
こきゃく /顧客/
こきゃくかんりよう /顧客管理用/
こきゃくがわ /顧客側/
こきゃくじょうほう /顧客情報/
こきゃくまんぞくど /顧客満足度/
こきゃくめい /顧客名/
こきゅう /呼吸/胡弓/故宮/故旧/固給/
こきゅうおん /呼吸音/
こきゅうき /呼吸器/
こきゅうきか /呼吸器科/
こきゅうきかん /呼吸器官/
こきゅうきけい /呼吸器系/
こきゅうきけいしっかん /呼吸器系疾患/
こきゅうきのう /呼吸機能/
こきゅうきん /呼吸筋;[解剖] respiratory muscles/
こきゅうこん /呼吸根/
こきゅうこんなん /呼吸困難/
こきゅうしょう /呼吸商;[医]RQ/
こきゅうちゅうすう /呼吸中枢/
こきゅうていこう /呼吸抵抗/
こきゅうていし /呼吸停止/
こきゅうはくぶついん /故宮博物院;www.npm.gov.tw/
こきゅうはくぶつかん /故宮博物館;www.npm.gov.tw/
こきゅうほう /呼吸法/
こきょう /故郷/古経/
こきろく /古記録/
こきん /古今/古琴/胡琴;(hu qin) 中国楽器の「*胡」の総称/
こきんしゅう /古今集/
こきんちょう /胡錦鳥/
こきんでんじゅ /古今伝授/
こきんわかしゅう /古今和歌集/
こぎ /小木/古義/狐疑/
こぎがく /古義学/
こぎしゅんじゅん /狐疑逡巡/
こぎって /小切手/
こぎってちょう /小切手帳/
こぎつね /子狐/小狐;-こんこん山の中/
こぎつねざ /小狐座;Vulpecula(Vul)/
こぎて /漕ぎ手/
こぎみ /子君/故君/小君;=子君/
こぎょ /枯魚/
こぎれ /小切れ/
こぎれい /小綺麗/
こく /酷/告/刻/国/黒/石/古句/克;克服/剋;相剋/尅;「剋」の異体字/穀;穀物/轂;こしき/斛;石斛/槲;かしわ/鵠;正鵠/梏;桎梏/圀;「国」の異体字/國;「国」の旧字(人名用漢字)/谷;峡谷/哭;慟哭/釛;かね/棘;(唐音) とげ/詰;?/
こくあく /酷悪/
こくい /黒衣/国威/
こくいっこく /刻一刻/
こくいはつよう /国威発揚/
こくいん /刻印/黒印/
こくいんじょう /黒印状/
こくう /虚空/穀雨;[二十四節気]4.20頃/
こくうん /黒雲/国運/
こくえ /黒衣/
こくえい /国営/黒影/
こくえいか /国営化/
こくえいきぎょう /国営企業/
こくえいきぎょうろうどうかんけいほう /国営企業労働関係法/
こくえいてん /国営店/
こくえいほうそう /国営放送/
こくえいりょこうしゃ /国営旅行社/
こくえき /国益/
こくえん /黒煙/黒鉛/
こくおう /国王/
こくおうへいか /国王陛下/
こくおん /国恩/
こくかっしょく /黒褐色/
こくが /国衙/
こくがい /国外/
こくがいさん /国外産/
こくがいしゃ /国外車/
こくがいだっしゅつ /国外脱出/
こくがいとうぼう /国外逃亡/
こくがいはつ /国外発/
こくがいはん /国外犯/
こくがいひん /国外品/
こくがいりゅうがく /国外留学/
こくがく /国学/國學/
こくがくいん /國學院/国学院;※「國學院」が正式/
こくがくいんくがやま /国学院久我山;※「國學院」が正式/國學院久我山/
こくがくいんだい /国学院大;※「國學院大學」が正式名/國學院大/
こくがくいんだいがく /國學院大學/国学院大学;※「國學院大學」が正式名/
こくがくしゃ /国学者/
こくぎ /国技/国議/
こくぎかん /国技館/
こくぐう /酷遇/
こくぐら /穀倉/
こくぐん /国軍/国郡;クニとコオリ/
こくけん /国研/
こくけんばん /黒鍵盤/
こくげき /国劇/
こくげん /刻限/
こくこ /国庫/
こくこうしりつ /国公私立/
こくこうりつ /国公立/
こくこく /刻々/刻刻/
こくご /国語/
こくごう /国号/
こくごおん /国語音/
こくごか /国語科/
こくごがく /国語学/
こくごがくしゃ /国語学者/
こくごきょういく /国語教育/
こくごきょうし /国語教師/
こくごきょうしつ /国語教室/
こくごしんぎかい /国語審議会/
こくごじしょ /国語辞書/
こくごじてん /国語辞典/
こくごだいじてん /国語大辞典/
こくごてき /国語的/
こくごのうりょく /国語能力/
こくごりょく /国語力/
こくさい /国際/国債;government bond/国祭;national feast/國際;「国」旧字/
こくさい> /国際;-社会,-大学,-司法裁判所/
こくさいうちゅうだいがく /国際宇宙大学/
こくさいうちゅうねん /国際宇宙年/
こくさいえいぞう /国際映像/
こくさいおりんぴっくいいんかい /国際オリンピック委員会;IOC (International Olympic Committee)/
こくさいおんがくさい /国際音楽祭/
こくさいおんせいきごう /国際音声記号;IPA/
こくさいか /国際化/国際課/
こくさいかいかん /国際会舘;異体字/
こくさいかいぎ /国際会議/
こくさいかいぎかいさい /国際会議開催/
こくさいかいぎじょう /国際会議場/
こくさいかいぎろんぶん /国際会議論文/
こくさいかいけいきじゅん /国際会計基準/
こくさいかいじきかん /国際海事機関;IMO/
こくさいかいせん /国際回線/
こくさいかかく /国際価格/
こくさいかきのう /国際化機能/
こくさいかくしき /国際格式/
こくさいかたいおう /国際化対応/
こくさいかばん /国際化版/
こくさいかわせ /国際為替/
こくさいかんかく /国際感覚/
こくさいかんけい /国際関係/
こくさいかんけいろん /国際関係論/
こくさいかんしゅうほうじょう /国際慣習法上/
こくさいがくせい /国際学生/
こくさいがくせいしょう /国際学生証/
こくさいがっかい /国際学会/
こくさいきかく /国際規格/
こくさいきかくあん /国際規格案/
こくさいきかくか /国際規格化/
こくさいきかくげんあん /国際規格原案/
こくさいきかくさくせい /国際規格作成/
こくさいきかん /国際機関/
こくさいきこう /国際機構/
こくさいきのう /国際機能/
こくさいきやく /国際規約/
こくさいきゅう /国際級/
こくさいきゅうじょたい /国際救助隊/
こくさいきょうそう /国際競争/国際競走/
こくさいきょうちょう /国際協調/
こくさいきょうつうご /国際共通語/
こくさいきょうてい /国際協定/
こくさいきょうどうけんきゅう /国際共同研究/
こくさいきょうりょく /国際協力/
こくさいきょうりょくぎんこう /国際協力銀行;www.jbic.go.jp/
こくさいきょく /国際局/
こくさいきりすときょうだい /国際基督教大/
こくさいきりすときょうだいがく /国際基督教大学;ICU/
こくさいきろく /国際記録/
こくさいきんゆう /国際金融/
こくさいくうこう /国際空港/
こくさいぐんだん /国際軍団/
こくさいけいじさいばんしょ /国際刑事裁判所/
こくさいけいりん /国際競輪/
こくさいけっこん /国際結婚/
こくさいけっさい /国際決済/
こくさいけっさいぎんこう /国際決済銀行/
こくさいけん /国際研/
こくさいけんきゅうしょ /国際研究所/
こくさいげんしりょくきかん /国際原子力機関/
こくさいげんゆかかく /国際原油価格/
こくさいこうき /国際光器/
こくさいこうぎょう /国際航業/国際興行/
こくさいこうくう /国際航空/
こくさいこうくううんちん /国際航空運賃/
こくさいこうけん /国際貢献/
こくさいこうにん /国際公認/
こくさいこうほう /国際公法;国際法/
こくさいこうむいん /国際公務員;international servant. 国連等の職員/
こくさいこうりゅう /国際交流/
こくさいこうりゅうききん /国際交流基金;Japan Foundation. www.jpf.go.jp/
こくさいこうりゅうだんたい /国際交流団体/
こくさいこうろ /国際航路/
こくさいご /国際語/
こくさいさいばんしょ /国際裁判所/
こくさいざっし /国際雑誌/
こくさいしほう /国際私法/
こくさいしほうさいばん /国際司法裁判/
こくさいしほうさいばんしょ /国際司法裁判所/
こくさいしゃかい /国際社会/
こくさいしゅうし /国際収支/
こくさいしゅぎ /国際主義;internationalism/
こくさいしょうけん /国債証券/
こくさいしょうたい /国際招待/
こくさいしょく /国際色/
こくさいしんぜん /国際親善/
こくさいしんぱん /国際審判/
こくさいしんぱんいん /国際審判員/
こくさいじょうせい /国際情勢/
こくさいじょうやく /国際条約/
こくさいじょうやくしゅう /国際条約集/
こくさいじんけんきやく /国際人権規約/
こくさいじんどうほう /国際人道法/
こくさいせい /国際性/
こくさいせいぎ /国際正義/
こくさいせいじ /国際政治/
こくさいせいじがく /国際政治学/
こくさいせいじがくしゃ /国際政治学者/
こくさいせいじし /国際政治史/
こくさいせつぞく /国際接続/
こくさいせん /国際線/
こくさいせんげん /国際宣言/
こくさいせんこうくう /国際線航空/
こくさいせんよう /国際線用/
こくさいせんよやく /国際線予約/
こくさいそしき /国際組織/
こくさいたいかい /国際大会/
こくさいたんい /国際単位;international unit(IU)/
こくさいたんいけい /国際単位系;systeme international d'unites,SI/
こくさいだいがく /国際大学/
こくさいつう /国際通/
こくさいつうか /国際通貨/
こくさいつうかききん /国際通貨基金/
こくさいつうしん /国際通信/
こくさいてがた /国際手形/
こくさいてき /国際的/
こくさいてきちめいど /国際的知名度/
こくさいてきひなん /国際的非難/
こくさいてんじじょう /国際展示場/
こくさいでんき /国際電気/
こくさいでんきつうしんれんごう /国際電気通信連合;ITU/
こくさいでんしんでんわ /国際電信電話/
こくさいでんでん /国際電電/
こくさいでんわ /国際電話/
こくさいとし /国際都市/
こくさいとりひき /国際取引/
こくさいのうぎょうかいはつききん /国際農業開発基金;IFAD/
こくさいは /国際派/
こくさいはつおんきごう /国際発音記号/
こくさいばん /国際版/
こくさいひかく /国際比較/
こくさいひほうかん /国際秘宝館/
こくさいひょうき /国際表記/
こくさいひょうじゅん /国際標準/
こくさいひょうじゅんか /国際標準化/
こくさいひょうじゅんかきかん /国際標準化機関/
こくさいひょうじゅんかきこう /国際標準化機構;ISO(International Organisation for Standardisation)/
こくさいびん /国際便/
こくさいふっこうかいはつぎんこう /国際復興開発銀行;International Bank for Reconstruction and Development(IBRD)/
こくさいふんそう /国際紛争/
こくさいぶ /国際部/
こくさいぶんかかいかん /国際文化会館/
こくさいへいわ /国際平和/
こくさいへいわねん /国際平和年/
こくさいほう /国際法/
こくさいほういはん /国際法違反/
こくさいほうがくしゃ /国際法学者/
こくさいほうき /国際法規/
こくさいほうじょう /国際法上/
こくさいほうそう /国際放送/
こくさいほうてき /国際法的/
こくさいほげいいいんかい /国際捕鯨委員会/
こくさいぼうえき /国際貿易/
こくさいまさつ /国際摩擦/
こくさいみんかんこうくうきかん /国際民間航空機関;ICAO/
こくさいめん /国際面/
こくさいめんきょ /国際免許/
こくさいめんきょしょう /国際免許証/
こくさいもんだい /国際問題/
こくさいゆうびん /国際郵便/
こくさいゆうびんかわせ /国際郵便為替/
こくさいよろん /国際世論/
こくさいりかい /国際理解/
こくさいりょきゃく /国際旅客/
こくさいりょこうしゃ /国際旅行社/
こくさいれっしゃ /国際列車/
こくさいれんごう /国際連合/
こくさいれんごうけんしょう /国際連合憲章/
こくさいれんごうじどうききん /国際連合児童基金;UNICEF (United Nations Children's Fund)/
こくさいれんごうなんみんこうとうべんむかんじむしょ /国際連合難民高等弁務官事務所;UNHCR (Office of the United Nations High Commissioner for Refugees)/
こくさいれんめい /国際連盟/國際聯盟/
こくさいろうどうきかん /国際労働機関/
こくさく /国策/
こくさくじぎょう /国策事業/
こくさん /国産/
こくさんき /国産機/
こくさんぎゅう /国産牛;国内で「３ヶ月以上」育てられた牛/
こくさんけいじどうしゃ /国産軽自動車/
こくさんさいこうきゅう /国産最高級/
こくさんしゃ /国産車/
こくさんはつ /国産初/
こくさんばん /国産盤/
こくさんひん /国産品/
こくさんまい /国産米/
こくし /酷使/国司;[律令制]/国史;national history/国士;有為の人物.「-無双」/国試;[略語]国家試験/国師;僧侶の称号/国使;delegate/
こくしかん /国士舘/国子監/
こくしかんだいがく /国士舘大学/
こくしたいけい /国史大系;明治刊の史籍集成叢書/
こくしだい /国士大/
こくしつ /黒漆/
こくしびょう /黒死病/
こくしむそう /国士無双/
こくしゅ /国主/国守/国手;名医/
こくしゅう /刻舟/
こくしょ /酷暑/国書/国初/黒書/
こくしょう /国生/国章/國生/濃漿/国掌/
こくしょかんこうかい /国書刊行会/
こくしょく /黒色/穀食/
こくしょくかやく /黒色火薬;gun powder/
こくしょくしゅ /黒色腫/
こくしょくじんしゅ /黒色人種/
こくしょくとそう /黒色塗装/
こくしょび /酷暑日;日中の最高気温が35℃を超えた日/
こくじ /告示/酷似/刻字/国事;state affaire.「-犯」/国字;eg.「喰」「峠」「働」/告辞;告げる言葉/刻時;clock/国璽/
こくじこうい /国事行為/
こくじしょうしょ /国璽尚書/
こくじはん /国事犯/
こくじぼん /国字本/
こくじょう /国情/
こくじょうじごく /黒縄地獄/
こくじょく /国辱/
こくじん /黒人/国人/
こくじんおんがく /黒人音楽/
こくじんけい /黒人系/
こくじんじょせい /黒人女性/
こくじんたち /黒人達/
こくじんだんせい /黒人男性/
こくじんてき /黒人的/
こくじんどれい /黒人奴隷/
こくじんもんだい /黒人問題/
こくじんれいか /黒人霊歌;[音楽]black spiritual/
こくすい /国粋/
こくすいしゅぎ /国粋主義/
こくすいしゅぎしゃ /国粋主義者/
こくせい /国政/国勢/
こくせいせんきょ /国政選挙/
こくせいちょうさ /国勢調査/
こくせいちょうさけん /国政調査権/
こくせき /国籍/刻石/
こくせきしょゆうしゃ /国籍所有者/
こくせきじょうこう /国籍条項/
こくせきじんしゅ /国籍人種/
こくせきべつ /国籍別/
こくせきほう /国籍法/
こくせきりだつ /国籍離脱/
こくせつ /国設/
こくせん /国選/刻線/
こくせんべんごし /国選弁護士/
こくせんべんごにん /国選弁護人/
こくせんや /国姓爺/
こくぜ /国是/
こくぜい /国税/酷税/
こくぜいきょく /国税局/
こくぜいせんもんかん /国税専門官/
こくぜいちょう /国税庁/
こくぜいちょうしゅうほう /国税徴収法/
こくぜいつうそくほう /国税通則法/
こくそ /告訴/
こくそう /国葬/穀倉/国喪/
こくそうちたい /穀倉地帯/
こくそけん /告訴権/
こくそじょう /告訴状/
こくぞうむし /穀象虫;米櫃の害虫/
こくぞく /国賊/
こくた /穀田/
こくたい /国体/国対;[略語]国会対策(委員会)/黒体/國軆;「国体」旧字/
こくたいごじ /国体護持/國軆護持/
こくたいせいじ /国対政治/
こくたいだいひょうせんしゅ /国体代表選手/
こくたいふくしゃ /黒体輻射/
こくたいほうしゃ /黒体放射/
こくたいよせん /国体予選/
こくたに /古九谷/
こくたん /黒檀/黒炭/
こくだい /国大/
こくだか /石高/
こくだかせい /石高制/
こくち /告知/国恥;-記念日(5.9)/
こくちきじ /告知記事/
こくちぎむ /告知義務/
こくちょう /国鳥;NB:日本のは「キジ」/黒鳥/
こくつぶ /穀粒/
こくてい /国定/
こくていきょうかしょ /国定教科書/
こくていこうえん /国定公園/
こくてつ /国鉄/
こくてつえき /国鉄駅/
こくてつがた /国鉄型/
こくてつし /国鉄史/
こくてつしゃりょう /国鉄車両/
こくてつしょく /国鉄色/
こくてつじだい /国鉄時代/
こくてつせん /国鉄線/
こくてつぜんせん /国鉄全線/
こくてつでんしゃ /国鉄電車/
こくてん /黒点/国典/
こくてんぐん /黒点群/
こくてんし /告天子/
こくでん /国電/
こくでんくかん /国電区間/
こくと /国都/
こくとう /黒糖/
こくとうげんまい /黒糖玄米/
こくど /国土/黒土/黒奴/
こくどう /国道/
こくどういちごうせん /国道一号線/
こくどうせん /国道線/
こくどうぞい /国道沿/
こくどうにごうせん /国道二号線/
こくどけいかく /国土計画/
こくどこうつう /国土交通/
こくどこうつうしょう /国土交通省;建設省、運輸省、国土庁が2001年1月の中央省庁再編で再編されたもの/
こくどこうつうだいじん /国土交通大臣/
こくどしゃ /国土舎/
こくどちょう /国土庁;NB:2001年1月の中央省庁再編で国土交通省に再編された/
こくどちりいん /国土地理院/
こくどりようけいかくほう /国土利用計画法/
こくない /国内/
こくないかかく /国内価格/
こくないがい /国内外/
こくないきかく /国内規格/
こくないくうこう /国内空港/
こくないさいてい /国内最低/
こくないさん /国内産/
こくないしじょう /国内市場/
こくないしゅっぱん /国内出版/
こくないしょう /黒内障/
こくないしょうひん /国内商品/
こくないしよう /国内仕様/
こくないじじょう /国内事情/
こくないせい /国内製/
こくないせいひん /国内製品/
こくないせん /国内線/
こくないせんうんちん /国内線運賃/
こくないせんよう /国内専用/国内線用/
こくないぜんいき /国内全域/
こくないぜんたい /国内全体/
こくないそうせいさん /国内総生産;GDP (gross domestic product)/
こくないだいりてん /国内代理店/
こくないちょうたつ /国内調達/
こくないつあー /国内ツアー/
こくないつうしん /国内通信/
こくないていか /国内定価/
こくないてき /国内的/
こくないでんわりょうきん /国内電話料金/
こくないとうし /国内投資/
こくないはつばい /国内発売/
こくないはん /国内犯/
こくないはんばい /国内販売/
こくないばん /国内盤/国内版/
こくないひん /国内品/
こくないびん /国内便/
こくないぶん /国内分/
こくないへん /国内編/
こくないほう /国内法/
こくないほうき /国内法規/
こくないほしょう /国内保証/
こくないみはつばい /国内未発売/
こくないむけ /国内向/
こくないめんきょしょう /国内免許証/
こくないもんだい /国内問題/
こくないよう /国内用/
こくないりゅうがく /国内留学/
こくないりょこう /国内旅行/
こくないれっしゃ /国内列車/
こくなん /国難/
こくにん /国人/
こくね /古久根/
こくねつ /酷熱/
こくはく /告白/酷薄/刻薄/穀帛/
こくはつ /告発/黒髪;くろかみ/
こくはつしゃ /告発者/
こくはつじょう /告発状/
こくはん /刻版/刻板/
こくはんびょう /黒斑病;[植物]/
こくばん /黒板/
こくばんけし /黒板消し/
こくひ /国費/
こくひょう /酷評/黒表;blacklist/
こくひりゅうがくせい /国費留学生/
こくひん /国賓/
こくび /小首/
こくびゃく /黒白/
こくふ /国富/国府/国父/
こくふう /国風/
こくふうはくう /黒風白雨;嵐/
こくふうぶんか /国風文化/
こくふく /克服/克復;†困難を乗り越え、原状に復する/
こくふだ /国府田/
こくふろん /国富論/
こくふん /穀粉/
こくぶ /国分/国府/
こくぶん /国文/告文/国分;地名/
こくぶんか /国文科/
こくぶんがく /国文学/
こくぶんじ /国分寺/
こくぶんじえき /国分寺駅/
こくぶんじかいどう /国分寺街道/
こくぶんじかん /国分寺間/
こくぶんじし /国分寺市/
こくぶんちょう /国分町/
こくぶんにじ /国分尼寺/
こくぶんぽう /国文法/
こくへいしゃ /国幣社/
こくへん /黒変/
こくべつ /告別/
こくべつしき /告別式/
こくほ /国保/国歩/
こくほう /国宝/国法/國寶/
こくほうきゅう /国宝級/
こくほん /刻本/
こくぼ /小久保/国母/
こくぼう /国防/
こくぼうぐん /国防軍/
こくぼうしょう /国防省/国防相;†大臣/
こくぼうしょく /国防色/
こくぼうじょう /国防上/
こくぼうそうしょう /国防総省/
こくぼうだいじん /国防大臣/
こくぼうちょうかん /国防長官/
こくぼうほう /国防法/
こくまい /黒米/
こくみん /国民/
こくみんかいぎ /国民会議/
こくみんかいへい /国民皆兵/
こくみんかいほけん /国民皆保険/
こくみんかくめい /国民革命/
こくみんかんじょう /国民感情/
こくみんがくは /国民楽派/
こくみんがっこう /国民学校/
こくみんき /国民機/
こくみんきゅうかむら /国民休暇村/
こくみんきょういく /国民教育/
こくみんきょうぎかい /国民協議会/
こくみんきんゆうこうこ /国民金融公庫/
こくみんぎかい /国民議会/
こくみんぐん /国民軍/
こくみんけいざい /国民経済/
こくみんけんこうほけん /国民健康保険/
こくみんけんこうほけんほう /国民健康保険法/
こくみんこっか /国民国家/
こくみんしゃこうそう /国民車構想/
こくみんしゅぎ /国民主義;nationalism/
こくみんしゅくしゃ /国民宿舎/
こくみんしゅけん /国民主権/
こくみんしょとく /国民所得/
こくみんしんさ /国民審査/
こくみんしんぶん /国民新聞/
こくみんせい /国民性/
こくみんせいかつ /国民生活/
こくみんせいかつはくしょ /国民生活白書/
こくみんせいとう /国民政党/
こくみんせいふ /国民政府/
こくみんぜんたい /国民全体/
こくみんそうししゅつ /国民総支出;[経済]gross national expenditure(GNE)/
こくみんそうせいさん /国民総生産/
こくみんそうせばんごうせい /国民総背番号制/
こくみんちょうようれい /国民徴用令/
こくみんてき /国民的/
こくみんてきえいゆう /国民的英雄/
こくみんてきばんぐみ /国民的番組/
こくみんてきびしょうじょ /国民的美少女/
こくみんとう /国民党/
こくみんとうごう /国民統合/
こくみんとうひょう /国民投票/
こくみんどうし /国民同士/
こくみんねんきん /国民年金/
こくみんねんきんほう /国民年金法/
こくみんひとりひとり /国民一人一人/
こくみんふくしぜい /国民福祉税/
こくみんふざい /国民不在/
こくみんふたん /国民負担/
こくみんふたんりつ /国民負担率/
こくみんほごほう /国民保護法;[法][略語]武力攻撃事態等における国民の保護のための措置に関する法律/
こくむ /国務/
こくむいん /国務院/
こくむしょう /国務省/国務相;†大臣/
こくむじかん /国務次官/
こくむだいじん /国務大臣/
こくむちょうかん /国務長官/
こくめい /国名/克明/刻銘/
こくも /国母/
こくもつ /穀物/
こくもつす /穀物酢/
こくもつるい /穀物類/
こくもり /石盛/
こくやく /国訳/国躍/
こくゆ /告諭/
こくゆう /国有/
こくゆうか /国有化/
こくゆうきぎょう /国有企業/
こくゆうご /国有後/
こくゆうざいさん /国有財産/
こくゆうざいさんほう /国有財産法/
こくゆうち /国有地/
こくゆうりん /国有林/
こくようせき /黒曜石/
こくら /小倉/
こくらえき /小倉駅/
こくらえきまえ /小倉駅前/
こくらかん /小倉間/
こくらがわ /小倉側/
こくらきた /小倉北/
こくらけいば /小倉競馬/
こくらけいばじょう /小倉競馬場/
こくらこうこう /小倉高校/
こくらこうじょう /小倉工場/
こくらじょう /小倉城/
こくらせん /小倉線/
こくらみなみ /小倉南/
こくり /国利/
こくりつ /国立/
こくりつえんげいじょう /国立演芸場/
こくりつかげきじょう /国立歌劇場/
こくりつがっこうせっちほう /国立学校設置法/
こくりつきょうぎじょう /国立競技場/
こくりつぎんこう /国立銀行;national bank/
こくりつけん /国立研/
こくりつけんきゅうきかん /国立研究機関/
こくりつげきじょう /国立劇場/
こくりつこうえん /国立公園/
こくりつこうえんない /国立公園内/
こくりつこっかいとしょかん /国立国会図書館/
こくりつしょうにびょういん /国立小児病院/
こくりつじゅんかんきびょう /国立循環器病/
こくりつだい /国立大/
こくりつだいがく /国立大学/
こくりつだいがくせい /国立大学生/
こくりつだいがくほうじん /国立大学法人/
こくりつだいせい /国立大生/
こくりつてんもんだい /国立天文台/
こくりつのうがくどう /国立能楽堂/
こくりつびじゅつかん /国立美術館/
こくりつびょういん /国立病院/
こくりみんぷく /国利民福/
こくりゅう /黒龍/黒竜/穀粒/
こくりゅうこう /黒竜江;中国北部/
こくりょう /国領/
こくりょく /国力/
こくるい /穀類/
こくれい /穀霊;[民俗学]corn spirit/
こくれつ /酷烈/
こくれん /国連/國聯/
こくれんあんぜんほしょうりじかい /国連安全保障理事会;UNSC/
こくれんあんぽり /国連安保理/
こくれんかいはつけいかく /国連開発計画;www.undp.org/
こくれんかめいこく /国連加盟国/
こくれんかんきょうけいかく /国連環境計画;www.unep.org/
こくれんかんけい /国連関係/
こくれんき /国連旗/
こくれんきかん /国連機関/
こくれんきょういくかがくぶんかきかん /国連教育科学文化機関;www.unesco.org/
こくれんぐん /国連軍/
こくれんけつぎ /国連決議/
こくれんけんしょう /国連憲章/
こくれんしょくいん /国連職員/
こくれんしょくりょうのうぎょうきかん /国連食糧農業機関;www.fao.org/
こくれんじどうききん /国連児童基金;www.unicef.org/
こくれんじむきょく /国連事務局/
こくれんじむそうちょう /国連事務総長/
こくれんじんこうききん /国連人口基金;www.unfpa.org/
こくれんそうかい /国連総会/
こくれんたいし /国連大使/
こくれんだいがく /国連大学;www.unu.edu/
こくれんへいわいじかつどう /国連平和維持活動;PKO/
こくれんへいわいじぐん /国連平和維持軍;PKF/
こくれんほんぶ /国連本部/
こくろう /国労/
こくろん /国論/
こくん /古訓/
こぐし /小串/
こぐすり /粉薬/
こぐち /小口/木口/
こぐちあつかい /小口扱い/
こぐちがき /小口書/
こぐちぎり /小口切り/
こぐちぼり /木口彫/
こぐちもくはん /木口木版/
こぐま /小熊/子熊/黒熊;(中国の武具の飾り)/
こぐまざ /小熊座;Ursa Minor(UMi)/
こぐれ /小暮/
こぐん /孤軍/
こぐんふんとう /孤軍奮闘/
こけ /苔/虚仮;人を―にする/
こけい /固形/古形/孤閨/固型;?/
こけいか /固形化/
こけいさんしょう /虎渓三笑/
こけいしょく /固形食/
こけいすーぷ /固形スープ/
こけいねんりょう /固形燃料/
こけいひりょう /固形肥料/
こけいぶつ /固形物/
こけいろ /苔色/
こけおどし /虚仮威し/
こけしのぶ /苔忍/
こけしょくぶつ /苔植物/
こけつ /固結/虎穴/
こけでら /苔寺/
こけにわ /苔庭/
こけむしるい /苔虫類/
こけもも /苔桃/
こけら /柿/
こけらおとし /柿落し/
こけらぶき /柿葺き/
こけん /沽券;-に関わる/孤剣/古賢/估券;=沽券/狐拳/
こげ /焦げ/
こげき /罅隙/
こげちゃ /焦げ茶/焦茶/
こげちゃいろ /焦げ茶色/
こげつ /湖月/鼓月/孤月/木月/
こげつき /焦げ付き/
こげめ /焦げ目/
こげめし /焦げ飯/
こげら /小啄木/
こげん /古言/古諺/
こげんた /子源太/
こげんてい /古言梯;楫取魚彦,1764/
ここ /個々/此処/個個/爰/呱々;赤子の泣き声/茲;≒此/
ここああじ /ココア味/
ここあいろ /ココア色;cocoa/
ここう /孤高/戸口;戸数と人口/虎口;-を脱する/糊口;-を凌ぐ/股肱/餬口;=糊口/
ここかしこ /此処彼処/
ここく /故国/
ここじん /個々人/個個人/
ここち /心地/
ここちよし /心地好/
ここに /個々に/此処に/是に/茲に/爰に/
ここぬか /九日;[古語]/
ここの /九/
ここのえ /九重/
ここのか /九日/９日/9日/
ここのそじ /九十路/九十/
ここのつ /九つ/
ここまい /古々米/
ここらへん /ここら辺/
こころ /心/
こころあたり /心当たり/心当り/
こころあて /心当て/
こころいき /心意気/
こころいっぱい /心一杯/
こころいれ /心入れ/
こころいわい /心祝い/
こころえ /心得/
こころえがお /心得顔/
こころえちがい /心得違い/
こころおき /心置き/
こころおきなく /心置き無く/心置きなく/
こころおくれ /心後れ/
こころおち /心落ち/
こころおぼえ /心覚え/
こころから /心から/
こころがけ /心掛け/
こころがまえ /心構え/
こころがら /心柄/
こころがわり /心変わり;変節/心変り/
こころくばり /心配り/
こころぐみ /心組み/
こころざし /志/
こころざま /心様/
こころしずか /心静か/
こころじょうぶ /心丈夫/
こころぞえ /心添え/
こころだのみ /心頼み/
こころだま /心魂/
こころだましい /心魂/
こころづかい /心遣い/
こころづくし /心尽くし/心尽し/
こころづけ /心付け/
こころづもり /心積もり/心積り/
こころづよ /心強/
こころな /心無/
こころなし /心無し;無理解/心做し;気のせい/心なし/心成し/心無/
こころね /心根/
こころのうち /心の内/
こころのこり /心残り/
こころのそこ /心の底;-から笑う/
こころのやみ /心の闇/
こころばえ /心延え/
こころばせ /心馳せ/
こころぶと /心太/
こころまかせ /心任せ/
こころまち /心待ち/
こころみ /試み/試/
こころもち /心持ち/心持/心もち/
こころもと /心許;-ない/心元;胸元/
こころやすだて /心安立て/
こころやり /心遣り/
こころゆ /心ゆ/
ここん /古今/
ここんちょもんじゅう /古今著聞集;1254/
ここんてい /古今亭/
ここんとうざい /古今東西/
ここんどっぽ /古今独歩/
ここんむそう /古今無双/
こご /古語/
こごう /古豪/呼号/小督;平家物語/
こごえ /小声/
こごし /小腰/
こごしょう /子児姓/
こごじてん /古語辞典/
こごた /小牛田/
こごたちょう /小牛田町/
こごと /小言/
こごめ /粉米/
こごもり /子籠り/
こごもりざけ /子籠り鮭/
こごり /凝り/
こさい /湖西/小才/
こさか /小坂/
こさかい /小堺/
こさかこうざん /小坂鉱山/
こさかた /小坂田/
こさかだ /小坂田/
こさく /小作/古作/
こさくち /小作地/
こさくにん /小作人/
こさくのう /小作農/
こさくりょう /小作料/
こささ /小笹/
こさざ /小佐々/
こさじ /小匙/小さじ/
こさつ /古刹/故殺/
こさはら /古佐原/
こさめ /小雨/
こさん /古参/
こさんじ /小三治/
こさんば /小三馬/
こざ /古座/胡坐/
こざい /古材/
こざいく /小細工/
こざかい /小坂井/
こざかいなだ /小境灘/
こざかな /小魚/小肴/
こざがわ /古座川/
こざき /小崎/駒崎;こまざき?/
こざくら /小桜/
こざけ /醴/
こざさ /小笹/
こざさはら /小笹原/
こざしき /小座敷/跨座式/
こざね /小札/
こざら /小皿/
こざる /小猿/子猿/
こざわ /涸沢/
こざん /故山;故郷の山/孤山/
こし /腰/古紙/輿;玉の-/枯死/古志/虎視;-眈々/古史/古詩/虎子/越/
こしあて /腰当/
こしあん /漉し餡/漉餡/
こしいた /腰板/
こしいれ /輿入れ/
こしお /小潮/
こしおび /腰帯/
こしおれ /腰折れ/
こしかいしゅう /古紙回収/
こしかけ /腰掛け/腰掛/
こしかけしごと /腰掛仕事/
こしかた /来し方/
こしかたゆくすえ /来し方行く末;D'ou venons-nous? Que sommes-nous? Ou allons-nous?/
こしかべ /腰壁/
こしかわ /越川/
こしが /越賀/
こしがみ /漉紙/
こしがや /越谷/
こしき /古式/甑/轂/漉し器/濾し器/
こしきぶのないし /小式部内侍;大江山 いく野の道の 遠ければ まだふみも見ず 天の橋立/
こしきり /越桐/
こしぎんちゃく /腰巾着/
こしくだけ /腰砕け/
こしぐるま /腰車/
こしぐるわ /腰曲輪/
こしこでん /古史古伝/
こしごえ /腰越/
こしじ /越路/
こしじそう /越路荘/
こしたやみ /木下闇/
こしたんたん /虎視眈々/虎視眈眈/
こしだ /越田/
こしだか /腰高/
こしつ /個室/固執/鼓室/痼疾/
こしつき /腰付き/
こしつしんだい /個室寝台/
こしつふう /個室風/
こしづか /越塚/
こしなか /越中/
こしなげ /腰投げ/
こしなげし /腰長押;[建築]/
こしなわ /腰縄/
こしぬけ /腰抜け/
こしぬの /腰布/
こしの /越廼/
こしのかんばい /越乃寒梅/
こしのぎ /小鎬/
こしのくに /越の国;地名/
こしのもの /腰の物;刀/
こしば /小柴/古柴/
こしばい /小芝居/
こしひも /腰紐/
こしぼそ /腰細/
こしぼね /腰骨/
こしまき /腰巻/
こしまど /腰窓;腰の高さからの窓/
こしまわり /腰回り/
こしみず /小清水/輿水/
こしみの /腰蓑/
こしみはる /越美晴/
こしむら /越村/
こしもと /腰元/越元/
こしゃきょう /古写経/
こしゃく /小癪/
こしゃほん /古写本/
こしやね /越屋根;[建築] 屋根の上の屋根/
こしやまそう /越山荘/
こしゅ /古酒/固守/戸主/鼓手/
こしゅう /固執/呼集/孤愁/孤舟/個集/故習/
こしゅく /固縮/
こしゅけん /戸主権/
こしゅつ /庫出/
こしゆ /腰湯/
こしょ /古書/
こしょいち /古書市/
こしょう /故障/呼称/湖沼/胡椒/小姓/古称/小性/扈従/孤松/誇称/楜/壺觴/壷漿/壺漿/
こしょうか /コショウ科/Piperaceae/
こしょうかしょ /故障箇所/
こしょうがく /湖沼学/
こしょうがつ /小正月/
こしょうぎ /小将棋/
こしょうげんいん /故障原因/
こしょうしゃ /故障者/故障車/
こしょうしゃぞくしゅつ /故障者続出/
こしょうしんだん /故障診断/
こしょうじ /故障時/
こしょうせい /故障性/
こしょうちゅう /故障中/
こしょうにん /小商人/
こしょうはっせい /故障発生/
こしょうはっせいじ /故障発生時/
こしょうひんど /故障頻度/
こしょうぶひん /故障部品/
こしょうへんこう /呼称変更/
こしょうまえ /故障前/
こしょうもく /コショウ目/Piperales/
こしょうりつ /故障率/
こしょうれき /故障歴/
こしょがい /古書街/
こしょく /古色/個食/孤食/
こしょくそうぜん /古色蒼然/
こしょし /古書肆/
こしょてん /古書店/古書展/
こしょてんがい /古書店街/
こしょり /呼処理/
こしよわ /腰弱/
こしらえ /拵え/
こしらえごと /拵え事/
こしろ /古代/小代/
こしわざ /腰技/
こしん /湖心/孤身/
こしんとう /古神道/
こじ /故事/孤児/誇示/古寺/固辞/居士/固持/古字/虎子/虎児/
こじいん /孤児院/
こじか /小鹿/子鹿/
こじかものがたり /子鹿物語/
こじき /古事記/乞食/
こじきこんじょう /乞食根性/
こじきでん /古事記伝/
こじしざ /小獅子座;Leo Minor(LMi)/
こじせいご /故事成語/
こじだい /子時代/
こじつ /故実/
こじつそうしょ /故実叢書/
こじてきしょうひ /誇示的消費/
こじま /小島/児島/古島/小嶋/戸島/
こじまかん /児島間/
こじまわん /児島湾/
こじゅ /古樹/
こじゅう /扈従/
こじゅうと /小姑/小舅/
こじゅうとめ /小姑/
こじょう /古城/湖上/弧状;⌒/孤城/小尉;能面の一種/
こじょうらくじつ /孤城落日/
こじょうるり /古浄瑠璃/
こじょうれっとう /弧状列島/
こじょうれんけつ /弧状連結/
こじらいれき /故事来歴/
こじり /鐺/小尻/
こじれ /拗れ/
こじろう /小次郎/
こじわ /小じわ/小皺;-が気になる/小ジワ/
こじん /個人/故人/古人/
こじんあて /個人宛/
こじんい /個人医/
こじんいけん /個人意見/
こじんえいぎょう /個人営業/
こじんえんぎ /個人演技/
こじんおいぬき /個人追抜/
こじんかいいん /個人会員/
こじんかん /個人間/
こじんかんきょう /個人環境/
こじんがくしゅう /個人学習/
こじんきゃく /個人客/
こじんきょうぎ /個人競技/
こじんきろく /個人記録/
こじんぎ /個人技/
こじんくうかん /個人空間/
こじんけいえい /個人経営/
こじんけんきん /個人献金/
こじんこうげき /個人攻撃/
こじんこうしょう /個人交渉/
こじんこうどう /個人行動/
こじんこじん /個人個人/個人々々/
こじんご /個人語;[言語]idiolect/
こじんごと /個人毎/
こじんさ /個人差/
こじんさいと /個人サイト/
こじんさま /個人様/
こじんさんか /個人参加/
こじんし /個人誌/
こじんしきべつ /個人識別/
こじんしどう /個人指導/
こじんしゅぎ /個人主義/
こじんしゅぎてき /個人主義的/
こじんしゅみ /個人趣味/
こじんしょう /個人賞/
こじんしょうごう /個人照合/
こじんしょうひ /個人消費/
こじんしょとく /個人所得/
こじんしょゆう /個人所有/
こじんしょゆうしゃ /個人所有者/
こじんしょゆうぶつ /個人所有物/
こじんしよう /個人使用/
こじんじぎょうぬし /個人事業主/
こじんじしょ /個人辞書/
こじんじしん /個人自身/
こじんじゅうみんぜい /個人住民税/
こじんじょうほう /個人情報/
こじんじょうほうほごほう /個人情報保護法;個人情報の保護に関する法律/
こじんせい /個人性/
こじんせいかつ /個人生活/
こじんせいせき /個人成績/
こじんせきにん /個人責任/
こじんせってい /個人設定/
こじんせつ /古人説/
こじんせん /個人戦/
こじんせんしゅけん /個人選手権/
こじんせんりょうけい /個人線量計/
こじんぜんしゅう /個人全集/
こじんぜんたい /個人全体/
こじんそうび /個人装備/
こじんたく /個人宅/
こじんたんい /個人単位/
こじんてき /個人的/
こじんてきいけん /個人的意見/
こじんてきかんじょう /個人的感情/
こじんてきかんそう /個人的感想/
こじんてききぼう /個人的希望/
こじんてきけんかい /個人的見解/
こじんてきしゅかん /個人的主観/
こじんてきしゅみ /個人的趣味/
こじんてきしんじょう /個人的信条/
こじんてきしんねん /個人的信念/
こじんてきじじょう /個人的事情/
こじんてきすいそく /個人的推測/
こじんてきたいけん /個人的体験/
こじんてきたちば /個人的立場/
こじんてきつごう /個人的都合/
こじんてきないよう /個人的内容/
こじんてきはんだん /個人的判断/
こじんてきようぼう /個人的要望/
こじんてきよっきゅう /個人的欲求/
こじんてきりよう /個人的利用/
こじんでんき /個人伝記/
こじんとうしか /個人投資家/
こじんどうし /個人同士/
こじんどうてい /個人同定/
こじんない /個人内/
こじんにんしょう /個人認証/
こじんねんきん /個人年金/
こじんねんぴょう /個人年表/
こじんはっこう /個人発行/
こじんはつめいか /個人発明家/
こじんばいばい /個人売買/
こじんばいばいらん /個人売買欄/
こじんびょういん /個人病院/
こじんべつ /個人別/
こじんむけこくさい /個人向け国債/
こじんめい /個人名/
こじんめいぎ /個人名義/
こじんもんだい /個人問題/
こじんゆにゅう /個人輸入/
こじんよう /個人用/
こじんより /個人寄/
こじんりょこう /個人旅行/
こじんりょこうしゃ /個人旅行者/
こじんれんしゅう /個人練習/
こじんわざ /個人技/
こすい /湖水/鼓吹/
こすいちほう /湖水地方/
こすう /個数/戸数/
こすうばい /個数倍/
こすうぶん /個数分/
こすぎ /小杉/
こすぎえき /小杉駅/
こすけがわ /小助川/
こすげ /小菅/
こすだ /小須田/
こすとげん /コスト減/
こすとさくげん /コスト削減/
こすとぞう /コスト増/
こすとだか /コスト高/
こすとめん /コスト面/
こすど /小須戸/
こすみ /小角/
こすもしょうけん /コスモ証券;[企業名]www.cosmo-sec.co.jp/
こすもす /秋桜/
こすもせきゆ /コスモ石油;[企業名]/
こすり /錯/
こずえ /梢/杪/
こせ /巨勢/小瀬/
こせい /個性/古生/古制/糊精;dextrin/
こせいか /個性化/
こせいかひるい /Archichlamydeae/
こせいせん /湖西線/
こせいだい /古生代;[地質年代]Palaeozoic. 5.4-2.5億年前/
こせいてき /個性的/
こせいぶつ /古生物/
こせいぶつがく /古生物学;paleontology/
こせいぶつがくしゃ /古生物学者/
こせがれ /小倅/小悴/
こせき /戸籍/古跡/古昔/小関/古関/古蹟/
こせきか /戸籍課/
こせきかんり /戸籍管理/
こせきしょうほん /戸籍抄本/
こせきじょう /戸籍上/
こせきとうほん /戸籍謄本/
こせきほう /戸籍法/
こせきめい /戸籍名/
こせたい /子世帯/
こせつ /古拙;つたないが古風な趣がある/古説/
こせつてん /子節点/
こせん /古銭/弧線/姑洗/
こせんきょう /跨線橋/
こせんじょう /古戦場/
こせんすい /枯山水/
こぜい /小勢/
こぜき /小関/
こぜつ /孤絶/
こぜに /小銭/
こぜにいれ /小銭入れ/
こぜりあい /小競り合い/小競合/
こそう /固相/枯草/古箏/古層/枯燥/鼓騒/鼓譟/
こそうきん /枯草菌/
こそうねつ /枯草熱/
こそく /姑息;「-な手段」 NB:本義は「一時凌ぎ」/呼息;⇔吸息/
こそし /古曽志/
こそだて /子育て/
こそで /小袖/
こそとがり /小外刈り/
こそどろ /こそ泥/コソ泥/
こそめつけ /古染付/
こそん /孤村/
こぞ /去年/
こぞう /小僧/子象/
こぞうずし /小僧寿司/
こぞく /古俗/故俗;=古俗/
こぞっこ /小僧っ子/
こぞって /挙って/
こぞの /小園/
こたい /固体;solid/個体;individual/鼓隊/古体/固態/
こたいかん /個体間/
こたいぐん /個体群/
こたいぐんぜんたい /個体群全体/
こたいぐんない /個体群内/
こたいさ /個体差/
こたいしきべつ /個体識別/
こたいじょう /固体状/
こたいじょうほう /個体情報/
こたいすう /個体数/
こたいたち /個体達/
こたいたんい /個体単位/
こたいちきゅう /固体地球/
こたいちゅう /固体中/
こたいてき /固体的/
こたいでんし /固体電子/
こたいでんしこうがく /固体電子工学/
こたいない /個体内/
こたいないぶ /個体内部/
こたいねんりょう /固体燃料/
こたいはっせい /個体発生/
こたいぶつりがく /固体物理学;solid state physics/
こたいへんすう /個体変数/
こたえ /答/答え/堪え/
こたえかた /答え方/
こたえられない /堪えられない/
こたか /小高/小鷹/
こたけ /小竹/
こたち /子達/
こたつ /炬燵/
こたつぶとん /炬燵布団/
こたつべんけい /炬燵弁慶/
こたつや /炬燵屋/
こたに /小谷/
こたび /此度/
こたろう /小太郎/虎太郎/
こたん /枯淡/古淡/
こだい /古代/誇大/
こだい> /古代;-紫,-社会,-ギリシャ語/
こだいいらい /古代以来/
こだいかいしゃく /誇大解釈/
こだいきかい /古代機械/
こだいぎれ /古代裂/
こだいこ /小太鼓/
こだいこうこく /誇大広告/
こだいご /古代語/
こだいし /古代史/
こだいしけんきゅうか /古代史研究家/
こだいしゃかい /古代社会;Ancient Society,1877,Morgan/
こだいしんわ /古代神話/
こだいじん /古代人/
こだいじんるい /古代人類/
こだいせんでん /誇大宣伝/
こだいぞめ /古代染/
こだいちゅうごく /古代中国/
こだいちょうせんご /古代朝鮮語/
こだいてき /古代的/
こだいとし /古代都市/
こだいとしょかん /古代図書館/
こだいにほんご /古代日本語/
こだいぶんか /古代文化/
こだいぶんめい /古代文明/
こだいへん /古代篇/
こだいまい /古代米/
こだいむらさき /古代紫/
こだいもうそう /誇大妄想/
こだいもじ /古代文字/
こだいら /小平/
こだいらし /小平市/
こだか /小高/
こだから /子宝/
こだくさん /子沢山/
こだくみ /木工/木匠/
こだし /小出し/
こだち /木立/小太刀/木立ち/
こだつの /小立野/
こだて /戸建/戸建て;[略語]一戸建て/小楯/木楯/
こだと /古田土/
こだな /蚕棚/
こだなか /小田中/
こだぬき /子狸/
こだね /子種/
こだま /木霊/谺/小玉/児玉;人名/兒玉/
こだまし /児玉氏/
こだわり /拘泥;原義:つまらぬことに気を取られること/拘泥り/
こち /東風/鯒/故地/故知/此方/乞/牛尾魚/
こちじ /越路;姓/
こちじき /古地磁気;paleomagnetism/
こちず /古地図/
こちゃく /固着/
こちゅう /壺中/
こちょう /誇張/胡蝶/蝴蝶;=胡蝶/鼓腸/古調/弧長/孤蝶/
こちょうせん /古朝鮮/
こちょうのゆめ /胡蝶の夢;[荘子]/
こちょうひょうげん /誇張表現/
こちょうらん /胡蝶蘭/
こちら /此方/
こちり /古地理/
こっ /国/
こっか /国家;state/国歌;anthem.「-斉唱」/国花/骨化/國家;「国」旧字/黒化/刻下/】/）/］/』/
こっかい /国会/黒海/告解/
こっかいぎいん /国会議員/
こっかいぎけつ /国会議決/
こっかいぎじどう /国会議事堂/
こっかいぎじどうまえ /国会議事堂前/
こっかいぎじろく /国会議事録/
こっかいしょうしゅう /国会召集/
こっかいたいさくいいんかい /国会対策委員会/
こっかいちゅうけい /国会中継/
こっかいとしょかん /国会図書館/
こっかいはつげん /国会発言/
こっかいほう /国会法/
こっかいまえ /国会前/
こっかかん /国家間/国家観/
こっかがいねん /国家概念/
こっかがく /国家学/
こっかきかく /国家規格/
こっかきかん /国家機関/
こっかきみつ /国家機密/
こっかぎょうじ /国家行事/
こっかぎょうせいそしきほう /国家行政組織法/
こっかく /骨格/骨骼;=骨格/
こっかくき /骨角器/
こっかくきん /骨格筋/
こっかぐん /国家群/
こっかけいざい /国家経済;national economy/
こっかけんりょく /国家権力/
こっかげんしゅ /国家元首/
こっかこうあんいいんかい /国家公安委員会/
こっかこうむいん /国家公務員/
こっかこうむいんほう /国家公務員法/
こっかしかく /国家資格/
こっかしけん /国家試験/
こっかしけんめんじょ /国家試験免除/
こっかしじょうしゅぎ /国家至上主義/
こっかしゃかい /国家社会/
こっかしゃかいしゅぎ /国家社会主義;national socialism/
こっかしゅぎ /国家主義/
こっかしゅせき /国家主席/
こっかしゅどう /国家主導/
こっかしんとう /国家神道/
こっかしんどう /国家神道/
こっかせいしょう /国歌斉唱/
こっかせんりゃく /国家戦略/
こっかぜんたい /国家全体/
こっかそうどういんほう /国家総動員法/
こっかぞう /国家像/
こっかたいこっか /国家対国家/
こっかたいせい /国家体制/
こっかたんい /国家単位/
こっかっしょく /黒褐色/
こっかてき /国家的/
こっかはさん /国家破産/
こっかばいしょう /国家賠償/
こっかばいしょうほう /国家賠償法/
こっかひみつ /国家秘密/
こっかほう /国家法/
こっかほしょう /国家補償/
こっかめい /国家名/
こっかよさん /国家予算/
こっかろん /国家論/
こっかん /酷寒/骨幹/国漢;国文・漢文/
こっき /国旗/克己/黒旗/国記;620,厩戸皇子。現存せず/
こっきけいよう /国旗掲揚/
こっきしん /克己心/
こっきふくれい /克己復礼/
こっきゅう /黒球/
こっきょう /国境/国教/国共;[中国史]国民党と共産党。「-合作,-内戦」/
こっきょうえき /国境駅/
こっきょうかい /国教会/
こっきょうがっさく /国共合作/
こっきょうせん /国境線/
こっきょうぞい /国境沿い/
こっきょうないせん /国共内戦/
こっきん /国禁/
こっく /刻苦/
こっくちょう /コック長/
こっくべんれい /刻苦勉励/
こっくん /国訓/
こっけい /滑稽/酷刑/
こっけいせつ /国慶節/
こっけいぼん /滑稽本/
こっけん /国権/黒鍵/国憲/国研/
こっけんじょう /国権上/
こっこ /国庫/
こっこう /国交/国光/
こっこうこうしょう /国交交渉/
こっこうしょう /国交省;国土交通省/国交相;†大臣/
こっこうせいじょうか /国交正常化/
こっこうりつ /国公立/
こっこうりつだい /国公立大/
こっこうりつだいがく /国公立大学/
こっこきん /国庫金/
こっこく /刻々/
こっこししゅつきん /国庫支出金;紐付き。⇔地方交付税/
こっこふたん /国庫負担/
こっこふたんきん /国庫負担金/
こっこふたんりつ /国庫負担率/
こっこほじょ /国庫補助/
こっこほじょきん /国庫補助金/
こっし /骨子/
こっしあん /骨子案/
こっしゅ /骨腫/
こっせつ /骨折/骨節;[解剖]osteomere/
こっせつしゃ /骨折者/
こっせつちりょうちゅう /骨折治療中/
こっそう /骨相/
こっそうがく /骨相学/
こったん /骨炭/
こっち /此方/
こっちょう /骨頂/
こっとい /特牛;地名,/
こっとう /骨董/
こっとうかち /骨董価値/
こっとうてきかち /骨董的価値/
こっとうひん /骨董品/
こっぱ /木っ端/木端/木ッ端/
こっぱい /骨牌/骨灰/
こっぱみじん /木っ端微塵/木端微塵/
こっぷざ /コップ座;Crater(Crt)/
こっぷん /骨粉/
こっぺん /骨片/
こっぽう /骨法/
こつ /骨/榾;ほた/忽;忽然/惚;恍惚/笏;しゃく/乞;乞食/兀/
こつあげ /骨揚げ/
こつえん /忽焉/
こつがい /乞丐/
こつがら /骨柄/
こつくり /木造/
こつさいぼう /骨細胞;[生物]osteocyte, bone cell/
こつざい /骨材;セメントに入れる砂など/
こつじき /乞食/
こつじょ /忽如/
こつじょう /骨状/
こつずい /骨髄/
こつずいいしょく /骨髄移植/
こつずいえん /骨髄炎;[医]/
こつずいしゅ /骨髄腫/
こつずいていきょう /骨髄提供/
こつずいていきょうしゃ /骨髄提供者/
こつずいばんく /骨髄バンク;www.jmdp.or.jp/
こつぜん /忽然/
こつぜんと /忽然と/
こつそしき /骨組織;[生物]bone tissue/
こつそしょうしょう /骨粗鬆症/
こつつぼ /骨壺/骨壷;「壺」異体字/
こつづみ /小鼓/
こつでんどう /骨伝導/
こつにく /骨肉/
こつにくしゅ /骨肉腫/
こつねん /忽然/
こつねんれい /骨年齢;bone age/
こつばん /骨盤/
こつひろい /骨拾い/
こつぶ /小粒/
こつぼ /小壺/
こつまく /骨膜/
こつまくえん /骨膜炎/
こつみ /木積/
こつみつど /骨密度/
こつりつ /骨立/
こつりん /骨鱗/
こつるせん /小鶴線/
こづか /小柄/小塚/
こづかい /小遣い/小使い;janitor/小使/
こづかいせん /小遣い銭/小遣銭/
こづかいちょう /小遣い帳/
こづくり /子作り;make love/木造り;wooden/小作り;tiny/
こづけ /小付け/小付/
こづち /小槌/
こづつ /小筒/
こづつみ /小包/
こづつみはがき /小包葉書/
こづめ /小爪/
こづる /小鶴/
こづるせん /小鶴線/
こづれ /子連れ/
こて /小手/鏝/籠手/鐺;≒鏝/
こてい /固定/湖底/小体/
こていいち /固定位置/
こていえき /固定液;fixative/
こていか /固定化/
こていかんねん /固定観念/
こていがいねん /固定概念/
こていがた /固定型/
こていきゃく /固定客/
こていきゅう /固定給/
こていきょく /固定局/
こていきんり /固定金利/
こていぐ /固定具/
こていしき /固定式/
こていしさん /固定資産;有形固定資産、無形固定資産、投資等の3つ/
こていしさんぜい /固定資産税/
こていしさんばいきゃくえき /固定資産売却益/
こていしさんばいきゃくそん /固定資産売却損/
こていしほん /固定資本/
こていしゃ /固定者/
こていしょうすう /固定小数/
こていしょうすうてん /固定小数点/
こていしょうすうてんえんざん /固定小数点演算/
こていしょうすうてんすう /固定小数点数/
こていじゅつ /固定術/
こていじょうけん /固定条件/
こていせい /固定制/固定性/
こていそうさ /固定操作/
こていそうば /固定相場/
こていそうばせい /固定相場制/
こていたん /固定端/
こていち /固定値/
こていちょう /固定長/
こていちょうきてきごうりつ /固定長期適合率/
こていてき /固定的/
こていてん /固定点/
こていでんわ /固定電話;⇔携帯電話/
こていにゅうりょく /固定入力/
こていはっせいげん /固定発生源/
こていはば /固定幅/
こていひ /固定費/
こていひょう /固定票/
こていひりつ /固定比率/
こていふさい /固定負債/
こていぶつ /固定物/
こていへんせい /固定編成/
こていほう /固定法/
こていほうしき /固定方式/
こていほうほう /固定方法/
こていまど /固定窓/
こていもじれつ /固定文字列/
こていよう /固定用/
こていよく /固定翼/
こていよくき /固定翼機/
こてがえし /小手返し/
こてがわ /古手川/小手川/
こてき /鼓笛/
こてきたい /鼓笛隊/
こてさき /小手先/
こてさし /小手指/
こてしらべ /小手調べ/
こてつ /小鉄/
こてなげ /小手投げ/
こてわざ /小手技/
こてん /古典/個展/古点/
こてんおんがく /古典音楽/
こてんがく /古典学/
こてんがっき /古典楽器/
こてんき /古典機/
こてんけい /古典系/
こてんげいのう /古典芸能/
こてんげき /古典劇/
こてんこだい /古典古代/
こてんご /古典語/
こてんしゅぎ /古典主義/
こてんじだい /古典時代/
こてんせき /古典籍/
こてんちゅう /古典中/
こてんてき /古典的/
こてんてきしゅほう /古典的手法/
こてんてきじょうけんづけ /古典的条件付/
こてんてきめいさく /古典的名作/
こてんは /古典派/
こてんはおんがく /古典派音楽/
こてんぶつり /古典物理/
こてんぶつりがく /古典物理学;classical physics. ⇔量子物理学/
こてんぶんがく /古典文学/
こてんぶんぽう /古典文法/
こてんらくご /古典落語/
こてんりきがく /古典力学/
こてんりろん /古典理論/
こてんろん /古典論/
こてんろんり /古典論理/
こでら /小寺/
こでん /古伝/
こと /事/言/琴;(楽器)/箏;≒琴/異;「意見を-にする」/殊;「殊に」(≒特に)/古都/糊塗/古渡/亊;「事」の異体字/
ことあげ /言挙げ/
こといみ /言忌み/
ことう /孤島/古刀/湖東/小藤/厚東/
ことえり /言選り/
ことかぜごうき /琴風豪規/
ことがうめ /琴ヶ梅/
ことがら /事柄/
ことぎれ /事切れ/
ことく /古徳/
ことこまか /事細か/
ことごと /事々/異事/
ことごとく /悉く/尽く/
ことさら /殊更/
ことざ /琴座;Lyra(Lyr)/
ことし /今年/
ことしあき /今年秋/
ことしいじょう /今年以上/
ことしいちばん /今年一番/
ことしかいさい /今年開催/
ことしかいそう /今年改装/
ことしかんれき /今年還暦/
ことしくれ /今年暮/
ことしこうはん /今年後半/
ことしさいご /今年最後/
ことしさいしょ /今年最初/
ことしさいだい /今年最大/
ことしじゅう /今年中/
ことしすえ /今年末/
ことしぜんはん /今年前半/
ことしだけ /今年竹/
ことしちゅう /今年中/
ことしぢゅう /今年中/
ことしなついこう /今年夏以降/
ことしはつ /今年初/
ことしはる /今年春/
ことしぶん /今年分/
ことしろ /事代/
ことじ /琴柱/
ことじたい /事自体/
ことだま /言霊/
ことづけ /言付け/託け;=言付け/事付;?/
ことづて /言伝/言伝て/言傳て;「伝」旧字/
ことてん /事典;NB:「辞典」と区別するための読み方/
ことてんざん /琴天山/
ことでん /琴電/
こととい /言問/
こととき /異時/
ことなかれ /事勿れ/
ことなかれしゅぎ /事勿れ主義/
ことなし /事無/
ことなりごすう /異なり語数;number of unique words/
ことに /殊に/琴似;地名,札幌/異に;=殊に/
ことにしき /琴錦/
ことね /琴音/
ことの /琴乃/琴野/
ことのついで /事の序/
ことのは /言の葉/
ことのほか /殊の外/
ことはじめ /事始/事始め/
ことはら /異腹/
ことば /言葉/詞/辞/
ことばあそび /言葉遊び/
ことばかず /言葉数/
ことばがき /詞書/
ことばがり /言葉狩り/
ことばじしん /言葉自身/
ことばじたい /言葉自体/
ことばじち /言葉質/
ことばじり /言葉尻/
ことばつき /言葉付き/
ことばづかい /言葉遣い/言葉使い/
ことばのあや /言葉の綾/
ことばぶそく /言葉不足/
ことばめん /言葉面/
ことひら /琴平/
ことひらせん /琴平線/
ことふじ /琴富士/
ことぶき /寿/壽/
ことぶきそう /寿荘/
ことぶきたいしゃ /寿退社/
ことぶきたいしょく /寿退職/
ことぶきや /寿屋/壽屋;「寿」旧字/
ことべっぷ /琴別府/
ことほぎ /寿/言祝ぎ/言寿ぎ/
ことほぞんほう /古都保存法/
ことほどさように /事程左様に/
ことまき /異巻/
ことみ /琴美/
こともなげ /事も無げ;(形容動詞)/
こともの /異者/
ことり /小鳥/
ことりたち /小鳥達/
ことりよう /小鳥用/
ことわけ /事訳/
ことわざ /諺/
ことわり /理/断り/
ことわりがき /断り書き/
こど /弧度/
こどう /鼓動/古道/古銅/鼓胴;つづみの胴部/小胴;こつづみ/
こどうきょう /跨道橋/
こどうぐ /小道具/
こどうぐや /小道具屋/
こどく /孤独/蠱毒/
こどくかん /孤独感/
こどくし /孤独死/
こどけい /子時計/
こどほう /弧度法;弧度(radian)で角度を図る方法/
こどまり /小泊/
こども /子供/子ども/小人/
こどもあいて /子供相手/
こどもあつかい /子供扱い/
こどもかい /子供会/
こどもかいいん /子供会員/
こどもぎんこう /子供銀行/
こどもごころ /子供心/
こどもしつ /子供室/
こどもじだい /子供時代/
こどもずき /子供好き/
こどもそうだんしつ /子供相談室/
こどもたち /子供達/
こどもだまし /子供騙し/
こどもづれ /子供連れ/
こどもなみ /子供並/
こどものひ /こどもの日;5.5/
こどもばんぐみ /子供番組/
こどもふく /子供服/
こどもべや /子供部屋/
こどもむけ /子供向け/
こどもよう /子供用/
こどもりょうきん /子供料金/
こな /粉/小名/
こない /庫内/
こないだ /此間/
こなおしろい /粉白粉/
こなか /小中/
こなかい /小仲井/
こなかだい /小仲台/
こなから /二合半/
こながい /小長井/
こなきじじい /子泣き爺/子泣爺/
こなぐすり /粉薬/
こなごな /粉々/
こなざとう /粉砂糖/
こなし /小梨/
こなじょう /粉状/
こなせっけん /粉石鹸/粉せっけん/
こなた /此方/
こなちーず /粉チーズ/
こなちゃ /粉茶/
こなつ /小夏/
こなふき /粉吹き/
こなべ /小鍋/
こなまいき /小生意気/
こなみ /小波/前妻/嫡妻;=前妻/
こなみじん /粉微塵/
こなみるく /粉ミルク/
こなや /粉屋/
こなゆき /粉雪/
こなら /枹/
こならい /小習/
こなわ /小縄/
こなん /湖南/
こにきし /王/
こにし /小西/
こにしき /小錦/
こにしろく /小西六/
こにもつ /小荷物/
こにんずう /小人数/
こぬか /小糠/
こぬかあめ /小糠雨/
こぬき /小貫/
こぬま /小沼/
こねこ /子猫/仔猫/子ネコ/小猫/
こねずみ /小鼠/子鼠/濃鼠/
こねた /小ネタ/
この /此の/斯の/此/
この> /此の/斯の/
このーど /子ノード;child node/
このあいだ /この間/此の間/
このうえ /この上/
このうら /金浦/
このえ /近衛/
このえしだん /近衛師団/
このえちょう /近江町;おうみちょう?/
このえてんのう /近衛天皇/
このえのちゅうじょう /近衛中将/
このえひでまろ /近衛秀麿/
このえふ /近衛府/
このえふみまろ /近衛文麿/
このえへい /近衛兵/
このかた /この方/此の方/此方/
このかみ /兄/
このかん /この間/
このこ /この子/
このこうべ /兄部/
このころ /この頃/
このご /この期/此期/
このごろ /この頃/此頃/
このさい /この際/
このさき /此の先/
このしゅ /この種/
このしろ /鮗/
このせつ /此の節/
このたび /この度/此度/此の度/
このて /この手/
このてん /この点/
このとき /この時/
このとし /この年/
このは /木の葉/
このはちょう /木の葉蝶/
このはな /此花/
このはなのさくやびめ /木花開耶姫/
このぶん /此の分/
このへん /この辺/此邊/
このほど /此の程/
このまえ /この前/
このみ /木の実/好み/この身/好/木實/
このみち /この道/此路/
このめ /木の芽/
このめどき /木の芽時/
このよ /この世/此の世/
このよう /此の様/
このわた /海鼠腸/
このんで /好んで/
こはぎ /小萩/
こはく /琥珀/
こはくいろ /琥珀色/
こはくちゅう /琥珀中/
こはぜ /鞐/
こはた /木幡/小幡/古畑/戸畑/
こはだ /木肌/小鰭;[魚]このしろ/樸;=木肌/木皮;=木肌/木膚;=木肌/
こはつ /孤発/
こはつせい /孤発性/
こはな /裔/
こはば /小幅/
こはばだか /小幅高/
こはばやす /小幅安/
こはま /小濱/
こはまちょう /小浜町/
こはら /小原/
こはり /小針/小梁/
こはる /小春/
こはるびより /小春日和/
こはん /湖畔/古版/孤帆/個販/
こはんとき /小半時/
こはんにち /小半日/
こば /木場/古葉/古馬;[競馬]3(4)歳以上の馬/古場/胡馬;-北風に依る/
こばい /故買/
こばいや /故買屋/
こばか /小馬鹿/
こばく /固縛/
こばこ /小箱/
こばし /小橋/
こばしら /小柱/
こばしり /小走り/
こばじん /古馬陣/
こばた /小幡/小旗/
こばたけ /小畑/
こばち /小鉢/
こばちりょうり /小鉢料理/
こばな /小花/小鼻/
こばなし /小話/小噺/小咄/
こばなれ /子離れ/
こばね /小羽根/
こばやかわ /小早川/
こばやかわたかかげ /小早川隆景/
こばやかわひであき /小早川秀秋/
こばやし /小林/古林/
こばやしあきら /小林旭/
こばやしいっさ /小林一茶/
こばやしたきじ /小林多喜二/
こばやしひでお /小林秀雄/
こばら /小腹/
こばり /小針/
こばると /Co/Cobalt/
こばん /小判/
こばんがた /小判型/小判形/
こばんごう /子番号/
こばんざめ /小判鮫/
こばんそう /小判草/
こひ /古碑/
こひき /粉引/
こひしつ /古皮質/
こひじ /泥/
こひつ /古筆/
こひつぎれ /古筆切/
こひつじ /子羊/仔羊/小羊/
こひとり /子一人/
こひなた /小日向/
こひやま /小桧山/
こひょう /個票/小兵/
こひるいまき /小比類巻/
こび /媚/媚び/狐媚/
こびき /木挽/
こびきちょう /木挽町/
こびじゅつ /古美術/
こびじゅつしょう /古美術商/
こびじゅつてん /古美術店/
こびちゃ /媚茶/
こびと /小人/
こびとしょう /小人症;[医]/
こびな /小雛/
こびゃくしょう /小百姓/
こびら /小平/
こびん /小瓶/小壜/
こぴーき /コピー機/
こぴーしょうひん /コピー商品/
こぴーひん /コピー品/
こぴーようし /コピー用紙/
こふ /古布/誇負/
こふう /古風/
こふきいも /粉吹き芋/粉吹芋/
こふく /鼓腹;-撃壌/胡服/古服/
こふくげきじょう /鼓腹撃壌/鼓腹撃壤;旧字/
こふじ /小藤/
こふみ /湖吹美/
こふん /古墳/
こふんじだい /古墳時代;3-7世紀/
こぶ /瘤/鼓舞/昆布/
こぶうし /瘤牛/
こぶくろ /小袋/子袋;(特に、食材としての)子宮/
こぶさ /小房/
こぶし /拳/辛夷/古武士/小節/
こぶしいも /拳芋/
こぶしょうしょ /戸部尚書/
こぶじめ /昆布締め/
こぶじゅつ /古武術/
こぶた /子豚/
こぶだし /昆布出汁/
こぶちざわ /小淵沢/
こぶちゃ /昆布茶/
こぶつ /古物/古仏/個物/
こぶつえいぎょうほう /古物営業法/
こぶつき /瘤付き/コブ付き/
こぶつしょう /古物商/故物商/
こぶとり /小太り/小肥り/
こぶどう /古武道/
こぶね /小舟/小船/
こぶへい /こぶ平/
こぶまき /昆布巻/昆布巻き/
こぶみ /小文/
こぶら /腓/
こぶり /小振り;†small.「-のイワシ」/小降り;†drizzle.「雨が-になる」/
こぶん /古文/子分/
こぶんけん /古文献/
こぶんしょ /古文書/
こぶんしょうしょ /古文尚書/
こぶんじ /古文辞/
こぶんじがく /古文辞学/
こへい /古兵/雇兵/雇聘/
こへん /湖辺/子偏/
こべ /小部/
こべつ /個別/戸別/
こべつか /個別化/
こべつぐたいてき /個別具体的/
こべつげきは /個別撃破/
こべつしどう /個別指導/
こべつしょうひぜい /個別消費税/
こべつせいぎょ /個別制御/
こべつそうだん /個別相談/
こべつたいおう /個別対応/
こべつちゅうもん /個別注文/
こべつてき /個別的/
こべつてきじえいけん /個別的自衛権/
こべつはいそう /個別配送/
こべつほうもん /戸別訪問/個別訪問/
こべつりがい /個別利害/
こべや /小部屋/
こほう /古方/孤峰/
こほうそう /個包装/
こほく /湖北/
こほり /氷/
こほん /小本/古本/孤本/
こぼう /顧望/
こぼうしょ /小奉書/
こぼうず /小坊主/
こぼく /古木/枯木/
こぼくかんがん /枯木寒巌/
こぼくしかい /枯木死灰;無気力/
こぼけ /小歩危/
こぼとけ /小仏/
こぼね /小骨;魚の-/子骨;扇の-/
こぼり /小堀/古保里/
こぼりえんしゅう /小堀遠州;(1579-1647) 茶人/
こぼれ /零れ/毀れ/
こぼれだね /零れ種/こぼれ種/
こぼればなし /零れ話/こぼれ話/
こぼんのう /子煩悩/
こま /駒;horse/独楽/小間/齣;cut/細/狛/高麗/
こまあみ /細編み/
こまあらし /駒嵐/
こまい /古米/駒井/小舞/氷下魚/氷魚/
こまいずみ /駒泉/
こまいぬ /狛犬/狛/
こまえ /狛江/小前/駒絵/小間絵/駒枝/
こまえし /狛江市/
こまおくり /コマ送り/駒送り/
こまおと /駒音/
こまおとし /齣落とし/齣落/
こまか /細か/
こまがく /高麗楽;雅楽の様式/
こまがた /駒形/
こまがたけ /駒ヶ岳/
こまがだけ /駒ヶ岳/
こまがね /駒ヶ根/
こまがみね /駒ヶ峯/
こまがわ /高麗川/
こまがわなかの /駒川中野/
こまき /小牧/駒木/
こまきやま /小牧山/
こまぎれ /細切れ/小間切れ;-100ください/
こまく /鼓膜/
こまくさ /駒草/
こまくじょう /鼓膜上/
こまくめん /鼓膜面/
こまくら /小枕/木枕/
こまぐみ /駒組み/
こまけん /小間研/
こまげた /駒下駄/
こまごま /細々/
こまごめ /駒込/
こまごめえき /駒込駅/
こまさい /駒祭/
こまざき /駒崎/
こまざわ /駒沢/
こまざわがくえん /駒沢学園/
こまざわこうえん /駒沢公園/
こまざわたいいくかん /駒沢体育館/
こまざわだい /駒沢大/
こまざわだいがく /駒沢大学/
こまざわだいがくえき /駒沢大学駅/
こまざわりくじょう /駒沢陸上/
こますう /コマ数/
こませ /駒瀬/
こまぞん /駒損/
こまた /小股/小俣;地名/
こまたすくい /小股掬い/
こまたんい /駒単位/
こまだ /駒田/
こまだい /駒大;駒澤大学/駒台;将棋の-/
こまち /小町/
こまちむすめ /小町娘/
こまちや /小町谷/
こまつ /小松/
こまつえき /小松駅/
こまつがわ /小松川/
こまつくうこう /小松空港/
こまつさきょう /小松左京;SF作家/
こまつざき /小松崎/
こまつしま /小松島/
こまつしまし /小松島市/
こまつせいさくしょ /小松製作所;[企業名]/
こまつだ /小松田/
こまつな /小松菜/
こまつのみや /小松宮/
こまつばら /小松原/
こまつびん /小松便/
こまづかい /小間使い/
こまと /小的/
こまど /小窓/
こまどく /駒得/
こまどり /駒鳥/
こまねずみ /独楽鼠;忙しいさま/
こまば /駒場/
こまばきょうぎじょう /駒場競技場/
こまばさい /駒場祭/
こまばとうだい /駒場東大/
こまばとうだいまえ /駒場東大前/
こまばりょう /駒場寮/
こまぶえ /高麗笛;高麗楽で使う笛/狛笛;高麗楽で使う笛/
こまみや /駒宮/
こまむすび /細結び/
こまむら /駒村/
こまめ /小まめ/細目/小忠実/
こまもの /小間物/
こまものや /小間物屋/
こまやか /細やか/
こまりもの /困り者/困り物/
こまりょう /駒寮/
こまる /小丸/
こまわり /小回り/
こまんどめい /コマンド名/
こみ /込み/込/
こみかた /混み方/
こみかど /小御門/
こみこみ /込み込み;[口]全ての費用を含んだ(価格)/
こみだし /小見出し/
こみち /小径/小道/小路/径/蹊/徑;「径」の旧字/子径;?/
こみちしょぼう /径書房/
こみっくし /コミック誌/
こみなと /小湊/
こみなとてつどう /小湊鉄道/
こみね /小峰/小峯/
こみの /小美濃/
こみみ /小耳/
こみや /小宮/
こみやま /小宮山/込山/
こむ /込/
こむかい /小向/
こむかいこうじょう /小向工場/
こむぎ /小麦/
こむぎいろ /小麦色/
こむぎこ /小麦粉/
こむぎこせいひん /小麦粉製品/
こむぎそうば /小麦相場/
こむし /小虫/
こむすび /小結/
こむすめ /小娘/
こむそう /虚無僧/
こむた /小牟田/
こむら /腓/小村/古村/木叢/
こむらがえり /腓返り/
こむらさき /濃紫/小紫/
こむらさきいろ /濃紫色/
こむろ /小室/
こむろぶし /小室節;[民謡]/
こめ /米/個目/※/
こめあぶら /米油/
こめい /古名/呼名/顧命/
こめいじ /古明地/
こめいち /米市/
こめかみ /蟀谷/
こめがふくろ /米ヶ袋/
こめぐら /米蔵/
こめこ /米粉/
こめこうじ /米麹/
こめこめ /米米/
こめしょうぐん /米将軍;徳川吉宗の渾名/
こめじょうちゅう /米焼酎/
こめじるし /※/
こめす /米酢/
こめそうどう /米騒動;1918/
こめそうば /米相場/
こめたに /米谷/
こめだ /米田/
こめだわら /米俵/
こめつが /米栂/
こめつき /米搗き/
こめつきばった /米搗き飛蝗/
こめつぶ /米粒/
こめつぶだい /米粒大/
こめづくり /米作り/
こめてん /米店/
こめどいや /米問屋/
こめどころ /米所/
こめぬか /米糠/米ぬか/
こめの /米野/
こめぱん /米パン/
こめひゃっぴょう /米百俵;one-phrase politics/
こめひょう /米兵/
こめびつ /米櫃/米びつ/
こめぶくろ /米袋/
こめへん /米偏/
こめみそ /米味噌/
こめや /米屋/
こめやまち /米屋町/
こめん /湖面/
こめんとぎょう /コメント行/
こめんとらん /コメント欄/
こも /菰/薦/
こもがい /熊川/
こもく /小目/
こもごも /交々/交/
こもじ /小文字/
こもじか /小文字化/
こもだ /菰田/小茂田/
こもち /子持ち/子持/
こもちかんらん /子持甘藍/
こもちけい /子持罫/
こもちづき /小望月/
こもどし /小戻し/
こもどり /小戻り/
こもの /小物/小者/菰野/薦野/
こものいれ /小物入/小物入れ/
こものせんもん /小物専門/
こものるい /小物類/
こもり /子守/子守り/小森/古森/木守/籠り/隠り/
こもりうた /子守唄/子守歌/子守り歌/子守り唄/
こもりや /小森谷/
こもりやく /子守役/
こもりよう /子守用/
こもれび /木漏れ日/木洩れ日/木洩れ陽/木洩日/
こもろ /小諸/
こもん /顧問/小紋/古文/
こもんかいぎ /顧問会議/
こもんじょ /古文書/
こもんじょがく /古文書学/
こもんべんごし /顧問弁護士/
こもんりょう /顧問料/
こや /小屋/木屋/昆陽/
こやいけ /昆陽池/
こやがけ /小屋掛け/
こやぎ /子山羊/
こやく /子役/
こやくにん /小役人/
こやくはいゆう /子役俳優/
こやぐち /小屋口/
こやぐみ /小屋組/
こやけ /小焼け/
こやさこ /小屋迫;姓/
こやさん /姑射山/
こやし /肥やし/
こやす /子安/
こやすがい /子安貝/
こやすみ /小休み/
こやだいら /小屋平/
こやち /小谷内/
こやつ /此奴/
こやつら /此奴等/
こやづ /小谷津/
こやづか /小屋束/
こやなぎ /小柳/
こやなぎるみこ /小柳ルミ子/
こやね /小屋根;[建築]庇など/
こやの /小谷野/
こやばり /小屋梁;[建築]/
こやま /小山/古山/湖山/
こやまだい /小山台/
こやまだいこうこう /小山台高校/
こやみ /小止み/
こやり /小槍/
こゆ /児湯/
こゆい /小結/
こゆう /固有/個有;?/
こゆううんどう /固有運動/
こゆうかくうんどうりょう /固有角運動量/
こゆうかんすう /固有関数/
こゆうご /固有語/
こゆうざ /小遊三;芸名/
こゆうざいさん /固有財産/
こゆうしゅ /固有種;[生物]endemic/
こゆうしゅうはすう /固有周波数/
こゆうしんどう /固有振動/
こゆうしんどうすう /固有振動数/
こゆうじむ /固有事務;⇔委任事務/
こゆうせい /固有性/
こゆうち /固有値/
こゆうちかいせき /固有値解析/
こゆうちぶんかい /固有値分解/
こゆうちもんだい /固有値問題/
こゆうべくとる /固有ベクトル/
こゆうめい /固有名/
こゆうめいし /固有名詞/
こゆき /小雪/粉雪/
こゆび /小指/
こゆびいっぽん /小指一本/
こゆみ /小弓/
こゆるぎ /小揺るぎ/
こよい /今宵/
こよう /雇用/古謡/小用/雇傭/
こようかんきょう /雇用環境/
こようかんけい /雇用関係/
こようきかい /雇用機会/
こようけいたい /雇用形態/
こようけいやく /雇用契約/
こようさべつ /雇用差別/
こようしゃ /雇用者/雇傭者/
こようじょうせい /雇用情勢/
こようそうしゅつ /雇用創出/
こようたい /固溶体/
こようたいさくほう /雇用対策法/
こようちょうせい /雇用調整/
こようぬし /雇用主/
こようふあん /雇用不安/
こようほう /胡耀邦/
こようほけん /雇用保険/
こようほけんほう /雇用保険法/
こよみ /暦/
こより /紙撚り/
こら /子等/児等/
こらい /古来/
こらいしゅ /古来種/
こらえしょう /堪え性/
こらむきじ /コラム記事/
こらむしゅう /コラム集/
こらむらん /コラム欄/
こり /狐狸/凝り/梱/
こりーけん /コリー犬/
こりこう /小利口/
こりごり /懲り懲り/
こりしょう /凝り性/
こりつ /孤立/
こりつかん /孤立感/
こりつけい /孤立系/
こりつご /孤立語/
こりつしき /孤立式/
こりつしゅぎ /孤立主義/
こりつたんご /孤立単語/
こりつてん /孤立点/
こりつはっせい /孤立発声/
こりつぶんし /孤立分子/
こりつむえん /孤立無援/
こりや /凝り屋/
こりゅう /古流/
こりょ /顧慮/
こりょう /湖陵/糊料/
こりょうり /小料理/
こりょうりや /小料理屋/
こりようかい /狐狸妖怪/
こりんとしき /コリント式;[建築]Corinthian order. ギリシア建築の様式/
こりんとしょ /コリント書;[聖書]Corinthians(Cor)/
こるい /孤塁/
こるくいろ /コルク色;cork/
こるくそう /コルク層/
こるくぬき /コルク抜き/
これ /此れ/之/是/此/惟/旃/斯れ/
これ> /之/是/此れ;-幸い,-何如に/
これい /古例/古礼/
これいじょう /これ以上/
これお /是雄/
これかた /是方/
これき /古暦/
これさだ /是定/
これしき /是式;何の-/是しき/
これだけ /是だけ/
これとう /惟任/
こればかり /是許/
これほど /是程/
これまで /是迄/
これみつ /惟光/
これみよがし /此れ見よがし/これ見よがし/
これら /是等/此れ等/
これらきん /コレラ菌;cholera/
ころ /頃/転/
ころあい /頃合い/頃合/
ころいどようえき /コロイド溶液;[化学]colloidal solution/
ころう /古老/固陋/虎狼/故老/孤老/狐狼/
ころく /小六/
ころし /殺し/
ころしあい /殺し合い/
ころしもんく /殺し文句/
ころしや /殺し屋/
ころび /転び/
ころも /衣/
ころもあげ /衣揚げ/
ころもがえ /衣替え/衣更え/更衣/
ころもがわ /衣川/
ころもで /衣手/
ころもへん /衣偏/
ころんびあ /哥倫比亞/
ころんびあだいがく /コロンビア大学;Columbia University. www.columbia.edu/
ころんびあとくべつく /コロンビア特別区;District of Columbia,DC/
こわ /強;強面/声;声色/聲;「声」の旧字/
こわいい /強飯/
こわいろ /声色/聲色;「声」旧字/
こわかれ /子別れ/
こわき /小脇/
こわきえん /小湧園/
こわく /蠱惑/
こわくだに /小涌谷/
こわくてき /蠱惑的/
こわけ /小分け/
こわごわ /怖々/
こわさき /声先/
こわざ /小技/
こわざし /声差し/
こわたり /古渡り/
こわだ /古和田/
こわだか /声高/聲高;旧字/
こわだんぱん /強談判/
こわっぱ /小童/
こわづくり /声作り/
こわね /声音/聲音;「声」旧字/
こわめし /強飯/
こわもて /強面/強持て;怖いので逆に優遇される/
こわり /小割/小割り/
こわれ /壊れ/
こわれもの /壊れ物/
こゑ /聲/
こん /紺/混/今/根/痕;痕跡/婚/懇;懇談/墾;開墾/魂/金/坤;[八卦]陰陰陰/昏;昏睡/困;困惑/梱;梱包/悃;≒懇/艮;ごん/恨;痛恨/很;もと・る/狠;≒很/跟;くびす/昆;昆虫/鯤;想像上の大魚/鯀;≒鯤/棍;棍棒/崑;崑崙/菎;菎蒻(=蒟蒻,こんにゃく)/蒟;蒟蒻/渾;渾身/琿/鶤;大きなトリ/溷;にご・る/滾;滾々と湧く/袞;袞衣/近/建/琴/壼/献/獻;「献」の旧字/
こん> /今/
こんい /懇意/
こんいつ /混一/
こんいろ /紺色/
こんいん /婚姻/根因/
こんいんご /婚姻後/
こんいんしょく /婚姻色/
こんいんじょう /婚姻状/
こんいんてきれい /婚姻適齢/
こんいんとどけ /婚姻届/
こんおん /根音;根音位置/
こんか /今夏/婚家/
こんかい /今回/
こんかいこうにゅう /今回購入/
こんかいさくせい /今回作成/
こんかいはつ /今回初/
こんかいはつしゅつじょう /今回初出場/
こんかいはつとうじょう /今回初登場/
こんかいはつばい /今回発売/
こんかいぶん /今回分/
こんかん /根幹/根冠/
こんかんちりょう /根幹治療/
こんが /混芽/
こんがいこうしょう /婚外交渉/
こんがいし /婚外子/
こんがいれんあい /婚外恋愛;[新語]「不倫」の言い換え語/
こんがすり /紺絣/
こんがっき /今学期/
こんがみ /紺紙/
こんがん /懇願/
こんき /根気/今季;this season.「-打率」/今期;this period.「-利益」/婚期/根基/
こんきさいご /今季最後/
こんきぜつぼう /今期絶望/
こんきはつ /今季初/
こんきはつしょうり /今季初勝利/
こんきはつゆうしょう /今期初優勝/
こんきまつ /今季末/
こんきゃく /困却/
こんきゅう /困窮/
こんきゅうしゃ /困窮者/
こんきょ /根拠/
こんきょち /根拠地/
こんきょはくじゃく /根拠薄弱/
こんきょふめい /根拠不明/
こんぎ /婚儀/
こんく /困苦/金口/
こんくらべ /根競べ/根比べ/
こんけい /根茎/根系/
こんけつ /混血/混結/
こんけつしゅ /混血種/
こんけつじ /混血児/
こんけつど /混血度/
こんげつ /今月/
こんげついっぱい /今月一杯/
こんげつげじゅん /今月下旬/
こんげつごう /今月号/
こんげつじゅう /今月中/
こんげつすえ /今月末/
こんげつちゅう /今月中/
こんげつちゅうじゅん /今月中旬/
こんげつど /今月度/
こんげつはつばい /今月発売/
こんげつぶん /今月分/
こんげつまつ /今月末/
こんげん /根源/根元/
こんげんてき /根源的/根元的/
こんこう /混交/混淆;=混交/金光/渾淆;<rare> =混交/
こんこうきょう /金光教/
こんこっかいちゅう /今国会中/
こんこん /懇々;-と言い聞かせる/昏々;-と眠る/滾々;-と湧く/滾滾/昏昏/渾渾/
こんご /今後/
こんごいっさい /今後一切/
こんごう /混合/金剛/今号/根号;√/
こんごういん /金剛院/
こんごうえき /混合液/
こんごうかい /金剛界/
こんごうかいまんだら /金剛界曼荼羅;vajradhatu mandala/
こんごうき /混合気;mixture gas/混合器;mixer/
こんごうきょう /金剛経/
こんごうきょういく /混合教育/
こんごうけいざい /混合経済;mixed economy/
こんごうけんご /金剛堅固/
こんごうこうつう /混合交通/
こんごうさん /金剛山/
こんごうざわ /金剛沢/
こんごうしゃ /金剛砂/
こんごうしょ /金剛杵/
こんごうしよう /混合仕様/
こんごうしんかい /金剛神界/
こんごうしんりょう /混合診療/
こんごうじ /金剛寺/
こんごうすいせん /混合水栓/
こんごうせい /混合性/
こんごうせき /金剛石/
こんごうせん /混合栓/混合戦/
こんごうづえ /金剛杖/
こんごうてき /混合的/
こんごうはだ /混合肌/
こんごうひ /混合比/
こんごうふえ /金剛不壊/
こんごうぶ /混合部/
こんごうぶじ /金剛峰寺/
こんごうぶつ /混合物/
こんごうへんせい /混合編成/
こんごうりき /金剛力/
こんごうりゅう /金剛流/
こんごうれっしゃ /混合列車/
こんごけんとう /今後検討/
こんごとうじょう /今後登場/
こんごとも /今後共/
こんごもんだい /今後問題/
こんさい /混載/根菜/
こんさいるい /根菜類/
こんさく /混作/
こんざい /混在/
こんざつ /混雑/
こんざつかいしょう /混雑解消/
こんざつかんわ /混雑緩和/
こんざつじ /混雑時/
こんざつじょうきょう /混雑状況/
こんざつじょうたい /混雑状態/
こんざつど /混雑度/
こんざつりつ /混雑率/
こんざん /崑山;地名,崑崙/
こんし /紺紙/婚資/
こんしーずん /今シーズン/
こんしこんでい /紺紙金泥/
こんしゅう /今週/今秋/
こんしゅういっしゅうかん /今週一週間/
こんしゅういっぱい /今週一杯/
こんしゅうきんようび /今週金曜日/
こんしゅうごう /今週号/
こんしゅうじゅう /今週中/
こんしゅうちゅう /今週中/
こんしゅうはつばい /今週発売/
こんしゅうぶん /今週分/
こんしゅうまつ /今週末/
こんしゅうまつごろ /今週末頃/
こんしゅご /混種語/
こんしゅん /今春/
こんしょ /懇書/
こんしょう /混晶/
こんしょく /混色/混植/混織/混食/
こんしょくこう /混色光/
こんしろ /紺白/
こんしん /渾身/懇親/混信/今身;今世での肉体/渾心/根針/
こんしんかい /懇親会/
こんしんかいひ /懇親会費/
こんしんかいひよう /懇親会費用/
こんじ /根治/今次/紺地/今時/金字/恨事/
こんじき /金色/
こんじきどう /金色堂/
こんじきやしゃ /金色夜叉;尾崎紅葉/
こんじゃく /今昔/
こんじゃくもじきょう /今昔文字鏡;www.mojikyo.org/
こんじゃくものがたり /今昔物語/
こんじゃくものがたりしゅう /今昔物語集/
こんじゅほうしょう /紺綬褒章/
こんじょう /根性/今生/紺青/懇情/
こんじょうなし /根性無/
こんじょうもの /根性物/
こんじょうよう /根状葉/
こんじょうわる /根性悪/
こんす /公司;[中国語]会社,「くんす」とも/
こんすい /昏睡/
こんすいじょうたい /昏睡状態/
こんすたんちのーぷる /君府/
こんず /漿/
こんせい /混成;-軌道/混声;-合唱/今世;cf.前世,来世/金精/混生/懇請/根生/
こんせいおん /混声音/
こんせいがっしょう /混声合唱/
こんせいがっしょうだん /混声合唱団/
こんせいき /今世紀/
こんせいきさいご /今世紀最後/
こんせいきしょとう /今世紀初頭/
こんせいきぜんはん /今世紀前半/
こんせいきちゅう /今世紀中/
こんせいきどう /混成軌道/
こんせいしゅ /混成酒/
こんせいりょだん /混成旅団/
こんせき /痕跡/今夕/
こんせききかん /痕跡器官/
こんせきてき /痕跡的/
こんせつ /懇切/今節/
こんせつていねい /懇切丁寧/
こんせん /混戦/混線/
こんせんじ /混戦時/
こんせんじょうたい /混戦状態/
こんせんだいち /根釧台地/
こんせんちゅう /混戦中/
こんせんもよう /混戦模様/
こんぜ /今世/
こんぜつ /根絶/
こんぜん /渾然/婚前/混然;=渾然/
こんぜんいったい /渾然一体/
こんぜんこうしょう /婚前交渉/
こんぜんせい /婚前姓/
こんそう /混走/
こんそうりゅう /混相流/
こんそくちゅうるい /根足虫類/
こんたいかい /今大会/
こんたん /魂胆/根端/
こんだ /金田/今田/
こんだく /混濁/溷濁/
こんだて /献立/
こんだてひょう /献立表/
こんだん /懇談/
こんだんかい /懇談会/
こんだんかいかいさい /懇談会開催/
こんち /根治/
こんちくしょう /此畜生/
こんちゃ /紺茶/
こんちゅう /昆虫/昆蟲/
こんちゅうがく /昆虫学/
こんちゅうき /昆虫記/
こんちゅうけい /昆虫系/
こんちゅうさいしゅう /昆虫採集/
こんちゅうしゃしんか /昆虫写真家/
こんちゅうしょく /昆虫食/
こんちゅうたち /昆虫達/
こんちゅうもう /昆虫網/
こんちゅうや /昆虫屋/
こんちゅうるい /昆虫類/
こんちょう /今朝/根調;≒基調/
こんちりょうほう /根治療法/
こんてい /根底/根柢;=根底/
こんていてき /根底的/
こんてなせん /コンテナ船;containership/
こんてんぎ /渾天儀/
こんでい /金泥/
こんでん /墾田/
こんでんえいねんしざいほう /墾田永年私財法/
こんとう /今冬/昏倒/
こんとく /懇篤/
こんとん /混沌/渾沌;=混沌/
こんど /今度/
こんどう /混同/近藤/金堂/金銅/金藤/
こんどういさみ /近藤勇/
こんなん /困難/
こんなんせい /困難性/
こんにち /今日/
こんにちてき /今日的/
こんにちは /今日は/
こんにゃく /蒟蒻/菎蒻/
こんにゃくいも /蒟蒻芋/こんにゃく芋/
こんにゃくぼん /蒟蒻本/
こんにゃくもんどう /蒟蒻問答/菎蒻問答/
こんにゅう /混入/
こんねん /今年/
こんねんど /今年度/
こんねんどいっぱい /今年度一杯/
こんねんどさいご /今年度最後/
こんねんどちゅう /今年度中/
こんねんどとうしょ /今年度当初/
こんねんどない /今年度内/
こんねんどにゅうしゃ /今年度入社/
こんねんどよう /今年度用/
こんねんばん /今年版/
こんねんまつ /今年末/
こんの /今野/紺野/金野/昆野/
こんのくん /今野君/
こんのみさこ /紺野美沙子/
こんばい /困憊/
こんばしょ /今場所/
こんばん /今晩/
こんばんは /今晩は/
こんぱい /困憊/
こんぱく /魂魄/
こんぱくとか /コンパクト化/
こんぱすざ /コンパス座;Circinus(Cir)/
こんぱるりゅう /金春流;シテ方/
こんぱん /今般/
こんひ /根被/
こんびにけっさい /コンビニ決済/
こんびにべんとう /コンビニ弁当/
こんぴら /金比羅/
こんぶ /昆布/
こんぶまき /昆布巻/昆布巻き/
こんぷとんこうか /コンプトン効果;[物理]Compton effect/
こんへんちょう /混変調/
こんぺいとう /金平糖;confeito/金米糖;=金平糖/
こんぺき /紺碧/
こんぼう /棍棒/混紡/懇望/こん棒/
こんぽう /梱包/
こんぽうさぎょう /梱包作業/
こんぽうざい /梱包材/
こんぽうざいりょう /梱包材料/
こんぽうだいきん /梱包代金/
こんぽうてすうりょう /梱包手数料/
こんぽうひ /梱包費/
こんぽん /根本/
こんぽんげんり /根本原理/
こんぽんてき /根本的/
こんぽんてきかいけつ /根本的解決/
こんぽんてきたいさく /根本的対策/
こんぽんてきもんだい /根本的問題/
こんま /今間;姓/，/
こんまけ /根負け/
こんめい /混迷;confuse/昏迷;[医]stupor/昆明;(Kunming) 雲南省の省都/
こんもう /根毛/懇望/
こんや /今夜/紺屋/紺谷/
こんやく /婚約/
こんやくしゃ /婚約者/
こんやくちゅう /婚約中/
こんやくはき /婚約破棄/
こんやくゆびわ /婚約指輪/
こんやくりょこう /婚約旅行/
こんやまち /紺屋町/
こんゆう /今夕/渾融/
こんよう /混用/昆陽/
こんよく /混浴/
こんらい /今来/
こんらん /混乱/
こんらんじ /混乱時/
こんらんじょうたい /混乱状態/
こんらんちゅう /混乱中/
こんりゅう /建立/根粒/根瘤/
こんりゅうほうが /建立奉加/
こんりん /金輪/
こんりんざい /金輪際/
こんりんならく /金輪奈落/
こんる /近流/
こんるり /紺瑠璃/
こんれい /婚礼/
こんろ /焜炉/
こんろん /崑崙/昆倫;?/崑崘;?/
こんわ /懇話/混和/
こんわかい /懇話会/
こんわく /困惑/
こんわくがお /困惑顔/
ご /語/後/御/誤/碁/五/期/呉/子;連濁/児;連濁/豆油/豆汁/護/悟;悟性/吾;吾人/伍;隊伍/互/娯/午;午前/后;午后(のみの慣用音)/檎;林檎/醐;醍醐味/瑚;珊瑚礁/胡;胡麻/梧;あおぎり/唔/寤;さめる/晤/牾/珸/齬;齟齬/茣;茣蓙(ゴザ)/蜈;蜈蚣(ムカデ)/忤;さからう/冴;さ・える/沍/篌/炬;(呉音)/壺;(呉音)/壷;「壺」の異体字/兒;「児」の旧字(人名用漢字)/５/5/庫;?/宕;?/
ご> /御/誤/後;後唐,後晋,後円融天皇/五/
ごーとご /ゴート語;Gothic/
ごーとぞく /ゴート族;Goth/
ごあいきょう /御愛嬌/御愛敬;=御愛嬌/ご愛嬌/ご愛敬/
ごあいこ /ご愛顧/御愛顧/
ごあいさつ /ご挨拶/御挨拶/
ごあいよう /ご愛用/御愛用/
ごあく /五悪/
ごあんしん /御安心/
ごあんない /ご案内/御案内/
ごい /語彙;vocabulary/語意;word sense/五位/五井/恋/戀;「恋」の旧字/伍井/五噫/
ごいけん /ご意見/御意見/
ごいけんなど /御意見等/
ごいけんばこ /ご意見箱/
ごいけんばん /御意見番/ご意見番/
ごいけんむよう /御意見無用/
ごいこう /御意向/
ごいこうもく /語彙項目/
ごいさぎ /五位鷺/
ごいし /碁石/
ごいすう /語彙数/
ごいそ /語彙素/
ごいぞく /御遺族/
ごいたい /御遺体/
ごいち /吾一/
ごいちじょうてんのう /後一条天皇/
ごいちどうさま /御一同様/
ごいちどく /御一読/
ごいっこう /御一行/御一考/
ごいっこうさま /御一行様/
ごいっしょ /ご一緒/御一緒/
ごいっしん /御一新/
ごいっちょう /御一聴/
ごいっぽう /御一報/
ごいてき /語彙的/
ごいのくろうど /五位の蔵人/
ごいらい /ご依頼/御依頼/
ごいりょく /語彙力/
ごいりよう /御入用/
ごいろん /語彙論;lexicology/
ごいん /誤飲/五音/後院/五韻/
ごいんかん /五員環/
ごいんきょ /御隠居/
ごいんず /五音図/
ごう /合/号/業/轟/剛;剛の者/豪;豪傑/濠;城の濠(=ほり)/壕;防空壕/郷/毫/拷/劫/強/傲;傲慢/嗷;嗷訴/敖;あそぶ/遨;≒敖/熬;≒煎/鼇;おおがめ/噛/囂;非難囂々/哈/盒;飯盒/刧;「劫」の異体字/號;「号」の旧字/軣;「轟」の異体字/
ごう> /豪;[略語]オーストラリア.-首脳,-大使/
ごうい /合意/
ごういあん /合意案/
ごういけいせい /合意形成/
ごういご /合意後/
ごういしょ /合意書/
ごういじこう /合意事項/
ごういつ /合一/
ごういてつづき /合意手続き/合意手続/
ごういてん /合意点/
ごういど /合意度/
ごういないよう /合意内容/
ごういぶんしょ /合意文書/
ごういほうしき /合意方式/
ごういん /強引/業因/
ごうう /豪雨/
ごうおん /轟音/号音/合音;[国語学]eg.あう→o/
ごうか /豪華/業火;[仏教]/劫火;[仏教]=こうか/業果;[仏教]業の報い/
ごうか> /豪華;-客船,-メンバー,-プレゼント/
ごうかあいぞうばん /豪華愛蔵版/
ごうかい /豪快/
ごうかいなべ /豪快鍋/
ごうかきゃくせん /豪華客船/
ごうかく /合格/
ごうかくいわい /合格祝/合格祝い/
ごうかくいん /合格印/
ごうかくきがん /合格祈願/
ごうかくしゃ /合格者/
ごうかくしゅくがかい /合格祝賀会/
ごうかくしょう /合格証/
ごうかくしょうしょ /合格証書/
ごうかくじ /合格時/
ごうかくつうち /合格通知/
ごうかくてん /合格点/
ごうかくはっぴょう /合格発表/
ごうかくりつ /合格率/
ごうかくりょく /合格力/
ごうかけいひん /豪華景品/
ごうかけんらん /豪華絢爛/
ごうかしょうひん /豪華賞品/
ごうかせん /豪華船/
ごうかばん /豪華版/
ごうかふろく /豪華付録/
ごうかぼん /豪華本/
ごうかれっしゃ /豪華列車/
ごうかん /号館/強姦/合歓/合巻/
ごうかんざい /強姦罪/
ごうかんじけん /強姦事件/
ごうかんない /号館内/
ごうかんま /強姦魔/
ごうがい /号外/號外;「号」旧字/
ごうがしゃ /恒河沙;10^52/
ごうがん /傲岸/
ごうがんふそん /傲岸不遜/
ごうき /号機/剛毅/豪気/豪鬼/剛気/豪毅/剛己/
ごうきぼくとつ /剛毅木訥/
ごうきゅう /号泣/剛球/強弓/
ごうきょう /剛強/
ごうきん /合金/
ごうきんせい /合金製/
ごうぎ /合議/豪気/豪儀;≒豪気/
ごうぎせい /合議制/
ごうぎたい /合議体/
ごうく /業苦/合区/業垢;[仏教]/
ごうぐら /郷倉/
ごうけ /郷家/
ごうけい /合計/豪渓/
ごうけいがく /合計額/
ごうけいきんがく /合計金額/
ごうけいじかん /合計時間/
ごうけいち /合計値/
ごうけいてん /合計点/
ごうけいてんすう /合計点数/
ごうけいとくてん /合計得点/
ごうけいほんすう /合計本数/
ごうけつ /豪傑/
ごうけつじ /豪血寺/
ごうけん /剛健/合憲/剛堅/
ごうげい /傲睨/
ごうこ /江湖/
ごうこう /毫光/
ごうこうおん /合口音/
ごうこうぞう /剛構造;[建築]変形しにくい構造/
ごうこく /合刻/号哭/
ごうこん /合コン/
ごうご /豪語/傲語/
ごうごう /囂囂/轟々/囂々/
ごうし /合祀/合資/郷士/合志;地名/郷司;姓/
ごうしがいしゃ /合資会社/
ごうしさい /合祀祭/
ごうししょう /合指症;[医]syndactyl/
ごうしつ /号室/
ごうしゃ /豪奢/郷社/号車/
ごうしゃばんごう /号車番号/
ごうしゅ /強酒/
ごうしゅう /豪州/江州;近江/
ごうしゅうさん /豪州産/
ごうしょ /劫初/
ごうしょう /豪商/号証/合焦/江商/業障/
ごうしん /剛心/
ごうじ /剛司/合字/
ごうじょう /強情/強盛;powerful/剛情;≒強情/
ごうじょっぱり /強情っ張り/
ごうすう /号数/
ごうせい /合成/剛性/豪勢/強請/合性/合生/
ごうせい> /合成;-皮革,-ゴム,-画像/
ごうせいおん /合成音/
ごうせいおんせい /合成音声/
ごうせいか /合成化/
ごうせいかがく /合成化学/
ごうせいかわ /合成革/
ごうせいかん /剛性感/
ごうせいかんすう /合成関数/
ごうせいかんみりょう /合成甘味料/
ごうせいぎょうれつ /剛性行列/
ごうせいこうそ /合成酵素;[生化学]synthetase/
ごうせいご /合成語/
ごうせいごむ /合成ゴム/
ごうせいしゃしん /合成写真/
ごうせいしゅ /合成酒/
ごうせいしょくひん /合成食品/
ごうせいじゅし /合成樹脂/
ごうせいす /合成酢/
ごうせいすう /合成数/
ごうせいせんい /合成繊維/
ごうせいせんざい /合成洗剤/
ごうせいせんりょう /合成染料/
ごうせいそうち /合成装置/
ごうせいぞくせい /合成属性/
ごうせいちゃくしょくりょう /合成着色料/
ごうせいはんのう /合成反応/
ごうせいひかく /合成皮革/
ごうせいひん /合成品/
ごうせいぶそく /剛性不足/
ごうせいぶつ /合成物/
ごうせいほう /合成法/
ごうせいほうしき /合成方式/
ごうせいほぞんりょう /合成保存料/
ごうせいまやく /合成麻薬/
ごうせいゆ /合成油/
ごうせいりつ /剛性率;[物理]ズレに対する弾性率/
ごうせいりょく /合成力/
ごうせっとう /強窃盗/
ごうせつ /豪雪/
ごうせつちいき /豪雪地域/
ごうせつちたい /豪雪地帯/
ごうせん /合繊/号線/合線/
ごうぜん /傲然;arrogantly.「-と言い放つ」/轟然;roaring.「-たる騒音」/
ごうそ /強訴/
ごうそう /豪壮/合装/
ごうそっきゅう /剛速球/
ごうそっきゅうとうしゅ /豪速球投手/
ごうぞく /豪族/
ごうた /剛太/
ごうたい /剛体/
ごうたいうんどう /剛体運動/
ごうたいぼう /剛体棒/
ごうたん /豪胆/剛胆/
ごうだ /合田/郷田/剛田/
ごうだつ /強奪/
ごうだてんのう /後宇多天皇/
ごうだん /強談/
ごうだんしょう /江談抄;大江匡房/
ごうち /郷地/碁打ち/合致/
ごうちゃく /合着/
ごうちょく /剛直/
ごうちん /轟沈/
ごうつ /江津/
ごうつくばり /業突く張り;欲張り/業突張/
ごうづ /江津/
ごうてい /豪邸/
ごうてき /号笛/豪的/強的/
ごうてんじょう /格天井/
ごうとう /強盗/号棟/鼇頭/豪宕/
ごうとうさつじん /強盗殺人/
ごうとうだん /強盗団/
ごうとうはん /強盗犯/
ごうとくじ /豪徳寺/
ごうど /神戸/
ごうどう /合同/≡/
ごうどうえんしゅう /合同演習/
ごうどうえんそうかい /合同演奏会/
ごうどうかいぎ /合同会議/
ごうどうかんけい /合同関係/
ごうどうかんそく /合同観測/
ごうどうがくしゅうかい /合同学習会/
ごうどうけんきゅうかい /合同研究会/
ごうどうこうえん /合同公演/
ごうどうこうぎょう /合同興業;[企業名]/
ごうどうし /合同誌/
ごうどうしゅせい /合同酒精/
ごうどうせい /合同性/
ごうどうせいてつ /合同製鐵;[企業名]/
ごうどうたいいくさい /合同体育祭/
ごうどうたいかい /合同大会/
ごうどうへんかん /合同変換/
ごうどうほう /合同法/
ごうどうれんしゅう /合同練習/
ごうな /寄居虫/
ごうの /郷野/
ごうのう /豪農/
ごうのうら /郷ノ浦/
ごうのもの /剛の者/
ごうはら /業腹/郷原/
ごうはん /合板/
ごうばつ /劫罰/
ごうばん /合板/
ごうひ /合否/合皮/合肥/
ごうひつ /合筆/
ごうひはんてい /合否判定/
ごうびょう /業病/
ごうびん /合瓶/
ごうふ /豪富/
ごうふく /剛腹;肝の据わった/剛愎;強情/
ごうぶち /格縁/
ごうぶん /合文/
ごうへき /剛壁/
ごうへん /合片/
ごうべん /合弁/
ごうべんか /合弁花/
ごうべんかるい /合弁花類/Gamopetalae/Sympetalae/
ごうべんがいしゃ /合弁会社/
ごうほう /合法/号砲/豪放/号俸/業報/
ごうほうか /合法化/
ごうほうせい /合法性/
ごうほうてき /合法的/
ごうほうどらっぐ /合法ドラッグ/
ごうほうらいらく /豪放磊落/
ごうほうり /合法裏/
ごうほうろん /合法論/
ごうぼう /号棒/
ごうま /降魔/業魔/格間/
ごうまい /豪邁/
ごうまつ /毫末/劫末/
ごうまん /傲慢/
ごうめ /合目/号目/
ごうめい /合名/
ごうめいがいしゃ /合名会社/
ごうも /毫も/
ごうもう /剛毛/毫毛;very few/
ごうもくてき /合目的/
ごうもくてきせい /合目的性;Zweckmassigkeit/
ごうもくてきてき /合目的的/
ごうもん /拷問/
ごうもんぐ /拷問具/
ごうゆう /豪遊/剛勇/豪勇/合有;[法]/豪雄;豪傑/遨遊/傲遊/
ごうよく /強欲/強慾;=強欲/
ごうり /合理/毫釐/
ごうりか /合理化/
ごうりかはんたい /合理化反対/
ごうりき /合力/強力/剛力/
ごうりきはん /強力犯/
ごうりしゅぎ /合理主義/
ごうりしゅぎてき /合理主義的/
ごうりせい /合理性/郷里制/
ごうりてき /合理的/
ごうりてきせつめい /合理的説明/
ごうりゃく /劫掠/
ごうりゅう /合流/
ごうりゅうし /合流子/
ごうりゅうしゃせん /合流車線/
ごうりゅうじ /合流時/
ごうりゅうせい /合流性/
ごうりゅうちてん /合流地点/
ごうりゅうちょくご /合流直後/
ごうりゅうてん /合流点/
ごうりゅうば /剛竜馬/
ごうりゅうへん /合流編/
ごうりょく /合力/
ごうりろん /合理論;rationalism/
ごうれい /号令/
ごうれいいっか /号令一下/
ごうれいしき /号令式/
ごうわん /剛腕/
ごうん /五蘊;[仏教]色・受・想・行・識/五雲;五色の雲/五運/
ごえ /越え/声/聲/肥/
ごえい /護衛/
ごえいか /御詠歌/
ごえいかん /護衛艦/
ごえいくうぼ /護衛空母/
ごえいくちくかん /護衛駆逐艦/
ごえいてん /ご栄転/御栄転/
ごえいへい /護衛兵/
ごえつ /呉越;春秋時代の呉国と越国。転じて仲の悪いこと/
ごえつどうしゅう /呉越同舟;仲の悪いもの同士が居合せること/
ごえふ /五衛府/
ごえもん /五右衛門/五衛門/
ごえもんぶろ /五右衛門風呂/
ごえん /御縁/ご縁/誤嚥;[医]飲食物等が気道に入ること/後宴/
ごえんじょ /ご援助/御援助/
ごえんだま /五円玉/
ごえんゆうてんのう /後円融天皇/
ごえんりょ /御遠慮/
ごおう /五黄;[陰陽道]/牛黄;生薬/牛王;-宝印/
ごおうほういん /牛王宝印/
ごおうぼ /ご応募/御応募/
ごおり /氷/
ごおん /語音/御恩/五音/呉音/五陰/ご恩/
ごおんおんかい /五音音階/
ごおんこ /ご恩顧/御恩顧/
ごおんじょうく /五陰盛苦/
ごおんめいりょうど /語音明瞭度/
ごか /五加;うこぎ/五箇;地名/五霞;地名,茨城県/
ごかい /誤解/五戒;[仏教]不殺生・不偸盗・不邪淫・不妄語・不飲酒/碁会/碁界/五回/五階/5階/
ごかいしょ /碁会所/
ごかいじょ /碁会所/
ごかいせつ /御解説/
ごかいそう /ご会葬/御会葬/
ごかいちょう /御開帳/
ごかいとう /ご回答/御回答/
ごかいどう /五街道/
ごかく /互角;even/五角;pentagon/牛角;「互角」の本来の表記/互格;?/
ごかくけい /五角形/
ごかくにん /ご確認/御確認/
ごかご /御加護/
ごかしょう /五個荘/
ごかしわばらてんのう /後柏原天皇/
ごかじょう /五カ条/
ごかせ /五ヶ瀬/
ごかぞく /ご家族/御家族/
ごかっけい /五角形/
ごかって /御勝手/
ごかつやく /ご活躍/御活躍/
ごかつよう /御活用/
ごかてい /ご家庭/御家庭/
ごかひ /五加皮/
ごかぼう /五家宝/
ごかめやまてんのう /後亀山天皇/
ごかやま /五箇山;富山. 合掌造りの民家で知られる/
ごかん /互換/五感/語感;nuance/語幹;[文法]stem/後漢;中国の王朝(25-220)/語間/五官;五感に対応する感覚器官/
ごかんいがい /五感以外/
ごかんおう /五冠王/
ごかんき /互換機/
ごかんきしゅ /互換機種/
ごかんきじょう /互換機上/
ごかんきよう /互換機用/
ごかんしょ /後漢書/
ごかんしん /御関心/
ごかんじょ /ご寛恕/御寛恕/後漢書/
ごかんせい /互換性/
ごかんそう /ご感想/御感想/
ごかんど /互換度/
ごかんひょう /互換表/
ごかんひん /互換品/
ごかんべん /御勘弁/
ごかんまつ /語幹末/
ごかんよう /ご寛容/御寛容/
ごがく /語学/五岳;中国の五霊山。泰山,衡山,華山,恒山,嵩山/
ごがくかもく /語学科目/
ごがくがくしゅうよう /語学学習用/
ごがくがっこう /語学学校/
ごがくくんれん /語学訓練/
ごがくけい /語学系/
ごがくこうざ /語学講座/
ごがくさんこうしょ /語学参考書/
ごがくしんしょ /語学新書/
ごがくてき /語学的/
ごがくよう /語学用/
ごがくりょく /語学力/
ごがつ /五月/５月/5月/皐月;※連想,旧暦/
ごがつかくめい /五月革命/
ごがつさい /五月祭/
ごがつびょう /五月病/
ごがん /護岸/
ごがんこうじ /護岸工事/
ごき /誤記/語気/御忌/御器/語基/呉器/
ごきおく /御記憶/
ごきかぶり /御器噛/
ごきげん /ご機嫌/御機嫌/
ごきげんうかがい /御機嫌伺い/
ごきげんななめ /ご機嫌斜め/御機嫌斜め/
ごきげんよう /御機嫌よう/
ごきしちどう /五畿七道;地名/
ごきそ /御器所/
ごきたい /ご期待/御期待/
ごきにゅう /ご記入/御記入/
ごきぼう /ご希望/御希望/
ごきゃく /五脚/
ごきゅう /御給/誤球/
ごきゅうけい /御休憩/
ごきょう /五橋/五経/
ごきょうさん /御協賛/
ごきょうじ /ご教示/御教示/
ごきょうじゅ /御教授;※「御教授下さい」は「御教示下さい」の誤りか/
ごきょうだい /御兄弟/
ごきょうどう /後教導/
ごきょうみ /御興味/
ごきょうりょく /ご協力/御協力/
ごきょうろん /護教論/
ごきょか /御許可/
ごきんじょ /ご近所/御近所/
ごぎ /語義/
ごぎてき /語義的/
ごぎゃく /五逆;[仏教]五つのタブー/
ごぎゃくざい /五逆罪/
ごぎゅう /呉牛;-月に喘ぐ (取越し苦労)/
ごぎょう /五行/御形/
ごぎょうせつ /五行説/
ごぎろん /御議論/
ごく /語句/極/獄/五区/国/石/
ごくあく /極悪/
ごくあくだい /極悪台/
ごくあくどうめい /極悪同盟/
ごくあくにん /極悪人/
ごくあくひどう /極悪非道/
ごくい /極意/獄衣/
ごくいちぶ /極一部/
ごくいん /極印/
ごくう /悟空/御供/
ごくかいせつ /語句解説/
ごくかん /極寒/
ごくけい /極刑/
ごくげつ /極月/
ごくごく /極々/
ごくごく> /極極/極々/
ごくさい /極彩/
ごくさいしき /極彩色/
ごくさむ /極寒/
ごくし /獄死/
ごくしゃ /獄舎/
ごくしゅう /獄囚/極宗/
ごくしょ /極暑/
ごくしょう /極小/
ごくしょうすう /極少数/極小数;?/
ごくしょうりょう /極少量/極小量/
ごくしょき /極初期/
ごくしん /極信/
ごくじょう /極上/
ごくじょうひん /極上品/
ごくせつめい /語句説明/
ごくそう /獄窓/
ごくそく /極促/獄則/
ごくそつ /獄卒/
ごくちゅう /獄中/
ごくつぶし /穀潰し/
ごくていおん /極低温/
ごくていおんそうち /極低温装置/
ごくていおんれいきゃく /極低温冷却/
ごくていそく /極低速/
ごくていそくじ /極低速時/
ごくどう /極道/
ごくどうし /極道史/
ごくない /獄内/
ごくひ /極秘/
ごくひしりょう /極秘資料/
ごくひじこう /極秘事項/
ごくひじっけん /極秘実験/
ごくひじょうほう /極秘情報/
ごくひり /極秘裏/極秘裡/
ごくひん /極貧/
ごくび /極微/
ごくびしょう /極微小/
ごくふつう /極普通/
ごくぶと /極太/
ごくぼそ /極細/
ごくぼそびき /極細挽き/
ごくもん /獄門/
ごくもんだけ /獄門岳/
ごくもんとう /獄門島/
ごくや /獄屋/
ごくやす /極安/
ごくらく /極楽/
ごくらくじ /極楽寺/
ごくらくじょうど /極楽浄土/
ごくらくちょう /極楽鳥/
ごくらくとんぼ /極楽蜻蛉/
ごくり /獄吏/
ごくろう /ご苦労/御苦労/
ごくろうさま /御苦労様/ご苦労さま/
ごぐん /語群/
ごけ /後家/碁笥/
ごけい /互恵/語形/五刑/
ごけいかんぜい /互恵関税/
ごけいけん /御経験/
ごけいせい /互恵性/
ごけいてき /互恵的/
ごけた /五桁/
ごけだおし /後家倒し/
ごけっこん /ご結婚/御結婚/
ごけっせき /ご欠席/御欠席/
ごけつ /五傑/
ごけにん /御家人/
ごけん /護憲/
ごけんきゅう /御研究/
ごけんこう /御健康/
ごけんしゅつ /誤検出/
ごけんしょう /ご健勝/御健勝/
ごけんそん /御謙遜/
ごけんとう /ご検討/御検討/御健闘/
ごけんは /護憲派/
ごけんれんごう /護憲連合/
ごげん /語源/御見/五弦/語原;=語源/五絃/五眼/御監/
ごげんがく /語源学;etymology/
ごげんせつ /語源説/
ごげんてき /語源的/
ごげんどおり /語源通り/
ごげんもじ /御見文字/
ごこ /五胡/5個/
ごこう /後光/五香/五光;[花札]/五劫;-思惟/五更/
ごこうい /ご好意/ご厚意/御好意/御厚意/
ごこうえん /御講演/
ごこうぎ /ご厚誼/御厚誼/ご高誼/御高誼/
ごこうごみん /五公五民/
ごこうし /ご厚志/御厚志/
ごこうしゆい /五劫思惟;[仏教]/
ごこうしょう /ご高承/
ごこうじょう /ご厚情/御厚情/
ごこうせい /語構成/
ごこうにゅう /御購入/
ごこうはい /ご高配/御高配/
ごこうみょうてんのう /後光明天皇/
ごこうらん /ご高覧/御高覧/
ごこうりょ /御考慮/
ごこく /五穀/護国/後刻/
ごこくじ /護国寺/
ごこくじんじゃ /護国神社/
ごこくほうじょう /五穀豊穣/
ごこじゅうろっこく /五胡十六国/
ごこち /心地/
ごころ /心/
ごこん /語根;[言語]root/五根;[仏教]眼・耳・鼻・舌・身／信・勤・念・定・慧/
ごこんじょう /ご懇情/御懇情/
ごご /午後/午后/語々/語語/
ごご#じ /午後#0時/午後#1時/午後#2時/
ごご#じはん /午後#0時半/
ごご> /午後/
ごごう /五合/
ごごうめ /五合目/
ごごち /心地;?/
ごごはんきゅう /午後半休/
ごごびん /午後便/
ごごん /五言/
ごごんこし /五言古詩;[文学]五字で句数無制限の漢詩/
ごごんぜっく /五言絶句/
ごごんりっし /五言律詩;[文学]七字八句の漢詩/
ごさ /誤差/
ごさい /後妻/五彩/五菜/五歳/
ごさいてんのう /後西天皇/
ごさかいせき /誤差解析/
ごさかくさんほう /誤差拡散法/
ごさかんすう /誤差関数/
ごさがてんのう /後嵯峨天皇/
ごさぎゃくでんぱん /誤差逆伝搬/
ごさく /吾作/
ごさくらまちてんのう /後桜町天皇/
ごさこう /誤差項/
ごさしゅう /御査収/
ごさしんごう /誤差信号/
ごさじょうほう /誤差情報/
ごさた /御沙汰;厳しい-/
ごさつ /誤殺/
ごさとくせい /誤差特性/
ごさどう /誤作動/
ごさはんい /誤差範囲/
ごさひょうか /誤差評価/
ごさぼう /誤差棒/
ごさよういん /誤差要因/
ごさん /誤算/午餐/
ごさんか /ご参加/御参加/
ごさんかい /午餐会;luncheon/
ごさんかた /御三方/
ごさんけ /御三家/
ごさんこう /御参考/
ごさんしゅう /御参集/
ごさんしょう /御参照/
ごさんじょうてんのう /後三条天皇/
ごさんどう /ご賛同/御賛同/
ごさんれつ /ご参列/御参列/
ござ /蓙/茣蓙/御座/後座/
ございしょ /御在所/
ござそうろう /御座候/
ごし /五指/腰/五子/呉子/語史;コトバの歴史/語誌;≒語史/語詞;word/越し/
ごしあい /五試合/
ごしえん /ご支援/御支援/
ごしき /五色/
ごしじ /御指示/
ごしそく /ご子息/
ごしちご /五七五/
ごしちちょう /五七調/
ごしっくしょうせつ /ゴシック小説;Gothic novel/
ごしっくたい /ゴシック体/
ごしっくようしき /ゴシック様式/
ごしつぎ /御質疑/
ごしつもん /ご質問/御質問/
ごしつもんなど /御質問等/
ごしてい /御指定/
ごしてき /ご指摘/御指摘/
ごしどう /ご指導/御指導/
ごしなん /御指南/
ごしま /五島/
ごしめい /御指名/
ごしゃ /誤射/誤写/
ごしゃく /語釈/五爵;[公侯伯子男]爵/
ごしゅ /五種/御酒/語種;和語・漢語・洋語/
ごしゅいんせん /御朱印船/
ごしゅう /互酬/後周;[中国史]こうしゅう/
ごしゅういしゅう /後拾遺集/
ごしゅういわかしゅう /後拾遺和歌集/
ごしゅうぎ /御祝儀/ご祝儀/
ごしゅうぎぶくろ /ご祝儀袋/御祝儀袋/
ごしゅうしょうさま /御愁傷様/
ごしゅうしん /ご執心/御執心/
ごしゅうせい /互酬性;reciprocity. 「ポトラッチの-」/
ごしゅうち /御周知/
ごしゅうにん /ご就任/御就任/
ごしゅうめ /五週目/
ごしゅきょうぎ /五種競技/
ごしゅこう /御趣向/
ごしゅし /御主旨/
ごしゅじん /ご主人/御主人/
ごしゅちょう /御主張/
ごしゅっしん /御出身/
ごしゅっせき /ご出席/御出席/
ごしゅつえん /御出演/
ごしゅみ /御趣味/
ごしゅるい /五種類/
ごしゅん /呉春/
ごしょ /御所/五所/
ごしょいずみ /御所泉/
ごしょう /後生/誤称/五障;[仏教]/五章/
ごしょうかい /ご紹介/御紹介/ご照会/御照会/
ごしょうきょ /誤消去/
ごしょうたい /ご招待/御招待/
ごしょうだいじ /後生大事/
ごしょうだく /御承諾/
ごしょうち /ご承知/御承知/
ごしょうのう /御笑納/
ごしょうみ /御賞味/
ごしょうらん /御笑覧/
ごしょがわら /五所川原/
ごしょがわらえき /五所川原駅/
ごしょく /五色/誤植/
ごしょくじ /御食事;「おしょくじ」？/
ごしょぐるま /御所車/
ごしょぞく /御所属/
ごしょの /御所野/
ごしょのうら /御所浦/
ごしょまと /御所的/
ごしょめい /御署名/
ごしょもう /御所望/
ごしょらくがん /御所落雁/
ごしよう /ご使用/御使用/誤使用/
ごしらかわてんのう /後白河天皇/
ごしん /護身/誤診;misdiagnose/誤審;misjudge/誤信;fallacy/
ごしんえい /御真影/
ごしんじゅつ /護身術/
ごしんせつ /御親切/
ごしんせん /五新線/
ごしんぞ /御新造/
ごしんぞう /御新造/
ごしんたい /御神体/
ごしんたく /ご神託/御神託/
ごしんとう /御神灯/
ごしんぱい /ご心配/御心配/
ごしんぷ /御親父/
ごしんぼく /御神木/
ごしんもじ /御心文字/御親文字/
ごじ /誤字/護持/五時/五次/５時/5時/
ごじあい /ご自愛/御自愛/
ごじさん /ご持参/
ごじしん /御自身/
ごじせい /ご時世/御時世/
ごじたく /御自宅/
ごじだつじ /誤字脱字/
ごじだつじとう /誤字脱字等/
ごじだつじなど /誤字脱字等/
ごじっぽ /五十歩/
ごじっぽひゃっぽ /五十歩百歩/
ごじつ /後日/
ごじつたん /後日譚/
ごじつだん /後日談/
ごじつちゅう /後日注/
ごじつものがたり /後日物語/
ごじてん /語辞典/
ごじひ /御慈悲/ご慈悲/
ごじぶん /御自分/
ごじまん /御自慢/
ごじみゃく /五次脈/
ごじゅう /五重/五十/
ごじゅうえんだま /五十円玉/
ごじゅうおくねん /五十億年/
ごじゅうおん /五十音/
ごじゅうおんじゅん /五十音順/
ごじゅうおんず /五十音図/
ごじゅうおんひょう /五十音表/
ごじゅうかた /五十肩/
ごじゅうから /五十雀/
ごじゅうさんつぎ /五十三次/
ごじゅうしょ /ご住所/御住所/
ごじゅうしょう /五重唱/
ごじゅうそう /五重奏/
ごじゅうにんまち /五十人町/
ごじゅうねん /五十年/
ごじゅうのとう /五重塔/
ごじゅっぽ /五十歩/
ごじゅっぽひゃっぽ /五十歩百歩/
ごじゅつ /後述/
ごじゅん /語順/
ごじゅんせつ /五旬節/
ごじゅんび /御準備/
ごじゆう /御自由/
ごじょ /互助/語序/互除;-法/
ごじょう /五条/五條/五常/互譲/誤乗/
ごじょうえき /五条駅/
ごじょうざか /五条坂/
ごじょうしゃ /誤乗車/
ごじょうだん /御冗談/
ごじょうめ /五城目/
ごじょかい /互助会/
ごじょくあくせ /五濁悪世/
ごじょげん /御助言/
ごじょほう /互除法/
ごじょりょく /御助力/
ごじる /呉汁/豆汁/
ごじん /御仁;お方/吾人;我々/五塵/
ごじんか /御神火/
ごじんたい /御神体/
ごじんりょく /御尽力/
ごす /呉須/
ごすい /午睡/五衰/
ごすいさつ /御推察/
ごすいしょう /御推奨/
ごすいせん /御推薦/
ごすいもじ /御推文字/
ごすう /語数/
ごすけ /吾助/
ごすざくてんのう /後朱雀天皇/
ごすん /五寸/
ごすんくぎ /五寸釘/
ごすんつぼね /五寸局/
ごすんもよう /五寸模様/
ごず /牛頭/
ごずいい /御随意/
ごずみ /後炭/
ごずめず /牛頭馬頭/
ごせ /御所/後世/
ごせい /互生/悟性/後世/碁聖/五星/五声/語勢/五聖/五清/五牲/
ごせいうん /ご盛運/御盛運/
ごせいえい /ご清栄/御清栄/御盛栄/
ごせいえん /御声援/
ごせいがいねん /悟性概念/
ごせいきゅう /ご請求/御請求/
ごせいぎょう /ご盛業/御盛業/
ごせいこう /御成功/
ごせいこうき /五星紅旗;中国の国旗/
ごせいこん /御成婚/
ごせいこんきねん /御成婚記念/
ごせいしょう /ご清祥/御清祥/ご清勝/御清勝/
ごせいたん /御生誕/
ごせいどうどう /五世同堂/
ごせいばいしきもく /御成敗式目/
ごせいほう /後世方/
ごせいほうか /後世方家/
ごせいようじょ /互生葉序/
ごせいらん /御清覧/
ごせっけ /五摂家/
ごせつぞく /誤接続/
ごせつめい /御説明/
ごせん /互選/五泉/五線/五千/
ごせんえん /五千円/
ごせんえんさつ /五千円札/
ごせんし /五線紙/
ごせんしゅう /後撰集/
ごせんぞ /ご先祖/御先祖/
ごせんたく /御宣託/
ごせんふ /五線譜/
ごせんもん /御専門/
ごぜ /瞽女/
ごぜん /午前/御前;-会議/御膳;おせち-/
ごぜん#じ /午前#1時/午前#0時/午前#2時/
ごぜん> /午前/
ごぜんかいぎ /御前会議/
ごぜんげんざい /午前現在/
ごぜんさま /午前様/
ごぜんじあい /御前試合/
ごぜんちゅう /午前中/
ごぜんはつ /午前発/
ごぜんはんきゅう /午前半休/
ごぜんびん /午前便/
ごぜんぶ /午前部/
ごぜんやま /御前山/
ごそ /語素;[言語]lexeme/
ごそう /護送/互層;[地質]laminate/五艘/誤想/
ごそうさ /誤操作/
ごそうしゃ /護送車/
ごそうせんだん /護送船団/
ごそうぞう /御想像/
ごそうだん /ご相談/御相談/
ごそうにゅう /誤挿入/
ごそうふ /ご送付/御送付/
ごそうぼうえい /誤想防衛/
ごそくもじ /御息文字/
ごそくろう /ご足労/御足労/
ごそつぎょう /御卒業/
ごそんがん /御尊顔/
ごそんじ /御存じ/
ごそんぷ /御尊父/
ごそんぷさま /御尊父様/
ごぞう /五臓/
ごぞうろっぷ /五臓六腑/
ごぞく /語族/五族/
ごぞんじ /ご存知/ご存じ/御存知/御存じ/
ごぞんち /御存知/
ごたい /五体/
ごたいおう /御対応/
ごたいそう /ご大層/御大層/
ごたいとうち /五体投地/
ごたいまんぞく /五体満足/
ごたいめん /御対面/
ごたいりく /五大陸/
ごたえ /応え/
ごたく /御託/五択/
ごたくせん /御託宣/ご託宣/
ごたしょう /ご多祥/御多祥/
ごたぶん /ご多分;-に漏れず/御多分/
ごたぼう /ご多忙/御多忙/
ごたぼうちゅう /御多忙中/
ごたま /五玉/
ごたようちゅう /ご多用中/御多用中/
ごたろう /五太郎/
ごたん /五反/
ごたんい /語単位/
ごたんだ /五反田/
ごたんだえき /五反田駅/
ごたんとう /御担当/五炭糖;[化学]pentose. C5H10O5/
ごだい /五代/五大/伍代/
ごだいこ /五大湖/
ごだいご /後醍醐/
ごだいごてんのう /後醍醐天皇/
ごだいさん /五台山/
ごだいし /五代史;新五代史と旧五代史/
ごだいしゅう /五大州/
ごだいじっこく /五代十国;[中国史]/
ごだいどう /五大堂/
ごだつ /誤脱/
ごだん /五段/後段/誤断/
ごだんかい /五段階/
ごだんかつよう /五段活用/
ごち /五智/
ごちそう /ご馳走/御馳走/
ごちそうさま /ご馳走様/ご馳走さま/御馳走様/ごちそう様/御馳走さま/
ごちゃく /御着/五着/
ごちゅう /語中/語注/語註/
ごちゅうい /ご注意/御注意/
ごちゅうこく /御忠告/
ごちゅうもく /御注目/
ごちゅうもん /ご注文/御注文/
ごちょう /語調/伍長/語長/
ごちょうせい /誤調整/
ごっかん /極寒/極官/
ごったに /ごった煮/
ごって /毎/
ごっぽう /業報/
ごつうか /誤通過/
ごつうち /ご通知/御通知/
ごつごう /ご都合/御都合/
ごつごうしゅぎ /御都合主義/ご都合主義/
ごつちみかどてんのう /後土御門天皇/
ごつぼ /五坪/
ごづめづ /牛頭馬頭/
ごて /後手/鏝/
ごてい /五帝/五鼎;-に食らわずんば-に烹られん/
ごていあん /御提案/
ごていきょう /御提供/
ごていしゅ /御亭主/
ごていしゅつ /御提出/
ごていじ /御提示/
ごていせい /御訂正/
ごていねい /ご丁寧/御丁寧/
ごてがち /後手勝/
ごてごて /後手後手/
ごてばん /後手番/
ごてひっしょう /後手必勝/
ごてゆうり /後手有利/
ごてん /御殿/
ごてんい /御典医/御殿医;=御典医/
ごてんした /御殿下/
ごてんば /御殿場/
ごてんばせん /御殿場線/
ごてんばほうめん /御殿場方面/
ごてんやま /御殿山/
ごでん /誤伝/
ごでんじゅ /御伝授/
ごと /毎/事/言/五斗/如/琴/亊/
ごとう /誤答/後藤/五島/語頭/五嶋/五頭/後唐;[中国史]こうとう/呉島/
ごとうごう /誤統合/
ごとうしゃく /五等爵;公爵・侯爵・伯爵・子爵・男爵/
ごとうしょ /御当所/
ごとうじ /後藤寺/
ごとうじょう /御登場/
ごとうすう /誤答数/
ごとうち /御当地/
ごとうちゃく /ご到着/御到着/
ごとうてん /後藤点/
ごとうれっとう /五島列島/
ごとうろく /誤登録/
ごとうろん /御討論/
ごとおび /五十日;日にちの末尾に五、十が付く日。支払日にあたる/
ごとく /五徳/悟得/
ごとし /如し/ゴト師;イカサマ師/
ごとに /毎に/
ごとばてんのう /後鳥羽天皇/
ごど /五度/
ごどう /悟道/
ごどうさ /誤動作/
ごどうはい /御同輩/
ごどうはん /御同伴/
ごどうやく /御同役/
ごどく /誤読/
ごないぎ /御内儀;おかみさん/
ごないしょ /御内書/
ごならてんのう /後奈良天皇/
ごなん /御難/
ごにじょうてんのう /後二条天皇/
ごにゅう /五入/悟入/
ごにゅうかい /御入会/
ごにゅうきん /ご入金/
ごにゅうじょう /御入場/
ごにゅうりょく /誤入力/
ごにん /誤認/五人/5人/
ごにんぐみ /五人組;[日本史]/
ごにんしき /誤認識/
ごにんたいほ /誤認逮捕/
ごにんばやし /五人囃子/
ごねどく /ごね得/ゴネ得/
ごねん /御念/五年/
ごねんかん /五年間/
ごねんせい /五年生/
ごねんめ /五年目/
ごのう /御悩/
ごのうせん /五能線/
ごのへ /五戸/
ごのみ /好み/
ごは /語派/
ごはい /誤配/向拝/御拝/
ごはいさつ /御拝察/
ごはいりょ /ご配慮/御配慮/
ごはさん /ご破算/御破算/
ごはっこう /誤発行/
ごはっちゅう /御発注/
ごはってん /ご発展/御発展/
ごはっと /御法度/ご法度/
ごはっぴょう /御発表/
ごはつげん /御発言/
ごはなぞのてんのう /後花園天皇/
ごはん /御飯/ご飯/誤判;misjudge/御判;はんこ/
ごはんえい /ご繁栄/御繁栄/
ごはんじょう /ご繁盛/御繁盛/
ごはんだん /御判断;your decision/誤判断;misjudge/
ごはんつぶ /御飯粒/
ごはんてい /誤判定/
ごば /後場/
ごばく /誤爆/
ごばらい /後払い/
ごばん /碁盤/五番/
ごばんがい /五番街/
ごばんしょうぶ /五番勝負/
ごばんめ /碁盤目;grid/五番目/
ごばんわり /碁盤割り/
ごひき /五匹/
ごひつ /五筆/
ごひはん /御批判/
ごひひょう /御批評/
ごひゃく /五百/
ごひゃくえんだま /五百円玉/
ごひゃくまんごく /五百万石/
ごひゃくらかん /五百羅漢/
ごひょうき /誤表記/
ごひょうじ /誤表示/
ごび /語尾/
ごびへんか /語尾変化/
ごびゅう /誤謬/
ごびょう /御廟/
ごふ /護符/後夫/五府;[律令制]五衛府/
ごふう /碁風/
ごふうじゅうう /五風十雨/
ごふうふ /御夫婦/
ごふかくさてんのう /後深草天皇/
ごふく /呉服/五福/
ごふくや /呉服屋/
ごふこう /御不幸/
ごふさい /御夫妻/
ごふざい /御不在/
ごふしみてんのう /後伏見天皇/
ごふじょう /御不浄/
ごふじん /御婦人/御夫人/
ごふたん /御負担/
ごふない /御府内/
ごふべん /御不便/
ごふまん /御不満/
ごふめい /御不明/
ごふん /胡粉/五分/
ごふんかん /五分間/
ごぶ /五分/五部/
ごぶがゆ /五分粥/
ごぶがり /五分刈り/
ごぶごぶ /五分五分/
ごぶさた /ご無沙汰/御無沙汰/
ごぶじ /御無事/
ごぶつ /御物;モノ/五仏/
ごぶつぜん /御仏前/
ごぶらんおり /ゴブラン織;gobelins/
ごぶれい /御無礼/
ごぶん /誤聞/五分/
ごへい /語弊/御幣/
ごへん /互変/
ごへんかん /誤変換/
ごへんきゃく /御返却/
ごへんこう /御変更/
ごへんじ /ご返事/御返事/
ごへんそう /ご返送/御返送/
ごへんとう /御返答/
ごべん /五弁/
ごべんたつ /御鞭撻/
ごほう /語法/誤報/御報/護法/午砲/
ごほうこく /ご報告/御報告/
ごほうし /ご奉仕/御奉仕/ご芳志/御芳志/
ごほうじ /御法事/
ごほうじん /護法神;[仏教]/
ごほうぜん /御宝前/
ごほうどう /誤報道/
ごほうねん /ご放念/御放念/
ごほうび /ご褒美/御褒美/
ごほうめい /ご芳名/御芳名/
ごほく /吾北/
ごほりかわてんのう /後堀河天皇/
ごほん /御本/
ごほんぎ /五本木/
ごほんけ /御本家/
ごほんぞん /御本尊/
ごほんにん /御本人/
ごほんゆび /五本指/
ごほんらい /語本来/
ごぼいん /五母音/
ごぼう /御坊/牛蒡/
ごぼうせい /五芒星/
ごぼどう /御母堂/
ごま /胡麻/護摩/駒/独楽/
ごまあえ /胡麻和え/
ごまあぶら /胡麻油/ごま油/ゴマ油/
ごまあん /胡麻餡/
ごまがら /胡麻殻/
ごましお /胡麻塩/
ごましおあたま /胡麻塩頭;白髪混じり/
ごますり /胡麻擂り;apple-polisher/
ごまだけ /胡麻竹/
ごまだれ /胡麻垂れ/
ごまつ /語末/
ごまどう /護摩堂/
ごまどうふ /胡麻豆腐/
ごまどうらん /胡麻胴乱;「ごまかす」の語源になったお菓子/
ごまのはい /護摩の灰;旅人狙いの泥棒/
ごまのはぐさか /ゴマノハグサ科/Scrophulariaceae/
ごまのはぐさもく /Personales/ゴマノハグサ目/
ごまふあざらし /胡麻斑海豹/
ごまみそ /胡麻味噌/
ごまよごし /胡麻汚し;胡麻和え/
ごまん /五万/
ごまんえつ /御満悦/
ごまんきつ /御満喫/
ごまんにん /五万人/
ごみ /塵;rubbish/五味;甘辛苦酸塩/芥;rubbish/塵芥;rubbish(じんかい)/護美;rubbish,忌み字/埖;rubbish,また地名/込;(連濁)/
ごみあくた /塵芥;ゴミ、値打のないもの/
ごみおか /五味岡/
ごみしょり /ゴミ処理/
ごみすて /ゴミ捨て/
ごみすてば /ゴミ捨て場/
ごみずのおてんのう /後水尾天皇/
ごみだし /ゴミ出し/
ごみはつでん /ごみ発電/
ごみばこ /ゴミ箱/
ごみひろい /ゴミ拾い/
ごみぶくろ /ゴミ袋/
ごみぶん /御身分/
ごみむし /歩行虫/
ごみゃく /語脈/
ごみや /五味屋/
ごみょう /五明/
ごみんかん /護民官/
ごむ /護謨/
ごむいた /ゴム板/
ごむいん /ゴム印/
ごむかん /ゴム管;rubber tube/
ごむぐつ /ゴム靴;rubber shoes/
ごむこうぎょう /ゴム工業/
ごむしょくぶつ /ゴム植物;ゴムの木/
ごむじょう /ゴム状/
ごむせい /ゴム製/
ごむせいひん /ゴム製品/
ごむぞうり /ゴム草履;flip-flops/
ごむぞこ /ゴム底;rubber sole/
ごむたい /御無体/
ごむだん /ゴム弾/
ごむてぶくろ /ゴム手袋/
ごむとび /ゴム跳び/
ごむなが /ゴム長/
ごむのき /ゴムの木/
ごむのり /ゴム糊;gum/
ごむひも /ゴム紐;elastic cord/
ごむふうせん /ゴム風船/
ごむまり /ゴム毬/
ごむよう /御無用/
ごむらかみてんのう /後村上天皇/
ごめ /込/米/
ごめい /五明/五名/
ごめいさつ /ご明察/御明察/
ごめいとう /御名答/
ごめいふく /御冥福/ご冥福/
ごめいわく /ご迷惑/御迷惑/
ごめん /御免/
ごめんください /御免下さい/
ごめんこうむる /蒙御免/
ごめんどう /御面倒/
ごめんなさい /御免なさい/
ごもく /五目/
ごもくそば /五目蕎麦/
ごもくならべ /五目並べ/
ごもくめし /五目飯/
ごもじ /五文字/
ごもち /御物;モノ/
ごもっとも /御尤も;御説-/
ごもつ /御物/
ごももぞのてんのう /後桃園天皇/
ごもるてがか /ゴモルテガ科/Gomortegaceae/
ごもん /御門/御紋/五門/
ごもんぜき /御門跡/
ごや /小屋/後夜;⇔初夜/五夜/午夜;AM0/
ごやく /誤訳;mistranslation/語訳;(複合用途) フランス-/
ごやくせいしょ /語訳聖書/
ごゆ /御油/
ごゆうじん /御友人/
ごゆうどう /誤誘導/
ごゆうよ /御猶予/
ごよう /御用;affair/誤用;abuse/ご用/五葉/
ごようい /御用意/
ごようおさめ /御用納め/
ごようがくしゃ /御用学者/
ごようきき /御用聞き/御用聞/
ごようきゅう /御要求/
ごようきん /御用金/
ごようけんせつ /五洋建設;[企業名]/
ごようしゃ /ご容赦/御容赦/
ごようしょうにん /御用商人/
ごようしんぶん /御用新聞/
ごようじん /御用心/
ごようす /御様子/
ごようぜいてんのう /後陽成天皇/
ごようたし /御用達/
ごようたつ /御用達/
ごようだつ /御用達/
ごようちょう /御用帳/
ごようぢょうちん /御用提灯/
ごようてい /御用邸/
ごようはじめ /御用始め/
ごようぼう /ご要望/御要望/
ごようまつ /五葉松/
ごようめい /ご用命/御用命/
ごようろん /語用論/
ごよく /五欲/
ごよさん /ご予算/
ごよてい /御予定/
ごよやく /御予約/
ごらいこう /御来光/ご来光/
ごらいごう /御来迎/
ごらいじょう /ご来場/御来場/
ごらいてん /ご来店/御来店/
ごらいりん /ご来臨/御来臨/
ごらく /娯楽/
ごらくえいが /娯楽映画/
ごらくさく /娯楽作/
ごらくさくひん /娯楽作品/
ごらくしせつ /娯楽施設/
ごらくしつ /娯楽室/
ごらくじだいげき /娯楽時代劇/
ごらくせい /娯楽性/
ごらくたいさく /娯楽大作/
ごらくてき /娯楽的/
ごらくばんぐみ /娯楽番組/
ごらくひ /娯楽費/
ごらくぼん /娯楽本/
ごらくよう /娯楽用/
ごらん /ご覧/御覧/
ごり /鮴/石伏魚/
ごりおし /ごり押し/ゴリ押し/
ごりかい /ご理解/御理解/
ごりしょう /御利生/
ごりっぱ /ご立派/御立派/
ごりっぷく /ご立腹/
ごりむちゅう /五里霧中/
ごりやく /御利益/ご利益/
ごりゅう /五竜/
ごりゅうい /御留意/
ごりゅうせい /ご隆盛/御隆盛/
ごりょう /御陵;皇族の墓/御領;domain/御料;貴人(のもの)/御霊;-信仰/後梁;[中国史]こうりょう/御寮;貴人(の子女)/
ごりょうかい /御了解/
ごりょうかく /五稜郭/
ごりょうけ /御両家/
ごりょうしゃ /御料車/
ごりょうしょう /ご了承/御了承/
ごりょうしん /ご両親/御両親/
ごりょうち /御料地/
ごりょうにん /御両人/御寮人/
ごりょうば /御猟場;宮内庁猟場/
ごりょうぼくじょう /御料牧場/
ごりょうめい /御両名/
ごりょこう /御旅行/
ごりよう /ご利用/御利用/
ごりん /五輪/五厘/五倫/
ごりんかいさい /五輪開催/
ごりんき /五輪旗/
ごりんさんか /五輪参加/
ごりんだいひょう /五輪代表/
ごりんのしょ /五輪書;宮本武蔵著/
ごりんよせん /五輪予選/
ごるい /語類/
ごるふじょう /ゴルフ場/
ごれい /語例;example of words/誤例;wrong example/
ごれいぜいてんのう /後冷泉天皇/
ごれいぜん /御霊前/
ごれんらく /ご連絡/御連絡/
ごろ /語呂/頃/
ごろー /ＧＯＲＯ/
ごろあわせ /語呂合わせ/語呂合せ/
ごろう /五郎/悟郎/悟朗/伍朗/ＧＯＲＯ/
ごろうじん /御老人/
ごろうまる /五郎丸/
ごろく /語録/五六/
ごろね /ごろ寝/ゴロ寝/
ごろはち /五郎八/
ごろべえ /五郎兵衛/
ごろも /衣/
ごわり /五割/
ごん /言/権/厳/艮;[八卦]陽陰陰/勤;勤行/魂/諢/金/嚴;「厳」の旧字(人名用漢字)/權;「権」の旧字/
ごんか /言下/
ごんきょう /権教;[仏教]方便としての教え/
ごんぎょう /勤行/
ごんく /言句/
ごんくーるしょう /ゴンクール賞;le Prix Gouncourt/
ごんぐ /欣求/
ごんぐじょうど /欣求浄土/
ごんげ /権化/
ごんげん /権現/
ごんげんづくり /権現造り;[建築]/権現造;[建築]/
ごんご /言語/
ごんごどうだん /言語道断/言語道斷;「断」旧字/
ごんじゃ /権者/
ごんじょう /言上/
ごんずい /権瑞/
ごんぞう /権造/
ごんだ /権田/
ごんてき /権的/
ごんどう /権藤/
ごんどうくじら /巨頭鯨/
ごんのそち /権帥;[律令制]太宰府長官/
ごんべえ /権兵衛/
ごんべん /言偏/
ごんりょう /艮陵/
さ /差/左;ひだり/佐;大佐/鎖;閉鎖/瑣;煩瑣/砂;砂金/沙;沙漠/紗;袱紗/裟;大袈裟/莎;はますげ/娑;娑羅双樹/嵯;嵯峨/嵳;「嵯」の異体字/磋;切磋琢磨/蹉;蹉跌/搓;(こす・る)/瑳;(みが・く)/槎;(いかだ)/嗟;咄嗟/査;捜査/渣;残渣/柤/叉;音叉/扠;扠首/乍;なが・ら/作;動作/做;「作」の異体字/詐;詐欺/梭;織機のヒ/唆;示唆/茶;茶道/些;些細/再;再来年/嗄;か・れる/挫;捻挫/早;早乙女/蓑;みの/簑;「蓑」の異体字/狭;若狭?/狹;「狭」の旧字(人名用漢字)/
さ> /左;左大臣,左中将,左飛(野球)/
さーかすだん /サーカス団/
さーくるかつどう /サークル活動/
さーばがわ /サーバ側/
さーびすがかり /サービス係/
さーびすぎょう /サービス業/
さーびすざんぎょう /サービス残業;[時事]不払い残業/
さーびすせいしん /サービス精神/
さーびすないよう /サービス内容/
さーびすめい /サービス名/
さーびすもう /サービス網/
さーびすよう /サービス用/
さーびすりょう /サービス料/
さーびすりょうきん /サービス料金/
さあや /紗綾/
さい /際/差異/最/再/歳/才/犀;[動物]rhino/賽;dice/骰子;dice/債/祭/菜/災/斎;斎宮/細/妻/佐井;人名,地名/差違;≒差異/哉;快哉/栽;盆栽/裁;裁判/載;掲載/采;采配/採;採用/彩;色彩/綵;≒彩/崔/催;開催/摧;(くだ・く)/偲;しの・ぶ/鰓;魚のエラ/腮;≒鰓/顋;≒鰓/豺;やまいぬ/犲;「豺」の異体字/塞;城塞/寨;≒塞/宰;主催/縡;(こと)/砕;粉砕/碎;「砕」の旧字(人名用漢字)/淬;(にらぐ)/柴;しば/砦;城砦/釵;(かんざし)/靫;うつぼ/齋;「斎」の旧字/儕;儕輩/斉;(呉音) 一斉/齊;「斉」の旧字(人名用漢字)/済;返済/濟;「済」の旧字/西;西方/晒;さら・す/洒;洒脱(しゃだつ)/灑;≒洒/樶;木のフシ/猜;猜疑心/纔;(わずか)/蔡;([中国史])/霽;は・れる/凄;(呉音) すご・い/悽;(呉音) 悽惨/衰;(漢音の一つ)/財;財布/殺;相殺/切;一切/責;?/
さい> /再/最/歳;?/
さいあい /最愛/
さいあく /最悪/
さいあくじょうけん /最悪条件/
さいあくち /最悪値/
さいあん /再案/
さいあんてい /最安定/
さいいき /西域/
さいいち /才一/
さいいちろう /斉一郎/
さいいん /西院/催淫/斎院/
さいいんざい /催淫剤/
さいいんよう /再引用/
さいう /細雨/最右/
さいうへん /最右辺/
さいうよく /最右翼/
さいうん /彩雲/
さいえい /再映/細纓/
さいえき /歳役/
さいえん /菜園/再演/才媛/最遠/再縁/
さいえんちょう /再延長/
さいえんてん /最遠点/
さいえんぽう /最遠方/
さいえんもの /再演物/
さいおう /最奥/塞翁/再応/再往/
さいおうがうま /塞翁が馬/
さいおうぼ /再応募/
さいおおぜき /再大関/
さいおおて /最大手/
さいおく /最奥/
さいおん /蔡温/
さいおんじ /西園寺/西恩寺/
さいおんじきんもち /西園寺公望/
さいおんじこう /西園寺公/
さいか /最下/災禍/裁可/採火;五輪の-式/西下/載貨/再嫁/彩花;姓/雑賀/
さいかい /再開;†resume.「仕事を-する」/再会;†reunion.「旧友と-する」/最下位/西海/際会;†めぐりあう。「事件に-する」/斎戒/
さいかいご /再開後/
さいかいしゃく /再解釈/
さいかいじ /再開時/
さいかいそう /最下位層/
さいかいぞう /再改造/
さいかいだっしゅつ /最下位脱出/
さいかいどう /西海道;九州/
さいかいはつ /再開発/
さいかいもくよく /斎戒沐浴/
さいかかい /最下階/
さいかきゅう /最下級/
さいかぎょう /最下行/
さいかく /才覚/西鶴/
さいかくにん /再確認/
さいかくはん /再撹拌/
さいかこう /再加工/
さいかそう /最下層/
さいかそく /再加速/
さいかだん /最下段/
さいかっせいか /再活性化/
さいかつどう /再活動/
さいかにゅう /再加入/
さいかねつ /再加熱/
さいかぶ /最下部/
さいかや /さいか屋/
さいかりゅう /最下流/
さいかわ /犀川/斉川/
さいかん /再刊/細管/菜館;[中国語](cai guan) restaurant/才幹/祭官/彩管;絵筆/災患/
さいかんさんゆう /歳寒三友/
さいかんはだん /細管破断/
さいが /雑賀/齋賀/
さいがい /災害/最外/際涯/
さいがいがわ /最外側/
さいがいきゅうじょけん /災害救助犬/
さいがいきょてんびょういん /災害拠点病院/
さいがいじ /災害時/
さいがいじょうほう /災害情報/
さいがいたいさくほんぶ /災害対策本部/
さいがいち /災害地/
さいがいぶ /最外部/
さいがいほしょう /災害補償/
さいがく /才学/
さいがくしゅう /再学習/
さいがわ /犀川/
さいき /再起;comeback.「-不能」/再帰;recurse.「-処理」/才気/祭器/催奇/再記/債鬼/佐伯/斉木/斎木/妻木/彩木/
さいきかんすう /再帰関数/
さいきかんぱつ /才気煥発/
さいきがた /再帰型/
さいきけい /再帰形/
さいきけいせい /催奇形性/
さいきしき /再帰式/
さいきせい /再帰性/最輝星/
さいきそ /再起訴/
さいきだいめいし /再帰代名詞/
さいきていぎ /再帰定義/
さいきてき /再帰的/
さいきてきかんすう /再帰的関数/
さいきてきこうぞう /再帰的構造/
さいきてきていぎ /再帰的定義/
さいきてきてつづき /再帰的手続き/
さいきどう /再起動/
さいきどうし /再帰動詞;[文法]reflexive. eg. show oneself, se donner/
さいきどうじ /再起動時/
さいきふのう /再起不能/
さいきゅう /最急/鰓弓;[生物]branchial arch/
さいきゅうこうか /最急降下/
さいきゅうこうかほう /最急降下法/
さいきゅうしゅう /再吸収/
さいきゅうゆ /再給油/
さいきょ /裁許/再挙/
さいきょう /最強/西京;京都/埼京;埼玉〜東京/歳刑;[陰陽道]八将神の一。水星/
さいきょういく /再教育/
さいきょうく /西京区/
さいきょうせつ /最強説/
さいきょうせん /埼京線/
さいきょうせんかいそく /埼京線快速/
さいきょうせんじゅうじょうえき /埼京線十条駅/
さいきょうづけ /西京漬け/西京漬;サワラの-/
さいきょうみそ /西京味噌/
さいきょうやき /西京焼/西京焼き/
さいきよびだし /再帰呼び出し/
さいきん /最近/細菌/
さいきん> /最近/
さいきんがく /細菌学;bacteriology/
さいきんごう /最近号/
さいきんしゅっぱん /最近出版/
さいきんじょうほう /最近情報/
さいきんせん /細菌戦;biological warfare/
さいきんちゅうもく /最近注目/
さいきんはっけん /最近発見/
さいきんはっぴょう /最近発表/
さいきんはつばい /最近発売/
さいきんひょうばん /最近評判/
さいきんびょう /細菌病/
さいきんへいき /細菌兵器/
さいきんほうえい /最近放映/
さいきんぼう /最近傍/
さいきんりゅうこう /最近流行/
さいきんりん /最近隣/
さいきんるい /最近類/
さいきんわだい /最近話題/
さいぎ /祭儀/猜疑/再議/
さいぎしん /猜疑心/
さいぎてき /猜疑的/
さいぎゃくてん /再逆転/
さいぎょう /西行/
さいぎょうほうし /西行法師/
さいぎんみ /再吟味/
さいく /細工/
さいくし /細工師/
さいくじょ /細工所/
さいくつ /採掘/
さいくつけん /採掘権/
さいくつしゃ /採掘車/
さいくもの /細工物/
さいくん /細君/
さいぐ /祭具/
さいぐう /斎宮/
さいぐさ /三枝/
さいぐんび /再軍備/
さいけい /再掲/歳計/
さいけいこく /最恵国/再警告/
さいけいこくたいぐう /最恵国待遇/
さいけいこくやっかん /最恵国約款/
さいけいさい /再掲載/
さいけいさん /再計算/
さいけいじょうよきん /歳計剰余金/
さいけいそく /再計測/
さいけいやく /再契約/
さいけいやくきん /再契約金/
さいけいれい /最敬礼/
さいけっしゅう /再結集/
さいけっしょう /再結晶;[化学]recrystallisation/
さいけっせい /再結成/
さいけっせいご /再結成後/
さいけっせいじ /再結成時/
さいけってい /再決定/
さいけつ /採血/採決;†vote.「法案の-」/裁決;†decide.「陪審員の-」/
さいけついいん /裁決委員/
さいけつかん /採血管/
さいけつごう /再結合/
さいけつほうほう /採血方法/
さいけん /債券;†bond/債権;†credit.「不良-」/再建;reconstruction/再見/細見/
さいけんかいしゅう /債権回収/
さいけんけいかく /再建計画/
さいけんこうい /債権行為/
さいけんさ /再検査/
さいけんさく /再検索/
さいけんしゃ /債権者/再検者/
さいけんしゃだいいけん /債権者代位権/
さいけんしゃとりけしけん /債権者取消権/
さいけんしょう /再検証/
さいけんしょうけん /債権証券/
さいけんじゅつ /再建術/
さいけんじょうと /債権譲渡/
さいけんちゅう /再建中/
さいけんとう /再検討/
さいけんほうき /債権放棄/
さいげい /才芸/
さいげつ /歳月/
さいげん /再現;represent/際限;limits.「-無く」/
さいげんかのう /再現可能/
さいげんせい /再現性/
さいげんてじゅん /再現手順/
さいげんど /再現度/
さいげんぶ /再現部/
さいげんりつ /再現率/
さいこ /最古/西湖/柴胡;[漢方]「-湯,小-湯」/才子/採子/
さいこう /最高/再考/採光/催行/再興/細孔/採鉱/再構/再校/斉衡;年号(854-857)/砕鉱/
さいこう> /最高;-限度,-速度,-水準/
さいこうい /最高位/
さいこういせん /最高位戦/
さいこうおん /最高音/
さいこうかい /再公開/
さいこうかいてんすう /最高回転数/
さいこうかかく /最高価格/
さいこうかんぶ /最高幹部/
さいこうがく /最高額/
さいこうがくふ /最高学府/
さいこうきおん /最高気温/
さいこうきかん /最高機関/
さいこうきしゅ /最高機種/
さいこうきみつ /最高機密/
さいこうきゅう /最高級/
さいこうきゅうき /最高級機/
さいこうきゅうひん /最高級品/
さいこうきろく /最高記録/
さいこうきんがく /最高金額/
さいこうけいえいせきにんしゃ /最高経営責任者;CEO/
さいこうけっさく /最高傑作/
さいこうけつあつ /最高血圧/
さいこうけん /最高検;[略語]最高検察庁/
さいこうけんい /最高権威/
さいこうけんさつちょう /最高検察庁/
さいこうけんりょくしゃ /最高権力者/
さいこうげんど /最高限度/
さいこうげんどがく /最高限度額/
さいこうこうど /最高高度/
さいこうこく /再抗告/
さいこうさい /最高裁/
さいこうさいさいばんかん /最高裁裁判官/
さいこうさいはんけつ /最高裁判決/
さいこうさいはんじ /最高裁判事/
さいこうさいばんしょ /最高裁判所/
さいこうさいばんしょちょうかん /最高裁判所長官/
さいこうさく /最高作/
さいこうさつ /再考察/
さいこうしっこうせきにんしゃ /最高執行責任者;COO/
さいこうしどうしゃ /最高指導者/
さいこうしはん /最高師範/
さいこうしゅつりょく /最高出力/
さいこうしょう /最高賞/再交渉/
さいこうしん /最高神/
さいこうじ /再工事/
さいこうじそく /最高時速/
さいこうすいじゅん /最高水準/
さいこうせい /再構成/
さいこうせいせき /最高成績/
さいこうせいほう /再構成法/
さいこうせきにん /最高責任/
さいこうせきにんしゃ /最高責任者/
さいこうぜいりつ /最高税率/
さいこうぜん /最高善/
さいこうそく /最高速/
さいこうそくしよう /最高速仕様/
さいこうそくど /最高速度/
さいこうたん /最後端/
さいこうち /最高値/
さいこうちく /再構築/
さいこうちくちゅう /再構築中/
さいこうちてん /最高地点/
さいこうちゃくじゅん /最高着順/
さいこうちょう /最高潮/
さいこうてん /最高点/
さいこうとくてん /最高得点/
さいこうど /最高度/
さいこうはつ /最後発/
さいこうび /最後尾/
さいこうふ /再交付/
さいこうぶ /最後部;†last/最高部;†top/
さいこうべん /再抗弁/
さいこうほう /最高峰/最後方/
さいこうほうき /最高法規/
さいこうれつ /最後列/
さいこうれべる /最高レベル/
さいこく /催告/
さいこくしょ /催告書/
さいこくじょう /催告状/
さいこくぼん /再刻本/
さいこさん /最古参/
さいこよう /再雇用/
さいころ /骰子/賽子;=骰子/
さいこん /再婚/菜根/細根;[植物]rootlet/再建;仏閣の-/
さいこんたん /菜根譚;洪応明/
さいこんりつ /再婚率/
さいご /最後;†end/最期;†死に際/西醐/
さいごう /西郷/
さいごうせい /再合成/
さいごうたかもり /西郷隆盛/
さいごうてるひこ /西郷輝彦/
さいごく /西国/
さいごっぺ /最後っ屁;イタチの-/最後屁/
さいごつうこく /最後通告/
さいごつうちょう /最後通牒/
さいごのしんぱん /最後の審判;[キリスト教]The Last Judgement/
さいごまで /最後迄/最後まで/
さいごん /西貢/
さいさ /歳差/最左/
さいさい /歳々;年々-/再々;≒再三/再載/歳歳/再再/彩々/
さいさい> /再々/
さいさいばん /再採番/
さいさいほうそう /再々放送/
さいさうんどう /歳差運動/才差運動/
さいさき /幸先/
さいさくせい /再作成/
さいさどく /再査読/
さいさへん /最左辺/
さいさよく /最左翼/
さいさん /採算/再三/
さいさんさいし /再三再四/
さいさんしゅつ /再算出/
さいさんせい /採算性/採算制;独立-/
さいさんてき /採算的/
さいさんどがいし /採算度外視/
さいさんらいん /採算ライン/
さいさんわれ /採算割れ/
さいし /妻子/祭祀;まつる/祭司;priest/再試/才子/再四;再三-/斉志/再思;-三考/載祀;一年/孥;?/
さいしあい /再試合/
さいしかじん /才子佳人/
さいしき /彩色/祭式/才識/
さいしけん /再試験/
さいしげんか /再資源化/
さいしこう /再試行/
さいしたびょう /才子多病/
さいしつ /祭室/妻室/才質/
さいしつもん /再質問/
さいして /際して/
さいしどう /再始動/
さいしもち /妻子持ち/
さいしもん /再試問/
さいしゃけん /再車検/
さいしゅ /採取/採種/祭主/歳首;としはじめ/
さいしゅう /最終/採集/
さいしゅう> /最終;-目的,-バス/
さいしゅうあかじ /最終赤字/
さいしゅうあん /最終案/
さいしゅういんさつぶつ /最終印刷物/
さいしゅうかい /最終回/
さいしゅうかくにん /最終確認/
さいしゅうかん /最終巻/
さいしゅうがくしょう /最終楽章/
さいしゅうがくねん /最終学年/
さいしゅうがくれき /最終学歴/
さいしゅうがぞう /最終画像/
さいしゅうがた /最終型/
さいしゅうきょく /最終曲/
さいしゅうぎょう /最終行/
さいしゅうくみ /最終組/
さいしゅうくろじ /最終黒字/
さいしゅうけい /最終形/再集計/最終景/
さいしゅうけいたい /最終形態/
さいしゅうけっか /最終結果/
さいしゅうけっせん /最終決戦/
さいしゅうけってい /最終決定/
さいしゅうけっていけん /最終決定権/
さいしゅうげんこう /最終原稿/
さいしゅうこう /最終稿/最終項/
さいしゅうこうえん /最終公演/最終講演/
さいしゅうこうぎ /最終講義/
さいしゅうごう /最終号/
さいしゅうごうい /最終合意/
さいしゅうさく /最終作/
さいしゅうざい /最終財;[経済]final goods/
さいしゅうしめきり /最終締切/
さいしゅうしゅう /最終週/
さいしゅうしゅだん /最終手段/
さいしゅうしゅつりょく /最終出力/
さいしゅうしょう /最終章/
さいしゅうしょうひしゃ /最終消費者/
さいしゅうしょく /再就職/
さいしゅうしょくさき /再就職先/
さいしゅうしょぶん /最終処分/
さいしゅうしょぶんじょう /最終処分場/
さいしゅうしょり /最終処理/
さいしゅうじゅんい /最終順位/
さいしゅうじょうたい /最終状態/
さいしゅうず /最終図/
さいしゅうせいさんがた /最終生産型/
さいしゅうせいせき /最終成績/
さいしゅうせきにん /最終責任/
さいしゅうせつ /最終節/
さいしゅうせん /最終戦/
さいしゅうせんこうかい /最終選考会/
さいしゅうせんそう /最終戦争/
さいしゅうそくど /最終速度/
さいしゅうぞうび /最終増備/
さいしゅうだん /最終段/
さいしゅうだんかい /最終段階/
さいしゅうち /最終値/
さいしゅうちてん /最終地点/
さいしゅうて /最終手/
さいしゅうていり /最終定理/
さいしゅうてき /最終的/
さいしゅうてきせきにん /最終的責任/
さいしゅうでんしゃ /最終電車/
さいしゅうとう /済州島/
さいしゅうとうひょう /最終投票/
さいしゅうとうろくば /最終登録馬/
さいしゅうとっきゅう /最終特急/
さいしゅうねん /最終年/
さいしゅうねんど /最終年度/
さいしゅうはっぴょう /最終発表/
さいしゅうはんだん /最終判断/
さいしゅうはんてい /最終判定/
さいしゅうばいりつ /最終倍率/
さいしゅうばん /最終版/
さいしゅうひみつへいき /最終秘密兵器/
さいしゅうび /最終日/
さいしゅうびごご /最終日午後/
さいしゅうびさいしゅうくみ /最終日最終組/
さいしゅうびぜんじつ /最終日前日/
さいしゅうびん /最終便/
さいしゅうぶぶん /最終部分/
さいしゅうへいき /最終兵器/
さいしゅうへんこうじこく /最終変更時刻/
さいしゅうへんせい /最終編成/
さいしゅうべんろん /最終弁論/
さいしゅうほうこく /最終報告/
さいしゅうほうこくしょ /最終報告書/
さいしゅうめん /最終面/
さいしゅうめんせつ /最終面接/
さいしゅうもくてき /最終目的/
さいしゅうもくてきち /最終目的地/
さいしゅうもくひょう /最終目標/
さいしゅうもくひょうち /最終目標値/
さいしゅうよせん /最終予選/
さいしゅうよそう /最終予想/
さいしゅうり /再修理/
さいしゅうれん /最終連/
さいしゅうろく /再収録/
さいしゅうろんぶん /最終論文/
さいしゅうわ /最終話/
さいしゅじゅつ /再手術/
さいしゅっか /再出荷/
さいしゅっぱつ /再出発/
さいしゅつ /歳出/
さいしゅつば /再出馬/
さいしゅんかん /再春館;[企業名]/
さいしょ /最初/税所/最所/細書/才所/
さいしょう /最小;†smallest/最少;†least in number/宰相/最勝;greatest/妻妾/
さいしょう> /最小;-値,-限度/
さいしょういそう /最小位相/
さいしょうか /最小化/最少化/
さいしょうかい /最小解/
さいしょうかいてんはんけい /最小回転半径/
さいしょうかげんり /最小化原理/
さいしょうかちょうち /最小可聴値/
さいしょうかもんだい /最小化問題/
さいしょうかんかく /最小間隔/
さいしょうき /最小期/
さいしょうきろく /最小記録/
さいしょうぎ /最小木/
さいしょうげん /最小限/最小元;[数学]smallest element/
さいしょうげんど /最小限度/
さいしょうこうせい /最小構成/
さいしょうこうばいすう /最小公倍数/
さいしょうこゆうち /最小固有値/
さいしょうじ /最勝寺/
さいしょうじじょう /最小２乗/最小二乗/最小2乗/
さいしょうじじょうかい /最小二乗解/最小2乗解/
さいしょうじじょうごさ /最小2乗誤差/
さいしょうじじょうほう /最小二乗法/最小2乗法/
さいしょうすう /最小数/
さいしょうせい /最小性/
さいしょうたんい /最小単位/
さいしょうち /最小値/
さいしょうてん /最小点/
さいしょうとくてん /最少得点/
さいしょうはんけい /最小半径/
さいしょうひんか /再商品化/
さいしょうりょう /最小量/
さいしょかい /最初回/
さいしょき /最初期/
さいしょきか /再初期化/
さいしょく /彩色;colour/菜食/彩飾;decorate/才色;-兼備/
さいしょくけんび /才色兼備/
さいしょくしゅぎ /菜食主義/
さいしょくしゅぎしゃ /菜食主義者/
さいしょくみんちか /再植民地化/
さいしょほど /最初程/
さいしょり /再処理/
さいしょりこうじょう /再処理工場/
さいしょりしせつ /再処理施設/
さいしよう /再使用/
さいしようきょだく /再使用許諾/
さいしん /最新/細心/再診;⇔初診/再審;[法]review.「-請求」/最深/祭神/砕身/西神/
さいしん> /最新;-式,-論文,-リンク,-パッチ/
さいしんうちゅうろん /最新宇宙論/
さいしんえい /最新鋭/
さいしんかん /最新刊/最新巻/
さいしんかんきょう /最新環境/
さいしんがた /最新型/
さいしんき /最新機/
さいしんきしゅ /最新機種/
さいしんきじ /最新記事/
さいしんぎ /再審議/
さいしんぎじゅつ /最新技術/
さいしんけんきゅうどうこう /最新研究動向/
さいしんごう /最新号/
さいしんさ /再審査/
さいしんさく /最新作/
さいしんしき /最新式/
さいしんじじょう /最新事情/
さいしんじょうきょう /最新状況/
さいしんじょうほう /最新情報/
さいしんせい /再申請/
さいしんせいきゅう /再審請求/
さいしんどうこう /最新動向/
さいしんにゅーす /最新ニュース/
さいしんばん /最新版/最新盤/
さいしんぼん /最新本/
さいしんろくおん /最新録音/
さいじ /歳児/催事/祭事/細字/西寺/斉次/細事/歳次/斎次/
さいじき /歳時記/斎食/
さいじざひょう /斉次座標/斎次座標/
さいじじょう /催事場/
さいじっけん /再実験/
さいじっこう /再実行/
さいじっそう /再実装/
さいじつ /祭日/斎日;=さいにち/
さいじつげん /再実現/
さいじゃく /最弱/
さいじゅうし /最重視/
さいじゅうてん /最重点/再充填/
さいじゅうてんかだい /最重点課題/
さいじゅうでん /再充電/
さいじゅうよう /最重要/
さいじゅうようかだい /最重要課題/
さいじゅうようし /最重要視/
さいじゅうようてん /最重要点/
さいじゅけん /再受験/
さいじゅしん /再受診/
さいじゅんかん /再循環/
さいじょ /才女/妻女/斎女/細叙/
さいじょう /最上/斎場/西条/西城/西條/祭場/齋城/
さいじょうい /最上位/
さいじょういきしゅ /最上位機種/
さいじょうえい /再上映/
さいじょうかい /最上階/
さいじょうきゅう /最上級/
さいじょうきゅうきしゅ /最上級機種/
さいじょうきゅうしゃ /最上級者/
さいじょうぎょう /最上行/
さいじょうじじょうかい /最小2乗解/
さいじょうじょう /再上場/
さいじょうせき /最上席/
さいじょうだん /最上段/
さいじょうぶ /最上部/
さいじょうりゅう /最上流/
さいじん /祭神/才人/
さいすいき /採水器/
さいすん /採寸/
さいずべつ /サイズ別/
さいせい /再生/済生/再製/最盛/済世/採精/歳星;木星/祭政/
さいせいいがく /再生医学;regenerative medicine/
さいせいいっち /祭政一致/
さいせいいりょう /再生医療;[医]皮膚や臓器などを再生・回復させる医療。/
さいせいうけおいにん /再生請負人/
さいせいおん /再生音/
さいせいおんがく /再生音楽/
さいせいおんじょう /再生音場/
さいせいかい /済生会/
さいせいかのう /再生可能/
さいせいが /再生画/
さいせいがわ /再生側/
さいせいき /最盛期/再生機/再生器/
さいせいきこう /再生機構/
さいせいきのう /再生機能/
さいせいきゅう /再請求/
さいせいぎじゅつ /再生技術/
さいせいけい /再生系/
さいせいげんかい /再生限界/
さいせいげんりょう /再生原料/
さいせいさん /再生産/
さいせいさんこうぞう /再生産構造/
さいせいさんせい /再生産性/
さいせいさんひん /再生産品/
さいせいし /再生紙/
さいせいしげん /再生資源/
さいせいしつ /再生室/
さいせいしゅつりょく /再生出力/
さいせいしんごう /再生信号/
さいせいじ /再生時/最盛時/
さいせいじかん /再生時間/
さいせいじゅつ /再生術/
さいせいじょうたい /再生状態/
さいせいせい /再生成/
さいせいせいぎょ /再生制御/
さいせいせんよう /再生専用/
さいせいせんようき /再生専用機/
さいせいそうち /再生装置/
さいせいたん /最西端/
さいせいちゅう /再生中/
さいせいのうりょく /再生能力/
さいせいばり /再生針/
さいせいひん /再生品/
さいせいび /再整備/
さいせいふのう /再生不能/
さいせいほう /再生法/
さいせいよう /再生用/
さいせいり /再整理/
さいせいりよう /再生利用/
さいせき /砕石/採石/載籍/
さいせきけん /採石権/
さいせきじゅつ /砕石術;[医]lithotripsy/
さいせきじょう /採石場/
さいせきどうしょう /砕石道床/
さいせっき /細石器/
さいせっきん /最接近/
さいせっけい /再設計/
さいせってい /再設定/
さいせつ /砕屑/細節/再説/細説/歳殺;[陰陽道]八将神の一。金星/
さいせつがん /砕屑岩;[地質]clast/
さいせつぞく /再接続/
さいせつぶつ /砕屑物/
さいせん /再選/賽銭/再戦/細線/西線/
さいせんか /細線化/
さいせんきょ /再選挙/
さいせんたん /最先端/最尖端/
さいせんたんぎじゅつ /最先端技術/
さいせんちゃく /最先着/
さいせんばこ /賽銭箱/
さいせんれいは /再洗礼派/
さいぜん /最善/最前/截然;=せつぜん/菜膳/
さいぜんさく /最善策/
さいぜんしゅ /最善手/
さいぜんせん /最前線/
さいぜんぶ /最前部/
さいぜんれつ /最前列/
さいそ /再訴/菜蔬/
さいそう /再送/採草/彩層/
さいそうさ /再操作/
さいそうしん /再送信/
さいそうてん /再装填/
さいそうふ /再送付/
さいそうぶん /再送分/
さいそく /最速/細則/催促/
さいそくきろく /最速記録/
さいそくたつ /最速達/
さいそくてい /再測定/
さいそくばく /再束縛/
さいそくれっしゃ /最速列車/
さいぞう /才蔵/
さいた /最多/財田/斎田/斉田/才田/齊田/
さいたあんだ /最多安打/
さいたい /臍帯;へそのお/妻帯;married (man)/
さいたいけつ /臍帯血/
さいたいしゃ /妻帯者/
さいたいほ /再逮捕/
さいたかね /最高値/
さいたく /採択/
さいたくりつ /採択率/
さいたくろんぶん /採択論文/
さいたしゅつじょう /最多出場/
さいたしょう /最多勝/
さいたしょうとうしゅ /最多勝投手/
さいたとうるい /最多盗塁/
さいたとくひょう /最多得票/
さいたま /埼玉/
さいたまけん /埼玉県/
さいたまけんけい /埼玉県警/
さいたまけんじん /埼玉県人/
さいたまけんない /埼玉県内/
さいたまけんみん /埼玉県民/
さいたまし /さいたま市;NB:2001年5月1日に浦和、大宮、与野三市が合併してできた市/
さいたまだい /埼玉大/
さいたまだいがく /埼玉大学/
さいたまほうめん /埼玉方面/
さいたらぶし /斎太郎節;[民謡]宮城/
さいたる /最たる/
さいたん /最短/採炭/
さいたん> /最短/
さいたんいっち /最短一致/
さいたんかい /最短解/
さいたんがくしゅう /最短学習/
さいたんきょり /最短距離/
さいたんけいろ /最短経路/
さいたんさつえいきょり /最短撮影距離/
さいたんしゅすう /最短手数/
さいたんしょうてんきょり /最短焦点距離/
さいたんじかん /最短時間/
さいたんろ /最短路/
さいだ /斉田/斎田/
さいだい /最大/細大;†「-漏らさず」/歳代;(助数詞) 「30歳代」/埼大;[略語]埼玉大学/
さいだい> /最大;-径,-積載量,-200G/
さいだいえんちょう /最大延長/
さいだいか /最大化/
さいだいかいてんすう /最大回転数/
さいだいかくりつ /最大確率/
さいだいかりょく /最大火力/
さいだいき /最大期/
さいだいきぼ /最大規模/
さいだいきゅう /最大級/
さいだいきょうど /最大強度/
さいだいきょよう /最大許容/
さいだいけいしゃ /最大傾斜/
さいだいけんいんりょく /最大牽引力/
さいだいげん /最大限/最大元;[数学]/
さいだいげんかい /最大限界/
さいだいげんかつよう /最大限活用/
さいだいげんどりょく /最大限努力/
さいだいげんり /最大原理/
さいだいこうふく /最大幸福/
さいだいこうやくすう /最大公約数/
さいだいこうやくすうてき /最大公約数的/
さいだいこすう /最大個数/
さいだいこゆうち /最大固有値/
さいだいしゃてい /最大射程/
さいだいしゅうはすう /最大周波数/
さいだいしゅつりょく /最大出力/
さいだいしょうひでんりょく /最大消費電力/
さいだいしんど /最大震度/
さいだいしんぱくすう /最大心拍数/
さいだいしんぷく /最大振幅/
さいだいじ /西大寺/
さいだいじゅうりょう /最大重量/
さいだいすう /最大数/
さいだいせいし /最大静止/
さいだいせいのう /最大性能/
さいだいせんそく /最大戦速/
さいだいぜんかく /最大全角/
さいだいたすう /最大多数/
さいだいち /最大値/
さいだいちょう /最大長/
さいだいでんあつ /最大電圧/
さいだいでんりょく /最大電力/
さいだいとくひょう /最大得票/
さいだいはば /最大幅/
さいだいひきょり /最大飛距離/
さいだいふうそく /最大風速/
さいだいみしよう /最大未使用/
さいだいもくひょう /最大目標/
さいだいようりょう /最大容量/
さいだいりかく /最大離角/
さいだいりりくじゅうりょう /最大離陸重量/
さいだいりろん /最大理論/
さいだいれんぞく /最大連続/
さいだん /祭壇/裁断;cut/細断;shred/採暖;暖を採る。 NB:体を暖めるのが「採暖」、部屋を暖めるのが「暖房」/截断;せつだん/
さいだんき /裁断器/
さいだんざ /祭壇座;Ara(Ara)/
さいち /才知/最遅/細緻/佐一/
さいちく /再築/
さいちゅう /最中/
さいちゅうおう /最中央/
さいちゅうせん /再抽選/
さいちゅうにゅう /再注入/
さいちゅうもん /再注文/
さいちょう /最長/最澄/再調/
さいちょう> /最長/
さいちょういっち /最長一致/
さいちょうかたみちきっぷ /最長片道切符/
さいちょうきょり /最長距離/
さいちょうさ /再調査/
さいちょうせい /再調整/最長性/
さいちょうせん /再挑戦/
さいちょうてん /最長点/
さいちょうふとうきょり /最長不倒距離/
さいちょうれつ /最長列/
さいついか /再追加/
さいてい /最低/裁定/再訂/
さいてい> /最低;-価格,-水準/
さいていあん /再提案/
さいていいっしゅうかん /最低一週間/
さいていおん /最低音/
さいていおんど /最低温度/
さいていかかく /最低価格/
さいていかかくたい /最低価格帯/
さいていがく /最低額/
さいていきおん /最低気温/
さいていきじゅん /最低基準/
さいていきゅう /最低級/
さいていぎ /再定義/
さいていけつあつ /最低血圧/
さいていげん /最低限/
さいていげんど /最低限度/
さいていげんひつよう /最低限必要/
さいていさいあく /最低最悪/
さいていしゅう /裁定集/
さいていしゅつ /再提出/
さいていじ /再提示/最低次/
さいていじゅうりょう /最低重量/
さいていじょうけん /最低条件/
さいていすいじゅん /最低水準/
さいていせい /再訂正/
さいていせん /最低線/
さいていそくど /最低速度/
さいていたんい /最低単位/
さいていち /最低値/
さいていちじょうこう /最低地上高/
さいていちんぎん /最低賃金/
さいていてん /最低点/
さいていとりひき /裁定取引/
さいていひつよう /最低必要/
さいていまち /裁定待ち/
さいていらいん /最低ライン/
さいていりょうきん /最低料金/
さいていりようきかん /最低利用期間/
さいていれべる /最低レベル/
さいてき /最適/
さいてきいち /最適位置/
さいてきか /最適化/
さいてきかい /最適解/
さいてきかしゅほう /最適化手法/
さいてきかせいぎょ /最適化制御/
さいてきかほう /最適化法/
さいてきかまえ /最適化前/
さいてきかもんだい /最適化問題/
さいてきかりろん /最適化理論/
さいてきかんり /最適管理/
さいてききょり /最適距離/
さいてきじょうけん /最適条件/
さいてきせい /最適性/
さいてきせいぎょ /最適制御/
さいてきせいぎょもんだい /最適制御問題/
さいてきせんりゃく /最適戦略/
さいてきち /最適値/
さいてきはいち /最適配置/
さいてん /祭典/採点/再転/西天/祭天/
さいてんけっか /採点結果/
さいてんけん /再点検/
さいてんしつ /採点室/
さいてんしゃ /採点者/
さいてんしゅうけい /採点集計/
さいてんひょう /採点表/
さいてんほうほう /採点方法/
さいてんようし /採点用紙/
さいでん /祭殿/
さいと /西都/
さいとう /斎藤;†(「いつき」の「斎」)/斉藤;†(「一斉」の「斉」)/齋藤;†「斎」旧字/齊藤;†「斉」旧字/
さいとうかん /再投函/
さいとうぐみ /斎藤組/
さいとうけいこ /斉藤慶子/
さいとうこう /再投稿/
さいとうごう /再統合/
さいとうし /再投資/
さいとうじょう /再登場/
さいとうたん /最東端/
さいとうどうさん /斎藤道三/
さいとうにゅう /再投入/
さいとうひょう /再投票/
さいとうもきち /斎藤茂吉;(1882-1953) 歌人。『赤光』『白き山』/
さいとうろく /再登録/
さいとえい /再渡英/
さいとく /才徳/
さいとそう /再塗装/
さいとつにゅう /再突入;re-entry の訳語/
さいど /再度/彩度;[光学]saturation/済度;[仏教]救済/
さいどう /細動/
さいどうふう /砕動風/
さいどうみゃく /細動脈/
さいどかくにん /再度確認/
さいどぎろん /再度議論/
さいどく /再読/
さいどけいさい /再度掲載/
さいどしつもん /再度質問/
さいどちょうせん /再度挑戦/
さいどとうこう /再度投稿/
さいどぼしゅう /再度募集/
さいどらいほう /再度来訪/
さいない /最内/
さいないしゅう /最内周/
さいないわく /最内枠/
さいなん /災難/済南/最南/
さいなんかん /最難関/
さいなんたん /最南端/
さいなんとう /最南東/
さいにち /斎日;[仏教]精進する日/
さいにゅう /歳入/再入/
さいにゅうか /再入荷/
さいにゅうかい /再入会/
さいにゅうかのう /再入可能/
さいにゅうがく /再入学/
さいにゅうけっかん /歳入欠陥/
さいにゅうこう /再入校/
さいにゅうこく /再入国/
さいにゅうこくきょか /再入国許可/
さいにゅうしょう /再入賞/
さいにゅうじょう /再入場/
さいにゅうもん /再入門/
さいにゅうりょく /再入力/
さいにょう /採尿/
さいにょうかん /細尿管;[解剖]nephric tubule/
さいにん /再認/再任/
さいにんしき /再認識/
さいねん /再燃/西念/
さいねんしょう /最年少/
さいねんしょうきろく /最年少記録/
さいねんちゃく /再粘着/
さいねんちょう /最年長/
さいのう /才能/採納/臍嚢/塞納/
さいのうしゅく /再濃縮/
さいのうてき /才能的/
さいのかわら /賽の河原/
さいのめ /賽の目/
さいは /歳破;[陰陽道]八将神の一。土星/
さいはい /采配/再拝/儕輩/
さいはいそう /再配送/
さいはいち /再配置/
さいはいちかのう /再配置可能/
さいはいふ /再配布/再配付;?/
さいはいふかのう /再配布可能/
さいはいぶん /再配分/
さいはく /西伯/
さいはっけん /再発見/
さいはっこう /再発行/
さいはっこうしんせいしょ /再発行申請書/
さいはっしん /再発信;†retransmission/再発進;†restart/
さいはっそう /再発送/
さいはつ /再発/
さいはつおん /再発音/
さいはつばい /再発売/
さいはつばいばん /再発売版/
さいはつばん /再発盤;reissued disk/再発版;reissued version/
さいはつぶつ /再発物/
さいはつぼうし /再発防止/
さいはつめい /再発明/
さいはて /最果て/
さいはん /再販;†resale.「-制度」/再版;†reprint.⇔初版/再犯;recommitment/最汎/
さいはんかかくいじ /再販価格維持/
さいはんかじゅう /再犯加重/
さいはんしてい /再販指定/
さいはんしょうひん /再販商品/
さいはんせい /再販制/
さいはんせいど /再販制度/
さいはんばい /再販売/
さいはんもと /再販元/
さいはんりつ /再犯率/
さいはんろん /再反論/
さいばい /栽培/
さいばいち /栽培地/
さいばいちゅう /栽培中/
さいばいほう /栽培法/
さいばし /菜箸/
さいばら /催馬楽/
さいばん /裁判/採番/歳晩/
さいばんいん /裁判員/
さいばんかん /裁判官/
さいばんかんかつ /裁判管轄/
さいばんかんだんがいほう /裁判官弾劾法/
さいばんかんぶんげんほう /裁判官分限法/
さいばんけん /裁判権/
さいばんざた /裁判沙汰/
さいばんしえん /裁判支援/
さいばんしょ /裁判所/裁判書/
さいばんしょしょきかん /裁判所書記官/
さいばんしょちょうさかん /裁判所調査官/
さいばんしょはんけつ /裁判所判決/
さいばんしょほう /裁判所法/
さいばんじょう /裁判上/
さいばんせいど /裁判制度/
さいばんせき /裁判籍/
さいばんちゅう /裁判中/
さいばんちょう /裁判長/
さいばんてつづき /裁判手続/
さいばんとうそう /裁判闘争/
さいばんねん /最晩年/
さいひ /採否/歳費/
さいひつ /細筆/才筆/
さいひはん /再批判/
さいひょう /砕氷/細氷/細評/
さいひょうか /再評価/
さいひょうじ /再表示/
さいひょうせん /砕氷船/
さいひんこく /最貧国/
さいひんち /最頻値/
さいび /細微/最美/最微/
さいびこう /最微光/
さいびょうが /再描画/
さいふ /財布/採譜/宰府/
さいふく /祭服/
さいふくよう /再複葉/
さいふじょう /再浮上/
さいふっとう /再沸騰/
さいぶ /細部/西部/
さいぶつ /才物/
さいぶん /細分/祭文/
さいぶんか /細分化;segmentation.「学問領域の-」/再分化;redifferentiation.「細胞の-」/
さいぶんかつ /再分割/細分割/
さいぶんぱい /再分配/
さいぶんるい /細分類/再分類/
さいへん /再編/細片/砕片/
さいへんかん /再変換/
さいへんき /再編期/
さいへんきょく /再編曲/
さいへんこう /再変更/
さいへんしゅう /再編集/
さいへんしゅうばん /再編集版/
さいへんせい /再編成/
さいべつ /細別/
さいべんきょう /再勉強/
さいほう /西方/裁縫/採訪/再報/細胞;=さいぼう/
さいほうえい /再放映/
さいほうじょうど /西方浄土/
さいほうせかい /西方世界/
さいほうそう /再放送/
さいほうそうかいし /再放送開始/
さいほうそうじ /再放送時/
さいほうそうちゅう /再放送中/
さいほうばこ /裁縫箱/
さいほうもん /再訪問/
さいほきゅう /再補給/
さいほく /最北/
さいほくたん /最北端/
さいほけん /再保険/
さいぼう /細胞/細棒/才望/
さいぼうえん /最望遠/
さいぼうかい /細胞塊/
さいぼうかく /細胞核;[生物]cell nucleus/
さいぼうかん /細胞間/
さいぼうがい /細胞外/
さいぼうがいきしつ /細胞外基質/
さいぼうけんだくえき /細胞懸濁液/
さいぼうこうがく /細胞工学/
さいぼうし /細胞死/
さいぼうしつ /細胞質/
さいぼうしゅ /細胞腫/
さいぼうしゅうき /細胞周期/
さいぼうしん /細胞診/
さいぼうじたい /細胞自体/
さいぼうせいぶつがく /細胞生物学/
さいぼうそしき /細胞組織;[生物]cell tissue/
さいぼうでんい /細胞電位/
さいぼうない /細胞内/
さいぼうないしょうか /細胞内消化/
さいぼうひょうめん /細胞表面/
さいぼうぶんれつ /細胞分裂/
さいぼうへき /細胞壁/
さいぼうまく /細胞膜/
さいぼうゆうごう /細胞融合/
さいぼしゅう /再募集/
さいぽすと /再ポスト/
さいまつ /歳末/
さいみつ /細密/最密/
さいみつが /細密画;miniature/
さいみゃく /細脈/
さいみょうじ /斎明寺/
さいみん /催眠/済民;経国-/細民;下層階級/
さいみんざい /催眠剤/
さいみんしょうほう /催眠商法/
さいみんじゅつ /催眠術/
さいみんじゅつし /催眠術師/
さいみんじょうたい /催眠状態/
さいみんちょうたい /細明朝体/
さいみんやく /催眠薬/
さいみんりょうほう /催眠療法;[精医]hypnosis/
さいむ /債務/
さいむしゃ /債務者/
さいむしょうかん /債務償還/
さいむしょり /債務処理/
さいむちょうか /債務超過/
さいむふたん /債務負担/
さいむふたんこうい /債務負担行為/
さいむふりこう /債務不履行/
さいむぶん /債務分/
さいむほしょう /債務保証;debt guarantee/
さいむめいぎ /債務名義/
さいむもんだい /債務問題/
さいめい /斉明/才名/
さいめいちょう /細明朝/
さいめいてんのう /斉明天皇/
さいめんきょ /再免許/
さいめんきょしんせい /再免許申請/
さいもく /細目/
さいもつ /済物/祭物/賽物/
さいもと /斉本/
さいもん /彩文/柴門/祭文/彩紋/
さいもんどき /彩文土器/
さいもんふみ /柴門ふみ/
さいやく /災厄/
さいやす /最安/
さいやすね /最安値/
さいゆ /採油/
さいゆう /西遊/最尤/彩釉/再遊/采邑/
さいゆうき /西遊記/
さいゆうしゅう /最優秀/
さいゆうしゅうかしょうしょう /最優秀歌唱賞/
さいゆうしゅうこば /最優秀古馬/
さいゆうしゅうしょう /最優秀賞/
さいゆうしゅうしょうがいば /最優秀障害馬/
さいゆうしゅうしんじんしょう /最優秀新人賞/
さいゆうしゅうせんしゅ /最優秀選手/
さいゆうしゅうせんしゅしょう /最優秀選手賞/
さいゆうしゅうとうしゅ /最優秀投手/
さいゆうすいてい /最尤推定/
さいゆうすいていほう /最尤推定法/
さいゆうせん /最優先/
さいゆうほう /最尤法/
さいゆうりょく /最有力/
さいゆうりょくこうほ /最有力候補/
さいゆしゅつ /再輸出/
さいゆにゅう /再輸入/
さいよ /宰予;孔子の弟子/
さいよう /採用/細腰/
さいようか /採用課/
さいようくぶん /採用区分/
さいようしけん /採用試験/
さいようしつ /採用室/
さいようじき /採用時期/
さいようじょうけん /採用条件/
さいようじょうほう /採用情報/
さいようたんとう /採用担当/
さいようぶ /採用部/
さいようりゆう /採用理由/
さいようれい /採用例/
さいようわく /採用枠/
さいらい /再来/
さいらんけい /採卵鶏/
さいり /再履/犀利/
さいりしゅう /再履修/
さいりしゅうしゃ /再履修者/
さいりゃく /才略/
さいりゅう /細粒;fine particle/細流;creek/
さいりゅうこう /再流行/
さいりゅうど /細粒度/
さいりょう /最良/裁量/宰領/才量/
さいりょうか /最良化/
さいりょうがえ /再両替/
さいりょうけん /裁量権/
さいりょうこうい /裁量行為/
さいりょうはんい /裁量範囲/
さいりょうろうどうせい /裁量労働制/
さいりょく /才力/
さいりよう /再利用/
さいりようかのう /再利用可能/
さいりようせい /再利用性/
さいりようほう /再利用法/
さいりん /再臨/
さいるい /催涙/
さいるいがす /催涙ガス;tear gas/
さいるいすぷれー /催涙スプレー/
さいるいだん /催涙弾/
さいれい /祭礼/
さいれつ /鰓裂;[生物]gill slit/
さいれんさい /再連載/
さいろう /豺狼/
さいろく /再録/採録/載録/
さいろくおん /再録音/
さいろくばん /再録版/
さいろくろんぶん /採録論文/
さいろん /再論/細論/
さいわ /再話/
さいわい /幸い/倖/幸/
さいわいく /幸区/
さいわいちょう /幸町/
さいわいびし /幸菱/
さいわかて /最若手/
さいわき /才脇/
さいわりびき /再割引;rediscount. 割引いた手形を再度(日銀で)割引くこと/
さいわん /才腕/
さいんいり /サイン入り/
さいんかい /サイン会/
さいんぼん /サイン本/
さう /然/
さうなしつ /サウナ室/
さうなぶろ /サウナ風呂/
さえ /冴/
さえき /佐伯/差益/冴木/
さえきく /佐伯区/
さえきゆうぞう /佐伯祐三;(1898-1928) 洋画家/
さえぐさ /三枝/
さえこ /冴子/さえ子/小枝子/沙絵子/佐栄子/冴虎/左枝子/
さえざえ /冴え冴え/冴々/
さえじま /冴島/
さえずり /囀り/
さえだ /佐枝/
さえつ /査閲/
さえど /佐江戸/
さえば /冴羽/
さえみ /冴美;名/三絵美/
さえもん /左衛門/
さえもんのかみ /左衛門督;[律令制]/
さえもんのじょう /左衛門尉/
さえもんふ /左衛門府;[律令制]/
さえん /茶園/差延/
さお /竿/棹;原義:船を進める棒/佐保;地名,奈良/杆/
さおう /沙翁;Shakespeare/
さおううおう /左往右往/
さおだけ /竿竹/
さおとめ /早乙女/五月女/
さおぶち /竿縁/
さおぶちてんじょう /竿縁天井/
さおもの /棹物/
さおり /沙織/小織/里織/早織/佐織/小緒里/
さおん /差音/
さか /坂/逆/茶菓/酒/阪;「坂」の異体字/
さかあがり /逆上がり;鉄棒/
さかい /境/堺;(大阪)/界/酒井/坂井/阪井/左海/酒居/酒伊/境井/
さかいがわ /境川/
さかいし /堺市/
さかいしない /堺市内/
さかいすじ /堺筋/
さかいすじせん /堺筋線/
さかいだ /境田/
さかいだかきえもん /酒井田柿右衛門/
さかいちょう /堺町/
さかいで /坂出/
さかいでえき /坂出駅/
さかいでがわ /坂出側/
さかいまさあき /堺正章/
さかいみなと /境港/
さかいめ /境目/
さかいり /酒煎り/
さかうえ /坂上/
さかうち /坂内/
さかうらみ /逆恨み/逆怨み/
さかえ /栄え/栄/榮;「栄」の旧字(人名用漢字)/
さかえだ /栄田/
さかえだに /栄谷/
さかえまち /栄町/
さかお /阪尾/
さかおとし /逆落とし/逆落し/
さかかく /坂角/
さかがみ /坂上/阪上/逆髪/
さかがめ /酒甕/
さかがわ /坂川/
さかき /榊/坂城/賢木/坂木/
さかきた /坂北/
さかきばら /榊原/
さかきばらおんせんぐち /榊原温泉口/
さかくら /坂倉/阪倉/
さかぐせ /酒癖/
さかぐち /坂口/阪口/
さかぐちあんご /坂口安吾;(1906-1955) 作家。『堕落論』/
さかぐら /酒蔵/
さかげ /逆毛/
さかこし /坂越/
さかことば /逆言葉/
さかさ /逆さ/逆/
さかさい /逆井/
さかさふじ /逆さ富士/
さかさま /逆様/
さかざき /坂崎/
さかし /賢し/
さかしお /逆潮/酒塩;-焼き/
さかした /坂下/阪下/
さかしたもん /坂下門/
さかしま /逆しま/倒/逆/
さかしら /賢しら/
さかしろ /酒代/
さかずき /杯/盃;「杯」の旧字(人名用漢字)/盞/觚/柧/
さかずめ /坂詰;※仮名遣い「さかづめ」/
さかた /坂田/酒田/阪田/
さかたかん /酒田間/
さかたきんとき /坂田金時/
さかたに /阪谷/
さかだい /酒代/
さかだち /逆立ち/酒断ち/逆立/
さかだる /酒樽/
さかづき /杯/盃/
さかづくり /酒造り/
さかて /逆手/酒手/
さかと /坂戸/
さかとったり /逆とったり/
さかど /坂戸/
さかな /魚/肴/
さかなかけ /魚懸け/
さかなが /阪長/
さかなし /坂梨/
さかなたち /魚達/
さかなだな /魚店/
さかなっけ /魚っ気/
さかなつき /魚突き/
さかなつり /魚釣り/魚釣/
さかなで /逆撫で/
さかなふらい /魚フライ/
さかなへん /魚偏/
さかなぼうちょう /魚包丁/
さかなや /魚屋/
さかなやそうごろう /魚屋宗五郎/
さかなりょうり /魚料理/
さかに /酒煮/
さかにわ /坂庭/
さかね /坂根/
さかの /坂野/
さかのうえ /坂上/
さかのうえたむらまろ /坂上田村麻呂/
さかのうえのたむらまろ /坂上田村麻呂/
さかはぎ /逆剥/
さかば /酒場/
さかばた /酒旗/
さかばやし /酒林/
さかびき /逆引き/
さかびたり /酒浸り/
さかびん /酒瓶/
さかぶね /酒槽/
さかべ /坂部/酒部/
さかほ /逆帆/
さかほぎ /坂祝/
さかぼうき /酒箒/
さかま /坂間/
さかまきおんせん /坂巻温泉/逆巻温泉/
さかまち /坂町/
さかまつげ /逆睫毛/
さかまんじゅう /酒饅頭/
さかみず /酒水/逆水/
さかみち /坂道/坂路/
さかみちはっしん /坂道発進/
さかむけ /逆剥け/
さかむし /酒蒸し/酒蒸/
さかむら /坂村/
さかめ /逆目/
さかもぎ /逆茂木/
さかもと /坂本/阪本/坂元/酒本/阪元/
さかもときゅう /坂本九/
さかもとせん /阪本線/
さかもとりゅういち /坂本龍一/
さかもとりょうま /坂本竜馬/
さかもり /酒盛り/酒盛/
さかもりうた /酒盛り唄/
さかや /酒屋/
さかやき /月代/
さかゆめ /逆夢/
さかり /盛り/盛/
さかりば /盛り場/
さかわ /佐川/栄和/坂和/
さかわがわ /酒匂川/
さかん /左官;plasterer/茶館/盛ん/佐官;field officer/主典;[律令制]/差換/
さかんや /左官屋/
さが /性/佐賀/嵯峨/
さがいこうい /詐害行為/
さがえ /寒河江/
さがえき /佐賀駅/嵯峨駅/
さがく /差額/
さがくぶん /差額分/
さがけん /佐賀県/
さがし /佐賀市/
さがしかた /探し方/
さがしもの /探し物/捜し物/
さがしょう /佐賀商/
さがしょうぎょう /佐賀商業/
さがた /嵯峨田/
さがだい /佐賀大/
さがだいがく /佐賀大学/
さがちょう /佐賀町/
さがてんのう /嵯峨天皇/
さがね /嵯峨根/
さがの /嵯峨野/
さがのせき /佐賀関/
さがのせん /嵯峨野線/
さがぼん /嵯峨本/
さがみ /相模/
さがみおおつか /相模大塚/
さがみおおの /相模大野/
さがみおおのえき /相模大野駅/
さがみおおはし /相模大橋/
さがみがわ /相模川/
さがみがわかこう /相模川河口/
さがみこ /相模湖/
さがみこえき /相模湖駅/
さがみこほうめん /相模湖方面/
さがみせん /相模線/
さがみてつどう /相模鉄道/
さがみはら /相模原/
さがみはらきゅうじょう /相模原球場/
さがみはらし /相模原市/
さがみはらしみん /相模原市民/
さがみはらせん /相模原線/
さがみわん /相模湾/
さがやま /嵯峨山/
さがら /相楽/相良/
さがらぐん /相楽郡/
さがり /下がり/
さがりめ /下がり目/
さがる /下ル/
さがわ /佐川/
さがわきゅうびん /佐川急便/
さがん /左岸/砂岩/左眼/
さき /先/崎/左記/前/早紀/沙樹/早岐/沙貴/咲/埼/尖/嵜/碕/早記/
さきいき /先行き/
さきいと /先糸/
さきえ /咲恵/
さきおくり /先送り/
さきおととい /一昨昨日/一昨々日;三日前/
さきおととし /一昨昨年/一昨々年;三年前/
さきおり /裂織/
さきがいけん /先買権/
さきがけ /魁/先駆け/先掛/
さきがし /先貸し/
さきがり /先借り/
さきぎり /先限/
さきぐあい /咲き具合/咲具合/
さきぐい /先食い/
さきこ /咲子/佐紀子/沙樹子/
さきごう /先号/
さきごろ /先頃/
さきさか /向坂/
さきさま /先様/
さきざき /先々/先崎/先先/
さきしましょとう /先島諸島;地名/
さきぞなえ /先備え/
さきた /崎田/咲田/
さきだか /先高/
さきだって /先立って/先達て;<rare>/
さきち /佐吉/
さきっちょ /先っちょ/
さきっぽ /先っぽ/
さきづけ /先付け/
さきて /先手/
さきと /崎戸/
さきどり /先取り/
さきどりとっけん /先取特権/
さきに /先に/前に;=先に/曩に;=先に/
さきのばし /先延ばし/
さきのり /先乗り/先乗/
さきはま /崎浜/咲浜/
さきばしり /先走り/
さきばらい /先払い/先払/
さきばん /先番/
さきぶれ /先触れ/
さきほど /先程/先ほど/
さきぼう /先棒/
さきぼそり /先細り/
さきまけ /先負;[六輝]/
さきまわり /先回り/
さきみ /咲美/
さきもの /先物/
さきものがい /先物買い/先物買/
さきものしじょう /先物市場/
さきものそうば /先物相場/
さきものとりひき /先物取引/
さきもり /防人/
さきや /崎谷/
さきやす /先安/
さきやま /崎山/咲山/
さきゅう /砂丘/
さきゆき /先行き/
さきょう /左京/
さきょうく /左京区/
さきょうしき /左京職;[律令制]朱雀大路西側の行政担当/
さきょうのだいぶ /左京大夫;[律令制]左京職の長官/
さきよみ /先読み/先読/
さきわけ /咲分け/
さきわたし /先渡し/
さきわれ /先割れ/
さきわれすぷーん /先割れスプーン/
さきん /砂金/差金/
さぎ /詐欺;fraud/鷺/詐偽;†いつわり/
さぎこうい /詐欺行為/
さぎさか /匂坂/
さぎさわ /鷺沢/
さぎざい /詐欺罪/
さぎし /詐欺師/サギ師/
さぎしち /鷺七/
さぎしょうほう /詐欺商法/
さぎじけん /詐欺事件/
さぎそう /鷺草/
さぎちょう /左義長;書き初めを燃やします/三毬杖/
さぎてき /詐欺的/
さぎぬま /鷺沼/
さぎぬまかん /鷺沼間/
さぎはさんざい /詐欺破産罪/
さぎょう /作業/サ行/さ行/
さぎょうい /作業衣/
さぎょういき /作業域/
さぎょういん /作業員/
さぎょうかせつ /作業仮説/
さぎょうかだい /作業課題/
さぎょうかてい /作業過程/
さぎょうかんきょう /作業環境/
さぎょうきおく /作業記憶/
さぎょうきかい /作業機械/
さぎょうきじゅん /作業基準/
さぎょうきょくせん /作業曲線/
さぎょうぎ /作業着/
さぎょうぐつ /作業靴/
さぎょうけいたい /作業形態/
さぎょうけんさ /作業検査/
さぎょうこうりつ /作業効率/
さぎょうざひょう /作業座標/
さぎょうしゃ /作業者/作業車/
さぎょうしゅうりょう /作業終了/
さぎょうしょ /作業所/
さぎょうじ /作業時/
さぎょうじかん /作業時間/
さぎょうじたい /作業自体/
さぎょうじゅうじ /作業従事/
さぎょうじゅうじしゃ /作業従事者/
さぎょうじょうきょう /作業状況/
さぎょうせん /作業船/
さぎょうだい /作業台/
さぎょうちゅう /作業中/
さぎょうづくえ /作業机/
さぎょうてき /作業的/
さぎょうてじゅん /作業手順/
さぎょうとちゅう /作業途中/
さぎょうどう /作業道/
さぎょうないよう /作業内容/
さぎょうにってい /作業日程/
さぎょうにんずう /作業人数/
さぎょうのうりつ /作業能率/
さぎょうば /作業場/
さぎょうひょう /作業表/
さぎょうび /作業日/
さぎょうふく /作業服/
さぎょうぶかい /作業部会/
さぎょうぶんせき /作業分析/
さぎょうぶんたん /作業分担/
さぎょうへいめん /作業平面/
さぎょうへんかくかつよう /サ行変格活用;[文法]サ変(〜する)/
さぎょうべつ /作業別/
さぎょうほうこく /作業報告/
さぎょうほうこくしょ /作業報告書/
さぎょうほうしん /作業方針/
さぎょうみす /作業ミス/
さぎょうよう /作業用/
さぎょうりょう /作業量;workload/作業料;fee/
さぎょうりょういき /作業領域/
さぎょうりょうほう /作業療法;[精医]/
さぎょうりょうほうし /作業療法士;occupational therapist(OT). 国家資格/
さぎり /狭霧/
さく /策/柵/作/佐久;地名/朔;朔日 ⇔晦/槊;ほこ/搾;搾取/昨;昨夜/咋;(くう)/窄;狭窄/酢;酢酸/柞;いすのき/炸;炸裂/筰;山田耕筰/削;削除/索;検索/錯;錯誤/筴/縒;より/鑿/做;「作」の異体字/簀;す/嘖;さいな・む/捉;(漢音) とら・える/齪;齷齪/冊;(慣用音)竹冊/册;「冊」の旧字/辟;?/乍;?/
さく> /昨;昨冬,昨シーズン,昨27日/
さくい /作為/作意/
さくいおん /錯イオン/
さくいちゅうしゅつ /作為抽出/
さくいてき /作為的/
さくいん /索引/
さくいんご /索引語/
さくえん /錯塩/
さくおう /策応/
さくおとこ /作男/
さくか /昨夏/さく果/朔果;※「さく」は草冠が必要(1-91-15)/
さくかんとく /作監督/
さくが /作画/
さくがかんとく /作画監督/
さくがぎじゅつ /作画技術/
さくがた /作型/
さくがら /作柄/
さくがりょく /作画力/
さくがん /削岩/鑿岩;=削岩/
さくがんき /削岩機/鑿岩機;=削岩機/
さくき /昨季/
さくきまで /昨季迄/
さくぎ /昨木/
さくぎょう /昨暁/
さくぎれ /索切/
さくぐ /索具/
さくげき /作劇/
さくげつ /昨月/
さくげん /削減/遡源;=そげん/溯源;=遡源/
さくげんきょうそう /削減競争/
さくげんこうか /削減効果/
さくげんとう /削減等/
さくげんは /削減派/
さくげんほう /削減法/
さくこん /昨今/
さくご /錯誤/索語/錯語/
さくごえ /柵越え/
さくさく /昨々/嘖々/
さくさくかん /サクサク感/
さくさん /酢酸/
さくざつ /錯雑/
さくし /作詞;-作曲/作詩;poesie/策士/錯視/佐久市;長野県/策試;科挙の最終試験/柵址/索師;?/
さくしーずん /昨シーズン/
さくしか /作詞家/
さくしさっきょく /作詞作曲/
さくししゃ /作詞者/作詩者;?/
さくししゃめい /作詞者名/
さくししょう /作詩賞/
さくしずけい /錯視図形/
さくしゃ /作者/
さくしゃいがい /作者以外/
さくしゃじしん /作者自身/
さくしゃたち /作者達/
さくしゃふめい /作者不明/
さくしゃべつ /作者別/
さくしゃほんにん /作者本人/
さくしゃめい /作者名/
さくしゅ /搾取/
さくしゅう /昨秋/作州/昨週/
さくしゅつ /作出/
さくしゅん /昨春/
さくしょ /索書/策書/
さくじ /作字/作事/
さくじつ /昨日/朔日/
さくじつしんや /昨日深夜/
さくじつはっそう /昨日発送/
さくじつはつばい /昨日発売/
さくじば /作事場/
さくじゅう /搾汁/
さくじょ /削除/
さくじょう /柵状/索条/作条/
さくじょうそしき /柵状組織/
さくじょかのう /削除可能/
さくじょきそく /削除規則/
さくじょほうほう /削除方法/
さくず /作図/
さくせい /作成;†create.「ファイルの-」/作製;†produce.「図面の-」/鑿井/
さくせいあん /作成案/
さくせいいらい /作成依頼/
さくせいかた /作成方/
さくせいかてい /作成過程/
さくせいかのう /作成可能/
さくせいかんきょう /作成環境/
さくせいがいしゃ /作成会社/
さくせいがわ /作成側/
さくせいきじ /作成記事/
さくせいきじゅん /作成基準/
さくせいきのう /作成機能/
さくせいご /作成後/
さくせいさぎょう /作成作業/
さくせいさくじょ /作成削除/
さくせいしえん /作成支援/
さくせいしゃ /作成者/作製者/
さくせいしゃいがい /作成者以外/
さくせいしょうにん /作成承認/
さくせいじ /作成時/作製時/
さくせいじき /作成時期/
さくせいじょう /作成上/作製上/
さくせいせきにんしゃ /作成責任者/
さくせいちゅう /作成中/
さくせいていあん /作成提案/
さくせいてじゅん /作成手順/
さくせいとうじ /作成当時/
さくせいとうひょう /作成投票/
さくせいにちじ /作成日時/
さくせいはいふ /作成配布/
さくせいひ /作成費/
さくせいび /作成日/
さくせいふか /作成不可/
さくせいぶ /作成部/
さくせいぶぶん /作成部分/
さくせいほう /作成法/
さくせいほうしき /作成方式/
さくせいほうほう /作成方法/
さくせいまえ /作成前/
さくせいまち /作成待ち/
さくせいもくひょう /作成目標/
さくせいよう /作成用/
さくせいようきゅう /作成要求/
さくせいようせい /作成要請/
さくせいようりょう /作成要領/
さくせいりゆう /作成理由/
さくせいれい /作成例/
さくせいろん /作成論/
さくせき /昨夕/
さくせつ /作設/錯節/
さくせん /作戦/作戰;「戦」旧字/
さくせんかいぎ /作戦会議/
さくせんきゅう /作戦級/
さくせんこうどう /作戦行動/
さくせんばん /作戦盤/
さくせんへんこう /作戦変更/
さくぜん /索然/
さくそう /錯綜/
さくぞう /作蔵/
さくぞうぶ /作像部/
さくたい /錯体/
さくたき /作滝/
さくたろう /朔太郎/
さくだい /作題/
さくだん /炸弾/
さくちゅう /作中/
さくちゅうじんぶつ /作中人物/
さくちょう /佐久町/昨朝/作調/錯聴/
さくつけ /作付/作付け/
さくづ /作図/
さくづけ /作付/作付け/
さくて /作手/
さくてい /策定/作庭/
さくていき /作庭記;世界最古のガーデニング入門書/
さくてき /索敵/
さくてきがわ /索敵側/
さくてきき /索敵機/
さくてきこうげき /索敵攻撃/
さくとう /作陶/昨冬/作東/作刀/
さくとうりょう /作陶料/
さくど /作土/
さくどう /策動/索道/
さくなみ /作並/
さくなみえき /作並駅/
さくにゅう /搾乳/
さくにゅうき /搾乳機;tapper/
さくにゅうよう /搾乳用/
さくねん /昨年/
さくねんあき /昨年秋/
さくねんいっぱい /昨年一杯/
さくねんくれ /昨年暮/
さくねんど /昨年度/
さくねんどうよう /昨年同様/
さくねんどばん /昨年度版/
さくねんなつ /昨年夏/
さくねんはる /昨年春/
さくねんひ /昨年比/
さくねんまつ /昨年末/
さくねんらい /昨年来/
さくのべ /作延/
さくはつ /炸発/
さくばく /索漠/索莫/索寞/
さくばん /昨晩/
さくばんしんや /昨晩深夜/
さくひこんぜ /昨非今是/
さくひょう /作表/
さくひょうきのう /作表機能/
さくひん /作品/
さくひんいご /作品以後/
さくひんいちらん /作品一覧/
さくひんか /作品化/
さくひんかいせつ /作品解説/
さくひんぐん /作品群/
さくひんしゅう /作品集/
さくひんしょう /作品賞/
さくひんしょうかい /作品紹介/
さくひんじたい /作品自体/
さくひんじょう /作品上/
さくひんじょうえいかい /作品上映会/
さくひんすう /作品数/
さくひんせかい /作品世界/
さくひんぜんたい /作品全体/
さくひんぜんぶ /作品全部/
さくひんたち /作品達/
さくひんちゅう /作品中/
さくひんない /作品内/
さくひんべつ /作品別/
さくひんめい /作品名/
さくひんもくろく /作品目録/
さくふ /作譜/
さくふう /作風/朔風/
さくふしゃ /作譜者/
さくぶつ /作物/
さくぶん /作文/
さくぶんぎじゅつ /作文技術/
さくぶんりょく /作文力/
さくへんきょく /作編曲/
さくほう /冊封;冊封体制/作法/昨報/
さくぼう /策謀/朔望/
さくぼうげつ /朔望月/
さくま /佐久間/作間/削磨/
さくましょうざん /佐久間象山/
さくません /佐久間線/
さくまち /佐久町/
さくみ /朔美/作見/
さくめ /作目/
さくめい /策命/錯迷/
さくもつ /作物/
さくもん /作文/策問/
さくや /昨夜/咲耶;名/
さくやく /炸薬/
さくやま /作山/咲山/
さくゆ /搾油/
さくゆう /昨夕/
さくら /桜/佐倉/佐久良/砂倉/紗倉/櫻;「桜」の旧字(人名用漢字)/
さくらい /桜井/櫻井/
さくらいえき /桜井駅/
さくらいせん /桜井線/
さくらいろ /桜色/
さくらうお /桜魚/
さくらえ /桜江/
さくらえび /桜蝦/
さくらおか /桜丘/
さくらおかじょし /桜丘女子/
さくらかわ /桜川/
さくらがい /桜貝/
さくらがおか /桜ヶ丘/桜丘/桜ケ丘/櫻ヶ丘/
さくらがほう /櫻画報/
さくらがみ /桜紙/
さくらがわ /桜川/
さくらぎ /桜木/桜樹/
さくらぎちょう /桜木町/櫻木町/
さくらぎちょうえきまえ /桜木町駅前/
さくらぎちょうかん /桜木町間/
さくらぐみ /桜組/
さくらこ /桜子/
さくらこうじ /桜小路/
さくらざわ /桜沢/
さくらし /佐倉市/
さくらしんまち /桜新町/
さくらじま /桜島/
さくらじまごう /桜島号/
さくらじません /桜島線/
さくらじまだいこん /桜島大根/
さくらじょうすい /桜上水/
さくらぜんせん /桜前線/
さくらそう /桜草/
さくらそうか /サクラソウ科/
さくらそうもく /サクラソウ目/Primulales/
さくらそうもくぐん /サクラソウ目群/
さくらだ /桜田/
さくらだい /桜鯛/桜台/
さくらだじゅんこ /桜田淳子/
さくらだもん /桜田門/
さくらだもんえき /桜田門駅/
さくらだもんがいのへん /桜田門外の変;[日本史]1860/
さくらぢゃや /桜茶屋/
さくらづき /桜月/
さくらづけ /桜漬;桜の花の漬物、またはピンク色にした大根の漬物/
さくらづつみ /桜堤/
さくらどおり /桜通/
さくらなべ /桜鍋;馬肉/
さくらなみき /桜並木/
さくらにく /桜肉;馬肉/
さくらのその /桜の園;Vishnevyi sad(1904), Chekhov/
さくらのみや /桜宮/
さくらば /桜庭/櫻庭/
さくらばし /桜橋/
さくらばな /桜花/
さくらひめぜんでんあけぼのぞうし /桜姫全伝曙草紙/
さくらふじ /桜富士/
さくらふぶき /桜吹雪/
さくらま /桜間/
さくらまち /桜町/
さくらまちてんのう /桜町天皇/
さくらまつり /桜祭/
さくらまんかい /桜満開/
さくらむし /桜蒸し/
さくらもち /桜餅/
さくらもと /桜本/
さくらもよう /桜模様/
さくらゆ /桜湯/
さくらん /錯乱/
さくらんじょうたい /錯乱状態/
さくらんぼ /桜桃/
さくらんぼう /桜桃/桜ん坊/
さくりつ /冊立/
さくりゃく /策略/
さくれい /作例/
さくれつ /炸裂/錯列/
さくろう /索郎/
さくわ /作話/索話/
さぐち /佐口/
さぐん /鎖群/
さけ /酒/鮭/
さけい /左傾/
さけうりば /酒売場/
さけかす /酒粕/
さけかわ /鮭川/
さけくせ /酒癖/
さけぐせ /酒癖/
さけずき /酒好き/
さけづくり /酒造り/
さけづけ /酒漬け/
さけてん /酒店/
さけに /酒煮/
さけのみ /酒飲み/酒飲/
さけびごえ /叫び声/
さけびたり /酒浸り/
さけびん /酒瓶/
さけみ /酒見/
さけめ /裂け目/裂目/
さけよい /酒酔い/
さける /辟/
さけるい /酒類/
さけん /差遣/
さげ /下げ/
さげあし /下げ足/
さげあま /下げ尼/
さげお /下げ緒/
さげかじ /下げ舵/
さげがみ /下げ髪;おさげ/垂髪/
さげしお /下げ潮/
さげしぶり /下げ渋り/
さげすみ /蔑み/貶み/
さげはば /下げ幅/
さげふだ /下げ札/
さげもどし /下げ戻し/
さげん /左舷/瑣言/
さこ /迫/佐古/逧/
さこう /酒匂/酒向/佐甲/鎖交/砂鉱/鎖港/
さこうしょう /砂鉱床/
さこうべん /左顧右眄/
さこえ /迫江/
さこく /鎖国/
さこくせいさく /鎖国政策/
さこだ /迫田/
さこつ /鎖骨/
さこん /左近/
さごし /青箭魚/
さごじょう /沙悟浄/
さごろも /狭衣/
さごろものたいしょう /狭衣大将;狭衣物語/
さごろもものがたり /狭衣物語/
ささ /笹/篠/佐々/些々/酒/小竹/
ささあめ /笹飴/
ささい /些細/瑣細/
ささえ /竹筒/小筒;酒(ささ)を入れる筒/支え/
ささお /笹尾/
ささおか /笹岡/佐佐岡/
ささかまぼこ /笹蒲鉾/
ささかみ /笹神/
ささかわ /笹川/
ささがわ /笹川/
ささき /佐々木/笹木/笹氣/
ささきこじろう /佐々木小次郎;剣客/
ささぎ /大角豆/
ささくら /笹倉/
ささぐり /篠栗/
ささげ /捧げ/大角豆/
ささげつつ /捧げ銃/
ささげもの /捧げ物/
ささこ /笹子/
ささこもち /笹子餅/
ささざき /笹崎/
ささざわ /笹沢/
ささした /笹下/
ささじま /笹島/
ささずし /笹寿司/
ささせ /笹瀬/
ささたけ /笹竹/篠竹/
ささたに /笹谷/
ささだ /笹田/
ささだんご /笹団子/
ささつ /査察/
ささつかん /査察官/
ささつせん /笹津線/
ささつだん /査察団/
ささつぶ /査察部/
ささづか /笹塚/
ささど /笹戸/
ささぬま /笹沼/
ささの /笹野/
ささのうち /笹之内/
ささのは /笹の葉;-さーらさら/
ささはら /笹原/佐々原/
ささぶね /笹舟/
ささべ /笹部/
ささべり /笹縁/
ささまき /笹巻/
ささみ /笹身;鶏肉/
ささめ /私語/
ささめき /私語/
ささめきごと /私語/
ささめごと /私語/
ささめゆき /細雪/
ささもと /笹本/篠本/
ささもり /笹森/
ささや /笹谷/笹屋/
ささやか /細やか/
ささやき /囁き;悪魔の-/
ささやとうげ /笹谷峠/
ささやま /篠山/笹山/
ささゆり /笹百合;lovely lily/
ささら /簓/
ささり /佐々里/
ささりんどう /笹竜胆/
ささわら /笹原/
ささわり /障り/
さざ /佐々/
さざえ /蠑螺/
さざえさん /サザエさん;[漫画]長谷川町子/
さざなみ /漣/さざ波/小波/細波/
さざれ /細/
さざんか /山茶花/
さし /沙市/砂嘴/左思;(?-308?) 詩人。『三都賦』/左史;⇔右史/渣滓/刺し/
さしあい /差し合い/
さしあし /差し足/差脚/
さしあたり /差し当たり/差し当り/
さしあみ /刺網/刺し網/
さしいれ /差し入れ/差入/差入れ/
さしうま /差し馬/
さしえ /挿絵/挿し絵/插絵;旧字混じり/插繪/
さしえがか /挿絵画家/
さしおさえ /差し押さえ/差押/差押え/差し押え/
さしおさえきんしざいさん /差押禁止財産/
さしかえ /差し替え/差替/
さしかけ /指し掛け/差掛け/
さしがさ /差し傘/
さしがね /差金/差し金/指金/指矩/
さしき /挿し木/佐敷/挿木/鎖式/
さしきず /刺し傷/
さしぐし /挿し櫛/
さしげ /差し毛/
さしこ /刺し子/刺子/
さしこおり /刺子織/
さしこみ /差し込み/差込み/
さしさわり /差し障り/差障り/
さししょうぎ /指将棋;⇔詰将棋/指し将棋/
さしず /指図/
さしずさいけん /指図債権/
さしずしょうけん /指図証券/
さしずにん /指図人;手形取引/
さしずめ /差し詰め/差詰め/
さしたる /然したる/
さしだ /指田/
さしだしにん /差出人/
さしちがえ /差し違え/刺し違え/
さしつかえ /差し支え/差支え/
さして /指し手/差し手/
さしで /差し出/
さしでぐち /差し出口/
さしでん /左氏伝;[略語]春秋左氏伝/
さしとめ /差し止め;出版-/差止/差止め/
さしとめせいきゅう /差し止め請求/差止め請求/
さしどめ /差止め/
さしなわ /差し縄/
さしにない /差し担い/
さしね /指値/指し値/さし値/
さしの /指野/
さしば /差し歯/差歯/
さしばし /刺し箸/
さしばな /挿花/
さしひき /差引/差し引き/差引き/
さしほ /挿穂;[園芸]/挿し穂;[園芸]挿し木する穂/
さしま /猿島/
さしみ /刺身/差し身/
さしみじょうゆ /刺身醤油/
さしみず /差し水/差水/
さしみぼうちょう /刺身包丁/刺し身包丁/
さしみよう /刺身用/
さしむかい /差向い/
さしめ /挿し芽/
さしもどし /差し戻し/差戻し/
さしもの /指物/
さしものし /指物師/
さしゅ /詐取/叉手/
さしゅう /査収/佐州;佐渡/
さしゅうごう /差集合/
さしゆうご /左支右吾/
さしょう /査証;visa/詐称/些少/左相/瑣小/
さしょうしゃ /詐称者/
さしょうべん /左少弁/
さしりょう /差料/差し料/
さしわたし /差渡し/
さしんしつ /左心室/
さしんぼう /左心房/
さじ /匙/些事/瑣事/佐治;地名/佐冶;?/
さじかげん /匙加減/
さじき /桟敷/
さじきせき /桟敷席/
さじま /佐島/
さじゅう /茶頭/
さじゅつ /詐術/
さじょう /鎖状/砂上/砂状/鎖錠/叉状/
さじょうしょう /左丞相;左大臣/
さじょうど /砂壌土/
さじん /砂塵/茶人/
さす /砂州/扠首;[建築]/
さすが /流石;当て字/遉;=流石/
さすけ /佐助/
さすだ /佐須田/
さすまた /刺股/指叉;=刺股/
さすらい /流離/
さすれば /然爲れば;「為」旧字/
さず /左図/
さずかりもの /授かり物/
させ /佐瀬/
させい /嗄声/
させき /沙石/砂石/
させつ /左折/
させつしゃ /左折車/
させつしんごう /左折信号/
させつじ /左折時/
させぼ /佐世保/
させぼこうせん /佐世保高専/
させぼし /佐世保市/
させぼせん /佐世保線/
させん /左遷/鎖線;―・―・/
させんけい /左線形/
させんせい /左旋性/
さぜん /作善/
さそ /誘/
さそいみず /誘い水/
さそう /佐宗/笹生/
さそく /左側/
さそり /蠍/蝎/
さそりおとこ /蠍男/
さそりざ /蠍座;Scorpius(Sco),(10.23-11.21)/
さそん /差損/
さぞ /嘸/
さぞかし /嘸かし/
さぞや /嘸や/
さた /沙汰/佐多/佐屋/沙多/
さたけ /佐竹/佐武/
さたみさき /佐多岬/
さたやみ /沙汰止み/
さたろう /佐太郎/
さたん /左端/嗟嘆/左袒/嗟歎/
さだ /定/貞/佐田/禎/偵/
さだあき /貞明/禎章/
さだい /佐大/
さだいえ /定家/
さだいしょう /左大将/
さだいじん /左大臣/
さだいべん /左大弁/
さだえ /貞江/
さだお /貞夫/貞雄/定夫/定雄/貞男/定男/貞郎;名/
さだおか /定岡/
さだおき /貞煕/
さだか /定か/
さだかた /定方/貞方/
さだかつ /定勝/
さだき /貞樹/定樹/貞木/
さだきち /定吉/
さだこ /貞子/
さだつぐ /貞次/
さだとし /貞俊/定利/
さだのぶ /定伸/
さだはる /貞治/
さだひこ /貞彦/定彦/
さだひろ /貞広/定宏/
さだまつ /貞松/定松/
さだまりごと /定まり事/
さだみさき /佐田岬/
さだみち /貞通/
さだみつ /貞光/
さだめ /定め/宿命/
さだめがき /定書/
さだめごと /定め事/
さだめし /定めし/
さだやす /定康/
さだゆき /貞行/
さだよし /貞芳/
さだん /左段/
さち /幸/倖/佐知/
さちえ /佐智恵/
さちお /幸雄/幸夫/佐千男/
さちこ /幸子/祥子/佐智子/早智子/佐知子/
さちゅう /左注/左註/沙中/砂中/
さちゅうかん /左中間;[野球]/
さちゅうぐうご /沙中偶語/
さちゅうべん /左中弁/
さちよ /祥代/
さっ /早/
さっか /作家/昨夏/作歌/擦過/
さっかーじょう /サッカー場/
さっかーせんしゅ /サッカー選手/
さっかーぶ /サッカー部/
さっかかつどう /作家活動/
さっかぎょ /溯河魚/
さっかく /錯覚;†illusion.「目の-」/錯角;†[数学]alternate angle.「-は等しい」/
さっかしょう /擦過傷/
さっかじん /作家陣/
さっかたち /作家達/
さっかべつ /作家別/
さっかめい /作家名/
さっかれん /作家連/
さっかん /作監/錯簡/
さっき /殺気/昨季/先刻;当て字/数奇/
さっきゅう /早急/遡及/
さっきょう /作況/作凶/
さっきょうしすう /作況指数/
さっきょく /作曲/
さっきょくか /作曲家/
さっきょくかめい /作曲家名/
さっきょくご /作曲後/
さっきょくしゃ /作曲者/
さっきょくしゃめい /作曲者名/
さっきょくしょう /作曲賞/
さっきょくじき /作曲時期/
さっきょくねんだい /作曲年代/
さっきょくほう /作曲法/
さっきょくほうほう /作曲方法/
さっきょくよう /作曲用/
さっきん /殺菌/
さっきんこうか /殺菌効果/
さっきんざい /殺菌剤/
さっきんりょう /殺菌料/
さっきんりょく /殺菌力/
さっく /作句/
さっこう /作興/
さっこん /昨今/
さっさ /佐々/
さっさじっちく /佐々十竹;儒学者(1640-1698)/
さっし /冊子/察し/刷子/
さっしこづつみ /冊子小包/
さっしど /サッシ戸/
さっしぼん /冊子本/
さっしまど /サッシ窓/
さっしゅう /薩州;薩摩/
さっしょう /殺傷/殺生/
さっしょうせき /殺生石/
さっしょうのうりょく /殺傷能力/
さっしょうりょく /殺傷力/
さっしん /刷新/殺身/
さっすい /撒水/
さっすう /冊数/
さっせい /殺生/殺青/
さっせつ /殺節/
さっそう /颯爽/
さっそく /早速/
さっそくにゅうしゅ /早速入手/
さっそざい /殺鼠剤/
さっち /察知/
さっちも /三進も/
さっちゅう /殺虫/
さっちゅうざい /殺虫剤/
さっちょう /薩長/
さっちょうれんごう /薩長連合;1866/
さって /幸手/
さってし /幸手市/
さっと /颯と/
さっとう /殺到/
さっとに /さっと煮/
さっぱ /撒播/拶双魚/
さっぱりかん /さっぱり感/
さっぱん /刷版/
さっぷ /撒布/
さっぷうけい /殺風景/
さっぽう /殺法/
さっぽろ /札幌/
さっぽろいかだいがく /札幌医科大学/
さっぽろいだい /札幌医大/
さっぽろえき /札幌駅/
さっぽろかん /札幌間/
さっぽろきねん /札幌記念/
さっぽろきんこう /札幌近郊/
さっぽろけいばじょう /札幌競馬場/
さっぽろこうさい /札幌高裁/
さっぽろこくさい /札幌国際/
さっぽろこくぜいきょく /札幌国税局/
さっぽろし /札幌市/
さっぽろしこうつうきょく /札幌市交通局/
さっぽろしてん /札幌支店/
さっぽろしない /札幌市内/
さっぽろたいかい /札幌大会/
さっぽろだいがく /札幌大学/
さっぽろてん /札幌店/
さっぽろはっちゃく /札幌発着/
さっぽろはつ /札幌発/
さっぽろばん /札幌版/
さっぽろびん /札幌便/
さっぽろほうめん /札幌方面/
さっぽろまるやまきゅうじょう /札幌円山球場/
さっぽろみなみこうこう /札幌南高校/
さっぽろめいぶつ /札幌名物/
さっぽん /刷本/
さつ /札/冊/刷/殺/察;警察/擦;摩擦/颯;颯爽/刹;(寺)古刹/箚/扎;(ぬく)/紮;結紮/撮;撮影/拶;挨拶/薩;薩摩/撒;撒布/册;「冊」の旧字/
さつい /殺意/
さついれ /札入れ;⇔小銭入れ/
さつう /茶通/
さつうばこ /茶通箱/
さつえい /撮影/
さつえいいち /撮影位置/
さつえいうらばなし /撮影裏話/
さつえいかい /撮影会/
さつえいかのう /撮影可能/
さつえいかんかく /撮影間隔/
さつえいかんとく /撮影監督/
さつえいき /撮影機/撮影器;?/
さつえいきざい /撮影機材/撮影器材;?/
さつえいきょり /撮影距離/
さつえいぎじゅつ /撮影技術/
さつえいけっか /撮影結果/
さつえいげんば /撮影現場/
さつえいこうか /撮影効果/
さつえいご /撮影後/
さつえいしゃ /撮影者/
さつえいじ /撮影時/
さつえいじかん /撮影時間/
さつえいじかんたい /撮影時間帯/
さつえいじょ /撮影所/
さつえいじょうきょう /撮影状況/
さつえいじょうけん /撮影条件/
さつえいずみ /撮影済/
さつえいせんそう /薩英戦争;1863/
さつえいせんよう /撮影専用/
さつえいぜんぱん /撮影全般/
さつえいたいしょう /撮影対象/
さつえいたいしょうぶつ /撮影対象物/
さつえいだい /撮影台/
さつえいち /撮影地/
さつえいちゅう /撮影中/
さつえいにちじ /撮影日時/
さつえいばいりつ /撮影倍率/
さつえいばしょ /撮影場所/
さつえいふうけい /撮影風景/
さつえいぶ /撮影部/
さつえいほう /撮影法/
さつえいほうほう /撮影方法/
さつえいまえ /撮影前/
さつえいもくてき /撮影目的/
さつえいよう /撮影用/
さつえいりょこう /撮影旅行/
さつがい /殺害/
さつがいしゃ /殺害者/
さつがいじけん /殺害事件/
さつき /皐月;陰暦5月/皐/五月/佐月/早月/
さつきあめ /五月雨;=さみだれ/
さつきがおか /五月丘/
さつきしょう /皐月賞/
さつきしょうば /皐月賞馬/
さつきだ /五月田/
さつきちょう /五月町/
さつきばれ /五月晴れ/五月晴/
さつきやま /五月山/
さつきやみ /五月闇/
さつげんがっき /擦弦楽器;⇔撥弦楽器/
さつこう /殺光/
さつしょぶん /殺処分/
さつじん /殺人/殺陣/
さつじんき /殺人鬼/
さつじんげんば /殺人現場/
さつじんこうい /殺人行為/
さつじんざい /殺人罪/
さつじんしゃ /殺人者/
さつじんしょうどう /殺人衝動/
さつじんじけん /殺人事件/
さつじんてき /殺人的/
さつじんてきこんざつ /殺人的混雑/
さつじんはん /殺人犯/
さつすう /冊数/
さつぞう /撮像/
さつぞうけい /撮像系/
さつたば /札束/
さつなん /薩南/
さつぬません /札沼線/
さつばつ /殺伐/
さつびら /札片/
さつま /薩摩/
さつまあげ /薩摩揚げ/
さつまいも /薩摩芋/さつま芋/甘藷/
さつまじしょ /薩摩辞書/
さつまじる /薩摩汁/
さつまのかみ /薩摩守/
さつまはやと /薩摩隼人/
さつまはん /薩摩藩/
さつまはんとう /薩摩半島/
さつまばん /薩摩版/
さつまびわ /薩摩琵琶/
さつまべん /薩摩弁/
さつまやき /薩摩焼/
さつめ /冊目/
さつもん /擦文/
さつもんどき /擦文土器/
さつもんぶんか /擦文文化/
さつゆう /殺熊/
さつよう /撮要/
さつりく /殺戮/
さづか /佐塚/
さて /扨/偖/
さてい /査定/
さていかかく /査定価格/
さていしゃ /査定者/
さておき /扨措き/
さてつ /砂鉄/蹉跌;stumble/
さてん /茶店/
さてんじ /サテン地/
さで /叉手/
さでん /佐伝/
さと /里/郷/智/聡/理/聰;旧字/
さとい /里居/
さといも /里芋/
さといもか /サトイモ科/
さといももく /サトイモ目/Arales/Spathiflorae/
さとう /砂糖/佐藤/差等/茶湯;=ちゃとう/左党/佐東/左道;=さどう/
さとういり /砂糖入/
さとうえいさく /佐藤栄作/
さとうがし /砂糖菓子/
さとうきび /砂糖黍/
さとうじょうゆ /砂糖醤油/
さとうだいこん /砂糖大根/
さとうづけ /砂糖漬/
さとうに /砂糖煮/
さとうにしき /佐藤錦/
さとうはるお /佐藤春夫/
さとうみず /砂糖水/
さとえ /さと江/
さとおさ /里長/
さとおや /里親/
さとかた /里方/
さとがえり /里帰り/
さとこ /聡子/智子/里子/理子/郷子/佐登子/沙都子/砂登子/
さとことば /里言葉/
さとご /里子/
さとごころ /里心/
さとざくら /里桜/
さとし /聡/理/知/智/聖/哲/恵/敏/悟/賢/覚/慧/諭/訓/聰;旧字/智史/智志/聡志/悟史/聡史/叡/里志/覺;旧字/理史/智嗣/覚志/
さとしょう /里庄/
さとだ /里田/
さとなか /里中/
さとなかまちこ /里中満智子/
さとひろ /理洋/
さとふか /里深/
さとぼう /里坊/
さとみ /里美/智美/里見/聡美/恵規/悟美/沙都美/聡巳/
さとみつ /理満/
さとみはっけんでん /里見八犬伝/
さとむら /里村/
さとやま /里山/
さとゆき /里雪/
さとり /悟り/
さとる /達/知/悟/智/暁;名/哲/聡/覚/了/覺;旧字/逹;「達」の異体字/
さど /佐渡/砂土/
さどう /作動/茶道/差動/左道;=さとう/佐道/茶頭/
さどうおん /作動音/
さどうがた /差動型/
さどうぐち /茶道口;[茶道]/
さどうせいげん /差動制限/
さどうちゅう /作動中/
さどうふりょう /作動不良/
さどうぶ /茶道部/
さどおけさ /佐渡おけさ;[民謡]/
さどがしま /佐渡島/
さどがや /佐渡谷/
さどきせん /佐渡汽船/
さどく /査読/
さどくいいん /査読委員/
さどくいらい /査読依頼/
さどくけっか /査読結果/
さどくし /査読子/
さどくしゃ /査読者/
さどやま /佐渡山/
さどわら /佐土原/
さない /佐内/左内/
さなえ /早苗/早生/早植/差波江/
さなか /最中/
さながら /宛ら/
さなき /鐸/
さなぎ /蛹/佐薙/
さなぎゆ /蛹油/
さなげ /猿投/
さなげやま /猿投山/
さなごうち /佐那河内/
さなだ /真田/
さなだたいへいき /真田太平記/
さなだひも /真田紐/
さなだまさゆき /真田昌幸/
さなだむし /真田虫/
さなだゆきむら /真田幸村/
さなみ /佐奈美/
さなる /佐鳴/
さぬき /讃岐;香川/佐貫;千葉/
さぬきかがわ /讃岐香川/
さぬきじん /讃岐人/
さぬきはくちょう /讃岐白鳥/
さぬきべん /讃岐弁/
さぬま /砂沼/
さね /実/核/札/
さねあつ /実篤/
さねちか /実近/
さねとう /実藤/實藤/
さねとみ /実美/
さねはる /実治/
さねもりものがたり /実盛物語/
さの /佐野/
さのう /左脳/砂嚢/佐納/
さのかわ /佐野川/
さのさか /佐野坂/
さのさぶし /さのさ節;(明治)/
さのし /佐野市/
さのしろう /佐野史郎/
さは /左派/
さはい /差配/
さはち /皿鉢;-料理/
さはちりょうり /皿鉢料理;土佐名物/
さはら /佐原/薩哈剌;Sahara/
さはん /茶飯/
さはんじ /茶飯事/
さば /鯖/佐波;地名/生飯/鯆;さば,いるか/
さばえ /鯖江/五月蠅/
さばおり /鯖折り/
さばかん /鯖缶/
さばき /捌/裁き/捌き/
さばきやく /捌役/
さばく /砂漠/沙漠;desert/佐幕/
さばくか /砂漠化;desertification/
さばくちたい /砂漠地帯/
さばくちゅう /砂漠中/
さばぐも /鯖雲/
さばし /佐橋/
さばずし /鯖鮨/鯖寿司/
さばひい /虱目魚/
さばぶし /鯖節;鯖で作った鰹節(もどき)/
さひょうえ /左兵衛/
さひょうえのかみ /左兵衛督;[律令制]/
さひょうえのじょう /左兵衛尉;[律令制]/
さび /錆/寂/銹;≒錆/鏥;「銹」の異体字/皺;衣服にできるしわ/
さびいろ /錆色/
さびえ /錆絵/
さびしがりや /寂しがり屋/淋しがり屋;そんなあなたはちょっと-さん/
さびしろ /淋代/
さびどめ /錆止め/さび止め/錆び止め/
さびねず /錆鼠/
さびょう /詐病/
さびれ /寂れ/
さぶ /佐武/
さぶしょ /三仏生/
さぶまりんとっきょ /サブマリン特許/
さぶらい /侍/
さぶろう /三郎/三朗/
さぶん /差分/
さぶんかい /差分解/
さぶんきんじ /差分近似/
さぶんけいしき /差分形式/
さぶんじょうほう /差分情報/
さぶんてん /差分点/
さぶんほう /差分法/
さぶんほうていしき /差分方程式/
さへん /左辺/サ変;[文法][略語]サ行変格活用(する)/
さへんち /左辺値/
さへんどうし /サ変動詞/
さべつ /差別/
さべついしき /差別意識/
さべつか /差別化/
さべつかいしょう /差別解消/
さべつかんじょう /差別感情/
さべつかんぜい /差別関税/
さべつこうい /差別行為/
さべつこうぞう /差別構造/
さべつご /差別語/
さべつしそう /差別思想/
さべつしゃ /差別者/
さべつしゅぎ /差別主義/
さべつしゅぎしゃ /差別主義者/
さべつじけん /差別事件/
さべつじったい /差別実態/
さべつせい /差別性/
さべつたいぐう /差別待遇/
さべつたいしょう /差別対象/
さべつてき /差別的/
さべつてきいしき /差別的意識/
さべつてきいと /差別的意図/
さべつてきこうい /差別的行為/
さべつてきひょうげん /差別的表現/
さべつてきようご /差別的用語/
さべつはいし /差別廃止/
さべつはつげん /差別発言/
さべつひはん /差別批判/
さべつひょうげん /差別表現/
さべつもんだい /差別問題/
さべつよう /差別用/
さべつようご /差別用語/
さべつろんしゃ /差別論者/
さべん /左弁/
さべんかん /左弁官/
さほ /佐保/左保/沙穂/
さほう /作法/左方/差法/
さほこ /佐保子/
さほど /然程/
さほやま /佐保山/
さぼう /砂防/茶房/詐謀/
さぼうだむ /砂防ダム/
さぼてん /仙人掌/覇王樹/
さぼてんもく /サボテン目/Cactales/
さぽーとじょうほう /サポート情報/
さま /様/樣;「様」の旧字(人名用漢字)/
さまかた /様方/
さまかたち /様形/
さまがわり /様変わり/様変り/
さまさま /様々/様様/
さまざま /様々/様様/
さまたげ /妨げ/
さまつ /瑣末/些末/
さまづけ /様付け;人を「○○様」と呼ぶこと/
さまに /様似/
さまのかみ /左馬頭/
さまのすけ /左馬助/
さまほん /様本/
さまりうむ /Sm/Samarium/
さみ /三味/沙弥/
さみしがりや /淋しがり屋/寂しがり屋/
さみず /三水/
さみせん /三味線/
さみだれ /五月雨/
さみだれぐも /五月雨雲/
さみだれしき /五月雨式/
さむ /寒/作務/
さむえ /作務衣/
さむかぜ /寒風/
さむかわ /寒川/
さむかわじんじゃ /寒川神社/
さむかわちょう /寒川町/
さむがり /寒がり/
さむがわ /寒川/
さむけ /寒気/
さむげたん /参鶏湯/
さむさ /寒さ/
さむざむ /寒々/
さむぞら /寒空/
さむよ /寒夜/
さむらい /侍/士/
さめ /鮫/雨/
さめいし /鮫石/
さめかわ /鮫川/
さめがい /醒ケ井/
さめがわ /鮫皮/沙皮/
さめこもん /鮫小紋/
さめしま /鮫島/
さめじま /鮫島/
さめす /鮫州/
さめはだ /鮫肌/鮫膚/
さも /然も/
さもじ /杓文字/左文字/
さもん /査問/左門/沙門/砂紋/
さもんじ /左文字/
さや /鞘;刀の-/莢;豆の-/沙耶/紗綾/佐屋/匣鉢;窯の中で焼き物を保護する容器/
さやあて /鞘当て/鞘当/
さやいんげん /莢隠元/
さやえんどう /莢豌豆/
さやか /沙也加/
さやく /鎖鑰/
さやこ /清子/彩也子/
さやどう /鞘堂/
さやま /狭山/佐山/茶山/
さやまし /狭山市/
さやまめ /莢豆/
さやよせ /鞘寄せ/
さゆ /白湯/素湯;=白湯/
さゆう /左右/←→/
さゆううち /左右打ち/
さゆうかくにん /左右確認/
さゆうぎゃく /左右逆/
さゆうぎゃくぞう /左右逆像/
さゆうけんよう /左右兼用/
さゆうこうご /左右交互/
さゆうさ /左右差/
さゆうじく /左右軸/
さゆうじょうげ /左右上下/
さゆうそうしょう /左右相称/
さゆうそくめん /左右側面/
さゆうたいしょう /左右対称/
さゆうたいしょうせい /左右対称性/
さゆうたん /左右端/
さゆうどう /左右動/
さゆうどくりつ /左右独立/
さゆうはんてん /左右反転/
さゆうひたいしょう /左右非対称/
さゆうほうこう /左右方向/
さゆうりょうたん /左右両端/
さゆうりょうほう /左右両方/
さゆり /小百合/早百合/沙由里/
さよ /小夜/
さよう /作用/左様/佐用;地名/左用/左葉/然様/
さよういん /作用因/
さようかく /作用角/
さようきじょ /作用機序/
さようし /作用子/
さようじゅんじょ /作用順序/
さようせん /作用線/
さようそ /作用素/
さようそろん /作用素論/
さようてん /作用点/
さようでんきょく /作用電極/
さようなら /左様なら/
さようはんさよう /作用反作用/
さよきょく /小夜曲/
さよく /左翼/
さよくしゅ /左翼手/
さよくせき /左翼席/
さよくてき /左翼的/
さよこ /小夜子/佐代子/沙夜子/紗世子/
さよしぐれ /小夜時雨/
さよならがち /サヨナラ勝ち/
さよならまけ /サヨナラ負け/
さより /細魚/
さら /皿/更/沙羅/
さらあらい /皿洗い;The dishwasher returns!/
さらい /杷;(農機具)/作礼/浚い/渫い/復習/
さらいげつ /再来月/
さらいしゅう /再来週/
さらいねん /再来年/
さらう /攫/
さらうどん /皿饂飩/皿うどん/
さらえ /杷/
さらかず /皿数/
さらがた /皿型/
さらきん /サラ金;サラリーマン金融/
さらこばち /皿小鉢/
さらさ /更紗/
さらさら /更々/
さらし /晒/曝し;-を巻く/晒し;-タマネギ/
さらしあん /晒し餡/
さらしくび /晒し首/
さらしこ /晒し粉/
さらしな /更級/更科/
さらしなきこう /更科紀行/
さらしなぐん /更級郡/
さらしなこ /更科粉/
さらしなそば /更科蕎麦/
さらしなにっき /更級日記/
さらしなのき /更科記/
さらしもの /晒し者/
さらしや /晒屋/
さらじゅ /沙羅樹/娑羅樹;=沙羅樹/
さらす /晒/
さらせにあもく /サラセニア目/Sarraceniales/
さらそうじゅ /沙羅双樹/娑羅双樹;=沙羅双樹/
さらだあぶら /サラダ油/
さらだな /サラダ菜/
さらだゆ /サラダ油/
さらち /更地/
さらなる /更なる/
さらに /更に/
さらぬ /然らぬ/
さらば /然らば/
さらばち /皿鉢/
さらべつ /更別/
さらまわし /皿回し/
さらまんだ /沙羅曼蛇/
さらやしき /皿屋敷;お菊さんが出ます/
さらやま /皿山/
さらゆ /新湯/
さり /紗理/
さりぎわ /去り際/
さりじょう /去り状/
さりちるさん /サリチル酸;[化学]salicylic acid. C6H4(OH)COOH/
さりとて /然りとて/
さりょう /茶寮/査領/
さる /猿/申;[十二支]9/沙流/去る;連体詞/
さるお /猿尾/
さるかい /猿飼/
さるがき /桾/
さるがく /猿楽/申楽/猿学/
さるがくし /猿楽師/
さるぎ /猿木/
さるくら /猿倉/
さるぐつわ /猿轡/
さるぐんだん /猿軍団/
さるげ /猿毛/
さるげんとどくさか /サルゲントドクサ科/Sargentodoxaceae/
さること /然ること/
さるしばい /猿芝居/
さるすべり /百日紅/
さるた /猿田/
さるたひこ /猿田彦/
さるぢえ /猿知恵/
さるとび /猿飛/
さるとびさすけ /猿飛佐助/
さるどし /申年/
さるのこしかけ /胡孫眼/
さるはし /猿橋/
さるばし /猿橋/
さるふぁざい /サルファ剤/
さるふつ /猿払/
さるまた /猿股/
さるまね /猿真似/
さるまわし /猿回し/
さるめんかじゃ /猿面冠者/
さるめんかんじゃ /猿面冠者/
さるや /猿谷/
さるやま /猿山/
さるわか /猿若/
さるわかちょう /猿若町;地名,現在の台東区/
さるわたり /猿渡/
されい /茶礼/
されき /砂礫/
されこうべ /髑髏/
さろま /佐呂間/
さわ /沢/澤;「沢」の旧字/茶話/佐和/佐波/
さわい /澤井/沢井/
さわいずみ /沢泉/
さわいり /沢入/
さわうち /沢内/澤内/
さわおか /澤岡/
さわかい /茶話会/
さわがに /沢蟹/
さわき /沢木/澤木/
さわぎ /騒ぎ/
さわぎうた /騒ぎ唄/
さわくり /沢栗/
さわぐち /沢口/
さわこ /佐和子/
さわざき /澤崎/沢崎/
さわすぎ /沢杉/
さわた /佐和田/
さわたり /沢渡/
さわだ /澤田/沢田/澤多/
さわだけんじ /沢田研二/
さわち /皿鉢/
さわちりょうり /皿鉢料理/
さわとうげ /沢峠/
さわの /沢野/
さわのぼり /沢登り/澤登/沢登/
さわはた /澤幡/
さわべ /沢辺/
さわまつ /沢松/
さわむら /沢村/澤村/
さわむらしょう /沢村賞/
さわもと /澤本/
さわや /沢弥/澤谷/
さわやか /爽やか/
さわやなぎ /沢柳/
さわやま /沢山/佐和山/
さわら /鰆/椹/佐原;地名/早良/
さわらし /佐原市/
さわらび /早蕨/
さわり /触り;-だけ見せる NB:「一番良い部分」の意。「始めの部分」ではない/障り;(trouble) -が出る,差し-/
さわわたり /沢渡/
さわん /左腕/
さわんとうしゅ /左腕投手/
さん /酸/産/山/三/算/桟;戸の-/散/参/賛/讃;≒賛/贊;「賛」の旧字/讚;「讃」の異体字/攅;(あつめる)/纉;(つぐ)/鑽;研鑽/鑚;「鑽」の異体字/惨;悲惨/慘;「惨」の旧字/參;「参」の旧字/驂;(そえうま)/彡/杉;すぎ/衫;(うすもの)/珊;珊瑚/刪;(けずる)刪除/跚;蹣跚(よろけ)/粲/燦;燦然/纂;編纂/簒;簒奪/戔;(すくない)/棧;桟橋/撒;撒水/繖;(かさ)/蚕;養蚕/蠶;「蚕」の旧字/蒜;大蒜(にんにく)/嶄/汕/潸/爨;飯盒炊爨/芟/斬/傘;傘下/餐;晩餐/３/3/
さん> /三/
さんあい /三愛/
さんあくどう /三悪道;[仏教]地獄道・餓鬼道・畜生道/
さんあくにん /三悪人/
さんあんこー /三暗刻/
さんい /賛意/三位/産衣/
さんいけっていせん /三位決定戦/
さんいち /三一/
さんいちしょぼう /三一書房;[出版社名]/
さんいっち /三一致/
さんいつ /散逸/散佚/
さんいつかてい /散逸過程/
さんいつけい /散逸系/
さんいつこうぞう /散逸構造/
さんいん /山陰/参院/産院/
さんいんぎいん /参院議員/
さんいんせん /参院選/山陰線/
さんいんちほう /山陰地方/
さんいんどう /山陰道/
さんいんほうそう /山陰放送/
さんいんほうめん /山陰方面/
さんいんほんかいぎ /参院本会議/
さんいんほんせん /山陰本線/
さんう /山雨/
さんえ /三慧;[仏教]/三会;[仏教]/三衣;[仏教]/
さんえい /三栄/
さんえいちょう /三栄町/
さんえいっぱつ /三衣一鉢;坊さん/
さんえき /酸液/三駅/
さんえん /山塩/三遠/
さんえんしゅぎ /三猿主義;NB:見ざる・言わざる・聞かざる/
さんおう /三桜/
さんおくえんじけん /三億円事件/
さんおんとう /三温糖/
さんか /参加/酸化/傘下/産科/賛歌/讃歌/惨禍/山火/山下/山河/山窩/
さんか> /酸化;[化学]oxide/
さんかあえん /酸化亜鉛/
さんかあんない /参加案内/
さんかい /散会;adjourn.「議会を-する」/山海;山と海/山塊;massif/参会;attend/散開;deploy.「歩兵を-させる」/三階/三回/3回/
さんかいき /三回忌/
さんかいご /散会後/
さんかいしき /参加意識/
さんかいじゅく /山海塾/
さんかいせいだん /散開星団;[天文]open cluster. eg. Pleiades/
さんかいめ /三回目/３回目/
さんかうけつけ /参加受付/
さんかえん /酸化炎;[化学]/酸化焔;[化学]/
さんかかくじ /参加各自/
さんかかくてい /参加確定/
さんかかのう /参加可能/
さんかかんげんこうそ /酸化還元酵素;[生化学]oxidoreductase/
さんかかんげんはんのう /酸化還元反応;[化学]redox reaction/
さんかがた /参加型/
さんかきかん /参加期間/
さんかきぼう /参加希望/
さんかきぼうしゃ /参加希望者/
さんかきん /参加金/
さんかきんたい /山河襟帯/
さんかぎんでんち /酸化銀電池;[化学]/
さんかく /三角/参画/△/▽/▲/▼/∴/∵/贊畫;旧字/3角/
さんかくいた /三角板/
さんかくか /三角化/
さんかくかんけい /三角関係/
さんかくかんすう /三角関数/三角函数/
さんかくきん /三角巾/三角筋/
さんかくぎょうれつ /三角行列/3角行列/
さんかくけい /三角形/3角形/
さんかくけいぶんかつ /三角形分割/
さんかくこーなー /三角コーナー/
さんかくざ /三角座;Triangulum(Tri)/
さんかくじょうぎ /三角定規/
さんかくす /三角州/
さんかくすい /三角錐/
さんかくそくりょう /三角測量/
さんかくちたい /三角地帯/
さんかくちゅう /三角柱/
さんかくてん /三角点/
さんかくとう /三角塔/
さんかくなみ /三角波/
さんかくは /三角波/
さんかくひ /三角比/
さんかくふらすこ /三角フラスコ/
さんかくほう /三角法/
さんかくぼう /三角帽/
さんかくぼうえき /三角貿易/
さんかくぼうし /三角帽子/
さんかくまど /三角窓/
さんかくもくば /三角木馬;拷問道具/
さんかくやろう /三角野郎/
さんかけいしき /参加形式/
さんかけってい /参加決定/
さんかけん /参加券/
さんかげつ /三ヶ月/三カ月/三箇月/
さんかこう /参加校/
さんかこうそ /酸化酵素;[生化学]oxidase/
さんかこく /参加国/
さんかごきぼう /参加御希望/
さんかさくひん /参加作品/
さんかざい /酸化剤/
さんかしかく /参加資格/
さんかしせい /参加姿勢/
さんかしゃ /参加者/
さんかしゃいしき /参加者意識/
さんかしゃうけつけちゅう /参加者受付中/
さんかしゃかくい /参加者各位/
さんかしゃかん /参加者間/
さんかしゃこじん /参加者個人/
さんかしゃしめい /参加者氏名/
さんかしゃすう /参加者数/
さんかしゃぜんいん /参加者全員/
さんかしゃそうすう /参加者総数/
さんかしゃたすう /参加者多数/
さんかしゃたち /参加者達/
さんかしゃにんずう /参加者人数/
さんかしゃぼしゅう /参加者募集/
さんかしゃめい /参加者名/
さんかしゃめいぼ /参加者名簿/
さんかしゃゆうし /参加者有志/
さんかしゅう /山家集;西行の歌集/
さんかしょ /三個所/
さんかしょう /参加賞/参加証/参加章/
さんかしんせい /参加申請/
さんかじ /参加時/
さんかじき /参加時期/
さんかじゅん /参加順/
さんかじゅんび /参加準備/
さんかじょうけん /参加条件/
さんかじんこう /参加人口/
さんかすいぎん /酸化水銀;[化学]HgO,Hg2O/
さんかすう /参加数/酸化数;[化学]oxidation number/
さんかせんしゅ /参加選手/
さんかせんりょう /酸化染料/
さんかそしき /参加組織/
さんかた /三方/
さんかだいがく /参加大学/
さんかだいきん /参加代金/
さんかだいすう /参加台数/
さんかだんたい /参加団体/傘下団体/
さんかちっそ /酸化窒素;NxOx/
さんかちゅう /参加中/
さんかっけい /三角形/3角形/
さんかっけいがた /三角形型/
さんかてつ /酸化鉄/
さんかとうろく /参加登録/
さんかとうろくひ /参加登録費/
さんかどう /酸化銅/
さんかなまり /酸化鉛;[化学]PbO,PbO2,Pb3O4/
さんかにんずう /参加人数/
さんかにんずうぶん /参加人数分/
さんかねつ /酸化熱/
さんかはんのう /酸化反応/
さんかば /参加馬/
さんかひ /参加費/
さんかひそ /酸化砒素;[化学]As2O3,As2O5/
さんかひむりょう /参加費無料/
さんかひょうめい /参加表明/
さんかひよう /参加費用/
さんかび /参加日/
さんかふのう /参加不能/
さんかぶつ /酸化物/
さんかほうこく /参加報告/
さんかほうほう /参加方法/
さんかぼうしざい /酸化防止剤/
さんかぼしゅう /参加募集/
さんかまえ /参加前/
さんかまく /酸化膜/
さんかむりょう /参加無料/
さんかめいが /三化螟蛾/
さんかめいぼ /参加名簿/
さんかもうしこみ /参加申し込み/参加申込/
さんかもうしこみあんない /参加申込案内/
さんかもうしこみしょ /参加申込書/
さんかようこう /参加要項/
さんかよてい /参加予定/
さんかよていしゃ /参加予定者/
さんかよていび /参加予定日/
さんかりつ /参加率/
さんかりょう /参加料/
さんかん /参観/山間/三巻/三冠/三関/三韓/三管;笙・篳篥・笛/三竿/参看;参照/算勘/散官/三浣/三澣;=三浣/
さんかんおう /三冠王/
さんかんがく /産官学/
さんかんけい /三環系/
さんかんしおん /三寒四温/
さんかんしき /三管式/
さんかんせん /三冠戦/
さんかんば /三冠馬/
さんかんび /参観日/
さんかんぶ /山間部/
さんが /山河/参賀/
さんがい /三階/三界;-に家なし/惨害/
さんがいせき /三階席/
さんがいだて /三階建て/
さんがいぶし /三階節;[民謡]新潟/
さんがく /山岳/産学/算額/産額/散楽/
さんがくおう /山岳王/
さんがくかい /山岳会/
さんがくかん /産学官/
さんがくきょうどう /産学協同/産学共同/
さんがくくかん /山岳区間/
さんがくしゃしん /山岳写真/
さんがくしんこう /山岳信仰/
さんがくせん /山岳線/
さんがくたび /山岳旅/
さんがくちたい /山岳地帯/
さんがくとう /山岳党;[世界史]Montagnards/
さんがくぶ /山岳部/
さんがくぶっきょう /山岳仏教/
さんがくよう /山岳用/
さんがくりん /山岳林/
さんがくろせん /山岳路線/
さんがっき /三学期/
さんがつ /三月/３月/3月/弥生;※連想,旧暦/
さんがつかくめい /三月革命/
さんがにち /三が日/三ヶ日/三箇日/
さんがね /三ケ根/
さんがねさん /三ヶ根山/
さんがわら /桟瓦;波状の(ありふれた)瓦/
さんがん /三願/三眼/三観/
さんがんし /三眼視/
さんき /算機/山気/三機/
さんきし /三騎士/
さんきち /三吉/
さんきゃく /三脚/山脚/
さんきゃくしよう /三脚使用/
さんきゃくよう /三脚用/
さんきゅう /産休/三級/山九/
さんきゅうだん /三球団/
さんきょ /山居/
さんきょう /山峡/三峡/三共/三強/三協/
さんきょうしょうじ /三協商事;[企業名]/
さんきょうせいやく /三共製薬;[企業名]/
さんきょうだい /三兄弟/
さんきょくめ /三曲目/
さんきん /三禁/
さんきんこうたい /参勤交代/
さんぎ /参議/算木/
さんぎいん /参議院/
さんぎいんぎいん /参議院議員/
さんぎいんせんきょ /参議院選挙/
さんぎょう /産業/三行/蚕業/三業/鑽仰/
さんぎょうい /産業医/
さんぎょうおうようぶもん /産業応用部門/
さんぎょうか /産業化/
さんぎょうかい /産業界/
さんぎょうかいかん /産業会館/
さんぎょうかくめい /産業革命/
さんぎょうかくめいじだい /産業革命時代/
さんぎょうかつどう /産業活動/
さんぎょうきかい /産業機械/
さんぎょうきょういく /産業教育/
さんぎょうきょうかい /産業協会/
さんぎょうこうきょう /産業公共/
さんぎょうこうぞう /産業構造/
さんぎょうさいせいきこう /産業再生機構;www.ircj.jp/
さんぎょうさいせいほう /産業再生法/
さんぎょうざいさん /産業財産/
さんぎょうざいさんけん /産業財産権/
さんぎょうしせつ /産業施設/
さんぎょうしほん /産業資本;industrial capital/
さんぎょうしゃかい /産業社会/
さんぎょうしゃかいがく /産業社会学;industrial sociology/
さんぎょうしゃりょう /産業車両/
さんぎょうしょう /産業省/
さんぎょうしんぶん /産業新聞/
さんぎょうしんりがく /産業心理学;industrial psychology/
さんぎょうじょう /産業上/
さんぎょうじょうほう /産業情報/
さんぎょうすぱい /産業スパイ/
さんぎょうせいさく /産業政策/
さんぎょうてき /産業的/
さんぎょうとしょ /産業図書/
さんぎょうどうろ /産業道路/
さんぎょうはいきぶつ /産業廃棄物/
さんぎょうはいすい /産業排水;⇔生活排水/
さんぎょうべつ /産業別/
さんぎょうぼうえき /産業貿易/
さんぎょうぼうえきかん /産業貿易館/
さんぎょうめ /3行目/
さんぎょうよう /産業用/
さんぎょうれんかんひょう /産業連関表/
さんく /産駒/惨苦/三区/
さんぐ /蚕具/
さんぐう /参宮/三宮/
さんぐん /三軍/
さんけ /三家/産気/
さんけい /産経/山系/参詣/三景/算計/散形/三計;一年・十年・一生の計画/
さんけいえん /三渓園/
さんけいおおさかはい /産経大阪杯/
さんけいかじょ /散形花序/繖形花序/
さんけいしょう /産経賞/
さんけいしんぶん /産経新聞/
さんけいしんぶんしゃ /産経新聞社;[企業名]www.sankei.co.jp/
さんけいみち /参詣道/
さんけた /三桁/
さんけたほう /三桁法/
さんけつ /酸欠/三傑/
さんけつし /酸欠死/
さんけつしょう /酸血症;[医]/
さんけつじょうたい /酸欠状態/
さんけん /散見/三軒/産研/三権/三研/
さんけんぶんりつ /三権分立/
さんげ /散華/山下/
さんげき /惨劇/
さんげさんげ /懺悔懺悔/
さんげたん /參鶏湯/
さんげつ /山月/
さんげつき /山月記;中島敦/
さんげん /三元/三絃/三弦;三味線／和琴・楽琵琶・楽箏/山弦/
さんげんしょく /三原色/
さんげんじゃや /三軒茶屋/
さんげんじゃやほうめん /三軒茶屋方面/
さんげんぢゃや /三軒茶屋/
さんこ /三鈷/三顧/3個/
さんこう /参考/山行/三光/散光/三皇/参向/三項/3項/三高/三江/三晃/三興/三考;再思-/三后;太皇太后・皇太后・皇后/鑽孔/
さんこういけん /参考意見/
さんこうかんけい /三項関係/3項関係/
さんこうきせん /三光汽船/
さんこうざい /散孔材/
さんこうしつ /参考室/
さんこうしゅってん /参考出展/
さんこうしゅっぴん /参考出品/
さんこうしょ /参考書/
さんこうしょせき /参考書籍/
さんこうしょもく /参考書目/
さんこうしょるい /参考書類/
さんこうしりょう /参考資料/
さんこうじこう /参考事項/
さんこうじょうほう /参考情報/
さんこうすいちょう /山高水長/
さんこうず /参考図/
さんこうせいうん /散光星雲/
さんこうせいさく /三光政策/
さんこうせん /三江線/
さんこうち /参考値/
さんこうちょう /三光鳥/
さんこうていど /参考程度/
さんこうてんし /三光天子/
さんこうとしょ /参考図書/
さんこうにん /参考人/
さんこうぶんけん /参考文献/
さんこうぶんけんなど /参考文献等/
さんこうぶんけんめい /参考文献名/
さんこうぶんれい /参考文例/
さんこうもく /3項目/
さんこうろんぶん /参考論文/
さんこく /惨酷/
さんこつ /散骨/
さんこのれい /三顧の礼/
さんご /産後/珊瑚/
さんごいろ /珊瑚色;coral red/
さんごう /三号/三郷/三合/山号/三業;[仏教]身業・口業・意業/参號;「号」旧字/三綱/三劫/
さんごうかん /三号館/
さんごかい /珊瑚海/
さんごかいかいせん /珊瑚海海戦/
さんごく /三国/三石/
さんごくかんしょう /三国干渉/
さんごくきょうしょう /三国協商/
さんごくし /三国志;中国の歴史書。正史のひとつ。著者は陳寿/三國志/三国史;?/
さんごくしえんぎ /三国志演義/
さんごくしかんけい /三国志関係/
さんごくしじだい /三国志時代/
さんごくじだい /三国時代/
さんごくじん /三国人/
さんごくどうめい /三国同盟/
さんごしょう /珊瑚礁/サンゴ礁/
さんごじゅ /珊瑚樹/
さんごせい /珊瑚製/
さんさ /三叉/
さんさい /山菜/三才/三彩;唐-/三菜;一汁-/三歳/
さんさいりょうり /山菜料理/
さんさく /散策/
さんさくどう /散策道/
さんさくひん /三作品/
さんさしんけい /三叉神経/
さんさつ /三冊/
さんさろ /三叉路/
さんさん /三々/燦々/三三;[囲碁]/珊々/
さんさんくど /三三九度/
さんさんごご /三々五々/三三五五/
さんさんななびょうし /三三七拍子/
さんざい /散在;あちこちにある/散財;expense/散剤;powder medicine/
さんざし /山査子;植物名/
さんざん /散々/三山/散散/惨々;?/
さんし /三枝/蚕糸/三子/三誌/三思/産仔/三史;史記・漢書・後漢書/
さんしあい /三試合/
さんしぇん /三弦/
さんしき /算式/三色/
さんしすいめい /山紫水明/
さんした /三下/
さんしつ /蚕室/産室/散失/
さんしまい /三姉妹/
さんしゃ /三者/三社/山車/三舎/
さんしゃきょうどう /三社共同/
さんしゃく /参酌/
さんしゃくだま /三尺玉/
さんしゃさんよう /三者三様/
さんしゃしょうけい /三斜晶系;[化学]triclinic system/
さんしゃたくいつ /三者択一/
さんしゃぼんたい /三者凡退/
さんしゃめんだん /三者面談/
さんしゅ /三種/
さんしゅう /参集/三州;三河/三舟;勝海舟・高橋泥舟・山岡鉄舟/讃州;讃岐/参州;三河/山州;山城/纂輯/三周/3週/
さんしゅうかん /三週間/
さんしゅうき /三周忌/
さんしゅうしゃ /三修社;[出版社名]ドイツ関連。www.sanshusha.co.jp/
さんしゅうめ /三週目/
さんしゅつ /算出;calcurate/産出;produce/
さんしゅつかんすう /算出関数/
さんしゅつきじゅん /算出基準/
さんしゅつけっか /算出結果/
さんしゅつふくよう /三出複葉/３出複葉/
さんしゅつほう /算出法/
さんしゅつほうほう /算出方法/
さんしゅつりょう /産出量/
さんしゅのじんぎ /三種の神器/
さんしゅるい /三種類/
さんしょ /山椒/
さんしょう /参照/三章/山椒/三唱/三省;[律令制]式部省,民部省,兵部省/三賞/三焦/酸漿/
さんしょううお /山椒魚/鯢/
さんしょうかしょ /参照箇所/
さんしょうかんけい /参照関係/
さんしょうしんごう /参照信号/
さんしょうじ /参照時/
さんしょうすう /参照数/
さんしょうせん /参照線/
さんしょうち /参照値/
さんしょうてん /参照点/
さんしょうでんきょく /参照電極/
さんしょうはんい /参照範囲/
さんしょうぶんけん /参照文献/
さんしょうほう /参照法/
さんしょうめん /参照面/
さんしょうもと /参照元/
さんしょうよう /参照用/
さんしょうわく /参照枠/
さんしょく /三色/三食/蚕食/
さんしょくき /三色旗/
さんしょくすみれ /三色菫;[植物]pensee sauvage/
さんしょくどうこく /三色同刻/
さんしょくどうじゅん /三色同順/
さんしろう /三四郎/三士郎/
さんしろういけ /三四郎池/
さんしん /三振/三線;沖縄の撥弦楽器/三信;[仏教]至心・信楽・欲生/三進/参審/三審;地裁・高裁・最高裁/三身;[仏教]法身・報身・応身/三伸;追伸の追伸/参進/
さんしんき /三神器/
さんしんご /三振後/
さんしんざん /三神山;蓬莱,方丈,瀛州／富士,熊野,熱田/
さんしんすう /三振数/
さんしんせい /参審制/
さんしんだつしゅ /三振奪取/
さんしんとう /三親等/
さんしんとうない /三親等内/
さんしんびる /三信ビル/
さんじ /惨事;disaster/参事;counselor/賛辞/讃辞;=賛辞/産児/三次/３次/3次/三時/3時/
さんじかい /三次会/
さんじかん /参事官/3時間/
さんじく /三軸/
さんじげん /三次元/３次元/3次元/
さんじげんくうかん /三次元空間/
さんじげんてき /三次元的/
さんじげんぶったい /三次元物体/３次元物体/
さんじせいげん /産児制限/
さんじみゃく /三次脈/
さんじゃく /三尺/
さんじゃくだま /三尺玉/
さんじゃまつり /三社祭;浅草神社/
さんじゅ /傘寿;80歳/
さんじゅう /三重/三十/卅/
さんじゅういちもじ /三十一文字/
さんじゅうく /三重苦/
さんじゅうけつごう /三重結合/
さんじゅうさつ /三重殺/
さんじゅうさんげんどう /三十三間堂/
さんじゅうさんしょ /三十三所;西国-/
さんじゅうし /三銃士/
さんじゅうしょう /三重唱/
さんじゅうじ /三重字/
さんじゅうすいそ /三重水素;tritium/
さんじゅうすうねん /三十数年/
さんじゅうそう /三重奏/
さんじゅうそうきょく /三重奏曲/
さんじゅうだい /三十代/
さんじゅうにんまち /三十人町/
さんじゅうねんせんそう /三十年戦争/
さんじゅうのとう /三重塔/
さんじゅうはちどせん /三十八度線;朝鮮戦争の休戦ライン(N38°)/
さんじゅうぼいん /三重母音;[音声学]triphthong/
さんじゅうろう /三十郎/
さんじゅうろっかせん /三十六歌仙/
さんじゅうろっけい /三十六計;-逃げるに如かず/
さんじゅつ /算術/
さんじゅつえんざん /算術演算/
さんじゅつえんざんし /算術演算子/
さんじゅつか /算術化/
さんじゅつかんすう /算術関数/
さんじゅつがた /算術型/
さんじゅつけいさん /算術計算/
さんじゅつしき /算術式/
さんじゅつしょ /算術書/
さんじゅつてき /算術的/
さんじゅつへいきん /算術平均/
さんじゅん /相俊/
さんじょ /賛助/三女/産所/刪除/
さんじょう /参上/惨状/山上/三条/三條/三乗/
さんじょうえき /三条駅/
さんじょうかいかん /山上会館/
さんじょうかん /三条間/
さんじょうき /三畳紀;[地質年代]Triassic.25100-19500万年前/
さんじょうけいはん /三条京阪/
さんじょうけいはんまえ /三条京阪前/
さんじょうこん /三乗根;[数学]third root/
さんじょうちょう /三条町/
さんじょうてんのう /三条天皇/
さんじょうほうめん /三条方面/
さんじょかいいん /賛助会員/
さんじょかいいんしゃ /賛助会員社/
さんじょきん /賛助金/
さんじょく /産褥/
さんじょくき /産褥期/
さんじょくねつ /産褥熱;[医]puerperal fever/
さんじん /山人/
さんすい /山水/散水/撒水/
さんすいが /山水画/
さんすいき /散水機/
さんすいしゃ /散水車/
さんすいせん /散水栓/
さんすいでんき /山水電気/
さんすう /算数/
さんすうかじゅぎょう /算数科授業/
さんすうけんてい /算数検定/
さんすくみ /三竦み/
さんすくりっとご /サンスクリット語;Sanskrit. 梵語/
さんすんだま /三寸玉/
さんず /三途/
さんずい /三水;[部首]「泳」の偏/
さんずのかわ /三途の川/
さんずん /三寸/
さんずんふりつ /三寸不律/
さんせ /三施;[仏教]財施・法施・無畏施/
さんせい /賛成/酸性/三世/山西/産生/三星/三省/三聖/参政/三精/惨凄/惨悽/
さんせいいけん /賛成意見/
さんせいう /酸性雨/
さんせいかはんすう /賛成過半数/
さんせいがわ /賛成側/
さんせいけん /参政権/
さんせいこ /酸性湖/
さんせいし /酸性紙/
さんせいしゃ /賛成者/三世社/
さんせいしゃたすう /賛成者多数/
さんせいしょくひん /酸性食品/
さんせいすい /酸性水/
さんせいすいようえきちゅう /酸性水溶液中/
さんせいたすう /賛成多数/
さんせいとうひょう /賛成投票/
さんせいど /酸性度;acidity/酸性土;acid soil/
さんせいどう /三省堂/
さんせいどうしょてん /三省堂書店/
さんせいどうほんてん /三省堂本店/
さんせいどじょう /酸性土壌/
さんせいは /賛成派/
さんせいはんたい /賛成反対/
さんせいひょう /賛成票/
さんせいひょうめい /賛成表明/
さんせいむ /酸性霧/
さんせいようえきちゅう /酸性溶液中/
さんせいりゆう /賛成理由/
さんせいろん /賛成論/
さんせき /山積/
さんせく /三セク;[略語]第三セクター/
さんせつこん /三節棍/
さんせん /参戦/三線/三選/山川/三遷/
さんせんけ /三千家/
さんせんそうもく /山川草木/
さんせんべん /三尖弁/
さんぜ /三世/
さんぜん /産前/燦然/参禅/三千/
さんぜんいん /三千院/
さんぜんさんご /産前産後/
さんぜんじょう /三千丈/
さんぜんせかい /三千世界/
さんぜんり /三千里/
さんそ /酸素/O/Oxygen/
さんそう /山荘/三相/三層/山僧/三索/散層/酸愴/惨愴/
さんそうけん /産総研;[略語]産業技術総合研究所/
さんそうこうりゅう /三相交流/
さんそきゅうにゅう /酸素吸入/
さんそきょうきゅう /酸素供給/
さんそきょうきゅうのうりょく /酸素供給能力/
さんそきょうきゅうりょう /酸素供給量/
さんそぎょらい /酸素魚雷/
さんそけい /酸素系/
さんそけつぼうしょう /酸素欠乏症/
さんそこうぎょう /酸素工業/
さんそこきゅう /酸素呼吸/
さんそせっしゅのうりょく /酸素摂取能力/
さんそたいしゃ /酸素代謝/
さんそちゅうどく /酸素中毒/
さんそどういたいひ /酸素同位体比/
さんそのうど /酸素濃度/
さんそぶそく /酸素不足/
さんそぶんあつ /酸素分圧/
さんそぼんべ /酸素ボンベ/
さんそん /山村/散村/
さんぞう /三蔵/
さんぞうほうし /三蔵法師/
さんぞく /山賊/
さんぞくせい /三属性/
さんぞくなべ /山賊鍋/
さんぞくばん /山賊版/
さんぞくやき /山賊焼き/
さんぞん /三尊;[仏教]/
さんたい /三体/三態;固体・液体・気体/三諦;[仏教]空諦・仮諦・中諦/算体/三台;-星/
さんたいせい /三台星/
さんたく /三択/
さんたま /三多摩/
さんたろう /三太郎/
さんたん /惨憺;-たる結果/賛嘆;admire/惨澹;=惨憺/讃嘆;=賛嘆/讃歎;=賛嘆/山丹;姫百合/三嘆;-これ久しゅうす/三歎;=三嘆/
さんたんか /山丹花;[植物]/
さんたんし /三端子/
さんたんとう /三炭糖;[化学]triose. C3H6O3/
さんだ /三田/
さんだい /参内/散大/三大/三代/三台/三題/産大;[略語]産業大学/
さんだいきゃくしき /三代格式/
さんだいしゅう /三代集;古今・後撰・拾遺/
さんだいじ /三大寺/
さんだいせつ /三大節;四方拝・紀元節・天長節/
さんだいばなし /三題噺/三題話/
さんだいめ /三代目/
さんだいりょうり /三大料理/
さんだつ /簒奪/
さんだつしゃ /簒奪者/
さんだや /三田屋/
さんだゆう /三太夫/
さんだん /算段/散弾/三段/霰弾;=散弾/
さんだんかい /三段階/
さんだんがまえ /三段構え/
さんだんきょう /三段峡/
さんだんげり /三段蹴り/
さんだんじゅう /散弾銃/
さんだんとび /三段跳/三段跳び/
さんだんばら /三段腹/
さんだんめ /三段目/
さんだんろんぽう /三段論法/
さんち /産地/山地/三値/
さんちたい /山地帯/
さんちちょくそう /産地直送/
さんちちょくばい /産地直売/
さんちちょっけつ /産地直結/
さんちゃ /三軒茶屋/
さんちゃく /参着/三着/
さんちゃほう /三家和/
さんちゅう /山中/
さんちゅうごえ /山中越/
さんちょう /山頂/三鳥/
さんちょうふきん /山頂付近/
さんちょうめ /三丁目/
さんちょく /産直/
さんつう /三通/産痛/
さんづくり /彡旁/
さんづけ /さん付け;人を「○○さん」と呼ぶこと。vouvoiement/
さんてい /算定/刪定/算程/
さんていばん /三訂版/
さんていほう /算定法/
さんていほうほう /算定方法/
さんてつ /三鉄/鑽鉄/
さんてん /三点/山巓/散点/…/3点/
さんてんせいやく /参天製薬;[企業名]/
さんてんとうし /三点透視/
さんてんりーだー /三点リーダー/…/……/
さんでん /散田/三伝/参殿/
さんと /三都/三斗/
さんとう /三島/山東/三等/三党/三頭/三東/山刀/算当/
さんとうか /山頭火/
さんとうきょうでん /山東京伝/
さんとうきん /三頭筋/
さんとうさい /山東菜/
さんとうしゃ /三等車/
さんとうせいじ /三頭政治/
さんとうはんとう /山東半島/
さんとうぶん /三等分/
さんとうへい /三等兵/
さんとおり /3通り/
さんとく /三徳/
さんとのふ /三都の賦/
さんど /三度/酸度;acidity/
さんどう /賛同/参道/山道/産道/散瞳/三道/参堂/
さんどうしゃ /賛同者/
さんどうしょ /賛同書/
さんどうやく /散瞳薬/
さんどがさ /三度笠/
さんどく /三毒/
さんどぬり /三度塗/
さんどまめ /三度豆;隠元豆,莢豌豆/
さんどめ /三度目/
さんない /山内/三内/
さんなん /三男/山南/
さんなんぼう /三男坊/
さんにゅう /参入;enter/算入;count in/酸乳;sour milk/
さんにゅうしょうへき /参入障壁/
さんにゅうじ /参入時/
さんにん /三人/３人/3人/
さんにんいじょう /三人以上/
さんにんぐみ /三人組/
さんにんさんよう /三人三様/
さんにんしまい /三人姉妹/
さんにんしょう /三人称/
さんにんたび /三人旅/
さんにんまえ /三人前/
さんにんむすめ /三人娘/
さんにんめ /三人目/
さんねん /三年/３年/
さんねんいか /三年以下/
さんねんいじょう /三年以上/
さんねんご /三年後/
さんねんざか /三年坂/
さんねんじ /三年次/三年時/
さんねんせい /三年生/3年生/
さんねんまえ /三年前/
さんのう /山王/
さんのうびょういん /山王病院/
さんのうまつり /山王祭;日吉大社・日枝神社/
さんのつぎ /三の次/
さんのつづみ /三の鼓;雅楽器/
さんのへ /三戸/
さんのまる /三の丸/
さんのみや /三宮/三の宮/
さんのみやえき /三宮駅/
さんのみやかん /三宮間/
さんのみやこうかした /三宮高架下/
さんはい /山廃/
さんはんきかん /三半規管/
さんば /産婆/三馬/三羽/生飯/散飯/
さんばい /三倍/三杯/
さんばいず /三杯酢/
さんばいぞうじょうしゅ /三倍増醸酒/
さんばいたい /三倍体;[生物]triploid/
さんばいまん /三倍満;[麻雀]/
さんばかたいしょう /三馬鹿大将/
さんばがらす /三羽烏/
さんばがわ /三波川/
さんばし /桟橋/棧橋/
さんばじゅつ /産婆術;ソクラテス/
さんばそう /三番叟/
さんばば /三婆/
さんばん /三番/
さんばんかん /三番館/
さんばんがい /三番街/
さんばんしょうぶ /三番勝負/
さんばんちょう /三番町/
さんばんめ /三番目/3番目/
さんぱ /三派/散播/撒播/
さんぱい /参拝/惨敗/産廃;[略語]産業廃棄物/酸敗/三拝/贊拜;旧字/
さんぱいきゃく /参拝客/
さんぱいきゅうはい /三拝九拝/
さんぱいしょり /産廃処理/
さんぱく /三泊/三拍/
さんぱくがん /三白眼/
さんぱつ /散髪/散発/三発/
さんぱつご /散髪後/
さんぱつてき /散発的/
さんぱつや /散髪屋/
さんぱつりょう /散髪料/
さんび /賛美/讃美;=賛美/酸鼻;-を極める/
さんびか /賛美歌/讃美歌/
さんびき /三匹/
さんびゃく /三百/
さんびゃくだいげん /三百代言/
さんびゃくにんまち /三百人町/
さんびゃくねんかん /三百年間/
さんびょうし /三拍子/
さんぴ /賛否/
さんぴょう /散票/
さんぴりょうろん /賛否両論/
さんぴん /三一/
さんふくせん /三複線/
さんふじんか /産婦人科/
さんふらんしすこ /桑港/
さんぶ /山武/三部/三分/
さんぶかい /三部会/
さんぶぎょう /三奉行;[日本史]寺社・町・勘定奉行/
さんぶぐん /山武郡/
さんぶさく /三部作/
さんぶつ /産物/讃仏/
さんぶつじ /三仏寺/
さんぶつじょう /讃仏乗/
さんぶん /散文/三分/
さんぶんし /散文詩/
さんぶんしてき /散文詩的/
さんぶんてき /散文的/
さんぶんるい /三分類/
さんぷ /散布/産婦/撒布/参府/算譜/
さんぷう /杉風;1647-1732/
さんぷく /山腹/三伏/
さんぷくつい /三幅対/
さんぷず /散布図/
さんぷたい /撒布体/
さんぷるばん /サンプル盤/
さんぷん /三分/
さんぷんかん /三分間/
さんへいほう /三平方/
さんべつ /産別;[略語]産業別(労働組合)/
さんべんしゅ /三鞭酒/
さんぺい /散兵/三平/
さんぺいじる /三平汁/
さんぺいせん /散兵線/
さんぺき /三碧;[陰陽道]/
さんほうこう /三方向/
さんぼう /参謀/三方/三宝/
さんぼうかん /三宝柑/
さんぼうこうじん /三宝荒神;[仏教]仏法僧の守護神/
さんぼうそうちょう /参謀総長/
さんぼうほんぶ /参謀本部/
さんぼく /三木/山北/
さんぼだい /三菩提/
さんぼん /三本/≡/
さんぼんあし /三本足/
さんぼんがわ /三本川/
さんぼんぎ /三本木/
さんぼんじめ /三本締め/
さんぼんすぎ /三本杉/
さんぼんだて /三本建/
さんぼんばしら /三本柱/
さんぼんまつ /三本松/
さんぼんめ /三本目/
さんぼんゆび /三本指/
さんぽ /散歩/三歩/刪補/
さんぽう /算法/三宝/三方/山砲/纂法/
さんぽういん /三宝院/
さんぽうげんご /算法言語/
さんぽちゅう /散歩中/
さんぽみち /散歩道/
さんま /秋刀魚/
さんまい /三昧/三枚/産米/
さんまいおろし /三枚下ろし;[料理]/
さんまいきょう /三昧境/
さんまいめ /三枚目/
さんまきめ /三巻目/
さんまん /散漫/三万/
さんみ /酸味/三位/
さんみいったい /三位一体/
さんみつ /三密/
さんみゃく /山脈/三藐/
さんみょう /三明/
さんみりょう /酸味料/
さんみんしゅぎ /三民主義/
さんめい /山名/三名/賛明/3名/
さんめん /三面/
さんめんきじ /三面記事/
さんめんきょう /三面鏡/
さんめんず /三面図/3面図/
さんめんろっぴ /三面六臂/
さんもうさく /三毛作/
さんもく /三目/
さんもじ /三文字/3文字/
さんもん /山門/三文/三門/
さんもんおぺら /三文オペラ/
さんもんきょう /三門峡/
さんもんばん /三文判/
さんもんぶんし /三文文士/
さんや /山野/山谷/三夜/
さんやく /三役/山薬;[漢方]ヤマイモ/散薬/纂訳/
さんやくいじょう /三役以上/
さんやそう /山野草/
さんゆ /産油/
さんゆうかん /三遊間/
さんゆうてい /三遊亭/
さんゆこく /産油国/
さんよ /参与/參與/贊譽/三余/
さんよう /山陽/三洋/山容/算用/三様;三者-/
さんようしょうかい /三陽商会/
さんようしょうけん /三洋証券;[企業名]NB:1999年に破産/
さんようしょうじ /三洋商事;[企業名]/
さんようしんかんせん /山陽新幹線/
さんようしんぶん /山陽新聞/
さんようじ /山陽路/
さんようじどうしゃどう /山陽自動車道/
さんようすうじ /算用数字/
さんようせん /山陽線/
さんようそ /三要素/
さんようちほう /山陽地方/
さんようちゅう /三葉虫/
さんようてつどう /山陽鉄道/
さんようでんき /三洋電機;[企業名]/
さんようでんしゃ /山陽電車/
さんようでんてつ /山陽電鉄/
さんようとっきゅう /山陽特急/
さんようどう /山陽道/
さんようひめじ /山陽姫路/
さんようほうそう /山陽放送/
さんようほうめん /山陽方面/
さんようほんせん /山陽本線/
さんよかん /参与官/
さんよかんさつ /参与観察/
さんらーたん /酸辣湯/
さんらい /三礼;周礼,儀礼,礼記/
さんらく /三楽/惨落/
さんらん /散乱/産卵/燦爛/
さんらんかいゆう /産卵回遊/
さんらんかく /散乱角/
さんらんかん /産卵管;[生物]ovipositor/
さんらんき /産卵期/
さんらんけい /産卵鶏/
さんらんげん /散乱源/
さんらんこう /散乱光/
さんらんしょう /産卵床/
さんらんじょう /産卵場/
さんらんせん /散乱線/
さんらんそう /産卵槽/
さんらんたい /散乱体/
さんらんてん /散乱点/
さんらんは /散乱波/
さんらんはんしゃ /散乱反射/
さんらんばこ /産卵箱/
さんらんばしょ /産卵場所/
さんらんほうほう /産卵方法/
さんらんほせい /散乱補正/
さんらんりろん /散乱理論/
さんり /三里/
さんりく /三陸/
さんりくかいがん /三陸海岸/
さんりつ /簒立/
さんりづか /三里塚/
さんりゃく /三略/
さんりゅう /三流/山流/
さんりゅうしゅ /散粒種/
さんりょう /産量/山稜;尾根/山陵;山と丘/三稜/算料/
さんりょうきょう /三稜鏡;prism/
さんりょうけい /三稜形/
さんりん /三輪/山林/
さんりんか /三輪花/
さんりんしゃ /三輪車/
さんりんしょとく /山林所得/
さんりんじてんしゃ /三輪自転車/
さんりんじぬし /山林地主/
さんりんぼう /三隣亡/
さんりんよう /三輪用/
さんる /三流/
さんるい /三塁/
さんるいがわ /三塁側/
さんるいしゅ /三塁手/
さんるいせん /三塁線/
さんるいそうしゃ /三塁走者/
さんるいだ /三塁打/
さんれい /山嶺/山霊/
さんれいごしん /三令五申/
さんれつ /参列/三裂/惨烈/3列/
さんれつしゃ /参列者/
さんれん /三連/
さんれんきゅう /三連休/
さんれんしょう /三連勝/
さんれんせい /三連星/
さんれんせん /三連戦/
さんれんぞく /三連続/
さんれんたん /三連単/
さんれんぱ /三連覇/
さんれんぱい /三連敗/
さんれんぱつ /三連発/
さんれんぷ /三連符/
さんれんぷく /三連複/
さんろう /参籠/
さんろうた /三朗太/
さんろく /山麓/
さんわ /三和/三羽/三話/
さんわぎんこう /三和銀行/
さんわこうさん /三和興産/
さんわせいさくしょ /三和製作所;[企業名]/
さんわり /三割/
ざ /座/挫;捻挫/坐;≒座/左/蔵;※「蔵王」の一部?/藏;「蔵」の旧字(人名用漢字)/
ざーさい /搾菜/
ざい /財/在/罪/材/剤;薬剤/座位/斉;(呉音)/西;東西/済;経済/才/戝;「財」の異体字/劑;「剤」の旧字/濟;「済」の旧字/
ざい> /在;在日,在中,在イラク/
ざいあく /罪悪/
ざいあくかん /罪悪感/
ざいあくし /罪悪視/
ざいい /在位/
ざいいきかん /在位期間/
ざいえい /在英/
ざいえき /在役/
ざいおう /在欧/
ざいか /財貨/罪科/罪過/在荷/
ざいかい /財界/在会/
ざいかいじん /財界人/
ざいかた /在方/
ざいかん /在韓;in South Korea/在監;in prison/在官;in office/在館/
ざいかんちゅう /在官中/
ざいかんべいぐん /在韓米軍/
ざいがい /在外/
ざいがいけんきゅういん /在外研究員/
ざいがいこうかん /在外公館/
ざいがいほうじん /在外邦人/
ざいがく /在学/
ざいがくきかん /在学期間/
ざいがくしゃ /在学者/
ざいがくしょうめいしょ /在学証明書/
ざいがくせい /在学生/
ざいがくちゅう /在学中/
ざいきゅう /罪咎/
ざいきょう /在京/在郷/
ざいきん /在勤/
ざいきんてあて /在勤手当/
ざいぎょう /罪業/
ざいく /細工/
ざいけ /在家/
ざいけい /財形/財経/
ざいけいちょちく /財形貯蓄/
ざいけいほうていしゅぎ /罪刑法定主義/
ざいげん /財源/
ざいげんかくほ /財源確保/
ざいこ /在庫/財庫/
ざいこいっそう /在庫一掃/
ざいこう /在校/在広/
ざいこうせい /在校生/
ざいこかんり /在庫管理/
ざいこきんしょう /在庫僅少/
ざいこく /在国/
ざいこくがい /在国外/
ざいこしょぶん /在庫処分/
ざいこじゅんかん /在庫循環/
ざいこちょうせい /在庫調整/
ざいことうし /在庫投資/
ざいこひん /在庫品/
ざいこひんはんばい /在庫品販売/
ざいこぶそく /在庫不足/
ざいこりょう /在庫量/
ざいごう /罪業/在郷/
ざいごうぐんじん /在郷軍人/
ざいごうぐんじんかい /在郷軍人会;legion/
ざいさん /財産/
ざいさんか /財産家/
ざいさんかんり /財産管理/
ざいさんく /財産区/
ざいさんけい /財産刑/
ざいさんけん /財産権/
ざいさんぜい /財産税/
ざいさんそうぞく /財産相続/
ざいさんてき /財産的/
ざいさんぶんよ /財産分与;離婚による-/
ざいさんぶんり /財産分離/
ざいさんもくろく /財産目録/
ざいしつ /材質/在室/罪質/
ざいしつひょうじ /材質表示/
ざいしゃ /在社/
ざいしゅう /罪囚/
ざいしゅく /在宿/
ざいしょ /在所/
ざいしょう /罪障/罪証/
ざいしょく /在職/
ざいしょくきかん /在職期間/
ざいしょくしゃ /在職者/
ざいしょくしょうめい /在職証明/
ざいしょくちゅう /在職中/
ざいじゅう /在住/
ざいじゅうしゃ /在住者/
ざいじょう /罪状/
ざいじょうにんぴ /罪状認否/
ざいす /座椅子/
ざいせ /在世/財施;[仏教]/
ざいせい /財政/在世/
ざいせいあかじ /財政赤字/
ざいせいがく /財政学/
ざいせいきき /財政危機/
ざいせいくろじ /財政黒字/
ざいせいさいけん /財政再建/
ざいせいざいさん /財政財産/
ざいせいししゅつ /財政支出/
ざいせいしゅうし /財政収支/
ざいせいじじょう /財政事情/
ざいせいじょうきょう /財政状況/
ざいせいじょうたい /財政状態/
ざいせいたんとう /財政担当/
ざいせいちょうせいききん /財政調整基金/
ざいせいてき /財政的/
ざいせいてきこんなん /財政的困難/
ざいせいとうゆうし /財政投融資/
ざいせいなん /財政難/
ざいせいほう /財政法/
ざいせいめん /財政面/
ざいせいゆうししきん /財政融資資金/
ざいせき /在籍;†enroll.「大学に-する」/在席;†attend.「課長は-している」/材積/罪責;guiltiness/罪跡;evidence/在昔/
ざいせきかん /罪責感/
ざいせきしゃ /在籍者/
ざいせきじ /在籍時/
ざいせきちゅう /在籍中/
ざいせん /在仙/
ざいぜん /財前/
ざいぞく /在俗/
ざいぞくそう /在俗僧/
ざいたい /罪体/
ざいたく /在宅/
ざいたくいりょう /在宅医療/
ざいたくかんご /在宅看護/
ざいたくきょういく /在宅教育;home schooling/
ざいたくきんむ /在宅勤務/
ざいたくけあ /在宅ケア;home care/
ざいたくびじねす /在宅ビジネス/
ざいたくふくぎょう /在宅副業/
ざいたくわーく /在宅ワーク/
ざいだん /財団/
ざいだんさいけん /財団債権/
ざいだんほうじん /財団法人/
ざいちゅう /在中/
ざいちょう /在庁/
ざいつ /財津/
ざいつかずお /財津和夫/
ざいてい /在廷/
ざいていしょうにん /在廷証人/
ざいてん /在天/
ざいとう /財投/在島/
ざいとうさい /財投債/
ざいに /在荷/
ざいにち /在日/
ざいにちかんこく /在日韓国/
ざいにちかんこくじん /在日韓国人/
ざいにちがいこくじん /在日外国人/
ざいにちちゅう /在日中/
ざいにちちゅうごくじん /在日中国人/
ざいにちちょうせんじん /在日朝鮮人/
ざいにちべいぐん /在日米軍/
ざいにっぽん /在日本/
ざいにほんだいかんみんこくみんだん /在日本大韓民国民団/
ざいにほんちょうせんじんそうれんごうかい /在日本朝鮮人総連合会/
ざいにん /在任/罪人/
ざいにんきかん /在任期間/
ざいにんきかんちゅう /在任期間中/
ざいにんちゅう /在任中/
ざいのう /財嚢/
ざいはく /財帛/
ざいば /在場/
ざいばつ /財閥/
ざいばつかいたい /財閥解体/
ざいふ /在府/
ざいふつ /在仏/
ざいぶつ /財物/
ざいべい /在米/
ざいほう /財宝/罪報/
ざいま /在間/
ざいむ /財務/
ざいむかいけい /財務会計;financial accounting/
ざいむかん /財務官;quaestor/
ざいむかんり /財務管理/
ざいむしょう /財務省;NB:大蔵省が2001年1月の中央省庁再編で再編されたもの/財務相;†大臣/
ざいむしょひょう /財務諸表;事業報告書、損益計算書、貸借対照表、キャシュフロー計算書、付属明細表、剰余金処分案の6つ/
ざいむじょうきょう /財務状況/
ざいむじょうたい /財務状態/
ざいむたいしつ /財務体質/
ざいむちょうかん /財務長官/
ざいむないよう /財務内容/
ざいむぶ /財務部/
ざいむぶんせき /財務分析/
ざいめい /罪名/在銘/
ざいめつ /罪滅/
ざいもく /材木/
ざいもくざかいがん /材木座海岸/
ざいもくや /材木屋/材木谷;人名/
ざいもつ /財物;ざいぶつ./
ざいや /在野/
ざいよく /財欲/
ざいらい /在来/
ざいらいえき /在来駅/
ざいらいがた /在来型/
ざいらいぎじゅつ /在来技術/
ざいらいこうほう /在来工法/
ざいらいしゃ /在来車/
ざいらいしゅ /在来種/
ざいらいせん /在来線/在来船/
ざいらいせんくかん /在来線区間/
ざいらいてつどう /在来鉄道/
ざいらいとっきゅう /在来特急/
ざいらんようぼうし /剤乱用防止/
ざいりゅう /在留/
ざいりゅうしかく /在留資格/
ざいりょう /材料/在寮/
ざいりょうかいはつ /材料開発/
ざいりょうかがく /材料科学/
ざいりょうかぶ /材料株/
ざいりょうがっか /材料学科/
ざいりょうきょうど /材料強度/
ざいりょうけい /材料系/
ざいりょうけんきゅうしつ /材料研究室/
ざいりょうこうがく /材料工学/
ざいりょうこうがくぶ /材料工学部/
ざいりょうこうがっか /材料工学科/
ざいりょうし /材料視/
ざいりょうだい /材料代/
ざいりょうてき /材料的/
ざいりょうとくせい /材料特性/
ざいりょうひ /材料費/
ざいりょうぶ /材料部/
ざいりょうりきがく /材料力学;material mechanics/
ざいりょく /財力/
ざいん /座員/
ざう /座右/
ざえ /才/
ざえもん /左衛門/
ざお /竿/棹/
ざおう /蔵王/
ざおうおんせん /蔵王温泉/
ざおうおんせんがい /蔵王温泉街/
ざおうかん /蔵王間/
ざおうさん /蔵王山/
ざおうちょう /蔵王町/
ざか /座下/坂/
ざかり /盛り/
ざが /座臥/坐臥/
ざがく /座学/
ざがしら /座頭/
ざがね /座金/
ざき /崎/嵜/咲き/
ざきょう /座興/
ざぎょう /座業;すわったままでする仕事・職業/ザ行/ざ行/
ざくぎり /ざく切り;キャベツの-/
ざくつ /座屈/
ざくら /桜/
ざくろ /柘榴/榴/石榴;=柘榴/
ざくろいし /柘榴石/石榴石;garnet/
ざけ /酒/
ざこ /雑魚/雑喉/座古;人名/
ざこう /座高/
ざこうさ /座高差/
ざこうじ /座光寺/
ざこつ /坐骨/挫骨/座骨/
ざこつしんけい /座骨神経/
ざこつしんけいつう /坐骨神経痛/座骨神経痛;sciatica/
ざこね /雑魚寝/雑寝;?/
ざこば /雑喉場/
ざさ /座作;立ち居振る舞い/坐作;=座作/笹/
ざざい /坐剤;坐薬/
ざし /座視/坐視/差し/
ざしき /座敷/
ざしきげい /座敷芸/
ざしきろう /座敷牢/
ざしきわらし /座敷童/
ざしつ /座室/
ざしゅ /座種/
ざしょ /座所/
ざしょう /座礁/挫傷;うちみ/坐礁;=座礁/
ざしょく /座食/坐食/
ざす /座主/
ざせき /座席/
ざせきかくほ /座席確保/
ざせきかん /座席間/
ざせきけん /座席券/
ざせきした /座席下/
ざせきしてい /座席指定/
ざせきしていけん /座席指定券/
ざせきしていせい /座席指定制/
ざせきしゃ /座席車/
ざせきしよう /座席使用/
ざせきすう /座席数/
ざせきていいん /座席定員/
ざせきはいち /座席配置/
ざせきばんごう /座席番号/
ざせきひょう /座席表/
ざせきよやく /座席予約/
ざせきりつ /座席率/
ざせきわく /座席枠/
ざせつ /挫折/
ざせつかん /挫折感/
ざせつしゃ /挫折者/
ざぜん /座禅/坐禅/座前/
ざそう /座葬/
ざぞう /座像/
ざた /沙汰/
ざたく /座卓/
ざだん /座談/
ざだんかい /座談会/
ざちゅう /座中/
ざちょう /座長/
ざっか /雑貨/
ざっかてん /雑貨店/
ざっかはんばい /雑貨販売/
ざっかや /雑貨屋/
ざっかん /雑感/
ざっき /雑記/
ざっきちょう /雑記帳/
ざっきゅう /雑給/
ざっきょ /雑居/
ざっきょびる /雑居ビル/
ざっきょぼう /雑居房;⇔独房/
ざっきん /雑菌/
ざっけん /雑件/
ざっこう /雑考/
ざっこく /雑穀/
ざっこん /雑婚/
ざっさん /雑纂/
ざっし /雑誌/
ざっしかい /雑誌会/
ざっしきしゃ /雑誌記者/
ざっしきじ /雑誌記事/
ざっしきょうかい /雑誌協会/
ざっしけいさいじ /雑誌掲載時/
ざっしこうこく /雑誌広告/
ざっししゃ /雑誌社/
ざっししょもつ /雑誌書物/
ざっしじょう /雑誌上/
ざっしだい /雑誌代/
ざっしとう /雑誌等/
ざっしなど /雑誌等/
ざっしへんしゅうしゃ /雑誌編集者/
ざっしべつ /雑誌別/
ざっしほんたい /雑誌本体/
ざっしめい /雑誌名/
ざっしゅ /雑種/雑酒/雑修/
ざっしゅうにゅう /雑収入/
ざっしゅきょうせい /雑種強勢/
ざっしょ /雑書/
ざっしょく /雑食/雑色/
ざっしょくせい /雑食性/
ざっしょくどうぶつ /雑食動物/
ざっしよう /雑誌用/
ざっしるい /雑誌類/
ざっしれんさい /雑誌連載/
ざっしれんさいじ /雑誌連載時/
ざっしれんさいちゅう /雑誌連載中/
ざっせつ /雑節;二十四節気以外の節/雑説;諸説/
ざっそう /雑草/雑想/
ざっそく /雑則/
ざっそん /雑損/
ざっそんこうじょ /雑損控除/
ざっそんしつ /雑損失/
ざった /雑多/
ざっちょ /雑著/
ざっとう /雑踏/雑沓;=雑踏/
ざっぱ /雑把/雑破/
ざっぱい /雑俳/雑輩/
ざっぱく /雑駁/
ざっぴ /雑費/
ざっぴつ /雑筆/
ざっぽう /雑報/
ざつ /雑/襍;「雑」の異体字/雜;「雑」の旧字(人名用漢字)/
ざつえい /雑詠/
ざつえき /雑役/雑益/
ざつおん /雑音/
ざつおんか /雑音下/
ざつおんしんごう /雑音信号/
ざつおんじょきょ /雑音除去/
ざつおんよくあつ /雑音抑圧/
ざつおんよくせい /雑音抑制/
ざつかぶ /雑株/
ざつがく /雑学/
ざつがくちしき /雑学知識/
ざつがくていど /雑学程度/
ざつがくぼん /雑学本/
ざつき /座付/
ざつきゅうよ /雑給与/
ざつぎ /雑技/
ざつぎだん /雑技団/
ざつぎょ /雑魚/
ざつぎょう /雑業/
ざつげい /雑芸/
ざつごん /雑言;[文学]字数不定(の詩)/
ざつごんこし /雑言古詩;[文学]字数・句数共に無制限の漢詩/
ざつさぎょう /雑作業/
ざつしゅうにゅう /雑収入;sundry income/
ざつしょとく /雑所得/
ざつじ /雑事/
ざつぜん /雑然/
ざつそんしつ /雑損失/
ざつだい /雑題/
ざつだん /雑談/
ざつだんふう /雑談風/
ざつねん /雑念/
ざつのう /雑嚢/
ざつはいすい /雑排水/
ざつぶつ /雑物/
ざつぶん /雑文/
ざつぼく /雑木/
ざつみんとう /雑民党/
ざつむ /雑務/
ざつよう /雑用/
ざつようがかり /雑用係/
ざつろく /雑録/
ざつわ /雑話/
ざてんし /座天使;thrones/
ざとう /座頭/
ざとういち /座頭市/
ざとうくじら /座頭鯨/
ざね /実/
ざはい /座配;席順/
ざはき /座掃き/
ざひょう /座標/
ざひょうけい /座標系/
ざひょうけいさん /座標計算/
ざひょうじく /座標軸/
ざひょうち /座標値/
ざひょうにゅうりょく /座標入力/
ざひょうひょうじ /座標表示/
ざひょうへいめん /座標平面/
ざひょうへんかん /座標変換/
ざぶ /座部/
ざぶとん /座布団/座蒲団/
ざぶろう /三郎/
ざぼうき /座箒;[茶道]/
ざま /座間/
ざまし /座間市/
ざまみ /座間見/
ざめ /鮫/
ざめつ /挫滅/
ざめつしょうこうぐん /挫滅症候群/
ざめん /座面/
ざもち /座持ち/
ざもと /座元/
ざやく /座薬/坐薬/
ざゆう /座右/
ざゆうのめい /座右の銘/
ざよく /座浴;hip bath/
ざら /皿/
ざらがみ /ざら紙/
ざらば /ざら場;[相場]/
ざらめ /粗目/
ざらめゆき /粗目雪/
ざり /座利/
ざりがに /蜊蛄/
ざる /笊/猿/
ざるご /笊碁/
ざるそば /笊蕎麦/
ざれ /戯れ/
ざれい /座礼/坐礼/
ざれうた /戯れ歌/戯歌/
ざれえ /戯れ絵/
ざれごと /戯言/戯れ言/戯事/
ざれつ /坐列/座列/
ざわ /沢/澤;「沢」の旧字/
ざん /残/山;(連濁)/算;(連濁)/惨;惨殺/参;(連濁)見参/斬;斬首/暫;暫定/塹;塹壕/嶄;(たかい)嶄然/慙;慙愧/慚;「慙」の異体字/鏨;たがね/讒;讒訴/巉;巉巌/懺;懺悔/懴;「懺」の異体字/竄;改竄/殘;「残」の旧字/慘;「惨」の旧字/
ざん> /残;残3軒/
ざんあつけい /残圧計/
ざんい /残遺/
ざんえい /残映/
ざんかい /慚悔/
ざんかん /斬奸/残寒/斬姦/
ざんがい /残骸/残害/斬刈/
ざんがく /残額/
ざんがん /巉巌/
ざんき /慚愧;-の念に堪えない(=とても恥ずかしい)/慙愧;=慚愧/残基/残機;[ゲーム]/慙悸;恥ずかしくて動悸がする/
ざんきゅう /斬級/残丘/
ざんきょう /残響/
ざんきょうおん /残響音/
ざんきょうおんじょう /残響音場/
ざんきょうかん /残響感/
ざんきょうしつ /残響室/
ざんきょうじかん /残響時間/
ざんきょうせい /残響性/
ざんきりょう /残気量/
ざんきん /残金/
ざんぎゃく /残虐/
ざんぎゃくこうい /残虐行為/
ざんぎゃくじけん /残虐事件/
ざんぎゃくせい /残虐性/
ざんぎゃくひどう /残虐非道/
ざんぎょう /残業/
ざんぎょうしょく /残業食/
ざんぎょうじかん /残業時間/
ざんぎょうだい /残業代/
ざんぎょうてあて /残業手当/
ざんぎょうでい /残業デイ/
ざんぎり /散切り/
ざんぎりあたま /散切り頭;-を叩いてみれば/
ざんくろう /斬九郎/
ざんけい /斬刑/
ざんけつ /残欠/残闕;=残欠/
ざんけん /残件/
ざんげ /懺悔/
ざんげしつ /懺悔室/
ざんげつ /残月/
ざんげん /讒言/
ざんこう /残光;afterglow/残香/残肴;食べ残し/
ざんこく /残酷/
ざんこん /残痕/
ざんごう /塹壕/
ざんさ /残渣/残差/
ざんさい /残債/残滓;(慣用読み) =ざんし/斬衰;中国の喪服/
ざんさぎょう /残作業/
ざんさつ /惨殺;無惨に殺す/斬殺;斬り殺す/
ざんさへいほうわ /残差平方和/
ざんざい /斬罪/
ざんし /残滓/惨死;†無惨な死/慙死;†恥じて死ぬ/
ざんしゃ /讒者/
ざんしゅ /斬首/
ざんしょ /残暑/
ざんしょう /残照/
ざんしょみまい /残暑見舞い/残暑見舞/
ざんしん /斬新/残心/嶄新;=斬新/
ざんじ /暫時/
ざんじつろく /残日録/
ざんじんざんば /斬人斬馬/
ざんすう /残数/
ざんせき /残席/
ざんせつ /残雪/
ざんせつき /残雪期/
ざんぜつ /嶄絶/
ざんぜん /嶄然/
ざんそ /讒訴/
ざんそん /残存/
ざんぞう /残像/
ざんぞうげんしょう /残像現象/
ざんぞん /残存/
ざんぞんりつ /残存率/
ざんぞんりょう /残存量/
ざんだか /残高/
ざんだかしょうかい /残高照会/
ざんだかしょうめい /残高証明/
ざんだかしょうめいしょ /残高証明書/
ざんだかぶそく /残高不足/
ざんだんすう /残弾数/
ざんち /残置/
ざんてい /暫定/
ざんていあん /暫定案/
ざんていいいん /暫定委員/
ざんていいいんかい /暫定委員会/
ざんていかい /暫定解/
ざんていかいぎょう /暫定開業/
ざんていかんりにん /暫定管理人/
ざんていしょち /暫定処置/
ざんていしょり /暫定処理/
ざんていせいけん /暫定政権/
ざんていそち /暫定措置/
ざんていてき /暫定的/
ざんていばん /暫定版/
ざんていよさん /暫定予算/
ざんてき /残敵/
ざんてつけん /斬鉄剣/
ざんとう /残党/
ざんとうがり /残党狩り/
ざんどすう /残度数/
ざんにっすう /残日数/
ざんにょう /残尿/
ざんにょうかん /残尿感/
ざんにん /残忍/惨忍/
ざんねん /残念/残年/
ざんねんかい /残念会/
ざんねんしごく /残念至極/
ざんねんしょう /残念賞/
ざんねんむねん /残念無念/
ざんばつ /斬伐/
ざんぱい /惨敗/
ざんぱつ /斬髪/
ざんぱん /残飯/
ざんぴん /残品/
ざんぶ /残部/
ざんぶつ /残物/
ざんぶん /残分/
ざんぺん /残片/
ざんぼう /讒謗/残亡/
ざんぽん /残本/槧本/
ざんまい /三昧/
ざんまいきょう /三昧境/
ざんむ /残務/残夢;見残した夢/
ざんむしょり /残務処理/
ざんむせいり /残務整理/
ざんよ /残余/殘餘;旧字/
ざんよさん /残予算/
ざんよざいさん /残余財産/
ざんりゅう /残留/
ざんりゅうおうりょく /残留応力;[物理][建築]外力がなくなっても内部に残る応力/
ざんりゅうかく /残留核/
ざんりゅうこじ /残留孤児/
ざんりゅうしねん /残留思念/
ざんりゅうしゃ /残留者/
ざんりゅうじき /残留磁気;remanence/
ざんりゅうじば /残留磁場/
ざんりゅうせんざい /残留洗剤/
ざんりゅうのうやく /残留農薬/
ざんりゅうぶつ /残留物/
ざんりゅうほうしゃのう /残留放射能/
ざんりゅうようせい /残留要請/
ざんりょう /残量/残料/
ざんりょうけいこく /残量警告/
ざんりょうけいこくとう /残量警告灯/
ざんりょうひょうじ /残量表示/
ざんるい /残塁/
し /死/詩;poem/詞;lyrics/師/士/市/氏/司/紙/誌/史/私/子/四/始/視/至/止/使/糸/雌;めす/歯/齒;「歯」の旧字/指/旨;論旨/仕;仕事/志;意志/支;支社/枝;えだ/肢;四肢/伺;うかが・う/嗣;世嗣/飼;飼育/笥;箪笥/覗;のぞ・く/祠;ほこら/諮;諮問/資;資本/咨/恣;恣意/瓷;≒磁/粢;しとぎ/姿;姿勢/熾;熾烈/幟;旗幟/施;施策/弛;弛緩/祉;福祉/址;城址/阯;「址」の異体字/沚/趾;趾骨/屍;しかばね/尸/巳;(干支の)み/屎;くそ/祀;祭祀/祇;祇園(ぎおん)/祗;つつしむ,まさに/砥;砥石/帋;「紙」の異体字/舐;な・める/斯;斯界/廝;こもの/厮;「廝」の異体字/髭;ひげ/呰;そしる/嘴;くちばし/觜;二十八宿の一つ/貲;あがなう/駟;駟馬/泗;泗水(中国の川)/矢/笶;竹の矢/篩;ふるい/獅;獅子/緇;(黒) 緇衣/輜;(兵站輸送車) 輜重/錙;錙銖/蚩/嗤;嗤笑/厶;わたくし(「私」の原字)/俟;ま・つ/竢;ま・つ/卮;さかずき/巵;「卮」の異体字/梔/絲;「糸」の旧字/茲;ここ/諡;おくりな/謚;「諡」の異体字/思;思考/偲;しの・ぶ/啻;ただ/嗜;嗜眠/耆;伯耆(ほうき)/贄;にえ/鷙;たか/試;試験/弑;弑逆/孜;孜々/紫;むらさき/脂;脂肪/賜;賜杯/漬;つ・ける/侈;奢侈/咫;(古代の長さの単位) 咫尺/妛/徙;うつる (「徒」とは別)/恃;自恃/揣;揣摩/摯;真摯/滓;(かす)残滓/痣;あざ/翅;はね。「前翅」/耜/肆;書肆/豕;いのこ/齎;もたら・す/釶;「鉈」の異体字/駛;駛走/梓;上梓/茨;いばら/匙;さじ/仔/刺;刺殺/姉;姉妹/此;これ/之;これ/芝;しば/衰;おとろ・える/次;つぎ/示;示唆/自;(漢音)/時;とき/柿;かき/只;ただ/知;動詞語幹?/岐;?/
し> /私;私設,私学校,私企業/始/
しーあは /シーア派/
しーがた /Ｃ型/
しーがたかんえん /Ｃ型肝炎;[医]/C型肝炎;[医]hepatitis C/
しーくきょう /シーク教/
しーぐあず /西瓜子/
しーげんご /Ｃ言語;[電算] C language/C言語;[電算] C language/
しーずんちゅう /シーズン中/
しーた /θ;theta/Θ;Theta/
しーたは /θ波/
しーでぃーてん /CD店/
しーどけん /シード権/
しーどこう /シード校/
しーぼーぎうむ /Sg/Seaborgium/
しーるざい /シール材/
しあ /四阿/
しあい /試合/仕合;≒試合/私愛;secret love/至愛;love supreme/四愛;菊・蓮・梅・蘭/
しあいいがい /試合以外/
しあいうん /試合運/
しあいかいさい /試合開催/
しあいかいし /試合開始/
しあいかいしご /試合開始後/
しあいかいしじかん /試合開始時間/
しあいかいしちょくご /試合開始直後/
しあいかいしちょくぜん /試合開始直前/
しあいかいしまえ /試合開始前/
しあいかんせん /試合観戦/
しあいきぼう /試合希望/
しあいけいか /試合経過/
しあいけいしき /試合形式/
しあいけっか /試合結果/
しあいけっかほうこく /試合結果報告/
しあいこうしゃ /試合巧者/
しあいご /試合後/
しあいしゅうりょう /試合終了/
しあいしゅうりょうご /試合終了後/
しあいしゅうりょうじかん /試合終了時間/
しあいしゅつじょう /試合出場/
しあいしょうかすう /試合消化数/
しあいじかん /試合時間/
しあいじたい /試合自体/
しあいじゅん /試合順/
しあいじょう /試合場/
しあいすう /試合数/
しあいぜんたい /試合全体/
しあいぜんはん /試合前半/
しあいぞっこう /試合続行/
しあいちゅう /試合中/
しあいちゅうけい /試合中継/
しあいちょくぜん /試合直前/
しあいてんかい /試合展開/
しあいとうじつ /試合当日/
しあいとちゅう /試合途中/
しあいないよう /試合内容/
しあいないようてき /試合内容的/
しあいにってい /試合日程/
しあいび /試合日/
しあいふうけい /試合風景/
しあいぶん /試合分/
しあいほうき /試合放棄/
しあいまえ /試合前/
しあいよう /試合用/
しあいよそう /試合予想/
しあいよてい /試合予定/
しあがり /仕上がり/仕上り/
しあく /四悪;[儒教]暴・虐・賊・有司/
しあくしゅ /四悪趣;[仏教]地獄・餓鬼・畜生・修羅/
しあげ /仕上げ/仕上/
しあげこう /仕上工/
しあさって /明々後日/明明後日/
しあつ /指圧/
しあつき /指圧器/
しあつし /指圧師/
しあつほう /指圧法/
しあわせ /幸せ/倖せ;=幸せ/仕合せ;巡り合わせ (NB:「幸せ」の語源)/幸福;当て字/
しあわせぶとり /幸せ太り/
しあわせもの /幸せ者/
しあわせよし /仕合はせ吉し/
しあん /思案;thought/試案;draft/私案;personal plan/
しあんか /シアン化/
しあんがお /思案顔/
しあんちゅう /思案中/
しあんなげくび /思案投げ首/思案投首/
しい /恣意/思惟/椎/四囲/私意/四位/示威;=じい/紫衣/四維/詩意/肆意;=恣意/尿/
しいえき /志井駅/
しいお /椎尾;姓/
しいか /詩歌/
しいがもと /椎本/
しいき /市域/椎木/篩域/
しいぎゃく /弑逆/
しいく /飼育/
しいくいん /飼育員/
しいくがかり /飼育係/
しいくじょうきょう /飼育状況/
しいくすい /飼育水/
しいくちゅう /飼育中/
しいくほう /飼育法/
しいくほうほう /飼育方法/
しいこうい /示威行為/
しいこうどう /示威行動/
しいざかな /強肴/
しいじ /椎路/
しいせい /恣意性/
しいそさん /尸位素餐/
しいた /θ;theta/Θ;Theta/
しいたけ /椎茸/
しいだ /志井田/椎田/
しいち /視位置/
しいて /強いて/
しいてき /恣意的/
しいな /椎名/粃;実のない籾/秕;=粃/椎菜/
しいなひゃっかてん /椎名百貨店/
しいなまこと /椎名誠;人名/
しいなまち /椎名町/
しいなりんぞう /椎名麟三/
しいの /椎野/
しいのき /椎の木/
しいば /椎葉/
しいら /粃/
しいる /罔/
しいれ /仕入れ/仕入/
しいれかかく /仕入価格/仕入れ価格/
しいれさき /仕入先/仕入れ先/
しいれだか /仕入高/
しいれね /仕入れ値/仕入値/
しいれぶ /仕入部/
しいん /試飲/死因/子音/私印/指印/市隠/
しいんぎぞう /私印偽造/
しいんぎょう /子音行/
しいんこうい /死因行為/
しいんしつ /試飲室/
しいんじ /子音字/
しいんぞうよ /死因贈与/
しいんぶ /子音部/
しいんぶぶん /子音部分/
しう /紫芋/死有/四有/糸雨/
しう゛ぁ /湿婆/
しうち /仕打ち/仕打/
しうと /舅/
しうとめ /姑/
しうら /市浦/
しうん /紫雲/
しうんじ /紫雲寺/
しうんてん /試運転/
しうんてんけっか /試運転結果/
しうんてんちゅう /試運転中/
しぇるへんすう /シェル変数/
しえ /紫衣/四衛/
しえい /市営;†municipal/私営;†private/
しえいこうつう /市営交通/
しえいしゃ /市営車/
しえいちかてつ /市営地下鉄/
しえいちゅうしゃじょう /市営駐車場/私営駐車場/
しえき /使役/私益/
しえきどうし /使役動詞/
しえしえ /謝謝;[中国語]xie xie (Thanks)/
しえん /支援/私怨/紫煙/試演/
しえんいん /支援員/
しえんかたんそ /四塩化炭素/
しえんかつどう /支援活動/
しえんかのう /支援可能/
しえんかんきょう /支援環境/
しえんきかん /支援機関/
しえんきぎょう /支援企業/
しえんきこう /支援機構/
しえんきのう /支援機能/
しえんきん /支援金/
しえんけい /支援系/
しえんこく /支援国/
しえんさく /支援策/
しえんざいだん /支援財団/
しえんしせつ /支援施設/
しえんしつ /支援室/
しえんしゃ /支援者/
しえんせんとうき /支援戦闘機/
しえんだんたい /支援団体/
しえんにん /支援人/
しえんひ /支援費/
しえんひせいど /支援費制度/
しえんぶ /支援部/
しえんほう /支援法/
しお /塩/潮;字義:朝のうしお/汐;字義:夕のうしお/志雄/史生/入/鹽;「塩」の旧字/
しおあい /潮合/
しおあじ /塩味/
しおい /塩井/
しおいがい /塩以外/
しおいり /塩入/
しおう /四王/雌黄/
しおうち /塩内/
しおうてん /四王天/
しおかげん /塩加減/
しおかぜ /潮風/汐風/
しおから /塩辛/
しおからごえ /塩辛声/
しおからとんぼ /塩辛蜻蛉/
しおかり /塩狩/
しおかわ /塩川/
しおがま /塩釜/塩竈/塩竃;「竈」異体字/
しおがまえき /塩釜駅/
しおがまこう /塩釜港/塩竃港/
しおがまし /塩釜市/
しおがません /塩釜線/
しおき /仕置/仕置き/
しおきにん /仕置人/
しおぎ /塩木/
しおくみ /汐汲/汐汲み/潮汲み/
しおくり /仕送り/
しおけ /塩気/
しおけむり /潮煙/
しおこさじ /塩小匙/
しおこしょう /塩胡椒/塩コショウ/
しおこんぶ /塩昆布/
しおさい /潮騒/
しおさば /塩鯖/
しおさめ /仕納め/爲納め;「為」旧字/
しおざかい /潮境/
しおざかな /塩魚/
しおざき /塩崎/潮崎/
しおざけ /塩鮭/
しおざわ /塩沢/塩澤/
しおじ /潮路/汐路/塩路/
しおじゃけ /塩鮭/
しおじり /塩尻/
しおじりえき /塩尻駅/
しおじる /潮汁/塩汁/
しおず /塩津/
しおずか /塩塚;※仮名遣い「しおづか」/
しおせ /塩瀬/
しおせんべい /塩煎餅/
しおた /塩田/潮田/
しおたに /塩谷/
しおだ /塩田/潮田/
しおだし /塩出し/
しおだち /塩断ち/
しおだまり /潮溜まり/
しおち /潮地/
しおつぐ /塩次/
しおづけ /塩漬/塩漬け/
しおづる /塩鶴/
しおで /塩出/
しおどき /潮時/
しおどめ /汐留/
しおなり /潮鳴り/
しおに /塩煮/
しおぬき /塩抜き/
しおの /塩野/
しおのえ /塩江/
しおのぎ /塩野義/
しおのぎせいやく /塩野義製薬;[企業名]/
しおのみさき /潮岬/
しおのみち /塩の道;千国街道/
しおのや /塩谷/
しおはま /塩浜/
しおはら /塩原/
しおばら /塩原/
しおばらおんせん /塩原温泉/
しおひ /潮干/
しおひがり /潮干狩り/潮干狩/
しおふき /潮吹き/
しおぶた /塩豚/
しおぶね /塩船/
しおぶろ /塩風呂/
しおべつ /塩別/
しおま /潮間/
しおまねき /潮招き/望潮;カニ/
しおまめ /塩豆/
しおみ /塩見/潮見/
しおみえき /潮見駅/
しおみず /塩水/潮水/
しおみだい /汐見台/潮見台/
しおむら /塩村/
しおもと /塩本/
しおもの /塩物/
しおもみ /塩揉み;[料理]「キュウリの-」/
しおや /塩谷/塩屋/
しおやき /塩焼/塩焼き/
しおやけ /潮焼け/
しおゆ /塩湯/潮湯/
しおらーめん /塩ラーメン/
しおり /栞/撓/枝折/詩央里/
しおりど /枝折戸/
しおん /子音/紫苑/私怨/歯音;[音声学]dental/師恩/至恩/
しおんいろ /紫苑色;淡紫/
しか /鹿/歯科/市価/史家/雌花/私家/志賀;地名/子夏/詩家/紙価;洛陽の-を高める/詞華/賜暇/翅果/然/飾/爾/餝/四科;徳行,言語,政事,文学(<論語)/知客/詩歌/
しかい /司会/視界/市会/死海/歯科医/四海/斯界/志怪;-小説/四界/死灰/尸解/此界/
しかいいん /歯科医院/
しかいぎいん /市会議員/
しかいけいてい /四海兄弟/
しかいし /歯科医師/
しかいしゃ /司会者/
しかいしゃせき /司会者席/
しかいしょうせつ /志怪小説/
しかいしんこう /司会進行/
しかいない /視界内/
しかいふりょう /視界不良/
しかいもんじょ /死海文書/
しかいや /司会屋/
しかいやく /司会役/
しかいりょう /司会料/
しかいりょうこう /視界良好/
しかえし /仕返し/
しかおい /鹿追/
しかかり /仕掛り/仕掛/
しかかりひん /仕掛り品/
しかきょうせい /歯科矯正/
しかぎこうし /歯科技工士/
しかく /資格/視覚;†vision.「-芸術」/四角/死角;†blind spot.「-を突く」/刺客/視角;†visual angle.「-に入らない」/詩客/■;box/□/◆;dia/◇/
しかくか /視覚化/
しかくかんけい /視覚関係/
しかくきゅう /資格給/
しかくけい /四角形/視覚系/
しかくけんてい /資格検定/
しかくげいじゅつ /視覚芸術/
しかくげんご /視覚言語/
しかくこうか /視覚効果/
しかくこうざ /資格講座/
しかくごうま /四角号碼/
しかくしけん /資格試験/
しかくしげき /視覚刺激/
しかくしめん /四角四面/
しかくしゅとく /資格取得/
しかくしゅとくご /資格取得後/
しかくしゅとくしゃ /資格取得者/
しかくしょう /資格証/
しかくしょうがい /視覚障害/
しかくしょうがいしゃ /視覚障害者/視覚障碍者/
しかくしょうがいしゃよう /視覚障害者用/
しかくしょり /視覚処理/
しかくしんごう /視覚信号/
しかくしんさ /資格審査/
しかくじょう /視覚上/
しかくじょうけん /資格条件/
しかくじょうほう /視覚情報/
しかくじょうほうしょり /視覚情報処理/
しかくすい /四角錐/
しかくせいげん /資格制限/
しかくそうしつ /資格喪失/
しかくてき /視覚的/
しかくてきこうか /視覚的効果/
しかくとうろく /資格登録/
しかくにんてい /資格認定/
しかくひしつ /視覚皮質/
しかくふよう /資格不要/
しかくぶ /視覚部/
しかくべつ /資格別/
しかくほゆう /資格保有/
しかくぼ /鹿窪/
しかくめい /資格名/
しかくや /視覚野;[解剖]visual area/
しかけ /仕掛け/仕掛/仕懸/
しかけにん /仕掛け人/仕掛人/
しかけはなび /仕掛け花火/仕掛花火/
しかけひん /仕掛品/
しかけんしん /歯科検診/
しかご /市俄古/
しかさわぐち /鹿沢口/
しかざわ /鹿沢/
しかざん /死火山/
しかし /然し/併し;≒然し/私窩子;whore/
しかして /而して/然して/
しかしながら /然し乍ら/併し乍ら/
しかしゅう /詞華集/私家集;⇔勅撰集/詞花集;=詞華集/
しかしょ /四ヶ所/
しかじか /云々;NB:「うんぬん」と同形/然々/云云/然然/
しかじゅう /死荷重;dead load/
しかず /如かず/若かず/
しかた /仕方/志方;地名,兵庫/
しかたに /鹿谷/
しかたばなし /仕方話/
しかちりょう /歯科治療/
しかっけい /四角形/
しかっしょく /紫褐色/
しかつ /死活/師勝;地名/
しかつてき /死活的/
しかつもんだい /死活問題/
しかと /確と;-受け取りました/聢と/聢/
しかど /鹿戸/
しかの /鹿野/
しかのしま /志賀島/
しかのみならず /加之/
しかばね /屍/
しかばん /私家版/
しかべ /鹿部/
しかま /飾磨;地名/色麻/志鎌/
しかまえき /飾磨駅/
しかまた /鹿又/
しかまち /鹿町/
しかみ /鹿見/爾見/
しかめっつら /顰めっ面/しかめっ面/
しかめつら /顰め面/
しかめん /死仮面/
しかも /而も/然も/
しからずんば /然らずんば/
しからば /然らば/
しかり /然り/尓/叱り/呵り/
しかりしこうして /然り而して/
しかりべつ /然別/
しかりべつこ /然別湖/
しかるべき /然る可き/
しかれども /然れども/
しかれば /然れば/
しかん /士官;officer.「自衛隊の-」/弛緩/史観;歴史観/歯間/仕官;serve.「大名に-する」/視姦/歯冠/私感/支間/視感/止観/支管/使館;公使館・大使館/子癇/屍姦/祠官/史官/師管/篩管;=師管/枝幹/詩巻/士関/糸管/
しかんおん /歯間音;[音声学]interdental/
しかんがっこう /士官学校/
しかんけん /資環研/
しかんこうほせい /士官候補生/
しかんざい /弛緩剤/
しかんしきかごうぶつ /脂環式化合物;[化学]alicyclic compound/
しかんたざ /只管打坐/
しかんほう /弛緩法/
しが /滋賀/志賀;-直哉/歯牙/四賀/齒牙;「歯」旧字/
しがい /市街/市外/死骸/紫外/屍骸/
しがいか /市街化/
しがいかちょうせいくいき /市街化調整区域/
しがいきょくばん /市外局番/
しがいこう /紫外光/
しがいしょく /紫外色/
しがいせん /紫外線/市街戦/市外線/
しがいせんきゅうしゅうざい /紫外線吸収剤/
しがいせんぼうしざい /紫外線防止剤/
しがいせんりょうほう /紫外線療法/
しがいち /市街地/
しがいちそうこう /市街地走行/
しがいちちゅうしん /市街地中心/
しがいちゅうしん /市街中心/
しがいつうわ /市外通話/
しがき /志垣/
しがきたろう /志垣太郎/
しがく /私学/史学/歯学/詩学/志学/試楽/斯学/
しがくか /史学科/歯学科/
しがくさつどうろ /志賀草津道路/
しがくじょせい /私学助成/
しがくぶ /歯学部/
しがけん /滋賀県/
しがけんか /滋賀県下/
しがけんぎかい /滋賀県議会/
しがけんみん /滋賀県民/
しがけんりつ /滋賀県立/
しがげんぱつ /志賀原発/
しがこうげん /志賀高原/
しがごえ /志賀越/
しがさと /滋賀里/
しがしゅう /詩画集/
しがじく /詩画軸/
しがちょう /志賀町/
しがっか /歯学科/
しがっこう /私学校/
しがつ /四月/４月/4月/卯月;※連想,旧暦/
しがつばか /四月馬鹿/
しがなおや /志賀直哉;(1883-1971)作家。『暗夜行路』/
しがほうめん /志賀方面/
しがらき /信楽/紫香楽/
しがらきのみやあと /紫香楽宮跡/
しがらきやき /信楽焼/
しがらみ /柵;(原義:水の流れを止めるサク)/
しがりゅうおう /志賀竜王/
しがん /志願/此岸/史眼/
しがんしゃ /志願者/
しがんせい /志願制/
しがんひょう /志願票/
しがんへい /志願兵/
しき /式/四季/指揮/士気/始期/死期/紙器/子規/史記;中国の歴史書。正史のひとつ。著者は司馬遷/志気/屍鬼/私記/志木/磯城/志岐/識/色/織/敷/拭/鋪/惻/市気/
しきい /敷居/閾/
しきいき /識閾/識域/
しきいし /敷石/舗石/
しきいた /敷板/
しきいち /閾値/しきい値/
しきうつし /敷写し/
しきか /指揮下/色価/
しきかい /色界/
しきかいぞうど /色解像度/
しきかく /色覚/
しきかくいじょう /色覚異常/
しきかくいじょうしゃ /色覚異常者/
しきかくけんさ /色覚検査/
しきかん /指揮官/色感/
しきかんとく /指揮監督/
しきがく /式楽/
しきがし /式菓子/
しきがみ /式神/敷紙/識神;=式神/
しきがわ /敷皮/
しきがわら /敷瓦/甃;NB:「いしだたみ」とも訓む/敷き瓦/
しききん /敷金/
しきぎょう /私企業/
しきけ /式家;[日本史]藤原氏-/
しきけいとう /指揮系統/
しきけん /識見/指揮権/
しきこう /式項/
しきこうぞう /式構造/
しきこうよう /士気高揚/
しきご /識語/
しきさい /色彩/四季菜/
しきさいかんかく /色彩感覚/
しきさいこうがく /色彩工学/
しきさいしんりがく /色彩心理学/
しきさしんごう /色差信号/
しきさんば /式三番/
しきし /色紙/
しきしだい /式次第/
しきしま /敷島/磯城島/
しきしゃ /指揮者/識者/
しきしゅ /色種/
しきしゅうさ /色収差/
しきしん /色神/
しきじ /識字/式辞/式次/
しきじかん /職事官/
しきじたい /式自体/
しきじつ /式日/
しきじゃく /色弱/
しきじょう /式場/色情/
しきじょうきょう /色情狂/
しきじりつ /識字率/
しきじん /式神/識神/
しきすう /色数/
しきせ /仕着せ/四季施/為着せ/
しきせだい /四季施代/仕着せ代/
しきせん /敷銭/
しきそ /色素/式素/
しきそう /色相/
しきそうかん /色相環/
しきそくぜくう /色即是空/
しきそさいぼう /色素細胞;[生物]pigment cell/
しきそせいかんぴしょう /色素性乾皮症/
しきそたい /色素体/
しきそちんちゃく /色素沈着;pigmentation/
しきそぶんし /色素分子/
しきた /敷田/
しきたま /敷玉/
しきたり /仕来り/仕來り;「来」旧字/爲來り;「為」「来」共に旧字/
しきだ /敷田/
しきだい /指揮台/式台/
しきち /敷地/
しきちがい /敷地外/
しきちきょうかい /敷地境界/
しきちず /敷地図/
しきちない /敷地内/
しきちめんせき /敷地面積/
しきちゅう /式中/
しきちょう /色調/色聴/四季帳/
しきてい /式亭/
しきてき /式的/
しきてん /式典/
しきど /色度/
しきどう /色道/
しきどうおおかがみ /色道大鏡;藤本箕山作。成立1678?/
しきないしゃ /式内社/
しきにん /識認/
しきね /式根/敷寝/
しきねじま /式根島/
しきねん /式年/
しきねんさい /式年祭/
しきのうりょく /指揮能力/
しきばん /色板/
しきばんごう /式番号/
しきひょう /色票/
しきふ /敷布/
しきふく /式服/
しきふくはんそうは /色副搬送波/
しきふね /式船/
しきぶ /式部/
しきぶかん /式部官/
しきぶしょう /式部省;[律令制]三省/
しきぶしょく /式部職;宮内庁-。儀式担当/
しきぶとん /敷布団/敷き布団/
しきぶん /式文/
しきへんけい /式変形/
しきべつ /識別/
しきべつかのう /識別可能/
しきべつき /識別器/
しきべつし /識別子/
しきべつじっけん /識別実験/
しきべつてん /識別点/
しきべつばんごう /識別番号/
しきべつほう /識別法/
しきべつめい /識別名/
しきべつよう /識別用/
しきべつりつ /識別率/
しきべつりょく /識別力/
しきほう /四季報/指揮法/色法;[仏教]/式法/
しきぼう /指揮棒/式帽/
しきま /色魔/
しきみ /樒/櫁/
しきみか /シキミ科/Illiciaceae/
しきみもどきか /シキミモドキ科/Winteraceae/
しきめ /式女/
しきめい /色名/
しきもう /色盲/
しきもく /式目/
しきもの /敷物/敷き物/
しきものがたり /四季物語/
しきもりいのすけ /式守伊之助/
しきゃく /支脚/刺客;=しかく/
しきやみ /頻闇/
しきゅう /支給/子宮/至急/四球/死球/
しきゅうかく /子宮角/
しきゅうがい /子宮外/
しきゅうがいにんしん /子宮外妊娠/
しきゅうがく /支給額/
しきゅうがん /子宮癌/子宮がん/子宮ガン/
しきゅうきんしゅ /子宮筋腫/
しきゅうけいかん /子宮頸管;[解剖]cervix/
しきゅうこう /子宮口/
しきゅうしき /始球式/
しきゅうせん /子宮腺/
しきゅうたい /糸球体/
しきゅうたいじんえん /糸球体腎炎/
しきゅうたいのう /糸球体嚢/
しきゅうない /子宮内/
しきゅうないまく /子宮内膜;[解剖]endometrium/
しきゅうないまくえん /子宮内膜炎;[医]endometritis/
しきゅうないまくしょう /子宮内膜症/
しきゅうび /支給日/
しきゅうへき /子宮壁/
しきゆう /色釉/
しきょ /死去/
しきょう /市況/司教/詩経/試供/示教/詩境/詩興/至境/
しきょうい /市教委;市教育委員会/
しきょういく /私教育/
しきょうく /司教区;bishopric/
しきょうばん /試供版/
しきょうひん /試供品/
しきょく /支局/詩曲/四極/
しきょくちょう /支局長/
しきよく /色欲/
しきり /仕切り/頻り/頻/陣;[文語](出産間際の)陣痛/
しきりかべ /仕切り壁/仕切壁/
しきりきん /仕切金/
しきりしょ /仕切書/
しきりじょう /仕切り状;invoice/
しきりせん /仕切り線;[相撲]/
しきりとびら /仕切扉/
しきりなおし /仕切り直し/
しきりに /頻/
しきりねだん /仕切値段/
しきりばいばい /仕切売買/
しきりや /仕切り屋/
しきりょう /敷料/式量;[化学]formula weight.「分子-」/識量;見識と度量/
しきりょく /識力/
しきろう /識浪/
しきわら /敷藁/
しきん /資金/至近/紫金/賜金/死菌/試金/
しきんあつめ /資金集め/
しきんうんよう /資金運用/
しきんうんようぶ /資金運用部;NB:2001年に廃止/
しきんえんじょ /資金援助/
しきんか /資金化/
しきんかいしゅう /資金回収/
しきんきょうきゅう /資金供給/
しきんきょうよ /資金供与/
しきんきょうりょく /資金協力/
しきんきょり /至近距離/
しきんぐり /資金繰り/
しきんぐりひょう /資金繰り表/
しきんげん /資金源/
しきんしと /資金使途/
しきんじゅよう /資金需要/
しきんじょう /紫禁城/
しきんせき /試金石/
しきんせんじょう /資金洗浄;[新語]money laundering/
しきんだん /至近弾/至近彈;「弾」旧字/
しきんちゅうにゅう /資金注入/
しきんちょうたつ /資金調達/
しきんちょうたつこすと /資金調達コスト/
しきんていきょう /資金提供/
しきんてき /資金的/
しきんなん /資金難/
しきんはいぶん /資金配分/
しきんぶそく /資金不足/
しきんまえわたし /資金前渡/
しきんめん /資金面/
しきんりょう /資金量/
しきんりょく /資金力/
しぎ /市議/鴫/鷸;=鴫/思議/仕儀/指技/私議/信貴;地名/
しぎかい /市議会/
しぎかいぎいん /市議会議員/
しぎこ /鴫子/
しぎさん /信貴山/
しぎの /鴫野/
しぎゃく /嗜虐/弑逆/
しぎゃくてき /嗜虐的;sadistic/
しぎやき /鴫焼き/
しぎょ /仔魚/
しぎょう /始業/施業;業務の実行/執行;=しゅぎょう(≠しっこう)/仕業;実際に稼働させる。「-点検」/士業;[新語]=さむらいぎょう/紙業/斯業/詩業/施行;=せこう,せぎょう/
しぎょうしき /始業式/
しぎょうじ /始業時/
しぎょうじかん /始業時間/
しぎょうてんけん /始業点検/
しぎょく /紫玉/
しぎょくえん /紫玉苑/
しぎん /詩吟/市銀/歯齦/
しぎんえん /歯齦炎/
しく /市区/詩句/死苦/四苦/珠玖/
しくうかん /視空間/
しくかつよう /シク活用;形容詞の活用形態/
しくきょう /シク教;Sikh/
しくちょうそん /市区町村/
しくちょうそんちょう /市区町村長/
しくちょうそんめい /市区町村名/
しくつ /試掘/
しくはちがい /四衢八街/
しくはっく /四苦八苦/
しくみ /仕組み/仕組/
しくんし /士君子/
しぐさ /仕草/仕種;=仕草/
しぐま /σ;sigma/Σ;Sigma/
しぐれ /時雨/
しぐれに /時雨煮/
しぐん /市郡/
しけ /時化/師家/
しけい /死刑/市警/私刑;lynch/詩型;versification/詩形;=詩型/紙型;[印刷]paper matrix/支系/司計/歯茎/
しけいおん /歯茎音/
しけいざい /私経済/
しけいしっこう /死刑執行/
しけいしゅう /死刑囚/
しけいせいど /死刑制度/
しけいだい /死刑台/
しけいはんけつ /死刑判決/
しけつ /止血/
しけつざい /止血剤/
しけん /試験/私見/私権/四間/
しけんうんよう /試験運用/
しけんうんようちゅう /試験運用中/
しけんかいし /試験開始/
しけんかいじょう /試験会場/
しけんかもく /試験科目/
しけんかん /試験管;test tube/試験官;examiner/
しけんかんけい /試験関係/
しけんかんとく /試験監督/
しけんかんべいびー /試験管ベイビー/
しけんき /試験機/
しけんきかく /試験規格/
しけんきかん /試験期間/試験機関/
しけんきかんちゅう /試験期間中/
しけんけいたい /試験形態/
しけんけっか /試験結果/
しけんけんきゅう /試験研究/
しけんけんきゅうきかん /試験研究機関/
しけんけんきゅうひ /試験研究費/
しけんこうかいちゅう /試験公開中/
しけんし /試験紙/
しけんしゃ /試験車/
しけんしゃりょう /試験車両/
しけんしゅうりょう /試験終了/
しけんしょ /試験所/
しけんじかん /試験時間/
しけんじょ /試験所/
しけんじょう /試験場/
しけんじょうけん /試験条件/
しけんせい /試験生/
しけんせいど /試験制度/
しけんせつび /試験設備/
しけんせん /試験線/
しけんそうこう /試験走行/
しけんたいさく /試験対策/
しけんだい /試験台/
しけんだんかい /試験段階/
しけんち /試験地/
しけんちゅう /試験中/
しけんちゅうし /試験中止/
しけんてき /試験的/
しけんとうじつ /試験当日/
しけんないよう /試験内容/
しけんび /試験日/
しけんびしゃ /四間飛車/
しけんふごうかく /試験不合格/
しけんへん /試験片/
しけんべんきょう /試験勉強/
しけんほうそう /試験放送/
しけんほうほう /試験方法/
しけんまえ /試験前/
しけんめんじょ /試験免除/
しけんもんだい /試験問題/
しけんよう /試験用/
しげ /重/成/茂/恵/繁/滋/卯/楙/
しげあき /重明/重昭/成章/繁明/
しげい /至芸/重井/
しげえだ /重枝/
しげお /茂雄/重雄/茂男/繁雄/茂夫/重夫/繁男/重男/繁夫/成夫/茂生/滋夫/成雄/滋雄/滋生/滋男/繁生/惠雄/恵雄/
しげかず /重一/茂和/繁一/
しげかつ /重勝/
しげがき /茂垣/
しげき /刺激/刺戟/史劇/詩劇/茂樹/繁樹/重樹/滋樹/茂喜/枝隙/
しげきいき /刺激閾;stimulus threshold/
しげきおん /刺激音/
しげきざい /刺激剤/
しげきしゅう /刺激臭/
しげきてき /刺激的/
しげきぶつ /刺激物/
しげきやく /刺激薬/
しげきりょうほう /刺激療法;[医]/
しげく /繁く/
しげこ /茂子/滋子/シゲ子/
しげさだ /繁定/
しげさと /重里/
しげし /茂志/
しげしげ /繁々;-と眺める/繁繁/
しげじ /茂司/
しげぞう /茂三/
しげた /重田/
しげたか /重隆/重高/
しげたけ /重武/
しげつぐ /重継/
しげとし /成俊/恵俊/
しげとも /成伴/
しげなが /重永/
しげなり /重成/
しげの /重野/滋野/
しげのぶ /重信/茂伸/滋延/
しげのり /重徳/重則/茂則/繁則/茂典/繁徳/卯典/
しげはら /重原/
しげはる /重治/
しげひこ /重彦/茂彦/
しげひろ /茂弘/重弘/重宏/重博/繁弘/
しげふみ /重文/
しげまさ /茂昌/
しげまつ /重松/
しげみ /茂み/繁み/茂見/茂美/成美/茂実/
しげみち /茂道/
しげみつ /重光/
しげむら /重村/
しげもり /重森/繁盛/
しげや /茂哉/
しげやす /成康/
しげやま /茂山/繁山/
しげゆき /茂之/重行/茂行/繁之/繁行/滋之/
しげよし /重義/誠良/
しげり /成里/
しげる /茂/滋/繁/楙/
しげん /資源/至言/始原/始源/死言/
しげんえねるぎーちょう /資源エネルギー庁;経産省外局。www.enecho.meti.go.jp/
しげんかいしゅう /資源回収/
しげんかん /始原環/
しげんかんり /資源管理/
しげんがく /資源学/
しげんこうがく /資源工学/
しげんごみ /資源ゴミ/
しげんさいぼう /始原細胞/
しげんさいりよう /資源再利用/
しげんしょうひ /資源消費/
しげんじょう /資源上/
しげんじょうきょう /資源状況/
しげんすう /四元数/
しげんせい /資源性/
しげんせつやく /資源節約/
しげんはいぶん /資源配分/
しげんもんだい /資源問題/
しげんわりあて /資源割当て/
しこ /鬼;醜悪／頑丈/醜;=鬼。「-の御盾」/四股;-を踏む/指呼/四庫/
しこう /思考/施行;†「法の-」/施工;†「工事の-」/指向;†ある方向に向かう。「オブジェクト-」/志向;†心を向ける。「上昇-」/試行;test/嗜好/至高;supreme/歯垢/紙工/市交/私考/私好/伺候/詩稿/支考;人名,各務-/私行;private conduct/四光;花札の役/至幸;bliss/視紅;rhodopsin/市郊/篩孔/
しこうあん /試行案/
しこういんりょう /嗜好飲料/
しこうか /指甲花/
しこうかいすう /試行回数/
しこうかいろ /思考回路/
しこうかつどう /思考活動/
しこうかてい /思考過程/
しこうがた /指向型/
しこうきかい /思考機械/
しこうきかん /試行期間/
しこうきかんちゅう /試行期間中/
しこうきじつ /施行期日/
しこうきそく /施行規則/
しこうぎじゅつ /施工技術/
しこうくんれん /思考訓練/
しこうけいさん /指向計算/
しこうけいしき /思考形式/
しこうけいたい /思考形態/
しこうげんご /指向言語/
しこうご /施行後/
しこうさ /思考差/
しこうさくご /試行錯誤/
しこうさくごてき /試行錯誤的/
しこうして /而して/
しこうじかん /思考時間/
しこうじき /施行時期/
しこうじっけん /思考実験/
しこうせい /指向性;†directional.「-マイク」/嗜好性/志向性;†oriented.「リスク-」/
しこうぜん /至高善/
しこうだんかい /試行段階/
しこうちゅう /試行中/思考中/
しこうてい /始皇帝;中国史上初の皇帝/
しこうていし /思考停止/
しこうてき /試行的/指向的/
しこうとくせい /指向特性/
しこうないよう /思考内容/
しこうのうりょく /思考能力/
しこうひん /嗜好品/
しこうび /施行日/
しこうぶつ /嗜好物/
しこうほう /思考法/施行法;民法-,刑法-,都市計画法-/
しこうほうこう /指向方向/
しこうほうほう /思考方法/
しこうまえ /施行前/
しこうようしき /思考様式/
しこうりょく /思考力/
しこうれい /施行令/
しこく /四国/紫黒/市國/
しこくいっしゅう /四国一周/
しこくおき /四国沖/
しこくかくけん /四国各県/
しこくさぶろう /四国三郎/
しこくさんち /四国山地/
しこくしぶ /四国支部/
しこくしゅっしんしゃ /四国出身者/
しこくだいがく /四国大学/
しこくちほう /四国地方/
しこくでんか /四国電化/
しこくない /四国内/
しこくほうめん /四国方面/
しこぜんしょ /四庫全書/
しこたん /色丹/
しこたんとう /色丹島/
しこつ /指骨;[解剖]phalange of hand/肢骨/篩骨;[解剖](頭蓋の)ethmoid/趾骨;[解剖]phalange of foot/歯骨;[解剖]dentary/死骨/
しこつおきな /醜つ翁/
しこつこ /支笏湖/
しこつとうやこくりつこうえん /支笏洞爺国立公園/
しこな /四股名/醜名/
しこのみたて /醜の御楯/
しこみ /仕込み/
しこみづえ /仕込み杖/
しこめ /醜女/
しこり /凝/凝り;=痼り/痼/痼り;-を残す/
しころ /錏/錣/鍜/
しこん /歯根/紫紺/士魂/紫根/紫金/詩魂/私恨/
しこんいろ /紫根色/
しこんしょうさい /士魂商才/
しご /死後;after death/死語;obsolete word/私語;private talk.「-厳禁」/詩語;poetic diction/識語/
しごう /諡号/紫合/詩豪/
しごき /扱き/
しごぎ /子午儀/
しごく /至極/司獄/
しごくしぜん /至極自然/
しごくたんじゅん /至極単純/
しごくとうぜん /至極当然/
しごこうちょく /死後硬直/
しごころ /詩心/
しごせん /子午線/
しごと /仕事/
しごとあいて /仕事相手/
しごとうた /仕事唄/
しごとうん /仕事運/
しごとおさめ /仕事納め/
しごとかんきょう /仕事環境/
しごとかんけい /仕事関係/
しごとかんすう /仕事関数/
しごとがえり /仕事帰り/
しごとがら /仕事柄/
しごときゅう /仕事給/
しごとぎ /仕事着/
しごとさがし /仕事探し/
しごとさき /仕事先/
しごとざん /仕事算/
しごとし /仕事師/
しごとじたい /仕事自体/
しごとじょう /仕事上/
しごとだかばらい /仕事高払い/
しごとちゅう /仕事中/
しごとづくえ /仕事机/
しごとないよう /仕事内容/
しごとにん /仕事人/
しごとねっしん /仕事熱心/
しごとはじめ /仕事始め/
しごとはんぶん /仕事半分/
しごとば /仕事場/
しごとばこ /仕事箱/
しごとぶり /仕事振り/仕事ぶり/
しごとべや /仕事部屋/
しごとよう /仕事用/
しごとりつ /仕事率/
しごとりょう /仕事量/
しごはっぴょう /死後発表/
しごめん /子午面/
しごめんじゅんかん /子午面循環/
しさ /示唆;suggest/視差/示差;distinct/
しさい /司祭/市債/子細/仔細;=子細/詩才/
しさいぼう /視細胞/刺細胞/篩細胞/
しさいもの /仔細者/
しさく /施策/試作;trial.「-品」/思索/詩作;poetry/
しさくがた /試作型/
しさくき /試作機/
しさくしゃ /試作車/
しさくだんかい /試作段階/
しさくちゅう /試作中/
しさくてき /試作的/
しさくばん /試作版/
しさくひん /試作品;prototype/詩作品;poetical works/
しさくぶ /試作部/
しさつ /視察/刺殺/
しさつおん /歯擦音;[音声学]/
しさつたい /刺殺体/
しさつだん /視察団/
しさてき /示唆的;suggestive/示差的;distinctive/
しさん /資産/試算/四散/私産/四三/
しさんうんよう /資産運用/
しさんか /資産家/
しさんかぜい /資産課税/
しさんかち /資産価値/
しさんかんり /資産管理/
しさんがく /資産額/
しさんごうけい /資産合計/
しさんじかい /市参事会/
しさんちくせき /資産蓄積/
しさんちょうさ /資産調査/
しさんばんごう /資産番号/
しさんひょう /試算表/
しさんひょうか /資産評価/
しざ /視座/
しざい /資材;†materials.「建築-」/私財;†personal fortune.「-を抛つ」/死罪/資財;†fortune/詩材/
しざいおきば /資材置場/
しざいちょうたつ /資材調達/
しざわ /志沢/
しざん /試算/死産/
しざんけつが /屍山血河/
しざんしょうしょ /死産証書/
しし /獅子/四肢/志士/詩誌/死屍/嗣子/師資;師弟。「-相承」/師子/詩史/私史;⇔正史/支子;⇔嫡子/子思/孜々;努め励む様子/史詩/祠祀/宍/肉/貎/獅/猪/尿/孜孜/
ししいでん /紫宸殿;=ししんでん/
ししうち /猪内/
ししおう /獅子王/
ししおどし /鹿威し/
ししがしら /獅子頭/
ししき /司式/始式/
ししきゅう /四死球/獅子宮;[十二宮]しし座(7.23-8.22)/
ししく /獅子吼/
ししくい /宍喰/
ししざ /獅子座;Leo(Leo),(7.23-8.22)/
ししざりゅうせいぐん /獅子座流星群/
ししそうしょう /師資相承/
ししそんそん /子々孫々/
ししつ /資質/脂質;fat/紙質/私室/歯質/支質/
ししづか /宍塚/
ししとう /獅子唐/
ししど /宍戸/
ししどじょう /宍戸錠/
ししばな /獅子鼻/
ししふんじん /獅子奮迅/
ししまい /獅子舞/
ししむら /肉叢/臠/
ししゃ /死者/支社/使者/試写;preview.「映画の-」/試射;test-fire.「銃の-」/詩社/四捨/視射/
ししゃかい /試写会/
ししゃく /子爵/
ししゃごにゅう /四捨五入/
ししゃざい /止瀉剤/
ししゃすう /死者数/
ししゃちょう /支社長/
ししゃのしょ /死者の書/
ししゃも /柳葉魚/
ししゅ /死守/四種/旨酒/旨趣/詩趣/四衆;[仏教]比丘・比丘尼・優婆塞・優婆夷/詩酒/四趣;=四悪趣/錙銖;わずかなもの/
ししゅう /詩集/刺繍/死臭/四周/屍臭/志州;志摩/刺しゅう/
ししゅういり /刺繍入り/
ししゅうえん /歯周炎;[医]/
ししゅうき /思秋期/
ししゅうびょう /歯周病/
ししゅうへん /市周辺/
ししゅく /私淑/止宿/四宿/
ししゅつ /支出/
ししゅつがく /支出額/
ししゅつきん /支出金/
ししゅつきんがく /支出金額/
ししゅつごうけい /支出合計/
ししゅんき /思春期/
ししょ /支所/司書;librarian/史書;historical book/支署/詩書;poetry book/四書;大学・中庸・論語・孟子/私書/死所/
ししょう /師匠/支障/死傷/市章/視床/刺傷/詩抄/詞章/私娼/四生;[仏教]胎生・卵生・湿生・化生/指掌/嗤笑/師承/至小/
ししょうかぶ /視床下部/
ししょうくつ /私娼窟/
ししょうしゃ /死傷者/
ししょうじ /指小辞/
ししょうじこ /死傷事故/
ししょうすじ /師匠筋/
ししょうせつ /私小説/
ししょうびょう /私傷病;業務に起因しない労働者の病気や怪我/
ししょきょうゆ /司書教諭/
ししょく /試食/嗜食;人肉-,-癖/紙燭/
ししょくばん /試食版/
ししょごきょう /四書五経/
ししょしょうしょ /私署証書/
ししょばこ /私書箱/
ししよう /試使用/
ししるいるい /死屍累々/
ししん /指針/私信/視診/私心/詩心/至心/指診;[医]touch examination/詩神;μυσαι/四診;望診・聞診・問診・切診/使臣/
ししんあん /指針案/
ししんけい /視神経/歯神経/
ししんしんぎょう /至心信楽;[仏教]/
ししんせい /始新世;[地質年代]Eocene. 5650-3540万年前/
ししんでん /紫宸殿/
ししんもーど /私信モード/
しじ /支持/指示/私事/師事/榻/四時/指事;六書の一/死児/指似/
しじいがい /指示以外/
しじかのう /指示可能/
しじく /視軸;optic axis/詩軸;詩画軸/
しじこうぞう /支持構造/
しじご /指示語/
しじし /指示子;specifier/指示詞;[文法]demonstrative/
しじしゃ /支持者/
しじしゃすう /支持者数/
しじしょ /指示書/
しじせいとう /支持政党/
しじそう /支持層/
しじそくど /指示速度/
しじそしき /支持組織/
しじたいしょう /指示対象/
しじだい /支持台/
しじだいめいし /指示代名詞/
しじつ /史実/子実/
しじつがん /資治通鑑/
しじつごう /私事都合/
しじつたい /子実体/
しじてき /指示的/
しじひょう /指示票/
しじほうほう /指示方法/
しじぼう /指示棒/
しじぼたい /支持母体/
しじま /静寂/黙/四十万/
しじみ /蜆/
しじみがい /蜆貝/
しじみじる /蜆汁/しじみ汁/シジミ汁/
しじみちょう /蜆蝶/
しじゃく /枝雀/
しじやく /指示薬/
しじゅ /紫綬/
しじゅう /始終/四十/四重/四獣;青龍,白虎,朱雀,玄武/止住/
しじゅういっかん /始終一貫/
しじゅうかた /四十肩/
しじゅうから /四十雀/
しじゅうくにち /四十九日/
しじゅうしちし /四十七士/
しじゅうしょう /四重唱/
しじゅうそう /四重奏/
しじゅうそうきょく /四重奏曲/
しじゅうそうだん /四重奏団/
しじゅうはって /四十八手/
しじゅく /私塾/
しじゅつ /施術/師術/四術;詩・書・礼・楽/
しじゅほうしょう /紫綬褒章/
しじゅん /諮詢/至純/咨詢;=諮詢/示準;-化石/
しじゅんかせき /示準化石/
しじゅんせつ /四旬節/
しじょ /子女/
しじょう /市場/史上;in history.「-最大」/試乗/至上;supreme.「-の幸福」/誌上;magazine/紙上;paper/詩情;poesie/私情;「-をさしはさむ」/糸状/市上/支城;⇔本城/四条/四條/歯状/矢状/至情;まごころ/施錠;せじょう/
しじょう> /史上;-最低,-最高齢,-有数/
しじょうかい /試乗会/
しじょうかいたく /市場開拓/
しじょうかいにゅう /市場介入/
しじょうかかく /市場価格/
しじょうかくだい /市場拡大/
しじょうかち /市場価値/
しじょうからすま /四条烏丸/
しじょうかわらまち /四条河原町/
しじょうき /試乗記/
しじょうきぼ /市場規模/
しじょうきょう /私情協/
しじょうきょうそう /市場競争/
しじょうきんこう /市場均衡;[経済]market equilibrium/
しじょうくうぜん /史上空前/
しじょうけいざい /市場経済/
しじょうけいせい /市場形成/
しじょうけんしゅう /市場研修/
しじょうげんり /市場原理/
しじょうさいきょう /史上最強/
しじょうさいこう /史上最高/
しじょうさいだい /史上最大/
しじょうさいてい /史上最低/
しじょうさいねんしょう /史上最年少/
しじょうさいやすね /史上最安値/
しじょうしゃ /試乗車/
しじょうしゅぎ /至上主義/市場主義/
しじょうせい /市場性/
しじょうせん /四条線/
しじょうちょうさ /市場調査/
しじょうてき /市場的/
しじょうてんのう /四条天皇/
しじょうとうにゅう /市場投入/
しじょうとうろん /誌上討論/
しじょうとりひき /市場取引/
しじょうなわて /四条畷/四條畷/
しじょうのあい /至上の愛/
しじょうのしっぱい /市場の失敗;[経済]market failure/
しじょうはつ /史上初/
しじょうぶんせき /市場分析/
しじょうめいだい /至上命題/
しじょうめいれい /至上命令/
しじょうりすく /市場リスク/
しじょうれい /市条例/
しじりつ /支持率/指示率/
しじりょく /支持力/
しじん /詩人/私人/四神;青龍,白虎,朱雀,玄武/士人/至人/資人/
しじんそうおう /四神相応/
しすい /止水/泗水;(si shui) 山東省の川/酒々井;人名/市水/
しすう /指数;index/紙数;紙幅/
しすうかんすう /指数関数/
しすうかんすうてき /指数関数的/
しすうげんすい /指数減衰/
しすうそく /指数則/
しすうてき /指数的/
しすうぶ /指数部/
しすうぶんぷ /指数分布/
しすうほうそく /指数法則/
しすてむか /システム化/
しすてむかいはつ /システム開発/
しすてむかんり /システム管理/
しすてむこうがく /システム工学/
しすてむしょうがい /システム障害/
しすてむせっけい /システム設計/
しすてむてちょう /システム手帳/
しすてむりろん /システム理論/
しず /静/靜;「静」の旧字(人名用漢字)/志津/
しずい /歯髄/雌蕊/
しずいえん /歯髄炎;[医]pulpitis/
しずえ /下枝;⇔上枝(ほつえ)/静江/静枝/志津恵/
しずお /静雄/静夫/静男/鎮雄/靜生/
しずおか /静岡/靜岡;旧字/
しずおかえき /静岡駅/
しずおかえきまえ /静岡駅前/
しずおかかん /静岡間/
しずおかがわ /静岡側/
しずおかぎんこう /静岡銀行/
しずおかけん /静岡県/
しずおかけんない /静岡県内/
しずおかけんみん /静岡県民/
しずおかけんりつだいがく /静岡県立大学/
しずおかこうこう /静岡高校/
しずおかし /静岡市/
しずおかしみん /静岡市民/
しずおかしんぶん /静岡新聞/
しずおかせいぶ /静岡西部/
しずおかせんばつ /静岡選抜/
しずおかだい /静岡大/
しずおかだいいち /静岡第一/
しずおかだいがく /静岡大学/
しずおかちく /静岡地区/
しずおかてつどう /静岡鉄道/
しずおかほうそう /静岡放送/
しずおかりこう /静岡理工/
しずおかりこうか /静岡理工科/
しずおかりこうかだい /静岡理工科大/
しずか /静/静香/静佳/閑か/静か/靜か;「静」旧字/
しずかごぜん /静御前/
しずがたけ /賤ヶ岳/
しずがわ /志津川/
しずぎん /静銀/
しずく /雫/滴/
しずくいし /雫石/
しずけさ /静けさ/
しずこ /静子/志津子/
しずごころ /静心/
しずしず /静々/
しずたに /閑谷/
しずだい /静大/
しずだいこうがくぶ /静大工学部/
しずない /静内/
しずのめ /賤の女/
しずのや /賤の屋/
しずみうお /沈み魚/
しずめ /沈め/鎮め/
しずや /静谷/靜谷/
しずりだい /静理大/
しずる /静流/
しずわ /後輪/
しせい /姿勢/市井;ちまた。「-の人」/市政;†市の行政/市制;†市の制度/刺青/施政;administrate/死生/市勢/至誠/私製/四声/雌性/至聖/詩聖;(杜甫)/資性;うまれつき/氏姓/私生;-児/志誠/
しせいか /施政下/
しせいかく /姿勢角/
しせいかつ /私生活/
しせいかん /死生観/司政官/
しせいけん /施政権/
しせいさつじんじけん /刺青殺人事件/
しせいし /市政史/
しせいしき /示性式/
しせいしこう /市制施行/
しせいしゃ /施政者/
しせいじ /私生児/
しせいじょ /至聖所;[宗教]sanctum sanctorum(holy of holies)/
しせいせいぎょ /姿勢制御/
しせいせいど /氏姓制度/
しせいせこう /市制施行/
しせいたい /四声体/
しせいだい /始生代/
しせいどう /資生堂/
しせいはがき /私製葉書/
しせいはだ /脂性肌/
しせいへんか /姿勢変化/
しせき /史跡/歯石/史蹟;=史跡/史籍;≒史書/咫尺/枝跡/
しせきせんり /咫尺千里/
しせきめいしょうてんねんきねんぶつ /史跡名勝天然記念物/
しせつ /施設;facility/私設;private.「-秘書」/使節;delegate/私説;private opinion/詩節;strophe/師説/士節/
しせつ> /私設;-秘書,-応援団,-サイト/
しせつおうえんだん /私設応援団/
しせつかいご /施設介護/
しせつかいせん /私設回線/
しせつかん /施設間/
しせつぜんたい /施設全体/
しせつちょう /施設長/
しせつとう /施設等/
しせつとしょかん /私設図書館/
しせつない /施設内/
しせつひ /施設費/
しせつひしょ /私設秘書/
しせつぶ /施設部/
しせん /視線/四川/支線;branch line/死線;deadline/詩仙/脂腺/私選/私戦/死戦/私撰/詩箋/
しせんけい /支線系/
しせんしょう /四川省/
しせんどう /詩仙堂/
しせんにゅうりょく /視線入力/
しせんふう /四川風/
しせんべんごにん /私選弁護人/
しせんりょうり /四川料理/
しぜい /市税/
しぜん /自然/至善/
しぜんあいて /自然相手/
しぜんいさん /自然遺産/
しぜんえんえき /自然演繹/
しぜんおん /自然音/
しぜんおんかい /自然音階/
しぜんかい /自然界/
しぜんかいとう /自然解凍/
しぜんかがく /自然科学/
しぜんかがくいがい /自然科学以外/
しぜんかがくてき /自然科学的/
しぜんかん /自然観/
しぜんかんき /自然換気;natural ventilation. 窓などによる. ⇔強制換気/
しぜんかんきょう /自然環境/
しぜんかんきょうほぜんほう /自然環境保全法/
しぜんかんさつ /自然観察/
しぜんかんそう /自然乾燥/
しぜんが /自然画/
しぜんがく /自然学/
しぜんききょう /自然気胸/
しぜんきゅうかむら /自然休暇村/
しぜんきゅうき /自然吸気/
しぜんけい /自然系/
しぜんけいざい /自然経済;natural economy/
しぜんけん /自然権/
しぜんげんご /自然言語/
しぜんげんごしょり /自然言語処理/
しぜんげんごりかい /自然言語理解/
しぜんげんしょう /自然現象/
しぜんこう /自然光/
しぜんこうえん /自然公園/
しぜんこうえんほう /自然公園法/
しぜんこうさつえい /自然光撮影/
しぜんさいがい /自然災害/
しぜんし /自然史;natural history/自然誌;=博物学/自然死;natural death/
しぜんしつぎょうりつ /自然失業率;[経済]/
しぜんしはくぶつかん /自然史博物館/
しぜんしゃかい /自然社会/
しぜんしゅうきょう /自然宗教/
しぜんしゅぎ /自然主義/
しぜんしゅぎてき /自然主義的/
しぜんしょうめつ /自然消滅/
しぜんしょうもう /自然消耗/
しぜんしょく /自然色/
しぜんしんがく /自然神学;natural theology/
しぜんしんろん /自然神論/
しぜんじ /自然児/
しぜんじょうたい /自然状態/
しぜんじん /自然人/
しぜんじんるいがく /自然人類学;physical anthropology/
しぜんすう /自然数/
しぜんすうぜんたい /自然数全体/
しぜんすうはい /自然崇拝/
しぜんすうろん /自然数論/
しぜんせい /自然性/
しぜんせき /自然石;fieldstone/
しぜんせんたく /自然選択;自然淘汰/
しぜんそう /自然葬/
しぜんぞう /自然増/
しぜんたい /自然体/
しぜんたいすう /自然対数/
しぜんたいりゅう /自然対流/
しぜんちゆ /自然治癒/
しぜんちゆのうりょく /自然治癒能力/
しぜんちゆりょく /自然治癒力/
しぜんちょう /自然長/
しぜんちょうわ /自然調和/
しぜんちりがく /自然地理学;physiography/
しぜんていぼう /自然堤防/
しぜんてき /自然的/
しぜんてきかんきょう /自然的環境/
しぜんてつがく /自然哲学/
しぜんとうた /自然淘汰/
しぜんどうぶつえん /自然動物園/
しぜんどくせん /自然独占;[経済]natural monopoly/
しぜんにんしき /自然認識/
しぜんのうほう /自然農法/
しぜんはかい /自然破壊/
しぜんはくぶつかん /自然博物館/
しぜんはっか /自然発火/
しぜんはっせい /自然発生/
しぜんはっせいてき /自然発生的/
しぜんはん /自然犯/
しぜんび /自然美/
しぜんぶつ /自然物/
しぜんぶん /自然文/
しぜんぶんかい /自然分解/
しぜんぶんけんさく /自然文検索/
しぜんぶんべん /自然分娩/
しぜんへんかん /自然変換/
しぜんほう /自然法/
しぜんほうしゃせん /自然放射線/
しぜんほうしゃのう /自然放射能/
しぜんほうそく /自然法則/
しぜんほご /自然保護/
しぜんほごだんたい /自然保護団体/
しぜんらっか /自然落下/
しぜんりつ /自然律/
しそ /始祖/紫蘇/
しそう /思想/試走/試奏/歯槽/死相/志操/詩想/宍粟/師僧/視奏/使嗾/詩草;詩の草稿/詩僧;poet-priest/指嗾;=使嗾/私送/祀竃/祀竈/
しそうか /思想家/
しそうかい /思想界/
しそうがた /視奏型/
しそうきょういく /思想教育/
しそうけんご /志操堅固/
しそうげんろん /思想言論/
しそうし /思想史/
しそうしつ /試奏室/
しそうしょ /思想書/
しそうしんじょう /思想信条/
しそうせい /思想性/
しそうたいけい /思想体系/
しそうてき /思想的/
しそうてきはいけい /思想的背景/
しそうとうせい /思想統制/
しそうなど /思想等/
しそうのうろう /歯槽膿漏/
しそうのじゆう /思想の自由;憲法19条/
しそうはいけい /思想背景/
しそうはん /思想犯/
しそか /シソ科/Labiatae/
しそく /子息/四則/四足/紙燭/脂燭/
しそくいろ /脂燭色;襲の色目/
しそくえんざん /四則演算/
しそちょう /始祖鳥/
しそつ /士卒/
しそまき /紫蘇巻き;[料理]調味味噌を紫蘇で巻いたもの/紫蘇巻/
しそもく /シソ目/Laminales/
しそん /子孫/至尊/
しぞう /死蔵/私蔵/
しぞうひん /死蔵品/
しぞく /氏族;clan/士族;武士階級/
した /下/舌/簧;reed/↓/舍;?/舐;?/舖;?/
した> /下;-準備,-拵え,-交渉/
したあご /下顎/
したあじ /下味/
したあらい /下洗い/
したい /死体/肢体;limbs/姿態/屍体;=死体/死胎;dead fetus/四諦;[仏教]苦諦・集諦・滅諦・道諦/詩体/姿体;NB:「姿態」は立ち居振る舞いまで含む/死體;「体」旧字/
したいあん /施耐庵;水滸伝/
したいいき /死体遺棄/
したいいきざい /死体遺棄罪/
したいいきじけん /死体遺棄事件/
したいおきば /死体置場/
したいけんあんしょ /死体検案書/
したいしょうがい /肢体障害/
したいしょり /死体処理/
したいじんいしょく /死体腎移植/
したいふ /士大夫/
したうけ /下請け/下請/
したうけにん /下請人/
したうち /舌打ち/舌打/
したえ /下絵/
したえだ /下枝/
したえつけ /下絵付け/
したえのぐ /下絵の具/
したおび /下帯/
したか /志鷹/
したかた /下方/
したがき /下書き/下書/
したがって /従って/
したがり /下刈り/
したがわ /下側/
したきりすずめ /舌切り雀;お伽話/
したぎ /下着/
したぎすがた /下着姿/
したく /支度/仕度;=支度/私宅/
したくきん /支度金/仕度金/
したくさ /下草/
したくちびる /下唇/
したくべや /支度部屋/
したぐつ /襪/
したぐみ /下組み/
したぐら /下鞍/
したけんぶん /下検分/
したげいこ /下稽古/
したごころ /下心/
したごしらえ /下拵え/下ごしらえ/
したごろも /下衣/
したさき /舌先/
したさきさんずん /舌先三寸/
したさんかく /下三角/
したざわり /舌触り/
したし /親し/
したしい /親/
したしく /親しく/
したしごと /下仕事/
したしょく /下職/
したしらべ /下調べ/下調/
したじ /下地/
したじき /下敷/下敷き/
したじゅんび /下準備/
したず /下図/
したそうだん /下相談/
したぞめ /下染め/
したたか /強か/健か/
したため /認め/
したたらず /舌足らず/
しただ /下田/
しただい /舌代/
したったらず /舌っ足らず/
したっぱ /下っ端/下端/下っぱ/
したっぱら /下っ腹/
したつ /示達/
したつき /下付き/
したつけ /下付/
したつづみ /舌鼓/
したつゆ /下露/
したづかい /舌使い/
したづつみ /舌鼓/
したづみ /下積み/
したて /下手/仕立て/仕立/
したてだしなげ /下手出し投げ/
したてなおし /仕立て直し/
したてなげ /下手投げ/
したてひねり /下手捻り/
したてもの /仕立物/
したてや /仕立屋/
したてん /．/
したで /下手/
したどり /下取り/下取/
したどりがく /下取額/
したなげ /下投げ/
したなめずり /舌舐めずり/
したに /下荷/
したぬり /下塗り/下塗/
したね /下値/
したの /下野/
したのね /舌の根/
したはら /下腹/
したはんぶん /下半分/
したば /下端/下葉/
したばえ /下生/下生え/
したばかま /下袴/
したばき /下履き/下穿き/下履/
したばたらき /下働き/
したばなし /下話/
したばり /下張り;襖の-/
したひも /下紐/
したび /下火/下樋/
したほうこう /下方向/
したまえ /下前/
したまえば /下前歯/
したまち /下町/
したまちことば /下町言葉/
したまちふう /下町風/
したみ /下見/下身/
したみいた /下見板/
したみず /下水/
したみち /下道/
したむき /下向き/
しため /下目/
したや /下谷/↓/下矢/下屋/
したやく /下役/下訳/
したやしき /下屋敷;⇔上屋敷/
したやじるし /↓/下矢印/
したゆで /下茹で/
したよみ /下読み/
したら /設楽/
したりがお /したり顔/
したん /紫檀/始端/肢端;手足の末端/枝端;木の枝の末端/
しだ /試打/羊歯/志田;人名/志太;人名/信太;人名/歯朶;=羊歯/羊齒;「歯」旧字/齒朶;「歯」旧字/
しだい /次第/私大/四大;[仏教]地水火風/至大;⇔至小/詩題/
しだいきしょ /四大奇書;水滸伝・三国志演義・西遊記・金瓶梅/
しだいしだいに /次第次第に/
しだいすう /始代数/
しだいせつ /四大節;四方拝・紀元節・天長節・明治節/
しだいに /次第に/
しだし /仕出し/
しだしょくぶつ /羊歯植物/シダ植物/
しだじょうしゅししょくぶつあこう /Pteridospermidae/
しだじょうしゅししょくぶつもく /Pteridospermales/
しだよう /試打用/
しだら /設楽/
しだるい /羊歯類/
しだれざくら /枝垂れ桜/垂れ桜/
しだれやなぎ /枝垂れ柳/垂れ柳/
しだわら /志俵/
しだん /師団/指弾/史談/詩壇/指彈;旧字/
しだんきぼ /師団規模/
しだんしょ /示談書/
しだんほんぶ /師団本部/
しち /質/七/死地/貭/私地;私有地. ⇔公地/四知;天知る地知る人知る我知る/至知;-は幾ならず/至智;ultimate sagesse/叱/
しち> /七/
しちいれ /質入れ/
しちいれうらがき /質入裏書/
しちいれしょうけん /質入証券/
しちうけ /質請け/
しちかいき /七回忌/
しちかく /視知覚/
しちがしゅく /七ヶ宿/
しちがつ /七月/７月/7月/文月;※連想,旧暦/
しちがつかくめい /七月革命;[世界史]la Revolution de Juillet(1830.7)/
しちがはま /七ヶ浜/
しちく /紫竹/糸竹;弦楽器と管楽器/飼畜/
しちぐさ /質草/質種/
しちけい /七経/
しちけん /質権/
しちけんしゃ /質権者/
しちけんせっていしゃ /質権設定者/
しちげんきん /七弦琴/
しちごさん /七五三/
しちごちょう /七五調/
しちごん /七言/
しちごんこし /七言古詩;[文学]七字で句数無制限の漢詩/
しちごんぜっく /七言絶句;[文学]七字四句の漢詩/
しちごんりっし /七言律詩/
しちさん /七三/
しちさんわけ /七三分け/
しちしちにち /七七日;四十九日/
しちしとう /七支刀/
しちしゃ /七社/
しちしょ /七書/
しちしょう /七生/
しちじ /七時/
しちじしき /七事式;[茶道]/
しちじゅう /七重/七十/
しちじゅうしち /七十七/
しちじゅうにんやくせいしょ /七十人訳聖書;Septuagint/
しちじゅうほうじゅ /七重宝樹/
しちじょう /七条/七城/七丈/
しちじょうかわらまち /七条河原町/
しちずんどけい /シチズン時計/
しちせい /七星/
しちせき /七赤/
しちだね /質種/
しちだん /七段/
しちてんはっき /七転八起/
しちてんばっとう /七転八倒/
しちとく /七徳/
しちど /七度/
しちどうがらん /七堂伽藍/
しちながれ /質流れ/
しちならべ /七並べ/
しちなん /七難/
しちなんはっく /七難八苦/
しちにん /七人/
しちねん /七年/
しちねんせんそう /七年戦争;1756-63/
しちねんめ /七年目/
しちのへ /七戸/
しちふく /七福/
しちふくじん /七福神/
しちふくせい /七福星/
しちふだ /質札/
しちぶ /七分/
しちぶしゅう /七部集;蕪村-,俳諧-,其角-/
しちへんげ /七変化/
しちほ /七歩/
しちほう /七宝;金・銀・瑠璃・玻璃・しゃこ・珊瑚・瑪瑙/
しちほのさい /七歩の才/
しちほん /七本/
しちみ /七味/
しちみとうがらし /七味唐辛子/
しちめんちょう /七面鳥/
しちめんどう /七面倒;「七」当て字/しち面倒/
しちゃく /試着/
しちゃくしつ /試着室/
しちや /質屋/七夜/
しちゅう /市中/支柱/司厨/死中/仔虫/
しちゅうかかく /市中価格/
しちゅうぎんこう /市中銀行/
しちゅうこん /支柱根/
しちゅうしんぶ /市中心部/
しちゅうすいめい /四柱推命/
しちょう /市長;mayor/試聴;†(preview)「-して買う」/視聴;†(watch)「-覚」「-者」/市町/支庁;⇔本庁/市庁;市庁舎/思潮/死兆/市朝/師長/士長/輜重/仕丁/征;[囲碁]/四丁;[囲碁]/紙帳;紙製の蚊帳/使庁/弛張/詩調/至重/鷙鳥;-群せず/
しちょうかい /試聴会;新譜の-/視聴会;古い映画の-/
しちょうかく /視聴覚/
しちょうかくきょういく /視聴覚教育/
しちょうかくしつ /視聴覚室/
しちょうかくしりょう /視聴覚資料/
しちょうかくじょうほう /視聴覚情報/
しちょうかくてき /視聴覚的/
しちょうかくてきこうか /視聴覚的効果/
しちょうかのう /視聴可能/
しちょうき /試聴記/
しちょうしつ /試聴室;listening room/視聴質;⇔視聴率/
しちょうしゃ /視聴者/市庁舎/
しちょうしゃさんか /視聴者参加/
しちょうしゃそう /視聴者層/
しちょうせん /市長選/
しちょうせんきょ /市長選挙/
しちょうそん /市町村/
しちょうそんがっぺい /市町村合併/
しちょうそんぎかい /市町村議会/
しちょうそんぎょうせい /市町村行政/
しちょうそんぜい /市町村税/
しちょうそんちょう /市町村長/
しちょうそんみんぜい /市町村民税/
しちょうそんやくしょ /市町村役所/
しちょうそんやくば /市町村役場/
しちょうねつ /弛張熱/
しちょうへい /輜重兵/
しちょうゆそつ /輜重輸卒/
しちょうりつ /視聴率/
しちょうりつかくほ /視聴率確保/
しちょうりつちょうさ /視聴率調査/
しちょうりょう /視聴料/
しちょく /司直/
しちょっけい /視直径/
しちよう /七曜/
しちようせい /七曜星/
しちようひょう /七曜表/
しちり /七里/
しちりけっかい /七里結界/
しちりん /七輪/
しちろう /七郎/
しちろうじ /七郎次/
しっか /失火/膝下/膝窩;膝の裏/叱呵/
しっかい /悉皆/
しっかく /失格/
しっかくしゃ /失格者/
しっかつ /失活/
しっかと /確と/聢と/
しっかり /確り/聢り/
しっかりもの /しっかり者/確り者;<rare>/
しっかん /疾患/失陥/失官/
しっかんしゃ /疾患者/
しっかんめい /疾患名/
しっき /湿気/漆器/
しっきゃく /失脚/
しっきん /失禁/
しっく /疾駆/
しっくい /漆喰/
しっけ /湿気/
しっけい /失敬/失計/
しっけつ /失血/
しっけつし /失血死/
しっけん /識見/執権/失権/
しっこ /疾呼/
しっこう /執行/失効/失行;[医]apraxia/膝行/
しっこうかん /執行官/
しっこうきかん /執行機関/
しっこうきそく /執行規則/
しっこうけん /執行権/
しっこうこうい /執行行為/
しっこうさいばんしょ /執行裁判所/
しっこうさんど /膝行三度/
しっこうしゃ /執行者/
しっこうしょう /失行症;[医]apraxia/
しっこうしょうしょ /執行証書/
しっこうしょぶん /執行処分/失効処分/
しっこうちゅう /執行中/
しっこうていし /執行停止/
しっこうにん /執行人/
しっこうぶ /執行部/
しっこうやく /執行役;委員会等設置会社において、業務執行を担当する者/
しっこうやくいん /執行役員/
しっこうゆうよ /執行猶予/
しっこうり /執行吏;apparitor/
しっこうりつ /執行率/
しっこうりょく /執行力/
しっこく /漆黒/桎梏/
しっこし /尻腰/
しっこんごう /執金剛/
しっさく /失策/失錯;≒失策/
しっしき /湿式/
しっしきこうほう /湿式工法;wet construction. eg.モルタル,コンクリ/
しっしっ /叱叱/
しっしょ /失書/
しっしょう /失笑/湿生;[仏教]/
しっしょく /失職/
しっしん /湿疹/失神/
しっせい /湿性/失政/湿生;[植物]⇔乾生/執政/叱正;叱り、正す。「ご-をお願いします」/叱声;叱る声。「-が飛ぶ」/
しっせいかん /執政官/
しっせいしょう /失声症;[精医]/
しっせいしょくぶつ /湿生植物;hydrophyte/
しっせき /叱責/失跡/叱斥/
しっせきちょう /叱責調/
しっそ /質素/
しっそう /疾走/失踪/執奏/
しっそうかん /疾走感/
しっそうしゃ /失踪者/
しっそうせんこく /失踪宣告/
しっそく /失速/
しっそくそくど /失速速度/
しった /叱咤/
しったい /失態/失対;[略語]失業対策/
しったか /知ったか;[口]知ったかぶり/
しったかぶり /知ったか振り/
しったげきれい /叱咤激励/
しったつ /執達/
しったつり /執達吏/
しったるた /悉達多;Siddhartha/
しったん /悉曇/
しったんがく /悉曇学/
しっち /湿地;marsh/失地;-回復/
しっちかいふく /失地回復/
しっちたい /湿地帯/
しっちゃく /失着/
しっちゃくご /漆着語/
しっちゅう /集注/失注;⇔受注/集註/
しっちょう /失調/室長/
しっちょうしょう /失調症/
しっちんまんぽう /七珍万宝/
しっつい /失墜/
しって /尻手/
しってん /失点/質点;しつてん/
しってんばっとう /七転八倒/
しっと /嫉妬/
しっとう /執刀/失当;inadequate/失投;[野球]careless pitch/
しっとうい /執刀医/
しっとしん /嫉妬心/
しっともうそう /嫉妬妄想/
しっぱい /失敗/
しっぱいさく /失敗作/
しっぱいしゃ /失敗者/
しっぱいじ /失敗時/
しっぱいじれい /失敗事例/
しっぱいだん /失敗談/
しっぱいりつ /失敗率/
しっぱいれい /失敗例/
しっぴ /失費/櫛比/
しっぴつ /執筆/
しっぴつかつどう /執筆活動/
しっぴつしゃ /執筆者/
しっぴつしゃめい /執筆者名/
しっぴつじゅん /執筆順/
しっぴつじん /執筆陣/
しっぴつちゅう /執筆中/
しっぴつようりょう /執筆要領/
しっぷ /湿布/
しっぷう /疾風/
しっぷうじんらい /疾風迅雷/
しっぷうどとう /疾風怒涛/
しっぷうもくう /櫛風沐雨/
しっぺい /疾病/竹篦/
しっぺいほけん /疾病保険;health insurance/
しっぺがえし /しっぺ返し/
しっぽ /尻尾/
しっぽう /七宝/
しっぽうとう /七宝塔/
しっぽうもん /七宝文/
しっぽうやき /七宝焼/七宝焼き/
しっぽく /卓袱/
しっぽくだい /卓袱台/
しっぽくりょうり /卓袱料理/
しつ /質/室/瑟;琴瑟/失/疾;疾病/嫉;嫉妬/湿;湿度/濕;「湿」の旧字(人名用漢字)/隰;(さわ)/漆;(うるし)漆器/膝;ひざ/悉;悉皆/蟋;蟋蟀/櫛;くし/叱;叱責/執;執務/蛭;ひる/貭;「質」の異体字/隲;(のぼる)/出;?/
しつい /失意/執意/視追/
しついん /室員/
しつう /歯痛/止痛/私通/四通;-八達/
しつうはったつ /四通八達/
しつおか /室岡/
しつおん /室温/
しつおんいか /室温以下/
しつおんちょうせい /室温調整/
しつおんていど /室温程度/
しつかい /室会/
しつかん /質感/
しつかんせつ /膝関節/
しつがい /室外/膝蓋/
しつがいき /室外機/
しつがいこつ /膝蓋骨/
しつがいじんたい /膝蓋靭帯/
しつがいよう /室外用/
しつぎ /質疑/
しつぎおうとう /質疑応答/
しつぎょう /失業/
しつぎょうしゃ /失業者/
しつぎょうたいさく /失業対策/
しつぎょうちゅう /失業中/
しつぎょうほけん /失業保険/
しつぎょうりつ /失業率/
しつけ /躾/仕付/仕付け/
しつけいと /仕付け糸/
しつげい /漆芸/
しつげん /湿原/失言/
しつご /失語/
しつごしょう /失語症/
しつじ /執事/
しつじつ /質実/
しつじつごうけん /質実剛健/
しつじゅん /湿潤/
しつぜつ /湿舌;大雨の原因となる/
しつちょう /室長/
しつてき /質的/
しつてきこうじょう /質的向上/
しつてきさ /質的差/
しつてきへんか /質的変化/
しつてきへんかん /質的変換/
しつてきもんだい /質的問題/
しつてん /質点/
しつてんけい /質点系;[物理]mass system/
しつでん /湿田/
しつでんち /湿電池;wet cell/
しつど /湿度/
しつどう /室堂/
しつどおんど /湿度温度/
しつどくしょう /失読症/
しつどけい /湿度計/
しつない /室内/
しつないうんどうかい /室内運動会/
しつないおんきょう /室内音響/
しつないおんじょう /室内音場/
しつないかんきょう /室内環境/
しつないかんげんがくだん /室内管弦楽団/
しつないがく /室内楽/
しつないがくばん /室内楽版/
しつないがわ /室内側/
しつないき /室内機/
しつないきょうぎ /室内競技/
しつないぎ /室内着;gown/
しつないこう /室内光/
しつないさつえい /室内撮影/
しつないそうおん /室内騒音/
しつないそうしょく /室内装飾;interior decorating/
しつないちょう /室内長/
しつないとう /室内灯/
しつないはば /室内幅/
しつないぷーる /室内プール/
しつないぼし /室内干し/
しつにん /失認/
しつねん /失念/
しつねんかぶ /失念株;[経済]/
しつば /叱罵/
しつばん /湿板;⇔乾板/
しつばんごう /室番号/
しつぼう /失望/
しつぼうかん /失望感/
しつぼく /質朴/質樸/
しつむ /執務/悉無/
しつむしつ /執務室/
しつむてき /悉無的/
しつむりつ /悉無律;[生物]全か無かの法則/
しつめい /失明/室名/
しつめいしゃ /失明者/
しつめいじょうたい /失明状態/
しつもん /質問/
しつもんいと /質問意図/
しつもんかしょ /質問箇所/
しつもんきじ /質問記事/
しつもんきのう /質問機能/
しつもんけいしき /質問形式/
しつもんけん /質問権/
しつもんこうもく /質問項目/
しつもんしつ /質問室/
しつもんしほう /質問紙法/
しつもんしゃ /質問者/
しつもんしゅう /質問集/
しつもんしょ /質問書/
しつもんじこう /質問事項/
しつもんじたい /質問自体/
しつもんじょう /質問状/
しつもんぜめ /質問攻め/質問責め/
しつもんちゅう /質問中/
しつもんでんわ /質問電話/
しつもんないよう /質問内容/
しつもんなど /質問等/
しつもんばこ /質問箱/
しつもんひょう /質問票/
しつもんぶん /質問文/
しつもんほうこく /質問報告/
しつもんもと /質問元/
しつもんよう /質問用/
しつよう /執拗/
しつらえ /設え/
しつらく /失楽/
しつらくえん /失楽園;Paradise Lost,1667,Milton/
しつりょう /質量;weight/室料;room charge/質料;[哲学]`υλη/
しつりょういん /質料因;アリストテレス/
しつりょうけっそん /質量欠損/
しつりょうさ /質量差/
しつりょうすう /質量数/
しつりょうそく /質量則/
しつりょうそくど /質量速度/
しつりょうぞうだい /質量増大/
しつりょうたい /質量体/
しつりょうちゅうしん /質量中心/
しつりょうひ /質量比/
しつりょうぶんせきけい /質量分析計/
しつりょうぶんぷ /質量分布/
しつりょうほぞん /質量保存/
しつりょうほぞんそく /質量保存則/
しつれい /失礼/
しつれいせんばん /失礼千万/
しつれん /失恋/
しつろ /失路;拓落-/
しづ /志津/
しづえ /志津恵/
しづか /謐/
しづがわ /志津川/
しづき /志筑/志築;姓/
しづく /雫;旧仮名/滴/
して /仕手/支手/爲手;「為」旧字/
してい /指定/師弟;†師匠と弟子/子弟;†年少者/姉弟/視程/私邸/仕丁/
していえき /指定駅/
していか /指定可/
していかのう /指定可能/
していかんけい /師弟関係/
していかんせんしょう /指定感染症/
していき /指定機/
していきかん /指定機関/
していきょうしゅうじょ /指定教習所/
していぎょう /指定行/
していぎょうしゃ /指定業者/
していぎょうむ /指定業務/
していくうきあつ /指定空気圧/
していけん /指定券/
していこうざ /指定口座/
していし /指定子/
していしゃ /指定車/
していしょく /指定職/
していしょしき /指定書式/
していじ /指定時/
していじかん /指定時間/
していすう /指定数/
していせいぶん /指定成分/
していせき /指定席/
していせきけん /指定席券/
していせきしゃ /指定席車/
していせきしゃりょう /指定席車両/
していせきとっきゅうけん /指定席特急券/
していせきよう /指定席用/
していせきりょうきん /指定席料金/
していち /指定地/
していちいきない /指定地域内/
していてん /指定店/指定点/
していとし /指定都市/
していどおり /指定通り/
していばんごう /指定番号/
していひん /指定品/
していび /指定日/
していふく /指定服/
していぶ /指定部/
していへんこう /指定変更/
していほう /指定法/
していほうほう /指定方法/
していぼうりょくだん /指定暴力団/
していめいがら /指定銘柄/
していよう /指定用/
していらん /指定欄/
していれい /指定例/
していれっしゃ /指定列車/
してかた /仕手方/シテ方/
してかぶ /仕手株/
してき /指摘/私的/史的/詩的/至適/
してき> /私的;-年金,-制裁,-顧問/
してきか /指摘下/
してきげんご /私的言語/
してきしよう /私的使用/
してきしようもくてき /私的使用目的/
してきじこう /指摘事項/
してきじち /私的自治/
してきせいさい /私的制裁;lynch/
してきせいり /私的整理;⇔法的整理/
してきどくせん /私的独占/
してきねんきん /私的年金/
してきふくせい /私的複製/
してきもくてき /私的目的/
してきゆいぶつろん /史的唯物論/
してきりえき /私的利益/
してきりよう /私的利用/
してきりようもくてき /私的利用目的/
してせん /仕手戦/
してつ /私鉄/
してつしゃりょう /私鉄車両/
してつせん /私鉄線/
してつでんしゃ /私鉄電車/
してとう /シテ島;Ile de la Cite/
してん /視点/支店/始点;⇔終点/支点;テコの-/祀典/祀天/
してんいぞん /視点依存/
してんざひょう /視点座標/
してんし /熾天使;seraphim/
してんじょうほう /支店情報/
してんちょう /支店長/
してんちょうさま /支店長様/
してんとう /支店等/
してんのう /四天王/
してんのうじ /四天王寺/
してんのうじまえ /四天王寺前/
してんめい /支店名/
しで /死出;-の旅/四手;[植物]hornbeam/椣;=四手/垂;=四手/
しでのたび /死出の旅/
しでのやま /死出の山/
しではら /幣原/
しではらきじゅうろう /幣原喜重郎/
しでむし /埋葬虫/
しでん /紫電/史伝/師伝/市電/
しでんいっせん /紫電一閃/
しでんかい /紫電改;旧海軍の戦闘機/紫電海;?/
しでんはいし /市電廃止/
しと /使途/使徒;apostles/死都/司徒/尿/
しとう /死闘/至当/私闘/指頭/紫藤/私党/
しとうかん /四等官;[律令制]長官・次官・判官・主典/
しとぎ /粢/
しとぎょうでん /使徒行伝/
しとく /至徳;年号(1384-1387)/四徳/
しとづつ /尿筒/
しとど /鵐/
しとね /褥/茵/
しとふめい /使途不明/
しとふめいきん /使途不明金/
しとみ /蔀/
しとみや /蔀屋/
しとめにん /仕留人/
しとやか /淑やか/
しど /志度/示度/私度/
しどう /指導/始動/市道;city road/私道;private road/士道/祠堂/四道/至道;最高の人道/斯道;この道/師道/詩道/示導/
しどうい /指導医/
しどういん /指導員/
しどういんけんしゅうかい /指導員研修会/
しどういんけんてい /指導員検定/
しどういんしつ /指導員室/
しどうか /指導下/
しどうきかん /指導機関/
しどうきょういく /指導教育/
しどうきょうかん /指導教官/
しどうきょうじゅ /指導教授/
しどうげんり /指導原理;ethos/
しどうこんなん /始動困難/
しどうご /始動後/
しどうしゃ /指導者/
しどうしゃたち /指導者達/
しどうしょ /指導書/
しどうじ /始動時/
しどうせい /始動性/指導性/
しどうせきにん /指導責任/
しどうそう /指導層/
しどうたいきょく /指導対局/
しどうだんたい /指導団体/
しどうちょくご /始動直後/
しどうてき /指導的/
しどうてきたちば /指導的立場/
しどうてびきしょ /指導手引書/
しどうどうき /示導動機/
しどうないよう /指導内容/
しどうぶ /指導部/
しどうほう /指導法/
しどうほうしん /指導方針/
しどうめん /指導面/
しどうようこう /指導要項/
しどうようりょう /指導要領/
しどうりねん /指導理念/
しどうりょく /指導力/
しどく /試読/死毒/屍毒/
しどせん /志度線/
しどそう /私度僧/
しどちょうせい /視度調整/
しどり /倭文/
しな /品/支那/科/
しない /市内/竹刀/
しないいどう /市内移動/
しないえき /市内駅/
しないかんこう /市内観光/
しないきどう /市内軌道/
しないきょくばん /市内局番/
しないきんこう /市内近郊/
しないざん /シナイ山;地名,Sinai/
しないじゅんかん /市内循環/
しないず /市内図/
しないせん /市内線/
しないたいかい /市内大会/
しないちゅうしんぶ /市内中心部/
しないつうわ /市内通話/
しないでんわ /市内電話/
しないでんわばんごう /市内電話番号/
しないでんわりょうきん /市内電話料金/
しないはんとう /シナイ半島;Sinai/
しないよう /市内用/
しなうす /品薄/
しなかず /品数/
しながき /品書き/品書/
しながら /品柄/
しながれ /品枯れ/
しながわ /品川/
しながわえき /品川駅/
しながわえきひがしぐち /品川駅東口/
しながわえきまえ /品川駅前/
しながわえきみなとみなみぐち /品川駅港南口/
しながわかん /品川間/
しながわく /品川区/
しながわくひがししながわ /品川区東品川/
しながわじょしがくいん /品川女子学院/
しながわひがしぐち /品川東口/
しなぎれ /品切れ/品切/
しなこ /信成子/
しなさだめ /品定め/
しなじな /品々/
しなじへん /支那事変/支那事變/
しなそば /支那蕎麦/
しなぞろえ /品揃え/
しなだ /品田/
しなだい /品代/
しなだま /品玉/
しなちく /支那竹;メンマ/
しなつるせん /品鶴線/
しなの /信濃/品濃/品野/
しなのおおまち /信濃大町/
しなのおおまちえき /信濃大町駅/
しなのがわ /信濃川/
しなのき /科の木/
しなのじ /信濃路/
しなのちょう /信濃町/
しなのまち /信濃町/
しなのまちえき /信濃町駅/
しなぶれ /品触れ/
しなもじ /品文字/
しなもの /品物/
しなん /指南/至難/
しなんしょ /指南書/
しなんじょ /指南所/
しなんばん /指南番/
しなんやく /指南役/
しに /死に;⇔生き/
しにいし /死に石/
しにいたるやまい /死に至る病;Sygdommen til Doden,1849,Kierkegaard (絶望のこと)/
しにかけ /死に掛け/
しにかた /死に方/
しにがお /死に顔/
しにがね /死に金/
しにがみ /死神/死に神/
しにぎわ /死に際/
しにく /歯肉/死肉/屍肉/視肉;中国の怪物/
しにくえん /歯肉炎/
しにくち /死に口/
しにげしょう /死に化粧/
しにざま /死に様/
しにしょうぞく /死装束/死に装束/
しにじたく /死に支度;Prepare to die, mortal!/
しにすがた /死に姿/
しにせ /老舗/
しにせきゅうだん /老舗球団/
しにせてん /老舗店/
しにぞこない /死に損ない/死に損い/
しにたい /死に体;[相撲]/
しにどき /死に時/
しにどころ /死に所/死に処/
しにはじ /死に恥/
しにば /死に場/
しにばしょ /死に場所/
しにばな /死に花/
しにひょう /死に票/死票/
しにびと /死に人/
しにみ /死に身/
しにみず /死に水/
しにめ /死に目/
しにものぐるい /死に物狂い/
しにゅう /刺入/
しにょう /屎尿/し尿/支繞/
しにょうしょり /し尿処理/屎尿処理/
しによう /死に様/
しにわかれ /死に別れ/
しにん /視認/死人/
しにんかのう /視認可能/
しにんせい /視認性/
しねん /思念/
しねんごう /私年号/
しの /篠/志乃/志野/紫乃/信乃/詩乃/
しのう /子嚢/詩嚢/司農/四能/
しのうきん /志納金/
しのうきんるい /子嚢菌類/
しのうくんれんし /視能訓練士/
しのうけい /司農卿/
しのうこうしょう /士農工商/
しのかわ /篠川/篠河/
しのがき /篠垣/
しのき /篠木/
しのぎ /鎬;-を削る/凌ぎ/篠木/凌/
しのぎじ /鎬地/
しのぎづくり /鎬造り/
しのくりせん /篠栗線/
しのごの /四の五の/
しのざき /篠崎/
しのしま /篠島/
しのしょうにん /死の商人/
しのすけ /志の輔/
しのたけ /篠竹/
しのだ /篠田/信田/信太/
しのだけ /篠竹/
しのだずし /信太鮨/
しのだまき /信太巻き/信太巻/
しのづか /篠塚/
しののい /篠ノ井/
しののいせん /篠ノ井線/
しののめ /東雲/
しののめぶし /東雲節;(明治)/
しのはい /死の灰/
しのはら /篠原/
しのばず /不忍/
しのばずぐち /不忍口/
しのばずのいけ /不忍池/
しのび /忍び/忍/
しのびあい /忍び逢い/
しのびあし /忍び足/
しのびあるき /忍び歩き/
しのびごえ /忍び声/
しのびで /忍び手;音を立てない拍手/
しのびなき /忍び泣き/
しのびね /忍び音/
しのびねものがたり /忍音物語/
しのびのもの /忍ノ者/
しのびわらい /忍び笑い/
しのぶ /忍/信夫/偲/紫伸/
しのぶえ /篠笛/
しのぶぐさ /忍草/荵/
しのみや /四宮/篠宮/四ノ宮/
しのむら /篠村/
しのもと /篠本/
しのやま /篠山/
しのやまきしん /篠山紀信/
しのろ /篠路/
しは /支派/
しはい /支配/賜杯/紙背/紙牌/
しはいか /支配下/
しはいかいきゅう /支配階級/
しはいかいそう /支配階層/
しはいぎ /支配木/
しはいけん /支配権/
しはいこう /支配項/
しはいこうぞう /支配構造/
しはいし /支配子/
しはいしゃ /支配者/
しはいしゃそう /支配者層/
しはいせつ /支配節/
しはいそう /支配層/
しはいち /支配地/
しはいちいき /支配地域/
しはいてき /支配的/
しはいてきちい /支配的地位/
しはいにん /支配人/
しはいもんじょ /紙背文書/
しはいよく /支配欲/
しはいりつ /支配率/
しはいりょく /支配力/
しはく /糸帛/
しはす /師走/
しはちへい /詩八病/
しはつ /始発/
しはつえき /始発駅/
しはつぐみ /始発組/
しはつち /始発地/
しはつていりゅうじょ /始発停留所/
しはつてん /始発点/
しはつでんしゃ /始発電車/
しはつびん /始発便/
しはつれっしゃ /始発列車/
しはらい /支払い/支払/
しはらいかんじょう /支払勘定/
しはらいがく /支払額/
しはらいき /支払機/
しはらいきょぜつしょうしょ /支払拒絶証書/
しはらいきんがく /支払金額/
しはらいじゅんびきん /支払準備金/
しはらいずみ /支払済/
しはらいせきにんしゃ /支払責任者/
しはらいち /支払地/
しはらいちょうしょ /支払調書/支払い調書/
しはらいていし /支払停止/
しはらいてがた /支払手形/
しはらいてすうりょう /支払手数料;勘定科目。社外の専門家に支払われる手数料/
しはらいにん /支払人/
しはらいのうりょく /支払能力/
しはらいび /支払日/
しはらいほうほう /支払方法/
しはらいほしょう /支払保証/
しはらいまどぐち /支払窓口/
しはらいめいれい /支払命令;[法]/
しはらいゆうよ /支払猶予;moratorium/
しはらいりし /支払利子/
しはらいりそく /支払利息/
しはらいりつ /支払率/
しはん /市販/師範/四半/紫斑/死斑/私版/屍斑/
しはんか /市販化/
しはんかかく /市販価格/
しはんがっこう /師範学校;ecole normale(Fr.)/
しはんき /四半期/
しはんきけっさん /四半期決算/
しはんしゃ /市販車/
しはんしゃりょう /市販車両/
しはんせいき /四半世紀/
しはんせいひん /市販製品/
しはんだい /師範代/
しはんひん /市販品/
しはんびょう /紫斑病/
しはんぶん /四半分/
しはんやく /市販薬/
しはんよう /市販用/
しば /芝/柴/司馬/斯波/死馬/
しばい /芝居/
しばいえ /芝居絵/
しばいぎ /芝居気/
しばいけ /芝池/
しばいごや /芝居小屋/
しばいじゃや /芝居茶屋;※仮名遣い「しばいぢゃや」/
しばいたい /四倍体;[生物]tetraploid/
しばいぢゃや /芝居茶屋/
しばいっけ /芝居っ気/
しばいぬ /柴犬/
しばうら /芝浦/
しばうらこうだい /芝浦工大/
しばえび /芝海老/芝エビ/芝蝦/青蝦/
しばかり /芝刈り/芝刈/柴刈り/柴刈/
しばかわ /芝川/
しばがき /柴垣/
しばき /柴木/
しばくさ /芝草/
しばけいけん /芝経験/
しばこうえん /芝公園/
しばこうかん /司馬江漢/
しばこうだい /芝工大/
しばさき /柴崎/
しばざかな /芝魚/
しばざき /柴崎/
しばざくら /芝桜/
しばし /暫し/暫/
しばした /芝下/
しばしば /屡/屡々/
しばす /市バス/始バス/
しばせん /司馬遷;漢の武帝の時代の人。史記の著者/
しばた /柴田/新発田/芝田/柴多/
しばたれんざぶろう /柴田錬三郎/
しばち /芝地/
しばづけ /柴漬け/柴漬/
しばの /柴野/芝野/
しばはし /柴橋/
しばはま /芝浜/
しばはら /柴原/芝原/
しばふ /芝生/
しばふせき /芝生席/
しばふひろば /芝生広場/
しばふぶぶん /芝生部分/
しばぶね /柴舟/
しばまた /柴又/
しばまち /柴町/
しばみや /柴宮/
しばめ /芝目/
しばやま /柴山/芝山/
しばやまてつどう /芝山鉄道/
しばらく /暫く/
しばらくぶり /暫く振り/
しばり /縛り/
しばりくび /縛り首/
しばりょうたろう /司馬遼太郎/
しばん /指板/篩板/
しばんむし /死番虫/
しひ /私費/詩碑/市費/施肥;せひ./
しひつ /紙筆/史筆/
しひゃくしびょう /四百四病/
しひょう /指標/死票/師表/私評/四表;四方/
しひょうか /指標化/
しび /至微/
しびと /死人/
しびとばな /死人花/
しびょう /死病/祠廟/詩病/
しびょうし /四拍子;小鼓・大鼓・太鼓・笛/
しびれ /痺れ/痺/
しびん /尿瓶;=溲瓶/溲瓶/
しふ /師父/紙布/師傅/詩賦/
しふう /詩風/
しふく /至福/私服;⇔制服/紙幅/雌伏;⇔雄飛/私腹;「-を肥やす」/
しふくせんねん /至福千年/
しふとじす /シフトJIS/
しふん /脂粉/私憤/紙粉/
しぶ /支部/渋/市部/四分/四部/師部;[植物]phloem/篩部;=師部/４分/澁;「渋」の旧字(人名用漢字)/澀;「渋」の異体字/
しぶあき /４分空/
しぶい /渋井/
しぶいち /四分一/
しぶえ /渋江/
しぶおんぷ /四分音符/４分音符/
しぶかいひ /支部会費/
しぶかつどう /支部活動/
しぶかわ /渋皮/渋川/
しぶかわえき /渋川駅/
しぶかわおんせん /渋川温泉/
しぶがき /渋柿/
しぶがきたい /シブがき隊/
しぶがっしょう /四部合唱/
しぶがみ /渋紙/
しぶがみいろ /渋紙色/
しぶき /飛沫/沫/渋木;山桃/繁吹/
しぶくさ /渋草/
しぶこう /渋公/
しぶさ /澁佐;姓/
しぶさわ /渋沢/澁澤/
しぶさわえき /渋沢駅/
しぶさわかん /渋沢間/
しぶさわたつひこ /澁澤龍彦;(1928-1987) 仏文学者/渋沢竜彦;※新字表記/
しぶし /志布志/
しぶしぶ /渋々/
しぶた /渋田/
しぶたいかい /支部大会/
しぶたに /渋谷/
しぶちゃ /渋茶/
しぶちょう /支部長/
しぶつ /私物/死物/
しぶつか /私物化/
しぶとうげ /渋峠/
しぶぬき /渋抜き/
しぶみ /渋み/
しぶみがわ /渋海川/
しぶや /渋谷/澁谷/
しぶやえき /渋谷駅/
しぶやえきまえ /渋谷駅前/
しぶやかいかん /渋谷会館/渋谷会舘/
しぶやかん /渋谷間/
しぶやく /渋谷区/澁谷區/
しぶやけい /渋谷系/
しぶやこうかいどう /渋谷公会堂/
しぶやじょし /渋谷女子/
しぶやせいぶ /渋谷西武/
しぶやてん /渋谷店/
しぶやほうこう /渋谷方向/
しぶやほうめん /渋谷方面/
しぶり /仕振り/
しぶりばら /渋り腹/
しぶれいかい /支部例会/
しぶろく /四分六/
しぶん /詩文/四分/士分/死文/支分/
しぶんか /死文化/
しぶんぎ /四分儀/
しぶんごれつ /四分五裂/
しぶんしゅう /詩文集/
しぶんしょ /私文書/
しぶんしょぎぞう /私文書偽造/
しへい /紙幣/子平/私兵/
しへいちょう /子平町/
しへいまち /子平町/
しへき /四壁/
しへん /詩篇/紙片/詩編;[聖書]Psalms(Ps,Psa)/四辺/
しへんけい /四辺形/
しべ /蕊/蘂;「蕊」の異体字1/蕋;「蕊」の異体字2/
しべちゃ /標茶/
しべつ /死別/士別;地名,北海道北部/標津;地名,北海道東部/標別;?/
しべつせん /標津線/
しべとろ /蕊取/
しべりあ /西伯利亞/
しべん /支弁/至便/思弁/
しべんてき /思弁的;speculative/
しほ /志保/志穂/志帆/詩穂;名/紫穂/試補/潮/汐/鹽/
しほう /司法/四方/至宝/私法/紫峰/刺胞/詩法/子法;⇔母法/市報/視法/死法/
しほうい /四方位;東西南北/
しほういいん /司法委員/
しほうかいぼう /司法解剖/
しほうかん /司法官/
しほうかんけいしゃ /司法関係者/
しほうかんけん /司法官憲/
しほうかんりょう /司法官僚/
しほうきかん /司法機関/
しほうきょうじょ /司法共助/
しほうぎょうせい /司法行政/
しほうけいさつしょくいん /司法警察職員/
しほうけん /司法権/
しほうけんしゅうじょ /司法研修所/
しほうさいばんしょ /司法裁判所/
しほうしけん /司法試験/
しほうしゅうしゅうせい /司法修習生/
しほうしょう /司法省/司法相;†大臣/
しほうしょし /司法書士/
しほうじん /私法人/
しほうせいど /司法制度/
しほうだい /仕放題/し放題/
しほうだいじん /司法大臣/
しほうちく /四方竹/
しほうちょうかん /司法長官/
しほうていど /四方程度/
しほうてん /至宝展/
しほうとうきょく /司法当局/
しほうとりひき /司法取引;[法]捜査協力の見返りに減刑等をすること/
しほうどうぶつ /刺胞動物/
しほうはい /四方拝;1.1/
しほうはっぽう /四方八方/
しほうはんだん /司法判断/
しほこ /志保子/
しほこう /支保工;[土木](support)/
しほさゐ /潮騒/
しほどき /潮時/
しほひ /潮干/
しほふき /潮吹き/
しほろ /士幌/
しほん /資本/紙本/
しほんか /資本家/
しほんかかいきゅう /資本家階級;capitalist class/
しほんかんけい /資本関係/
しほんかんじょう /資本勘定/
しほんがわ /資本側/
しほんきん /資本金/
しほんこうせい /資本構成/
しほんごうけい /資本合計/
しほんさんか /資本参加/
しほんざい /資本財/
しほんしじょう /資本市場/
しほんしゅぎ /資本主義/
しほんしゅぎけいざい /資本主義経済/
しほんしゅぎしゃ /資本主義者/
しほんしゅぎしゃかい /資本主義社会/
しほんしゅぎてき /資本主義的/
しほんしんか /資本深化;capital deepening/
しほんしんしゅつ /資本進出/
しほんじゅんびきん /資本準備金;法定準備金の一種。新株発行時の額面オーバー分/
しほんじょうよきん /資本剰余金/
しほんせい /資本制/
しほんちくせき /資本蓄積/
しほんていけい /資本提携/
しほんとりひき /資本取引/
しほんぬし /資本主/
しほんばしら /四本柱;[相撲]/
しほんりょく /資本力/
しほんろん /資本論/
しぼ /思慕/私募/皺/
しぼう /死亡/脂肪/志望/子房/
しぼういちじきん /死亡一時金;国民年金/
しぼうかい /子房下位/
しぼうかん /脂肪肝;脂肪のついた肝臓/
しぼうきじ /死亡記事/
しぼうげんいん /死亡原因/
しぼうこう /志望校/
しぼうさいぼう /脂肪細胞/
しぼうさん /脂肪酸/
しぼうしゃ /死亡者/志望者/
しぼうしゅ /脂肪腫;[医]lipoma/
しぼうしんだんしょ /死亡診断書/
しぼうじ /死亡時/
しぼうじこ /死亡事故/
しぼうすう /死亡数/
しぼうそしき /脂肪組織;[生物]adipose tissue/
しぼうぞく /脂肪族;[化学]/
しぼうた /柴生田/
しぼうとどけ /死亡届/
しぼうどうき /志望動機/
しぼうはんてい /死亡判定/
しぼうぶん /脂肪分/
しぼうほけん /死亡保険/
しぼうほけんきん /死亡保険金/
しぼうゆ /脂肪油/
しぼうりつ /死亡率/
しぼうりょう /脂肪量/
しぼく /司牧/
しぼさい /私募債;private issue. ⇔公募債/
しぼつ /死没/死歿/
しぼり /絞り/
しぼりかす /絞り滓/搾り滓/
しぼりじる /絞り汁/搾り汁;juice.「レモンの-」/
しま /島/縞/嶋;「島」の旧字(人名用漢字)/志摩/四万;地名/志麻/嶌;「島」の異体字2/揣摩/志真/
しまあじ /縞鰺/
しまい /姉妹/終い/仕舞い/仕舞/了い/
しまいかんけい /姉妹関係/
しまいき /姉妹機/
しまいきしゅ /姉妹機種/
しまいこう /姉妹校/
しまいご /姉妹語/
しまいさき /縞伊佐木/
しまいしゃ /姉妹車/
しまいてん /姉妹店/
しまいとし /姉妹都市/
しまいひん /姉妹品/
しまいへん /姉妹編/姉妹篇/
しまいやく /姉妹役/
しまうた /島唄;[民謡]琉球地方/
しまうち /島内/
しまうちゅう /島宇宙/
しまお /島尾/嶋尾/
しまおか /島岡/
しまおくそく /揣摩臆測/
しまか /縞蚊/
しまかげ /島影/島陰/
しまかぜ /島風/
しまがくれ /島隠れ/
しまがはら /島ヶ原/
しまがら /縞柄/
しまき /島木/
しまきんぺん /島近辺/
しまぐに /島国/
しまぐにこんじょう /島国根性/
しまぐにてき /島国的/
しまこ /志麻子/
しまこうさく /島耕作/
しまこうぞう /縞構造/
しまさき /島崎/嶋崎/
しまざき /島崎/嶋崎/
しまざきとうそん /島崎藤村/
しましま /縞々/
しまじ /島地/
しまじょう /縞状/
しまじり /島尻/
しまず /島津/
しませ /島瀬/
しません /島線/志摩線/
しませんき /島戦記/
しまぜんぶ /島全部/
しまたに /島谷/嶋谷/
しまだ /島田/嶋田/
しまだい /縞鯛/
しまだかん /島田間/
しまだし /島田市/
しまだようこ /島田陽子/
しまつ /始末/嶋津/
しまつしょ /始末書/
しまつにん /始末人/
しまづ /島津/嶋津/
しまづけ /島津家/
しまづせいさくしょ /島津製作所;[企業名]/
しまづたい /島伝い/
しまてつ /島鉄/
しまとう /島藤/
しまなか /島中/嶋中/
しまながし /島流し/
しまね /島根/
しまねけん /島根県/
しまねげんぱつ /島根原発/
しまねだい /島根大/
しまねちょう /島根町/
しまの /島野/嶋野/
しまのうち /島之内/
しまのせき /島ノ関/
しまばら /島原/
しまばらこう /島原港/
しまばらさん /島原山/
しまばらし /島原市/
しまばらしない /島原市内/
しまばらじょう /島原城/
しまばらてつどう /島原鉄道/
しまばらはんとう /島原半島/
しまひ /仕舞ひ/
しまぶくろ /島袋/
しまほうめん /島方面/
しままき /島牧/
しままつ /島松/
しまみや /嶋宮/
しまむら /島村/嶋村/
しまめ /縞目/
しまめのう /縞瑪瑙/
しまもと /島本/
しまもよう /縞模様/
しまもり /島守/島森/
しまや /島谷/
しまやま /島山/
しまり /締まり;-のない顔/締り/締/
しまりす /縞栗鼠/
しまりや /締り屋/
しまわき /嶋脇/
しまんとがわ /四万十川/
しみ /紙魚;bookworm/衣魚;≒紙魚/詩味/染み/凍み/汚点/蠹魚/
しみじみ /染々/沁々/
しみず /清水/志水/紫水/
しみずいくたろう /清水幾太郎;(1907-88) 評論家/
しみずえき /清水駅/
しみずかわ /清水川/
しみずけんせつ /清水建設;[企業名]/
しみずさわ /清水沢/
しみずし /清水市/
しみずしみん /清水市民/
しみずしょう /清水商/
しみずだいら /清水平/
しみずだに /清水谷/
しみずちょう /清水町/
しみずとうげ /清水峠/
しみずぬま /清水沼/
しみずはら /清水原/
しみずひがし /清水東/
しみずひがしこうこう /清水東高校/
しみずや /清水屋/
しみずよしのり /清水義範/
しみどうふ /凍み豆腐/
しみぬき /染み抜き/
しみもち /凍み餅/
しみゃく /支脈/
しみょう /至妙/
しみん /市民/嗜眠/士民;士族と平民/
しみんうんどう /市民運動/
しみんうんどうだんたい /市民運動団体/
しみんおんせん /市民温泉/
しみんか /市民課/市民化/
しみんかいかん /市民会館/
しみんかいかんまえ /市民会館前/
しみんかくめい /市民革命/
しみんぎいん /市民議員/
しみんけん /市民権/
しみんげきじょう /市民劇場/
しみんしゃかい /市民社会/
しみんせいかつ /市民生活/
しみんせんそう /市民戦争;civil war/
しみんぜい /市民税/
しみんたいかい /市民大会/
しみんだいがく /市民大学/
しみんだいがくこうざ /市民大学講座/
しみんだんたい /市民団体/
しみんてきじゆう /市民的自由/
しみんびょういん /市民病院/
しみんびょうどう /四民平等/
しみんほう /市民法;le droit bourgeoi/
しみんむせん /市民無線/
しみんよう /市民用/
しむかっぷ /占冠/
しむかっぷかん /占冠間/
しむけ /仕向/仕向け/
しむけこく /仕向国/
しむけち /仕向地/仕向け地/
しむら /志村/
しめ /締め/〆/注連;boundary marker.「-縄」/志免;地名/締/示/
しめい /氏名/指名;nominate/使命;mission/市名/誌名/紙名/指命;order/死命/
しめいいいんかい /指名委員会;委員会等設置会社の取締役会内に設置される委員会/
しめいかいこ /指名解雇/
しめいかん /使命感/
しめいぎょうしゃ /指名業者/
しめいさいけん /指名債権/
しめいじ /指名時/
しめいじゅんい /指名順位/
しめいすいせん /指名推選/
しめいだしゃ /指名打者/
しめいつうわ /指名通話/
しめいてはい /指名手配/
しめいひょうじけん /氏名表示権/
しめいらん /使命欄/
しめいりょう /指名料/
しめかざり /注連飾り/標飾り/七五三飾り/
しめがね /締金/
しめきり /締切/締め切り/締切り/〆切/〆切り/
しめきりご /締切後/
しめきりじこく /締切時刻/
しめきりちょくぜん /締切直前/
しめきりび /締切日/締め切り日/〆切日/
しめきりまえ /締切前/
しめきりまぎわ /締切間際/
しめぐ /締め具/締具/
しめこみ /締め込み;[相撲]まわし/締込み;[相撲]/
しめご /締め後/
しめさば /締め鯖/
しめし /示し/
しめしばい /湿し灰;[茶道]/
しめじ /湿地;きのこ/
しめすへん /示偏/
しめだいこ /締太鼓/締め太鼓/
しめつ /死滅/
しめつけ /締め付け/締付け/締めつけ/
しめて /〆て/締めて;-2000万円也/
しめなわ /注連縄/七五三縄/標縄/
しめの /示野/
しめび /締め日/締日/
しめむら /示村/
しめり /湿り/
しめりけ /湿り気/
しめりごえ /湿り声/
しめりゆき /湿り雪/
しめわざ /締め技/締技/
しめん /紙面/誌面/四面/
しめんそか /四面楚歌/
しめんたい /四面体/
しも /霜/下/
しも> /下;下一段(活用),下御所,下女中/
しもあがた /下県/
しもあな /霜穴/
しもあやし /下愛子/
しもい /下井/下位/
しもいぐさ /下井草/
しもいだ /下井田/
しもいち /下市/下一/
しもいちだん /下一段/
しもいちだんかつよう /下一段活用/
しもいな /下伊那/
しもいなば /下稲葉/
しもう /刺毛/
しもうさ /下総/
しもうま /下馬/
しもお /下尾/
しもおか /下岡/
しもおちあい /下落合/
しもかた /下方/
しもかぬき /下香貫/
しもかまがり /下蒲刈/
しもかわ /下川/
しもかわべ /下河辺/
しもがこい /霜囲い/
しもがも /下鴨/
しもがもおんせん /下賀茂温泉/
しもがもじんじゃ /下鴨神社/
しもがれ /霜枯れ/
しもき /下期/
しもきた /下北/
しもきたこうつう /下北交通/
しもきたざわ /下北沢/
しもきたざわえき /下北沢駅/
しもきたざわきたぐち /下北沢北口/
しもきたはんとう /下北半島/
しもきたやま /下北山/
しもぎょう /下京/
しもく /四木/
しもくに /下國/
しもくろかわ /下黒川/
しもぐち /下口/
しもげ /下毛/
しもこうべ /下河辺/
しもこしき /下甑/
しもごう /下郷/
しもごえ /下肥/
しもごおり /下郡/
しもさか /下坂/
しもさくのべ /下作延/
しもざ /下座/
しもざき /霜崎;姓/
しもざと /下里/
しもざわ /下沢/
しもしき /下敷/
しもしきりょう /下敷領/
しもしん /下新/
しもじ /下地/
しもじま /下嶋/
しもじも /下々/下下/
しもじゅう /下重/
しもじょう /下條/下条/下城/
しもすわ /下諏訪/
しもすわえき /下諏訪駅/
しもせわ /下世話/
しもぞの /下園/下薗/
しもたかい /下高井/
しもたかいど /下高井戸/
しもたかの /下高野/
しもたや /仕舞屋/仕舞た屋/
しもだ /下田/
しもだいら /下平/
しもだて /下館/
しもちしま /下地島/
しもちゃ /下家;[麻雀]/
しもちゅういほう /霜注意報/
しもつ /下津/
しもつい /下津井/
しもついでんてつ /下津井電鉄/
しもつかた /下つ方/
しもつが /下都賀/
しもつき /霜月;陰暦11月/下付き/
しもつけ /下野/
しもつじ /下辻/
しもつふさ /下総;しもうさ/
しもつま /下妻/
しもづま /下妻/
しもて /下手/
しもと /楚/笞/
しもとり /霜鳥/霜取り;defrost/下鳥/霜取/
しもどけ /霜解け/霜融け/
しもなか /下中/
しもなり /下成/
しもに /下二/
しもにいかわ /下新川/
しもにた /下仁田/
しもにたねぎ /下仁田葱/
しもにだん /下二段/
しもにだんかつよう /下二段活用/
しもねた /下ネタ/
しもの /下野/
しものく /下の句/
しものせき /下関/
しものせきえき /下関駅/
しものせきかん /下関間/
しものせきがわ /下関側/
しものせきし /下関市/
しものせきじょうやく /下関条約;1895/
しもはんき /下半期/
しもはんしん /下半身/
しもばしら /霜柱/
しもばやし /下林/
しもひとけた /下一桁/
しもひろ /下廣/
しもふさ /下総/
しもふり /霜降り/霜降/
しもぶくれ /下膨れ/下脹れ;-のたるんだ頬/
しもへい /下閉伊/
しもべ /下部/僕/下僕/
しもましき /下益城/
しもまるこ /下丸子/
しもみち /下道/
しもみのち /下水内/
しもむ /下無/
しもむら /下村/
しもめぐろ /下目黒/
しもやけ /霜焼け/
しもやしき /下屋敷/
しもやなぎ /下柳/
しもやま /下山/霜山/
しもやまて /下山手/
しもよ /霜夜/
しもよけ /霜除け;[園芸]antifrost/
しもよし /下吉/
しもれんじゃく /下連雀/
しもん /諮問/指紋/試問/子門/市門/
しもんいいんかい /諮問委員会/
しもんかい /試問会/
しもんかいぎ /諮問会議/
しもんきかん /諮問機関/
しもんしょうごう /指紋照合/
しもんじ /指文字/
しもんなついん /指紋捺印/
しゃ /車/者/社/写/射/謝/舎/煮;煮沸/奢;豪奢/赭;赭顔/赦;容赦/遮;遮蔽/鷓;鷓鴣/蔗;蔗糖/紗;羅紗/砂;土砂/沙;恒河沙/娑;娑婆/捨;喜捨/舍;「舎」の旧字/洒;瀟洒/西;xi/斜;斜面/這;(は・う)這般/炙;(あぶ・る)親炙/卸;おろし/柘;柘榴(ざくろ)/瀉;吐瀉/寫;「写」の旧字1/冩;「写」の旧字2/
しゃーぷ /♯;音楽記号/＃;number/
しゃあ /西/
しゃい /謝意/斜位/差異/
しゃいん /社員/社印/
しゃいんかん /社員間/
しゃいんきょういく /社員教育/
しゃいんしょう /社員証/
しゃいんしょくどう /社員食堂/
しゃいんそうかい /社員総会;社団法人の議決機関(株主総会相当)/
しゃいんばんごう /社員番号/
しゃいんりょう /社員寮/
しゃいんりょこう /社員旅行/
しゃいんわり /社員割/
しゃうん /社運/
しゃえい /射影/写影/
しゃえいほう /射影法/
しゃおう /沙翁;Shakespeare/
しゃおく /社屋/
しゃおん /遮音/謝恩/
しゃおんかい /謝恩会/
しゃおんこうか /遮音効果/
しゃおんせい /遮音性/
しゃおんせいのう /遮音性能/
しゃおんとうきゅう /遮音等級/
しゃおんとくせい /遮音特性/
しゃおんもじ /写音文字/
しゃおんりょう /遮音量/
しゃか /釈迦/社歌/
しゃかい /社会/
しゃかいあく /社会悪/
しゃかいいがく /社会医学;social medicine/
しゃかいいしき /社会意識/
しゃかいいっぱん /社会一般/
しゃかいいどう /社会移動/
しゃかいいりょう /社会医療/
しゃかいうんどう /社会運動/
しゃかいか /社会科;†(科目)/社会化;†socialisation.「性行動の-」/
しゃかいかいそう /社会階層/
しゃかいかいはつ /社会開発/
しゃかいかがく /社会科学/
しゃかいかがくかんけい /社会科学関係/
しゃかいかがくけい /社会科学系/
しゃかいかがくてき /社会科学的/
しゃかいかがくぶんや /社会科学分野/
しゃかいかつどう /社会活動/
しゃかいかてい /社会過程/
しゃかいかんきょう /社会環境/
しゃかいかんけい /社会関係/
しゃかいかんげん /社会還元/
しゃかいかんしゅう /社会慣習/
しゃかいがく /社会学/
しゃかいがくしゃ /社会学者/
しゃかいがくてき /社会学的/
しゃかいがくぶ /社会学部/
しゃかいきこう /社会機構/
しゃかいきはん /社会規範/
しゃかいきばん /社会基盤/
しゃかいきょういく /社会教育/
しゃかいきょういくがく /社会教育学/
しゃかいきょういくほう /社会教育法/
しゃかいけいやく /社会契約/
しゃかいけん /社会権/
しゃかいけんきゅうじょ /社会研究所/
しゃかいげんごがく /社会言語学;social linguistics/
しゃかいげんしょう /社会現象/
しゃかいげんしょうか /社会現象化/
しゃかいこう /社会工/
しゃかいこうがく /社会工学/
しゃかいこうがくるい /社会工学類/
しゃかいこうがっか /社会工学科/
しゃかいこうけん /社会貢献/
しゃかいこうぞう /社会構造/
しゃかいこうどう /社会行動/
しゃかいさんか /社会参加/
しゃかいし /社会史/
しゃかいしそうしゃ /社会思想社/
しゃかいしほん /社会資本/
しゃかいしみん /社会市民/
しゃかいしゅうだん /社会集団/
しゃかいしゅぎ /社会主義/
しゃかいしゅぎかくめい /社会主義革命/
しゃかいしゅぎけいざい /社会主義経済;socialist economy/
しゃかいしゅぎしゃ /社会主義者;socialist/
しゃかいしゅぎてき /社会主義的/
しゃかいしんしゅつ /社会進出/
しゃかいしんり /社会心理/
しゃかいしんりがく /社会心理学/
しゃかいしんりがくてき /社会心理学的/
しゃかいじぎょう /社会事業/
しゃかいじたい /社会自体/
しゃかいじょう /社会上/
しゃかいじょうきょう /社会状況/
しゃかいじょうしき /社会常識/
しゃかいじょうせい /社会情勢/
しゃかいじん /社会人/
しゃかいじんいんせい /社会人院生/
しゃかいじんきょういく /社会人教育/
しゃかいじんたいかい /社会人大会/
しゃかいじんちゅうしん /社会人中心/
しゃかいじんにゅうがく /社会人入学/
しゃかいじんにゅうし /社会人入試/
しゃかいじんやきゅう /社会人野球/
しゃかいじんよう /社会人用/
しゃかいじんよびぐん /社会人予備軍/
しゃかいじんるいがく /社会人類学;social anthropology/
しゃかいせい /社会性/
しゃかいせいかつ /社会生活/
しゃかいせいかつてき /社会生活的/
しゃかいせいぎ /社会正義/
しゃかいせいさく /社会政策;social policy/
しゃかいせいど /社会制度/
しゃかいせいぶつがく /社会生物学/
しゃかいぜんたい /社会全体/
しゃかいぜんぱん /社会全般/
しゃかいそしき /社会組織/
しゃかいぞう /社会増/
しゃかいたいせい /社会体制/
しゃかいちつじょ /社会秩序/
しゃかいつうねん /社会通念/
しゃかいつうねんじょう /社会通念上/
しゃかいてき /社会的/
しゃかいてきいしき /社会的意識/
しゃかいてきいみ /社会的意味/
しゃかいてきえいきょう /社会的影響/
しゃかいてきおう /社会適応/
しゃかいてきおうせい /社会適応性/
しゃかいてきかんきょう /社会的環境/
しゃかいてきかんしゅう /社会的慣習/
しゃかいてききせい /社会的規制/
しゃかいてきこうせい /社会的公正/社会的構成/
しゃかいてきこうせいかんすう /社会的厚生関数/
しゃかいてきこうどう /社会的行動/
しゃかいてきごうい /社会的合意/
しゃかいてきしえん /社会的支援/
しゃかいてきしめい /社会的使命/
しゃかいてきしんよう /社会的信用/
しゃかいてきじゃくしゃ /社会的弱者/
しゃかいてきじょうきょう /社会的状況/
しゃかいてきじょうしき /社会的常識/
しゃかいてきせいさい /社会的制裁/
しゃかいてきせいやく /社会的制約/
しゃかいてきせきにん /社会的責任/
しゃかいてきそくめん /社会的側面/
しゃかいてきそんざい /社会的存在;social being/
しゃかいてきそんしつ /社会的損失/
しゃかいてきたちば /社会的立場/
しゃかいてきちい /社会的地位/
しゃかいてきつうねん /社会的通念/
しゃかいてきにゅういん /社会的入院;[時事]行き場のない老人などを入院させておくこと/
しゃかいてきひはん /社会的批判/
しゃかいてきひょうか /社会的評価/
しゃかいてきぶんみゃく /社会的文脈/
しゃかいてきみぶん /社会的身分/
しゃかいてきもんだい /社会的問題/
しゃかいてきよういん /社会的要因/
しゃかいてきようそ /社会的要素/
しゃかいてきりえき /社会的利益/
しゃかいてきわだい /社会的話題/
しゃかいとう /社会党/
しゃかいとうけい /社会統計;social statistics/
しゃかいとうさは /社会党左派/
しゃかいとうせい /社会統制/
しゃかいとうた /社会淘汰;⇔自然淘汰/
しゃかいとうたいかい /社会党大会/
しゃかいどうとく /社会道徳/
しゃかいなべ /社会鍋;募金活動/
しゃかいにんしき /社会認識/
しゃかいは /社会派/
しゃかいはいけい /社会背景/
しゃかいはさくひん /社会派作品/
しゃかいひはん /社会批判/
しゃかいびょうりがく /社会病理学;social pathology/
しゃかいふあん /社会不安/
しゃかいふうちょう /社会風潮/
しゃかいふくし /社会福祉/
しゃかいふくしきょうぎかい /社会福祉協議会/
しゃかいふくしし /社会福祉士/
しゃかいふくししせつ /社会福祉施設;social welfare facilities/
しゃかいふくししゅじ /社会福祉主事/
しゃかいふくしじぎょうほう /社会福祉事業法/
しゃかいふくしほうじん /社会福祉法人/
しゃかいふっき /社会復帰/
しゃかいふてきおうしゃ /社会不適応者/
しゃかいぶ /社会部/
しゃかいへんか /社会変化/
しゃかいへんかく /社会変革/
しゃかいへんどう /社会変動/
しゃかいほう /社会法/
しゃかいほうげん /社会方言;[言語]sociolect. 社会階層特有の用語・用法など。⇔地域方言/
しゃかいほうし /社会奉仕/
しゃかいほけん /社会保険/
しゃかいほけんちょう /社会保険庁;www.sia.go.jp/
しゃかいほけんりょう /社会保険料/
しゃかいほけんろうむし /社会保険労務士/
しゃかいほしょう /社会保障/
しゃかいほしょうせいど /社会保障制度/
しゃかいみんしゅしゅぎ /社会民主主義/
しゃかいみんしゅとう /社会民主党/
しゃかいめん /社会面/
しゃかいもんだい /社会問題/
しゃかいもんだいか /社会問題化/
しゃかいりろん /社会理論/
しゃかいりんり /社会倫理/
しゃかく /車格/射角/社格;会社のgrade/斜格/
しゃかくきん /斜角筋/
しゃかさま /釈迦様/
しゃかさんぞん /釈迦三尊/
しゃかっこう /斜滑降/
しゃかどう /釈迦堂/
しゃかにょらい /釈迦如来/
しゃかむに /釈迦牟尼/
しゃかん /車間/舎監/
しゃかんきょり /車間距離/
しゃが /車駕/
しゃがい /社外/車外/舎飼い;⇔放し飼い/
しゃがいかんさやく /社外監査役/
しゃがいとりしまりやく /社外取締役/
しゃがいひ /社外秘/
しゃがいひん /社外品/
しゃがいべんきょうかい /社外勉強会/
しゃがく /写楽/
しゃがれごえ /嗄れ声/
しゃがん /斜眼/赭顔/
しゃがんたい /遮眼帯/
しゃき /社旗/社規/
しゃきしゃきかん /シャキシャキ感/
しゃきゅう /社給/
しゃきゅうひん /社給品/
しゃきょう /写経/
しゃきょり /射距離/
しゃきん /謝金/
しゃぎ /謝儀/
しゃぎぬ /紗衣/
しゃぎょう /社業/
しゃく /尺/酌;お-/笏/癪;-に障る/勺;1／10合/杓;杓子/灼;灼熱/妁;媒妁(=媒酌)/芍;芍薬/爵;公爵/嚼;咀嚼/釈;解釈/釋;「釈」の旧字/斫;(きる)/皙;(呉音) 白皙(はくせき)/蜥;蜥蜴/爍;(とかす)/鑠;矍鑠/昔;(呉音)今昔/借;借財/錫;すず/綽;余裕綽々/石;(呉音)磐石/赤;(呉音)赤口/蹟;(呉音) 奇蹟/炸;(呉音) 炸裂/
しゃくい /爵位/
しゃくぎ /釈義/
しゃくざい /借財/
しゃくし /杓子/釈子;釈迦の弟子/
しゃくしじょうぎ /杓子定規/
しゃくしな /杓子菜/
しゃくしゃく /綽々;余裕-/灼々/綽綽/灼灼/
しゃくしょ /借書/
しゃくじ /借字/
しゃくじい /石神井/
しゃくじいこうえん /石神井公園/
しゃくじいだい /石神井台/
しゃくじょう /錫杖/
しゃくすん /尺寸/
しゃくせん /借銭/
しゃくぜん /釈然/灼然/
しゃくそん /釈尊/
しゃくだま /尺玉/
しゃくち /借地/尺地/
しゃくちけん /借地権/
しゃくちしゃくやほう /借地借家法/
しゃくちしゃっかほう /借地借家法/
しゃくちにん /借地人/
しゃくちほう /借地法/
しゃくちょうくう /釈迢空;歌人・詩人。本名折口信夫/
しゃくちりょう /借地料/
しゃくちん /借賃/
しゃくとりむし /尺取虫/尺蠖/
しゃくど /尺度/赤土/
しゃくどう /赤銅/
しゃくどういろ /赤銅色/
しゃくどち /尺度値/
しゃくどほう /尺度法/
しゃくなが /尺長/
しゃくなげ /石楠花/石南花/
しゃくにゅう /借入/
しゃくにゅうきん /借入金/
しゃくねつ /灼熱/
しゃくねつじごく /灼熱地獄/
しゃくのたね /癪の種/
しゃくはち /尺八/
しゃくびょうし /笏拍子/
しゃくふ /酌婦/
しゃくぶく /折伏/
しゃくほう /釈放/
しゃくま /借間/
しゃくめい /釈明/綽名;あだな/
しゃくもん /借問/
しゃくや /借家/
しゃくやく /芍薬/
しゃくやにん /借家人/
しゃくよう /借用/
しゃくようご /借用語/
しゃくようしょ /借用書/
しゃくようしょうしょ /借用証書/
しゃくようねがい /借用願/
しゃくらん /借覧/
しゃくりょう /借料/酌量/
しゃくりょうげんけい /酌量減軽/
しゃくん /社訓/
しゃぐま /赤熊/赭熊/
しゃけ /鮭/社家/
しゃけい /斜頸;[医]torticollis/斜頚;異体字/斜傾/舎兄/
しゃけいよう /写経用/
しゃけつ /瀉血/
しゃけん /車検/車券;競馬でいう馬券の競輪版。勝者投票券/写研/
しゃけんぎれ /車検切/
しゃけんしょう /車検証/
しゃけんしょうきさい /車検証記載/
しゃけんじ /車検時/
しゃけんじょう /車検場/
しゃけんせいど /車検制度/
しゃけんせいび /車検整備/
しゃけんたいおう /車検対応/
しゃけんたいおうひん /車検対応品/
しゃけんだい /車検代/
しゃけんだいこう /車検代行/
しゃけんどり /車検取り/
しゃけんひよう /車検費用/
しゃけんまえ /車検前/
しゃげき /射撃/
しゃげきかん /射撃艦/
しゃげきじょう /射撃場/
しゃこ /車庫/蝦蛄;(甲殻類)/鷓鴣;[鳥]/
しゃこう /社交/車高/遮光/斜行;†「馬が-する」/射倖;=射幸/射幸;-心,-性/斜交;†oblique.「-する2直線」/
しゃこうか /社交家/
しゃこうかい /社交界/
しゃこうけいやく /射倖契約/
しゃこうさいばい /遮光栽培/
しゃこうざひょう /斜交座標/
しゃこうし /斜行枝/
しゃこうしん /射幸心/射倖心;=射幸心/
しゃこうじれい /社交辞令/
しゃこうせい /社交性/遮光性/
しゃこうだんす /社交ダンス/
しゃこうちょうせい /車高調整/
しゃこうてき /社交的/
しゃこうばん /遮光板/
しゃこうへんか /車高変化/
しゃこく /社告/
しゃこしょうめい /車庫証明/
しゃこしょうめいしんせい /車庫証明申請/
しゃこたん /積丹/
しゃこたんはんとう /積丹半島/
しゃこだい /車庫代/
しゃこつき /車庫付き/
しゃこない /車庫内/
しゃこほう /車庫法/
しゃさい /車載/社債/
しゃさいかのう /車載可能/
しゃさいき /車載機/
しゃさいけん /社債券/
しゃさいこうぐ /車載工具/
しゃさいしき /車載式/
しゃさいよう /車載用/
しゃさつ /射殺/
しゃさん /社参/
しゃざい /謝罪/斜材/
しゃざいこうこく /謝罪広告/
しゃざいぶん /謝罪文/
しゃざいようきゅう /謝罪要求/
しゃし /社史/斜視/奢侈/奢恣;ほしいままの贅沢/奢肆;=奢恣/
しゃしぜい /奢侈税;luxury tax/
しゃしつ /車室/
しゃしつない /車室内/
しゃしゃく /車借/
しゃしゃらくらく /洒々落々/洒洒落落/
しゃしゅ /車種/射手/社主/叉手/
しゃしゅきせい /車種規制/
しゃしゅごと /車種毎/
しゃしゅしてい /車種指定/
しゃしゅせんたく /車種選択/
しゃしゅせんてい /車種選定/
しゃしゅつ /射出/
しゃしゅつご /射出後/
しゃしゅつせいけい /射出成型/
しゃしゅつせいけいき /射出成型機/
しゃしゅべつ /車種別/
しゃしょ /赦書/
しゃしょう /車掌/捨象/社章/蔗漿;砂糖水/
しゃしょうく /車掌区/
しゃしょうしつ /車掌室/
しゃしょうしゃ /車掌車/
しゃしょうちょう /車掌長/
しゃしょうべん /車掌弁/
しゃしょく /写植/社食/赭色/社稷/
しゃしょくき /写植機/
しゃしょくもじ /写植文字/
しゃしょくや /写植屋/
しゃしょゆう /社所有/
しゃしん /写真/捨身/
しゃしんいり /写真入り/写真入/
しゃしんいんさつ /写真印刷/
しゃしんうつり /写真写り/
しゃしんか /写真家/
しゃしんかん /写真館/
しゃしんがかり /写真係/
しゃしんき /写真機/
しゃしんこうぎょう /写真工業/
しゃしんさつえい /写真撮影/
しゃしんさつえいかい /写真撮影会/
しゃしんざっし /写真雑誌/
しゃしんし /写真誌/
しゃしんしゅう /写真集/
しゃしんしゅうかんし /写真週刊誌/
しゃしんしょくじ /写真植字;[印刷]filmsetting/
しゃしんしょり /写真処理/
しゃしんじゅく /写真塾/
しゃしんじゅつ /写真術/
しゃしんだい /写真代/
しゃしんちょう /写真帖/写真帳/
しゃしんてん /写真展;photo exhibition/写真店;photo studio/
しゃしんてんぷ /写真添付/
しゃしんは /写真派/
しゃしんはんてい /写真判定/
しゃしんばん /写真版/
しゃしんひょうげん /写真表現/
しゃしんびじゅつかん /写真美術館/
しゃしんぶ /写真部/
しゃしんや /写真屋/
しゃしんよう /写真用/
しゃしんようひん /写真用品/
しゃじ /謝辞/社寺/斜字;italic/写字;-生/
しゃじく /車軸/
しゃじくがわ /車軸側/
しゃじくも /車軸藻/
しゃじけんちく /社寺建築/
しゃじせい /写字生/
しゃじたい /斜字体/
しゃじつ /写実/社日/
しゃじつしゅぎ /写実主義/
しゃじつしゅぎてき /写実主義的/
しゃじつてき /写実的/
しゃじゅう /車重/
しゃじゅつ /射術/
しゃじょう /車上/射場/謝状;感謝状/赦状;赦免状/
しゃじょうあらし /車上荒らし/
しゃじん /舎人/
しゃせい /射精/写生/社製/
しゃせいが /写生画/
しゃせいご /写声語/
しゃせいたいかい /写生大会/
しゃせいぶん /写生文/
しゃせきしゅう /沙石集/
しゃせつ /社説/
しゃせん /車線/斜線/社線/
しゃせんかん /車線間/
しゃせんがわ /車線側/
しゃせんきせい /車線規制/
しゃせんごと /車線毎/
しゃせんすう /車線数/
しゃせんせいげん /斜線制限;[建築](建築基準法) 道路-,隣地-,北側-/
しゃせんない /車線内/
しゃせんへんこう /車線変更/
しゃせんへんこうじ /車線変更時/
しゃぜ /社是/
しゃぜつ /謝絶/
しゃぜん /社前/
しゃそう /車窓/社葬/斜走/
しゃそく /車速/社則/社足;?/
しゃぞう /写像/
しゃたい /車体/斜体/
しゃたいがわ /車体側/
しゃたいけいじょう /車体形状/
しゃたいこうしん /車体更新/
しゃたいこうぞう /車体構造/
しゃたいこうぶ /車体後部/
しゃたいしょく /車体色/
しゃたいせいのう /車体性能/
しゃたいちょう /車体長/
しゃたいはば /車体幅/
しゃたいばんごう /車体番号/
しゃたいへき /車体壁/
しゃたく /社宅/
しゃたくせいど /社宅制度/
しゃたんぶ /車端部/
しゃだい /社台/車台/
しゃだつ /洒脱/
しゃだん /遮断/社団/しゃ断/射断/
しゃだんき /遮断機;踏切の-/遮断器;配電盤の-/
しゃだんぶつ /遮断物/
しゃだんほうじん /社団法人/
しゃだんぼう /遮断棒/
しゃち /鯱/
しゃちがわら /鯱瓦;しゃちほこがわら/
しゃちく /社畜/洒竹/
しゃちほこ /鯱/鯱鉾/
しゃちほこがわら /鯱瓦/
しゃちゅう /車中/社中/
しゃちゅうはく /車中泊/
しゃちょう /社長/車長/
しゃちょうこじん /社長個人/
しゃちょうしつ /社長室/
しゃちょうしゅうにん /社長就任/
しゃちょうじにん /社長辞任/
しゃちょうせき /斜長石;plagioclase/
しゃっか /借家/
しゃっかく /尺蠖;尺取虫/
しゃっかにん /借家人/
しゃっかほう /借家法;1991に借地借家法に統合/
しゃっかん /借款/
しゃっかんさい /借換債/
しゃっかんほう /尺貫法;尺、升、貫の単位を使用するわが国古来の度量衡法/
しゃっきょう /石橋/釈教;仏教/
しゃっきょうか /釈教歌/
しゃっきん /借金/
しゃっきんおとこ /借金男/
しゃっきんく /借金苦/
しゃっきんせいかつ /借金生活/
しゃっきんとり /借金取り/
しゃっきんへんさい /借金返済/
しゃっく /赤口;=しゃっこう/
しゃっくり /吃逆/
しゃっけい /借景/
しゃっこう /赤口;[六輝]/赤光/笏康/灼光/
しゃっこつ /尺骨/
しゃてい /射程/舎弟/
しゃていがい /射程外/
しゃていきょり /射程距離/
しゃていけんない /射程圏内/
しゃていない /射程内/
しゃてき /射的/
しゃでん /社殿/
しゃとう /斜塔/社頭/車頭/
しゃど /斜度/赭土/
しゃどう /車道/
しゃな /紗那/
しゃない /社内/車内/
しゃないかいさつ /車内改札/
しゃないがい /社内外/
しゃないきそく /社内規則/
しゃないきてい /社内規定/
しゃないきんえん /社内禁煙/
しゃないけんがく /車内見学/
しゃないけんさつ /車内検札/
しゃないけんしゅう /社内研修/
しゃないこうぼせい /社内公募制/
しゃないし /社内誌/
しゃないしゃしん /車内写真/
しゃないじじょう /社内事情/
しゃないせいさん /車内精算/
しゃないせいど /社内制度/
しゃないせつび /車内設備/
しゃないせんよう /社内専用/
しゃないぜんたい /社内全体/
しゃないてき /社内的/
しゃないでんわちょう /社内電話帳/
しゃないとう /車内灯/
しゃないはんばい /車内販売/社内販売/
しゃないひょうじゅん /社内標準/
しゃないびん /社内便/
しゃないふりん /社内不倫/
しゃないぶんしょ /社内文書/
しゃないほう /社内報/
しゃないほうそう /車内放送/
しゃないほじゅうけん /車内補充券/
しゃないむけ /社内向/
しゃないりょこう /社内旅行/
しゃないりよう /社内利用/
しゃないれんあい /社内恋愛/
しゃないわりびき /社内割引/
しゃにくさい /謝肉祭/
しゃにち /社日/
しゃにむに /遮二無二/
しゃにゅう /西入/
しゃねつ /遮熱/
しゃはば /車幅/
しゃはばとう /車幅灯/
しゃはん /這般/車販/社販/
しゃば /娑婆/車馬/
しゃばくじょう /射爆場/
しゃばん /車番/社判/
しゃひ /社費/舎費/
しゃび /奢靡/
しゃふ /車夫/写譜/
しゃふう /社風/
しゃふく /車幅/
しゃふくとう /車幅灯/
しゃふつ /煮沸/
しゃふつき /煮沸器/
しゃぶんれつ /斜分裂/
しゃへい /遮蔽/遮へい/
しゃへいざい /遮蔽材/
しゃへいじっけん /遮蔽実験/
しゃへいせっけい /遮蔽設計/
しゃへいたい /遮蔽体/
しゃへいばん /遮蔽板/
しゃへいぶつ /遮蔽物/
しゃへん /斜辺/
しゃべつ /差別/
しゃべり /喋り/
しゃほ /社保/
しゃほう /斜方/車砲/
しゃほうけい /斜方形;=菱形/
しゃほうしょうけい /斜方晶系;[化学]orthorhombic system/
しゃほたん /社保短/
しゃほん /写本/
しゃぼんだま /シャボン玉/しゃぼん玉/
しゃまく /紗幕/
しゃみ /沙弥/三味/
しゃみせん /三味線/
しゃみせんかい /三味線界/
しゃみせんや /三味線屋/
しゃみんとう /社民党/
しゃみんれん /社民連/
しゃむ /社務/暹羅/
しゃむしょ /社務所/
しゃむねこ /シャム猫/
しゃめい /社名/車名/社命;会社の命令/
しゃめいへんこう /社名変更/
しゃめん /斜面/赦免/
しゃめんじょう /斜面上/赦免状/
しゃめんへんか /斜面変化/
しゃも /軍鶏/
しゃもじ /杓文字/
しゃもん /沙門/借問/
しゃもんおり /斜文織/
しゃゆう /社有/社友/
しゃゆうち /社有地/
しゃよう /社用/斜陽/
しゃようか /斜陽化/
しゃようしゃ /社用車/
しゃようぞく /社用族/斜陽族/
しゃらく /写楽/洒落;easy-going/酒楽;?/
しゃらじゅ /娑羅樹/
しゃらそうじゅ /娑羅双樹/
しゃり /舎利/斜里;地名/射利/
しゃりえき /斜里駅/
しゃりき /車力/
しゃりでん /舎利殿/
しゃりとう /舎利塔/
しゃりほつ /舎利弗/
しゃりょう /車両/車輌;「輛」の異体字/車輛;本来の用字/社領/
しゃりょういがい /車両以外/
しゃりょううんぱんぐ /車両運搬具/
しゃりょううんよう /車両運用/
しゃりょうかかく /車両価格/
しゃりょうかさい /車両火災/
しゃりょうかん /車両間/
しゃりょうかんかく /車両感覚/
しゃりょうがいしゃ /車両会社/
しゃりょうがわ /車両側/
しゃりょうきち /車両基地/
しゃりょうきてい /車両規定/
しゃりょうく /車両区/
しゃりょうぐち /車両口/
しゃりょうけい /車両系/
しゃりょうけいしき /車両形式/
しゃりょうげんかい /車両限界/
しゃりょうこうかん /車両交換/
しゃりょうこうさく /車両工作/
しゃりょうこうにゅう /車両購入/
しゃりょうこしょう /車両故障/
しゃりょうじゅうりょう /車両重量/
しゃりょうすう /車両数/
しゃりょうせいのう /車両性能/
しゃりょうぜんたい /車両全体/
しゃりょうぜんぶ /車両全部/
しゃりょうだい /車両代/
しゃりょうちゅうしん /車両中心/
しゃりょうてんけん /車両点検/
しゃりょうとうろく /車両登録/
しゃりょうない /車両内/
しゃりょうないぶ /車両内部/
しゃりょうはいちひょう /車両配置表/
しゃりょうはば /車両幅/
しゃりょうばんごう /車両番号/
しゃりょうばんごうひょう /車両番号標/
しゃりょうぶそく /車両不足/
しゃりょうほう /車両法/
しゃりょうほけん /車両保険/
しゃりょうほんたい /車輌本体/
しゃりょうれいぼう /車両冷房/
しゃりん /車輪/
しゃりんおん /車輪音/
しゃりんせき /車輪石/
しゃりんせんばん /車輪旋盤/
しゃりんのした /車輪の下;Unterm Rad,Hesse,1906/
しゃれ /洒落/
しゃれい /謝礼/車齢/
しゃれき /社歴/車歴/
しゃれきじょう /車歴上/
しゃれこうべ /髑髏/
しゃれっけ /洒落っ気/
しゃれつ /車列/斜列/
しゃれぼん /洒落本/
しゃれもの /洒落者/
しゃわーしつ /シャワー室/
しゃんそんかしゅ /シャンソン歌手/
しゃんたん /上湯/
しゃんつぁい /香菜;xiang cai/
しゃんはい /上海/
しゃんはいかぶ /上海株/
しゃんはいがに /上海蟹/
しゃんはいこうつうだいがく /上海交通大学/
しゃんはいご /上海語/
しゃんはいじへん /上海事変/上海事變;旧字/
しゃんはいとっきゅう /上海特急/
しゃんはいりょうり /上海料理/
しゃんぱん /三鞭酒/
しゃんぷーだい /シャンプー台/
しや /視野/子夜;AM0/
しやかく /視野角/
しやきょうさく /視野狭窄/
しやく /試薬/試訳/
しやくかんり /試薬管理/
しやくしょ /市役所/
しやくしょまえ /市役所前/
しやくよう /試薬用/
しやけ /初宿/
しやしょうがい /視野障害/
しやぜんたい /視野全体/
しやりつ /視野率/
しゅ /主/種/朱/手/首/酒/腫;腫瘍/踵;きびす/守/狩;狩猟/取/趣;趣味/娵;よめ/娶;めと・る/諏;諏訪/株;守株/殊;特殊/珠;胚珠/侏;侏儒/洙;洙水(山東省の川)/蛛;蜘蛛/銖;錙銖/修;修行/衆;衆生/須;須臾/棕;棕櫚/椶;「棕」の異体字/殳;(ほこづくり)/繻;繻子/鬚;(ひげ)鬚髯/麈;おおじか/撞;種目/
しゅ> /主/
しゅーぱい /数牌/
しゅーまい /焼売/
しゅい /首位/趣意/主意/主位;⇔客位/種衣/
しゅいあらそい /首位争い/
しゅいかんらく /首位陥落/
しゅいがため /首位固め/
しゅいけっせん /首位決戦/
しゅいこうぼう /首位攻防/
しゅいこうぼうせん /首位攻防戦/
しゅいしゅぎ /主意主義/
しゅいしょ /趣意書/主意書/
しゅいだしゃ /首位打者/
しゅいだっかい /首位奪回/
しゅいち /主一/
しゅいどくそう /首位独走/
しゅいろ /朱色/
しゅいん /主因/朱印/手淫/手印/
しゅいんじょう /朱印状/
しゅいんせん /朱印船/
しゅう /州/集/週/臭/終/周/宗/囚/衆;皆の衆/聚;聚合/驟;驟雨/収;収集/收;「収」の旧字(人名用漢字)/修;修理/脩;束脩/蓚;蓚酸/袖;(そで)鎧袖/岫;(いわあな)/就;就学/蹴;一蹴/鷲;わし/秀;優秀/綉/銹;さび/洲;す/酬;報酬/駲;「馴」の異体字/輯;編輯/楫;かじ/緝;つむぐ/葺;ふ・く/讐;復讐/讎;「讐」の異体字/售;うる/蒐;蒐集/醜;美醜/習;練習/慴;おそれる/褶;褶曲/摺;す・る/酋;酋長/遒/逎;「遒」の異体字/楢;なら/秋;秋季/穐;「秋」の異体字/愁;憂愁/萩;はぎ/啾;鬼哭啾啾/愀/楸;ひさぎ/湫;(くて)/甃;(石畳)/鞦;鞦韆/鰍;かじか/鍬;くわ/泅;(およぐ)/螽;螽斯(しゅうし,きりぎりす)/祝;祝儀/拾;拾得/襲;襲撃/舟;孤舟/執;執着/羞;羞恥/繍;刺繍/溲;溲瓶(しびん)/慫;しょう?/蹤;しょう?/嗅;きゅう?/朱;しゅ?/踵;しゅ?/
しゅう> /州;-境,-議会,-警察/週;週２回,週三回,週明け/終/
しゅうあく /醜悪/
しゅうあけ /週明け/
しゅうあし /週足;[相場]「-チャート」/
しゅうい /周囲/拾遺/就位/秋意/衆意/周位;?/
しゅういかんきょう /周囲環境/
しゅういしゅう /拾遺集/
しゅういち /週一;once a week/修一;人名/秀一/周一/
しゅういちにち /週一日/
しゅういちょう /周囲長/
しゅういちろう /修一郎/周一郎/
しゅういっかい /週一回/
しゅういつ /秀逸/
しゅういん /衆院/執印/秋陰/
しゅういんぎいん /衆院議員/
しゅういんせん /衆院選/
しゅうう /秋雨;あきさめ/驟雨;にわか雨/
しゅううん /舟運/
しゅうえい /秀英/
しゅうえいしゃ /集英社;[出版社名]www.shueisha.co.jp/
しゅうえいしゃぶんこ /集英社文庫/
しゅうえき /収益/就役/周易/
しゅうえききん /収益金/
しゅうえきこうぞう /収益構造/
しゅうえきざいさん /収益財産/
しゅうえきせい /収益性/
しゅうえきりつ /収益率/
しゅうえきりょく /収益力/
しゅうえつ /収悦/
しゅうえん /終焉;the end/終演;end of a show/就園/周縁/終宴;end of a party/秀演/終鴛;?/
しゅうえんがた /周縁型/
しゅうえんご /終演後/
しゅうえんじ /終演時/
しゅうえんそうち /集煙装置/
しゅうえんぶ /周縁部/
しゅうお /羞悪/
しゅうおもい /主思い/
しゅうおん /集音/収音/
しゅうおんらい /周恩来/
しゅうか /集荷/臭化;[化学]「-エチル,-銀」/秀歌/集貨/衆寡;-敵せず/衆化;?/
しゅうかい /集会/周回/集塊/醜怪/聚会/聚會;「会」旧字/
しゅうかいおくれ /周回遅れ/
しゅうかいきどう /周回軌道/
しゅうかいしつ /集会室/
しゅうかいじょ /集会所/
しゅうかいすう /周回数/
しゅうかいせきぶん /周回積分/
しゅうかいどう /秋海棠/
しゅうかいどうろ /周回道路/
しゅうかいめい /集会名/
しゅうかいろ /周回路/
しゅうかぎん /臭化銀;[化学]AgBr/
しゅうかく /収穫;†harvest.「米の-」/臭覚/収獲;†game.「狩の-」/
しゅうかくき /収穫期;harvest season/収穫機;harvester/
しゅうかくさい /収穫祭/
しゅうかくていげん /収穫逓減/
しゅうかくぶつ /収穫物/
しゅうかくまえ /収穫前/
しゅうかくりょう /収穫量/
しゅうかさい /愁華祭/
しゅうかすいそ /臭化水素/
しゅうかつ /就活/
しゅうかぶつ /臭化物/
しゅうかへいげつ /羞花閉月/
しゅうかん /習慣/週間;†(of the) week.「愛鳥-」/週刊;†weekly.「-誌」/収監/終刊;刊行終了/終巻;最後の巻/秋官/醜漢/
しゅうかん> /週刊/
しゅうかんあさひ /週刊朝日/
しゅうかんいじょう /週間以上/
しゅうかんか /習慣化/週刊化;月刊誌の-/
しゅうかんけいば /週刊競馬/
しゅうかんげんだい /週刊現代/
しゅうかんご /週間後/
しゅうかんごう /終刊号/
しゅうかんごと /週間毎/
しゅうかんざっし /週刊雑誌/
しゅうかんし /週刊誌/週刊紙;weekly newspaper/
しゅうかんしょうねん /週刊少年;(雑誌名の一部?)/週間少年;?/
しゅうかんせい /習慣性/
しゅうかんづけ /習慣付け/
しゅうかんてき /習慣的/
しゅうかんてんきよほう /週間天気予報/
しゅうかんぶんしゅん /週刊文春/
しゅうかんほうせき /週刊宝石/
しゅうかんまえ /週間前/
しゅうかんれんさい /週刊連載/
しゅうがく /就学/修学;-旅行/宗学;宗派の学問/
しゅうがくいん /修学院/
しゅうがくさき /就学先/
しゅうがくしょう /終楽章/
しゅうがくせい /就学生;大学以外の教育機関に学ぶ外国人/
しゅうがくまえ /就学前/
しゅうがくりつ /就学率/
しゅうがくりょこう /修学旅行/
しゅうがくりょこういがい /修学旅行以外/
しゅうがくりょこうせい /修学旅行生/
しゅうがくりょこうよう /修学旅行用/
しゅうがくりょこうれっしゃ /修学旅行列車/
しゅうがわり /週替わり/
しゅうき /周期/秋季;†/臭気/秋期;†/終期/周忌/秋気;秋の気配/宗規/終帰/
しゅうきうんどう /周期運動/
しゅうきおん /周期音/
しゅうきかい /周期解/
しゅうきかんすう /周期関数/
しゅうききょうかいじょうけん /周期境界条件/
しゅうきこうぞう /周期構造/
しゅうきこうれいさい /秋季皇霊祭;現・秋分の日/
しゅうきじ /集記事/
しゅうきすいせい /周期彗星;[天文]periodic comet/
しゅうきせい /周期性/
しゅうきせつ /周期説/
しゅうきたいかい /秋季大会/
しゅうきてき /周期的/
しゅうきてん /周期点/
しゅうきはけい /周期波形/
しゅうきひょう /周期表/
しゅうきへんどう /周期変動/
しゅうきほう /集気法/
しゅうきゃく /集客/
しゅうきゃくこうか /集客効果/
しゅうきゃくもくてき /集客目的/
しゅうきゃくりょく /集客力/
しゅうきゅう /週休;-二日/蹴球;football/週給;weekly pay/秋宮/
しゅうきゅうふつか /週休二日/
しゅうきょう /宗教/州境;state line/秋興/
しゅうきょういっぱん /宗教一般/
しゅうきょうおんがく /宗教音楽/
しゅうきょうか /宗教家/
しゅうきょうかいかく /宗教改革/
しゅうきょうかん /宗教観/
しゅうきょうが /宗教画/
しゅうきょうがく /宗教学/
しゅうきょうがくしゃ /宗教学者/
しゅうきょうがっか /宗教学科/
しゅうきょうきょういく /宗教教育/
しゅうきょうきょく /宗教曲/
しゅうきょうげき /宗教劇/
しゅうきょうげんしょう /宗教現象/
しゅうきょうさいばん /宗教裁判/
しゅうきょうさいばんかん /宗教裁判官/
しゅうきょうし /宗教史/
しゅうきょうしゃかいがく /宗教社会学/
しゅうきょうしょく /宗教色/
しゅうきょうしん /宗教心/
しゅうきょうしんりがく /宗教心理学;religious psychology/
しゅうきょうじょう /宗教上/
しゅうきょうせい /宗教性/
しゅうきょうせんそう /宗教戦争/
しゅうきょうだんあつ /宗教弾圧/
しゅうきょうだんたい /宗教団体/
しゅうきょうだんたいほう /宗教団体法/
しゅうきょうてき /宗教的/
しゅうきょうてきけんい /宗教的権威/
しゅうきょうてつがく /宗教哲学;philosophy of religion/
しゅうきょうほうじん /宗教法人/
しゅうきょうもんだい /宗教問題/
しゅうきょうろん /宗教論/
しゅうきょうろんそう /宗教論争/
しゅうきょく /終局/終曲/褶曲/終極/周極;-星/
しゅうきょくいき /周極域/
しゅうきょくさんみゃく /褶曲山脈/
しゅうきょくせい /周極星;[天文]circumpolar star/
しゅうきょくりゅう /周極流/
しゅうきりつ /周期律/
しゅうきりつひょう /周期律表/
しゅうきん /集金/
しゅうきんにん /集金人/
しゅうきんぶくろ /集金袋/
しゅうぎ /祝儀/衆議/宗義/
しゅうぎいん /衆議院/
しゅうぎいんかいさん /衆議院解散/
しゅうぎいんぎいん /衆議院議員/
しゅうぎいんせんきょ /衆議院選挙/
しゅうぎいんほうせいきょく /衆議院法制局/
しゅうぎかい /州議会/
しゅうぎく /秋菊/
しゅうぎぶくろ /祝儀袋/
しゅうぎょう /就業;†work.「-人口」/修業;†study.「-年限」/終業/
しゅうぎょうきそく /就業規則/
しゅうぎょうしき /終業式/
しゅうぎょうしゃ /就業者/
しゅうぎょうじかん /就業時間/終業時間/
しゅうぎょうじかんちゅう /就業時間中/
しゅうぎょうじんこう /就業人口/
しゅうぎょうせいげん /就業制限/
しゅうぎょうちゅう /就業中/修業中/
しゅうぎょうにっすう /就業日数/
しゅうぎょうひょう /就業票/
しゅうぎょうりつ /就業率/
しゅうぎょこうか /集魚効果/
しゅうぎわしょ /集義和書/
しゅうぎん /秀吟/
しゅうく /秀句/
しゅうぐ /衆愚/
しゅうぐせいじ /衆愚政治/
しゅうぐん /州軍/
しゅうけい /集計/修景/
しゅうけいかいし /集計開始/
しゅうけいがかり /集計係/
しゅうけいきかん /集計期間/
しゅうけいけっか /集計結果/
しゅうけいけっかはっぴょう /集計結果発表/
しゅうけいさぎょう /集計作業/
しゅうけいしゃ /集計者/
しゅうけいじ /集計時/
しゅうけいじょう /集計上/
しゅうけいじょうきょう /集計状況/
しゅうけいたんとう /集計担当/
しゅうけいちゅう /集計中/
しゅうけいはっぴょう /集計発表/
しゅうけいほうほう /集計方法/
しゅうけいよう /集計用/
しゅうけつ /集結;gather.「広場に-する」/終結;terminate.「論争の-」/
しゅうけつぶ /終結部/
しゅうけん /集権/舟券;競馬でいう馬券の競艇版/
しゅうけんてき /集圏的/
しゅうげき /襲撃/
しゅうげきしゃ /襲撃者/
しゅうげつ /秋月/
しゅうげん /祝言/
しゅうこ /修子/収子/
しゅうこう /就航;in service/集光/修好/周航;cruise round/周行/舟行/舟航/収公;没収/醜行/衆口/秋向/
しゅうこうきょう /集光鏡/
しゅうこうてん /周口店/
しゅうこうぶ /集光部/
しゅうこうれんず /集光レンズ;condenser (lens)/
しゅうこつ /収骨/
しゅうごう /集合/習合;神仏-/聚合/秋毫;very small/
しゅうごういしき /集合意識/
しゅうごうえんざん /集合演算/
しゅうごうか /集合果/
しゅうごうかた /集合型/
しゅうごうがいねん /集合概念/
しゅうごうがた /集合型/
しゅうごうけい /集合系/
しゅうごうご /集合後/集合語/輯合語/
しゅうごうざい /集合材/
しゅうごうざいさん /集合財産/
しゅうごうしゃしん /集合写真/
しゅうごうじかん /集合時間/
しゅうごうじごく /衆合地獄/
しゅうごうじゅうたく /集合住宅;アパート・マンションなど/
しゅうごうぞく /集合族/
しゅうごうたい /集合体/
しゅうごうていこう /集合抵抗/
しゅうごうてき /集合的/
しゅうごうてきむいしき /集合的無意識/
しゅうごうはん /集合犯/
しゅうごうばしょ /集合場所/
しゅうごうび /集合日/
しゅうごうぶつ /集合物/
しゅうごうへいきん /集合平均/
しゅうごうろん /集合論/
しゅうごろう /周五郎/脩五郎/
しゅうさ /収差/
しゅうさい /収載/秀才/州際/集載;集めて載せる/
しゅうさく /秀作;fine work/習作;study/周作;人名/秀策;人名/
しゅうさず /収差図/
しゅうさつ /集札/
しゅうさん /衆参/集散/蓚酸;(COOH)2/シュウ酸/聚散;≒集散/
しゅうさんかじょ /集散花序/
しゅうさんき /周産期/
しゅうさんしゅぎ /集産主義;collectivism/
しゅうさんち /集散地/
しゅうさんりょういん /衆参両院/
しゅうざい /集材/秋材/
しゅうざかい /州境/
しゅうざん /周山/
しゅうし /収支/修士/終始;†all along.「-無言で」/終止;†stop.「楽曲の-」/宗旨/修史/
しゅうし> /終始/
しゅうしいちねん /修士一年/修士壱年/
しゅうしいっかん /終始一貫/
しゅうしうちわけしょ /収支内訳書/
しゅうしかてい /修士課程/
しゅうしかていじだい /修士課程時代/
しゅうしがえ /宗旨替え/
しゅうしがくいろんぶん /修士学位論文/
しゅうしき /終式/
しゅうしきょく /修史局;現・史料編纂所/
しゅうしけい /終止形/
しゅうしけいさん /収支計算/
しゅうしけっさん /収支決算/
しゅうしごう /修士号/
しゅうししゅうりょう /修士終了/
しゅうしせん /終止線/
しゅうしそつ /修士卒/
しゅうしにねん /修士二年/
しゅうしひょう /収支表/
しゅうしふ /終止符/
しゅうしぼ /収支簿/
しゅうしゃ /終車/
しゅうしゅう /収集;†collect.「ゴミ-」/収拾;†settle.「事態の-」/蒐集;(≒収集。esp.価値あるものを集める) 「切手-」/啾々;弱々しくなくさま/拾集;pickup/啾啾/集輯;gather and edit/集収;?/
しゅうしゅうか /収集家/蒐集家/
しゅうしゅうかんり /収集管理/
しゅうしゅうさぎょう /収集作業/
しゅうしゅうし /収集子/
しゅうしゅうしゃ /収集車/収集者/
しゅうしゅうび /収集日/
しゅうしゅうへき /収集癖/
しゅうしゅうほうほう /収集方法/
しゅうしゅうりつ /集収率/
しゅうしゅく /収縮/
しゅうしゅくりつ /収縮率/
しゅうしゅぼうかん /袖手傍観/
しゅうしょ /集書/衆庶/周書;二十一史/
しゅうしょう /終章/愁傷/就床/修証/周章;-狼狽/秋宵/
しゅうしょうさま /愁傷様/
しゅうしょうろうばい /周章狼狽/
しゅうしょく /就職/修飾/秋色;秋の気配/愁色;sorrowful look/襲職;仕事を継ぐ/
しゅうしょくいわい /就職祝/就職祝い/
しゅうしょくか /就職課/
しゅうしょくかつどう /就職活動/
しゅうしょくかつどうよう /就職活動用/
しゅうしょくかんけい /就職関係/
しゅうしょくぐち /就職口/
しゅうしょくご /修飾語/
しゅうしょくごく /修飾語句/
しゅうしょくさき /就職先/
しゅうしょくさべつ /就職差別/
しゅうしょくざっし /就職雑誌/
しゅうしょくし /修飾子/
しゅうしょくしけん /就職試験/
しゅうしょくしゃ /就職者/
しゅうしょくじ /就職時/
しゅうしょくじょうほう /就職情報/
しゅうしょくじょうほうし /就職情報誌/
しゅうしょくせつめいかい /就職説明会/
しゅうしょくせんせん /就職戦線/
しゅうしょくせんせんいじょう /就職戦線異状/
しゅうしょくそうだん /就職相談/
しゅうしょくなん /就職難/
しゅうしょくぶ /就職部/
しゅうしょくまえ /就職前/
しゅうしょくもんだい /就職問題/
しゅうしょくりつ /就職率/
しゅうしょくろうにん /就職浪人;[新語]/
しゅうしろんぶん /修士論文/
しゅうしん /就寝/終身;for life.「-刑」/修身;moral/執心/終審/集信/
しゅうしんかいいん /終身会員/
しゅうしんかいひ /終身会費/
しゅうしんけい /終身刑/
しゅうしんこよう /終身雇用/
しゅうしんこようせい /終身雇用制/
しゅうしんさいばんしょ /終審裁判所/
しゅうしんじ /就寝時/
しゅうしんじかん /就寝時間/
しゅうしんねんきん /終身年金/
しゅうしんほけん /終身保険/
しゅうしんまえ /就寝前/
しゅうしんよう /就寝用/
しゅうじ /習字/修辞/週次/集字/修二;人名/修司/修治/秀治/周二/秀司/修次/秀次/宗司/
しゅうじがく /修辞学/
しゅうじぎもんぶん /修辞疑問文/
しゅうじつ /終日/週日/秋日/
しゅうじつきんえん /終日禁煙/
しゅうじてき /修辞的/
しゅうじゃく /執着/
しゅうじゅ /収受/
しゅうじゅうろう /宗十郎/
しゅうじゅく /習熟/
しゅうじゅくど /習熟度/
しゅうじょ /醜女/
しゅうじょう /衆生/醜状/
しゅうじょうたい /終状態/
しゅうじょく /就褥/
しゅうじょし /終助詞/
しゅうじん /囚人/集塵/衆人/
しゅうじんかんし /衆人環視/
しゅうじんき /集塵器/
しゅうじんせん /囚人船/
しゅうじんふく /囚人服/
しゅうすい /集水;-器,-溝/秋水/
しゅうすけ /秀介/
しゅうすじ /主筋/
しゅうせい /修正;(amend) 法案の-/集成/習性/修整;(retouch) 写真の-/終生/秋声/修成;修正し完成する/衆生/秋晴/終世;=終生/衆星/宗制/輯成;≒集成/醜声/銹錆/
しゅうせいあん /修正案/
しゅうせいいけん /修正意見/
しゅうせいいち /修正位置/
しゅうせいえき /修正液/
しゅうせいかしょ /修正箇所/修正個所/
しゅうせいかのう /修正可能/
しゅうせいきじ /修正記事/
しゅうせいきぼう /修正希望/
しゅうせいご /修正後/
しゅうせいざい /集成材/
しゅうせいし /修正子/
しゅうせいしほんしゅぎ /修正資本主義;modified capitalism/
しゅうせいしゅぎ /修正主義/
しゅうせいしんこく /修正申告/
しゅうせいじ /修正時/
しゅうせいじこう /修正事項/
しゅうせいじょうこう /修正条項/
しゅうせいじょうほう /修正情報/
しゅうせいずみ /修正済/
しゅうせいぜんご /修正前後/
しゅうせいち /修正値/
しゅうせいちゅう /修正中/
しゅうせいていあん /修正提案/
しゅうせいてん /修正点/
しゅうせいとうこう /修正投稿/
しゅうせいなし /修正無/
しゅうせいばん /修正版/
しゅうせいぶぶん /修正部分/
しゅうせいぶん /修正分/修正文/
しゅうせいへんしゅう /修正編集/
しゅうせいほう /修正法/
しゅうせいまえ /修正前/
しゅうせいよう /修正用/修正要/
しゅうせいりゆう /修正理由/
しゅうせいりょう /修正量/
しゅうせき /集積/就籍/
しゅうせきか /集積化/
しゅうせきかいろ /集積回路/
しゅうせきそう /集積層/
しゅうせきたい /集積体/
しゅうせきち /集積地/
しゅうせきてん /集積点/
しゅうせきど /集積度/
しゅうせん /終戦/周旋/集線/臭腺/鞦韆;ぶらんこ/終戰;「戦」旧字/
しゅうせんきねんび /終戦記念日/
しゅうせんぎょう /周旋業/
しゅうせんご /終戦後/
しゅうせんちょくご /終戦直後/
しゅうせんや /周旋屋/
しゅうぜい /収税/州税/
しゅうぜつ /秀絶/愁絶/
しゅうぜん /修繕/愁然/
しゅうぜんつみたてきん /修繕積立金/
しゅうぜんひ /修繕費/
しゅうそ /臭素/宗祖/愁訴/Br/Bromine/
しゅうそう /秋霜/終相/愀愴/
しゅうそうれつじつ /秋霜烈日/
しゅうそく /収束/終息/集束;focussing/周速/終熄;=終息/
しゅうそくかいせき /収束解析/
しゅうそくかてい /収束過程/
しゅうそくけい /収束形/
しゅうそくさき /収束先/
しゅうそくじょうけん /収束条件/
しゅうそくせい /収束性/
しゅうそくそくど /収束速度/
しゅうそくち /収束値/
しゅうそくていり /収束定理/
しゅうそくてん /収束点/
しゅうそくとくせい /収束特性/
しゅうそくはんけい /収束半径/
しゅうそくはんてい /収束判定/
しゅうそくほう /収束法/
しゅうそくりつ /収束率/
しゅうそさん /臭素酸/
しゅうそつ /修卒/
しゅうそん /集村/
しゅうぞう /収蔵;store/修造;mend/修三;人名/秀三/脩三/収三/
しゅうぞうひん /収蔵品/
しゅうぞうぶつ /収蔵物/
しゅうぞく /習俗/
しゅうたい /醜態/
しゅうたいしょう /終対象/
しゅうたいせい /集大成/
しゅうたろう /秀太郎/終太郎/
しゅうたん /終端/愁嘆/
しゅうたんい /週単位/
しゅうたんえき /終端駅/
しゅうたんがわ /終端側/
しゅうたんきごう /終端記号/
しゅうたんじょうけん /終端条件/
しゅうたんそうち /終端装置/
しゅうたんそくど /終端速度/
しゅうたんていこう /終端抵抗/
しゅうたんば /愁嘆場/
しゅうたんもじ /終端文字/
しゅうだいすう /終代数/
しゅうだつ /収奪/
しゅうだん /集団/終段/
しゅうだん> /集団/
しゅうだんいしき /集団意識;group-conscious/
しゅうだんいしけってい /集団意思決定/
しゅうだんいでんがく /集団遺伝学/
しゅうだんかぜ /集団風邪/
しゅうだんかつどう /集団活動/
しゅうだんかん /集団間/
しゅうだんかんせん /集団感染/
しゅうだんきはん /集団規範/
しゅうだんけいせい /集団形成/
しゅうだんけっこん /集団結婚/
しゅうだんけんしん /集団検診/
しゅうだんこうどう /集団行動/
しゅうだんこん /集団婚;[文化人類学]group marriage/
しゅうだんさいみん /集団催眠/
しゅうだんしこう /集団思考/
しゅうだんしどう /集団指導/
しゅうだんしゅうしょく /集団就職/
しゅうだんしんり /集団心理/
しゅうだんじえいけん /集団自衛権/
しゅうだんじさつ /集団自殺/
しゅうだんせいかつ /集団生活/
しゅうだんそかい /集団疎開/
しゅうだんそしょう /集団訴訟/
しゅうだんちゅう /集団中/
しゅうだんてき /集団的/
しゅうだんてきじえいけん /集団的自衛権/
しゅうだんどうし /集団同士/
しゅうだんない /集団内/
しゅうだんぼうこう /集団暴行/
しゅうだんりきがく /集団力学/
しゅうだんれんしゅう /集団練習/
しゅうち /周知;†well-known.「-の事実」/羞恥/衆知;†民衆の知恵。「-を集める」/周智;地名/終値/習知;learn/周緻/
しゅうちく /修築/
しゅうちしん /羞恥心/
しゅうちじ /州知事/
しゅうちてってい /周知徹底/
しゅうちど /周知度/
しゅうちゃく /執着/終着/祝着/
しゅうちゃくえき /終着駅/
しゅうちゃくしん /執着心/
しゅうちゃくてん /終着点/
しゅうちゅう /集中/集注;論語-/集註/
しゅうちゅうか /集中化/
しゅうちゅうかんり /集中管理/
しゅうちゅうかんりほうしき /集中管理方式/
しゅうちゅうがた /集中型/
しゅうちゅうきょく /集中局/
しゅうちゅうけん /集中研/
しゅうちゅうげんしょう /集中現象/
しゅうちゅうこうぎ /集中講義/
しゅうちゅうこうげき /集中攻撃/
しゅうちゅうこうざ /集中講座/
しゅうちゅうこうじ /集中工事/
しゅうちゅうごうう /集中豪雨/
しゅうちゅうちりょうしつ /集中治療室/
しゅうちゅうてき /集中的/
しゅうちゅうとうこう /集中投稿/
しゅうちゅうび /集中日/
しゅうちゅうほうえい /集中放映/
しゅうちゅうほうか /集中砲火/
しゅうちゅうやく /集中役/
しゅうちゅうりょく /集中力/
しゅうちょう /酋長/周長/
しゅうちん /袖珍/
しゅうちんばん /聚珍版/
しゅうちんぼん /袖珍本/
しゅうづら /主面/
しゅうてい /舟艇/修訂/
しゅうていばん /修訂版/
しゅうてん /終点/秋天/
しゅうてんえん /周転円/
しゅうてんげしゃ /終点下車/
しゅうでん /終電/集電/
しゅうでんしゃ /終電車/
しゅうでんそうち /集電装置/
しゅうと /姑/州都/舅/衆徒;=しゅと/宗徒/囚徒/修斗/
しゅうとう /周到/秋冬/周東/
しゅうとく /習得;†learn.「技術の-」/修得;†master.「単位の-」/収得;†gain.「土地の-」/拾得;†pick up.「財布を-する」/修徳/
しゅうとくかのう /習得可能/
しゅうとくきょくせん /習得曲線/
しゅうとくこうこう /修徳高校/
しゅうとくしょうきん /収得賞金/
しゅうとくぜい /収得税/
しゅうとくそくど /習得速度/
しゅうとくど /修得度/
しゅうとくぶつ /拾得物/
しゅうとくほう /修得法/
しゅうとめ /姑/
しゅうどう /修道/摺動/州道/衆道;(しゅどう) 江戸のやおい/
しゅうどういん /修道院/
しゅうどうかい /修道会/
しゅうどうし /修道士/
しゅうどうじょ /修道女/
しゅうどうそう /修道僧/
しゅうない /週内/
しゅうにゅう /収入/
しゅうにゅういんし /収入印紙/
しゅうにゅうかくほ /収入確保/
しゅうにゅうきんがく /収入金額/
しゅうにゅうげん /収入源;†income source.「主な-」/収入減;†income decrease.「不況による-」/
しゅうにゅうごうけい /収入合計/
しゅうにゅうぞう /収入増/
しゅうにゅうぞうか /収入増加/
しゅうにゅうばいぞう /収入倍増/
しゅうにゅうやく /収入役/
しゅうにん /就任/
しゅうにんえんぜつ /就任演説/
しゅうにんしき /就任式/
しゅうねん /周年/執念/終年/
しゅうねんさいばい /周年栽培/
しゅうねんぶかく /執念深く/
しゅうのう /収納/就農/終脳;telencephalon/
しゅうのうかぐ /収納家具/
しゅうのうかのう /収納可能/
しゅうのうこ /収納庫/
しゅうのうじ /収納時/
しゅうのうだな /収納棚/
しゅうのうぶくろ /収納袋/
しゅうのうぶつ /収納物/
しゅうのうほう /収納法/
しゅうは /宗派/周波/秋波;「-を送る」(=色目を使う)/
しゅうはい /集配/
しゅうはいきょく /集配局/
しゅうはいしん /集配信/
しゅうはいゆうびんきょく /集配郵便局/
しゅうはすう /周波数/
しゅうはすうおうとう /周波数応答/
しゅうはすうかいせき /周波数解析/
しゅうはすうくうかん /周波数空間/
しゅうはすうくぶん /周波数区分/
しゅうはすうさんぷりんぐ /周波数サンプリング/
しゅうはすうしよう /周波数使用/
しゅうはすうじく /周波数軸/
しゅうはすうじくじょう /周波数軸上/
しゅうはすうじょうほう /周波数情報/
しゅうはすうせいぶん /周波数成分/
しゅうはすうせんたくせい /周波数選択性/
しゅうはすうたい /周波数帯/
しゅうはすうたいいき /周波数帯域/
しゅうはすうちょうせい /周波数調整/
しゅうはすうてき /周波数的/
しゅうはすうとくせい /周波数特性/
しゅうはすうはんい /周波数範囲/
しゅうはすうひ /周波数比/
しゅうはすうひょうじ /周波数表示/
しゅうはすうぶぶん /周波数部分/
しゅうはすうぶんかいのう /周波数分解能/
しゅうはすうぶんかつ /周波数分割/
しゅうはすうぶんせき /周波数分析/
しゅうはすうへんかん /周波数変換/
しゅうはすうへんさ /周波数偏差/
しゅうはすうへんちょう /周波数変調;frequency modulation(FM)/
しゅうはすうへんどう /周波数変動/
しゅうはすうべつ /周波数別/
しゅうはすうほうこう /周波数方向/
しゅうはすうほせい /周波数補正/
しゅうはすうりょういき /周波数領域/
しゅうはつ /終発/
しゅうばく /就縛/
しゅうばす /終バス/
しゅうばつ /秀抜/舟筏/
しゅうばん /終盤/週番/終板/
しゅうばんしゅ /終盤手/
しゅうばんせん /終盤戦/
しゅうひ /周皮/
しゅうひょう /集票/衆評/
しゅうび /秀美/愁眉/秀眉/
しゅうふ /醜婦/
しゅうふう /秋風/宗風/
しゅうふく /修復/
しゅうふくかのう /修復可能/
しゅうふくさぎょう /修復作業/
しゅうふくじゅつ /修復術/
しゅうふくちゅう /修復中/
しゅうふくほうほう /修復方法/
しゅうふつ /修祓/
しゅうふつか /週二日/
しゅうぶん /秋分;[二十四節気]9.23頃/醜聞/
しゅうぶんてん /秋分点/
しゅうぶんのひ /秋分の日;9.23頃/
しゅうぶんび /秋分日/
しゅうへい /州兵/周平/修平/衆兵/
しゅうへき /習癖/周壁/皺襞/
しゅうへん /周辺/
しゅうへんいき /周辺域/
しゅうへんかいろ /周辺回路/
しゅうへんかんきょう /周辺環境/
しゅうへんきき /周辺機器/
しゅうへんぎじゅつ /周辺技術/
しゅうへんくういき /周辺空域/
しゅうへんげんこう /周辺減光/
しゅうへんこうりょう /周辺光量/
しゅうへんこく /周辺国/
しゅうへんこっか /周辺国家/
しゅうへんし /周辺視/
しゅうへんしや /周辺視野/
しゅうへんしょこく /周辺諸国/
しゅうへんしょみんぞく /周辺諸民族/
しゅうへんじゅうみん /周辺住民/
しゅうへんそうち /周辺装置/
しゅうへんぞう /周辺像/
しゅうへんちいき /周辺地域/
しゅうへんてき /周辺的/
しゅうへんぶ /周辺部/
しゅうへんぶぶん /周辺部分/
しゅうへんみんぞく /周辺民族/
しゅうへんりょういき /周辺領域/
しゅうほ /修補/
しゅうほう /週報/州法/秀峰/秋芳/秀芳/
しゅうほうどう /秋芳洞/
しゅうぼう /衆望/醜貌/
しゅうまい /焼売/
しゅうまく /終幕/
しゅうまつ /週末;†weekend/終末;†the end/
しゅうまついりょう /終末医療/
しゅうまつき /終末期/
しゅうまつきいりょう /終末期医療/
しゅうまつきせい /週末帰省/
しゅうまつまえ /週末前/
しゅうまつろん /終末論/
しゅうみ /臭味/
しゅうみつ /周密/
しゅうみん /就眠/衆民/
しゅうむ /宗務/
しゅうめ /週目/周目/
しゅうめい /襲名/醜名;infamy/
しゅうめいひろう /襲名披露/
しゅうもく /衆目/
しゅうもん /宗門/
しゅうや /終夜/秀哉/秋夜/
しゅうやうんてん /終夜運転/
しゅうやく /集約/
しゅうやくてき /集約的/
しゅうゆ /終油/
しゅうゆう /周遊/
しゅうゆうかん /修猷館/
しゅうゆうくかん /周遊区間/
しゅうゆうけん /周遊券/
しゅうゆうこうくうけん /周遊航空券/
しゅうよう /収容;†accommodate.「-所」「光-」/収用;†[法](expropriate)国などによる強制的取得。「土地の-」/修養/襲用/
しゅうようしせつ /収容施設/
しゅうようしゃ /収容者/
しゅうようじょ /収容所/
しゅうようじんいん /収容人員/
しゅうようすう /収容数/
しゅうようだいすう /収容台数/
しゅうようにんずう /収容人数/
しゅうようのうりょく /収容能力/
しゅうようほう /収用法/
しゅうようりょう /収容量/
しゅうようりょく /収容力/
しゅうら /修羅/
しゅうらい /襲来/
しゅうらく /集落/聚落;=集落/
しゅうらん /秀蘭/収攬;人心-/
しゅうり /修理/
しゅうりいらい /修理依頼/
しゅうりかのう /修理可能/
しゅうりぎじゅつ /修理技術/
しゅうりぎょう /修理業/
しゅうりこう /修理工/
しゅうりこうじょう /修理工場/
しゅうりこうちん /修理工賃/
しゅうりざい /修理剤/修理材/
しゅうりしょくにん /修理職人/
しゅうりたいせい /修理体制/
しゅうりだい /修理代/
しゅうりちゅう /修理中/
しゅうりつ /収率/州立/
しゅうりつだい /州立大/
しゅうりつだいがく /州立大学/
しゅうりてん /修理店/
しゅうりてんけん /修理点検/
しゅうりでんぴょう /修理伝票/
しゅうりないよう /修理内容/
しゅうりのうりょく /修理能力/
しゅうりひ /修理費/
しゅうりひよう /修理費用/
しゅうりひん /修理品/
しゅうりび /修理日/
しゅうりふのう /修理不能/
しゅうりぶひん /修理部品/
しゅうりぶもん /修理部門/
しゅうりほうほう /修理方法/
しゅうりまえ /修理前/
しゅうりや /修理屋/
しゅうりゅう /周流/
しゅうりょう /終了;†finish/修了;†complete.「大学院-」/収量/秋涼/
しゅうりょうおん /終了音/
しゅうりょうきねん /終了記念/
しゅうりょうけい /終了型/
しゅうりょうご /終了後/
しゅうりょうしき /修了式;†「学年の-」/終了式;†「イベントの-」/
しゅうりょうしゃ /修了者/
しゅうりょうしょう /修了証/
しゅうりょうしょり /終了処理/
しゅうりょうじ /終了時/
しゅうりょうじかん /終了時間/
しゅうりょうじこく /終了時刻/
しゅうりょうじてん /終了時点/
しゅうりょうじょうけん /終了条件/
しゅうりょうせい /修了生/終了性/
しゅうりょうせんげん /終了宣言/
しゅうりょうち /終了値/
しゅうりょうちょくご /終了直後/
しゅうりょうちょくぜん /終了直前/
しゅうりょうてん /終了点/
しゅうりょうねんげん /修了年限/
しゅうりょうはんてい /終了判定/
しゅうりょうほうこく /終了報告/
しゅうりょうまえ /終了前/
しゅうりょうまぎわ /終了間際/
しゅうりょうまじか /終了間近/
しゅうりょうよてい /終了予定/
しゅうりょく /衆力/
しゅうりよう /修理用/
しゅうりようひん /修理用品/
しゅうりようぶひん /修理用部品/
しゅうりん /秋霖;秋の長雨。秋雨前線による雨。/秋林/
しゅうるし /朱漆/
しゅうれい /秀麗/終礼;⇔朝礼/秋冷/周礼;しゅらい/週令/
しゅうれっしゃ /終列車/
しゅうれん /修練/収斂/習練/收斂;「収」旧字/
しゅうれんざい /収斂剤/
しゅうれんせい /収斂性/
しゅうろう /就労/周郎/秀朗/秀郎/
しゅうろうちゅう /就労中/
しゅうろうびざ /就労ビザ/
しゅうろく /収録/集録;†集めて収録する/
しゅうろくきょく /収録曲/
しゅうろくきょくすう /収録曲数/
しゅうろくけい /収録系/
しゅうろくご /収録後/
しゅうろくごすう /収録語数/
しゅうろくさく /収録作/
しゅうろくさくひん /収録作品/
しゅうろくじかん /収録時間/
しゅうろくじゅん /収録順/
しゅうろくち /収録地/
しゅうろくぶん /収録分/
しゅうろくぼん /収録本/
しゅうろん /修論/宗論/衆論;vox populi/
しゅうろんしんさ /修論審査/
しゅうろんはっぴょうかい /修論発表会/
しゅうわ /秀和/
しゅうわい /収賄/醜穢/
しゅうわいざい /収賄罪/
しゅえ /衆会/修慧;[仏教]/集会/
しゅえい /守衛/輸贏;勝敗/
しゅえいしつ /守衛室/
しゅえいじょ /守衛所/
しゅえん /主演/酒宴/主煙/
しゅえんえいが /主演映画/
しゅえんじょゆう /主演女優/
しゅえんじょゆうしょう /主演女優賞/
しゅえんだんゆう /主演男優/
しゅえんだんゆうしょう /主演男優賞/
しゅおう /手応/
しゅおん /主音/主恩/
しゅおんせい /主音声/
しゅか /酒家/主家/種化/
しゅかい /首魁/
しゅかいろ /主回路/
しゅかく /主格;[文法]nominative/主客;「-転倒」/酒客;drinker/
しゅかくてんとう /主客転倒/
しゅかん /主観;subjectivity/主管;†supervise.「-官庁」/主幹;†chief.「雑誌-」/首巻/
しゅかんこう /主幹校/
しゅかんざっしゅ /種間雑種;[生物]interspecies hybrid/
しゅかんしゅぎ /主観主義;subjectivism/
しゅかんじ /主幹事/
しゅかんせい /主観性/
しゅかんてき /主観的/
しゅかんてきはんだん /主観的判断/
しゅかんてきひょうげん /主観的表現/
しゅかんてきようそ /主観的要素/
しゅかんひょうか /主観評価/
しゅかんろん /主観論/
しゅが /主我/珠芽;[植物]bulbel/主芽;[植物]main bud/
しゅがいねん /種概念/
しゅがき /朱書/朱書き/
しゅがん /主眼/
しゅき /手記/酒器/酒気/主機/手旗/朱記/主基/首記/酒旗/
しゅきおく /主記憶/
しゅきおくそうち /主記憶装置/
しゅきおくようりょう /主記憶容量/
しゅきおび /酒気帯び/
しゅきおびうんてん /酒気帯び運転/
しゅきごう /主記号/
しゅきゃく /主脚/主客;=しゅかく/
しゅきゅう /守旧/首級/
しゅきゅうは /守旧派/
しゅきょう /主教/酒興/
しゅきん /手巾/
しゅぎ /主義/手技/
しゅぎしゃ /主義者/
しゅぎしゅちょう /主義主張/
しゅぎょう /修行/修業;=しゅうぎょう/執行;[仏教]/
しゅぎょうしゃ /修行者/
しゅぎょうじだい /修行時代/
しゅぎょうじょう /修行場/
しゅぎょうちゅう /修行中/
しゅぎょうどう /修行道/修行堂/
しゅぎょく /珠玉/
しゅく /祝/宿/珠久;人名/粛;粛正/肅;「粛」の旧字/縮;縮小/蓿;苜蓿/叔;叔父(しゅくふ,おじ)/淑;淑女/俶;(ととのえる)/槭;槭樹(かえで)/菽;まめ/蹙;顰蹙/粥;かゆ/夙;夙夜/倏;(たちまち)/戚;?/
しゅく> /祝/
しゅくあ /宿痾/
しゅくあく /宿悪/
しゅくあん /宿案/
しゅくい /祝意/宿意/
しゅくうん /宿運/
しゅくえい /宿営/
しゅくえいち /宿営地/
しゅくえき /宿駅/
しゅくえん /祝宴/宿縁;karma/宿怨;積年の怨み/祝筵;祝宴の席/
しゅくが /祝賀/
しゅくがかい /祝賀会/
しゅくがく /宿学/
しゅくがじょう /祝賀状/
しゅくがわ /夙川/
しゅくがわこうえん /夙川公園/
しゅくがわら /宿河原/
しゅくがん /宿願/
しゅくき /淑気/
しゅくぎ /祝儀/
しゅくぐち /宿口;姓/
しゅくぐん /粛軍/
しゅくけい /粛啓/
しゅくけいえん /縮景園/
しゅくげん /縮減/
しゅくこ /祝子/
しゅくこんそう /宿根草/
しゅくごう /縮合/宿業/
しゅくさい /祝祭/
しゅくさいげき /祝祭劇/
しゅくさいじつ /祝祭日/
しゅくさつ /縮刷/粛殺/
しゅくさつばん /縮刷版/
しゅくざい /宿罪/
しゅくし /祝詞/宿志/宿紙/
しゅくしゃ /宿舎/縮写/縮砂/
しゅくしゃく /縮尺/
しゅくしゅ /宿主/
しゅくしゅく /粛々/粛粛/
しゅくしょ /宿所/
しゅくしょう /縮小/祝勝/祝捷;=祝勝/
しゅくしょういんさつ /縮小印刷/
しゅくしょうかい /祝勝会/
しゅくしょうかいしゃく /縮小解釈/
しゅくしょうかくだい /縮小拡大/
しゅくしょうがぞう /縮小画像/
しゅくしょうきのう /縮小機能/
しゅくしょうきんこう /縮小均衡;[経済]/
しゅくしょうけいこう /縮小傾向/
しゅくしょうさいせいさん /縮小再生産/
しゅくしょうじ /縮小時/
しゅくしょうばん /縮小版/
しゅくしょうりつ /縮小率/
しゅくしん /粛慎/
しゅくじ /祝辞/
しゅくじつ /祝日/
しゅくじつほう /祝日法/
しゅくじょ /淑女/
しゅくすい /宿酔;二日酔い/
しゅくず /縮図/
しゅくせ /宿世/
しゅくせい /粛清;†purge.「反動分子の-」/粛正;†clean up.「綱紀-」/宿星/祝聖/
しゅくせつ /祝節/宿雪/
しゅくぜん /粛然/宿善/
しゅくそつぎょう /祝卒業/
しゅくたい /縮退/
しゅくたいど /縮退度/
しゅくだい /宿題/
しゅくだいじこう /宿題事項/
しゅくちょく /宿直/
しゅくてき /宿敵/
しゅくてん /祝典/
しゅくてんこうしんきょく /祝典行進曲/
しゅくてんじょきょく /祝典序曲/
しゅくでん /祝電/
しゅくでんひろう /祝電披露/
しゅくとう /祝祷/粛党/
しゅくとく /淑徳/
しゅくとくがくえん /淑徳学園/
しゅくとくこうこう /淑徳高校/
しゅくとくすがも /淑徳巣鴨/
しゅくどう /縮瞳/
しゅくにっちょく /宿日直/
しゅくはい /祝杯/
しゅくはく /宿泊/
しゅくはくあっせん /宿泊斡旋/
しゅくはくか /宿泊可/
しゅくはくきゃく /宿泊客/
しゅくはくきゃくせんよう /宿泊客専用/
しゅくはくけん /宿泊券/
しゅくはくさき /宿泊先/
しゅくはくしせつ /宿泊施設/
しゅくはくしゃ /宿泊者/
しゅくはくしゃいがい /宿泊者以外/
しゅくはくしょう /宿泊証/
しゅくはくじょ /宿泊所/
しゅくはくじょうほう /宿泊情報/
しゅくはくせつび /宿泊設備/
しゅくはくだい /宿泊代/
しゅくはくだいきん /宿泊代金/
しゅくはくち /宿泊地/
しゅくはくていいん /宿泊定員/
しゅくはくとう /宿泊棟/
しゅくはくばしょ /宿泊場所/
しゅくはくひ /宿泊費/
しゅくはくひよう /宿泊費用/
しゅくはくぷらん /宿泊プラン/
しゅくはくもうしこみしょ /宿泊申込書/
しゅくはくゆうたいけん /宿泊優待券/
しゅくはくよやく /宿泊予約/
しゅくはくりょう /宿泊料/
しゅくはくりょうきん /宿泊料金/
しゅくば /宿場/
しゅくばまち /宿場町/
しゅくびょう /宿病/
しゅくふく /祝福/
しゅくぶん /祝文/
しゅくへい /宿弊/
しゅくべつ /祝別/
しゅくべん /宿便/
しゅくほう /祝砲/
しゅくぼう /宿坊/宿望/
しゅくまる /宿丸/
しゅくみょう /宿命/
しゅくめい /宿命/
しゅくめいてき /宿命的/
しゅくめいろん /宿命論/
しゅくもう /縮毛/
しゅくや /夙夜/
しゅくやく /縮約/
しゅくよう /宿曜/
しゅくりょう /宿料/
しゅくろう /宿老/
しゅくん /主君/殊勲/
しゅくんしゃ /殊勲者/
しゅくんしょう /殊勲賞/
しゅぐう /殊遇/
しゅけい /主計/主系/主刑;[法]⇔付加刑/
しゅけいか /主計課/
しゅけいかん /主計監/
しゅけいきょく /主計局/
しゅけいせい /種形成/
しゅけいちょう /主計長/
しゅけいぼ /主計簿/
しゅけいりょう /主計寮;[律令制]/
しゅけいれつ /主系列/
しゅけいれつせい /主系列星/
しゅけん /主権/
しゅけんいじょう /主権移譲/
しゅけんかいふく /主権回復/
しゅけんこっか /主権国家/
しゅけんざいみん /主権在民/
しゅけんしゃ /主権者/
しゅけんしんがい /主権侵害/
しゅげい /手芸/
しゅげいざいりょう /手芸材料/
しゅげいざっし /手芸雑誌/
しゅげいしょ /手芸書/
しゅげた /主桁/
しゅげん /修験/
しゅげんいん /主原因/
しゅげんご /主言語/
しゅげんじゃ /修験者/
しゅげんどう /修験道/
しゅげんりょう /主原料/
しゅこ /朱子/
しゅこう /趣向/酒肴/手工;craft/首肯;「-し難い」/手交;hand over.「証書を-する」/手稿;manuscript/珠孔;[植物]micropyle/殊功/
しゅこうか /主効果/
しゅこうぎょう /手工業/
しゅこうげい /手工芸/
しゅこうじく /主光軸/
しゅこうせん /主光線/
しゅこうりょう /酒肴料/
しゅこつ /手骨/
しゅこん /主根/酒魂/
しゅこんかんしょうこうぐん /手根管症候群/
しゅこんけい /主根系/
しゅご /守護/主語/
しゅごう /酒豪/
しゅごきし /守護騎士/
しゅごしき /守護職/
しゅごしゃ /守護者/
しゅごしん /守護神/
しゅごじん /守護神/
しゅごせい /守護星/
しゅごだい /守護代/
しゅごだいみょう /守護大名/
しゅごれい /守護霊/
しゅさ /主査/種差/主鎖/
しゅさい /主催;†host.「大会を-する」/主宰;†preside.「劇団の-」/主菜;main dish.⇔副菜/主祭/
しゅさいこく /主催国/
しゅさいしゃ /主催者;†host.「大会の-」/主宰者;†president.「同人誌の-」/
しゅさいしゃがわ /主催者側/
しゅさいしゃはっぴょう /主催者発表/
しゅさいじあい /主催試合/
しゅさいだんたい /主催団体/
しゅさよう /主作用/
しゅさん /酒盞/
しゅさんち /主産地/
しゅさんぶつ /主産物/
しゅざ /首座/主座/
しゅざい /取材/主剤/首罪/
しゅざいかつどう /取材活動/
しゅざいきょひ /取材拒否/
しゅざいじん /取材陣/
しゅざいちゅう /取材中/
しゅざいはん /取材班/
しゅざいはんい /取材範囲/
しゅざいばんぐみ /取材番組/
しゅざいよう /取材用/
しゅざいりょう /主材料/
しゅざん /珠算/
しゅし /趣旨;†理由や目的。「当NPOの-」/主旨;†主な意味。「論文の-」/種子/手指/朱子/殊死/銖錙;=錙銖/繻竢/酒肆/
しゅしがく /朱子学/
しゅしきぼん /手識本/
しゅししょうどく /種子消毒/
しゅししょくぶつ /種子植物/
しゅししょくぶつもん /種子植物門/Spermatophyta/
しゅしせつめい /趣旨説明/
しゅしゃ /取捨/手写/種車/
しゅしゃかい /種社会/
しゅしゃせんたく /取捨選択/
しゅしゃりん /主車輪/
しゅしゅ /種々/守株;株(くいぜ)を守る/
しゅしゅざった /種々雑多/
しゅしゅつ /輸出/
しゅしょ /朱書/手書/首書/
しゅしょう /首相/主将/殊勝/主唱;†中心となって唱える/手掌/首唱;†真っ先に唱える/首将/酒漿/修正/
しゅしょうえ /修正会/
しゅしょうかんてい /首相官邸/
しゅしょうけいけんしゃ /首相経験者/
しゅしょうこうせんせい /首相公選制;[時事]/
しゅしょく /主食/酒食;wine and dine/酒色;wine and women/手燭/
しゅしょり /主処理/
しゅしん /主審/主神/酒神;Bacchus/朱唇/珠心/
しゅしんか /種進化/
しゅしんこうし /朱唇皓歯/
しゅしんしつ /主寝室/
しゅじ /主事/朱字/主辞;head-word/主餌/
しゅじい /主治医/
しゅじく /主軸/
しゅじつ /主日/種実/手実/
しゅじつるい /種実類/
しゅじゃく /朱雀/
しゅじゅ /種々/侏儒/種種/
しゅじゅう /主従/
しゅじゅうかんけい /主従関係/
しゅじゅざった /種々雑多/種種雑多/
しゅじゅつ /手術/主述;[文法]主部と述部/
しゅじゅつあと /手術跡/
しゅじゅつご /手術後/
しゅじゅつしつ /手術室/
しゅじょう /衆生/主上/主情/
しゅじょうさいど /衆生済度/
しゅじょうしゅぎ /主情主義;emotionalism/
しゅじん /主人/
しゅじんこう /主人公/
しゅじんこうたち /主人公達/
しゅじんこうほんにん /主人公本人/
しゅじんさま /主人様/
しゅじんもん /主尋問/
しゅす /繻子/
しゅすい /取水/
しゅすいこう /取水口/
しゅすいとう /取水塔/
しゅすう /種数/
しゅすじ /主筋/
しゅずみ /朱墨/
しゅせい /酒精/守勢;-に立たされる/守成;-は難し/主星;連星の明るい方/首星;星座で最も明るい星/
しゅせいぎょき /主制御器/
しゅせいひん /主製品/
しゅせいぶん /主成分/
しゅせいぶんぶんせき /主成分分析/
しゅせき /主席;国家-/首席;-奏者/酒席/手跡/酒石/手蹟;=手跡/
しゅせき> /首席;(principal) -研究員,-バイオリニスト/
しゅせきえい /酒石英/
しゅせきけんきゅうかん /首席研究官/
しゅせきごうかく /首席合格/
しゅせきさん /酒石酸/
しゅせつ /主節;[文法]main clause/守節;節義を守る/
しゅせん /主戦/酒仙/守戦/酒戦/
しゅせんきしゅ /主戦騎手/
しゅせんじょう /主戦場/
しゅせんせん /主戦線/
しゅせんど /守銭奴/
しゅせんは /主戦派/
しゅせんりつ /主旋律/
しゅせんりょく /主戦力/
しゅぜい /酒税/主税/
しゅぜいきょく /主税局/
しゅぜいほう /酒税法/
しゅぜいりょう /主税寮/
しゅぜん /酒膳/主膳;宮中の料理人/修禅;[仏教]禅定を修める/修善;[仏教]善行を積む/鬚髯/
しゅぜんじ /修善寺;地名,静岡/修禅寺;修善寺にある寺院/
しゅぜんじちょう /修善寺町/
しゅぜんじものがたり /修善寺物語/修禅寺物語/
しゅぜんたい /種全体/
しゅそ /主訴/首座/
しゅそう /主相/
しゅそうさ /主走査/
しゅそうじゅつ /手相術/
しゅそりょうたん /首鼠両端/
しゅぞう /酒造;さかづくり/酒蔵;さかぐら/
しゅぞうか /酒造家/
しゅぞうけんがく /酒蔵見学/
しゅぞうけんきゅうじょ /酒造研究所/
しゅぞうし /酒造史/
しゅぞく /種族/
しゅぞくてき /種族的/
しゅぞくほぞん /種族保存/
しゅたい /主体/
しゅたいしゃ /主体者/
しゅたいせい /主体性/
しゅたいてき /主体的/
しゅたく /手沢/
しゅたくぼん /手沢本/
しゅたる /主たる/
しゅたんとう /主担当/
しゅだい /主題;theme/首題;はじめの題目/腫大/主代/
しゅだいか /主題歌;theme song/主題化;topicalise/
しゅだいきょく /主題曲/
しゅだいず /主題図/
しゅだいていじ /主題提示/
しゅだいてき /主題的/
しゅだいわく /主台枠/
しゅだつ /須達/
しゅだん /手段/
しゅだんてき /手段的/
しゅち /主知/主値/趣致/恤;(呉音)/
しゅちく /種畜/
しゅちしゅぎ /主知主義/
しゅちせつ /主知説/
しゅちにくりん /酒池肉林/
しゅちゅう /手中/主柱/
しゅちょ /主著/
しゅちょう /主張/首長/腫脹/朱鳥;年号(686)/主徴;[医]presenting sign/主調;[音楽]Haupttonart/主潮;main current/殊寵/
しゅちょうおん /主調音;[音楽]tonic/
しゅちょうこく /首長国/
しゅちょうこくれんぽう /首長国連邦/
しゅちょうじたい /主張自体/
しゅちょうぜんたい /主張全体/
しゅちょうてん /主張点/
しゅちょうどおり /主張通り/
しゅちょうないよう /主張内容/
しゅちょうほうほう /主張方法/
しゅっか /出荷/出火/
しゅっかかいし /出荷開始/
しゅっかがく /出荷額/
しゅっかき /出荷機/
しゅっかご /出荷後/
しゅっかじ /出荷時/
しゅっかじき /出荷時期/
しゅっかじっせき /出荷実績/
しゅっかじてん /出荷時点/
しゅっかすう /出荷数/
しゅっかだいすう /出荷台数/
しゅっかちょくぜん /出荷直前/
しゅっかにちじ /出荷日時/
しゅっかばん /出荷版/
しゅっかび /出荷日/
しゅっかぶん /出荷分/
しゅっかまち /出荷待ち/
しゅっかよてい /出荷予定/
しゅっかりょう /出荷量/
しゅっかん /出棺/
しゅっきょ /卒去/
しゅっきょう /出郷/出京/
しゅっきん /出勤/出金/
しゅっきんじ /出勤時/
しゅっきんじかん /出勤時間/
しゅっきんでんぴょう /出金伝票/
しゅっきんび /出勤日/
しゅっきんぼ /出勤簿/
しゅっきんまえ /出勤前/
しゅっけ /出家/
しゅっけしゃ /出家者/
しゅっけっせき /出欠席/
しゅっけつ /出血/出欠/
しゅっけつかかく /出血価格/
しゅっけつせい /出血性/
しゅっけつたりょう /出血多量/
しゅっけつひょう /出欠表/
しゅっこ /出庫/
しゅっこう /出向/出港;港を出ること/出航;航行を始めること/出稿;「広告の-」/出講;授業をする/
しゅっこうさき /出向先/
しゅっこうちゅう /出向中/
しゅっこく /出国/
しゅっこくけんさ /出国検査/
しゅっこくしんさ /出国審査/
しゅっこくじ /出国時/
しゅっこくぜい /出国税/
しゅっこくてつづき /出国手続/出国手続き/
しゅっこくびん /出国便/
しゅっこじ /出庫時/
しゅっこつ /倏忽;suddenly/
しゅっこんそう /宿根草;[園芸]jaundice root. cf.多年草/
しゅっさつ /出札/
しゅっさつがかり /出札係/
しゅっさつぐち /出札口/
しゅっさん /出産/
しゅっさんいがい /出産以外/
しゅっさんいわい /出産祝/出産祝い/
しゅっさんきゅうか /出産休暇/
しゅっさんしょうめいしょ /出産証明書/
しゅっさんじ /出産時/
しゅっさんたいしょく /出産退職/
しゅっさんよていび /出産予定日/
しゅっし /出資/出仕/
しゅっしきん /出資金/
しゅっしさき /出資先/
しゅっししゃ /出資者/
しゅっしひりつ /出資比率/
しゅっしほう /出資法/
しゅっしゃ /出社/出射/出車/
しゅっしゃび /出社日/
しゅっしゃまえ /出社前/
しゅっしゃめん /出射面/
しゅっしょ /出所/出処/
しゅっしょう /出生/
しゅっしょうぜんしんだん /出生前診断/
しゅっしょうとどけ /出生届/
しゅっしょうりつ /出生率/
しゅっしょく /出色/出食/
しゅっしょご /出所後/
しゅっしょしんたい /出処進退/
しゅっしん /出身/
しゅっしんがくぶ /出身学部/
しゅっしんがっか /出身学科/
しゅっしんがっこう /出身学校/
しゅっしんけん /出身県/
しゅっしんこう /出身校/
しゅっしんこうこう /出身高校/
しゅっしんこく /出身国/
しゅっしんしゃ /出身者/
しゅっしんしゃどうし /出身者同士/
しゅっしんだいがく /出身大学/
しゅっしんち /出身地/
しゅっすい /出水/出穂/
しゅっせ /出世/出瀬/
しゅっせい /出生/出征/出精/
しゅっせいしょうめいしょ /出生証明書/
しゅっせいすう /出生数/
しゅっせいぜんしんだん /出生前診断/
しゅっせいち /出生地/
しゅっせいとどけ /出生届/
しゅっせいまえしんだん /出生前診断/
しゅっせいりつ /出生率/
しゅっせうお /出世魚/
しゅっせかいどう /出世街道/
しゅっせがしら /出世頭/
しゅっせき /出席/
しゅっせきかいすう /出席回数/
しゅっせききぼう /出席希望/
しゅっせきしゃ /出席者/
しゅっせきじ /出席時/
しゅっせきじょうきょう /出席状況/
しゅっせきてん /出席点/
しゅっせきにっすう /出席日数/
しゅっせきばんごう /出席番号/
しゅっせきぼ /出席簿/
しゅっせきりつ /出席率/
しゅっせけん /出世間/
しゅっせけんてき /出世間的/
しゅっせさく /出世作/
しゅっせばらい /出世払い/
しゅっそう /出走/出槽/
しゅっそうかいすう /出走回数/
しゅっそうかいひ /出走回避/
しゅっそうかのう /出走可能/
しゅっそうかのうとうすう /出走可能頭数/
しゅっそうきんし /出走禁止/
しゅっそうけん /出走権/
しゅっそうしかく /出走資格/
しゅっそうじょうけん /出走条件/
しゅっそうせいげん /出走制限/
しゅっそうとうすう /出走頭数/
しゅっそうとうろく /出走登録/
しゅっそうとりけし /出走取消/
しゅっそうば /出走馬/
しゅっそうまえ /出走前/
しゅっそうよてい /出走予定/
しゅっそうよていば /出走予定馬/
しゅったい /出来/
しゅったいきん /出退勤/
しゅったつ /出立/
しゅったん /出炭/
しゅっちょう /出張/出超;輸出超過/
しゅっちょういらい /出張依頼/
しゅっちょういらいしょ /出張依頼書/
しゅっちょうこうせい /出張校正/
しゅっちょうさき /出張先/
しゅっちょうさつえい /出張撮影/
しゅっちょうしゃ /出張者/
しゅっちょうしゅうり /出張修理/
しゅっちょうしょ /出張所/
しゅっちょうじ /出張時/
しゅっちょうじょ /出張所/
しゅっちょうちゅう /出張中/
しゅっちょうてあて /出張手当/
しゅっちょうはんばい /出張販売/
しゅっちょうばぼう /出張馬房/
しゅっちょうひ /出張費/
しゅっちょうほうこく /出張報告/
しゅっちょうまえ /出張前/
しゅっちょうめいれいしょ /出張命令書/
しゅっちょうりょひ /出張旅費/
しゅっちょうりよう /出張利用/
しゅっちん /出陳/
しゅってい /出廷/出艇/
しゅってん /出展;「展示会への-」/出店;「コンビニの-」/出典;「引用部分の-」/
しゅってんさくひん /出展作品/
しゅってんしゃ /出展者/出店者/
しゅってんふめい /出典不明/
しゅっとう /出頭/
しゅっとうにん /出頭人/
しゅっとうめいれい /出頭命令/
しゅっぱつ /出発/
しゅっぱつき /出発機/
しゅっぱつしんこう /出発進行/
しゅっぱつしんごう /出発信号/
しゅっぱつしんごうき /出発信号機/
しゅっぱつじ /出発時/
しゅっぱつじかん /出発時間/
しゅっぱつじこく /出発時刻/
しゅっぱつち /出発地/
しゅっぱつちてん /出発地点/
しゅっぱつちょくぜん /出発直前/
しゅっぱつていこう /出発抵抗/
しゅっぱつてん /出発点/
しゅっぱつび /出発日/
しゅっぱつびん /出発便/
しゅっぱつまえ /出発前/
しゅっぱつまぎわ /出発間際/
しゅっぱん /出版/出帆;sail/
しゅっぱんかい /出版会/
しゅっぱんかんけい /出版関係/
しゅっぱんかんけいしゃ /出版関係者/
しゅっぱんがいしゃ /出版会社/
しゅっぱんきねん /出版記念/
しゅっぱんきょく /出版局/
しゅっぱんぎょう /出版業/
しゅっぱんぎょうかい /出版業界/
しゅっぱんけいやく /出版契約/
しゅっぱんけん /出版権/
しゅっぱんけんしゃ /出版権者/
しゅっぱんしゃ /出版社/出版者;†出版した人/
しゅっぱんしゃがわ /出版社側/
しゅっぱんしゃなど /出版社等/
しゅっぱんしゃふめい /出版社不明/
しゅっぱんしゃべつ /出版社別/
しゅっぱんしゃめい /出版社名/出版者名;†/
しゅっぱんじ /出版時/
しゅっぱんじぎょうほんぶ /出版事業本部/
しゅっぱんじん /出版人/
しゅっぱんにん /出版人/
しゅっぱんのじゆう /出版の自由;憲法21条/
しゅっぱんふ /出版譜/
しゅっぱんぶ /出版部/
しゅっぱんぶすう /出版部数/
しゅっぱんぶつ /出版物/
しゅっぱんほう /出版法/
しゅっぱんまえ /出版前/
しゅっぱんもと /出版元/
しゅっぴ /出費/
しゅっぴつ /出筆/
しゅっぴん /出品/
しゅっぴんさっか /出品作家/
しゅっぴんしゃ /出品者/
しゅっぴんちゅう /出品中/
しゅっぴんぶつ /出品物/
しゅっぴんほうほう /出品方法/
しゅっぷ /出府/
しゅっぺい /出兵/
しゅっぽん /出奔/
しゅつ /出/蟀;蟋蟀(こおろぎ)/恤;救恤(きゅうじゅつ)/卆;「卒」の旧字/
しゅつえき /出役/
しゅつえじぷとき /出エジプト記;[聖書]Exodus(Ex,Exod)/
しゅつえん /出演/出捐/
しゅつえんいちらん /出演一覧/
しゅつえんさく /出演作/
しゅつえんさくひん /出演作品/
しゅつえんしゃ /出演者/
しゅつえんしゃぜんいん /出演者全員/
しゅつえんしゃたち /出演者達/
しゅつえんしゃめい /出演者名/
しゅつえんじょうほう /出演情報/
しゅつえんちゅう /出演中/
しゅつえんばんぐみ /出演番組/
しゅつえんよてい /出演予定/
しゅつえんりょう /出演料/
しゅつが /出芽/出駕/
しゅつがん /出願/
しゅつがんしかく /出願資格/
しゅつがんしょ /出願書/
しゅつがんずみ /出願済/
しゅつがんちゅう /出願中/
しゅつがんにん /出願人/
しゅつがんび /出願日/
しゅつぎょ /出御/
しゅつけっせき /出欠席/
しゅつげき /出撃/
しゅつげん /出現/
しゅつげんいち /出現位置/
しゅつげんかくりつ /出現確率/
しゅつげんかのうせい /出現可能性/
しゅつげんすう /出現数/
しゅつげんばしょ /出現場所/
しゅつげんひんど /出現頻度/
しゅつげんまえ /出現前/
しゅつげんりつ /出現率/
しゅつごく /出獄/
しゅつざん /出山/
しゅつじ /出自/
しゅつじょう /出場/出状/出定/
しゅつじょうかいすう /出場回数/
しゅつじょうかしゅ /出場歌手/
しゅつじょうかのう /出場可能/
しゅつじょうきかい /出場機会/
しゅつじょうきてい /出場規定/
しゅつじょうけん /出場権/
しゅつじょうけんかくとく /出場権獲得/
しゅつじょうこう /出場校/
しゅつじょうこうけってい /出場校決定/
しゅつじょうこうご /出定後語/
しゅつじょうこく /出場国/
しゅつじょうしかく /出場資格/
しゅつじょうしゃ /出場者/
しゅつじょうしょうご /出定笑語/
しゅつじょうせんしゅ /出場選手/
しゅつじょうせんしゅとうろく /出場選手登録/
しゅつじょうちゅう /出場中/
しゅつじょうていし /出場停止/
しゅつじょうば /出場馬/
しゅつじょうよてい /出場予定/
しゅつじょうよていしゃ /出場予定者/
しゅつじょうわく /出場枠/
しゅつじん /出陣/
しゅつだい /出題/
しゅつだいがわ /出題側/
しゅつだいけいしき /出題形式/
しゅつだいしゃ /出題者/
しゅつだいじ /出題時/
しゅつだいもと /出題元/
しゅつど /出土/
しゅつどう /出動/
しゅつどひん /出土品/
しゅつにゅう /出入/
しゅつにゅうかんり /出入管理/
しゅつにゅうこく /出入国/
しゅつにゅうこくかんりきょく /出入国管理局/
しゅつにゅうこくぜい /出入国税/
しゅつのう /出納/
しゅつば /出馬/
しゅつばとうひょう /出馬投票/
しゅつばひょう /出馬表/
しゅつばひょうめい /出馬表明/
しゅつぼつ /出没/
しゅつぼつち /出没地/
しゅつむ /出務/
しゅつもくよそう /出目予想/
しゅつもん /出門/
しゅつらい /出来/
しゅつらん /出藍/
しゅつり /出離/
しゅつりしょうじ /出離生死/
しゅつりょう /出漁/出猟/
しゅつりょく /出力/
しゅつりょくいち /出力位置/
しゅつりょくか /出力可/
しゅつりょくかのう /出力可能/
しゅつりょくかんすう /出力関数/
しゅつりょくがわ /出力側/
しゅつりょくくらす /出力クラス/
しゅつりょくけい /出力系/
しゅつりょくけいしき /出力形式/
しゅつりょくけっか /出力結果/
しゅつりょくこうじょう /出力向上/
しゅつりょくさいだい /出力最大/
しゅつりょくさき /出力先/
しゅつりょくし /出力紙/
しゅつりょくしてい /出力指定/
しゅつりょくしょり /出力処理/
しゅつりょくしんごう /出力信号/
しゅつりょくじ /出力時/
しゅつりょくじく /出力軸/
しゅつりょくせん /出力線/
しゅつりょくそう /出力層/
しゅつりょくそうさ /出力操作/
しゅつりょくそうち /出力装置/
しゅつりょくたん /出力端/
しゅつりょくたんし /出力端子/
しゅつりょくだん /出力段/
しゅつりょくち /出力値/
しゅつりょくちゅう /出力中/
しゅつりょくちょうせい /出力調整/
しゅつりょくでんあつ /出力電圧/
しゅつりょくとくせい /出力特性/
しゅつりょくはけい /出力波形/
しゅつりょくばいたい /出力媒体/
しゅつりょくひんしつ /出力品質/
しゅつりょくぶ /出力部/
しゅつりょくほう /出力法/
しゅつりょくほうほう /出力方法/
しゅつりょくもじ /出力文字/
しゅつりょくよう /出力用/
しゅつりょくようきゅう /出力要求/
しゅつりょくようし /出力用紙/
しゅつりょくれい /出力例/
しゅつりょくれつ /出力列/
しゅつるい /出塁/
しゅてん /朱点/主点/主典/
しゅてんし /主天使;dominations/
しゅてんどうじ /酒呑童子/手天童子;[漫画]永井豪/
しゅでい /朱泥/
しゅでん /主殿;-造り/
しゅでんげん /主電源/
しゅでんづくり /主殿造り/
しゅでんどうき /主電動機/
しゅでんりょう /主殿寮;[律令制]施設・設備の維持管理役/
しゅと /首都/首途/酒徒/
しゅとう /種痘/手刀/酒盗/手套;てぶくろ。「-を脱す」(=本気を出す)/首藤;人名/
しゅときのう /首都機能/
しゅとく /取得/
しゅとくかがく /取得価額/
しゅとくかのう /取得可能/
しゅとくげんか /取得原価/
しゅとくご /取得後/
しゅとくしゃ /取得者/
しゅとくしんせいしょ /取得申請書/
しゅとくじ /取得時/
しゅとくじこう /取得時効/
しゅとくだいこうぎょうしゃ /取得代行業者/
しゅとくほうほう /取得方法/
しゅとくみこみ /取得見込/
しゅとくりょう /取得料/
しゅとけん /首都圏/
しゅとけんきんこう /首都圏近郊/
しゅとけんてつどう /首都圏鉄道/
しゅとけんない /首都圏内/
しゅとこう /首都高/
しゅとこうこうだん /首都高公団/
しゅとこうした /首都高下/
しゅとこうそく /首都高速/
しゅとこうそくどうろ /首都高速道路/
しゅとして /主として/
しゅどう /手動/主導/首藤/主動/衆道/
しゅどう> /手動;-接続,-エレベータ/
しゅどうかいへいしき /手動開閉式/
しゅどうがた /主導型/手動型/
しゅどうけいさんき /手動計算機/
しゅどうけん /主導権/
しゅどうしき /手動式/
しゅどうせってい /手動設定/
しゅどうそうさ /手動操作/
しゅどうそうしん /手動送信/
しゅどうだい /手動台/
しゅどうてき /主導的/
しゅどうとうろく /手動登録/
しゅどうは /手動派/
しゅどうへんそくき /手動変速機/
しゅどうりん /主動輪/
しゅどく /酒毒/
しゅにく /朱肉/酒肉/
しゅにん /主任/
しゅにんいん /主任員/
しゅにんかい /主任会/
しゅにんきょうじゅ /主任教授/
しゅにんぎし /主任技師/
しゅにんけんきゅうかん /主任研究官/
しゅにんしゃ /主任者/
しゅにんしゃしけん /主任者試験/
しゅぬり /朱塗り/
しゅねんしょうしつ /主燃焼室/
しゅのう /首脳/主脳/
しゅのうかいぎ /首脳会議/
しゅのうかいだん /首脳会談/
しゅのうじん /首脳陣/
しゅのうはんたい /酒嚢飯袋/
しゅのうぶ /首脳部/
しゅはい /酒杯/手背/酒盃/
しゅはく /手搏/
しゅはん /主犯/首班/酒飯/
しゅはんかく /主犯格/
しゅば /種馬/
しゅばい /酒売/
しゅばんごう /主番号/
しゅひ /守秘/種皮;[植物]seed coat/珠皮;[植物]integument/種肥/
しゅひぎむ /守秘義務/
しゅひぎむいはん /守秘義務違反/
しゅひつ /主筆/朱筆/
しゅひん /主賓/
しゅび /守備/首尾/
しゅびいち /守備位置/
しゅびいっかん /首尾一貫/
しゅびがた /守備型/
しゅびがため /守備固め/
しゅびがわ /守備側/
しゅびき /朱引/朱引き/
しゅびじん /守備陣/
しゅびたい /守備隊/
しゅびはんい /守備範囲/
しゅびはんいがい /守備範囲外/
しゅびぼうがい /守備妨害/
しゅびめん /守備面/
しゅびょう /種苗/
しゅびょうほう /種苗法/
しゅびよく /首尾よく/首尾良く/
しゅびりつ /守備率/
しゅびりょく /守備力/
しゅびりょくきょうか /守備力強化/
しゅふ /主婦/主夫/首府/
しゅふぎょう /主婦業/主夫業/
しゅふく /首服/
しゅふやく /主婦役/
しゅふれん /主婦連/
しゅぶ /首部;first part/主部;main part/
しゅぶき /主武器/
しゅぶつ /主物/
しゅぶん /主文/
しゅへい /手兵/守兵/珠柄/
しゅへいかつ /主平滑/
しゅへき /酒癖/
しゅへんあつき /主変圧器/
しゅべつ /種別/
しゅべつごと /種別毎/
しゅべつじゅん /種別順/
しゅべつひょうじ /種別表示/
しゅべつへんこう /種別変更/
しゅほ /酒保/
しゅほう /手法/主砲/主峰;山脈の-/修法/
しゅぼ /酒母/
しゅぼう /酒房;酒屋/首謀/主謀;=首謀/酒坊;=酒房/
しゅぼうしゃ /首謀者/主謀者;=首謀者/
しゅぼくてん /朱墨点/
しゅぼば /種牡馬/
しゅぼばじてん /種牡馬辞典/
しゅぼばせいせき /種牡馬成績/
しゅまい /酒米/
しゅまつ /朱抹/
しゅみ /趣味/須弥;-山/
しゅみきょうよう /趣味教養/
しゅみざ /須弥座/
しゅみし /趣味誌/
しゅみじん /趣味人/
しゅみせい /趣味性/
しゅみせん /須弥山/
しゅみだん /須弥壇/
しゅみてき /趣味的/
しゅみひん /趣味品/
しゅみゃく /主脈/
しゅむ /主務/
しゅむかんちょう /主務官庁/
しゅむだいじん /主務大臣/
しゅめ /主馬/
しゅめーるご /シュメール語;Sumerian/
しゅめーるじん /シュメール人;Sumerian/
しゅめい /種名;[生物]specific name/主命/
しゅめもり /主メモリ/
しゅもーど /主モード/
しゅもく /種目/撞木/
しゅもくがた /撞木形/
しゅもくざめ /撞木鮫/
しゅもくづえ /撞木杖/
しゅもくてき /主目的/
しゅもくべつ /種目別/
しゅもくまち /撞木町/
しゅもつ /腫物/
しゅもん /朱門/
しゅやく /主役/主薬/
しゅやくかく /主役格/
しゅやくきゅう /主役級/
しゅゆ /須臾/
しゅよう /主要/腫瘍/主用/須要/
しゅよう> /主要;-紙,-政党,-メンバー/
しゅよういん /主要因/
しゅようえき /主要駅/
しゅようかげきじょう /主要歌劇場/
しゅようかんせん /主要幹線/
しゅようがく /腫瘍学/
しゅようきかん /主要機関/
しゅようきき /主要機器/
しゅようきょてんかん /主要拠点間/
しゅようくうこう /主要空港/
しゅようこく /主要国/
しゅようさくひん /主要作品/
しゅようさんぎょう /主要産業/
しゅようしゅだい /主要主題/
しゅようじかん /主要時間/
しゅようじんぶつ /主要人物/
しゅようそしき /主要組織/
しゅようだいがく /主要大学/
しゅようち /主要地/
しゅようちょさく /主要著作/
しゅようとうじょうじんぶつ /主要登場人物/
しゅようとし /主要都市/
しゅようどうろ /主要道路/
しゅようひしゃたい /主要被写体/
しゅようぶ /主要部/
しゅようぶひん /主要部品/
しゅようぶぶん /主要部分/
しゅようぶもん /主要部門/
しゅようへんこうてん /主要変更点/
しゅようようそ /主要要素/
しゅようろんぶん /主要論文/
しゅよく /主翼/
しゅよくじょう /主翼上/
しゅら /修羅/
しゅらい /周礼/
しゅらおう /修羅王/
しゅらじょう /修羅場/
しゅらどう /修羅道/
しゅらば /修羅場/
しゅらもの /修羅物/
しゅらん /酒乱/
しゅり /首里/修理;-大夫/
しゅりけん /手裏剣/
しゅりし /首里市/
しゅりしき /修理職/
しゅりだいぶ /修理大夫/
しゅりはんどく /周利槃特/
しゅりゅう /主流/腫瘤/
しゅりゅうえん /主流煙/
しゅりゅうだん /手榴弾/
しゅりゅうは /主流派/
しゅりょう /狩猟/首領/酒量/
しゅりょうけん /狩猟犬/
しゅりょうじゅう /狩猟獣;†(撃たれる方)/狩猟銃;†(撃つ方)/
しゅりょうたいしょう /狩猟対象/
しゅりょうほう /狩猟法;[法][略語]鳥獣の保護及び狩猟の適正化に関する法律/
しゅりょうめんきょ /狩猟免許/
しゅりょうよう /狩猟用/
しゅりょく /主力/
しゅりょくかん /主力艦/
しゅりょくき /主力機/
しゅりょくきゅう /主力級/
しゅりょくぎんこう /主力銀行;[金融]NB:「main bank」は和製英語/
しゅりょくこう /主力行/
しゅりょくしょうひん /主力商品/
しゅりょくせいひん /主力製品/
しゅりょくせんしゃ /主力戦車/
しゅりょくせんしゅ /主力選手/
しゅりょくだしゃ /主力打者/
しゅりょくとうしゅ /主力投手/
しゅりょくぶたい /主力部隊/
しゅるい /種類/酒類;liquor/
しゅるいかぶ /種類株;株主の権利内容が普通株と異なる株式/
しゅるいごと /種類毎/
しゅるいさいけん /種類債権/
しゅるいすう /種類数/
しゅるいべつ /種類別/
しゅるいめい /種類名/
しゅれいもん /守礼門/
しゅれん /手練/
しゅろ /棕櫚/椶櫚/
しゅろう /酒楼/
しゅろうちわ /棕櫚団扇/
しゅろちく /棕櫚竹;[植物]ヤシ科/
しゅろんぶん /主論文/
しゅわ /手話/
しゅわおん /主和音/
しゅわくせい /主惑星/
しゅわこうしゅうかい /手話講習会/
しゅわひょうげん /手話表現/
しゅわん /手腕/
しゅわんか /手腕家/
しゅわんさいぼう /シュワン細胞;[生物]Schwann cell/
しゅん /旬/春/瞬;瞬間/舜;論語等に見える伝説上の名君/蕣;あさがお/俊;俊足/峻;急峻/竣;竣工/駿;優駿/悛;改悛/浚;浚渫/皴;しわ/逡;逡巡/雋/儁/惷/蠢;蠢動/墫/濬/筍;たけのこ/
しゅんい /春意/
しゅんいち /俊一/峻一/
しゅんいちろう /俊一郎/俊一朗/
しゅんう /春雨/
しゅんえい /俊英/
しゅんか /春夏/春霞/春歌/
しゅんかしゅうとう /春夏秋冬/
しゅんかしょり /春化処理/
しゅんかどう /春華堂/
しゅんかん /瞬間/春寒/春官/筍干/笋羹;=筍干/笋干;=筍干/
しゅんかんいどう /瞬間移動/
しゅんかんげい /瞬間芸/
しゅんかんさいだい /瞬間最大/
しゅんかんさいだいふうそく /瞬間最大風速/
しゅんかんしゅんかん /瞬間瞬間/
しゅんかんせっちゃく /瞬間接着/
しゅんかんせっちゃくざい /瞬間接着剤/
しゅんかんそうずしまものがたり /俊寛僧都島物語/
しゅんかんてき /瞬間的/
しゅんかんふうそく /瞬間風速/
しゅんかんゆわかしき /瞬間湯沸かし器/瞬間湯沸し器/
しゅんが /春画/
しゅんき /春季;†/春期;†/春機;発情/春気;春景色/峻輝/
しゅんきこうれいさい /春季皇霊祭;現・春分の日/
しゅんきたいかい /春季大会/春期大会/
しゅんきち /駿吉/
しゅんきゅう /春宮/
しゅんきょ /峻拒/
しゅんきょう /春興/
しゅんきんしょう /春琴抄;谷崎潤一郎/
しゅんぎく /春菊/
しゅんぎょ /旬魚/
しゅんぎょう /春暁/春業/
しゅんけい /春景/
しゅんけつ /俊傑/
しゅんけん /峻険/峻嶮/
しゅんげざい /峻下剤/
しゅんげつ /春月/
しゅんげん /峻厳/
しゅんこう /竣工/春光/竣功/
しゅんこうしき /竣工式/
しゅんこく /瞬刻/
しゅんさい /俊才/
しゅんさつ /瞬殺/
しゅんざい /春材/
しゅんしゅう /俊秀/春愁/
しゅんしょ /春初/
しゅんしょう /春宵/
しゅんしょく /春色/
しゅんしん /舜臣/春心/
しゅんじ /瞬時/俊二/俊治/俊次/俊司/
しゅんじち /瞬時値/
しゅんじつ /春日/
しゅんじゅう /春秋/
しゅんじゅうさしでん /春秋左氏伝;『春秋』の註釈書/
しゅんじゅうじだい /春秋時代;BC770-BC403/
しゅんじゅうせんごくじだい /春秋戦国時代/
しゅんじゅん /逡巡/
しゅんじょう /春情/
しゅんすい /旬粋/
しゅんすけ /俊介/俊輔/俊亮/
しゅんせい /竣成;竣工/俊成;?/
しゅんせつ /浚渫/春節/春雪/
しゅんせつせん /浚渫船/
しゅんぜん /春前/
しゅんそく /俊足/駿足/瞬息;単位。10^-16/
しゅんぞう /俊三/
しゅんたろう /俊太郎/
しゅんだん /瞬断/春暖/
しゅんちょう /春鳥;鶯/
しゅんつ /順子/
しゅんてい /瞬停/
しゅんてつ /俊哲/
しゅんでい /春泥/
しゅんでん /瞬電/
しゅんとう /春闘/
しゅんとうぐん /駿東郡/
しゅんどう /蠢動/春藤/
しゅんば /駿馬/
しゅんぱつりょく /瞬発力/
しゅんぱつりょくしょうぶ /瞬発力勝負/
しゅんびん /俊敏/
しゅんぶん /春分;[二十四節気]3.21頃/
しゅんぶんてん /春分点/
しゅんぶんのひ /春分の日;3.21頃/
しゅんぶんび /春分日/
しゅんぷう /春風/
しゅんぷうたいとう /春風駘蕩/
しゅんぷうてい /春風亭/
しゅんぷく /春服/
しゅんべつ /峻別/
しゅんぼう /俊髦/
しゅんぽん /春本/
しゅんみん /春眠/
しゅんむ /春夢/
しゅんめ /駿馬/
しゅんや /春夜/
しゅんよう /春陽/
しゅんようぶんこ /春陽文庫/
しゅんらい /春雷/
しゅんらん /春蘭/
しゅんれい /峻嶺/
しゅんれつ /峻烈/
しゅんろう /俊朗/隼郎/春郎/隼朗/
しゆう /雌雄/私有;private/市有;city owned/師友/詩友/子游;孔子の弟子/
しゆう> /私有;†private/市有;†city owned/
しゆういしゅ /雌雄異株/
しゆういたい /雌雄異体/
しゆうざいさん /私有財産/
しゆうち /私有地;private land/市有地;city-owned land/
しゆうどうしゅ /雌雄同株/
しゆうどうたい /雌雄同体/
しゆうぶつ /私有物/
しゆうりん /私有林/
しょ /所/初/書/署;警察-/諸;もろもろ/緒;はじめの/処/暑/庶;庶民/蔗;蔗糖/曙;(あけぼの)曙光/渚;なぎさ/薯;馬鈴薯/藷;甘藷/且;かつ/岨;そわ/狙;(漢音) ねら・う/砠/苴/雎/杵;きね/黍;きび/墅/嶼;島嶼/胥/蜍;蟾蜍/處;「処」の旧字/苜;?/
しょ> /諸/初/
しょーろんぽう /小籠包/
しょあく /諸悪/
しょあくまくさ /諸悪莫作/
しょい /所謂/所為/
しょいこ /背負子/
しょいちねん /初一念/
しょいり /初入/
しょいん /書院/所員;研究所の-/署員;消防署の-/書淫;読書に溺れる/
しょいんし /書院紙/
しょいんづくり /書院造り;[建築]/書院造/
しょいんぶんこ /書院文庫/
しょいんぼん /初印本/
しょう /賞/将/商/小/少/称/証/症/章/省/相/抄/性;懲り性/笙;(邦楽器)/簫;(中国などの管楽器)/鉦;かね/頌;称える歌/昭;昭和/升;10合/床/匠;楽匠/勝/笑/庄;庄屋/粧;化粧/償;弁償/詳;詳細/祥;吉祥/荘;荘園/装;衣装/爿;(しょうへん)/牀;≒床/妝/蒋;蒋介石/醤;醤油/奨;推奨/奬;「奨」の旧字(人名用漢字)/獎;「奨」の旧字2/將;「将」の旧字(人名用漢字)/漿;血漿/鏘/廠;(壁のない建物)工廠/厰;「廠」の異体字/敞;(ひろい)/囁;ささや・く/懾;(おそれる)/顳;(こめかみ)/妾;妾腹/霎;(小雨)/衝;衝撃/鍾;鍾馗/牆;かき/墻;「牆」の異体字/檣;ほばしら/艢;=檣/薔;薔薇/焦;焦点/樵;きこり/礁;座礁/蕉;芭蕉/憔;憔悴/彰;表彰/樟;くすのき/障;障害/嶂/璋/瘴/昌;昌運/唱;唱歌/娼;娼婦/菖;菖蒲/倡/猖;猖獗/晶;結晶/橸;まさ/召;召喚/招;招待/沼;湖沼/照;照明/紹;紹介/詔;詔勅/劭/邵/韶/哨;哨戒/宵;(よい)春宵/梢;末梢/消;消滅/硝;硝酸/肖;肖像/鞘;(さや)腱鞘炎/蛸;たこ/峭;(けわしい)峻峭/悄;悄然/稍;やや/誚;(そしる)/逍;逍遥/銷;≒消/霄;(そら)/嘗;(な・める)臥薪嘗胆/甞;「嘗」の異体字/掌;車掌/裳;衣裳/嘯;うそぶ・く/瀟;瀟洒/蕭;蕭々/松;松竹/枩;「松」の異体字/訟;訴訟/淞;(中国の河川名)/鬆;す/焼;焼却/燒;「焼」の旧字(人名用漢字)/従;したが・う/樅;もみ/聳;そび・える/傷;傷害/慯/殤/觴;濫觴/鐘;かね/憧;あこが・れる/翔;飛翔/慴/摺;す・る/悚/竦;すく・む/炒;いた・める/鈔;≒抄/湘;湘南/廂;ひさし/鍬;くわ/愀/湫;くて/尚;高尚/承;承知/捷;敏捷/昇;上昇/陞;≒昇/渉;交渉/椒;山椒/誦;諳誦/咲;さ・く/篠;しの/筱;「篠」の異体字/秤;はかり/剿;(殺す)/燮/庠;(学校)/浹/舂;うす/餉;かれいい/鷦;鷦鷯(みそさざい)/證;「証」の旧字/稱;「称」の旧字/象;現象/橡;くぬぎ/腫;(漢音) 腫瘍/上;(漢音)上人/愴;(呉音) 悲愴/井;(呉音)/声;(呉音)声明/聲;「声」の旧字/猩;猩猩/姓;(呉音)/星;(呉音)/生;(呉音)/正;(呉音)正気/政;(呉音)/青;(呉音)/清;(呉音)/精;(呉音)/錆;(呉音)/鯖;(呉音)/
しょう# /小#0/小#2/
しょう> /小;†(small) 小休止,小アジア/省;省エネ,省資源,省スペース/少;†(few) 少人数,少産少死/正;正二位/
しょうあい /鍾愛/
しょうあく /掌握/性悪/小悪/
しょうあくせつ /性悪説/
しょうあじあ /小アジア;地名,Asia Minor/
しょうあつ /昇圧/
しょうあつざい /昇圧剤;[医]vasopressor/
しょうあん /正安;年号(1299-1302)/承安;年号(1171-1175)/硝安/
しょうい /少尉/小異/傷痍;-軍人/焼夷;-弾/
しょういいんかい /小委員会/
しょういぐんじん /傷痍軍人/
しょういだん /焼夷弾/燒夷彈;旧字/
しょういち /正一/昭一/昌一/彰一/昇一/祥一/章一/庄一/省一/昭市/小一/小１/小1/
しょういちろう /正一郎/昭一郎/
しょういん /勝因/証印/松蔭/正院/小引/承引/小飲/
しょういんこうこう /松蔭高校/
しょういんしん /小陰唇/
しょうう /小雨;こさめ/少雨;高温-/生有/請雨/
しょううちゅう /小宇宙/
しょううん /勝運/昌運/
しょうえ /庄衛/
しょうえい /頌栄/昭栄/庄栄/昌栄/庄衛/
しょうえいしゃ /翔泳社;[企業名]www.shoeisha.co.jp/
しょうえいじょしがくいん /頌栄女子学院/
しょうえき /漿液/省益;[新語](国益でなく)省庁の利益/昌益/小駅/
しょうえきち /承役地/
しょうえね /省エネ/
しょうえねせい /省エネ性/
しょうえねるぎー /省エネルギー;energy conservation. 省エネ/
しょうえん /消炎/荘園/小園/硝煙/小宴/小円;[数学]small circle/庄園;=荘園/招宴/鞘炎/瘴煙/
しょうえんざい /消炎剤/
しょうえんじ /生臙脂/
しょうえんだんう /硝煙弾雨/
しょうえんちんつうさよう /消炎鎮痛作用/
しょうえんはんのう /硝煙反応/
しょうお /尚夫/
しょうおう /照応/勝央/承応;年号(1652-1655)/正応;年号(1288-1293)/商鞅/蕉翁/
しょうおく /小屋/
しょうおん /消音/昇温/
しょうおんき /消音器/
しょうおんそうち /消音装置/
しょうおんりょう /小音量/
しょうか /消化;†digest.「食物の-」/消火;†extinguish.「-活動」/唱歌/昇華/商家;商人の家/商科;商業科/頌歌;ode/硝化;nitrify/小花/小家/娼家/正嘉;年号(1257-1259)/小過;小さな過ち/消夏/銷夏;=消夏/漿果;=液果/証果;[仏教]/昌華;店名/小舸/
しょうかい /紹介/照会/商会/詳解/哨戒/小海/
しょうかいいがい /紹介以外/
しょうかいかいいん /紹介会員/
しょうかいき /哨戒機/
しょうかいきじ /紹介記事/
しょうかいぎ /小会議/
しょうかいぎしつ /小会議室/
しょうかいけっか /照会結果/
しょうかいさき /照会先/紹介先/
しょうかいしゃ /紹介者/照会者/
しょうかいしょ /紹介書/
しょうかいしんご /捷解新語/
しょうかいじょ /紹介所/
しょうかいじょう /紹介状/
しょうかいせき /蒋介石/
しょうかいそしき /紹介組織/
しょうかいぞう /小改造/
しょうかいちゅう /照会中/
しょうかいてい /哨戒艇/
しょうかいていど /紹介程度/
しょうかいは /小会派/
しょうかいばんぐみ /紹介番組/
しょうかいぶん /紹介文/紹介分;†「前回の-」/
しょうかいぼん /紹介本/
しょうかいや /紹介屋/
しょうかいらん /紹介欄/
しょうかいりょう /紹介料/
しょうかいわく /紹介枠/
しょうかえき /消化液/
しょうかかつどう /消火活動/
しょうかかん /消化管/
しょうかがた /昇華型/
しょうかき /消化器;†胃腸/消火器;†火を消す/小火器;small arms/
しょうかきか /消化器科/
しょうかきかん /消化器官/
しょうかく /昇格/翔鶴/衝角/省画/
しょうかくご /昇格後/
しょうかくしゃ /昇格者/
しょうかくもんだい /昇格問題/
しょうかこう /松花江;地名,(Songhua Jiang)/
しょうかこうそ /消化酵素/
しょうかざい /消火剤/
しょうかしあいすう /消化試合数/
しょうかじあい /消化試合/
しょうかせいかいよう /消化性潰瘍/
しょうかせつび /消火設備/
しょうかせん /消火栓;fireplug/消化腺;digestive gland/松果腺;[解剖]conarium/
しょうかそんじゅく /松下村塾/
しょうかぞく /小家族/
しょうかたい /松果体/
しょうかっこ /小括弧/（/）/
しょうかどう /松花堂;松花堂弁当/
しょうかどうべんとう /松花堂弁当/
しょうかねつ /昇華熱/
しょうかふりょう /消化不良/
しょうかぶ /正株/
しょうかへい /小花柄/
しょうかぼう /裳華房;[出版社名]/
しょうかりつ /消化率/
しょうかりょく /消化力/
しょうかわ /荘川/
しょうかん /償還;†redeem.「国債の-」/召喚;†呼び出す。「証人の-」/召還;†呼び戻す。「大使の-」/商館;trading house/娼館;whore house/将官/小寒;[二十四節気]1.6頃/小官/小缶/荘官/招喚;†招き呼ぶ/消閑;killing time/松幹/小閑/少閑;=小閑/
しょうかんかぶしき /償還株式/
しょうかんきじつ /償還期日/
しょうかんさえき /償還差益/
しょうかんしゃ /召喚者/
しょうかんしゅう /商慣習/
しょうかんしゅうほう /商慣習法/
しょうかんじゅもん /召喚呪文/
しょうかんじょう /召喚状/
しょうかんねんすう /償還年数/
しょうかんろん /傷寒論;漢方のバイブル/
しょうが /生姜/唱歌;邦楽の-/小我/小雅;詩経の-/生薑;(本来の字)/薑/
しょうがい /障害;†obstacle.「-物」「-者」/生涯/傷害;†injury.「-罪」/渉外/障碍;≒障害/障礙;≒障害/生害;kill/
しょうがいがくしゅう /生涯学習/
しょうがいきょういく /生涯教育/
しょうがいきょうそう /障害競走/
しょうがいげんえき /生涯現役/
しょうがいざい /傷害罪/
しょうがいしゃ /障害者/障碍者/
しょうがいしゃうんどう /障害者運動/
しょうがいしゃきほんほう /障害者基本法/
しょうがいしゃきょういく /障害者教育/
しょうがいしゃさべつ /障害者差別/
しょうがいしゃてちょう /障害者手帳/
しょうがいしゃふくし /障害者福祉/
しょうがいしゃもんだい /障害者問題/
しょうがいしゅうひ /傷害周皮/
しょうがいじ /障害児/障害時/
しょうがいじきょういく /障害児教育/
しょうがいじしせつ /障害児施設/
しょうがいせいせき /生涯成績/
しょうがいたいさく /障害対策/
しょうがいたんとう /渉外担当/
しょうがいだりつ /生涯打率/
しょうがいちし /傷害致死/
しょうがいちしざい /傷害致死罪/
しょうがいちょうさ /障害調査/
しょうがいどくしん /生涯独身/
しょうがいねんきん /障害年金/
しょうがいば /障害馬/
しょうがいぶい /障害部位/
しょうがいぶつ /障害物/
しょうがいぶつきょうそう /障害物競争/
しょうがいほけん /傷害保険/障害保険/
しょうがく /小学/少額/奨学/小額;≒少額/商学/正覚/
しょうがくかん /小学館/
しょうがくきふきん /奨学寄付金/
しょうがくきん /奨学金/
しょうがくけっさい /少額決済/
しょうがくせい /小学生/奨学生/
しょうがくせいいか /小学生以下/
しょうがくせいじだい /小学生時代/
しょうがくせいじぶん /小学生時分/
しょうがくせいだんし /小学生男子/
しょうがくせいていがくねん /小学生低学年/
しょうがくせいみまん /小学生未満/
しょうがくせいやく /小学生役/
しょうがくせいよう /小学生用/
しょうがくそしょう /少額訴訟/
しょうがくぶ /小学部/商学部/
しょうがくろくねんせい /小学六年生/
しょうがじる /生姜汁/
しょうがっかん /小学館/
しょうがっかんけい /小学館系/
しょうがっかんそうしょ /小学館叢書/
しょうがっかんはっこう /小学館発行/
しょうがっこう /小学校/
しょうがっこうきょうし /小学校教師/
しょうがっこうこうがくねん /小学校高学年/
しょうがっこうじだい /小学校時代/
しょうがっこうだんかい /小学校段階/
しょうがっこうていがくねん /小学校低学年/
しょうがつ /正月/
しょうがついらい /正月以来/
しょうがつきせい /正月帰省/
しょうがつきぶん /正月気分/
しょうがつこうかい /正月公開/
しょうがつことば /正月言葉/
しょうがつそうそう /正月早々/
しょうがつちゅう /正月中/
しょうがつばん /正月版/
しょうがつばんぐみ /正月番組/
しょうがつまえ /正月前/
しょうがつやすみ /正月休み/
しょうがつよう /正月用/
しょうがつりょうり /正月料理/
しょうがみそ /生姜味噌/
しょうがもく /ショウガ目/Musales/Zingiberales/Scitamineae/
しょうがやき /生姜焼き/生姜焼/
しょうがゆ /生姜湯/
しょうがわ /庄川/
しょうがん /賞翫/賞玩/
しょうき /正気/勝機/瘴気/笑気;N2O/商機/正機;悪人-/鍾馗/小器/詳記/将器/匠気/焼燬/
しょうきぎょう /小企業/
しょうきく /松菊;-猶存す/
しょうきち /小吉;おみくじ/正吉/昭吉/
しょうきぼ /小規模/
しょうきゃく /焼却;†burn.「ゴミの-」/償却;†depreciate.「減価-」/消却;†cancel.「株式-」/正客/
しょうきゃくきかん /償却期間/
しょうきゃくきげん /償却期限/
しょうきゃくしょぶん /焼却処分/
しょうきゃくしょり /焼却処理/
しょうきゃくじょ /焼却所/
しょうきゃくじょう /焼却場/
しょうきゃくひ /償却費/
しょうきゃくりつ /償却率/
しょうきゃくろ /焼却炉/
しょうきゅう /昇給;†pay rise/昇級;†promotion/承久;年号(1219-1222)/小球/
しょうきゅうし /小休止/小臼歯/
しょうきゅうしけん /昇級試験/
しょうきゅうしょうだん /昇級昇段/
しょうきょ /消去/
しょうきょう /正慶;年号(1332-1334)/商況/小凶/
しょうきょうと /小京都/
しょうきょうれんごう /勝共連合/
しょうきょく /消極/小曲/唱曲/
しょうきょくさく /消極策/
しょうきょくざいさん /消極財産/
しょうきょくしせい /消極姿勢/
しょうきょくしゅう /小曲集/
しょうきょくせい /消極性/
しょうきょくてき /消極的/
しょうきょくてきさんせい /消極的賛成/
しょうきょくてきはんたい /消極的反対/
しょうきょくてきりゆう /消極的理由/
しょうきょほう /消去法/
しょうきん /賞金/正金/償金;†compensation/渉禽/
しょうきんおう /賞金王/
しょうきんかせぎ /賞金稼ぎ/
しょうきんくび /賞金首/
しょうきんじょおう /賞金女王/
しょうきんそうがく /賞金総額/
しょうきんてき /賞金的/
しょうきんぶそく /賞金不足/
しょうぎ /将棋/商議/省議/床几;stool/娼妓/象棋;=将棋/小義;⇔大義/勝義/牀几;=床几/
しょうぎいご /将棋囲碁/
しょうぎかい /将棋界/
しょうぎかいかん /将棋会館/
しょうぎかんけい /将棋関係/
しょうぎきょうかい /将棋協会/
しょうぎさし /将棋指し;proxy/
しょうぎし /将棋史/
しょうぎしなん /将棋指南/
しょうぎせかい /将棋世界;[雑誌名]/
しょうぎせんしゅけん /将棋選手権/
しょうぎたいきょく /将棋対局/
しょうぎだおし /将棋倒し/
しょうぎどうじょう /将棋道場/
しょうぎばん /将棋盤/将棋板;(折り畳みの?)/
しょうぎぶ /将棋部/
しょうぎまつり /将棋祭/
しょうぎょ /椒魚/松魚/
しょうぎょう /商業/聖教;[仏教]釈迦の教え/
しょうぎょうか /商業科;†「高校の-」/商業化;†commercialise.「新技術の-」/
しょうぎょうかいぎしょ /商業会議所/
しょうぎょうがっこう /商業学校/
しょうぎょうぎんこう /商業銀行/
しょうぎょうけい /商業系/
しょうぎょうこうこう /商業高校/
しょうぎょうこうとうがっこう /商業高等学校/
しょうぎょうこく /商業国/
しょうぎょうさくひん /商業作品/
しょうぎょうし /商業誌/
しょうぎょうしせつ /商業施設/
しょうぎょうしほん /商業資本;commercial capital/
しょうぎょうしゅぎ /商業主義;commercialism/
しょうぎょうしゅぎてき /商業主義的/
しょうぎょうしょうけん /商業証券/
しょうぎょうしんよう /商業信用/
しょうぎょうじょう /商業上/
しょうぎょうせいひん /商業製品/
しょうぎょうせん /商業船/
しょうぎょうたんこうぼん /商業単行本/
しょうぎょうち /商業地/商業値/
しょうぎょうちいき /商業地域/
しょうぎょうちく /商業地区/
しょうぎょうちょうぼ /商業帳簿/
しょうぎょうてがた /商業手形;commercial bill/
しょうぎょうてき /商業的/
しょうぎょうてきりえき /商業的利益/
しょうぎょうとうき /商業登記/
しょうぎょうとうきぼ /商業登記簿/
しょうぎょうとし /商業都市/
しょうぎょうどうとく /商業道徳/
しょうぎょうびじゅつ /商業美術;commercial art/
しょうぎょうびる /商業ビル/
しょうぎょうぶん /商業文/
しょうぎょうぶんや /商業分野/
しょうぎょうぼき /商業簿記;commercial bookkeeping/
しょうぎょうもくてき /商業目的/
しょうぎょうよう /商業用/
しょうぎょうりよう /商業利用/
しょうぎょうれつ /小行列/
しょうぎょうれつしき /小行列式/
しょうぎようご /将棋用語/
しょうぎれんめい /将棋連盟/
しょうぎん /商銀/
しょうぎんが /小銀河/
しょうく /章句/小躯/
しょうくうかん /商空間/小空間/
しょうくうとう /照空灯;searchlight/
しょうくかく /小区画/
しょうくかん /小区間/
しょうぐん /将軍/小郡/
しょうぐんけ /将軍家/
しょうぐんしょく /将軍職/
しょうぐんづか /将軍塚/
しょうけい /小計/承継/小径/憧憬/象形/小景/晶系/鐘形/正慶/昌慶/勝景/小憩/小経/捷径/上卿/尚絅/祥啓/少憩/小慧/紹継/祥慶/少頃/松径/商計/小逕/捷勁/
しょうけいしゅとく /承継取得/
しょうけいもじ /象形文字/
しょうけつ /焼結/猖獗;rage.「-を極める」/燒結;「焼」旧字/
しょうけん /証券/商圏/正絹/小見/正見/商権/證券;異体字/
しょうけんか /証券化/
しょうけんかい /証券界/
しょうけんがいしゃ /証券会社/
しょうけんがいしゃきんむ /証券会社勤務/
しょうけんきんゆうかいしゃ /証券金融会社/
しょうけんぎょうかい /証券業界/
しょうけんぎょうむ /証券業務/
しょうけんしじょう /証券市場/
しょうけんしゅうしつ /小研修室/
しょうけんとうし /証券投資/
しょうけんとうししんたく /証券投資信託/
しょうけんとりひきいいんかい /証券取引委員会/
しょうけんとりひきじょ /証券取引所/
しょうけんとりひきとうかんしいいんかい /証券取引等監視委員会/
しょうけんとりひきほう /証券取引法/
しょうけんろう /笑犬楼/笑犬樓/
しょうげ /障碍/障礙/
しょうげき /衝撃/笑劇/小隙/
しょうげきおん /衝撃音/
しょうげききゅうしゅうざい /衝撃吸収材/
しょうげききゅうしゅうりつ /衝撃吸収率/
しょうげきじょう /小劇場/
しょうげきせい /衝撃性/
しょうげきそうおん /衝撃騒音/
しょうげきてき /衝撃的/
しょうげきは /衝撃波/
しょうげん /証言/将監/象限/正元;年号(1259-1260)/承元;年号(1207-1211)/詳言/
しょうげんきょぜつけん /証言拒絶権/
しょうげんしゃ /証言者/
しょうげんしゅう /証言集/
しょうげんないよう /証言内容/
しょうげんりょく /証言力/
しょうこ /証拠/尚古/称呼;読み方/鉦鼓/小戸/商賈/商估/祥子;人名/翔子/聖子/尚子/晶子/昌子/章子/荘子/昌己/しょう子/省子/抄子/宵子/證拠;「証」異体字/
しょうこあつめ /証拠集め/
しょうこいんめつ /証拠隠滅/証拠湮滅/
しょうこう /商工/昇降/将校/小康/焼香/症候/商高;[略語]商業高校/紹興/消光/商港/小考;my thought/小稿;my text/少考;(碁などで)⇔長考/召公/昇汞;HgCl2/消耗/焼光/小功/昭晃/照校/銷耗/
しょうこうい /商行為/
しょうこうかい /商工会/
しょうこうかいぎしょ /商工会議所/
しょうこうき /昇降機/
しょうこうぎょう /商工業/
しょうこうぎょうしゃ /商工業者/
しょうこうくみあい /商工組合;trade association. 「○○県電機-,-中央金庫,-法」/
しょうこうくみあいちゅうおうきんこ /商工組合中央金庫;www.shokochukin.go.jp/
しょうこうぐち /昇降口/
しょうこうぐん /症候群/
しょうこうけい /小口径/
しょうこうざ /小講座/
しょうこうし /小公子/
しょうこうしき /昇降式/
しょうこうしゅ /紹興酒/
しょうこうじょ /小公女/
しょうこうじょうたい /小康状態/
しょうこうすい /昇汞水/
しょうこうだ /昇降舵/
しょうこうだい /焼香台/
しょうこうだいじん /商工大臣/
しょうこうつうしょう /昭光通商;[企業名]/
しょうこうてん /昇交点/
しょうこうてんのう /称光天皇/
しょうこうどう /昭晃堂/
しょうこうねつ /猩紅熱/
しょうこうひ /商工費/
しょうこうほ /賞候補/
しょうこうもく /小項目/
しょうこうろーん /商工ローン/
しょうこうろう /小紅楼/
しょうこかいじ /証拠開示/
しょうこかくほ /証拠確保/
しょうこきん /証拠金/
しょうこく /小国;small country/相国;宰相/生国;mother country/
しょうこくみん /少国民/小国民;=少国民/
しょうこさいばんしゅぎ /証拠裁判主義/
しょうこしゃしん /証拠写真/
しょうこしゅうしゅう /証拠収集/
しょうこしょるい /証拠書類/
しょうこしらべ /証拠調べ/
しょうこじょう /証拠上/
しょうこつ /踵骨/掌骨/
しょうこのうりょく /証拠能力/
しょうこふじゅうぶん /証拠不十分/
しょうこぶっけん /証拠物件/
しょうこぶつ /証拠物/
しょうこほう /証拠法/
しょうこほうほう /証拠方法/
しょうこほぜん /証拠保全/
しょうこり /性懲り/
しょうこりょく /証拠力/
しょうこん /商魂/傷痕/性根/招魂/
しょうこんさい /招魂祭/
しょうこんしゃ /招魂社/
しょうご /正午/証悟;[仏教]/省吾;人名/正吾/祥吾/昭吾/翔吾/昌吾/祥悟/尚五/小五/小５/小5/小語/笑語/
しょうごいん /聖護院/
しょうごう /称号;title/商号;trade name/照合;match/正業;[仏教]/稱號;「号」旧字/
しょうごういん /照合印/
しょうごうけっか /照合結果/
しょうごうさくせん /捷号作戰;「戦」旧字/
しょうごうしゃ /照合者/
しょうごうじ /照合時/
しょうごうじかん /照合時間/
しょうごうせいど /照合精度/
しょうごうぶ /照合部/
しょうごうぶん /照合文/
しょうごうほう /照合法/
しょうごうよう /照合用/
しょうごうりつ /照合率/
しょうごく /小国/生国/
しょうごげんざい /正午現在/
しょうごはつ /正午発/
しょうごひっちゃく /正午必着/
しょうごまで /正午迄/
しょうごん /荘厳/
しょうさ /少佐/証左/照査/小差/
しょうさい /詳細/商才/省際/小才/小祭/
しょうさいか /詳細化/
しょうさいけんさく /詳細検索/
しょうさいけんとう /詳細検討/
しょうさいことう /小柴胡湯;[漢方]/
しょうさいじょうほう /詳細情報/
しょうさいず /詳細図/
しょうさいずめん /詳細図面/
しょうさいせっけい /詳細設計/
しょうさいせってい /詳細設定/
しょうさいばん /詳細版/
しょうさいふめい /詳細不明/
しょうさいみてい /詳細未定/
しょうさかん /小属/
しょうさく /小策/昇作/
しょうさっし /小冊子/
しょうさつ /省察/笑殺/小冊/
しょうさん /賞賛/小３/小3/硝酸;HNO3/称賛;≒賞賛/勝算/小三/消散/賞讃/少産;-多死/
しょうさんえん /硝酸塩/
しょうさんぎん /硝酸銀/
しょうさんげん /小三元;[麻雀]/
しょうさんしょうし /少産少死/
しょうざい /小罪/商材/
しょうざき /庄崎/
しょうざっし /小雑誌/
しょうざぶろう /正三郎/
しょうざんかん /勝山館/
しょうし /証紙/焼死/少子/笑止/小史/生死/硝子/尚志/将士/省資/抄紙/尚士/賞詞/少死/昇志/賞賜/小詩/頌詩/少史;[律令制]主典(さかん)/
しょうしか /少子化/
しょうしかん /尚志館/
しょうしげん /省資源/
しょうしこうれいか /少子高齢化/
しょうしせんばん /笑止千万/
しょうしたい /硝子体;[解剖](眼球の)corpus vitreum/焼死体;burned body/
しょうしつ /消失/焼失/銷失/
しょうしつせん /消失線/
しょうしつてん /消失点/
しょうしみん /小市民/
しょうしみんてき /小市民的/
しょうしもく /鞘翅目;[生物]beeltes/
しょうしゃ /商社/勝者/照射/小社/瀟洒/傷者/哨舎/抄写/
しょうしゃいん /商社員/
しょうしゃかく /照射角/
しょうしゃく /焼灼/小尺/
しょうしゃご /照射後/
しょうしゃごしけん /照射後試験/
しょうしゃしょくひん /照射食品/
しょうしゃせんりょう /照射線量/
しょうしゃはんい /照射範囲/
しょうしゃめん /照射面/
しょうしゃめんせき /照射面積/
しょうしゃよう /照射用/
しょうしゃりょう /照射量/
しょうしゅ /漿酒/
しょうしゅう /消臭/招集;†「会議の-」(NB:地方議会や株主総会は原則としてこちら)/召集;†「-令状」「国会の-」(NB:国会と兵士は必ずこちら)/
しょうしゅうかん /商習慣/
しょうしゅうごう /商集合/
しょうしゅうざい /消臭剤/
しょうしゅうせい /小修正/
しょうしゅうだん /小集団/
しょうしゅうれい /召集令/
しょうしゅうれいじょう /召集令状/
しょうしゅくしゃく /小縮尺/
しょうしゅつ /抄出/晶出;crystallisation/
しょうしゅん /頌春/
しょうしょ /証書/詔書;みことのり/尚書;(官名)/小暑;[二十四節気]7.8頃/哨所;sentinel post/鈔書/抄書/召書/
しょうしょう /少々/少将/小小/小々;サイズは大,中,小,-/小将;地名/少少/蕭蕭;風-/蕭々/晶晶/将相/小照/瀟湘/少小;年少/悄悄;しょんぼり/悄々/昭昭;明白/章章;明白/彰彰;明白/昌昌;盛ん/小祥;一周忌/商聖/小升/省掌/鏘鏘/蕭牆/小哨/詔召/悚悚/
しょうしょう> /少々/
しょうしょかしつけ /証書貸付;loan on deed. 借用証書を取る融資/
しょうしょく /小食/少食;=小食/小職/粧飾/
しょうしょしょう /尚書省/
しょうしょたい /小所帯/
しょうしん /昇進/傷心/小心/正真/焼身/小身/焦心/衝心/
しょうしんげ /正信偈;浄土宗/
しょうしんさいん /賞審査員/
しょうしんしょうめい /正真正銘/
しょうしんじさつ /焼身自殺/
しょうしんぷく /小振幅/
しょうしんまえ /昇進前/
しょうしんもの /小心者/
しょうしんもんだい /昇進問題/
しょうしんよく /昇進欲/
しょうしんよくよく /小心翼翼/小心翼々/
しょうじ /商事/障子/正時;0分0秒ちょうどを表す時刻。毎正時/消磁;degauss/小路/生死;-即涅槃/小児;(しょうに?)/精進;=しょうじん/小字/小事/少時/尚侍/頌辞/賞辞/庄司/正治;年号(1199-1201)/昭二/東海林/正二/昭治/章二/荘司/昭次/昌二/庄子/正次/尚史/昇司/章司/昭司/勝治/将司/昇治/尚司/昇二/祥治/彰治/捷二/祥之/
しょうじがいしゃ /商事会社/
しょうじがみ /障子紙/
しょうじき /正直/
しょうじきぎょうしゃ /正直業者;?/
しょうじきもの /正直者/
しょうじこ /精進湖/
しょうじそくねはん /生死即涅槃/
しょうじつ /消日/
しょうじてん /小辞典/小事典/
しょうじばいばい /商事売買/
しょうじま /生島/
しょうじゃ /生者/精舎/盛者/
しょうじゃく /正雀/小弱/
しょうじゅ /松樹/聖衆/
しょうじゅう /小銃/聖衆/小獣/
しょうじゅしょうしゃ /賞受賞者/
しょうじゅつ /詳述/賞恤/
しょうじゅつきん /賞恤金/
しょうじゅん /昇順/照準/
しょうじゅんがんきょう /照準眼鏡/
しょうじゅんき /照準器/
しょうじゅんてん /照準点/
しょうじょ /少女/消除/翔女/小序/
しょうじょあい /少女愛/
しょうじょあにめ /少女アニメ/
しょうじょう /症状/賞状/小乗/掌状/掌上/猩々;orangutan/猩猩/清浄/商状/蕭条/招状/霄壌/
しょうじょうけいげん /症状軽減/
しょうじょうさいげん /症状再現/
しょうじょうせぜ /生生世世/生々世々/
しょうじょうひ /猩々緋/
しょうじょうふくよう /掌状複葉/
しょうじょうぶっきょう /小乗仏教/
しょうじょうみゃく /掌状脈/
しょうじょうるてん /生生流転/生々流転/
しょうじょかしゅ /少女歌手/
しょうじょざっし /少女雑誌/
しょうじょし /少女誌/
しょうじょしゅみ /少女趣味/
しょうじょしょうせつ /少女小説/
しょうじょたい /少女隊/
しょうじょたち /少女達/
しょうじょぶもん /少女部門/
しょうじょまんが /少女漫画/少女マンガ/
しょうじょまんがか /少女漫画家/
しょうじょまんがざっし /少女漫画雑誌/
しょうじょまんがし /少女漫画誌/
しょうじろう /象二郎/正次郎/彰二郎/章治郎/
しょうじん /精進/小人/消尽/焼尽/生身/
しょうじんあげ /精進揚/精進揚げ/
しょうじんおとし /精進落とし/精進落し/
しょうじんけっさい /精進潔斎/
しょうじんしょう /小人症;[医]/
しょうじんび /精進日/
しょうじんぶつ /小人物/
しょうじんりょうり /精進料理/
しょうすい /憔悴/小水/松翠/将帥/消衰/少水/
しょうすう /少数;†few/小数;†0.01/勝数/
しょうすう> /少数/
しょうすういけん /少数意見/
しょうすうかぶぬしけん /少数株主権/
しょうすうがわ /小数側/
しょうすうしい /小四喜/
しょうすうしゃ /少数者/
しょうすうせいえい /少数精鋭/
しょうすうせいえいしゅぎ /少数精鋭主義/
しょうすうてん /小数点/
しょうすうてんいか /小数点以下/
しょうすうてんすう /小数点数/
しょうすうとう /少数党/
しょうすうにんずう /少数人数/
しょうすうは /少数派/
しょうすうひょうじ /小数表示/
しょうすうぶ /小数部/
しょうすうぶぶん /小数部分/
しょうすうみんぞく /少数民族/
しょうすけ /庄助/正助/昭助/
しょうず /小豆/
しょうずい /祥瑞/
しょうせい /小生/焼成/招請/笑声/将星;-隕つ/小成/照星;銃の照準器/勝勢/称制/
しょうせいこん /招婿婚/
しょうせいりょく /小勢力/
しょうせき /証跡/硝石;saltpetre/鐘石;(楽器)/
しょうせきのうほうしょう /掌蹠膿疱症/
しょうせっかい /消石灰/
しょうせつ /小説;novel/小節;[音楽]measure/詳説/小雪;[二十四節気]11.23頃/消雪/章節/
しょうせつか /小説家/小説化/
しょうせつげんだい /小説現代/
しょうせつざっし /小説雑誌/
しょうせつし /小説誌/
しょうせつしんずい /小説神髄;(1885-86)坪内逍遥/
しょうせつせん /小節線/
しょうせつちゅう /小説中/
しょうせつない /小説内/
しょうせつばん /小説版/
しょうせつぶん /小節分/
しょうせつぼん /小説本/
しょうせつめ /小節目/
しょうせん /商戦;sales battle.「年末-」/商船;merchant ship.「-隊」/省線/
しょうせんきょう /昇仙峡/
しょうせんきょく /小選挙区/
しょうせんきょくせい /小選挙区制/
しょうせんきょくひれいだいひょうへいりつせい /小選挙区比例代表並立制/
しょうせんこうせん /商船高専/
しょうせんだい /商船大/
しょうせんだいがく /商船大学/
しょうせんでんしゃ /省線電車/
しょうぜつ /勝絶/
しょうぜん /承前/悄然;しょんぼり/小善;⇔大善|小悪/性善;[仏教]本性としての善/蕭然;寂しい/悚然;ぞっとする/竦然;=悚然/小全;[造語]小さな「大全」/哨然;?/
しょうぜんてい /小前提/
しょうそ /勝訴/
しょうそう /焦燥/尚早/少壮/焦躁;=焦燥/傷愴/悄愴/
しょうそういん /正倉院/
しょうそういんもんじょ /正倉院文書/
しょうそうかん /焦燥感/
しょうそく /消息/
しょうそくすじ /消息筋/
しょうそくつう /消息通/
しょうそくふめい /消息不明/
しょうそつ /将卒/小卒/
しょうそん /焼損/
しょうぞう /肖像/省三/昭三/正三/正蔵/尚三/勝三/彰三/捷三/省造/正像;[仏教]正法と像法/小像/
しょうぞういん /正倉院/
しょうぞうが /肖像画/
しょうぞうがてん /肖像画展/
しょうぞうけん /肖像権/
しょうぞうしゅう /肖像集/
しょうぞく /装束/
しょうた /翔太/正太/章太/
しょうたい /正体/招待/小隊/小体/消退/昌泰;年号(898-901)/商体/請待/
しょうたいきゃく /招待客/
しょうたいけん /招待券/
しょうたいこうえん /招待講演/
しょうたいこうえんしゃ /招待講演者/
しょうたいしゃ /招待者/
しょうたいじょう /招待状/
しょうたいせんしゅ /招待選手/
しょうたいちょう /小隊長/
しょうたいにゅうじょうけん /招待入場券/
しょうたいば /招待馬/
しょうたいび /招待日/
しょうたいふめい /正体不明/
しょうたいりょこう /招待旅行/
しょうたく /沼沢/妾宅/
しょうたろう /正太郎/章太郎/昭太郎/承太郎/
しょうたん /賞嘆/
しょうたんい /章単位/
しょうだ /正田/庄田/掌打/
しょうだい /招提;[仏教]寺院/商大;[略語]商科大学,商業大学/章題;chapter title/唱題;[仏教]/昌代;繁栄の時代/小代/正代/昭代;太平の時代/掌大/
しょうだいやき /小代焼/小岱焼;=小代焼/
しょうだく /承諾/
しょうだくいん /承諾印/
しょうだくけん /承諾権/
しょうだくしょ /承諾書/
しょうだくじょうけん /承諾条件/
しょうだて /章立て/
しょうだん /商談/昇段/笑談/
しょうだんかい /商談会/
しょうだんせいりつ /商談成立/
しょうだんせいりつご /商談成立後/
しょうだんちゅう /商談中/
しょうち /承知/招致/勝地/小知/召致/
しょうちうんどう /招致運動/
しょうちく /松竹/小竹;尺八/
しょうちくばい /松竹梅/
しょうちのすけ /承知の助;ガッテン-/
しょうちゃんぼう /正ちゃん帽/
しょうちゅう /小中/焼酎/正中;年号(1324-1326)/掌中/
しょうちゅうがく /小中学/
しょうちゅうがくせい /小中学生/
しょうちゅうがくせいじだい /小中学生時代/
しょうちゅうがくせいむけ /小中学生向け/
しょうちゅうがっこう /小中学校/
しょうちゅうこう /小中高/
しょうちょ /小著/
しょうちょう /象徴/省庁/小腸/消長/正長;年号(1428-1429)/省疔;?/
しょうちょうかい /象徴界;[精医]le symbolique/
しょうちょうし /象徴詩/
しょうちょうしゅぎ /象徴主義/
しょうちょうじょうひ /小腸上皮/
しょうちょうせい /象徴性/
しょうちょうてき /象徴的/
しょうちょうてんのう /象徴天皇/
しょうちょうてんのうせい /象徴天皇制/
しょうちょうは /象徴派;[文学]les symbolistes. Verlaine,Mallarmeなど/
しょうちょく /詔勅/
しょうちん /消沈/銷沈/
しょうつき /祥月/
しょうつきめいにち /祥月命日/
しょうてい /掌底/小弟/小亭/
しょうていぎょくはく /鐘鼎玉帛;豪華な宴会/
しょうていぼく /小低木/
しょうていり /小定理/
しょうてき /小敵/
しょうてきほう /小滴法/
しょうてすと /小テスト/
しょうてつものがたり /正徹物語/
しょうてん /商店/焦点/昇天/笑点;[固有名詞]番組名/聖天/小店/小篆/衝天/消点;vanishing point/声点/
しょうてんいどう /焦点移動/
しょうてんか /焦点化/
しょうてんかい /商店会/
しょうてんがい /商店街/
しょうてんきょり /焦点距離/
しょうてんしゅ /商店主/
しょうてんしんど /焦点深度/
しょうてんせつ /昇天節/
しょうてんはんい /焦点範囲/
しょうでん /小伝/昇殿/省電;[略語]省電力・省線電車/詳伝/昭電/小電/召電/招電/
しょうでんしゃ /祥伝社;[出版社名]www.shodensha.co.jp/
しょうでんりょく /省電力/小電力/
しょうでんりょくがた /小電力型/
しょうでんりょくきのう /省電力機能/
しょうと /省都;provincial capital/商都;mercantile city/
しょうとう /消灯/小刀/松濤;地名/消燈;「灯」異体字/鐘塔/檣頭/昇騰/
しょうとうきょう /小東京/
しょうとうしょう /小頭症;[医]/
しょうとうじかん /消灯時間/
しょうとうすう /小頭数/
しょうとうるい /少糖類;=オリゴ糖,⇔多糖類/
しょうとく /聖徳/正徳;年号(1711-1716)/生得/承徳;年号(1097-1099)/称徳/
しょうとくがくえん /聖徳学園/
しょうとくしゅう /小特集/
しょうとくたいし /聖徳太子/
しょうとくてんのう /称徳天皇/
しょうとつ /衝突/
しょうとついち /衝突位置/
しょうとつおん /衝突音/
しょうとつかく /衝突核/
しょうとつこん /衝突痕/
しょうとつご /衝突後/
しょうとつじ /衝突時/
しょうとつじこ /衝突事故/
しょうとつじっけん /衝突実験/
しょうとつてん /衝突点/
しょうとつはんてい /衝突判定/
しょうとつまえ /衝突前/
しょうとつみつど /衝突密度/
しょうとつりつ /衝突率/
しょうとり /商取;商品取引/証取/
しょうとりひき /商取引/
しょうとりほう /証取法/
しょうど /照度/焦土;施設・家屋を焼き払う。「-戦術」/焼土;農地を焼いて改良する/
しょうどう /衝動/正道/唱導;唱え導く/唱道;先に立ち唱える (NB:「道」=「言う」)/小道/聖道/晶洞/章動/聳動/
しょうどううり /衝動売り/
しょうどうがい /衝動買い/
しょうどうせい /衝動性/
しょうどうてき /衝動的/
しょうどうとく /商道徳/
しょうどうぶつ /小動物/
しょうどうもん /聖道門/
しょうどく /消毒/誦読;=読誦/
しょうどくかい /抄読会/
しょうどくき /消毒器/
しょうどくやく /消毒薬/
しょうどくよう /消毒用/
しょうどけい /照度計/
しょうどさ /照度差/
しょうどしま /小豆島/
しょうどじま /小豆島/
しょうどせんじゅつ /焦土戦術/焦土戰術;「戦」旧字/
しょうどちょうせい /照度調整/
しょうどぶんぷ /照度分布/
しょうない /庄内/省内/荘内/渉内/
しょうなごん /少納言/
しょうなり /≦/＜/小なり/
しょうなん /湘南/沼南/小難/
しょうなんこうこう /湘南高校/
しょうなんしょく /湘南色/
しょうなんだい /湘南台/
しょうなんだいえき /湘南台駅/
しょうなんちく /湘南地区/
しょうなんちほう /湘南地方/
しょうなんでんし /湘南電子/
しょうなんでんしゃ /湘南電車/
しょうなんふじさわ /湘南藤沢/
しょうに /小児/小二/小２/小2/少弐/
しょうにか /小児科/
しょうにかい /小児科医/
しょうにがん /小児癌/小児がん/小児ガン/
しょうにき /小児期/
しょうにく /正肉/
しょうにげか /小児外科/
しょうにぜんそく /小児喘息/
しょうにびょう /小児病/
しょうにびょうてき /小児病的/
しょうにまひ /小児麻痺/
しょうにゅう /鍾乳/
しょうにゅうせき /鍾乳石/
しょうにゅうたい /鍾乳体/
しょうにゅうどう /鍾乳洞/鐘乳洞/
しょうにん /承認/商人/証人/上人/聖人/昇任/小人/
しょうにんかんもん /証人喚問/
しょうにんご /承認後/
しょうにんじ /承認時/
しょうにんずう /少人数/
しょうにんずうがっきゅう /少人数学級/
しょうにんだい /証人台/
しょうにんとうひょう /承認投票/
しょうにんばんごう /承認番号/
しょうね /性根/
しょうねつ /焦熱/
しょうねつじごく /焦熱地獄/
しょうねん /少年/生年/正念/
しょうねんあい /少年愛/
しょうねんいん /少年院/
しょうねんかんべつしょ /少年鑑別所/
しょうねんがっしょうだん /少年合唱団/
しょうねんがほうしゃ /少年画報社/
しょうねんけいむしょ /少年刑務所/
しょうねんし /少年誌/
しょうねんしょうじょ /少年少女/
しょうねんしんぱん /少年審判/
しょうねんじ /少年時/
しょうねんじだい /少年時代/
しょうねんたい /少年隊/
しょうねんたち /少年達/
しょうねんたんていだん /少年探偵団/
しょうねんだん /少年団/
しょうねんはんざい /少年犯罪/
しょうねんば /正念場/
しょうねんばん /少年版/
しょうねんひこう /少年非行/
しょうねんぴ /省燃費/
しょうねんぶもん /少年部門/
しょうねんほう /少年法/
しょうねんほごし /少年保護司/
しょうねんまんが /少年漫画/少年マンガ/
しょうねんまんがし /少年漫画誌/
しょうねんもの /少年物/
しょうねんやく /少年役/
しょうの /庄野/笙野/
しょうのう /小脳/樟脳;camphor/小農/笑納/
しょうのうひしつ /小脳皮質/
しょうのすけ /庄之助/
しょうは /消波/小破/
しょうはい /勝敗/賞牌/賞杯/少牌/招牌/
しょうはいきりょう /小排気量/
しょうはいすう /勝敗数/
しょうはいひょう /勝敗表/
しょうはく /松柏;常緑樹。貞操/蕭白/
しょうはさん /小破産/
しょうはち /正八/
しょうはぶろっく /消波ブロック;防波堤の/
しょうはん /小藩/
しょうばい /商売/
しょうばいおんな /商売女/
しょうばいがたき /商売敵/
しょうばいがら /商売柄/
しょうばいぎ /商売気/
しょうばいじょう /商売上/
しょうばいじょうず /商売上手/
しょうばいどうぐ /商売道具/
しょうばいにん /商売人/
しょうばいはんじょう /商売繁盛/
しょうばいひん /商売品/
しょうばいほうほう /商売方法/
しょうばいもの /商売物/
しょうばいや /商売屋/
しょうばたけ /正畠/
しょうばつ /賞罰/
しょうばら /庄原/
しょうばらし /庄原市/
しょうばん /床板;=床版/床版/相伴/承盤/
しょうばんごう /章番号/
しょうひ /消費/
しょうひかつどう /消費活動/
しょうひかんすう /消費関数;[経済]consumption function/
しょうひがく /消費額/
しょうひきげん /消費期限/
しょうひきたく /消費寄託/
しょうひけいかく /消費計画/
しょうひけいたい /消費形態/
しょうひこく /消費国/
しょうひざい /消費財/
しょうひししゅつ /消費支出/
しょうひしゃ /消費者/
しょうひしゃうんどう /消費者運動/
しょうひしゃかい /消費社会;societe de consommation(Baudrillard)/
しょうひしゃかかく /消費者価格/
しょうひしゃきんゆう /消費者金融/
しょうひしゃけいやくほう /消費者契約法/
しょうひしゃせんたー /消費者センター/
しょうひしゃそうだん /消費者相談/
しょうひしゃだんたい /消費者団体/
しょうひしゃふたん /消費者負担/
しょうひしゃぶっかしすう /消費者物価指数/
しょうひしゃほご /消費者保護/
しょうひしゃほごきほんほう /消費者保護基本法/
しょうひせいかつ /消費生活/
しょうひせいこう /消費性向/
しょうひぜい /消費税/
しょうひぜいこみ /消費税込/
しょうひぜいどうにゅう /消費税導入/
しょうひぜいぬき /消費税抜き/
しょうひぜいぶん /消費税分/
しょうひぜいべつ /消費税別/
しょうひぜいほう /消費税法/
しょうひぜいりつ /消費税率/
しょうひぜんたい /消費全体/
しょうひたいしゃく /消費貸借/
しょうひち /消費地/
しょうひちょちくこうどう /消費貯蓄行動/
しょうひつ /省筆/
しょうひでんりゅう /消費電流/
しょうひでんりょく /消費電力/
しょうひほうほう /消費方法/
しょうひゃっか /小百科/
しょうひょう /商標/証票;voucher/証憑;evidence/賞表;praise/
しょうひょうけん /商標権/
しょうひょうとうろく /商標登録/
しょうひょうほう /商標法/
しょうひょうめい /商標名/
しょうひりつ /消費率/
しょうひりょう /消費量/
しょうひん /商品/賞品/小品/
しょうひんか /商品化/
しょうひんかいはつ /商品開発/
しょうひんかいはつか /商品開発課/
しょうひんかいはつしつ /商品開発室/
しょうひんかいはつぶ /商品開発部/
しょうひんかかく /商品価格/
しょうひんかけん /商品化権/
しょうひんかち /商品価値/
しょうひんきかく /商品企画/
しょうひんぐん /商品群/
しょうひんけいざい /商品経済/
しょうひんけん /商品券/
しょうひんこうせい /商品構成/
しょうひんさきものとりひき /商品先物取引/
しょうひんさくもつ /商品作物/
しょうひんしじょう /商品市場/
しょうひんしゅう /小品集/
しょうひんじぎょうぶ /商品事業部/
しょうひんじょうほう /商品情報/
しょうひんせい /商品性/
しょうひんせっけい /商品設計/
しょうひんせつめい /商品説明/
しょうひんそうこ /商品倉庫/
しょうひんちしき /商品知識/
しょうひんていど /商品程度/
しょうひんとりひきじょ /商品取引所/
しょうひんはつばい /商品発売/
しょうひんはんばい /商品販売/
しょうひんばん /商品版/
しょうひんばんごう /商品番号/
しょうひんばんづけ /商品番付/
しょうひんめい /商品名/
しょうひんれい /商品例/
しょうび /焦眉/賞美/薔薇;rose/
しょうびすい /薔薇水;rosewater/
しょうびのきゅう /焦眉の急/
しょうびょう /傷病/
しょうびょうへい /傷病兵/
しょうびん /翡翠/小瓶/
しょうふ /娼婦/
しょうふう /蕉風/
しょうふうろうげつ /嘯風弄月/
しょうふく /招福/承服/小幅/妾腹/承伏/慴伏/
しょうふくてい /笑福亭/
しょうふくていつるこう /笑福亭鶴光/
しょうふだ /正札/
しょうぶ /勝負/正夫/菖蒲/尚武/
しょうぶいろ /菖蒲色/
しょうぶうん /勝負運/
しょうぶえん /菖蒲園/
しょうぶかん /勝負勘/
しょうぶけい /勝負型/
しょうぶこんじょう /勝負根性/
しょうぶごと /勝負事/
しょうぶざけ /菖蒲酒/
しょうぶし /勝負師/
しょうぶしたぎ /勝負下着/
しょうぶたい /小部隊/
しょうぶつ /生仏/正物/
しょうぶて /勝負手/
しょうぶどころ /勝負所/
しょうぶなし /勝負無し;draw/
しょうぶぱんつ /勝負パンツ/
しょうぶふく /勝負服/
しょうぶぶん /小部分/
しょうぶもん /小部門/
しょうぶゆ /菖蒲湯/
しょうぶろん /勝負論/
しょうぶん /性分/小文/昌文/
しょうぶんかん /松文館/
しょうぶんしゃ /昭文社;[出版社名]地図。www.mapple.co.jp/晶文社;[出版社名]文学・芸術書。www.shobunsha.co.jp/
しょうぶんせつ /小文節/
しょうぶんるい /小分類/
しょうへい /招聘/昌平/正平;年号(1346-1370)/昇平/将兵/昭平/省平/小兵/笑瓶/章平/承平;年号(931-938)/傷兵/哨兵/招へい;招聘/
しょうへいが /障屏画/
しょうへいこう /昌平黌/
しょうへいじょう /招聘状/
しょうへいもと /招聘元/
しょうへき /障壁/晶癖;[化学]crystal habit/牆壁/墻壁/
しょうへきが /障壁画;障屏画と壁画/
しょうへん /小片/掌編/小編/小変;small change/掌篇/小篇/爿偏;[部首]/
しょうへんこう /小変更/
しょうへんせい /小編成/
しょうべつ /小別/
しょうべん /小便/少弁/
しょうべんき /小便器/
しょうべんこぞう /小便小僧/
しょうほーる /小ホール/
しょうほう /商法/詳報/正保;年号(1644-48)/唱法/小胞/承保;年号(1074-1077)/勝報/捷報/
しょうほうじ /正法地;人名/
しょうほうたい /小胞体/
しょうほうてい /小法廷/
しょうほうてん /商法典/
しょうほく /勝北/
しょうほん /抄本;abstract.「戸籍-」/正本;original/小本;small book/証本;拠り所となる本/
しょうぼ /召募/
しょうぼう /消防/正法/小房/焼亡/
しょうぼうえんきょう /小望遠鏡/
しょうぼうかん /消防官/
しょうぼうし /消防士/
しょうぼうしせつ /消防施設/
しょうぼうしゃ /消防車/
しょうぼうしょ /消防署/
しょうぼうしょいん /消防署員/
しょうぼうじ /正法寺/
しょうぼうたい /消防隊/
しょうぼうたいいん /消防隊員/
しょうぼうだん /消防団/
しょうぼうちょう /消防庁/消防長/
しょうぼうてい /消防艇;海の消防車/
しょうぼうひ /消防費/
しょうぼうほう /消防法/
しょうま /消磨/
しょうまく /漿膜/
しょうまつ /章末/
しょうまる /正丸/
しょうまん /小満;[二十四節気]5.21頃/正満;人名/
しょうみ /賞味/正味/
しょうみ> /正味;-資産,-財産,-200g/
しょうみきかん /賞味期間/
しょうみきげん /賞味期限/
しょうみざいさん /正味財産/
しょうみじかん /正味時間/
しょうみつ /詳密/
しょうみゃく /小脈/
しょうみょう /声明/小名/称名/唱名/
しょうみょうじ /称名寺;横浜市/
しょうむ /商務/
しょうむしょう /商務省/
しょうむてんのう /聖武天皇/
しょうめい /証明/照明/召命/章名/鐘銘/正銘/證明;「証」旧字/
しょうめいおわり /証明終/
しょうめいかのう /証明可能/
しょうめいかのうせい /証明可能性/
しょうめいかんきょう /証明環境/
しょうめいき /証明器/証明機/
しょうめいきぐ /照明器具/
しょうめいぎ /証明木/
しょうめいけい /証明系/
しょうめいけんしょう /証明検証/
しょうめいこう /証明項/
しょうめいさくせい /証明作成/
しょうめいしすてむ /証明システム/
しょうめいしゃ /証明者/
しょうめいしゃしん /証明写真/
しょうめいしょ /証明書/
しょうめいしょう /証明証/
しょうめいしょはっこう /証明書発行/
しょうめいしょるい /証明書類/
しょうめいず /証明図/
しょうめいせつび /照明設備/
しょうめいせんりゃく /証明戦略/
しょうめいだん /照明弾/
しょうめいちゅう /証明中/
しょうめいてつづき /証明手続き/
しょうめいとう /照明灯/照明燈/
しょうめいふかのう /証明不可能/
しょうめいほう /証明法/
しょうめいほうしき /証明方式/
しょうめいほうほう /証明方法/
しょうめいもんだい /証明問題/
しょうめいよう /照明用/証明用/
しょうめいりょく /証明力/
しょうめいりろん /証明理論/
しょうめいれい /証明例/
しょうめいろん /証明論/
しょうめつ /消滅/生滅;[仏教]/
しょうめつご /消滅後/
しょうめつし /消滅子/
しょうめつしょり /消滅処理/
しょうめつじこう /消滅時効/
しょうめつせん /消滅線/
しょうめん /正面/小面;facet/生面;?/
しょうめんきって /正面切って/
しょうめんぐち /正面口/
しょうめんげんかん /正面玄関/
しょうめんしゃしん /正面写真/
しょうめんしょうとつ /正面衝突/
しょうめんぞう /正面像/
しょうめんちゅうしゃじょう /正面駐車場/
しょうめんとっぱ /正面突破/
しょうめんほうこう /正面方向/
しょうめんまど /正面窓/
しょうもう /消耗/睫毛/
しょうもうせん /消耗戦/
しょうもうど /消耗度/
しょうもうひん /消耗品/
しょうもうひんかんけい /消耗品関係/
しょうもうひんだい /消耗品代/
しょうもうひんひ /消耗品費/
しょうもくひょう /小目標/
しょうもくろく /小目録/
しょうもつ /抄物/
しょうもの /抄物/
しょうもん /証文/正文/声聞/小問/蕉門;芭蕉の門下/掌紋/
しょうもんき /将門記/
しょうもんだい /小問題/
しょうや /庄屋/
しょうやく /生薬/抄訳/小役/硝薬/
しょうやま /庄山/正山/
しょうゆ /醤油/
しょうゆあじ /醤油味/
しょうゆいため /醤油炒め/
しょうゆう /少輔/小勇/
しょうゆがお /醤油顔/
しょうゆさし /醤油差し/
しょうゆづけ /醤油漬/
しょうゆらーめん /醤油ラーメン/
しょうよ /賞与/
しょうよう /商用/小用/逍遥/称揚/照葉/小葉/慫慂;recommend/従容;calm/賞揚;prise/賞用;賞めて用いる/縦容;=従容/
しょうようか /商用化/
しょうようがくは /逍遥学派;アリストテレス学派/
しょうようき /商用機/
しょうようこうりゅう /商用交流/
しょうようしゃ /商用車/
しょうようじゅ /照葉樹/
しょうようじゅりん /照葉樹林/
しょうようせいひん /商用製品/
しょうようてき /商用的/
しょうようでんりょく /商用電力/
しょうようびざ /商用ビザ/
しょうようぶん /商用文/
しょうようぶんや /商用分野/
しょうようめい /商用名/
しょうようもくてき /商用目的/
しょうようりょう /小容量/
しょうよきん /賞与金/
しょうよく /小欲/
しょうよくちそく /小欲知足/
しょうよひきあてきん /賞与引当金/
しょうよん /小四/小４/小4/
しょうら /初裏;[俳諧]/
しょうらい /将来/生来/招来/松籟/請来/
しょうらいけいかく /将来計画/
しょうらいけいかくいいんかい /将来計画委員会/
しょうらいこうそう /将来構想/
しょうらいせい /将来性/
しょうらいぞう /将来像/
しょうらいてき /将来的/
しょうらいてんぼう /将来展望/
しょうらいよそく /将来予測/
しょうらん /笑覧/照覧/
しょうり /勝利/掌理/小利/捷利/小吏/
しょうりき /正力;姓/
しょうりしゃ /勝利者/
しょうりじょうけん /勝利条件/
しょうりすう /勝利数/
しょうりせんげん /勝利宣言/
しょうりだてん /勝利打点/
しょうりつ /勝率/聳立/
しょうりとうしゅ /勝利投手/
しょうりゃく /省略/正暦;年号(990-995)/承暦;年号(1077-1081)/商略/
しょうりゃくか /省略可/
しょうりゃくかのう /省略可能/
しょうりゃくきごう /省略記号/
しょうりゃくけい /省略形/
しょうりゃくじ /省略時/
しょうりゃくじかいしゃく /省略時解釈/
しょうりゃくち /省略値/
しょうりゃくほう /省略法;[修辞]elliptic/
しょうりゃくめい /省略名/
しょうりゅう /昇龍/昇竜/小流/
しょうりゅうぎょ /昇流魚/
しょうりゅうけん /昇竜拳/昇龍拳/
しょうりょ /焦慮/
しょうりょう /少量/小量;-な人物/渉猟/松陵/精霊;[仏教]死者の霊/聖霊;=精霊/商量/将領/
しょうりょういき /小領域/
しょうりょうえ /聖霊会/
しょうりょうか /少量化/
しょうりょうせいさん /少量生産/
しょうりょうだな /精霊棚/
しょうりょうながし /精霊流し/
しょうりょうぶね /精霊舟;精霊流しの舟/
しょうりょく /省力/
しょうりょくか /省力化/
しょうりょこう /小旅行/
しょうりん /松林/少林/
しょうりんじ /少林寺;-拳法/
しょうりんじけんぽう /少林寺拳法/
しょうるい /生類/
しょうるいあわれみのれい /生類憐みの令;[日本史]/
しょうれい /症例/奨励/省令/瘴癘;マラリアなど/勝令/
しょうれいかい /奨励会/
しょうれいかいいん /奨励会員/
しょうれいきん /奨励金/
しょうれいけんきゅう /奨励研究/
しょうれいしょう /奨励賞/
しょうれいせいど /奨励制度/
しょうれんげ /青蓮華/
しょうろ /松露/捷路/
しょうろう /鐘楼/精霊/
しょうろうびょうし /生老病死/
しょうろく /抄録/小禄;安月給/詳録/小六/小６/小6/
しょうろっぽう /小六法/
しょうろん /小論/詳論/
しょうろんぶん /小論文/
しょうろんぶんていしゅつ /小論文提出/
しょうろんぽう /小籠包/
しょうわ /昭和;年号(1926-1989)/正和;年号(1312-1317)/小話/庄和/唱和/笑話/承和;年号(834-848)/倡和/
しょうわ#ねん /昭和#0年/昭和#1年/昭和#2年/昭和#3年/
しょうわかようし /昭和歌謡史/
しょうわき /昭和期/
しょうわきち /昭和基地/
しょうわきねんこうえん /昭和記念公園/
しょうわく /昭和区/
しょうわくせい /小惑星/
しょうわけんぽう /昭和憲法/
しょうわこうこう /昭和高校/
しょうわさんぎょう /昭和産業;[企業名]/
しょうわさんじゅうねんだい /昭和三十年代/
しょうわし /昭和史/
しょうわしぇるせきゆ /昭和シェル石油;[企業名]/
しょうわしょき /昭和初期/
しょうわしょねん /昭和初年/
しょうわしんざん /昭和新山/
しょうわじょし /昭和女子/
しょうわじょしだい /昭和女子大/
しょうわせきゆ /昭和石油;[企業名]/
しょうわちょう /昭和町/
しょうわてんのう /昭和天皇/
しょうわでんこう /昭和電工;[企業名]/
しょうわどう /昭和堂/
しょうわびょういん /昭和病院/
しょうわり /章割り/
しょうわる /性悪/
しょうわん /小彎/
しょえ /初会/所依;[仏教]拠り所/
しょえん /初演/所縁;[仏教]ゆかり/諸縁;[仏教]諸々のゆかり/
しょえんしゃ /初演者/
しょえんじ /初演時/
しょおう /諸王/
しょおく /書屋/
しょおもて /初表;[俳諧]/
しょおり /初折;[俳諧]/
しょか /初夏/書架/書家/諸家/
しょかい /初回/初会/所懐/所懷/
しょかいしゃけん /初回車検/
しょかいとくてん /初回特典/
しょかいにゅうきん /初回入金/
しょかいひ /諸会費/
しょかいぶん /初回分/
しょかつ /所轄/諸葛/
しょかついん /所轄員/
しょかつこうめい /諸葛孔明;三国時代・蜀漢の丞相/
しょかつどう /諸活動/
しょかつりょう /諸葛亮;三国時代・蜀漢の丞相/
しょかてい /諸過程/
しょかん /所管/書簡/所感/書館/書翰/初刊/書巻/初巻/初寒/書函/
しょかん> /所管/
しょかんけい /諸関係/
しょかんけいしゃ /諸関係者/
しょかんしゅう /書簡集/
しょかんしょうちょう /所管省庁/
しょかんせん /書簡箋/
しょかんたいしょうせつ /書簡体小説/
しょかんちょう /所管庁/
しょかんばこ /書簡箱/
しょかんぶん /書簡文/
しょが /書画/
しょがい /所外/書外/
しょがいこく /諸外国/
しょがいねん /諸概念/
しょがかり /諸掛/諸掛り/
しょがく /諸学/初学/所学/
しょがくしゃ /初学者/
しょがこっとう /書画骨董/
しょがん /所願/
しょき /初期/書記/所期;expected.「-の目的」/書紀;日本書紀/暑気/所記;[言語]signifie/書櫃/
しょき> /初期;-投資,-費用,-症状/
しょきあたり /暑気中り/
しょきいち /初期位置/
しょきか /初期化/
しょきかかんすう /初期化関数/
しょきかご /初期化後/
しょきかしょり /初期化処理/
しょきかじ /初期化時/
しょきかぶ /初期化部/
しょきかん /諸機関/書記官/
しょきかんきょう /初期環境/
しょきかんすう /初期関数/
しょきかんちょう /書記官鳥/
しょきがた /初期型/
しょきがめん /初期画面/
しょききょく /書記局/
しょきけい /初期型/
しょきこうてい /初期工程/
しょきさくひん /初期作品/
しょきしゃ /初期車/
しょきしゅっか /初期出荷/
しょきしゅっかばん /初期出荷版/
しょきしょうじょう /初期症状/
しょきじゅうでん /初期充電/
しょきじょうけん /初期条件/
しょきじょうたい /初期状態/
しょきじょうほう /初期情報/
しょきせい /書記生/
しょきせってい /初期設定/
しょきせっていち /初期設定値/
しょきそ /書記素;grapheme/
しょきそく /諸規則/
しょきたんぺんしゅう /初期短編集/
しょきだんかい /初期段階/
しょきち /初期値/
しょきちょう /書記長/
しょきてい /諸規定/
しょきとうし /初期投資/
しょきとうしがく /初期投資額/
しょきとうろく /初期登録/
しょきのう /諸機能/
しょきはいち /初期配置/
しょきはんしゃ /初期反射/
しょきはんしゃおん /初期反射音/
しょきばらい /暑気払い/
しょきひよう /初期費用/
しょきふりょう /初期不良/
しょきゅう /初級/初球/初給/雎鳩/書笈/
しょきゅううち /初球打ち/
しょきゅうき /初級機/
しょきゅうしゃ /初級者/
しょきゅうしゃよう /初級者用/
しょきゅうへん /初級編/
しょきょう /書経/
しょぎ /所議/
しょぎしょ /枌所/
しょぎじゅつ /諸技術/
しょぎょう /所業/諸行/所行/
しょぎょうおうじょう /諸行往生/
しょぎょうむじょう /諸行無常/
しょく /食/職/色/初句/蜀;中国の地名・国名。四川省/触;抵触/觸;「触」の旧字/蝕;日蝕/属;(漢音)属託(=嘱託)/屬;「属」の旧字/嘱;属託/囑;「嘱」の旧字/燭;燭台/矚;(つける)/埴;はに/植;植物/殖;繁殖/稙;(わさだ)/拭;払拭/軾;蘇軾/禝;(五穀の神)/稷;きび/謖;馬謖/嗇;吝嗇/穡;稼穡/飾;修飾/餝;「飾」の異体字/織;製織/贖;贖罪/寔;(まことに)/昃;(かたむく)/喰;?/
しょく> /続;-古今集,-拾遺集/
しょくあたり /食中り/
しょくあつ /触圧/
しょくあん /職安/
しょくあんどおり /職安通り/
しょくい /職位/
しょくいき /職域/
しょくいく /食育/
しょくいん /職員/職印/
しょくいんかいぎ /職員会議/
しょくいんさいよう /職員採用/
しょくいんしつ /職員室/
しょくいんしゅくしゃ /職員宿舎/
しょくいんぞう /職員増/
しょくいんだんたい /職員団体/
しょくいんろく /職員録/
しょくえ /触穢/
しょくえん /食塩/食鹽/
しょくえんすい /食塩水/
しょくおや /職親/
しょくかい /職階/
しょくがい /食害/
しょくがん /食玩;[略語]食品玩具/
しょくぎょう /職業/
しょくぎょうあんていじょ /職業安定所/
しょくぎょうあんていほう /職業安定法/
しょくぎょういしき /職業意識/
しょくぎょうえんそうか /職業演奏家/
しょくぎょうか /職業科/
しょくぎょうかん /職業観/
しょくぎょうがら /職業柄/
しょくぎょうきょういく /職業教育/
しょくぎょうくんれん /職業訓練/
しょくぎょうくんれんこう /職業訓練校/
しょくぎょうくんれんだいがく /職業訓練大学/
しょくぎょうぐんじん /職業軍人/
しょくぎょうご /職業語/
しょくぎょうじょう /職業上/
しょくぎょうせんたく /職業選択/
しょくぎょうせんたくのじゆう /職業選択の自由;憲法22条/
しょくぎょうだんたい /職業団体/
しょくぎょうてき /職業的/
しょくぎょうてきせいけんさ /職業適性検査/
しょくぎょうのうりょくかいはつそうごうだいがっこう /職業能力開発総合大学校;www.uitec.ehdo.go.jp/
しょくぎょうひみつ /職業秘密/
しょくぎょうびょう /職業病/
しょくぎょうふじん /職業婦人/
しょくぎょうべつ /職業別/
しょくぎょうやきゅう /職業野球/
しょくぎょうらん /職業欄/
しょくぎょうりんり /職業倫理/
しょくぎれ /食切れ/
しょくぐん /職群/
しょくげん /食言/飾言/
しょくご /食後/
しょくごすうじかん /食後数時間/
しょくごせんわかしゅう /続後撰和歌集/
しょくさい /植栽/食彩/
しょくさいぼう /食細胞/
しょくさいりん /植栽林/
しょくさつ /喰殺/
しょくさよう /食作用/
しょくさん /殖産/
しょくさんこうぎょう /殖産興業/
しょくさんじゅうたく /殖産住宅/
しょくさんじん /蜀山人/
しょくざい /食材/贖罪/殖財/
しょくざいてん /食材店/
しょくし /食指/
しょくしつ /職質;職務質問/
しょくしないしんのう /式子内親王/
しょくしゅ /職種/触手/蝕手;?/
しょくしゅどうぶつ /触手動物/
しょくしょう /食傷/職掌/
しょくしょうがら /職掌柄/
しょくしょうぎみ /食傷気味/
しょくしん /触診/
しょくじ /食事/食餌;†diet.「-療法」/植字/
しょくじかい /食事会/
しょくじかいすう /食事回数/
しょくじきゅうけい /食事休憩/
しょくじけん /食事券/
しょくじご /食事後/
しょくじじかん /食事時間/
しょくじだい /食事代/
しょくじちゅう /食事中/
しょくじつき /食事付/
しょくじとうばん /食事当番/
しょくじどき /食事時/
しょくじひょう /食事表/
しょくじふうけい /食事風景/
しょくじゅ /植樹/
しょくじゅう /職住/
しょくじゅういったい /職住一体/
しょくじゅうせっきん /職住接近/
しょくじゅさい /植樹祭;Arbor Day/
しょくじょ /織女/
しょくじょせい /織女星/
しょくじよう /食事用/
しょくじりょうほう /食餌療法/食事療法;NB:許容されつつある表記/
しょくじん /食人/食尽/蝕甚/
しょくじんき /食人鬼/
しょくじんしゅ /食人種/
しょくす /食酢/
しょくせい /植生/食性/職制/
しょくせいかつ /食生活/
しょくせいかつかいぜん /食生活改善/
しょくせいがく /植生学/
しょくせいひょう /職制表/
しょくせいへんこう /職制変更/
しょくせき /職責/
しょくせつ /触接/
しょくせんき /食洗機;[新語][略語]食器洗い機/
しょくぜん /食前/食膳/
しょくぜんしゅ /食前酒/
しょくぜんほうじょう /食前方丈/
しょくそ /職組/
しょくそう /食草/
しょくたい /食滞/飾帯/
しょくたく /食卓/嘱託/囑託;旧字/
しょくたくい /嘱託医/
しょくたくえん /食卓塩/
しょくたくさつじん /嘱託殺人/
しょくたん /職短/
しょくだい /燭台/燭臺/
しょくち /触知/諸口/初口/
しょくちゅう /食虫/
しょくちゅうしょくぶつ /食虫植物/
しょくちゅうどく /食中毒/
しょくちゅうるい /食虫類/
しょくちょう /職長/
しょくつう /食通/
しょくてん /触点/
しょくど /埴土/
しょくどう /食堂/食道/
しょくどうえいぎょう /食堂営業/
しょくどうがん /食道癌/食道がん/食道ガン/
しょくどうけんだんわしつ /食堂兼談話室/
しょくどうしゃ /食堂車/
しょくどうへき /食道壁/
しょくどうらく /食道楽/
しょくにく /食肉/
しょくにくかこう /食肉加工/
しょくにくしょり /食肉処理/
しょくにくもく /食肉目;[生物]Carnivora/
しょくにくるい /食肉類/
しょくにほんぎ /続日本紀;697-791の歴史書。797年成立/
しょくにほんこうき /続日本後紀;833-850の歴史書。869年成立/
しょくにん /職人/
しょくにんいしき /職人意識/
しょくにんうたあわせ /職人歌合/
しょくにんかたぎ /職人気質/
しょくにんきしつ /職人気質;※「しょくにんかたぎ」が普通/
しょくにんげい /職人芸/
しょくにんだましい /職人魂/
しょくにんはだ /職人肌/
しょくにんわざ /職人技/
しょくのう /職能/色濃/
しょくのうきゅう /職能給/
しょくのうせい /職能制/
しょくのうだんたい /職能団体/
しょくはこうしゅうにあり /食在広州/
しょくはつ /触発/
しょくば /職場/
しょくばい /触媒/
しょくばいそうち /触媒装置/
しょくばいそうちゃく /触媒装着/
しょくばいどく /触媒毒;[化学]catalyst poison. 触媒を働かなくさせる物質/
しょくばかい /職場会/
しょくばかんきょう /職場環境/
しょくばない /職場内/
しょくばめい /職場名/
しょくぱん /食パン/
しょくひ /食費/植皮/
しょくひん /食品/
しょくひんうり /食品売/
しょくひんうりば /食品売場/
しょくひんえいせい /食品衛生/
しょくひんえいせいせきにんしゃ /食品衛生責任者;飲食店に一人は必要/
しょくひんえいせいほう /食品衛生法/
しょくひんかん /食品館/
しょくひんがい /食品害/
しょくひんがんぐ /食品玩具;食玩/
しょくひんぐん /食品群/
しょくひんこうぎょう /食品工業/
しょくひんせいぶんひょう /食品成分表/
しょくひんてん /食品展/
しょくひんてんかぶつ /食品添加物/
しょくひんてんかぶつこうていしょ /食品添加物公定書/
しょくひんほぞんよう /食品保存用/
しょくひんや /食品屋/
しょくひんよう /食品用/
しょくひんりゅうつう /食品流通/
しょくひんるい /食品類/
しょくふ /織布/
しょくぶつ /植物/食物/
しょくぶつえん /植物園/
しょくぶつかい /植物界/
しょくぶつがく /植物学/
しょくぶつくけい /植物区系;[生物]flora/
しょくぶつけい /植物系/
しょくぶつし /植物誌/食物誌/
しょくぶつしつ /植物質/
しょくぶつじょうたい /植物状態;-が続く/
しょくぶつずかん /植物図鑑/
しょくぶつせい /植物性/
しょくぶつせいたんぱくしつ /植物性蛋白質/
しょくぶつせいぶん /植物成分/
しょくぶつせんい /植物繊維;plant fiber. cf.化学繊維/
しょくぶつぜんたい /植物全体/
しょくぶつそう /植物相;[生物]flora/
しょくぶつたい /植物体/
しょくぶつちりがく /植物地理学;phytogeography/
しょくぶつてき /植物的/
しょくぶつにんげん /植物人間/
しょくぶつほるもん /植物ホルモン;[生物]plant hormone/
しょくぶつめい /植物名/
しょくぶつゆ /植物油/
しょくぶつゆらい /植物由来/
しょくぶん /職分/
しょくぶんか /食文化/
しょくへんこうせい /食変光星;[天文]eclipsing binary/
しょくべに /食紅/
しょくほう /触法/織豊/
しょくほうしょうねん /触法少年/
しょくほうじだい /織豊時代/
しょくぼう /嘱望/
しょくみ /食味/
しょくみん /植民/殖民/
しょくみんしゃ /植民者/
しょくみんせい /植民星/
しょくみんせいさく /植民政策/
しょくみんせん /植民船/
しょくみんち /植民地/
しょくみんちか /植民地化/
しょくみんちかいほう /植民地解放/
しょくみんちけいえい /植民地経営/
しょくみんちしはい /植民地支配/
しょくみんちしゅぎ /植民地主義/
しょくみんちてき /植民地的/
しょくみんちぶんかつ /植民地分割/
しょくみんわくせい /植民惑星/
しょくむ /職務/
しょくむきゅう /職務給/
しょくむけいれきしょ /職務経歴書/
しょくむけんげん /職務権限/
しょくむしつもん /職務質問/
しょくむじょう /職務上/
しょくむじょうさくせい /職務上作成/
しょくむすいこう /職務遂行/
しょくむたいまん /職務怠慢/
しょくむないよう /職務内容/
しょくむはつめい /職務発明/
しょくめい /職名/
しょくもう /植毛/
しょくもく /嘱目/属目;=嘱目/
しょくもつ /食物/
しょくもつせんい /食物繊維/
しょくもつちゅう /食物中/
しょくもつれんさ /食物連鎖/
しょくやすみ /食休み/
しょくゆう /贖宥/
しょくゆうじょう /贖宥状/
しょくよう /食用/
しょくようあぶら /食用油/
しょくようか /食用可/
しょくようがえる /食用蛙/
しょくようぎく /食用菊/
しょくようじょう /食養生/
しょくよく /食欲/
しょくよくいじょう /食欲異常/
しょくよくおうせい /食欲旺盛/
しょくよくげんたい /食欲減退/
しょくよくぞうしん /食欲増進/
しょくよくちゅうすう /食欲中枢/
しょくよくふしん /食欲不振/
しょくらい /触雷/
しょくりょう /食料/食糧;特に主食/
しょくりょうあんぜんほしょう /食料安全保障/食糧安全保障/
しょくりょうえんじょ /食糧援助/
しょくりょうかんりせいど /食糧管理制度/
しょくりょうかんりほう /食糧管理法/
しょくりょうきょうきゅう /食料供給/
しょくりょうじきゅうりつ /食料自給率/食糧自給率/
しょくりょうちょう /食糧庁/
しょくりょうなん /食糧難/
しょくりょうひん /食料品/食糧品/
しょくりょうひんうり /食料品売/
しょくりょうひんうりば /食料品売場/
しょくりょうひんや /食料品屋/
しょくりょうぶそく /食糧不足/
しょくりょうほう /食糧法;[法][略語]主要食糧の需給及び価格の安定に関する法律。1995年、食管法に代わり施行/
しょくりょうもんだい /食糧問題/
しょくりん /植林/
しょくるいご /触塁後/
しょくれき /職歴/
しょくれんせい /食連星;[天文]eclipsing binary/
しょくろく /食禄/
しょくわん /触腕/
しょくん /諸君/
しょぐう /処遇/諸遇;?/
しょけ /所化/
しょけい /処刑/諸兄/初経/書契/
しょけいし /諸兄姉/
しょけいだい /処刑台/
しょけいひ /諸経費/
しょけっか /諸結果/
しょけつ /処決/
しょけん /所見;opinion.「医師の-」/初見;初めて見る。「-の譜面」/諸賢/書見;reading.「-台」/
しょけんきゅうきかん /諸研究機関/
しょけんじゃ /諸賢者/
しょけんだい /書見台/
しょけんり /諸権利/
しょげい /諸芸/
しょげつ /初月/
しょげん /諸元;factors,「性能-」/緒言;introduction/初元;改元の年/初弦;-の月(=上弦)/
しょげんご /諸言語/
しょげんひょう /諸元表/
しょこ /書庫;archive/書賈;書籍商/
しょこう /諸侯;lords.領主たち/初稿/曙光/初校/諸公;ministers.高位の人達/初項/初更/
しょこうぎょう /諸工業/
しょこうじょ /諸控除/
しょこうばん /初稿版/
しょこく /諸国/初刻/
しょこくかん /諸国間/
しょこくまんゆうき /諸国漫遊記/
しょこくみん /諸国民/
しょこん /初婚/
しょご /諸語/
しょごう /初号/
しょさ /所作/
しょさい /書斎/所載/書債/
しょさいは /書斎派/
しょさく /諸作/
しょさくひん /諸作品/
しょさつ /初刷/書冊/書札/
しょさん /所産/初産/
しょさんべつ /初山別/
しょざ /初座/
しょざい /所在/
しょざいあんない /所在案内/
しょざいち /所在地/
しょざいひょう /所在表/
しょざん /諸山/初産/
しょし /書誌/諸氏/初志/書肆;bookstore/書士;司法-/諸子;-百家/庶子;⇔嫡子/所司/諸士;-法度/諸姉;ladies/書史/所思/書司;[律令制]/諸誌/書笥;本箱/
しょしかんてつ /初志貫徹/
しょしがく /書誌学/
しょしき /書式/諸式/
しょしきか /書式化/
しょしきしていし /書式指定子/
しょしきじゆう /書式自由/
しょしきせいぎょ /書式制御/
しょしきせいぎょもじ /書式制御文字/
しょしきせってい /書式設定/
しょしきどおり /書式通り/
しょしきもじれつ /書式文字列/
しょしじょうほう /書誌情報/
しょしだい /所司代/
しょしつ /書室/
しょしひゃっか /諸子百家/
しょしゃ /書写/諸社/諸車/
しょしゃきん /諸謝金/
しょしゅ /諸種/書手/
しょしゅう /所収/初秋/諸州/諸宗/
しょしゅうさ /諸収差/
しょしゅつ /初出/所出/庶出/
しょしゅつし /初出誌/
しょしゅん /初春/
しょしょ /諸処/諸所/処暑;[二十四節気]8.24頃/所々/処々/処処/諸書/
しょしょう /所掌/諸将/書証/
しょしん /初心/初診/所信;-演説/書信;letter/初審/諸臣/
しょしんかい /初心会/
しょしんしゃ /初心者/
しょしんしゃあいて /初心者相手/
しょしんしゃかんげい /初心者歓迎/
しょしんしゃきょういく /初心者教育/
しょしんしゃこうざ /初心者講座/
しょしんしゃたいさく /初心者対策/
しょしんしゃてき /初心者的/
しょしんしゃふう /初心者風/
しょしんしゃへん /初心者編/
しょしんしゃまーく /初心者マーク/
しょしんしゃむけ /初心者向け/
しょしんしゃよう /初心者用/
しょしんひょうめい /所信表明/
しょしんもの /初心者/
しょしんりょう /初診料/初診療/
しょしんわ /諸神話/
しょじ /所持/諸事/書字/
しょじきん /所持金/
しょじこう /諸事項/
しょじしゃ /所持者/
しょじしょうがい /書字障害/
しょじじょう /諸事情/
しょじにん /所持人/
しょじひん /所持品/
しょじひんけんさ /所持品検査/
しょじゃく /書籍/
しょじゃくかん /書籍館/
しょじゅん /初旬/
しょじょ /処女/
しょじょう /書状/諸嬢/
しょじょうけん /諸条件/
しょじょうやく /諸条約/
しょじょかいたい /処女懐胎/
しょじょきゅう /処女宮;[十二宮]おとめ座(8.23-9.22)/
しょじょこうかい /処女航海/
しょじょさく /処女作/
しょじょせい /処女性/
しょじょせん /処女戦/
しょじょそうしつ /処女喪失/
しょじょたんこうぼん /処女単行本/
しょじょち /処女地/
しょじょちょうへん /処女長編/
しょじょまく /処女膜/
しょじょりん /処女林/
しょじん /庶人/
しょずみ /初炭/
しょずり /初刷/
しょせい /書生/初生/諸政/処世/書聖/庶政/
しょせいかたぎ /書生気質;『当世-』/
しょせいくん /処世訓/
しょせいしつ /諸性質/
しょせいじ /初生児/
しょせいじゅつ /処世術/
しょせいど /諸制度/
しょせいぶし /書生節;(明治) 演歌のルーツ/
しょせいりょく /諸勢力/
しょせいろん /書生論/
しょせき /書籍/書跡/書蹟/
しょせきうりば /書籍売場/
しょせきかん /書籍館/
しょせきぐん /書籍群/
しょせきこづつみ /書籍小包/
しょせきだい /書籍代/
しょせきてん /書籍店/
しょせきはんばい /書籍販売/
しょせきぶ /書籍部/
しょせきへんしゅうぶ /書籍編集部/
しょせきめい /書籍名/
しょせきるい /書籍類/
しょせってい /諸設定/
しょせつ /諸説;†various views.「-がある」/所説;†one's view.「教授の-」/
しょせつび /諸設備/
しょせつふんぷん /諸説紛々/諸説紛紛/
しょせん /所詮/初戦;最初の戦い|試合/緒戦;序盤の戦い|試合/書泉/諸戦;battles/
しょせんぐらんで /書泉グランデ/
しょせんせい /諸先生/
しょせんせいがた /諸先生方/
しょせんたにん /所詮他人/
しょせんはいたい /初戦敗退/
しょせんぱい /諸先輩/
しょせんぱいがた /諸先輩方/
しょせんぶっくたわー /書泉ブックタワー/
しょせんぶっくまーと /書泉ブックマート/
しょせんむり /所詮無理/
しょぜい /諸税/
しょそう /諸相;aspects/所相;[文法]passive voice.⇔能相/書窓;書斎(の窓)/初相/
しょそく /初速/
しょそくど /初速度/
しょそん /諸尊/書損/
しょぞう /所蔵/
しょぞうしりょう /所蔵資料/
しょぞうびじゅつかん /所蔵美術館/
しょぞく /所属/
しょぞくがっかい /所属学会/
しょぞくがっかいめい /所属学会名/
しょぞくきかん /所属機関/
しょぞくきかんめい /所属機関名/
しょぞくきぎょう /所属企業/
しょぞくぎいん /所属議員/
しょぞくこうざ /所属講座/
しょぞくこく /所属国/
しょぞくさき /所属先/
しょぞくさきじゅうしょ /所属先住所/
しょぞくじむしょ /所属事務所/
しょぞくせい /所属性/
しょぞくせいとう /所属政党/
しょぞくそしき /所属組織/
しょぞくだんたい /所属団体/
しょぞくちょう /所属長/
しょぞくばしょ /所属場所/
しょぞくぶかめい /所属部課名/
しょぞくへんこう /所属変更/
しょぞくべつ /所属別/
しょぞくべや /所属部屋/
しょぞくめい /所属名/
しょぞくめいしょう /所属名称/
しょぞん /所存/
しょたい /書体/所帯/
しょたいくらぶ /書体倶楽部/
しょたいけん /初体験/
しょたいぬし /所帯主/
しょたいめん /初対面/
しょたいもち /所帯持ち/
しょだい /初代/書題/初台/
しょだいおうじゃ /初代王者/
しょだいかいちょう /初代会長/
しょだいかんじ /初代幹事/
しょだいき /初代機/
しょだいにほん /初代日本/
しょだいみょう /諸大名/
しょだち /初太刀/
しょだな /書棚/
しょだん /初段/処断/書壇/
しょだんかい /諸段階/
しょだんけい /処断刑/
しょだんたい /諸団体/
しょち /処置/書痴/
しょちあん /処置案/
しょちつ /書帙/
しょちほう /処置法/
しょちゅう /暑中;-見舞/書中;文中/
しょちゅうい /諸注意/
しょちゅうおみまい /暑中お見舞い/暑中御見舞い/
しょちゅうおみまいもうしあげます /暑中お見舞い申し上げます/
しょちゅうきゅう /初中級/
しょちゅうきゅうしゃ /初中級者/
しょちゅうとう /初・中等/初中等/
しょちゅうみまい /暑中見舞/
しょちょう /所長/署長/初潮/
しょちょうしつ /所長室/
しょちょうせん /所長選/
しょっかい /職階/
しょっかいきゅう /職階給/
しょっかいせい /職階制/
しょっかく /触覚;†touch sense/触角;†antenna.「昆虫の-」/食客;居候/
しょっかくじょうほう /触覚情報/
しょっかくてき /触覚的/
しょっかん /食感;食べた感触/触感;触れた感触/食間;食事と食事の間/食管;[略語]食糧管理/
しょっかんせいど /食管制度/
しょっかんほう /食管法;食糧管理法/
しょっき /食器/織機/
しょっきあらい /食器洗い/
しょっきあらいき /食器洗い機/
しょっきかんそうき /食器乾燥機/
しょっきすう /食器数/
しょっきせんじょうき /食器洗浄器/
しょっきだな /食器棚/
しょっきゅう /職級/触球/
しょっきよう /食器用/
しょっきようせんざい /食器用洗剤/
しょっきり /初っ切り/
しょっきるい /食器類/
しょっくし /ショック死/
しょっくりょうほう /ショック療法/
しょっけん /職権/食券/
しょっけんらんよう /職権濫用/職権乱用/
しょっこう /職工/燭光/
しょっぱな /初っ端/初端/
しょづくえ /書机/
しょて /初手/
しょてあて /諸手当/
しょてい /所定/
しょていがい /所定外/
しょていじこう /所定事項/
しょていたんい /所定単位/
しょていようし /所定用紙/
しょていらん /所定欄/
しょていり /諸定理/
しょてん /書店/諸点;points/諸天;gods/所天/
しょてんがい /書店街/
しょてんくみあい /書店組合/
しょてんめい /書店名/
しょでん /初伝/所伝/書伝/
しょとう /諸島/初頭;early/初等;elementary/初冬;early winter/蔗糖/ショ糖/初唐/書套/
しょとう> /初等;(elementary) -教育,-代数/
しょとうか /初等科/
しょとうかんすう /初等関数/
しょとうきか /初等幾何/
しょとうきょういく /初等教育/
しょとうすうがく /初等数学/
しょとうてき /初等的/
しょとうぶ /初等部/
しょとく /所得/
しょとくかくさ /所得格差/
しょとくかくし /所得隠し/
しょとくきんがく /所得金額/
しょとくこうか /所得効果/
しょとくこうじょ /所得控除/
しょとくしょうめい /所得証明/
しょとくしょうめいしょ /所得証明書/
しょとくすいじゅん /所得水準/
しょとくせい /諸特性/
しょとくせいさく /所得政策/
しょとくぜい /所得税/
しょとくぜいげんぜい /所得税減税/
しょとくぜいほう /所得税法/
しょとくぜいりつ /所得税率/
しょとくそう /所得層/
しょとくぶんぱい /所得分配;[経済]income distribution/
しょとくほしょう /所得保障/
しょとくわり /所得割;個人住民税の-,⇔均等割/
しょどう /書道/初動/諸道/所動/
しょどうか /書道家/
しょどうきょうしつ /書道教室/
しょどうぐ /諸道具/
しょどうぶ /書道部/
しょない /所内/署内/
しょなぬか /初七日/
しょなのか /初七日/
しょにち /初日/
しょにちかんばい /初日完売/
しょにちよう /初日用/
しょにゅう /初乳/
しょにん /初任/諸人/
しょにんきゅう /初任給/
しょにんしゃ /初任者/
しょにんしゃけんしゅうせいど /初任者研修制度/
しょねつ /暑熱/
しょねん /初年/
しょねんど /初年度/
しょねんどさんく /初年度産駒/
しょねんどとうろく /初年度登録/
しょのうりょく /諸能力/
しょは /諸派/
しょはつ /初発/
しょはん /初版/諸般/初犯/
しょはんはっこう /初版発行/
しょはんぼん /初版本/
しょばだい /ショバ代/
しょばつ /処罰/
しょばん /初版;しょはん/初盤/
しょひ /諸費/書皮/
しょひょう /書評/諸表/書票/
しょひょうし /書評誌/
しょひょうらん /書評欄/
しょひよう /諸費用/
しょびょう /諸病/
しょふ /書譜/
しょふう /書風/
しょふく /書幅/
しょぶっか /諸物価/
しょぶつ /諸仏/諸物/庶物;=諸物/
しょぶん /処分/
しょぶんじょう /処分場/
しょぶんたいしょう /処分対象/
しょぶんひん /処分品/
しょぶんほうほう /処分方法/
しょぶんめい /諸文明/
しょぶんや /諸分野/
しょぶんりょう /処分量/処分料/
しょへき /書癖/
しょへん /初編/所変/初篇/
しょほ /初歩/書舗/
しょほう /処方/書法/諸法;laws/諸方;here and there/
しょほうかいくう /諸法皆空/
しょほうげん /諸方言/
しょほうじっそう /諸法実相/
しょほうせん /処方箋/処方せん/
しょほうそく /諸法則/
しょほうむが /諸法無我/
しょほうりょう /処方料/
しょほてき /初歩的/
しょほてきしつもん /初歩的質問/
しょほん /諸本/
しょぼう /書房/
しょみん /庶民/
しょみんぞく /諸民族/
しょみんてき /庶民的/
しょみんは /庶民派/
しょむ /庶務/
しょむか /庶務課/
しょむかかり /庶務掛/
しょむがかり /庶務掛/
しょむぶ /庶務部/
しょめい /署名;sign/書名;title/
しょめいあつめ /署名集め/
しょめいうんどう /署名運動/
しょめいかつどう /署名活動/
しょめいきじ /署名記事/
しょめいだい /諸命題/
しょめいなついん /署名捺印/
しょめいよう /署名用/
しょめいようし /署名用紙/
しょめん /書面/
しょめんしんり /書面審理/
しょめんじょう /書面上/
しょもう /所望/
しょもく /書目/
しょもつ /書物/
しょもんだい /諸問題/
しょや /初夜/
しょやく /初訳/
しょやけん /初夜権/
しょゆう /所有/所由;よりどころ/
しょゆうかく /所有格/
しょゆうかのう /所有可能/
しょゆうけん /所有権/
しょゆうけんいてん /所有権移転/
しょゆうけんりゅうほ /所有権留保/
しょゆうしゃ /所有者;owner/所有車;my car/
しょゆうしゃめい /所有者名/
しょゆうち /所有地/
しょゆうぶつ /所有物/
しょゆうりつ /所有率/
しょよ /所与/
しょよう /所要;†required.「-時間」/所用;†affaire.「-で出掛ける」/初葉/初陽/
しょようじかん /所要時間/所用時間;?/
しょようじかんさ /所要時間差/
しょようじかんたんしゅく /所要時間短縮/
しょようにっすう /所用日数/
しょようりょう /所要量/
しょり /処理/
しょりえき /処理液/
しょりおち /処理落ち/
しょりかいろ /処理回路/
しょりかのう /処理可能/
しょりがく /処理学/
しょりき /処理機/
しょりきょか /処理許可/
しょりぎじゅつ /処理技術/
しょりけい /処理系/
しょりけいたい /処理形態/
しょりけっか /処理結果/
しょりけんきゅうぶ /処理研究部/
しょりこうがく /処理工学/
しょりこうりつ /処理効率/
しょりご /処理後/
しょりしつ /処理室/
しょりしゃ /処理者/
しょりしゅうりょうご /処理終了後/
しょりしゅほう /処理手法/
しょりしんごう /処理信号/
しょりじ /処理時/
しょりじかん /処理時間/
しょりじゅん /処理順/
しょりじょう /処理場/処理上/
しょりすい /処理水/
しょりすう /処理数/
しょりずみ /処理済み/処理済/
しょりせいのう /処理性能/
しょりそうち /処理装置/
しょりそくど /処理速度/
しょりたいしょう /処理対象/
しょりちゅう /処理中/
しょりてじゅん /処理手順/
しょりないよう /処理内容/
しょりのうりょく /処理能力/
しょりはん /処理班/
しょりひよう /処理費用/
しょりぶ /処理部/
しょりぶぶん /処理部分/
しょりほう /処理法/
しょりほうしき /処理方式/
しょりほうほう /処理方法/
しょりまえ /処理前/
しょりゅう /庶流/諸流/
しょりょう /所領/諸量/緒量/
しょりょうぶ /書陵部;宮内庁-。図書と陵墓担当/
しょりよう /処理用/
しょりりつ /処理率/
しょりりょう /処理量/
しょりろん /諸理論/
しょりん /書林/
しょるい /書類/
しょるいいっしき /書類一式/
しょるいじょう /書類上/
しょるいせんこう /書類選考/
しょるいそうけん /書類送検/
しょるいていしゅつ /書類提出/
しょるいてつづき /書類手続/書類手続き/
しょるいめい /書類名/
しょるいよう /書類用/
しょれい /書例/諸例/諸礼/
しょろう /初老/所労/
しょろん /所論;論ずるところ/緒論;はじめの論/書論/諸論;もろもろの論/
しょわけ /諸訳/
しょんずい /祥瑞/
しょんべん /小便/
しよ /施与;=せよ/賜与/
しよう /使用/仕様/試用;trial/私用;private/施用;apply/飼養/枝葉/脂溶/止揚;Aufheben/子葉/飼葉;?/
しよういき /使用域/
しよういじょう /仕様以上/
しようか /使用可/仕様化/
しようかいし /使用開始/
しようかいしご /使用開始後/
しようかいしび /使用開始日/
しようかいしまえ /使用開始前/
しようかいすう /使用回数/
しようかていしゃ /使用過程車/
しようかのう /使用可能/
しようかのうじかん /使用可能時間/
しようかん /使用感/使用艦/
しようかんきょう /使用環境/
しようがき /仕様書/
しようがっき /使用楽器/
しようき /使用記/
しようきかく /仕様規格/
しようきかん /試用期間/使用期間/使用機関/
しようきき /使用機器/
しようきげん /使用期限/
しようきしゅ /使用機種/
しようきじゅつ /仕様記述/
しようきじゅつげんご /仕様記述言語/
しようきじゅん /使用基準/
しようきせい /使用規制/
しようきょか /使用許可/
しようきょだく /使用許諾/
しようきょだくけいやく /使用許諾契約/
しようきょだくりょう /使用許諾料/
しようきんし /使用禁止/
しようくぶん /使用区分/
しようくべつ /使用区別/
しようけいけん /使用経験/
しようけいけんしゃ /使用経験者/
しようけいぞく /使用継続/
しようけいたい /使用形態/
しようけってい /仕様決定/
しようけん /使用権/
しようげんご /使用言語/
しようこうりつ /使用効率/
しようご /使用後/
しようさくせい /仕様作成/
しようさくてい /仕様策定/
しようざいりょう /使用材料/
しようしつ /使用室/
しようしゃ /使用者/仕様車/
しようしゃしゅ /使用車種/
しようしゃじしん /使用者自身/
しようしゃめい /使用者名/
しようしゃりょう /使用車両/
しようしゅうはすう /使用周波数/
しようしゅうはすうたい /使用周波数帯/
しようしょ /仕様書/
しようしょう /子葉鞘/
しようしょうめい /使用証明/
しようじ /使用時/
しようじかん /使用時間/
しようじしゅく /使用自粛/
しようじっせき /使用実績/
しようじょう /使用上/仕様上/
しようじょうきょう /使用状況/
しようじょうけん /使用条件/止揚条件/
しようすいりょう /使用水量/
しようずみ /使用済み/使用済/
しようせいげん /使用制限/
しようせっけい /仕様設計/
しようせつめいしょ /使用説明書/
しようせんく /使用線区/
しようぜん /使用前/
しようぜんご /使用前後/
しようそ /篩要素/
しようたいしゃく /使用貸借/
しようちゅう /使用中/試用中/
しようついか /仕様追加/
しようていし /使用停止/
しようてびきしょ /使用手引書/
しようでんあつ /使用電圧/
しようでんげん /使用電源/
しようでんりょく /使用電力/
しようとどけ /使用届/
しようど /使用度/
しようにん /使用人/
しようねんげつ /使用年月/
しようねんすう /使用年数/
しようのうど /使用濃度/
しようはんい /使用範囲/
しようばん /試用版/仕様盤/
しようひんど /使用頻度/
しようふか /使用不可/
しようふかのう /使用不可能/
しようふのう /使用不能/
しようぶひん /使用部品/
しようへんこう /仕様変更/使用変更;?/
しようほう /使用法/
しようほうこく /試用報告/
しようほうほう /使用方法/
しようぼ /使用簿/
しようまいすう /使用枚数/
しようまえ /使用前/
しようまっせつ /枝葉末節/
しようめん /使用面/
しようもくてき /使用目的/
しようようと /使用用途/
しようようりょう /使用容量/
しようよてい /使用予定/
しようりつ /使用率/
しようりょう /使用料;fee/使用量;usage/
しようりょうきん /使用料金/
しようれい /使用例/
しよく /私欲/
しら /白/調/
しら> /白;白糸,白和え,白葦毛/
しらあえ /白和え/
しらあわ /白泡/白沫/
しらい /白井/
しらいし /白石/
しらいた /白板/
しらいち /白市/
しらいちょう /白井町/
しらいと /白糸/
しらうお /白魚/
しらうめ /白梅/
しらうめがくえん /白梅学園/
しらえ /白江/
しらおい /白老/
しらおか /白岡/
しらかた /白方/白潟;姓/
しらかば /白樺/
しらかばこ /白樺湖/
しらかばは /白樺派/
しらかばばやし /白樺林/
しらかべ /白壁/
しらかべづくり /白壁造り;[建築]/
しらかみ /白神/
しらかみさんち /白神山地;地名,東北/
しらかゆ /白粥/
しらかわ /白川/白河/
しらかわごう /白川郷;飛騨。切妻合掌造で高名/
しらかわてんのう /白河天皇/
しらかわどおり /白川通り/
しらかわよふね /白川夜船;見たふりをすること／ぐっすり眠ること/
しらが /白髪/
しらがあたま /白髪頭/
しらがぞめ /白髪染め/白髪染/
しらがた /白潟;姓/
しらがねぎ /白髪葱/白髪ネギ/
しらがまじり /白髪交じり/
しらがみ /白神/
しらき /白木/
しらきづくり /白木造り/
しらきばる /白木原/
しらきや /白木屋/
しらぎ /新羅/
しらぎく /白菊/
しらぎぬ /白絹/
しらく /刺絡/
しらくび /白首/
しらくも /白雲;white cloud/白癬;[医]tinea/
しらくら /白倉/
しらけ /白け/
しらこ /白子/
しらこばと /白子鳩/
しらさか /白坂/
しらさき /白崎/
しらさぎ /白鷺/
しらさぎじょう /白鷺城;姫路城/
しらさや /白鞘/
しらさわ /白沢/
しらじ /白地/
しらじしきうらがき /白地式裏書/
しらじら /白々/
しらす /白子/白砂/白州/白須/白洲/
しらすな /白砂;姓/
しらすぼし /白子干し/しらす干し/
しらず /知らず/不知/
しらずしらず /知らず識らず/知らず知らず/
しらずみ /白炭/
しらせ /知らせ/報せ/白瀬/
しらた /白太/
しらたか /白鷹/
しらたき /白滝/
しらたま /白玉/白珠/
しらたまこ /白玉粉/
しらちゃ /白茶/
しらつち /白土/
しらつゆ /白露/
しらつる /白鶴/
しらと /白土/白戸/白都/
しらとり /白鳥/白取/
しらなみ /白波/白浪/
しらに /白煮/
しらぬい /不知火/
しらぬいがた /不知火型;[相撲]/
しらぬいまい /不知火舞/
しらぬいものがたり /白縫物語/白縫譚/
しらぬか /白糠/
しらぬぞんぜぬ /知らぬ存ぜぬ/
しらぬひ /不知火/
しらぬり /白塗り;銀メッキ/
しらね /白根/
しらねさん /白根山/
しらは /白羽/白刃/
しらはい /白灰/
しらはし /白橋/
しらはた /白旗/白幡/
しらはのや /白羽の矢/
しらはま /白浜/白濱/
しらはまちょう /白浜町/
しらひげ /白髭;白い口ひげ/白鬚;白い顎ひげ/
しらびょうし /白拍子/
しらふ /素面/
しらふじ /白藤/
しらべ /調べ/調/
しらべかた /調べ方/
しらべもの /調べ物/
しらほ /白保/白帆/
しらほね /白骨/
しらほねおんせん /白骨温泉/
しらみ /虱/蝨/
しらみつぶし /虱潰し/
しらみね /白峰/
しらみぼん /虱本/
しらやき /白焼/白焼き/
しらやなぎ /白柳/
しらやま /白山/
しらゆ /白湯/
しらゆき /白雪/
しらゆきひめ /白雪姫/
しらゆり /白百合/
しらゆりがくえん /白百合学園/
しらんかお /知らん顔/
しらんぷり /知らん振り/
しり /尻/私利/臀;原義:「尻」は肛門、「臀」は臀部/
しりーずもの /シリーズ物/
しりあい /知り合い/知合い/知合/
しりあがり /尻上がり/尻上り/
しりあて /尻当て/尻当/
しりあな /尻穴/
しりあるせつぞく /シリアル接続/
しりあるばんごう /シリアル番号/
しりうち /知内/
しりうま /尻馬/
しりお /尻尾/
しりおし /尻押し/
しりおも /尻重/
しりがい /鞦/
しりがる /尻軽/
しりがるおんな /尻軽女/
しりきしない /尻岸内/
しりきれ /尻切れ/
しりきれとんぼ /尻切れ蜻蛉/
しりくち /後口/尻口/
しりげ /尻毛/
しりこだま /尻子玉;河童に抜かれると死にます/
しりごみ /尻込み/しり込み/後込み/
しりさがり /尻下がり/尻下り/
しりしよく /私利私欲/
しりすぼみ /尻窄み/
しりっぺた /尻っぺた/
しりつ /私立;†(private) わたくしりつ/市立;†(city) いちりつ/
しりつ> /私立;†(private) わたくしりつ/市立;†(city) いちりつ/
しりつがっこう /私立学校/
しりつがっこうほう /私立学校法/
しりつこう /私立校/私立高/
しりつこうこう /私立高校/
しりつたんてい /私立探偵/
しりつたんていしょうせつ /私立探偵小説/
しりつだい /市立大/私立大/
しりつだいがく /私立大学/
しりつちゅう /私立中/
しりつちゅうがく /私立中学/
しりつとしょかん /市立図書館/
しりつびょういん /市立病院/
しりつぼみ /尻窄み;頭でっかち-/尻つぼみ/
しりてえき /尻手駅/
しりとり /尻取り/
しりぬぐい /尻拭い/
しりぬけ /尻抜け/
しりびと /知り人/
しりびれ /尻鰭/
しりべ /後志/
しりべし /後志/
しりべつがわ /尻別川/
しりめ /尻目/後目/
しりめつれつ /支離滅裂/
しりもち /尻餅/尻もち/尻持ち;後ろ盾/
しりゃく /史略/
しりやき /尻焼/
しりゅう /支流/緇流;僧侶仲間/
しりょ /思慮/
しりょう /資料;†data.「会議の-」/飼料;†feed.「ブタの-」/史料;†historical source.「フランス革命の-」/試料;†sample.「化学実験の-」/死霊/思料/思量/私領/
しりょうあつめ /資料集め/
しりょうえつらん /資料閲覧/
しりょうおきば /資料置場/
しりょうか /資料課/
しりょうかち /資料価値/
しりょうかん /資料館/史料館/
しりょうこ /資料庫/
しりょうさくせい /資料作成/
しりょうしつ /資料室/
しりょうしゃしん /資料写真/
しりょうしゅう /資料集/
しりょうず /指了図/
しりょうせい /資料性/
しりょうせいきゅう /資料請求/
しりょうせいり /資料整理/
しりょうだい /資料代/
しりょうだいきん /資料代金/
しりょうちゅう /資料中/
しりょうてきかち /資料的価値/
しりょうばんごう /資料番号/
しりょうひはん /史料批判/
しりょうへん /資料編/
しりょうへんさんじょ /史料編纂所;(東大内)/
しりょうめい /資料名/
しりょうよう /飼料用/
しりょうるい /資料類/
しりょく /視力/資力/死力/
しりょくかいふく /視力回復/
しりょくけんさ /視力検査/
しりょくさ /視力差/
しりょくしょうがい /視力障害/
しりょくしょうがいしゃ /視力障害者/
しりょくしょうがいしゃよう /視力障害者用/
しりょくていか /視力低下/
しりょくひょう /視力表/
しりょふんべつ /思慮分別/
しりょぶそく /思慮不足/
しりん /四隣/歯輪/
しりんだーじょう /シリンダー錠/
しる /汁/什;?/知/
しるけ /汁気/
しるけんり /知る権利/
しるこ /汁粉/
しるし /印/標/徴;effect/験;effect/首級;討ち取ったくび/首;=首級/証/誌/記/著し/
しるしばた /標旗/
しるしばんてん /印半纏/
しるとがん /シルト岩;[地質]siltstone/
しるばーせいこう /シルバー精工/
しるひと /知る人/
しるべ /標/導/
しるまし /徴/怪/
しるもの /汁物/
しるよし /知る由/
しるるき /シルル紀;[地質年代]Silurian. 4390-4085万年前/
しれい /指令;†上からの命令/司令;†軍隊などの指揮/死霊/使令;†命じて使役する/
しれいかん /司令官/指令官/
しれいき /指令器/
しれいけいとう /指令系統/
しれいち /指令値/
しれいちょうかん /司令長官/
しれいとう /司令塔/
しれいぶ /司令部/
しれいほうしき /指令方式/
しれごと /痴れ言;また-を/
しれつ /熾烈/歯列/
しれつきょうせい /歯列矯正/
しれとこ /知床/
しれとこごこ /知床五湖/
しれとことうげ /知床峠/
しれもの /痴れ者/
しれん /試練/試煉;≒試練/試錬;≒試練(?)/思恋/
しろ /白/城/代;糊代/支路;わかれみち/子路;孔子の弟子/
しろ> /白;白塗り,白ペンキ,白無垢/
しろあお /白青/
しろあと /城跡/
しろあり /白蟻/白アリ/
しろあわ /白泡/白沫/
しろあん /白餡/白あん/
しろい /白井/
しろいし /白石/
しろいと /白糸/
しろいぬ /白犬/
しろいめ /白い目/
しろいもの /白い物/
しろいろしんこく /白色申告/
しろいわ /白岩/
しろう /脂漏/屍蝋/四郎/史郎/志郎/史朗/士郎/司郎/士朗/四朗/詩郎/司朗/支朗/死狼/梔蝋/
しろうお /白魚/素魚/
しろうさぎ /白兎/
しろうず /白水/
しろうせい /脂漏性/
しろうと /素人/
しろうとかんがえ /素人考え/
しろうとげい /素人芸/
しろうとしつもん /素人質問/
しろうとしばい /素人芝居/
しろうとしゅう /素人衆/
しろうとしゅうだん /素人集団/
しろうとすじ /素人筋/
しろうとたんてい /素人探偵/
しろうとてき /素人的/
しろうとどうぜん /素人同然/
しろうとはんだん /素人判断/
しろうとばなれ /素人離れ/
しろうとみ /素人見/
しろうとむき /素人向き/素人向/
しろうとめ /素人目/
しろうとりょうり /素人料理/
しろうま /白馬/
しろうまおおいけ /白馬大池/
しろうまだけ /白馬岳/
しろうり /白瓜/
しろうんも /白雲母/
しろえび /白海老/
しろおび /白帯/
しろかき /代掻き;[農業]田植の前に水を満たし土を均すこと/
しろかぜ /城風/
しろかっこ /『/
しろかね /白金/
しろかねそうあか /シロカネソウ亜科/Isopyroideae/
しろかねだい /白金台/
しろかび /白カビ/白黴/白かび/
しろかわ /城川/
しろかん /白缶/
しろがしら /白頭/
しろがそ /白画素/
しろがね /銀/白銀/白金/
しろがねいろ /白銀色/
しろがねだい /白金台/
しろがらす /白烏/
しろき /白木/
しろきや /白木屋/
しろぎつね /白狐/
しろぎぬ /白絹/
しろく /四緑;[陰陽道]/
しろくじちゅう /四六時中/
しろくじら /白鯨/
しろくばん /四六判/
しろくび /白首/
しろくま /白熊/
しろくら /白倉/
しろくろ /白黒/
しろくろえきしょう /白黒液晶/
しろくろしゃしん /白黒写真/
しろくろはんてん /白黒反転/
しろぐつ /白靴/
しろぐみ /白組/
しろけいとう /白系統/
しろこ /白子/
しろこしょう /白胡椒;white pepper/
しろこっか /』/
しろごま /白胡麻/
しろさ /白さ/
しろさき /白崎/
しろさわ /白沢/代沢/
しろさんかく /白三角/
しろざけ /白酒/
しろざとう /白砂糖/
しろしか /白鹿/
しろした /城下/白下;白砂糖の一歩手前/
しろしたとう /白下糖/
しろしょうぞく /白装束/
しろじ /白地/白字/
しろすな /白砂/
しろず /白酢;紫蘇抜き梅酢/
しろずみ /白炭/
しろた /城田/代田/白田/
しろたえ /白妙/
しろたく /白タク;非合法のタクシー/
しろたけ /白武/
しろたなせん /白棚線/
しろたに /城谷/
しろたま /白珠/
しろだ /白田/
しろだすき /白襷/
しろだま /白玉/
しろちゃ /白茶;baicha/
しろぢ /白地/
しろつち /白土/
しろつめくさ /白詰草/
しろとり /白鳥/
しろながすくじら /白長須鯨;世界最大/
しろなまず /白癜/
しろなんばー /白ナンバー;白いナンバープレート(の自家用車)/
しろぬかちょう /白糠町/
しろぬき /白抜き/白抜/
しろぬり /白塗り/
しろね /白根/
しろねぎ /白葱/白ネギ/
しろねこ /白猫/
しろねずみ /白鼠/
しろの /城野/
しろはた /白旗/
しろばい /白バイ/
しろばかま /白袴/
しろばこ /白箱/
しろばん /白番/
しろひげ /白髭/
しろひとり /白灯蛾/
しろひょう /白票/
しろふく /白服/
しろふだや /白札屋/
しろぶさ /白房/
しろぶち /白縁/
しろへび /白蛇/
しろべえ /四郎兵衛/
しろぼし /白星/○/☆/
しろま /城間/
しろまく /白幕/
しろまじゅつ /白魔術/
しろまだら /白斑/
しろまる /白丸/○/〇;漢数字のゼロ/
しろみ /白身/城見/白み/
しろみざかな /白身魚/
しろみず /白水/
しろみそ /白味噌/
しろむく /白無垢/
しろむらさき /白紫/
しろめ /白目/白眼/
しろもじ /白文字/
しろもち /白餅/
しろもと /城本/
しろもの /代物/白物/
しろものかでん /白物家電;冷蔵庫・洗濯機など/
しろもん /白門/
しろや /城谷/
しろやなぎ /白柳/
しろやま /城山/白山/
しろやまえき /白山駅/
しろゆもじ /白湯文字/
しろれんが /白煉瓦/
しろわいん /白ワイン/
しろん /試論/史論/私論/詩論/至論/
しわ /皺/史話/詩話/私話/紫波;地名/襞/皴/
しわがれごえ /嗄れ声/
しわく /思惑;[仏教]/
しわくちゃ /皺くちゃ/
しわけ /仕訳;帳簿の-/仕分け;荷物の-/仕分/
しわけちょう /仕訳帳/
しわざ /仕業/為業;=仕業/爲業;「為」旧字/
しわしわ /皺皺/皺々/
しわす /師走;陰暦12月/
しわすぼうず /師走坊主/
しわひめ /志波姫/
しわほう /視話法/指話法/
しわよせ /皺寄せ/しわ寄せ/皴寄せ/
しわんぼう /吝ん坊;ケチ/
しをさめ /仕納め/爲納め;「為」旧字/
しをり /栞/
しん /芯;core/心;heart/臣/新/真/親/信/身/神/清;中国の王朝(1612-1912)/秦;中国の王朝(?-BC206)/晋;中国の王朝(?-BC376, 265-420, 936-946)/深/進/診/審/針/森/寝/慎;慎重/槙;まき/嗔;いか・る/瞋;いか・る/鷆;よたか/鷏;「鷆」の異体字/侵;侵略/浸;浸水/駸/辰/娠;妊娠/振;三振/賑;にぎ・わい/震;地震/宸;天子の./唇;口唇/脣;≒唇/蜃;蜃気楼/榛;はしばみ/蓁/臻;いた・る/箴;箴言/鍼;鍼灸/申;申請/伸;追伸/紳;紳士/呻;呻吟/畛;あぜ/軫/袗;ひとえ/疹;湿疹/滲;滲出/蔘;人蔘/薪;まき/辛;香辛料/矧;は・ぐ/哂;わら・う NB:「晒す」とは別/岑;みね/忱;まこと/怎;いかで/斟;斟酌/晨;あした/沁;し・みる/瀋;瀋陽/甄/簪;かんざし/縉;縉紳(=高官)/襯;襯衣(しんい,シャツ)/譖;そし・る/譛;「譖」の異体字/讖;予言/齔;歯が生え変わる/請;(唐音)/津;天津/眞;「真」の旧字(人名用漢字)/愼;「慎」の旧字(人名用漢字)/晉;「晋」の旧字/寢;「寝」の旧字(人名用漢字)/
しん> /新/真/親;(pro-) 親日,親韓/
しんあい /親愛/信愛/深愛/
しんあいなる /親愛なる/
しんあおもりえき /新青森駅/
しんあおやま /新青山/
しんあさひ /新旭/
しんあん /新案/
しんい /真意/神威/神意/心意/寝衣/瞋恚/深意/神異/神位/鍼医/身位/襯衣/
しんいいづかえき /新飯塚駅/
しんいき /神域/震域;seismic area/
しんいしかわ /新石川/
しんいそご /新磯子/
しんいたばし /新板橋/
しんいち /真一/伸一/信一/慎一/新一/進一/眞一/新市/晋一/紳一/真市/信市/申一/眞市/震一/
しんいちろう /真一郎/慎一郎/信一郎/伸一郎/眞一郎/新一郎/進一郎/辰一郎/振一朗/
しんいまみや /新今宮/
しんいも /新藷/新芋/
しんいり /新入り/
しんいん /心因/真因/神韻/
しんいんせい /心因性/
しんいんはんのう /心因反応/
しんいんひょうびょう /神韻縹渺/神韻縹緲/神韻縹眇/
しんうおのめ /新魚目/
しんうすい /新碓氷/
しんうすゆきものがたり /新薄雪物語/
しんうち /真打/真打ち/
しんうよく /新右翼/
しんうらやす /新浦安/
しんうん /進運/
しんうんちん /新運賃/
しんえい /新鋭/親衛/真影/親英/新栄/神栄/信栄/
しんえいき /新鋭機/
しんえいたい /親衛隊/
しんえいわちゅうじてん /新英和中辞典/
しんえき /新駅/
しんえきかいぎょう /新駅開業/
しんえつ /信越/親閲/
しんえつせん /信越線/
しんえつほうそう /信越放送/
しんえつほんせん /信越本線/
しんえん /深淵;abyss/深遠;profound/真円/神苑/親縁/真猿/
しんえんけい /真円形/
しんえんるい /真猿類;[生物]anthropoidea/
しんおう /震央/深奥/
しんおうきょり /震央距離/
しんおうじ /新王子/
しんおうめかいどう /新青梅街道/
しんおおくぼ /新大久保/
しんおおくぼえき /新大久保駅/
しんおおさか /新大阪/
しんおおさかえき /新大阪駅/
しんおおさかかん /新大阪間/
しんおおつか /新大塚/
しんおおつかえき /新大塚駅/
しんおおひらした /新大平下/
しんおおみや /新大宮/
しんおがわまち /新小川町/
しんおくさわ /新奥沢/
しんおのみち /新尾道/
しんおん /心音/唇音/震音/
しんおんか /唇音化;[音声学]labialisation/
しんか /進化;evolve/深化;deepen/真価/臣下/神化/神火/真果/心窩/
しんかい /深海/新開/新海/神界/新貝/神階;神様のランク/深回/
しんかいいん /新会員/
しんかいいんしょうかい /新会員紹介/
しんかいぎょ /深海魚/
しんかいじゅう /新怪獣/
しんかいそく /新快速/
しんかいそくでんしゃ /新快速電車/
しんかいたく /新開拓/
しんかいち /新開地/
しんかいてい /深海底/
しんかいてん /新開店/
しんかいはつ /新開発/
しんかいろ /新回路/
しんかかてい /進化過程/
しんかがく /新科学/
しんかがた /進化型/
しんかく /神格/真核/
しんかくか /神格化/
しんかくせいぶつ /真核生物/
しんかくとう /新格闘/
しんかけい /進化形/
しんかげりゅう /新陰流/
しんかしゃ /新華社;中国の通信社。www.xinhua.org/
しんかしょてん /新華書店/
しんかぞく /新華族/
しんかてき /進化的/
しんかてん /進化点/
しんかな /新仮名/
しんかにゅう /新加入/
しんかぶ /新株/心窩部/
しんかぶひきうけけん /新株引受権;warrant/
しんかぶひきうけけんつきしゃさい /新株引受権付社債/
しんかぶよやくけん /新株予約権;[金融]stock option/
しんかまはらえき /新蒲原駅/
しんから /心から/
しんかりょく /進化力/
しんかろん /進化論/
しんかろんてき /進化論的/
しんかわ /新川/
しんかわさき /新川崎/
しんかわさきえき /新川崎駅/
しんかわさきみつい /新川崎三井/
しんかん /新刊/新館/神官/震撼/新歓/信管/森閑/深閑;=森閑/宸翰/心肝/深感/
しんかんあんない /新刊案内/
しんかんかくは /新感覚派/
しんかんきょう /新環境/
しんかんこんぱ /新歓コンパ/
しんかんしょ /新刊書/
しんかんしょうかい /新刊紹介/
しんかんしょてん /新刊書店/
しんかんじ /新幹事/
しんかんじょうほう /新刊情報/
しんかんせん /新幹線/
しんかんせんえき /新幹線駅/
しんかんせんかいぎょうじ /新幹線開業時/
しんかんせんかいぎょうまえ /新幹線開業前/
しんかんせんかいさつ /新幹線改札/
しんかんせんかいつう /新幹線開通/
しんかんせんがわ /新幹線側/
しんかんせんくかん /新幹線区間/
しんかんせんこうかきょう /新幹線高架橋/
しんかんせんこくらえき /新幹線小倉駅/
しんかんせんしゃない /新幹線車内/
しんかんせんしょう /新感染症/
しんかんせんしんえき /新幹線新駅/
しんかんせんじゆうせき /新幹線自由席/
しんかんせんせいび /新幹線整備/
しんかんせんせつぞく /新幹線接続/
しんかんせんていしゃえき /新幹線停車駅/
しんかんせんでんしゃ /新幹線電車/
しんかんせんとうきょうえき /新幹線東京駅/
しんかんせんとっきゅうけん /新幹線特急券/
しんかんせんよう /新幹線用/
しんかんせんりょうきん /新幹線料金/
しんかんとく /新監督/
しんかんぼん /新刊本/
しんかんりにん /新管理人/
しんかんりょう /新官僚/
しんが /真我/
しんがい /侵害/心外/辛亥;-革命/震駭;世界を-させる/新谷/
しんがいかくめい /辛亥革命/
しんがいこくじん /新外国人/
しんがいしゃ /新会社/侵害者/
しんがいじじつ /侵害事実/
しんがいじん /新外人/
しんがいねん /新概念/真概念/
しんがお /新顔/
しんがく /進学/神学/新学/信学/心学/
しんがくか /神学科/
しんがくかい /信学会/
しんがくぎほう /信学技報;信州大学の紀要/
しんがくこう /進学校/
しんがくご /進学後/
しんがくさき /進学先/
しんがくし /信学誌/
しんがくしどう /進学指導/
しんがくしゃ /進学者/神学者;theologist/
しんがくじ /進学時/
しんがくじゅく /進学塾/
しんがくたいぜん /神学大全;Summa Theologiae,13c,Thomas Aquinas/
しんがくだいがく /神学大学/
しんがくてき /神学的/
しんがくねん /新学年/
しんがくぶ /神学部/
しんがくりつ /進学率/
しんがくろん /信学論/
しんがくろんそう /神学論争/
しんがた /新型/
しんがたき /新型機/
しんがたしゃ /新型車/
しんがたしゃりょう /新型車両/
しんがたでんしゃ /新型電車/
しんがたとっきゅう /新型特急/
しんがたとっきゅうしゃりょう /新型特急車両/
しんがたばくだん /新型爆弾/
しんがたばん /新型番/
しんがたよう /新型用/
しんがっかい /信学会/
しんがっき /新学期/
しんがっこう /進学校;prep school/神学校;seminary/
しんがぽーる /新嘉坡;Singapore/
しんがら /新柄/
しんがり /殿/
しんがん /真贋/心眼;mind's eye/心願;wish/
しんき /新規;new/心機;-一転/新奇;novel/新期;new period/心気/辛気;-臭い/神姫/神器/神気/振起/新機;new machine/蜃気/
しんき> /新規;-作成,-契約,-登録/
しんきいってん /心機一転/
しんきかいいん /新規会員/
しんきかいきょく /新規開局/
しんきかいてん /新規開店/
しんきかいはつ /新規開発/
しんきかく /新企画;new plan/新規格;new standard/
しんきかごうぶつ /新規化合物/
しんきかにゅう /新規加入/
しんきけいやく /新規契約/
しんきげん /新紀元/
しんきげんしゃ /新紀元社;[出版社名]www.shinkigensha.co.jp/
しんきこう /新機構/
しんきこうかい /新規公開/
しんきこうかいかぶ /新規公開株/
しんきこうしん /心悸亢進/
しんきこきゃく /新規顧客/
しんきさくせい /新規作成/
しんきさんか /新規参加/
しんきさんかきぼう /新規参加希望/
しんきさんかしゃ /新規参加者/
しんきさんにゅう /新規参入/
しんきさんにゅうしゃ /新規参入者/
しんきしゅ /新機種/
しんきしゅしょうかい /新機種紹介/
しんきしゅってん /新規出店/
しんきしゅとくしゃ /新規取得者/
しんきしゅはっぴょう /新機種発表/
しんきしょう /心気症/
しんきしょうひん /新規商品/
しんきじ /新記事/
しんきじぎょうすいしん /新規事業推進/
しんきじく /新機軸/
しんきじゅうたく /新規住宅/
しんきじゅん /新基準/
しんきじょうじょう /新規上場/
しんきせい /新規性;今までになかったこと NB:著作権発生の要件/新奇性;目新しいこと/
しんきせってい /新規設定/
しんきた /新喜多/
しんきち /新吉/信吉/真吉/進吉/
しんきついか /新規追加/
しんきてい /新規定/
しんきていあん /新規提案/
しんきとうろく /新規登録/
しんきにゅうかいしゃ /新規入会者/
しんきのう /新機能/心機能/
しんきば /新木場/
しんきぶっしつ /新規物質/
しんきゅう /鍼灸/新旧/進級;promote/審級;stage/賑給/
しんきゅういん /鍼灸院/
しんきゅうがた /新旧型/
しんきゅうこうたい /新旧交替/
しんきゅうし /鍼灸師/
しんきゅうだん /新球団/
しんきゅうちりょう /鍼灸治療/
しんきゅうめん /真球面/
しんきゅうりょうほう /新旧両方/
しんきょ /新居/
しんきょう /心境/新教;Protestant/新京/信教;religion.「-の自由」/新疆;(Xinjiang)「-ウイグル自治区」/進境;progress/心胸/新彊;?/
しんきょういく /新教育/
しんきょうごく /新京極/
しんきょうせん /神京戦/
しんきょうち /新境地/
しんきょうと /新教徒/
しんきょうどうやく /新共同訳/
しんきょうのじゆう /信教の自由;憲法20条/
しんきょうふくざつ /心境複雑/
しんきょく /新曲/神曲;Divina Comedia,1307-21,Dante/
しんきょくはっぴょう /新曲発表/
しんきょくはっぴょうかい /新曲発表会/
しんきょくめん /新局面/
しんきりゅうえき /新桐生駅/
しんきろう /蜃気楼/
しんきろく /新記録/
しんきろくたっせい /新記録達成/
しんきろせん /新規路線/
しんきん /心筋/信金/真菌/親近/伸筋;⇔屈筋/
しんきんえん /心筋炎;[医]/
しんきんかん /親近感/
しんきんこうそく /心筋梗塞/
しんきんしょう /心筋症;[医]/真菌症;[医]/
しんきんちゅうおうきんこ /信金中央金庫;www.shinkin-central-bank.jp/
しんきんるい /真菌類/
しんぎ /審議/真偽/信義/新技/神技/新義;new meaning/真義;true meaning/進木/心木/
しんぎいいんかい /審議委員会/
しんぎいり /審議入り/
しんぎかい /審議会/
しんぎかん /審議官/
しんぎじゅつ /新技術/
しんぎじゅつかいはつ /新技術開発/
しんぎじゅつじぎょうだん /新技術事業団/
しんぎそく /信義則/
しんぎたい /心技体/
しんぎたいしょう /審議対象/
しんぎち /真偽値/
しんぎちゅう /審議中/
しんぎふ /新岐阜/
しんぎふめい /真偽不明/
しんぎょう /信楽;[仏教]教えを信じ喜ぶ/心経;[略語]般若波羅蜜多心経/
しんぎょうそう /真行草/
しんぎろん /神義論/
しんぎん /呻吟/
しんく /真紅/深紅/辛苦/
しんくい /身口意/
しんくう /真空/
しんくうかん /真空管/
しんくうかんかいろ /真空管回路/
しんくうかんしき /真空管式/
しんくうかんじだい /真空管時代/
しんくうけい /真空計/
しんくうこう /新空港/
しんくうこうがく /真空工学/
しんくうこうけいかく /新空港計画/
しんくうだんねつ /真空断熱/
しんくうちたい /真空地帯;void/
しんくうちゅう /真空中/
しんくうでんし /真空電子/
しんくうはどう /真空波動/
しんくうば /真空場/
しんくうぱっく /真空パック/
しんくうほうでん /真空放電/
しんくうぼ /新空母/
しんくみ /信組/
しんくん /神君/
しんぐ /寝具/神具/
しんぐう /新宮/信宮/
しんぐうえん /新宮宛/
しんぐてん /寝具店/
しんぐるばん /シングル盤;single/
しんぐん /進軍/新軍/
しんけ /新家/
しんけい /神経/唇形/針形/
しんけいいがく /神経医学/
しんけいえん /神経炎/
しんけいか /神経科/神経家/
しんけいかいぼう /神経解剖/
しんけいかいぼうがく /神経解剖学/
しんけいかいろ /神経回路/
しんけいかいろがっかい /神経回路学会/
しんけいかいろもう /神経回路網/
しんけいかがく /神経科学/
しんけいかがくしゃ /神経科学者/
しんけいかく /神経核/
しんけいかつどう /神経活動/
しんけいかびん /神経過敏/
しんけいかん /神経間/神経管/
しんけいかんけい /神経関係/
しんけいかんさいぼう /神経幹細胞/
しんけいかんれん /神経関連/
しんけいがく /神経学/
しんけいがくてき /神経学的/
しんけいがしゅ /神経芽腫;[医]neuroblastoma/
しんけいがす /神経ガス;nerve gas/
しんけいきこう /神経機構/
しんけいけい /神経系/
しんけいけつごう /神経結合/
しんけいげか /神経外科/
しんけいげん /神経元/
しんけいこうさいぼう /神経膠細胞/
しんけいこん /神経根/
しんけいさいぼう /神経細胞/
しんけいさいぼうたい /神経細胞体/
しんけいざいせいさく /新経済政策/
しんけいしき /新形式/
しんけいしげき /神経刺激/
しんけいしっかん /神経疾患/
しんけいしつ /神経質/
しんけいしつまい /新形質米/
しんけいしゅうまつ /神経終末/
しんけいしゅうもう /神経集網/
しんけいしょう /神経症/神経鞘/
しんけいしょうがい /神経障害/
しんけいしんどうし /神経振動子/
しんけいしんり /神経心理/
しんけいしんりがく /神経心理学/
しんけいじゅようたい /神経受容体/
しんけいじょうほうしょり /神経情報処理/
しんけいすいじゃく /神経衰弱/
しんけいせい /神経性/新京成/
しんけいせいでんてつ /新京成電鉄/
しんけいせいぶつがく /神経生物学/
しんけいせいりがく /神経生理学/
しんけいせいりがくしゃ /神経生理学者/
しんけいせつ /神経節/
しんけいせん /神経戦/
しんけいせんい /神経繊維/
しんけいそう /神経叢/
しんけいそしき /神経組織;[生物]nerve tissue/
しんけいたんい /神経単位/
しんけいだん /神経弾/
しんけいちゅうすう /神経中枢/
しんけいつう /神経痛/
しんけいでんたつぶっしつ /神経伝達物質/
しんけいとうがい /神経頭蓋/
しんけいとっき /神経突起/
しんけいどく /神経毒/
しんけいないか /神経内科/
しんけいはい /神経胚/
しんけいはん /新京阪/
しんけいばん /神経板/
しんけいぱるす /神経パルス/
しんけいびょう /神経病/
しんけいまひ /神経麻痺/
しんけいもう /神経網/
しんけいやく /新契約/
しんけつ /審決/心血/
しんけん /真剣/親権/進研/神剣/新券/神権/神拳/震研/
しんけんざい /新建材/
しんけんし /真剣師/
しんけんしゃ /親権者/
しんけんしょうぶ /真剣勝負/
しんけんせいじ /神権政治/
しんけんぜみ /進研ゼミ/
しんけんぽう /新憲法/
しんげき /進撃/新劇/
しんげつ /新月/心月/
しんげん /震源/進言;counsel/箴言;proverb/信玄/森厳/
しんげんいき /震源域/
しんげんきょり /震源距離/
しんげんこう /信玄公/
しんげんし /新元史;二十五史/
しんげんじょうほう /震源情報/
しんげんち /震源地/
しんげんぶくろ /信玄袋/
しんこ /新古/新香/真個/
しんこいわ /新小岩/
しんこいわえき /新小岩駅/
しんこう /進行/振興;†promote.「学術-」/新興;†emerging.「-産業」/信仰/親交/侵攻;†invasion.「イラク-」/進攻;†offense.「バグダッドへの-」/深紅;=しんく/深耕;深く耕すこと/神幸/新光/神鋼/真光/真興/新香/深更/進講;貴人への講義/新晃/進貢/深厚/神工/親好/侵寇/進航/深交/侵行/辰功/
しんこういぜん /侵攻以前/
しんこうかい /振興会/親交会/
しんこうかじょう /信仰箇条;credo/
しんこうがかり /進行係/
しんこうき /神皇記/
しんこうきぎょう /新興企業/
しんこうけい /進行形/
しんこうこう /新興校/
しんこうこく /新興国/
しんこうこくはく /信仰告白/
しんこうこっか /新興国家/
しんこうざいだん /振興財団/
しんこうしゃ /信仰者/新光社/進講者/
しんこうしゅうきょう /新興宗教/
しんこうしゅうきょうだんたい /新興宗教団体/
しんこうしょく /深紅色/
しんこうしん /信仰心/
しんこうじゅうたくち /新興住宅地/
しんこうじょう /進行上/信仰上/
しんこうじょうきょう /進行状況/
しんこうじょうたい /進行状態/
しんこうせい /進行性/
しんこうそう /新構想/
しんこうそくど /進行速度/
しんこうちゅう /進行中/侵攻中/
しんこうつう /新交通/
しんこうど /進行度/
しんこうどくりつこく /新興独立国/
しんこうは /進行波/
しんこうはかい /進行波解/
しんこうひょう /進行表/
しんこうべ /新神戸/
しんこうべえき /新神戸駅/
しんこうほうこう /進行方向/
しんこうほうこうまえ /進行方向前/
しんこうほうこうみぎがわ /進行方向右側/
しんこうぼうがい /進行妨害/
しんこうまひ /進行麻痺;[医]progressive paralysis/
しんこうやく /進行役/
しんこきゅう /深呼吸/
しんこきんしゅう /新古今集/
しんこきんわかしゅう /新古今和歌集/
しんこく /深刻/申告/神国/新穀/新刻;新版/親告;-罪/
しんこくか /深刻化/
しんこくきげん /申告期限/
しんこくげき /新国劇/
しんこくざい /親告罪;強姦罪などのように、公訴の提起に告訴を必要条件とする犯罪/
しんこくしゃ /申告者/
しんこくしょ /申告書/
しんこくせい /申告制/
しんこくのうぜい /申告納税/
しんこくのうぜいせいど /申告納税制度/
しんこくぶんりかぜい /申告分離課税/
しんこくほうほう /申告方法/
しんこくもれ /申告漏れ/
しんこくようし /申告用紙/
しんこくりつげきじょう /新国立劇場;www.nntt.jac.go.jp/
しんこしゃ /新古車/
しんこだ /新小田/
しんこっちょう /真骨頂/
しんこてんしゅぎ /新古典主義/
しんこてんてき /新古典的/
しんことに /新琴似/
しんこひん /新古品/
しんこやす /新子安/
しんこん /新婚/心根/心魂;heart/身魂;body and soul/身根;[仏教]/親懇/
しんこんかてい /新婚家庭/
しんこんしょや /新婚初夜/
しんこんせいかつ /新婚生活/
しんこんりょこう /新婚旅行/
しんご /慎吾/真吾/信吾/新吾/伸吾/真悟/晋吾/新語/信悟/伸悟/進悟/紳悟/晋午/神語/讖語/
しんごう /信号/神郷/新郷/身業;[仏教]/賑給/
しんごうおん /信号音/
しんごうか /信号化/
しんごうかいせき /信号解析/
しんごうき /信号機;signaler/信号旗;signal flag/信号器/
しんごうきょうど /信号強度/
しんごうきょくせい /信号極性/
しんごうきろく /信号記録/
しんごうぎじゅつ /信号技術/
しんごうけい /信号系/
しんごうけいとう /信号系統/
しんごうげん /信号源/
しんごうこうさてん /信号交差点/
しんごうしょ /信号所/
しんごうしょり /信号処理/
しんごうしょりしゅほう /信号処理手法/
しんごうしょりよう /信号処理用/
しんごうしょりりろん /信号処理理論/
しんごうじょう /信号場/
しんごうせいぶん /信号成分/
しんごうせつび /信号設備/
しんごうせん /信号線/
しんごうぜんたい /信号全体/
しんごうたいざつおんひ /信号対雑音比/
しんごうち /信号値/
しんごうちゅうしゅつ /信号抽出/
しんごうちょう /信号長/
しんごうつうしん /信号通信/
しんごうでんたつ /信号伝達/
しんごうはいち /信号配置/
しんごうはけい /信号波形/
しんごうひょう /信号表/
しんごうぶんせき /信号分析/
しんごうほうしき /信号方式/
しんごうまち /信号待ち/
しんごうむし /信号無視/
しんごうめい /信号名/
しんごうめん /信号面/
しんごうれつ /信号列/
しんごうろ /信号路/
しんごごうめ /新五合目/
しんごさんけ /新御三家/
しんごじてん /新語辞典/
しんごだいし /新五代史;二十一史/
しんごん /真言/
しんごんしゅう /真言宗/
しんごんみっきょう /真言密教/
しんさ /審査/辰砂;=しんしゃ/
しんさーびす /新サービス/
しんさい /震災/新妻;にいづま/神祭/親裁;君主による裁決/親祭;天皇による祭事/神彩/薪柴/神采/
しんさいいん /審査委員/
しんさいたいさく /震災対策/
しんさいばし /心斎橋/
しんさいばしすじ /心斎橋筋/
しんさいん /審査員/
しんさかい /審査会/
しんさかん /審査官/
しんさき /審査器/
しんさきじゅん /審査基準/
しんさく /新作/真作;⇔偽作,贋作/振作;promote/晋作;人名/進作/
しんさくじょうほう /新作情報/
しんさくせいさくちゅう /新作制作中/
しんさくたんぺん /新作短編/
しんさくひん /新作品/
しんさくもんだい /新作問題/
しんさけっか /審査結果/
しんさけっかつうち /審査結果通知/
しんさけんとう /審査検討/
しんさしゃ /審査者/
しんさじてん /審査時点/
しんさせいきゅう /審査請求/
しんさたいしょう /審査対象/
しんさっぽろ /新札幌/
しんさつ /診察/新札/
しんさつしつ /診察室/
しんさつび /診察日/
しんさび /審査日/
しんさほうこく /審査報告/
しんさよく /新左翼/
しんさん /辛酸/新参/神算/
しんさんだ /新三田/
しんざ /新座/神座/
しんざい /芯材/心材/深在/浸剤/
しんざいけもじ /新在家文字/
しんざいこ /新在庫/
しんざいせい /深在性/
しんざき /新崎/
しんざっし /新雑誌/
しんざつおん /心雑音;[医]murmur/
しんざわ /新沢/新澤/
しんざん /神山/深山/新参/心算/
しんざんしゅ /新参種/
しんざんもの /新参者/
しんざんゆうこく /深山幽谷/
しんし /紳士/真摯/浸漬/進士;科挙等の試験科目(の合格者)/振子/神士/新市/新史/神祠/参差/唇歯/
しんしおん /唇歯音;[音声学]labio-dental/
しんしき /新式/神式/
しんしきょうてい /紳士協定/
しんしきょうやく /紳士協約;gentlemen's agreement/
しんしこう /新試行/
しんしさ /真摯さ/
しんししゅくじょ /紳士淑女/
しんしちょう /振子長/
しんしっかん /心疾患/
しんしっこうぶ /新執行部/
しんしつ /寝室/心室/
しんしてい /新指定/
しんしてき /紳士的/
しんしどうめい /紳士同盟/
しんしどうようりょう /新指導要領/
しんしのつ /新篠津/
しんしふう /紳士風/
しんしふく /紳士服/
しんしほしゃ /唇歯輔車/
しんしものせき /新下関/
しんしゃ /新車/新社/深謝/辰砂;HgS/親炙/
しんしゃおく /新社屋/
しんしゃかいじん /新社会人/
しんしゃかいとう /新社会党/
しんしゃかいはつ /新車開発/
しんしゃかかく /新車価格/
しんしゃく /斟酌/新釈/
しんしゃこうにゅう /新車購入/
しんしゃこうにゅうじ /新車購入時/
しんしゃしゅ /新車種/
しんしゃしょう /新社章/
しんしゃじ /新車時/
しんしゃじょうほう /新車情報/
しんしゃそうちゃく /新車装着/
しんしゃちょう /新社長/
しんしゃどうにゅう /新車導入/
しんしゃめい /新社名/
しんしゃりょう /新車両/新車輌/新車輛/
しんしゅ /新種/新酒/進取/新手/神酒/
しんしゅう /信州/真宗/侵襲;[医]/神州/新修/新秋/
しんしゅうきょう /新宗教/
しんしゅうじん /信州人/
しんしゅうそば /信州蕎麦/
しんしゅうだい /信州大/
しんしゅうだいがく /信州大学/
しんしゅうてき /侵襲的/
しんしゅうほうめん /信州方面/
しんしゅうみそ /信州味噌/
しんしゅく /伸縮/新宿/
しんしゅくけい /伸縮計/
しんしゅくじ /伸縮時/
しんしゅくじざい /伸縮自在/
しんしゅくせい /伸縮性/
しんしゅくりつ /伸縮率/
しんしゅだん /新手段/
しんしゅつ /進出;advance/浸出;ooze/新出;⇔既出/滲出;≒浸出/神出;-鬼没/侵出;invade/
しんしゅつえき /滲出液/
しんしゅつきぼつ /神出鬼没/
しんしゅつしょく /進出色/
しんしゅと /新首都/
しんしゅどき /新酒時/
しんしゅほう /新手法/
しんしゅぼば /新種牡馬/
しんしゅん /新春/
しんしゅんごう /新春号/
しんしゅんとくべつきかく /新春特別企画/
しんしゅんばん /新春版/
しんしゅんほうだん /新春放談/
しんしょ /新書;岩波-/親書;自筆の書状/信書;手紙/真書;楷書/神書/心緒/親署;天皇のサイン/讖書/
しんしょう /心象;image/辛勝/心証;裁判官の-/身障;[略語]身体障害(者)/新梢/身上/信証/神将/志ん生/真症/心性;[仏教]/紳商/財産;当て字?/
しんしょうが /新生姜/
しんしょうしゃ /身障者/
しんしょうしゃさべつ /身障者差別/
しんしょうなん /新湘南/
しんしょうひつばつ /信賞必罰/
しんしょうひん /新商品/
しんしょうふうけい /心象風景/
しんしょうぼうだい /針小棒大/
しんしょかん /新書館;[出版社名]/
しんしょく /侵食;†encroach.「領土の-」/浸食;†erode.「雨水による-」/寝食;「-を共にする」/新色/神職/侵蝕;=侵食/浸蝕;=浸食/神色;顔色/
しんしょくさよう /浸食作用/
しんしょちょう /新所長/
しんしょばん /新書版/新書判/
しんしょびん /信書便;民間業者による郵便相当の信書. 「(一般|特定)-事業」/
しんしょびんほう /信書便法;[法][略語]「民間事業者による信書の送達に関する法律」。2002年制定/
しんしょぼん /新書本/
しんしよう /紳士用/新仕様/
しんしろ /新城/
しんしろく /紳士録/
しんしん /心身/新進/新々/津々;興味-/深々;雪が-と降る/心神;mind.「-喪失」/津津/信心;しんじん?/伸身/
しんしんきえい /新進気鋭/
しんしんこうじゃく /心神耗弱/
しんしんさっか /新進作家/
しんしんしょう /心身症/
しんしんそうしつ /心神喪失/
しんしんそうしつしゃ /心神喪失者/
しんしんとう /新進党/
しんしんどう /駸々堂/
しんしんにげんろん /心身二元論/
しんじ /神事/新字/進士/信士/心事/心耳/真字/宍道/真司/伸二/慎二/真二/信二/真治/伸治/信次/慎司/信治/慎治/伸司/伸次/新司/信司/新治/眞治/晋司/晋二/晋次/愼二/伸自/神餌/神字;神代文字/鍼治/
しんじかさがけ /神事笠懸/
しんじぎょう /新事業/
しんじぎょうそうしゅつそくしんほう /新事業創出促進法/
しんじこ /宍道湖/
しんじじつ /新事実/
しんじずもう /神事相撲/
しんじたい /新字体/
しんじだい /新時代/
しんじっけん /新実験/
しんじつ /真実/信実;honest/
しんじつせい /真実性/
しんじつど /真実度/
しんじつみ /真実味/
しんじのう /神事能/
しんじまい /神事舞/
しんじゃ /信者/心者/
しんじゃが /新ジャガ/新じゃが/
しんじゃたち /信者達/
しんじゅ /真珠/新樹/神授/親授/
しんじゅいり /真珠入り/
しんじゅいろ /真珠色;pearl/
しんじゅう /心中/神獣/臣従/
しんじゅうしょ /新住所/
しんじゅうしょち /新住所地/
しんじゅうみん /新住民/
しんじゅうるい /真獣類/
しんじゅうろう /真十郎/
しんじゅがい /真珠貝/
しんじゅく /新宿/
しんじゅくえき /新宿駅/
しんじゅくえきにしぐち /新宿駅西口/
しんじゅくえきひがしぐち /新宿駅東口/
しんじゅくえきみなみぐち /新宿駅南口/
しんじゅくおだきゅう /新宿小田急/
しんじゅくおんがくさい /新宿音楽祭/
しんじゅくかぶきちょう /新宿歌舞伎町/
しんじゅくがわ /新宿側/
しんじゅくぎょえん /新宿御苑/
しんじゅくく /新宿区/
しんじゅくこうせいねんきん /新宿厚生年金/
しんじゅくさんちょうめ /新宿三丁目/
しんじゅくしょぼう /新宿書房/
しんじゅくせん /新宿線/
しんじゅくせんおがわちょう /新宿線小川町/
しんじゅくちゅうおうこうえん /新宿中央公園/
しんじゅくてん /新宿店/
しんじゅくどおり /新宿通り/
しんじゅくにしぐち /新宿西口/
しんじゅくにしぐちえき /新宿西口駅/
しんじゅくにしぐちしてん /新宿西口支店/
しんじゅくはつ /新宿発/
しんじゅくひがしぐち /新宿東口/
しんじゅくほうめん /新宿方面/
しんじゅくまるい /新宿丸井/
しんじゅくみつこし /新宿三越/
しんじゅくみなみぐち /新宿南口/
しんじゅこんしき /真珠婚式;30周年/
しんじゅそう /真珠層/
しんじゅつ /申述/心術/神術/鍼術;針治療/
しんじゅつしょ /申述書/
しんじゅつどうとく /心術道徳/
しんじゅぶつ /神儒仏/
しんじゅわん /真珠湾/
しんじゅわんこうげき /真珠湾攻撃/
しんじゅん /浸潤/
しんじゆうしゅぎ /新自由主義/
しんじょ /寝所/晋書;二十一史/神助/
しんじょう /心情/信条/身上/新庄/新城/真情/進上/新條/
しんじょうかん /新庄間/
しんじょうさい /新嘗祭;11.23 現・勤労感謝の日/
しんじょうしょ /身上書/進上書/
しんじょうせき /新定跡/
しんじょうてき /心情的/
しんじょうばし /新城橋/
しんじょうほう /新情報/
しんじょはら /新所原/
しんじろう /新次郎/慎次郎/
しんじん /新人/信心/深甚/審尋/神人/真人/審訊;=審尋/
しんじんえんげいたいしょう /新人演芸大賞/
しんじんおう /新人王/
しんじんか /信心家/
しんじんかしゅ /新人歌手/
しんじんきしゅ /新人騎手/
しんじんきょういく /新人教育/
しんじんけんしゅう /新人研修/
しんじんけんしゅうちゅう /新人研修中/
しんじんこうえん /新人公演/
しんじんしょう /新人賞/
しんじんせん /新人戦/
しんじんせんしゅ /新人選手/
しんじんたち /新人達/
しんじんまんがか /新人漫画家/
しんじんよう /新人用/
しんじんるい /新人類/
しんすい /浸水;†flood.「床上-」/心酔/進水;†launch.「新造艦の-式」/深水;†deep water/薪水;†家事労働。「-の労」/
しんすいしき /進水式/
しんすいじこ /浸水事故/
しんすいせい /親水性;hydrophile/新彗星/
しんすいのろう /薪水の労;-を取る/
しんすう /進数;notation.「16-」/真数;antilog.⇔対数/芯数;「ケーブルの」/
しんすけ /伸介/信介/紳助/慎介/信輔/紳介/
しんずい /真髄/神髄;≒真髄/心髄;≒真髄/
しんずし /新逗子/
しんずしえき /新逗子駅/
しんせい /申請/新生/神聖/新星;nova/真正;†authentic.「-な証書」/真性;†genuine.⇔仮性。「-コレラ」/新制;†⇔旧制。「-大学」/新製;†create.「-車両」/新政;建武の-/神性;deity/心性;mentality/新姓;⇔旧姓/親政;天子の-/神政;thearchy/親征/辰星;-落落/晨星;水星/
しんせい> /真性;-コレラ,-包茎/
しんせいうけつけ /申請受付/
しんせいか /神聖化/
しんせいかつ /新生活/
しんせいがく /申請額/
しんせいがん /深成岩/
しんせいき /新世紀/
しんせいきへん /新世紀編/
しんせいぎんこう /新生銀行/
しんせいけい /神聖系/
しんせいけん /新政権/
しんせいけんじゅりつ /新政権樹立/
しんせいご /申請後/
しんせいさき /申請先/
しんせいし /神聖視/心性史;histoire des mentalites/
しんせいしゃ /申請者/新声社;[文学史]/新製車/
しんせいしゃりょう /新製車両/
しんせいしょ /申請書/
しんせいしょう /申請証/
しんせいしょよう /申請書用/
しんせいしょるい /申請書類/
しんせいじ /新生児/申請時/
しんせいじよう /新生児用/
しんせいじん /新成人/
しんせいせきにんしゃ /申請責任者/
しんせいそしき /申請組織/
しんせいたんとうしゃ /申請担当者/
しんせいだい /新生代/
しんせいだいがく /新制大学/
しんせいちゅう /申請中/
しんせいでん /神制電/
しんせいとう /新生党/
しんせいど /新制度/
しんせいどう /新星堂/
しんせいどうめい /神聖同盟;[世界史](1815)Holy Alliance/
しんせいないよう /申請内容/
しんせいねん /新青年/
しんせいのう /新性能/
しんせいのうか /新性能化/
しんせいのうしゃ /新性能車/
しんせいばんごう /申請番号/
しんせいひん /新製品/
しんせいひんいちらん /新製品一覧/
しんせいひんかいはつ /新製品開発/
しんせいひんしょうかい /新製品紹介/
しんせいひんじょうほう /新製品情報/
しんせいひんてんじかい /新製品展示会/
しんせいひんはっぴょうかい /新製品発表会/
しんせいひんはつばい /新製品発売/
しんせいふかしん /神聖不可侵/
しんせいほうけい /真性包茎/
しんせいめん /新生面/
しんせいよう /申請用/
しんせいようし /申請用紙/
しんせいりょう /申請料/
しんせいろーまていこく /神聖ローマ帝国/
しんせかい /新世界/真世界/
しんせかいきこう /新世界紀行/
しんせかいこうきょうきょく /新世界交響曲/
しんせかいせんたい /新世界戦隊/
しんせかいちつじょ /新世界秩序/
しんせき /親戚/浸漬;=しんし (慣用読み)/真蹟/真跡;=真蹟/臣籍;-に下る/
しんせきいちどう /親戚一同/
しんせきえんじゃ /親戚縁者/
しんせきかんけい /親戚関係/
しんせきこうか /臣籍降下/
しんせだい /新世代/
しんせっき /新石器/
しんせっきじだい /新石器時代/
しんせっけい /新設計/
しんせつ /新設/親切/深雪;deep snow/新雪;virgin snow/新説;new theory/真説;true theory/深切;=親切/
しんせつえき /新設駅/
しんせつかいはい /新設改廃/
しんせつがっか /新設学科/
しんせつがっぺい /新設合併/
しんせつぎ /親切気/
しんせつこう /新設校/
しんせつごかし /親切ごかし/
しんせつしん /親切心/
しんせつじょうたい /新雪状態/
しんせつせっけい /親切設計/
しんせつぞく /新接続/
しんせつひ /新設費/
しんせつぶんかつ /新設分割/
しんせん /新鮮/新線/神泉/神仙/芯線/振戦/新選/心線/神饌/深浅/伸線/浸染/神占/震顫/神僊/
しんせんか /新鮮化/芯線化/
しんせんくかん /新線区間/
しんせんぐみ /新撰組/新選組/
しんせんし /新戦士/
しんせんしそう /神仙思想/
しんせんしんじゅく /新線新宿/
しんせんみ /新鮮味/
しんせんりょく /新戦力/
しんぜ /信施/
しんぜん /親善/神前/浸染/森然/
しんぜんけっこん /神前結婚/
しんぜんしき /神前式/
しんぜんしゅう /新全集/
しんぜんじあい /親善試合/
しんぜんたいし /親善大使/
しんぜんび /真善美/
しんそ /信組/親疎/
しんそう /真相/深層/新装/深窓/眞相;旧字/真草/神葬/伸葬/
しんそうかいてん /新装開店/
しんそうかいめい /真相解明/
しんそうかん /新創刊/
しんそうきゅうめい /真相究明/
しんそうこうぞう /深層構造;deep structure/
しんそうさい /神葬祭/
しんそうしんり /深層心理/
しんそうしんりがく /深層心理学/
しんそうしんりてき /深層心理的/
しんそうじゅんかん /深層循環/
しんそうすい /深層水/
しんそうてき /深層的/
しんそうばん /新装版/
しんそうりゅう /深層流/
しんそく /神速/神足/
しんそくつう /神足通/
しんそくぶつしゅぎ /新即物主義;Neue Sachlichkeit. Kastnerなど/
しんそこ /心底/真底;≒心底/
しんそこ> /心底/
しんそざい /新素材/
しんそしき /新組織/
しんそつ /新卒/真率/
しんそつしゃ /新卒者/
しんぞ /新造/
しんぞう /心臓/新造/神像/心像/新三/
しんぞういしょく /心臓移植/
しんぞうき /新造機/
しんぞうけい /心臓形/
しんぞうご /新造語;neologism/
しんぞうし /心臓死/
しんぞうしっかん /心臓疾患/
しんぞうしゃ /新造車/
しんぞうしゃりょう /新造車両/
しんぞうじ /新造時/
しんぞうせん /新造船/
しんぞうにんげん /新造人間/
しんぞうびょう /心臓病/
しんぞうぶ /心臓部/
しんぞうへき /心臓壁/
しんぞうほっさ /心臓発作/
しんぞうまっさーじ /心臓マッサージ/
しんぞうまひ /心臓麻痺;[医]heart attack/
しんぞうやぶり /心臓破り/
しんぞく /親族/神族;神の一族/
しんぞくいちどう /親族一同/
しんぞくかい /親族会/
しんぞくかいぎ /親族会議/
しんぞくかんけい /親族関係/
しんた /新太/心太/
しんたい /身体/進退/神体/新体/真諦/
しんたいいぞん /身体依存/
しんたいうかがい /進退伺い/進退伺/
しんたいかんかく /身体感覚/
しんたいきかん /身体器官/
しんたいけい /新体系/身体刑;笞刑など ⇔自由刑/
しんたいけんさ /身体検査/
しんたいげんご /身体言語;body language/
しんたいげんしょう /身体現象/
しんたいし /新体詩/
しんたいししょう /新体詩抄/
しんたいしょうがいしゃ /身体障害者/
しんたいしょうがいしゃふくしほう /身体障害者福祉法/
しんたいせい /新体制/身体性/
しんたいせっしょく /身体接触/
しんたいぜんたい /身体全体/
しんたいそう /新体操/
しんたいそうぶ /新体操部/
しんたいそくてい /身体測定/
しんたいちゅう /身体中/
しんたいてき /身体的/
しんたいてきえいきょう /身体的影響/
しんたいてきみりょく /身体的魅力/
しんたいないぶ /身体内部/
しんたいのじゆう /身体の自由;=人身の自由/
しんたいぷ /新タイプ/
しんたいめん /身体面/
しんたいようじ /真太陽時/
しんたいりく /新大陸/
しんたいりょうなん /進退両難/
しんたかなわ /新高輪/
しんたかね /新高値/
しんたく /信託/新宅/神託/
しんたくがいしゃ /信託会社/
しんたくぎん /信託銀/
しんたくぎんこう /信託銀行/
しんたくざいさん /信託財産/
しんたくとうち /信託統治/
しんたくとうちりじかい /信託統治理事会/
しんたくほう /信託法/
しんたちかわ /新立川/
しんたつ /進達/申達/
しんたつしょ /進達書/
しんたつまき /新竜巻/
しんたなべ /新田辺/
しんたに /新谷/
しんたまがわせん /新玉川線/
しんたるい /新垂井/
しんたろう /慎太郎/新太郎/信太郎/辰太郎/
しんたん /薪炭/震旦/心胆/晨旦/
しんだい /寝台/新台/身代/神大/信大/神代/
しんだいいれかえ /新台入替/
しんだいかぎり /身代限り;[日本史]江戸時代の破産/
しんだいきゃくしゃ /寝台客車/
しんだいけん /寝台券/
しんだいこしつ /寝台個室/
しんだいしゃ /寝台車/
しんだいしゃりょう /寝台車両/
しんだいでんしゃ /寝台電車/
しんだいとっきゅう /寝台特急/
しんだいはば /寝台幅/
しんだいもじ /神代文字/
しんだいりょうきん /寝台料金/
しんだいれっしゃ /寝台列車/
しんだけ /新竹/
しんだつ /侵奪/
しんだん /診断/
しんだんがく /診断学/
しんだんがた /診断型/
しんだんきじゅん /診断基準/
しんだんけっか /診断結果/
しんだんし /診断士/
しんだんしょ /診断書/
しんだんじょうほう /診断情報/
しんだんたい /新団体/
しんだんひょう /診断表/
しんだんび /診断日/
しんだんほう /診断法/
しんだんほうほう /診断方法/
しんだんめい /診断名/
しんち /新地/心地/真値/新治/新知/真智/神智/深知/深智/
しんちーむ /新チーム/
しんちがく /神智学/
しんちく /新築/新竹;new bamboos.  「しんだけ」とも/
しんちくいっこだて /新築一戸建/
しんちくこうじ /新築工事/
しんちくちゅう /新築中/
しんちくぶっけん /新築物件/
しんちしき /新知識/
しんちとせ /新千歳/
しんちとせくうこう /新千歳空港/
しんちとせくうこうえき /新千歳空港駅/
しんちへい /新地平/
しんちゃ /新茶/
しんちゃく /新着/
しんちゃくきじ /新着記事/
しんちゃくじゅん /新着順/
しんちゃくじょうほう /新着情報/
しんちゃくとしょ /新着図書/
しんちゃくとしょあんない /新着図書案内/
しんちゃくめーる /新着メール/
しんちゅう /心中/真鍮/進駐/親中;親・中国/鉐/
しんちゅういた /真鍮板/
しんちゅうぐん /進駐軍/
しんちゅうごく /新中国/
しんちゅうせい /真鍮製/
しんちゅうせん /真鍮線/
しんちゅうぼう /真鍮棒/
しんちょ /新著/心緒/
しんちょう /慎重/身長;†height/新潮;[企業名]/伸長;†(grow)伸びる/新調/伸張;†(expand)伸び広がる/清朝;清王朝/志ん朝;人名/深長;意味-/晨朝/
しんちょうさ /身長差/
しんちょうしせい /慎重姿勢/
しんちょうしゃ /新潮社;[出版社名]www.shinchosha.co.jp/新庁舎/
しんちょうたいじゅう /身長体重/
しんちょうは /慎重派/
しんちょうぶんこ /新潮文庫/
しんちょうぶんこばん /新潮文庫版/
しんちょうろん /慎重論/
しんちょうろんしゃ /慎重論者/
しんちょく /進捗/神勅/
しんちょくじょうきょう /進捗状況/
しんちょくせんしゅう /新勅撰集/
しんちょくせんわかしゅう /新勅撰和歌集/
しんちょくど /進捗度/
しんちょくほうこく /進捗報告/
しんちょくりつ /進捗率/
しんちん /新陳/深沈/
しんちんたいしゃ /新陳代謝/
しんつう /心痛/
しんつだぬま /新津田沼/
しんつるみ /新鶴見/
しんづ /新津/
しんて /新手/
しんてい /進呈/新訂/心底/新艇/新帝/
しんていあん /新提案/
しんていし /心停止/
しんてき /心的;mental/神的;divine/神笛/
しんてきげんしょう /心的現象/
しんてつ /神鉄/
しんてら /新寺/
しんてん /進展;†progress.「計画の-」/伸展;†expand.「勢力の-」/親展;†(手紙の)CONFIDENTIAL/神典/秦篆/
しんてんおう /信天翁/
しんてんかい /新展開/
しんてんじょうきょう /進展状況/
しんてんそう /伸展葬/
しんてんたいはっけん /新天体発見/
しんてんち /新天地/
しんてんちょう /新天町/
しんてんどうち /震天動地/
しんてんぽ /新店舗/
しんでし /新弟子/
しんでん /神殿/新田/寝殿;-造り/心電/神伝/震電;海軍戦闘機/親電/
しんでんず /心電図/
しんでんづくり /寝殿造り/寝殿造/
しんと /新都/信徒/新渡/
しんとう /浸透/神道/心頭/新党/親等/新棟/真藤/神東/振盪/新刀/滲透/榛東/神統/震盪;脳-/神灯/
しんとうあつ /浸透圧/
しんとうき /神統記/
しんとうきょう /新東京/
しんとうごぶしょ /神道五部書/
しんとうさい /新搭載/
しんとうしゅう /神道集/
しんとうじょ /新唐書;二十一史/
しんとうじょう /新登場/
しんとうせい /浸透性/
しんとうど /浸透度/
しんとうめっきゃく /心頭滅却/
しんとうりょく /浸透力/
しんとく /神徳/新得;地名/
しんところざわ /新所沢/
しんとしょく /新塗色/
しんとしん /新都心/
しんとそう /新塗装/
しんとちぎ /新栃木/
しんとちょう /新都庁/
しんとっきゅう /新特急/
しんとっきゅうくさつ /新特急草津/
しんとつかわ /新十津川/
しんとね /新利根/
しんとみ /新富/
しんど /震度/深度;depth/進度;progress/心土/震怒/
しんどう /振動;†(oscillation) 特に、周期を持つ運動。「振り子の-」/震動;†(shake)「地震の-」/神童/新道/神道/伸銅/進藤/新藤/新堂/真藤/
しんどうおん /振動音/
しんどうかい /振動解/
しんどうきゅうしゅう /振動吸収/
しんどうきゅうしゅうざい /振動吸収材/
しんどうけい /振動計/振動系/神道系/
しんどうし /振動子/
しんどうしきょうど /振動子強度/
しんどうしゅうはすう /振動周波数/
しんどうすう /振動数/
しんどうそくど /振動速度/
しんどうてき /振動的/
しんどうでんぱ /振動伝播/
しんどうば /振動場/
しんどうばん /振動板/
しんどうまく /振動膜/
しんどうめん /振動面/
しんどく /真読/
しんない /心内/新内/唇内/
しんないかく /新内閣/
しんないがいめん /新内外綿/
しんないぶし /新内節;[浄瑠璃]/
しんないまくえん /心内膜炎;[医]/
しんなかの /新中野/
しんながた /新長田/
しんなごやえき /新名古屋駅/
しんならしの /新習志野/
しんならしのえき /新習志野駅/
しんなんよう /新南陽/
しんに /瞋恚/真に/
しんにち /親日;pro-Japan/新日/
しんにちか /親日家/
しんにちこく /親日国/
しんにちてき /親日的/
しんにちは /親日派/
しんにっこう /新日鉱/
しんにってつ /新日鉄/新日鐵/新日本製鉄株式会社;※abbrev/
しんにってつかまいし /新日鉄釜石/
しんにっぽん /新日本/
しんにっぽんせいてつ /新日本製鐵;[企業名]/
しんにほん /新日本/
しんにほんおんがく /新日本音楽/
しんにほんきかく /新日本企画/
しんにほんきこう /新日本紀行/
しんにほんしょうけん /新日本証券;[企業名]NB:現・新光証券/
しんにほんせいてつ /新日本製鐵;[企業名]/新日本製鉄;※「新日本製鐵」が正式名称/
しんにゅう /侵入;invasion.「住居-」/進入;approach.「カーブに-する」/新入;「-社員」/浸入;inundation.「雨水-」/之繞/
しんにゅうか /新入荷/進入可/
しんにゅうかい /新入会/
しんにゅうかいいん /新入会員/
しんにゅうがく /新入学/
しんにゅうがくせい /新入学生/
しんにゅうきんし /進入禁止/
しんにゅうきんしいはん /進入禁止違反/
しんにゅうけいろ /進入経路/
しんにゅうしゃ /侵入者/
しんにゅうしゃいん /新入社員/
しんにゅうしゃいんきょういく /新入社員教育/
しんにゅうしゃりょう /進入車両/
しんにゅうしゅ /侵入種/
しんにゅうじ /進入時/侵入時/
しんにゅうせい /新入生/
しんにゅうせいかんげい /新入生歓迎/
しんにゅうせいかんゆう /新入生勧誘/
しんにゅうそくど /進入速度/
しんにゅうふか /進入不可/
しんにゅうぶいん /新入部員/
しんにゅうほうこう /進入方向/
しんにゅうほうほう /侵入方法/
しんにゅうまく /新入幕/
しんにゅうよう /進入用/
しんにゅうろ /侵入路/
しんにょ /真如/信女/
しんにょう /之繞;[部首]「道」「遞」のにょう/
しんにん /新任/信任/信認/親任/
しんにん> /新任;-役員,-教官/
しんにんきょうかん /新任教官/
しんにんじょう /信任状/
しんにんすう /信任数/
しんにんとうひょう /信任投票/
しんにんひょう /信任票/
しんぬり /真塗/
しんね /心根/新値/
しんねた /新ネタ/
しんねつ /身熱/
しんねん /信念/新年/軫念/
しんねんかい /新年会/
しんねんごう /新年号/
しんねんそうそう /新年早々/
しんねんど /新年度/
しんねんどよさんあん /新年度予算案/
しんの /神野/新野/
しんのう /親王/神農/心嚢/心王/新皇/
しんのうとう /秦皇島/
しんのすけ /慎之介/新之助/信之介/進之助/
しんのぞう /心の臓;心臓/
しんのとうげ /新野峠/
しんのり /新海苔/
しんはっけん /新発見/
しんはっけんでん /新八犬伝/
しんはっそう /新発想/
しんはつばい /新発売/
しんはんにん /真犯人/
しんば /新馬/神馬/
しんばし /新橋/
しんばしえき /新橋駅/
しんばしえきまえ /新橋駅前/
しんばしえんぶじょう /新橋演舞場/
しんばしょう /新馬勝/
しんばしら /心柱/真柱/
しんばせん /新馬戦/
しんばた /新畑/
しんばつ /神罰/
しんばば /新馬場/
しんばばえき /新馬場駅/
しんばら /新原/
しんばり /心張り/
しんばりぼう /心張り棒/
しんばん /新版/新番/新盤/
しんばんぐみ /新番組/
しんばんぐみしょうかい /新番組紹介/
しんばんぐみじょうほう /新番組情報/
しんぱ /新派/
しんぱい /心配/心肺/神拝/
しんぱいきのう /心肺機能/
しんぱいごと /心配事/
しんぱいしょう /心配性/
しんぱいてん /心配点/
しんぱいむよう /心配無用/
しんぱく /心拍/心搏/
しんぱくすう /心拍数/
しんぱち /新八/
しんぱつ /進発/深発/
しんぱん /審判/信販/新版/侵犯/親藩/神判/
しんぱんいん /審判員/
しんぱんかん /審判官/
しんぱんがいしゃ /信販会社/
しんぱんぎじゅつ /審判技術/
しんぱんけい /信販系/
しんぱんこうしゅうかい /審判講習会/
しんぱんしかく /審判資格/
しんぱんだん /審判団/
しんぱんちょう /審判長/
しんぱんぶ /審判部/
しんひきた /新疋田/
しんひしつ /新皮質/
しんひっさつわざ /新必殺技/
しんひろしまくうこう /新広島空港/
しんび /審美/
しんびがん /審美眼/
しんびしか /審美歯科/
しんびてき /審美的/
しんぴ /神秘/真皮/真否/心皮/
しんぴか /神秘化/
しんぴげき /神秘劇;NB:mystere(聖史劇)の誤訳/
しんぴしそう /神秘思想/
しんぴしゅぎ /神秘主義/
しんぴしゅぎてき /神秘主義的/
しんぴせい /神秘性/
しんぴつ /真筆/宸筆/親筆/
しんぴてき /神秘的/
しんぴょう /信憑/
しんぴょうせい /信憑性/
しんぴょうろん /新評論/
しんぴわおん /神秘和音/
しんぴん /新品/神品/
しんぴんかかく /新品価格/
しんぴんじ /新品時/
しんぴんじょうたい /新品状態/
しんぴんどうよう /新品同様/
しんぴんぼん /新品本/
しんふがい /申不害/
しんふじ /新富士/
しんふじえき /新富士駅/
しんふぜん /心不全/
しんふらの /新富良野/
しんふり /進振り/進振/
しんぶ /深部/神武/
しんぶかんかく /深部感覚;女性的な-/
しんぶきげん /神武紀元/
しんぶっしつ /新物質/
しんぶつ /神仏/真物/心仏/
しんぶつこんこう /神仏混淆/
しんぶつしゅうごう /神仏習合/
しんぶつぶんり /神仏分離/
しんぶぶんしゅうごう /真部分集合/
しんぶん /新聞/
しんぶんかい /新聞会/
しんぶんかくし /新聞各紙/
しんぶんかんゆう /新聞勧誘/
しんぶんかんゆういん /新聞勧誘員/
しんぶんき /新聞記/
しんぶんきしゃ /新聞記者/
しんぶんきじ /新聞記事/
しんぶんきゅうかんび /新聞休刊日/
しんぶんきょく /新聞局/
しんぶんぐん /新聞群/
しんぶんこうこく /新聞広告/
しんぶんざっし /新聞雑誌/
しんぶんし /新聞紙/
しんぶんしじょう /新聞紙上/
しんぶんしゃ /新聞社/
しんぶんしゃがわ /新聞社側/
しんぶんしゃまえ /新聞社前/
しんぶんじょう /新聞上/
しんぶんじょうほう /新聞情報/
しんぶんじん /新聞人/
しんぶんすう /真分数/
しんぶんだね /新聞種/
しんぶんてき /新聞的/
しんぶんてん /新聞店/
しんぶんとう /新聞等/
しんぶんはいたつ /新聞配達/
しんぶんはいたつじょ /新聞配達所/
しんぶんはっぴょう /新聞発表/
しんぶんはんばいてん /新聞販売店/
しんぶんへんしゅう /新聞編集/新聞編輯/
しんぶんほうどう /新聞報道/
しんぶんめい /新聞名/
しんぶんもじ /新聞文字/
しんぶんや /新聞屋/
しんぶんようご /新聞用語/
しんぶんれんさい /新聞連載/
しんぷ /新譜/新婦/神父/親父/
しんぷう /新風/
しんぷがわ /新婦側/
しんぷく /振幅/心服/信服/心腹/臣服/
しんぷくあっしゅく /振幅圧縮/
しんぷくおうとう /振幅応答/
しんぷくじ /真福寺/
しんぷくせいぎょ /振幅制御/
しんぷくち /振幅値/
しんぷくてん /振幅点/
しんぷくとくせい /振幅特性/
しんぷくひ /振幅比/
しんぷくぶんぷ /振幅分布/
しんぷくへんちょう /振幅変調/
しんぷじょうほう /新譜情報/
しんぷはつばい /新譜発売/
しんへいき /新兵器/
しんべい /親米/
しんべん /唇弁;[植物]labellum/
しんべんてん /新弁天/
しんぺい /新兵/神兵/親兵;近衛兵など/新平/晋平/慎平/
しんぺん /身辺/新編/神変/新篇/
しんぺんざっき /身辺雑記/
しんぺんせいり /身辺整理/
しんぺんちょうさ /身辺調査/
しんほう /進法/心法/
しんほうしき /新方式/
しんほうほう /新方法/
しんほく /真北/
しんほしゅしゅぎ /新保守主義/
しんほだか /新穂高/
しんほどがや /新保土ヶ谷/
しんほんかくは /新本格派/
しんほんてん /新本店/
しんほんや /新本屋/
しんぼ /新保/真保/
しんぼう /辛抱/信望/心房;[解剖]atrium/心棒;spindle/伸坊;人名/深謀;-遠慮/辛棒;(当て字) =辛抱/心法;[仏教]/
しんぼうえんりょ /深謀遠慮/
しんぼうさいどう /心房細動/
しんぼうしゃ /信奉者/
しんぼく /親睦/神木/臣僕/
しんぼくかい /親睦会/
しんぼくかいいん /親睦会員/
しんぼくかいひ /親睦会費/
しんぼち /新発意/
しんぼとけ /新仏/
しんぼり /新堀/
しんぽ /進歩/
しんぽう /新報/新法/信奉/
しんぽうしゃ /信奉者/
しんぽしゅぎ /進歩主義;progressism/
しんぽてき /進歩的/
しんぽとう /進歩党/
しんぽん /新本/
しんまい /新米/
しんまいせんせい /新米先生/
しんまえ /新前/
しんまえばし /新前橋/
しんまおう /新魔王/
しんまきゅう /新魔球/
しんまく /心膜/
しんまち /新町/
しんまちだ /新町田/
しんまつ /新松/
しんまつだ /新松田/
しんまつだえき /新松田駅/
しんまつど /新松戸/
しんまるこ /新丸子/
しんまるこえきまえ /新丸子駅前/
しんみ /親身/新味;newness.「-に乏しい」/辛味/新見;人名/
しんみせ /新店/
しんみた /新三田/
しんみち /新道;梅田―/
しんみつ /親密/深密/身密/
しんみどうすじ /新御堂筋/
しんみなと /新湊/
しんみなとし /新湊市/
しんみなみぐち /新南口/
しんみょう /神妙/身命/新名;地名/
しんみん /臣民/
しんみんぽう /新民法/
しんむら /新村/
しんめ /新芽/神馬/
しんめい /神明/新明/神名/身命;-を賭する/深名/神命/
しんめいかい /新明解/
しんめいさいばん /神明裁判/
しんめいしょう /新名称/
しんめいだい /真命題/
しんめいづくり /神明造り;[建築]/神明造;[建築]/
しんめいぶつ /新名物/
しんめいわこうぎょう /新明和工業;[企業名]/
しんめにゅー /新メニュー/
しんめん /新免/
しんめんばー /新メンバー/
しんめんぼく /真面目/
しんめんもく /真面目;本来の姿/新面目;新しい姿/
しんもつ /進物/神物/
しんもの /新物/
しんもり /新森/
しんもん /審問/神門/真文/神文/真門/心門/讖文/
しんもんかん /審問官/
しんや /深夜/真也/信也/伸也/晋也/真矢/進也/信哉/真哉/新也/新家/晋哉/伸弥/眞哉/信矢/真家/
しんやあにめ /深夜アニメ/
しんやえいが /深夜映画/
しんやきゅうこう /深夜急行/
しんやぎょう /深夜業/
しんやく /新薬/新約;新約聖書/新訳;new translation/神薬;霊薬/信約;covenant/
しんやくいん /新役員/
しんやくしじ /新薬師寺/
しんやくせいしょ /新約聖書/
しんやしき /新屋敷/
しんやじかんたい /深夜時間帯/
しんやそうしょ /深夜叢書/
しんやでんりょく /深夜電力/
しんやとっきゅう /深夜特急/
しんやばんぐみ /深夜番組/
しんやびん /深夜便/
しんやほうそう /深夜放送/
しんやま /新山/
しんやまぐち /新山口/
しんやわく /深夜枠/
しんやわりびき /深夜割引/
しんやわりまし /深夜割増/
しんゆ /新湯/
しんゆう /親友/心友/深憂/
しんゆうばり /新夕張/
しんゆうやく /親友役/
しんゆせい /親油性/
しんゆにっと /新ユニット/
しんゆり /新百合/
しんよ /神輿/
しんよう /信用/瀋陽/針葉/新陽/
しんようかいふく /信用回復/
しんようがし /信用貸し/
しんようきょうどうくみあい /信用協同組合/
しんようきんこ /信用金庫/
しんようくみあい /信用組合/
しんようけいざい /信用経済;credit economy/
しんようざん /信用残/
しんようしっつい /信用失墜/
しんようしゅうしゅく /信用収縮/
しんようしょうかい /信用照会/
しんようじゅ /針葉樹/
しんようじゅりん /針葉樹林/
しんようじょう /信用状/
しんようじょうほう /信用情報/
しんようせい /信用性/
しんようそうぞう /信用創造/
しんようちょうさ /信用調査/
しんようちょうさがいしゃ /信用調査会社/
しんようとりひき /信用取引/
しんようど /信用度/
しんようほけん /信用保険;credit insurance. 従業者の不正等による損害を補填。「身元-」/
しんようほしょう /信用保証/
しんようりすく /信用リスク/
しんようりょく /信用力/
しんよこはま /新横浜/
しんよこはまえき /新横浜駅/
しんよこはまどおり /新横浜通り/
しんら /森羅/
しんらい /信頼/新来/神来/
しんらいかいふく /信頼回復/
しんらいかん /信頼感/
しんらいかんけい /信頼関係/
しんらいくかん /信頼区間/
しんらいけいすう /信頼係数/
しんらいせい /信頼性/
しんらいちょう /新雷鳥/
しんらいど /信頼度/
しんらいのげんそく /信頼の原則/
しんらつ /辛辣/
しんらばんしょう /森羅万象/
しんらまんぞう /森羅万象/
しんらん /親鸞/
しんり /心理;mentality/真理;truth/審理;trial/心裡;-留保/心裏;=心裡/
しんりおんきょう /心理音響/
しんりかんすう /真理関数/
しんりがく /心理学/
しんりがくしゃ /心理学者/
しんりがくてき /心理学的/
しんりがくてきけんきゅう /心理学的研究/
しんりがくようご /心理学用語/
しんりがっか /心理学科/
しんりきょう /真理教/
しんりくうかん /心理空間/
しんりけん /心理研/
しんりけんさ /心理検査/
しんりげき /心理劇/
しんりさくせん /心理作戦/
しんりし /心理士/
しんりしゅぎ /心理主義;mentalism/
しんりじっけん /心理実験/
しんりじょう /心理上/
しんりじょうきょう /心理状況/
しんりじょうけん /真理条件;[論理]truth condition/
しんりじょうたい /心理状態/
しんりせい /真理性/
しんりせん /心理戦/
しんりち /真理値/
しんりちひょう /真理値表/
しんりつ /震慄/
しんりてき /心理的/
しんりてきえいきょう /心理的影響/
しんりてききょり /心理的距離/
しんりてきこうか /心理的効果/
しんりてきしょうげき /心理的衝撃/
しんりてきちりょう /心理的治療/
しんりてすと /心理テスト/
しんりひょう /真理表/
しんりびょうしゃ /心理描写/
しんりぶつりがく /心理物理学/
しんりぶつりがくてき /心理物理学的/
しんりぶつりじっけん /心理物理実験/
しんりぶつりてき /心理物理的/
しんりぶんせき /心理分析/
しんりゃく /侵略/侵掠;≒侵略/
しんりゃくこうい /侵略行為/
しんりゃくこく /侵略国/
しんりゃくざい /侵略罪/
しんりゃくしゃ /侵略者/
しんりゃくせい /侵略性/
しんりゃくせんそう /侵略戦争/
しんりゃくち /侵略地/
しんりゃくちゅう /侵略中/
しんりゃくてき /侵略的/
しんりゃくてきこうい /侵略的行為/
しんりゃくろん /侵略論/
しんりや /心理屋/
しんりゅう /神龍/神竜/
しんりょ /深慮/神慮/
しんりょう /診療/神領/新涼/
しんりょうか /診療科/
しんりょうかもく /診療科目/
しんりょうきん /新料金/
しんりょうしつ /診療室/
しんりょうしょ /診療所/
しんりょうじょ /診療所/
しんりょうたいせい /診療体制/
しんりょうだいきん /診療代金/
しんりょうちゅう /診療中/
しんりょうないか /心療内科/
しんりょうほうしゅう /診療報酬/
しんりょうほうしゅうめいさいしょ /診療報酬明細書/
しんりょく /新緑/深緑/神力/心力/真緑/
しんりりゅうほ /心裡留保/
しんりりょうほう /心理療法/
しんりろん /新理論/
しんりん /森林/親臨/
しんりんかさい /森林火災/
しんりんくみあい /森林組合/
しんりんげんかい /森林限界;森林育成の上限,亜寒帯と寒帯の境,亜高山帯と高山帯の境/
しんりんこうえん /森林公園/
しんりんしげん /森林資源/
しんりんしょくぶつがく /森林植物学/
しんりんせいび /森林整備/
しんりんそうけん /森林総研/
しんりんちたい /森林地帯/
しんりんてつどう /森林鉄道/
しんりんばっさい /森林伐採/
しんりんほう /森林法/
しんりんよく /森林浴/
しんるーる /新ルール/
しんるい /親類/
しんるいえんじゃ /親類縁者/
しんるいすじ /親類筋/
しんるいぶん /進塁分/
しんれい /心霊/神霊/浸礼/新例/振鈴/
しんれいげんしょう /心霊現象/
しんれいしゃしん /心霊写真/
しんれいしょり /深冷処理/
しんれいじゅつ /心霊術/
しんれいてき /心霊的/
しんれいばい /新冷媒/
しんれき /新暦/
しんれつ /進列/
しんれんさい /新連載/
しんろ /進路/針路;磁針の示す進路。「艦隊の-」/
しんろう /新郎/心労/身廊/辛労/滲漏/
しんろうがわ /新郎側/
しんろうしんぷ /新郎新婦/
しんろきぼう /進路希望/
しんろく /新録/神鹿/
しんろくおん /新録音/
しんろしどう /進路指導/
しんろじょう /進路上/
しんろせん /新路線/
しんろそうだん /進路相談/
しんろへんこう /進路変更/
しんろへんこうきんし /進路変更禁止/
しんろぼうがい /進路妨害/
しんろめい /進路名/
しんろん /新論/
しんわ /神話/親和/新和/
しんわかいうん /新和海運/
しんわかんけい /神話関係/
しんわがく /神話学;mythology/
しんわぎんこう /親和銀行/
しんわじてん /神話辞典/
しんわじょう /神話上/
しんわせい /親和性/
しんわせかい /神話世界/
しんわたいけい /神話体系/
しんわだ /新和田/
しんわてき /神話的/
しんわりょく /親和力/
じ /字/地/辞;(あいさつ)閉式の-/痔/時/事/自/次/寺/路/児/柱;琴柱/璽;玉-/爾;thou,that/尓;「爾」の異体字/邇;(ちかい)/迩;「邇」の異体字/而;しかして/粫/轜;(柩車)/侍;侍従/持;持参/峙;対峙/恃;矜恃/畤;(まつりのにわ)/蒔;ま・く/塒;ねぐら/示;示威/祀;(呉音) 祭祀/耳;耳鼻/餌;好餌/珥;(みみだま)/慈;慈悲/滋;滋養/磁;磁石/孳;(うむ)/茲;ここ/似;類似/亊;「事」の異体字/岻/怩;忸怩/瓷;瓷器/膩;(あぶら)/辭;「辞」の旧字/二;不二/弍;「二」の異体字/兒;「児」の旧字(人名用漢字)/子;(連濁)柑子/司;(連濁)宮司/至;(連濁)冬至/仕;(呉音)給仕/除;(慣用音)除目/治;(呉音)政治/冶;(や。当て字)刀鍛冶/士;(呉音)/嗣;(呉音)/史;(人名用)/仁;(人名用)/知;ご存知,?/寿;?/爺;じい?/以;い?/只;し,ただ?/
じ> /次/
じーぱん /Ｇパン/Gパン/
じーめん /Ｇメン/Gメン/
じあ /次亜;[化学]-塩素酸,-リン酸,硫酸Na/
じあ> /次亜;[化学]-塩素酸,-リン酸,硫酸Na/
じあい /自愛/慈愛/地合/時合/地合い/試合/
じあえんそさん /次亜塩素酸/
じあえんそさんえん /次亜塩素酸塩/
じあげ /地上げ/地上/
じあぞか /ジアゾ化/
じあまり /字余り/
じあめ /地雨/
じあん /事案/治安;年号(1021-1024)/
じい /自慰/爺/辞意/示威/侍医/次位/字彙/辞彙/磁位/事彙/
じいがたけ /爺ヶ岳/
じいき /寺域/
じいこう /時以降/
じいこうい /自慰行為/
じいさま /爺様/
じいさん /爺さん/祖父さん/
じいしき /自意識/
じいしきかじょう /自意識過剰/
じいた /地板/
じいてき /示威的/自慰的/
じいぱん /Ｇパン/
じいや /爺や/
じいろ /地色/
じいん /寺院/次韻/
じいんけんちく /寺院建築/
じう /慈雨/時雨/
じうえ /地植え/
じうた /地歌/
じうたい /地謡/
じうん /時運/
じぇーぽっぷ /Ｊポップ/Jポップ/
じぇーりーぐ /Ｊリーグ/
じぇいあーるひがしにほん /JR東日本/
じぇっとき /ジェット機/
じぇっとふんしゃ /ジェット噴射/
じえい /自営/自衛/侍衛/
じえいかん /自衛官/自衛艦/
じえいぎょう /自営業/
じえいぎょうしゃ /自営業者/
じえいけん /自衛権/
じえいさく /自衛策/
じえいしゅだん /自衛手段/
じえいしょうぼうたい /自衛消防隊/
じえいせんそう /自衛戦争/
じえいそしき /自衛組織/
じえいたい /自衛隊/
じえいたいいん /自衛隊員/
じえいたいき /自衛隊機/
じえいたいさんか /自衛隊参加/
じえいたいしょぞく /自衛隊所属/
じえいたいほう /自衛隊法/
じえん /自演/慈円;(1155-1225) 『愚管抄』/
じお /塩/
じおう /地黄/
じおり /地織/
じおん /字音/
じおんじ /慈恩寺/
じか /自家/時価/直/時下/磁化;magnetise/字化/耳科/磁荷;magnetic charge/時課/自歌/
じか> /直;直談判,直焼き,直リン/
じかい /次回/磁界/自戒/自壊/耳介/持戒/字解/辞海;文語中国語の辞典/次会/
じかいいこう /次回以降/
じかいかいぎ /次回会議/
じかいかんじ /次回幹事/
じかいけい /磁界系/
じかいこうえん /次回公演/
じかいさく /次回作/
じかいしゃけん /次回車検/
じかいとうこう /次回投稿/
じかいにってい /次回日程/
じかいよこく /次回予告/
じかうち /直打ち/
じかかいけい /時価会計/
じかきょくせん /磁化曲線/
じかく /自覚/痔核/字画/寺格/耳殻/時隔/
じかくしだい /自覚次第/
じかくしょうじょう /自覚症状/
じかくすう /字画数/
じかくてき /自覚的/
じかけ /仕掛け/仕掛/
じかげんぞう /自家現像/
じかさいばい /自家栽培/
じかしゅぎ /時価主義/
じかしゅっぱん /自家出版/
じかしょうひ /自家消費/
じかしょり /自家処理/
じかじゅせい /自家受精/自花受精/
じかじゅふん /自家受粉/
じかず /字数/
じかせい /自家製/
じかせいみそ /自家製味噌/
じかせん /耳下腺/
じかせんえん /耳下腺炎/
じかそうがく /時価総額/
じかた /地方/
じかたしょ /地方書/
じかたび /地下足袋/
じかたもんじょ /地方文書/
じかだん /直談/
じかだんぱん /直談判/
じかちゅうどく /自家中毒/
じかつ /自活/
じかづけ /直付け/
じかづみ /直積/
じかとりひき /直取引/
じかどうちゃく /自家撞着/
じかに /直に/
じかはっこう /時価発行/
じかはつでん /自家発電/
じかばき /直穿き/直履き/
じかび /直火/
じかびしき /直火式/
じかほう /時価法/
じかまき /直播き;[農業]苗でなく、種籾を直接蒔くこと/
じかやき /直焼き/
じかやくろうちゅう /自家薬籠中/
じかよう /自家用/
じかようしゃ /自家用車/
じかろ /地火炉/
じかん /時間/次官/字間/耳管/耳間/
じかんいがい /時間以外/
じかんいぞん /時間依存/
じかんいってい /時間一定/
じかんいない /時間以内/
じかんうんてん /時間運転/
じかんえいぎょう /時間営業/
じかんおくれ /時間遅れ/
じかんか /時間化/
じかんかじゅう /時間荷重/
じかんかせぎ /時間稼ぎ/
じかんかへん /時間可変/
じかんかんかく /時間間隔;time interval/時間感覚;sense of time/
じかんかんけい /時間関係/
じかんかんり /時間管理/
じかんがい /時間外/
じかんがいかさん /時間外加算/
じかんがいてあて /時間外手当/
じかんがいねん /時間概念/
じかんきゅう /時間給/時間休/次官級/
じかんきれ /時間切れ/
じかんきろく /時間記録/
じかんぎれ /時間切れ/
じかんくかん /時間区間/
じかんけいか /時間経過/
じかんけいやく /時間契約/
じかんけいれつ /時間系列/
じかんげいじゅつ /時間芸術;Zeitkunst. 音楽・文学など。⇔空間芸術/
じかんげんしゅ /時間厳守/
じかんこうか /時間効果/
じかんこうぞう /時間構造/
じかんご /時間後/
じかんごと /時間毎/
じかんさ /時間差/
じかんさこうげき /時間差攻撃;[バレーボール]フェイントでブロックをかいくぐる戦法/
じかんさぶん /時間差分/
じかんざひょう /時間座標/
じかんしてい /時間指定/
じかんしょうとつ /時間衝突/
じかんしょり /時間処理/
じかんしんごう /時間信号/
じかんじく /時間軸/
じかんじくじょう /時間軸上/
じかんじくほうこう /時間軸方向/
じかんじっけん /時間実験/
じかんじょうほう /時間情報/
じかんじょうほうしょり /時間情報処理/
じかんすう /時間数/
じかんせい /時間制/時間性/
じかんせいげん /時間制限/
じかんせいぶん /時間成分/
じかんせきぶん /時間積分/
じかんせってい /時間設定/
じかんせつ /時間説/
じかんせん /時間線/
じかんそう /時間走/
じかんそくてい /時間測定/
じかんそんしつ /時間損失/
じかんたい /時間帯/
じかんたいきゅう /時間耐久/
じかんたんしゅく /時間短縮/
じかんたんしゅくこうか /時間短縮効果/
じかんちえん /時間遅延/
じかんちかく /時間知覚/
じかんちゅう /時間中/
じかんちょう /時間長/
じかんちょうせい /時間調整/
じかんつぶし /時間潰し/
じかんていし /時間停止/
じかんていど /時間程度/
じかんてき /時間的/
じかんてきけいか /時間的経過/
じかんてきよういん /時間的要因/
じかんてきよゆう /時間的余裕/
じかんとくせい /時間特性/
じかんない /時間内/
じかんはいぶん /時間配分/
じかんはけい /時間波形/
じかんはってん /時間発展/
じかんはん /時間半/
じかんはんざい /時間犯罪/
じかんはんてん /時間反転/
じかんひ /時間比/
じかんひょう /時間表/
じかんひょうじ /時間表示/
じかんびぶん /時間微分/
じかんぶそく /時間不足/
じかんぶん /時間分/
じかんぶんかいのう /時間分解能/
じかんへいきん /時間平均/
じかんへいきんち /時間平均値/
じかんへんか /時間変化/
じかんへんこう /時間変更/
じかんへんどう /時間変動/
じかんべつ /時間別/
じかんほうこう /時間方向/
じかんまえ /時間前/
じかんまち /時間待ち/時間待/
じかんまど /時間窓/
じかんむせいげん /時間無制限/
じかんめ /時間目/
じかんようそ /時間要素/
じかんりつ /時間率/
じかんりょういき /時間領域/
じかんりょこう /時間旅行/
じかんれつ /時間列/
じかんろん /時間論/
じかんろんり /時間論理/
じかんわく /時間枠/
じかんわり /時間割/
じかんわりひょう /時間割表/
じが /自我/自画/
じがい /自害/
じがいしき /自我意識/
じがお /地顔/
じがく /自学/
じがじさん /自画自賛/自画自讃/
じがぞう /自画像/
じがため /地固め/
じがね /地金/
じがみ /地神/地紙/
じがめん /自画面/
じがん /慈顔/
じき /時期;period/次期;next period/磁気;magnetism/磁器;porcelain/直/時季;season/自機/時機;chance/自棄;自暴-/自記/食/喰/敷/瓷器/
じき> /直;直弟子,直取引,直状/
じきあらし /磁気嵐/
じきか /磁気化/
じきかーど /磁気カード;magnetic card/
じきかいてい /次期改訂/
じきかいろ /磁気回路/
じききろく /磁気記録/
じききろくばいたい /磁気記録媒体/
じきけん /磁気圏/
じきこうほ /次期候補/
じきこっかい /次期国会/
じきごと /時期毎/
じきさ /時期差/
じきさくひん /次期作品/
じきさん /直参/
じきしげき /磁気刺激/
じきしつ /磁器質/
じきしゃへい /磁気遮蔽/
じきしゅ /次機種/
じきしょ /直書/
じきしょうそう /時期尚早/
じきしょうそうろん /時期尚早論/
じきじき /直々/
じきじきに /直々に/
じきじょう /直状/
じきじょうほう /磁気情報/
じきすう /時期数/
じきせい /磁器製/
じきせつ /直説/
じきそ /直訴/
じきそう /直奏/
じきたんい /時期単位/
じきだん /直談/
じきだんぱん /直談判/
じきちゅう /時期中/
じきちりょうき /磁気治療器/
じきてーぷ /磁気テープ/
じきてき /時期的/自棄的/
じきでぃすく /磁気ディスク;magnetic disk(MD)/
じきでし /直弟子/
じきでん /直伝/
じきとう /直答/
じきとりひき /直取引/
じきに /直に/
じきばいたい /磁気媒体/
じきひつ /直筆/
じきふ /食封/
じきふじょうてつどう /磁気浮上鉄道/
じきふめい /時期不明/
じきぶん /時期分/
じきへっど /磁気ヘッド;[電算]magnetic head/
じきぼう /次期防/
じきみや /直宮/
じきもの /直物;直物相場/
じきもん /直門/
じきゅう /時給;hourly wages/自給;self-support/持久/自救;help oneself/
じきゅうこうい /自救行為/
じきゅうじそく /自給自足/
じきゅうせん /持久戦/
じきゅうそう /持久走/
じきゅうりつ /自給率/
じきゅうりょく /持久力/
じきゆうどう /磁気誘導;[物理]/
じきょ /辞去/
じきょう /自供/耳鏡;[医]otoscope/持経/
じきょうげん /地狂言/
じきょうじゃ /持経者/
じきょく /時局/自局/磁極/
じきらん /直覧/
じきりょく /磁気力/
じきわ /直話/
じぎ /時宜/字義/児戯/辞儀/
じぎどおり /字義通り/
じぎゃく /自虐/
じぎゃくてき /自虐的/
じぎょう /事業/次行/事行/
じぎょうか /事業家/
じぎょうかい /事業会/
じぎょうかいはつしつ /事業開発室/
じぎょうかいはつぶ /事業開発部/
じぎょうかつどう /事業活動/
じぎょうがいしゃ /事業会社/
じぎょうきょうどうくみあい /事業協同組合/
じぎょうけいかく /事業計画/
じぎょうしつ /事業室/
じぎょうしゃ /事業者/
じぎょうしゃがわ /事業者側/
じぎょうしゅ /事業主/
じぎょうしゅうにゅう /事業収入/
じぎょうしょ /事業所/
じぎょうしょかん /事業所間/
じぎょうしょぜい /事業所税/
じぎょうしょとく /事業所得/
じぎょうしょない /事業所内/
じぎょうじゅんびしつ /事業準備室/
じぎょうじょう /事業場/
じぎょうすいしん /事業推進/
じぎょうすいしんしつ /事業推進室/
じぎょうすいしんぶ /事業推進部/
じぎょうすいしんほんぶ /事業推進本部/
じぎょうぜい /事業税/
じぎょうたい /事業体/
じぎょうだん /事業団/
じぎょうてんかい /事業展開/
じぎょうないよう /事業内容/
じぎょうぬし /事業主/
じぎょうねんど /事業年度/
じぎょうひ /事業費/
じぎょうぶ /事業部/
じぎょうぶかいはつ /事業部開発/
じぎょうぶかいはつぶ /事業部開発部/
じぎょうぶせい /事業部制/
じぎょうぶちょう /事業部長/
じぎょうぶない /事業部内/
じぎょうぶもん /事業部門/
じぎょうぶんや /事業分野/
じぎょうほう /事業法/
じぎょうほうこくしょ /事業報告書;財務諸表の1つ/
じぎょうほんぶ /事業本部/
じぎょうよう /事業用/
じぎょうようしゃ /事業用車/
じぎょうりょういき /事業領域/
じぎわ /地際/
じく /軸/字句/磁区;[物理]magnetic domain/舳;へさき/竺;天竺/宍;(肉)/衄/衂;「衄」の異体字/忸;忸怩/
じくあし /軸足/
じくう /時空/
じくうい /時空意/
じくうかん /時空間/
じくうけ /軸受/軸受け/
じくかいせき /字句解析/
じくかいせきき /字句解析器/
じくかん /軸間/時区間/次区間/
じくがい /軸外/
じくぎ /軸木/
じくぐみ /軸組/
じくぐみこうほう /軸組工法/
じくこてい /軸固定/
じくさく /軸索/
じくさくとっき /軸索突起;軸索,神経細胞から出る一本の長い突起,⇔樹状突起/
じくじ /忸怩/
じくじゅう /軸重/
じくじょう /軸上/
じくじょうほう /軸情報/
じくすう /軸数/
じくずれ /地崩れ/
じくせい /軸性;axial/
じくせいぶん /軸成分/
じくせん /軸線/
じくそう /軸装/
じくそうかん /軸相関/
じくたいしょう /軸対称/
じくない /軸内/
じくはら /軸原;姓/
じくばこ /軸箱/
じくばり /字配り/
じくほうこう /軸方向/
じくまわり /軸回/
じくもの /軸物/
じくや /軸屋/
じくりつ /軸率;[化学]axial ratio/
じくりゅう /軸流/
じくろ /舳艫/
じくん /字訓;古語辞典/二君/
じぐ /治具;jig/
じぐち /地口/
じぐん /自軍/
じけ /寺家/
じけい /字形/字型/慈恵/次兄/自警/
じけいいだいびょういん /慈恵医大病院/
じけいだん /自警団/
じけいれつ /時系列/
じけいれつかいせき /時系列解析/
じけいれつしょり /時系列処理/
じけいれつじゅん /時系列順/
じけつ /自決/
じけん /事件/
じけんいらい /事件以来/
じけんかんれん /事件関連/
じけんきしゃ /事件記者/
じけんげんば /事件現場/
じけんご /事件後/
じけんしょり /事件処理/
じけんせい /事件性/
じけんちょう /事件帳/
じけんはっかくご /事件発覚後/
じけんばんごう /事件番号/
じけんぼ /事件簿/
じげ /地毛/自解/地下/
じげにん /地下人/
じげん /次元/時限/字源/事言/示現/示顕/辞源/
じげんか /次元化/
じげんかいせき /次元解析/
じげんがぞうしょり /次元画像処理/
じげんくうかん /次元空間/
じげんけんきゅうかい /時限研究会/
じげんしき /時限式/
じげんじょう /次元上/
じげんすう /次元数/
じげんそう /次元窓/
じげんそうち /時限装置/
じげんてき /次元的/時限的/
じげんばくだん /時限爆弾/
じげんめ /時限目/
じげんりっぽう /時限立法/
じげんりゅう /示現流;剣術の一派/
じこ /自己/事故/
じこ> /自己;-批判,-充足,-投資/
じこあい /自己愛/
じこあぴーる /自己アピール/
じこあんじ /自己暗示/
じこいしき /自己意識/
じこいちすいてい /自己位置推定/
じこいらい /事故以来/
じこう /事項/次項/時効;prescription/自校/時候;season/時好/耳孔/事行/
じこうきかん /時効期間/
じこうさくいん /事項索引/
じこうしき /字光式/
じこうだいにごう /次項第二号/
じこうほ /次候補/
じこかいかく /自己改革/
じこかいき /自己回帰/
じこかいけつ /自己解決/
じこかいぞう /自己改造/
じこかいとう /自己解凍/
じこかいとうけいしき /自己解凍形式/
じこかくちょう /自己拡張/
じこかぶ /自己株/
じこかぶしき /自己株式/
じこかんけつ /自己完結/
じこかんけつがた /自己完結型/
じこかんけつてき /自己完結的/
じこかんしょう /自己干渉/
じこかんり /自己管理/
じこがくしゅうがた /自己学習型/
じこきじゅん /自己基準/
じこきせい /自己規制/
じこきゅうしゅう /自己吸収/
じこきょうぶんさん /自己共分散/
じこきろく /自己記録/
じこきんゆう /自己金融/
じこぎせい /自己犠牲/
じこぎまん /自己欺瞞/
じこく /時刻/自国/二黒;[陰陽道]/
じこくいこう /時刻以降/
じこくご /自国語/
じこくせい /自国製/
じこくてん /持国天/
じこくない /自国内/
じこくひょう /時刻表/
じこくひょうじ /時刻表示/
じこくひょうふっこくばん /時刻表復刻版/
じこくぶんか /自国文化/
じこくみん /自国民/
じこくらん /時刻欄/
じこくりょう /自国領/
じこくんれん /自己訓練/
じこけいせい /自己形成/
じこけいたい /事故形態/
じこけいはつ /自己啓発/
じこけいやく /自己契約/
じこけっていけん /自己決定権/
じこけんお /自己嫌悪/
じこけんじよく /自己顕示欲/
じこげんきゅう /自己言及/
じこげんきゅうせい /自己言及性;self-reference/
じこげんば /事故現場/
じここうたい /自己抗体;自己免疫により作られる抗体/
じこご /事故後/
じこさいこう /自己最高/
じこさいてん /自己採点/
じこさいみん /自己催眠/
じこさてい /自己査定/
じこさんしょう /自己参照/
じこし /事故死/
じこしほん /自己資本;資本金、法定準備金、剰余金の3つ/
じこしほんひりつ /自己資本比率/
じこしぼうりつ /事故死亡率/
じこしゃ /事故車/
じこしゃへい /自己遮蔽/
じこしゅうふく /自己修復/
じこしゅうふくきのう /自己修復機能/
じこしゅちょう /自己主張/
じこしょうか /自己消化/
じこしょうかい /自己紹介/
じこしょうかいぶん /自己紹介文/
じこしょうめい /事故証明/
じこしん /自己新;自己新記録/
じこしんこく /自己申告/
じこしんせい /自己申請/
じこしんだん /自己診断/
じこじ /事故時/
じこじつげん /自己実現/
じこじゅうそく /自己充足/
じこじゅうたい /事故渋滞/
じこじょうけん /自己条件/
じこじょうほう /自己情報/
じこすう /事故数/
じこせいとうか /自己正当化/
じこせきにん /自己責任/事故責任/
じこぜんご /事故前後/
じこそうかん /自己相関/
じこそうかんかんすう /自己相関関数/
じこそうかんけいすう /自己相関係数/
じこそうじ /自己相似/
じこそうじせい /自己相似性/
じこそうぞう /自己創造/
じこそがい /自己疎外;精神による自己否定/
じこそしき /自己組織/
じこそしきか /自己組織化/
じこそしきかこうぞう /自己組織化構造/
じこそしきかほう /自己組織化法/
じこそしきけい /自己組織系/
じこそしきてき /自己組織的/
じこぞうしょく /自己増殖/
じこぞうしょくがた /自己増殖型/
じこちゅう /自己中;[口]自己中心的(な人)/事故中/
じこちゅうしん /自己中心/
じこちゅうしんてき /自己中心的/
じこちゅうしんは /自己中心派/
じこちょうさ /事故調査/自己調査/
じこちょうせつ /自己調節/
じこちょくご /事故直後/
じこつごう /自己都合/
じこていせい /自己訂正/
じこてきよう /自己適用/
じことうえい /自己投影/
じことうじ /事故当時/
じことうすいてき /自己陶酔的/
じこどういつせい /自己同一性;identity/
じこどうけい /自己同型/
じこどうけいぐん /自己同型群/
じこないよう /事故内容/
じこにんしき /自己認識/
じこはあく /自己把握/
じこはかい /自己破壊/
じこはさん /自己破産/
じこはさんしんせい /自己破産申請/
じこはっせい /事故発生/
じこはっせいりつ /事故発生率/
じこはんえい /自己反映/
じこはんえいけいさん /自己反映計算/
じこはんせい /自己反省/
じこばいばい /自己売買;証券会社が自らの勘定で行う有価証券の売買,⇔委託売買/
じこひげ /自己卑下/
じこひてい /自己否定/
じこひはん /自己批判/
じこひょうか /自己評価/
じこひょうげん /自己表現/
じこぴーあーる /自己ＰＲ/自己PR/
じこふくせいし /自己複製子/
じこふたん /自己負担/
じこふたんがく /自己負担額/
じこぶんせき /自己分析/
じこべすと /自己ベスト/
じこべんかい /自己弁解/
じこべんご /自己弁護/
じこほうこく /事故報告/
じこほぞん /自己保存/
じこほぞんほんのう /自己保存本能/
じこほんい /自己本位/
じこぼうえい /自己防衛/
じこぼうえいさく /自己防衛策/
じこぼうえいほんのう /自己防衛本能/
じこぼうぎょ /自己防御/
じこぼうし /事故防止/
じこぼうしこうか /事故防止効果/
じこまん /自己満;自己満足/
じこまんぞく /自己満足/
じこみ /仕込み/
じこむじゅん /自己矛盾/
じこむどうちゃく /自己無撞着/
じこめんえき /自己免疫;[生物]autoimmunity/
じこもくてきか /自己目的化/
じこよくせい /自己抑制/
じこりつ /事故率/
じこりゅう /自己流/
じこりゅうかいしゃく /自己流解釈/
じこれい /事故例/
じこれき /事故歴/
じこれんびん /自己憐憫/
じころ /時頃/
じご /事後/爾後/持碁/耳語/
じごう /次号/寺号/自業/
じごうじとく /自業自得/
じごうよこく /次号予告/
じごえ /地声/
じごく /地獄/
じごくえ /地獄絵/
じごくえず /地獄絵図/
じごくかい /地獄界/
じごくず /地獄図/
じごくだに /地獄谷/
じごくどう /地獄道;[仏教]/
じごくへん /地獄変;地獄変相,地獄変相の略/地獄篇;神曲の-/
じごくみみ /地獄耳/
じごごうとう /事後強盗;窃盗犯が窃盗の後に強盗を行うこと/
じごしょうだく /事後承諾/
じごしょり /事後処理/
じごてき /事後的/
じごほうこく /事後報告/
じごれんらく /事後連絡/
じごろ /時頃/
じごろう /滋悟郎/
じさ /時差/橲/
じさいてき /次最適/
じさいと /自サイト/
じさく /自作/次作/治作/
じさくきじ /自作記事/
じさくきょく /自作曲/
じさくじえん /自作自演/
じさくじゅつ /自作術/
じさくのう /自作農/
じさくは /自作派/
じさくひん /自作品/
じさくよう /自作用/
じさげ /字下げ/
じさしき /時差式/
じさしゅっきん /時差出勤/
じさつ /自殺/
じさついじ /自殺遺児/
じさつかんよざい /自殺関与罪/
じさつこうい /自殺行為/
じさつしゃ /自殺者/
じさつてき /自殺的;suicidal/
じさつてん /自殺点/
じさつほうじょ /自殺幇助/
じさつみすい /自殺未遂/
じさつよう /自殺用/
じさばら /橲原/
じさぶろう /治三朗/
じさぼけ /時差ボケ/
じさん /持参/自賛/自讃/自参/
じさんきん /持参金/
じざい /自在/
じざいてん /自在天/
じざかい /地境/
じざけ /地酒/
じし /自死/次子/示指/獅子/慈氏/侍史/自恣/
じしいじ /自死遺児/
じしき /次式/
じしつ /自室/痔疾/自失;茫然-/地質/
じしぼさつ /慈氏菩薩/
じしゃ /自社/寺社/自車/侍者/辞謝/轜車;昔の霊柩車/
じしゃかいはつ /自社開発/
じしゃかぶ /自社株/
じしゃく /磁石/
じしゃくか /磁石化/
じしゃせい /自社製/
じしゃせいさん /自社生産/
じしゃせいひん /自社製品/
じしゃせん /自車線/
じしゃせんない /自社線内/
じしゃない /自社内/
じしゃはっちゅうしゃ /自社発注車/
じしゃびん /自社便/
じしゃぶぎょう /寺社奉行/
じしゃわく /自社枠/
じしゅ /自主/自首/字種/時衆/寺主/
じしゅ> /自主;-法,-検査,-流通/
じしゅう /次週/自習/時宗/自修/時衆/
じしゅういこう /次週以降/
じしゅうしつ /自習室/
じしゅうよう /磁州窯/
じしゅうようきょうざい /自習用教材/
じしゅうよこく /次週予告/
じしゅかいはつ /自主開発/
じしゅかんり /自主管理/
じしゅきせい /自主規制/
じしゅく /自粛/
じしゅくきかん /自粛期間/
じしゅくちゅう /自粛中/
じしゅけん /自主権/
じしゅけんさ /自主検査/
じしゅけんぽうせいてい /自主憲法制定/
じしゅこうぎょう /自主興行/
じしゅざいげん /自主財源;地方税など. ⇔依存財源/
じしゅじょうえい /自主上映/
じしゅじょうえいかい /自主上映会/
じしゅせい /自主性/
じしゅせいさく /自主制作/自主製作/
じしゅせいさくえいが /自主製作映画/
じしゅせいさくばん /自主製作盤/自主制作版/
じしゅせんゆう /自主占有/
じしゅたいしょく /自主退職/
じしゅてき /自主的/
じしゅてんけん /自主点検/
じしゅとれ /自主トレ;<training/
じしゅどくおう /自主独往/
じしゅどくりつ /自主独立/
じしゅはっこう /自主発行/
じしゅはんだん /自主判断/
じしゅばん /自主盤/
じしゅりゅうつう /自主流通/
じしゅりゅうつうまい /自主流通米/
じしょ /辞書/地所/自署;signature/字書;字引/自書;自筆/璽書/
じしょう /自称/事象/次章/自傷;自傷行為/時称;[文法]tense/時鐘;time bell/自照;自己観照/治承;年号(1177-81)/自性;[仏教]/時尚/自象;?/
じしょう> /自称;(would-be) -右翼,-名人/
じしょうぎ /持将棋/
じしょうくどう /事象駆動/
じしょうこうい /自傷行為/
じしょうじ /慈照寺;銀閣寺の正式な名前/
じしょかんり /辞書管理/
じしょがくしゅう /辞書学習/
じしょく /辞職/自食/辞色;tones and expressions/
じしょくかんこく /辞職勧告/
じしょくねがい /辞職願/
じしょけいしき /辞書形式/
じしょけんさく /辞書検索/
じしょしき /辞書式/
じしょしきじゅんじょ /辞書式順序/
じしょじゅん /辞書順/
じしょじょうほう /辞書情報/
じしょてき /辞書的/
じしょとうろく /辞書登録/
じしょとうろくきのう /辞書登録機能/
じしょないよう /辞書内容/
じしょびき /辞書引き/
じしょぶん /辞書分/
じしょめい /辞書名/
じしょもの /辞書物/
じしん /自身;†self.「自分-」/自信;†confidence.「-がない」/地震/磁針;magnetic needle/時針;hour hand/磁心;magnetic core/侍臣/地神/
じしんか /自信家/
じしんかじょう /自信過剰/
じしんかんそく /地震観測/
じしんがく /地震学/
じしんがっかい /地震学会/
じしんけい /地震計/
じしんけん /地震研/
じしんけんきゅうしょ /地震研究所/
じしんけんきゅうじょ /地震研究所/
じしんげん /地震源/
じしんこうがく /地震工学/
じしんさく /自信作/
じしんじょうほう /地震情報/
じしんぜんちょうげんしょう /地震前兆現象/
じしんそうしつ /自信喪失/
じしんだんそう /地震断層/
じしんちたい /地震地帯/
じしんどう /地震動/
じしんなし /自信無/
じしんは /地震波/
じしんはっせい /地震発生/
じしんほけん /地震保険/
じしんまんまん /自信満々/
じしんや /地震屋/
じしんよち /地震予知/
じしんよちけんきゅう /地震予知研究/
じしんよちじょうほう /地震予知情報/
じしんりょく /地震力/
じじ /時事/爺/時々/自恃/
じじい /爺/
じじえいご /時事英語/
じじかい /次々回/次次回/
じじく /耳軸/
じじこくこく /時々刻々/
じじこっこく /時々刻々/時時刻刻/
じじさま /爺様/
じじつ /事実/時日/
じじつうしんしゃ /時事通信社/
じじつかくにん /事実確認/
じじつかんけい /事実関係/
じじつこん /事実婚/
じじつごにん /事実誤認/
じじつしん /事実審/
じじつじょう /事実上/
じじつじょうかいさん /事実上解散/
じじつじょうふかのう /事実上不可能/
じじつてき /事実的/
じじつにんしき /事実認識/
じじつにんてい /事実認定/
じじつほうこく /事実報告/
じじつむこん /事実無根/
じじつもんだい /事実問題/
じじねた /時事ネタ/
じじばば /爺婆/祖父祖母/
じじぶつぶつ /事事物物/
じじもんだい /時事問題/
じじゃく /自若;泰然-/示寂;[仏教]菩薩の死/
じじゅう /自重/侍従/
じじゅうしょく /侍従職;宮内庁-。 天皇・皇后担当/
じじゅうちょう /侍従長;宮内庁侍従職の長/
じじゅん /耳順;60歳/次順;next up/
じじょ /次女/自助/侍女/二女/自序/自叙/
じじょう /事情/次条;⇔前条/二乗;n^2/自浄;-作用/自乗;n*n/治定/磁場;=じば/２乗/2乗/
じじょうけんてい /二乗検定/
じじょうこん /自乗根;[数学]sqrt/
じじょうごさ /二乗誤差/2乗誤差/
じじょうさよう /自浄作用/
じじょうじばく /自縄自縛;自業自得/
じじょうせつめい /事情説明/
じじょうたい /次状態/
じじょうだいいっこう /次条第一項/
じじょうちょうしゅ /事情聴取/
じじょうつう /事情通/
じじょうのうりょく /自浄能力/
じじょうへいきん /二乗平均/
じじょうほう /二乗法/
じじょうわ /二乗和/自乗和/２乗和/2乗和/
じじょぐ /自助具/
じじょでん /自叙伝/
じじょどりょく /自助努力/
じじようご /時事用語/
じじん /自陣/自刃/時人/自尽/
じすい /自炊/
じすう /字数/時数/次数/
じすうかん /次数間/
じすうしてい /字数指定/
じすうせいげん /字数制限/
じすこーど /JISコード;Japanese Industrial Standard Code/
じすぷろしうむ /Dy/Dysprosium/
じすべり /地滑り/地すべり/
じすべりてき /地滑り的;landslide/
じず /次図/
じずめ /字詰め;※仮名遣い「じづめ」/
じずら /字面;※仮名遣い「じづら」/
じずらどおり /字面通り;※仮名遣い「じづら」/
じせい /自生/磁性/自制/時世;ご-/時勢;-に逆らう/時制;[文法]tense/自省/辞世/自製/
じせいけん /自制研/
じせいしゅ /自生種;[植物]indigen/
じせいしん /自制心/
じせいたい /磁性体/
じせいふん /磁性粉/
じせき /自責/次席;⇔主席/事績;achievement/自席;own seat/事跡;trace/事蹟;=事跡/耳石;[解剖]statolith/
じせき> /次席;(assistant) -代表,-報道官/
じせきてき /自責的/
じせきてん /自責点/
じせきのねん /自責の念/
じせだい /次世代/
じせだいいこう /次世代以降/
じせだいき /次世代機/
じせつ /時節/自説/次節/持説/
じせつがら /時節柄/
じせん /自薦;recommend oneself/自選;-詩集/次戦/
じせんき /自戦記/
じせんしょ /自薦書/
じせんたせん /自薦他薦/
じせんよう /耳栓用/
じぜん /事前/慈善;charity/次善;second best/
じぜん> /事前;-申請,-登録/
じぜんうんどう /事前運動;根回し/
じぜんかくりつ /事前確率/
じぜんかつどう /慈善活動/
じぜんがくしゅう /事前学習/
じぜんこうにゅう /事前購入/
じぜんしてい /事前指定/
じぜんしんさ /事前審査/
じぜんじぎょう /慈善事業/
じぜんじゅんび /事前準備/
じぜんじょうけん /事前条件/
じぜんだんたい /慈善団体/
じぜんち /事前値/
じぜんちょうさ /事前調査/
じぜんつうこく /事前通告/
じぜんてき /事前的/
じぜんとうぎ /事前討議/
じぜんとうろく /事前登録/
じぜんとうろくふよう /事前登録不要/
じぜんはいふ /事前配布/
じぜんはっぴょう /事前発表/
じぜんひょうか /事前評価/
じぜんぶんぷ /事前分布/
じぜんよやく /事前予約/
じぜんよやくよう /事前予約要/
じぜんれんらく /事前連絡/
じそ /自訴/
じそう /自走/次走/事相/時相/寺僧/自掃/
じそうかのう /自走可能/
じそうしき /自走式/
じそうほう /自走砲/
じそうろんり /時相論理/
じそく /時速/磁束;[電磁気学]flux/自足/
じそくき /自速機/
じそくけい /磁束計;fluxmeter/
じそくみつど /磁束密度/
じそん /自尊;-心/自損;-事故/自存;aseity/児孫/
じそんしん /自尊心/
じそんじえい /自存自衛/
じそんじこ /自損事故/
じぞう /地蔵/
じぞうがお /地蔵顔/
じぞうとうげ /地蔵峠/
じぞうどう /地蔵堂/
じぞうぼん /地蔵盆/
じぞく /持続/
じぞくおん /持続音/
じぞくかのう /持続可能;sustainable/
じぞくかん /持続感/
じぞくかんせんしゃ /持続感染者/
じぞくじかん /持続時間/
じぞくせい /持続性/
じぞくてき /持続的/
じぞくりょく /持続力/
じた /自他/舌/
じたい /自体/事態/辞退/字体/字體/
じたいじょう /辞退状/
じたく /自宅/支度/仕度/
じたくけんじむしょ /自宅兼事務所/
じたくせい /自宅生/
じたくたいき /自宅待機/
じたくとうちゃく /自宅到着/
じたくまえ /自宅前/
じたくりょうよう /自宅療養/
じたくろくおん /自宅録音/
じたつ /示達/
じたとも /自他共/
じたん /時短/
じだ /耳朶/次打/
じだい /時代/次代;next generation/地代;rent/事大;-主義/
じだいおくれ /時代遅れ/時代後れ/
じだいかんかく /時代感覚;-の鋭い作家/
じだいぎれ /時代裂/
じだいくぶん /時代区分/
じだいげき /時代劇/
じだいこうしょう /時代考証;時代劇で設定された時代に適合するかどうかの考証/
じだいさくご /時代錯誤;アナクロニズム,時代後れ/
じだいさくごてき /時代錯誤的/
じだいし /時代史/
じだいしゅぎ /事大主義;虎の威をかる狐/
じだいしょうせつ /時代小説/
じだいしょく /時代色/
じだいじゅん /時代順/
じだいじょうきょう /時代状況/
じだいせい /時代性/
じだいせいしん /時代精神;ある時代の象徴的な精神,cf.民族精神/
じだいせってい /時代設定/
じだいそう /時代相/
じだいてき /時代的/
じだいはいけい /時代背景/
じだいまつり /時代祭;10・22,平安神宮/
じだいもの /時代物/
じだらく /自堕落/
じだん /示談/次段/
じだんこうしょう /示談交渉/
じだんだ /地団駄/地団太/
じち /自治/
じちいかだいがく /自治医科大学/
じちかい /自治会/
じちかいしつ /自治会室/
じちぎょうせい /自治行政/
じちく /自治区/
じちけん /自治権/
じちしょう /自治省;NB:2001年1月の中央省庁再編で総務省に再編された/自治相;†大臣/
じちせい /自治制/自治性/
じちせいふ /自治政府/
じちたい /自治体/
じちたいめい /自治体名/
じちだいがっこう /自治大学校/
じちだいじん /自治大臣/
じちだんたい /自治団体/
じちゅう /自註/自注/
じちょ /自著/
じちょう /次長/自重/自嘲/次丁/
じちょうぎみ /自嘲気味/
じちょうけんじ /次長検事;検事総長の補佐を行う検察官/
じちょうたん /次頂端/
じちょうてき /自嘲的/
じちよう /実用/
じちりょう /自治領/
じちろう /自治労/
じちん /自沈/
じちんさい /地鎮祭/
じっ /十/
じっか /実家/実科/
じっかい /十戒/十階/十界/十誡/実解/
じっかはく /実家泊/
じっかん /実感/十干/甲乙丙丁戊己庚辛壬癸;十干 ※abbrev/
じっかんじゅうにし /十干十二支/
じっき /実機/実記/
じっきょう /実況/実教;[仏教]方便でない、真の教え/
じっきょうけんぶん /実況見分/
じっきょうしゃ /実況者/
じっきょうしゅっぱん /実教出版;[出版社名]/
じっきょうじん /実況陣/
じっきょうせき /実況席/
じっきょうたんとう /実況担当/
じっきょうちゅうけい /実況中継/
じっきょうほうそう /実況放送/
じっきんしょう /十訓抄;説話集(1252)/
じっくんしょう /十訓抄/
じっけい /実刑/実兄/実景/実形;actual form/実系/
じっけいはんけつ /実刑判決/
じっけつ /十傑/
じっけん /実験;experiment/実権;power/実見;部屋の-/実検;首-/實驗/
じっけんいいんかい /実験委員会/
じっけんえいが /実験映画/
じっけんか /実験可/
じっけんかいし /実験開始/
じっけんかいしご /実験開始後/
じっけんかいせき /実験解析/
じっけんかがくしゃ /実験科学者/
じっけんかのう /実験可能/
じっけんき /実験機/
じっけんきぐ /実験器具/
じっけんきざい /実験機材/実験器材/
じっけんきょく /実験局/
じっけんぎじゅつ /実験技術/
じっけんけい /実験系/
じっけんけいかく /実験計画/
じっけんけっか /実験結果/
じっけんげんば /実験現場/
じっけんげんり /実験原理/
じっけんごさ /実験誤差/
じっけんさんか /実験参加/
じっけんざいりょう /実験材料/
じっけんし /実験誌/
じっけんしき /実験式/
じっけんしせつ /実験施設/
じっけんしつ /実験室/
じっけんしつけい /実験室系/
じっけんしゃ /実験者/
じっけんしゅたい /実験主体/
じっけんしゅほう /実験手法/
じっけんしんりがく /実験心理学/
じっけんしんりがくしゃ /実験心理学者/
じっけんじかん /実験時間/
じっけんじじつ /実験事実/
じっけんじたい /実験自体/
じっけんじゅんび /実験準備/
じっけんじょう /実験場/実験上/
じっけんじょうけん /実験条件/
じっけんすい /実験水/
じっけんすうがく /実験数学/
じっけんずみ /実験済/
じっけんせい /実験性/実験星/
じっけんせつぞく /実験接続/
じっけんせつび /実験設備/
じっけんそうち /実験装置/
じっけんだい /実験台/
じっけんだんかい /実験段階/
じっけんち /実験値/
じっけんちゅう /実験中/
じっけんづくえ /実験机/
じっけんてき /実験的/
じっけんてきけんしょう /実験的検証/
じっけんてきこうさつ /実験的考察/
じっけんてきさくひん /実験的作品/
じっけんてきしょうこ /実験的証拠/
じっけんでーた /実験データ/
じっけんとう /実験棟/
じっけんどうぶつ /実験動物/
じっけんないよう /実験内容/
じっけんばしょ /実験場所/
じっけんばんぐみ /実験番組/
じっけんひけんしゃ /実験被験者/
じっけんぶ /実験部/
じっけんぶつりがく /実験物理学/
じっけんほうこく /実験報告/
じっけんほうそう /実験放送/
じっけんほうほう /実験方法/
じっけんもくてき /実験目的/
じっけんや /実験屋/
じっけんよう /実験用/
じっけんれい /実験例/
じっけんろ /実験炉/
じっけんろんぶん /実験論文/
じっこ /十個/
じっこう /実行;†execute.「-に移す」/実効;†effective.「-出力」/
じっこう> /実効;(effective) -感度,-価格,-出力/
じっこうい /実行委/
じっこういいん /実行委員/
じっこういいんかい /実行委員会/
じっこういいんちょう /実行委員長/
じっこういらい /実行依頼/
じっこうかいすう /実行回数/
じっこうかのう /実行可能/
じっこうかのうけいしき /実行可能形式/
じっこうかのうじょうたい /実行可能状態/
じっこうかんきょう /実行環境/
じっこうかんきょうじょう /実行環境上/
じっこうかんし /実行監視/
じっこうかんど /実効感度/
じっこうがた /実行型/
じっこうがめん /実行画面/
じっこうきょか /実行許可/
じっこうけいかく /実行計画/
じっこうけいしき /実行形式/
じっこうけっか /実行結果/
じっこうけん /実行権/
じっこうけんげん /実行権限/
じっこうこうりつ /実行効率/
じっこうご /実行後/
じっこうしはい /実効支配/
じっこうしゃ /実行者/
じっこうしゅたい /実行主体/
じっこうじ /実行時/
じっこうじかん /実行時間/
じっこうじっせき /実行実績/
じっこうじゅんじょ /実行順序/
じっこうじょうきょう /実行状況/
じっこうじょうたい /実行状態/
じっこうせい /実効性/
じっこうせいのう /実行性能/
じっこうせんりょう /実効線量/
じっこうせんりょうとうりょう /実効線量当量/
じっこうぜいりつ /実効税率/
じっこうそくど /実行速度/実効速度/
じっこうぞうばいりつ /k$_{eff}$/実効増倍率/
じっこうぞくせい /実行属性/
じっこうたい /実行体/
じっこうだんかい /実行段階/
じっこうち /実効値/
じっこうちゅう /実行中/
じっこうてき /実効的/
じっこうてじゅん /実行手順/
じっこうてんそうそくど /実効転送速度/
じっこうとちゅう /実行途中/
じっこうはん /実行犯/
じっこうび /実行日/
じっこうふかのう /実行不可能/
じっこうふのう /実行不能/
じっこうぶ /実行部/
じっこうぶん /実行文/
じっこうほう /実行法/
じっこうほうしき /実行方式/
じっこうほうほう /実行方法/
じっこうまえ /実行前/
じっこうりょく /実行力/実効力;actual effect/
じっこうれい /実行例/
じっこん /入魂/実根/昵懇/
じっさ /実査/
じっさい /実際/
じっさいえいぞう /実際映像/
じっさいか /実際家/
じっさいじょう /実際上/
じっさいせい /実際性/
じっさいてき /実際的/
じっさいに /実際に/
じっさいもんだい /実際問題/
じっさぎょう /実作業/
じっさく /実作/
じっし /実施/実子/実姉/十指/実視/
じっしけっか /実施結果/
じっしけん /実施権/
じっしご /実施後/
じっししゃ /実施者/
じっしじき /実施時期/
じっしじょうきょう /実施状況/
じっしせっけい /実施設計/
じっしちゅう /実施中/
じっしつ /実質/
じっしつか /実質化/
じっしつしゅぎ /実質主義;⇔形式主義/
じっしつじょう /実質上/
じっしつぞうぜい /実質増税/
じっしつちゅう /実質中/
じっしつちんぎん /実質賃金/
じっしつてき /実質的/
じっしつてきこうか /実質的効果/
じっしつねんりつ /実質年率/
じっしつやく /実質役/
じっしび /実施日/
じっしほうしん /実施方針/
じっしほうほう /実施方法/
じっしゃ /実写/実車/実者/
じっしゃえいが /実写映画/
じっしゃかい /実社会/
じっしゃがめん /実写画面/
じっしゃばん /実写版/
じっしゃふう /実写風/
じっしゃもの /実写物/
じっしゅ /十種/
じっしゅう /実習/実収;実収入/
じっしゅうさき /実習先/
じっしゅうしつ /実習室/
じっしゅうせい /実習生/
じっしゅうそうち /実習装置/
じっしゅうねん /十周年/
じっしゅうよう /実習用/
じっしゅきょうぎ /十種競技/
じっしょう /実証/実正/十漿/
じっしょうしゅぎ /実証主義/
じっしょうじっけん /実証実験/
じっしょうずみ /実証済/
じっしょうせい /実証性/
じっしょうてき /実証的/
じっしようこう /実施要綱/実施要項/
じっしようりょう /実施要領/
じっしれい /実施例/
じっしん /実親/実身;BTRON のファイルシステム上の概念/十進/１０進/
じっしんすう /十進数/
じっしんぶんるいほう /十進分類法/
じっしんほう /十進法/
じっすう /実数/
じっすうかい /実数解/
じっすうがた /実数型/
じっすうぜんたい /実数全体/
じっすうたい /実数体/
じっすうち /実数値/
じっすうていすう /実数定数/
じっすうぶ /実数部/
じっすうろん /実数論/
じっすん /実寸/
じっせい /実勢/日星;太陽と星々/
じっせいかかく /実勢価格/
じっせいかつ /実生活/實生活/
じっせいかつじょう /実生活上/
じっせかい /実世界/
じっせき /実績/
じっせきあり /実績有/
じっせきさく /実績作/
じっせきしゅぎ /実績主義/
じっせきじゅうし /実績重視/
じっせきち /実績値/
じっせきちょうさ /実績調査/
じっせきば /実績馬/
じっせきぶそく /実績不足/
じっせつ /実説/
じっせん /実践;†practice.「主張を-する」/実戦;†actual combat.「-に投入する」/実線;†⇔点線/
じっせんかつどう /実践活動/
じっせんからて /実戦空手/
じっせんきゅうこう /実践躬行;自分で実行する,自ら実際に行動する/
じっせんきょういく /実践教育/
じっせんけい /実戦形/
じっせんけいけん /実戦経験/
じっせんけっか /実践結果/
じっせんこうざ /実践講座/
じっせんさんか /実戦参加/
じっせんしょうぎょう /実践商業/
じっせんじょしがくえん /実践女子学園/
じっせんせい /実践性/
じっせんてき /実践的;†practical/実戦的;†suitable for real combat/
じっせんてきぎじゅつ /実践的技術/
じっせんてつがく /実践哲学;practical philosophy/
じっせんとうにゅう /実戦投入/
じっせんはいび /実戦配備/
じっせんへん /実践編/
じっせんめん /実践面/
じっせんりせい /実践理性;[哲学]reinen Vernunft (Kantの用語)/
じっせんりせいひはん /実践理性批判;Kritik der reinen Vernunft,1788,Kant/
じっそう /実装;implement/実相;reality/十層/
じっそうかんきょう /実装環境/
じっそうかんにゅう /実相観入/
じっそうき /実装機/
じっそうぎじゅつ /実装技術/
じっそうげんご /実装言語/
じっそうしよう /実装仕様/
じっそうじ /実装時/実相寺/
じっそうじょう /実装上/
じっそうほう /実装法/
じっそうほうしき /実装方式/
じっそうほうほう /実装方法/
じっそうめんせき /実装面積/
じっそうれい /実装例/
じっそく /実測/
じっそくけっか /実測結果/
じっそくず /実測図/
じっそくち /実測値/
じっそくれい /実測例/
じっそん /実損/
じったい /実態;†real situation.「杜撰な-」/実体;†substance.「-のなさ」「-参照」/
じったいか /実体化/
じったいがいねん /実体概念/
じったいきょう /実体鏡/
じったいけいざい /実体経済/
じったいけん /実体験/
じったいけんしゃ /実体験者/
じったいけんびきょう /実体顕微鏡/
じったいさんしょう /実体参照/
じったいちょうさ /実態調査/
じったいてき /実体的;substantive/実態的;of reality?/
じったいは /実体波/
じったいほう /実体法/
じっち /実地/
じっちえんしゅう /実地演習/
じっちけいけん /実地経験/
じっちけんしゅう /実地研修/
じっちけんしょう /実地検証/
じっちしけんめんじょ /実地試験免除/
じっちちょうさ /実地調査/
じっちゃく /実着/
じっちゅう /十中/
じっちゅうはっく /十中八九/
じっちょう /十兆/
じっちょうりょく /実張力/
じっちょく /実直/
じっつう /十通/
じって /十手/
じってい /実弟/実体/
じっていほう /実定法/
じっていほうじょう /実定法上/
じってつ /十哲/
じっとく /拾得/十徳/
じっぱ /十把/十羽/
じっぱひとからげ /十把一絡げ;何もかも一緒くた/十把一絡/
じっぴ /実費/実否/
じっぴき /十匹/
じっぴふたん /実費負担/
じっぴぶん /実費分/
じっぷ /実父/
じっぷん /十分/
じっぷんかん /十分間/
じっぺんしゃいっく /十返舎一九;人名,江戸後期の戯作者/
じっぽ /十歩/
じっぽう /実包/十方/実法/
じっぽうせかい /十方世界/
じっぽん /日本/
じつ /実/日/昵;昵懇/實;「実」の旧字(人名用漢字)/
じつ> /実;(actual) 実データ,実手形,実容量/
じつい /実委/実意/
じついん /実印/実員/
じつう /耳痛/
じつうんよう /実運用/
じつえき /実益/
じつえん /実演/
じつえんか /実演家/
じつえんじょう /実演場/
じつえんはんばい /実演販売/
じつおや /実親/
じつおん /実音/
じつおんげん /実音源/
じつおんじょう /実音場/
じつおんせい /実音声/
じつおんぞう /実音像/
じつかた /実方/
じつかどう /実稼働/
じつかぶ /実株/
じつかわ /実川/
じつかんきょう /実環境/
じつかんすう /実関数/
じつがい /実害/
じつがく /実学;practical science/実額;actual amount/
じつがめん /実画面/
じつきおく /実記憶/
じつぎ /実技/
じつぎこうしゅう /実技講習/
じつぎしけん /実技試験/
じつぎょう /実業/
じつぎょうか /実業家/
じつぎょうかい /実業界/
じつぎょうがっこう /実業学校/
じつぎょうだん /実業団/
じつぎょうのにほん /実業之日本/
じつぎょうのにほんしゃ /実業之日本社/
じつくうかん /実空間/
じつくうかんじょう /実空間上/
じつけいすう /実係数/
じつけいそく /実計測/
じつげつ /日月/
じつげん /実現/
じつげんか /実現化/
じつげんかてい /実現過程/
じつげんかのう /実現可能/
じつげんかのうせい /実現可能性/
じつげんきこう /実現機構/
じつげんきぼう /実現希望/
じつげんぎじゅつ /実現技術/
じつげんけいたい /実現形態/
じつげんし /実現子/
じつげんしゅほう /実現手法/
じつげんじょう /実現上/
じつげんせい /実現性/
じつげんど /実現度/
じつげんふかのう /実現不可能/
じつげんふのう /実現不能/
じつげんほう /実現法/
じつげんほうほう /実現方法/
じつげんみ /実現味/
じつげんようきゅう /実現要求/
じつこうりつ /実効率/
じつご /実語/
じつさぎょう /実作業/
じつざい /実在/
じつざいかん /実在感/
じつざいせい /実在性/
じつざいてき /実在的/
じつざいろん /実在論/
じつしよう /実使用/
じつじ /実字/実耳/
じつじかん /実時間/
じつじかんしょり /実時間処理/
じつじかんせい /実時間性/
じつじきゅうぜ /実事求是;事実に即して真実を探究する/
じつじく /実軸/
じつじゅ /実需/
じつじょう /実情/実状;≒実情/
じつせかい /実世界/
じつぞう /実像/
じつぞん /実存/
じつぞんしゅぎ /実存主義;人間の個別存在を中心に置く哲学の立場/
じつぞんてき /実存的/
じつぞんてつがく /実存哲学;philosophie existentielle,existentialisme/
じつたいけん /実体験/
じつたいしょう /実対称/
じつだん /実弾/
じつちえん /実遅延/
じつづき /地続き/
じつていすう /実定数/
じつてんぽ /実店舗/
じつどう /実働;working.「-時間」/実動;practice.「-演習」/
じつどうさ /実動作/
じつどうじかん /実働時間/
じつに /実に/
じつねん /実年/
じつねんぴ /実燃費/
じつねんれい /実年齢/
じつねんろん /実念論/
じつのところ /実の所/
じつは /実は/
じつばい /実売/
じつばいかかく /実売価格/
じつばりき /実馬力/
じつひきすう /実引数/
じつぶ /実部/
じつぶつ /実物/
じつぶつだい /実物大/
じつぶつだいもけい /実物大模型/
じつぶつとりひき /実物取引/
じつぼ /実母/地坪/
じつまい /実妹/
じつむ /実務/実夢;≒正夢/
じつむか /実務家/
じつむけいけん /実務経験/
じつむけいけんしゃ /実務経験者/
じつむしゃ /実務者/
じつむてき /実務的/
じつめい /実名/
じつやく /実役/
じつよう /実用/実葉;[植物]fertile leaves/
じつようか /実用化/
じつようかいてんいき /実用回転域/
じつようかいろ /実用回路/
じつようかいわ /実用会話/
じつようかじだい /実用化時代/
じつようかどうむき /実用化動向/
じつようき /実用機/実用期/
じつようしゃ /実用車/
じつようしゅぎ /実用主義/
じつようしょ /実用書/
じつようしんあん /実用新案/
じつようしんあんけん /実用新案権/
じつようじょう /実用上/
じつようじょうもんだい /実用上問題/
じつようせい /実用性/
じつようてき /実用的/
じつようど /実用度/
じつようねんぴ /実用燃費/
じつようひん /実用品/
じつようほんい /実用本位/
じつようめん /実用面/
じつようれい /実用例/
じつり /実利/実理;practical theory/
じつりしゅぎ /実利主義;philistinism/
じつりてき /実利的/
じつりゆうせん /実利優先/
じつりょく /実力/
じつりょくいじょう /実力以上/
じつりょくこうし /実力行使/
じつりょくさ /実力差/
じつりょくしゃ /実力者/
じつりょくしゅぎ /実力主義/
じつりょくてき /実力的/
じつりょくてすと /実力テスト/
じつりょくどおり /実力通り/
じつりょくは /実力派/
じつりょくはくちゅう /実力伯仲/
じつりょくば /実力馬/
じつりょくひかく /実力比較/
じつりょくぶそく /実力不足/
じつれい /実例/
じつれき /実歴/
じつれん /実連/
じつろう /実労/
じつろうじかん /実労時間/
じつろく /実録/
じつわ /実話/
じづめ /字詰め/字詰/
じづら /字面/
じづらじょう /字面上/
じてい /自邸/時程/
じていすう /時定数/次定数/
じてき /自適/
じてっこう /磁鉄鉱/
じてん /辞典;†dictionary.「国語-」/時点/事典;†encyclopedia.「百科-」/次点/自転/字典;†じびき。「漢字-」/辭典;「辞」旧字/
じてんしゃ /自転車/自轉車;「転」旧字/
じてんしゃいどう /自転車移動/
じてんしゃおうだんたい /自転車横断帯/
じてんしゃおきば /自転車置場/
じてんしゃぎょうかい /自転車業界/
じてんしゃざっし /自転車雑誌/
じてんしゃせんようどう /自転車専用道/
じてんしゃそうぎょう /自転車操業/
じてんしゃつうがく /自転車通学/
じてんしゃつうきん /自転車通勤/
じてんしゃどう /自転車道/
じてんしゃぶひん /自転車部品/
じてんしゃほんたい /自転車本体/
じてんしゃや /自転車屋/
じてんしゃよう /自転車用/
じてんしゃりょこう /自転車旅行/
じてんしゃれき /自転車歴/
じてんしゅうき /自転周期/
じてんじく /自転軸/
じてんせつ /自転説/
じてんそくど /自転速度/
じでん /自伝/
じでんてきさくひん /自伝的作品/
じとう /地頭/自党/自答/寺塔/時祷/字統;字源辞典/
じとうしょ /時祷書/
じとうてんのう /持統天皇/
じとく /自得/自涜/
じとり /地鶏/
じどう /自動/児童/耳道/侍童/
じどう> /自動;-改札,-楽器/
じどううんてん /自動運転/
じどうえんそう /自動演奏/
じどうえんちょう /自動延長/
じどうおうとう /自動応答/
じどうおうとうでんわ /自動応答電話/
じどうか /自動化/
じどうかい /児童会/
じどうかいかん /児童会館/
じどうかいぎょう /自動改行/
じどうかいけつ /自動解結/
じどうかいさつ /自動改札/
じどうかいさつか /自動改札化/
じどうかいさつき /自動改札機/
じどうかいちょう /児童会長/
じどうかいとう /自動解凍/
じどうかいふく /自動回復/
じどうかき /自動火器/
じどうかくてい /自動確定/
じどうかん /児童館/
じどうかんそうき /自動乾燥機/
じどうかんり /自動管理/
じどうがくえん /児童学園/
じどうがた /自動型/
じどうがっき /自動楽器/
じどうがっしょうだん /児童合唱団/
じどうきどう /自動起動/
じどうきゅうし /自動給紙/
じどうきりかえ /自動切替/自動切換/
じどうぎゃくたい /児童虐待/
じどうぎゃくたいぼうしほう /児童虐待防止法/
じどうぎれ /自動切/
じどうけいさん /自動計算/
じどうけいそく /自動計測/
じどうけいぞく /自動継続/
じどうけんさ /自動検査/
じどうけんしゅつ /自動検出/
じどうけんしょう /児童憲章;1951/自動検証/
じどうけんばいき /自動券売機/
じどうこうえん /児童公園/
じどうこうしん /自動更新/
じどうごうせい /自動合成/
じどうさいはっしん /自動再発信/
じどうさくじょ /自動削除/
じどうさくせい /自動作成/
じどうさくせいきのう /自動作成機能/
じどうさっきょく /自動作曲/
じどうざっし /児童雑誌/
じどうし /自動詞/
じどうしき /自動式/
じどうしきべつ /自動識別/
じどうしはらいき /自動支払機/
じどうしゃ /自動車/
じどうしゃいがい /自動車以外/
じどうしゃかさい /自動車火災/
じどうしゃかんけい /自動車関係/
じどうしゃかんれん /自動車関連/
じどうしゃがいしゃ /自動車会社/
じどうしゃがっこう /自動車学校/
じどうしゃきぎょう /自動車企業/
じどうしゃきょうかい /自動車協会/
じどうしゃきょうしゅうじょ /自動車教習所/
じどうしゃぎょうかい /自動車業界/
じどうしゃけんさひょう /自動車検査票/
じどうしゃこうがく /自動車工学/
じどうしゃこうじょう /自動車工場/
じどうしゃこうつう /自動車交通/
じどうしゃざっし /自動車雑誌/
じどうしゃしけんじょう /自動車試験場/
じどうしゃしゃかい /自動車社会/
じどうしゃしゅとくぜい /自動車取得税/
じどうしゃしんこうかい /自動車振興会/
じどうしゃじこ /自動車事故/
じどうしゃじゅうりょうぜい /自動車重量税/
じどうしゃせいさくしょ /自動車製作所/
じどうしゃせいび /自動車整備/
じどうしゃせいびし /自動車整備士/
じどうしゃせんしんこく /自動車先進国/
じどうしゃせんよう /自動車専用/
じどうしゃせんようどう /自動車専用道/
じどうしゃぜい /自動車税/
じどうしゃそんがいばいしょうせきにんほけん /自動車損害賠償責任保険;自賠責/
じどうしゃつうきんしゃ /自動車通勤者/
じどうしゃでんわ /自動車電話/
じどうしゃとうろく /自動車登録/
じどうしゃどう /自動車道/
じどうしゃどうろ /自動車道路/
じどうしゃはいしゅつ /自動車排出/
じどうしゃはんばい /自動車販売/
じどうしゃひょうろんか /自動車評論家/
じどうしゃぶ /自動車部/
じどうしゃぶんか /自動車文化/
じどうしゃほけん /自動車保険/
じどうしゃほゆうりつ /自動車保有率/
じどうしゃや /自動車屋/
じどうしゃゆうせん /自動車優先/
じどうしゃゆそう /自動車輸送/
じどうしゃよう /自動車用/
じどうしゃようご /自動車用語/
じどうしゃようとりょう /自動車用塗料/
じどうしゃりようしゃ /自動車利用者/
じどうしゃろーん /自動車ローン/
じどうしゅうけい /自動集計/
じどうしゅうせい /自動修正/
じどうしゅうりょう /自動終了/
じどうしょ /児童書/
じどうしょうこうき /自動昇降機/
じどうしょうじゅう /自動小銃/
じどうしょうめい /自動証明/
じどうしょうめつ /自動消滅/
じどうしょり /自動処理/
じどうしんりがく /児童心理学;child psychology/
じどうじっこう /自動実行/
じどうじゅしん /自動受信/
じどうじゅんかい /自動巡回/
じどうじりつしえんしせつ /児童自立支援施設;community home,reformatory. 旧・教護院 <児童福祉法/
じどうせいぎょ /自動制御/
じどうせいぎょこうがく /自動制御工学/
じどうせいさんき /自動精算機/
じどうせいせい /自動生成/
じどうせいせいほう /自動生成法/
じどうせってい /自動設定/
じどうせんしゃき /自動洗車機/
じどうせんたく /自動選択/
じどうせんたくき /自動洗濯機/
じどうそうきん /自動送金/
じどうそうさ /自動操作/
じどうそうしん /自動送信/
じどうそうじゅう /自動操縦/
じどうそうだんしょ /児童相談所/
じどうそうだんじょ /児童相談所;児童福祉法に基づく/
じどうそうちゃく /自動装着/
じどうそうふ /自動送付/
じどうたいおう /自動対応/
じどうちゃっか /自動着火/
じどうちゅうしゅつ /自動抽出/
じどうちょうせい /自動調整/
じどうついじゅう /自動追従/
じどうてあて /児童手当/
じどうていぎ /自動定義/
じどうていせい /自動訂正/
じどうてき /自動的/
じどうてきよう /自動適用/
じどうてんそう /自動転送/
じどうてんぷ /自動添付/
じどうてんめつ /自動点滅/
じどうてんやく /自動点訳/
じどうとうこう /自動投稿/
じどうとうひょう /自動投票/
じどうとうろく /自動登録/
じどうどあ /自動ドア/
じどうにゅうりょく /自動入力/
じどうにりん /自動二輪/
じどうにりんしゃ /自動二輪車/
じどうにりんめんきょ /自動二輪免許/
じどうにんぎょう /自動人形/
じどうにんしき /自動認識/
じどうはっしん /自動発信/
じどうはつばい /自動発売/
じどうはんてい /自動判定/
じどうはんばい /自動販売/
じどうはんばいき /自動販売機/
じどうはんべつ /自動判別/
じどうばんそう /自動伴奏/
じどうひきおとし /自動引落/
じどうびょうが /自動描画/
じどうふか /自動付加/
じどうふくし /児童福祉/
じどうふくしし /児童福祉司/
じどうふくししせつ /児童福祉施設/
じどうふくしほう /児童福祉法/
じどうふくせいきき /自動複製機器/
じどうふようてあて /児童扶養手当/
じどうふりかえ /自動振替/
じどうふりこみ /自動振込/
じどうぶんかつ /自動分割/
じどうぶんかつきのう /自動分割機能/
じどうぶんがく /児童文学/
じどうへいれつか /自動並列化/
じどうへんかん /自動変換/
じどうへんこう /自動変更/
じどうへんしん /自動返信/
じどうへんすう /自動変数/
じどうへんそう /自動返送/
じどうへんそく /自動変速/
じどうへんそくき /自動変速機/
じどうへんとう /自動返答/
じどうほせい /自動補正/
じどうほんやく /自動翻訳/
じどうほんやくき /自動翻訳機/
じどうほんやくでんわ /自動翻訳電話/
じどうぽるの /児童ポルノ/
じどうまき /自動巻/自動巻き/
じどうまきもどし /自動巻き戻し/
じどうまど /自動窓/
じどうまんが /児童漫画/
じどうようごしせつ /児童養護施設/
じどうよやく /自動予約/
じどうりつ /自同律;[論理]A≡A/
じどうりょうがえき /自動両替機/
じどうれんけつ /自動連結/
じどうれんけつき /自動連結器/
じどうろうどう /児童労働/
じどうろくが /自動録画/
じどうろこう /自動露光/
じどうろしゅつ /自動露出/
じどり /地鶏/地取り/
じない /地内/寺内/耳内/
じないちょう /寺内町/
じならし /地均し/
じならび /字並び/
じなり /地鳴り/
じなん /次男/二男/
じなんきょく /磁南極/
じなんぼう /次男坊/
じにけいすう /ジニ係数;[経済]Gini coefficient/
じにん /辞任/自認;自分で認める。「失敗を-する」/自任;自分がそうだと思い込む。「識者を-する」/神人/
じにんご /辞任後/
じにんせつ /辞任説/
じぬし /地主/
じねずみ /地鼠/
じねつ /地熱/
じねん /自然/
じねんじょ /自然薯;とろろにする薯/自然生;≒自然薯/
じねんど /次年度/
じねんどいこう /次年度以降/
じねんほうに /自然法爾/
じのかみ /地の神/
じのし /地伸し/
じのぶん /地の文;⇔会話文/
じのり /地乗り/
じは /自派/
じはい /字牌/
じはく /自白/
じはくざい /自白剤/
じはだ /地肌/
じはつ /自発/次発/
じはつこうい /自発行為/
じはつせい /自発性/
じはつてき /自発的/
じはつてきいし /自発的意志/
じはつてきこうどう /自発的行動/
じはつてきさんか /自発的参加/
じはつてきせいしん /自発的精神/
じはつほうでん /自発放電/
じはば /字幅/
じはん /時半/事犯/自販;[略語]自動販売(機),自動車販売/次版/
じはんき /自販機/
じはんころ /時半頃/
じば /地場/磁場/
じばいせき /自賠責/
じばいせきほけん /自賠責保険/
じばく /自爆/自縛/地縛/
じばくこうげき /自爆攻撃/
じばくそうち /自爆装置/
じばくてろ /自爆テロ/
じばくれい /地縛霊/自縛霊/
じばさんぎょう /地場産業/
じばちゅう /磁場中/
じばつ /治罰/
じばつてき /自罰的/
じばら /自腹/
じばん /地盤/次版/
じばんちょうさ /地盤調査/
じばんちんか /地盤沈下/
じぱい /字牌/
じひ /慈悲/自費/
じひさんか /自費参加/
じひしゅっぱん /自費出版/
じひしんちょう /慈悲心鳥/
じひしんりょう /自費診療/
じひつ /自筆/
じひつしょうしょ /自筆証書/
じひつふ /自筆譜/
じひびき /地響き/
じひょう /辞表/次表/耳標;ear tag.「牛の-」/時評/恃憑/
じひょうき /字表記/
じび /耳鼻/
じびーる /地ビール/
じびいんこう /耳鼻咽喉/
じびいんこうか /耳鼻咽喉科/
じびか /耳鼻科/
じびき /字引/地引/
じびきあみ /地引き網/地引網/地曳網/地曳き網/
じびょう /持病/
じふ /自負/慈父/
じふく /地覆/時服/地幅/
じふしん /自負心/
じふてりあきん /ジフテリア菌;diphtheria/
じふぶき /地吹雪/
じふへん /時不変/
じふん /自噴;「-する温泉」/自刎/時分;じぶん/
じふんせい /自噴井/
じぶ /治部/
じぶく /地覆/地幅/
じぶくろ /地袋/
じぶしょう /治部省;[律令制]八省/
じぶつ /事物/
じぶもん /自部門/
じぶん /自分/時分/
じぶんあて /自分宛/
じぶんいがい /自分以外/
じぶんかって /自分勝手/
じぶんかつ /時分割/
じぶんかつしょり /時分割処理/
じぶんこじん /自分個人/
じぶんごのみ /自分好み/
じぶんさがし /自分探し/
じぶんし /自分史;autobiography/
じぶんしだい /自分次第/
じぶんじしん /自分自身/
じぶんじしんいがい /自分自身以外/
じぶんせんよう /自分専用/
じぶんたち /自分達/自分たち/
じぶんちゅうしん /自分中心/
じぶんひとり /自分一人/
じぶんほんい /自分本位/
じぶんめいぎ /自分名義/
じぶんよう /自分用/
じぶんりゅう /自分流/
じへい /自閉/時弊/
じへいしょう /自閉症/
じへいしょうじ /自閉症児/
じへん /事変/時変/事變/
じへんしんごう /時変信号/
じへんまえ /事変前/
じべた /地べた/
じべん /自弁/
じぺーじ /次ページ/次頁/
じほう /時報/寺宝/次鋒;先鋒,-,中堅/
じほく /磁北/
じほくせん /磁北線/
じぼ /字母/慈母/
じぼう /自暴/
じぼうじき /自暴自棄/
じぼしん /地母神/
じぼひょう /字母表/
じま /島/縞/嶋;「島」の旧字(人名用漢字)/嶌;「島」の異体字2/
じまい /仕舞/仕舞い/
じまえ /時前/自前/
じまく /字幕/
じまくいり /字幕入り/
じまくばん /字幕版/
じまくほうそう /字幕放送/
じまひ /仕舞い/
じまま /自儘/
じまわり /地廻り/地回り;ごろつき/
じまん /自慢/
じまんげ /自慢気/
じまんばなし /自慢話/
じみ /地味/滋味;深い味わい/
じみち /地道/
じみめ /地味目/
じみん /自民/
じみんぞく /自民族/
じみんぞくちゅうしんしゅぎ /自民族中心主義/
じみんとう /自民党/
じみんとうせいけん /自民党政権/
じみんとうぶんきょうぞく /自民党文教族/
じみんどくせん /自民独占/
じむ /事務/寺務;寺のつとめ/時務/
じむいす /事務椅子/
じむいん /事務員/
じむかた /事務方/
じむかちょう /事務課長/
じむかん /事務官/
じむかんきょう /事務環境/
じむかんそか /事務簡素化/
じむかんり /事務管理/
じむき /事務機/事務器/
じむききてん /事務機器展/
じむきょく /事務局/
じむきょくちょう /事務局長/
じむけい /事務系/
じむけいさん /事務計算/
じむさぎょう /事務作業/
じむし /地虫/
じむしつ /事務室/
じむしょ /事務所/
じむしょいてん /事務所移転/
じむしょうもうひん /事務消耗品/
じむしょかんけい /事務所関係/
じむしょがわ /事務所側/
じむしょく /事務職/
じむしょり /事務処理/
じむしょりひよう /事務処理費用/
じむしょるい /事務書類/
じむじかん /事務次官/
じむじょう /事務上/
じむそうきょく /事務総局/
じむそうちょう /事務総長/
じむたんとう /事務担当/
じむたんとうしゃ /事務担当者/
じむちょう /事務長/
じむづくえ /事務机/
じむてき /事務的/
じむてきれんらく /事務的連絡/
じむてすうりょう /事務手数料/
じむてつづき /事務手続き/
じむとう /事務棟/
じむひ /事務費/
じむふたん /事務負担/
じむぶ /事務部/
じむぶちょう /事務部長/
じむぶもん /事務部門/
じむほさいん /事務補佐員/
じむや /事務屋/
じむよう /事務用/
じむようひん /事務用品/
じむれべる /事務レベル;-会合,-協議/
じむれんらく /事務連絡/
じむれんらくよう /事務連絡用/
じめい /自明/字名/
じめいかい /自明解/
じめいきん /自鳴琴;=オルゴール/
じめいのり /自明の理/
じめつ /自滅/
じめつこうい /自滅行為/
じめん /地面/字面;=じづら/
じもく /耳目;-を集める/除目;[古語]任官の儀式/
じもくじ /甚目寺/
じもつ /持物;[仏教]仏の持ち物/
じもと /地元/
じもといがい /地元以外/
じもといしき /地元意識/
じもとがくせい /地元学生/
じもとけいさつ /地元警察/
じもとこうこうせい /地元高校生/
じもとさいしゅうせん /地元最終戦/
じもとし /地元紙/
じもとしほん /地元資本/
じもとしゃ /地元車/
じもとしゅっしん /地元出身/
じもとしょうてんがい /地元商店街/
じもとしょうぼう /地元消防/
じもとしんぶん /地元新聞/
じもとじちかい /地元自治会/
じもとじゅうみん /地元住民/
じもとせつめいかい /地元説明会/
じもとせんしゅつ /地元選出/
じもとぜい /地元勢/
じもとちょうみん /地元町民/
じもとみっちゃく /地元密着/
じもとみっちゃくがた /地元密着型/
じもとみん /地元民/
じもとゆうり /地元有利/
じもの /地物/
じもよう /地模様/
じもん /自問/寺門/地紋/地文/次問/字紋/
じもんじとう /自問自答/
じゃ /邪/蛇/者/麝;麝香/闍;闍婆(java)/
じゃーじゃーめん /ジャージャー麺/
じゃあく /邪悪/
じゃいなきょう /ジャイナ教/
じゃいん /邪淫/
じゃいんかい /邪淫戒;[仏教]五戒の一つ/
じゃかご /蛇籠/
じゃかん /蛇管/
じゃがいも /じゃが芋/ジャガ芋/
じゃき /邪気/邪鬼/
じゃきょう /邪教/
じゃきょく /邪曲/
じゃく /弱/若/尺/寂;静寂/惹;惹起/雀;雀躍/搦;から・める/鉐/着;(呉音)/
じゃく> /弱;弱酸性,弱アルカリ性,弱電解質/
じゃくえんさん /弱塩酸/
じゃくおん /弱音/
じゃくおんき /弱音器/
じゃくかりょく /弱火力/
じゃくきょうちゅう /弱強中/
じゃくけいしき /弱形式/
じゃくご /著語/
じゃくさん /弱酸/
じゃくさんせい /弱酸性/
じゃくし /弱視/杓子/弱志/
じゃくししゃ /弱視者/
じゃくししゃよう /弱視者用/
じゃくしつ /弱質/
じゃくしゃ /弱者/
じゃくしゃほご /弱者保護/
じゃくしゅう /若州;若狭/
じゃくしょう /弱小/
じゃくしょうこく /弱小国/
じゃくしょうせいりょく /弱小勢力/
じゃくしん /弱震/
じゃくじょう /寂静/
じゃくそつ /弱卒/
じゃくたい /弱体/
じゃくたいか /弱体化/
じゃくたいとうしゅじん /弱体投手陣/
じゃくちゅう /若冲/
じゃくちゅうきょう /弱中強/
じゃくちょう /寂聴/
じゃくてき /弱敵/
じゃくてん /弱点/
じゃくでん /弱電/
じゃくでんかい /弱電界/
じゃくでんかいしつ /弱電解質;[化学]weak electrolyte/
じゃくにくきょうしょく /弱肉強食/
じゃくねん /若年/寂然/弱年;=若年/
じゃくねんしゃ /若年者/
じゃくねんしゃいん /若年社員/
じゃくねんせい /若年性/
じゃくねんそう /若年層/
じゃくねんれい /若年齢/
じゃくはい /若輩/弱輩/
じゃくはいもの /若輩者/
じゃくはく /弱拍/
じゃくはん /雀斑/
じゃくへんか /弱変化/
じゃくまく /寂寞/
じゃくめつ /寂滅/
じゃくめついらく /寂滅為楽/
じゃくやく /雀躍/
じゃくら /雀羅/
じゃくらんはん /雀卵斑/
じゃくれい /若齢/弱齢;=若齢/
じゃくれいしゃ /弱冷車/
じゃくれいぼうしゃ /弱冷房車/
じゃぐち /蛇口/
じゃけ /鮭/
じゃけがい /ジャケ買い/
じゃけん /邪険;-に扱う/邪見;wicked view/邪慳;=邪険/邪剣;evil sword/
じゃこ /雑魚/
じゃこう /麝香/蛇行;=だこう/
じゃこうじか /麝香鹿/
じゃこうそう /麝香草/
じゃこうねこ /麝香猫/
じゃこうれんりそう /麝香連理草/
じゃこばんは /ジャコバン派;[世界史]Jacobin/
じゃし /邪視/
じゃしゅう /邪宗/
じゃしゅうもん /邪宗門/
じゃしん /邪神;false god/邪心;malice/蛇身/
じゃじゃうま /じゃじゃ馬/
じゃじゅつ /邪術/
じゃすい /邪推/
じゃずきっさ /ジャズ喫茶/
じゃずけん /ジャズ研/
じゃせい /邪正/
じゃせつ /邪説/
じゃそく /蛇足/
じゃっか /弱化/
じゃっかん /若干;†some/弱冠;†原義:男子の20歳/
じゃっかんえいきょう /若干影響/
じゃっかんき /若干気/
じゃっかんふあん /若干不安/
じゃっかんふあんてい /若干不安定/
じゃっかんむり /若干無理/
じゃっかんめい /若干名/
じゃっかんもんだい /若干問題/
じゃっかんゆうり /若干有利/
じゃっかんりょう /若干量/
じゃっかんわりだか /若干割高/
じゃっき /惹起/弱起;旋律が弱拍から始まること/
じゃっく /惹句/
じゃっけん /弱肩;[野球]⇔強肩/
じゃっこう /寂光/弱行/
じゃっこういん /寂光院/
じゃっこく /弱国/
じゃとう /蛇頭/
じゃどう /邪道/
じゃねん /邪念/
じゃのひげ /蛇の鬚/
じゃのめ /蛇の目/
じゃはな /謝花/
じゃばら /蛇腹/
じゃひ /邪飛/
じゃび /蛇皮/
じゃびせん /蛇皮線;沖縄の楽器、別名三線/
じゃほう /邪法/
じゃぽにかまい /ジャポニカ米;短粒種。普通のお米/
じゃま /邪魔/
じゃまだて /邪魔立て/
じゃまもの /邪魔者/邪魔物/
じゃみせん /三味線/
じゃむし /蛇虫/
じゃもん /蛇紋/
じゃもんがん /蛇紋岩;serpentinite/
じゃもんせき /蛇紋石;serpentine/
じゃよく /邪欲/
じゃらい /射礼/
じゃり /砂利/
じゃりうんぱん /砂利運搬/
じゃりさいしゅ /砂利採取/
じゃりじき /砂利敷き/
じゃりせん /ジャリ銭/
じゃりみち /砂利道/砂利路/
じゃりゅう /邪龍/
じゃれん /邪恋/
じゃわ /爪哇;Java/
じゃわご /ジャワ語;Javanese/
じゃん /雀/醤;豆板-,甜麺-,XO-,蕃椒-/
じゃんき /雀鬼/
じゃんくや /ジャンク屋/
じゃんごう /雀豪/
じゃんし /雀士/雀師/
じゃんそう /雀荘/
じゃんたく /雀卓/
じゃんぱい /雀牌/
じゃんぷだい /ジャンプ台/
じゃんぷりょく /ジャンプ力/
じゃんぼき /ジャンボ機/
じやき /地焼き/地焼/
じやく /持薬/
じゅ /受/授/樹/寿/綬;紫綬/呪;呪文/咒;「呪」の異体字/竪;たて/豎;豎子/需;需要/儒;儒教/嬬;つま/濡;ぬ・れる/孺/懦;(漢音) 怯懦/襦;襦袢/珠;真珠/愀/聚;(慣用音)類聚/戍;(慣用音)/従;(呉音)/就;(呉音) 成就/鷲;(呉音) わし/讐;(呉音) 復讐/讎;「讐」の異体字/壽;「寿」の旧字(人名用漢字)/
じゅ> /従;従四位下/
じゅあつ /受圧/
じゅあん /寿庵/樹庵/
じゅい /呪医/儒医/
じゅいしゃ /受遺者/
じゅいち /寿一/
じゅいん /入院;寺の住職になること/呪印/樹陰/
じゅう /獣/銃/中/重/十/従/住/汁/柔;柔道/揉;も・む/糅;かて/蹂;蹂躙/鞣;なめ・す/戎;(えびす)戎夷/絨;絨毯/充;充実/什;什器/柱;琵琶の-/狃;なれる/拾;ひろ・う/渋;渋滞/澁;「渋」の旧字(人名用漢字)/澀;「渋」の旧字2/縦;操縦/縱;「縦」の旧字(人名用漢字)/從;「従」の旧字(人名用漢字)/从;「従」の異体字(本字)/獸;「獣」の旧字(人名用漢字)/廿;にじゅう (NB:音読みは一応「じゅう」)/10/
じゅう> /重/従;(従属)従米,(位階)従三位/十/
じゅうあく /十悪/
じゅうあつ /重圧/
じゅうあつかん /重圧感/
じゅうい /獣医/十位/重囲/
じゅういおん /重イオン/
じゅういがくぶ /獣医学部/
じゅういがっか /獣医学科/
じゅういがっこう /獣医学校/
じゅういし /獣医師/
じゅういち /十一/
じゅういちがつ /十一月/１１月/11月/霜月;※連想,旧暦/
じゅういつ /充溢/
じゅういん /充員/
じゅうえいそう /重営倉/
じゅうえき /獣疫/汁液/
じゅうえん /十円/重縁/柔婉/
じゅうえんだま /十円玉/
じゅうおう /縦横/十王/
じゅうおうか /縦横家/
じゅうおうまち /十王町/
じゅうおうむぐう /縦横無隅/
じゅうおうむげ /縦横無礙/
じゅうおうむじん /縦横無尽/
じゅうおく /十億/
じゅうおん /重音/
じゅうか /住家/銃火/従価/重科/
じゅうかい /重解/
じゅうかいき /重回帰/
じゅうかがく /重化学/
じゅうかがくこうぎょう /重化学工業/
じゅうかき /重火器/
じゅうかく /縦隔/
じゅうかさんぜい /重加算税/
じゅうかしつ /重過失/
じゅうかぜい /従価税/
じゅうかん /縦貫/獣姦/重患/
じゅうかんきょう /住環境/
じゅうかんせん /縦貫線/
じゅうかんどう /縦貫道/
じゅうがい /獣害/
じゅうがつ /十月/１０月/10月/神無月;※連想,旧暦/
じゅうがん /銃眼/
じゅうき /什器;日用雑貨/重機/銃器;firearms/住基;[略語]住民基本台帳。「-ネット,-カード,-法」/重器;重要なもの/
じゅうきかい /重機械/
じゅうきかんじゅう /重機関銃/
じゅうきこうへい /重機甲兵/
じゅうきざい /重機材/
じゅうきせい /銃規制/
じゅうきち /重吉/
じゅうきねっと /住基ネット/
じゅうきゅう /十九/
じゅうきゅうさい /十九歳/
じゅうきょ /住居/
じゅうきょあと /住居跡/
じゅうきょかんきょう /住居環境/
じゅうきょしんにゅうざい /住居侵入罪/
じゅうきょち /住居地/
じゅうきょちいき /住居地域/
じゅうきょひ /住居費/
じゅうきょひょうじ /住居表示/
じゅうきょひょうじばんごう /住居表示番号/
じゅうきょふほうしんにゅう /住居不法侵入/
じゅうきょようせんざい /住居用洗剤/
じゅうきんぞく /重金属/
じゅうぎょう /従業/
じゅうぎょういん /従業員/
じゅうぎょういんくみあい /従業員組合/
じゅうぎょういんすう /従業員数/
じゅうぎょういんはんばい /従業員販売/
じゅうぎょういんもちかぶせいど /従業員持株制度/
じゅうぎょうしゃ /従業者/
じゅうく /重苦/
じゅうぐん /従軍/
じゅうぐんいあんふ /従軍慰安婦/
じゅうぐんきしゃ /従軍記者/
じゅうぐんしさい /従軍司祭/
じゅうけい /重慶/従兄/重刑/従系/銃刑/
じゅうけいこう /重慶港/
じゅうけいしょう /重軽傷/
じゅうけいてい /従兄弟/
じゅうけいはんてん /重慶飯店/
じゅうけつ /充血/
じゅうけん /住建/銃剣/重検/
じゅうけんじゅつ /銃剣術/
じゅうけんどう /柔剣道/
じゅうけんどうじょう /柔剣道場/
じゅうげき /銃撃/
じゅうげきせん /銃撃戦/
じゅうげん /重言/
じゅうこ /住戸;集合住宅の居住単位/
じゅうこう /重厚/重工/銃口/重項/獣行/
じゅうこうかん /重厚感/
じゅうこうぎょう /重工業/
じゅうこうげき /銃攻撃/
じゅうこうぞう /柔構造;[建築]変形して外力を受け流す構造/
じゅうこく /重刻/縦谷/
じゅうこつ /獣骨/獸骨;「獣」旧字/
じゅうこん /重根/重婚/
じゅうご /銃後/十五/
じゅうごう /重合/
じゅうごうしょくばい /重合触媒/
じゅうごうせい /重合性/
じゅうごうたい /重合体/
じゅうごうど /重合度/
じゅうごねんせんそう /十五年戦争;1931-45/
じゅうごひき /十五匹/
じゅうごや /十五夜/
じゅうさいぼう /柔細胞/
じゅうさつ /銃殺/重刷/重殺/
じゅうさつけい /銃殺刑/
じゅうさん /十三/
じゅうさんかいき /十三回忌/
じゅうさんかいだん /十三階段;絞首台(への階段)/
じゅうさんだいしゅう /十三代集/
じゅうさんづか /十三塚/
じゅうさんや /十三夜/
じゅうさんろばん /十三路盤/
じゅうざ /銃座/
じゅうざい /重罪/縦材;[建築]/
じゅうし /重視/銃士/従姉/獣脂/従祀/
じゅうしちげん /十七絃;大型の琴(1921-)/
じゅうしちし /十七史/
じゅうしちじょうけんぽう /十七条憲法;[日本史]604/
じゅうしちもじ /十七文字/
じゅうしちや /十七夜;立待月/
じゅうしてい /従姉弟/
じゅうしまい /従姉妹/
じゅうしまつ /十姉妹/
じゅうしゃ /従者/
じゅうしやま /十四山/
じゅうしゅつ /重出/
じゅうしょ /住所/
じゅうしょあて /住所宛/
じゅうしょいん /住所印/
じゅうしょう /重症;†重い症状。「-の中毒」，/重傷;†ひどいケガ。「-を負う」/重賞/重唱;[音楽]/銃床;gunstock/
じゅうしょうがい /重障害/
じゅうしょうきゅうせいこきゅうきしょうこうぐん /重症急性呼吸器症候群;severe acute respiratory syndrome(SARS)/
じゅうしょうきょうそう /重賞競走/重賞競争/
じゅうしょうしゅぎ /重商主義/
じゅうしょうせいは /重賞制覇/
じゅうしょく /住職/重職/
じゅうしょしめい /住所氏名/
じゅうしょしめいねんれい /住所氏名年齢/
じゅうしょち /住所地/
じゅうしょてき /住所的/
じゅうしょなど /住所等/
じゅうしょばん /住所判/
じゅうしょひょうき /住所表記/
じゅうしょふてい /住所不定/
じゅうしょふめい /住所不明/
じゅうしょへんこう /住所変更/
じゅうしょらん /住所欄/
じゅうしょろく /住所録/
じゅうしょろくきのう /住所録機能/
じゅうしん /重心/重臣/銃身/住心/従心;70歳/獣身/獣心/
じゅうしんいち /重心位置/
じゅうしんいどう /重心移動/
じゅうしんけい /重心系/
じゅうしんてん /重心点/
じゅうじ /従事/十字/十時/住持/10時/
じゅうじか /十字架/
じゅうじがた /十字形/
じゅうじぐん /十字軍/
じゅうじけい /十字形/
じゅうじしゃ /従事者/
じゅうじしゃめんきょ /従事者免許/
じゅうじしゃめんきょしょう /従事者免許証/
じゅうじじょう /十字状/
じゅうじつ /充実/
じゅうじつかん /充実感/
じゅうじつき /充実期/
じゅうじつど /充実度/
じゅうじつひ /充実費/
じゅうじほうか /十字砲火/
じゅうじゃく /柔弱;=にゅうじゃく/
じゅうじや /十字屋/
じゅうじゅう /重々/
じゅうじゅつ /柔術/
じゅうじゅん /従順/柔順/重巡/
じゅうじょう /十条/重畳/
じゅうじょうえき /十条駅/
じゅうじょうせいし /十條製紙;[企業名]/
じゅうじょうどおり /十条通り/
じゅうじろ /十字路/
じゅうじん /獣人/獣神/
じゅうすい /重水/
じゅうすいそ /重水素/
じゅうすいろ /重水炉;⇔軽水炉/
じゅうすう /十数/
じゅうすうかい /十数回/
じゅうすうきょく /十数局/
じゅうすうこ /十数戸/
じゅうすうつう /十数通/
じゅうすうにん /十数人/
じゅうすうねん /十数年/
じゅうすうねんまえ /十数年前/
じゅうすうばい /十数倍/
じゅうすうびょう /十数秒/
じゅうすうふん /十数分/
じゅうすうほん /十数本/
じゅうすうまん /十数万/
じゅうすうまんえん /十数万円/
じゅうせい /銃声/獣性/重星/
じゅうせき /重責/重石;タングステン鉱石/
じゅうせきぶん /重積分/
じゅうせん /縦線/住専;住宅金融専門会社/
じゅうせんし /重戦士/
じゅうせんしゃ /重戦車/
じゅうぜい /重税/
じゅうぜん /従前/十全/十善;[仏教]/
じゅうぜんじ /十禅師/
じゅうぜんほうご /十善法語/
じゅうそ /重祚/
じゅうそう /縦走/重層/重曹/十三/重奏/重装/銃創/住僧/従僧/
じゅうそうかん /重相関;[数学]multiple correlation/
じゅうそうきへい /重装機兵/
じゅうそうきょく /重奏曲/
じゅうそうこう /重装甲/
じゅうそうせい /重層性/
じゅうそうてき /重層的;multilayered/
じゅうそうとちゅう /縦走途中/
じゅうそうび /重装備/
じゅうそく /充足/充塞/
じゅうそくかのう /充足可能/
じゅうそくかのうせい /充足可能性/
じゅうそしき /柔組織/
じゅうそつ /従卒/
じゅうぞう /十三/重像/
じゅうぞく /従属/
じゅうぞくえいようせいぶつ /従属栄養生物/
じゅうぞくかんけい /従属関係;subordination/
じゅうぞくこく /従属国/
じゅうぞくし /従属子/
じゅうぞくじんこう /従属人口;0〜14歳と65歳以上の人口の和/
じゅうぞくせい /従属性/
じゅうぞくせつ /従属節/
じゅうぞくてき /従属的/
じゅうぞくへんすう /従属変数;[数学]dependent variable/
じゅうぞくろん /従属論/
じゅうたい /渋滞/重体/重態/縦隊/紐帯/銃隊/獣帯/
じゅうたいかくご /渋滞覚悟/
じゅうたいかんわ /渋滞緩和/
じゅうたいこうさてん /渋滞交差点/
じゅうたいさいこうび /渋滞最後尾/
じゅうたいじ /渋滞時/
じゅうたいじょうきょう /渋滞状況/
じゅうたいちゅう /渋滞中/
じゅうたいろ /渋滞路/
じゅうたく /住宅/
じゅうたくか /住宅化/
じゅうたくかいはつ /住宅開発/
じゅうたくがい /住宅街/
じゅうたくきんゆうこうこ /住宅金融公庫/
じゅうたくけい /住宅系/
じゅうたくけんせつひ /住宅建設費/
じゅうたくこうにゅうじ /住宅購入時/
じゅうたくさんぎょう /住宅産業/
じゅうたくしきん /住宅資金/
じゅうたくしんぽうしゃ /住宅新報社/
じゅうたくじじょう /住宅事情/
じゅうたくじょうほう /住宅情報/
じゅうたくせいさく /住宅政策/
じゅうたくせいのう /住宅性能/
じゅうたくせつび /住宅設備/
じゅうたくだんち /住宅団地/
じゅうたくち /住宅地/
じゅうたくちいき /住宅地域/
じゅうたくちく /住宅地区/
じゅうたくちず /住宅地図/
じゅうたくてあて /住宅手当/
じゅうたくてんじじょう /住宅展示場/
じゅうたくはんばい /住宅販売/
じゅうたくひ /住宅費/
じゅうたくひほじょ /住宅費補助/
じゅうたくひよう /住宅費用/
じゅうたくほじょ /住宅補助/
じゅうたくほじょてあて /住宅補助手当/
じゅうたくまえ /住宅前/
じゅうたくもんだい /住宅問題/
じゅうたくよう /住宅用/
じゅうたくろーん /住宅ローン/
じゅうたん /絨毯/絨緞/
じゅうたんさん /重炭酸/
じゅうたんばくげき /絨毯爆撃/絨緞爆撃/
じゅうだい /重大/十代/十大/重代;先祖代々の/
じゅうだい> /重大/
じゅうだいし /重大視/
じゅうだいしゃ /従台車/
じゅうだいじこ /重大事故/
じゅうだいせい /重大性/
じゅうだいはっぴょう /重大発表/
じゅうだいもんだい /重大問題/
じゅうだん /縦断/銃弾/十段/銃彈;旧字/
じゅうだんきこう /縦断紀行/
じゅうだんせん /十段戦/
じゅうだんてき /縦断的/
じゅうだんめん /縦断面/
じゅうちん /重鎮/
じゅうつうざい /縦通材/
じゅうづめ /重詰め/
じゅうてい /従弟/重訂/
じゅうていおん /重低音/
じゅうてき /獣的/
じゅうてん /重点/充填/
じゅうてんか /重点化/
じゅうてんけんきゅう /重点研究/
じゅうてんこうもく /重点項目/
じゅうてんこうりつ /充填効率/
じゅうてんざい /充填剤/
じゅうてんてき /重点的/
じゅうてんりょういき /重点領域/
じゅうてんりょういきけんきゅう /重点領域研究/
じゅうでん /充電/
じゅうでんかのう /充電可能/
じゅうでんかんりょう /充電完了/
じゅうでんかんりょうご /充電完了後/
じゅうでんき /充電器/充電機/
じゅうでんきかん /充電期間/
じゅうでんこうりつ /充電効率/
じゅうでんご /充電後/
じゅうでんしき /充電式/
じゅうでんじ /充電時/
じゅうでんじかん /充電時間/
じゅうでんじょうたい /充電状態/
じゅうでんだい /充電台/
じゅうでんち /充電池/
じゅうでんちゅう /充電中/
じゅうでんでんりゅう /充電電流/
じゅうでんふりょう /充電不良/
じゅうでんよう /充電用/
じゅうでんりょう /充電量/
じゅうとう /充当/住棟/重盗;[野球]double steal/充棟;汗牛-/
じゅうとうほう /銃刀法;[法][略語]銃砲刀剣類所持等取締法/
じゅうとうろく /重登録/
じゅうとく /重篤/
じゅうとこうだん /住都公団/
じゅうとざんぐつ /重登山靴/
じゅうど /重度/
じゅうどう /柔道/
じゅうどうか /柔道家/
じゅうどうぎ /柔道着/
じゅうどうしょうねん /柔道少年/
じゅうどうじょう /柔道場/
じゅうどうせいふくし /柔道整復師/
じゅうどうぶ /柔道部/
じゅうどしょうがい /重度障害/
じゅうなん /柔軟/
じゅうなんか /柔軟化/
じゅうなんかい /十何回/
じゅうなんぎょう /十何行/
じゅうなんざい /柔軟剤/
じゅうなんしあげ /柔軟仕上げ;-剤/
じゅうなんしせい /柔軟姿勢/
じゅうなんせい /柔軟性/
じゅうなんたいそう /柔軟体操/
じゅうなんにち /十何日/
じゅうなんねん /十何年/
じゅうなんまい /十何枚/
じゅうに /十二/１２/
じゅうにいんねん /十二因縁/
じゅうにおん /十二音/
じゅうにおんおんがく /十二音音楽;dodecaphony/
じゅうにかげつ /十二ヶ月/十二カ月/
じゅうにがつ /十二月/１２月/12月/師走;※連想,旧暦/極月;※連想,旧暦/
じゅうにきゅう /十二宮/
じゅうにく /獣肉/
じゅうにし /十二支/子丑寅卯辰巳午未申酉戌亥;※abbrev/十二司;[律令制]/
じゅうにしちょう /十二指腸/
じゅうにしちょうかいよう /十二指腸潰瘍/
じゅうにしちょうがん /十二指腸癌/
じゅうにしと /十二使徒/
じゅうにしんしょう /十二神将/
じゅうにじんしょう /十二神将/
じゅうにてん /十二天/
じゅうにひとえ /十二単/
じゅうにぶん /十二分/
じゅうにほうい /十二方位/
じゅうにりつ /十二律/
じゅうにん /住人/重任/十人/
じゅうにんたち /住人達/
じゅうにんといろ /十人十色/
じゅうにんなみ /十人並/
じゅうねん /十年/十念/
じゅうねんいじょう /十年以上/
じゅうねんいじょうまえ /十年以上前/
じゅうねんいちじつ /十年一日/
じゅうねんご /十年後/
じゅうねんひとむかし /十年一昔/
じゅうねんまえ /十年前/
じゅうねんめ /十年目/
じゅうのうしゅぎ /重農主義/
じゅうはち /十八/
じゅうはちきん /十八金/18禁/１８禁/
じゅうはちぎんこう /十八銀行/
じゅうはちばん /十八番/
じゅうはちらかん /十八羅漢/
じゅうはっしりゃく /十八史略/
じゅうはっぱん /十八般;武芸-/
じゅうはん /重版;reprint/重犯/従犯;⇔主犯/
じゅうばい /十倍/
じゅうばいいじょう /十倍以上/
じゅうばくげきき /重爆撃機/
じゅうばこ /重箱/
じゅうばこよみ /重箱読み/
じゅうばつ /重罰/
じゅうばん /重版/十番/
じゅうばんしょうてんがい /十番商店街/
じゅうばんみてい /重版未定/
じゅうひ /獣皮/柔皮/
じゅうびょう /重病/
じゅうびょうたんい /十秒単位/
じゅうびょうにん /重病人/
じゅうふか /重負荷/
じゅうふく /重複;=ちょうふく/
じゅうぶ /十分/
じゅうぶつ /従物/
じゅうぶん /十分/充分/重文/
じゅうぶんあんてい /十分安定/
じゅうぶんかくほ /十分確保/
じゅうぶんかのう /十分可能/
じゅうぶんしょうち /十分承知/
じゅうぶんしようかのう /十分使用可能/
じゅうぶんじつげんかのう /十分実現可能/
じゅうぶんじょうけん /十分条件/
じゅうぶんせい /十分性/充分性/
じゅうぶんたいおう /充分対応/
じゅうぶんちゅうい /十分注意/
じゅうぶんつうよう /充分通用/
じゅうぶんのいちぜい /十分の一税;[世界史]tithe/
じゅうぶんはいりょ /十分配慮/
じゅうぶんまんぞく /十分満足/
じゅうぶんゆうこう /十分有効/
じゅうへい /従兵/
じゅうべえ /十兵衛/十平衛/
じゅうべん /重弁;[植物]multivalve. 八重咲きの. ⇔単弁/
じゅうべんか /重弁花/
じゅうほう /重宝/銃砲/重砲/什宝/
じゅうほうでん /充放電/
じゅうぼいん /重母音/
じゅうぼう /住房/
じゅうぼく /従僕/
じゅうまい /十枚/従妹/
じゅうまん /充満/十万/
じゅうまんえん /十万円/
じゅうまんおくど /十万億土;[仏教]この世と極楽との距離/
じゅうまんにん /十万人/
じゅうまんばい /十万倍/
じゅうまんぶ /十万部/
じゅうまんほう /充満法/
じゅうみん /住民/
じゅうみんうんどう /住民運動/
じゅうみんか /住民課/
じゅうみんがわ /住民側/
じゅうみんきほんだいちょう /住民基本台帳/
じゅうみんきほんだいちょうほう /住民基本台帳法/
じゅうみんしゅたい /住民主体/
じゅうみんぜい /住民税/
じゅうみんぜいがく /住民税額/
じゅうみんそしょう /住民訴訟/
じゅうみんとうひょう /住民投票/
じゅうみんとうろく /住民登録/
じゅうみんとうろくしょう /住民登録証/
じゅうみんひょう /住民票/住民表;住民のリスト?/
じゅうめい /十名/
じゅうめん /渋面/従免;[略語]従事者免許/
じゅうもう /絨毛;villus/獣毛;animal hair/柔毛;soft hair/
じゅうもうまく /絨毛膜/
じゅうもつ /什物/
じゅうもんじ /十文字/
じゅうもんじこうこう /十文字高校/
じゅうや /十夜/
じゅうやく /重役/十薬;[漢方]ドクダミ/重訳;retranslate/重厄/
じゅうやくしゅっきん /重役出勤/
じゅうゆ /重油/
じゅうよう /重要/重用/充用/
じゅうようかだい /重要課題/
じゅうようきみつ /重要機密/
じゅうようきん /充用金/
じゅうようぎだい /重要議題/
じゅうようけっていじこう /重要決定事項/
じゅうようこうもく /重要項目/
じゅうようご /重要語/
じゅうようさく /重要作/
じゅうようさくひん /重要作品/
じゅうようさんこうにん /重要参考人/
じゅうようし /重要視/重陽子/
じゅうようしょるい /重要書類/
じゅうようしりょう /重要資料/
じゅうようじこう /重要事項/
じゅうようじんぶつ /重要人物/
じゅうようせい /重要性/
じゅうようてん /重要点/
じゅうようど /重要度/
じゅうようぶんかざい /重要文化財/
じゅうようほあんぶひん /重要保安部品/
じゅうようむけいぶんかざい /重要無形文化財/
じゅうようもんだい /重要問題/
じゅうよく /獣欲/
じゅうよん /十四/
じゅうよんさい /十四歳/
じゅうらい /従来/
じゅうらいがた /従来型/
じゅうらいき /従来機/
じゅうらいきかく /従来規格/
じゅうらいきしゅ /従来機種/
じゅうらいぎじゅつ /従来技術/
じゅうらいしゅほう /従来手法/
じゅうらいてき /従来的/
じゅうらいひ /従来比/
じゅうらいほう /従来法/
じゅうらいほうしき /従来方式/
じゅうらん /縦覧/
じゅうり /重利/
じゅうりゅうし /重粒子/
じゅうりょう /重量/従量;-課金/十両/銃猟/
じゅうりょうあげ /重量挙げ/
じゅうりょうかん /重量感/
じゅうりょうきゅう /重量級/
じゅうりょうけい /重量計/
じゅうりょうさ /重量差/
じゅうりょうしゃ /重量車/
じゅうりょうせい /従量制/
じゅうりょうぜい /重量税/従量税/
じゅうりょうぜいかんぷ /重量税還付/
じゅうりょうそくてい /重量測定/
じゅうりょうてき /重量的/
じゅうりょうはいぶん /重量配分/
じゅうりょうひ /重量比/
じゅうりょうぶつ /重量物/
じゅうりょうへんか /重量変化/
じゅうりょく /重力/
じゅうりょくいがい /重力以外/
じゅうりょくいど /重力井戸/
じゅうりょくかそく /重力加速/
じゅうりょくかそくど /重力加速度/
じゅうりょくけい /重力計;gravity meter/重力系;gravitational system/
じゅうりょくけんない /重力圏内/
じゅうりょくげん /重力源/
じゅうりょくこうばい /重力勾配/
じゅうりょくしき /重力式/
じゅうりょくしつりょう /重力質量/
じゅうりょくじょう /重力場/
じゅうりょくせいぎょ /重力制御/
じゅうりょくそうごさよう /重力相互作用/
じゅうりょくていすう /重力定数/
じゅうりょくは /重力波/
じゅうりょくはけんしゅつ /重力波検出/
じゅうりょくはほう /重力波砲/
じゅうりょくはぼうえんきょう /重力波望遠鏡/
じゅうりょくば /重力場;gravity field/
じゅうりょくほうかい /重力崩壊/
じゅうりょくほうこう /重力方向/
じゅうりょくほうていしき /重力方程式/
じゅうりょくれんず /重力レンズ;[天文]gravitational lens/
じゅうりん /蹂躙/蹂躪;「躙」異体字/
じゅうるい /獣類/
じゅうれつ /縦列/
じゅうれつちゅうしゃ /縦列駐車/
じゅうれん /重連/
じゅうろう /十郎/
じゅうろうた /十郎太/
じゅうろうどう /重労働/
じゅうろく /十六/
じゅうろくぎんこう /十六銀行/
じゅうろくさい /十六歳/
じゅうろくしん /十六進/１６進/
じゅうろくしんほう /十六進法/
じゅうろくちゃ /十六茶;[商標]/
じゅうろくぶおんぷ /十六分音符/
じゅうろくや /十六夜/
じゅうろくらかん /十六羅漢;[仏教]/
じゅうわり /十割/
じゅえい /寿永;年号(1182-1184)/樹影/
じゅえき /受益/樹液/
じゅえきけん /受益権/
じゅえきしゃ /受益者/
じゅえきしゃふたん /受益者負担/
じゅえきしゃふたんきん /受益者負担金/
じゅえきしょうけん /受益証券/
じゅおん /受音/
じゅおんがわ /受音側/
じゅおんけい /受音系/
じゅおんてん /受音点/
じゅか /樹下/儒家/樹香/
じゅかい /樹海/受戒/授戒;受戒させる/
じゅかいえ /授戒会;[仏教]/
じゅかせきじょう /樹下石上/
じゅかん /樹冠;[植物]crown/樹幹;trunk/樹間;between the trees/入棺/
じゅがく /儒学/
じゅがん /呪願/
じゅき /授記/
じゅきしゃ /受寄者/
じゅきぶつ /受寄物/
じゅきゅう /需給;supply and demand/受給;receive/
じゅきゅうしかく /受給資格/
じゅきょう /儒教/受教;教えを受けること/授亨;?/
じゅぎょう /授業/受業;教えを受けること/
じゅぎょういがい /授業以外/
じゅぎょうかもく /授業科目/
じゅぎょうしゅっせき /授業出席/
じゅぎょうじかん /授業時間/
じゅぎょうちゅう /授業中/
じゅぎょうてんかい /授業展開/
じゅぎょうとうろく /授業登録/
じゅぎょうないよう /授業内容/
じゅぎょうまえ /授業前/
じゅぎょうよう /授業用/
じゅぎょうりょう /授業料/
じゅぎょうりょうめんじょ /授業料免除/
じゅく /塾;学習-/熟;ripe/受苦/孰;いずれ/宿;(連濁)野宿/
じゅくいん /塾員/
じゅくぎ /熟議/
じゅくこう /熟考/塾講/塾高/
じゅくこうし /塾講師/
じゅくご /熟語/
じゅくし /熟視/熟柿/熟思/
じゅくじ /熟字/
じゅくじくん /熟字訓/
じゅくじょ /熟女/
じゅくすい /熟睡/
じゅくせい /熟成;ripen/塾生;塾の生徒/
じゅくせいど /熟成度/
じゅくたつ /熟達/
じゅくたつか /熟達化/
じゅくたつしゃ /熟達者/
じゅくだん /熟談/
じゅくち /熟知/
じゅくちょう /塾長/
じゅくとう /塾頭/
じゅくど /熟度/
じゅくどく /熟読/
じゅくどくがんみ /熟読玩味/
じゅくない /塾内/
じゅくねん /熟年/
じゅくねんりこん /熟年離婚/
じゅくみん /熟眠/
じゅくらん /熟覧/
じゅくりょ /熟慮/
じゅくりょだんこう /熟慮断行/
じゅくれん /熟練/
じゅくれんこう /熟練工/
じゅくれんしゃ /熟練者/
じゅくれんち /熟練値/
じゅくれんど /熟練度/
じゅくん /受勲/
じゅけい /樹形/受刑/受継/綬鶏/
じゅけいしゃ /受刑者/
じゅけいず /樹形図/
じゅけつしゃ /受血者/
じゅけん /受験/受検;†検査などを受ける/授権/
じゅけんえいご /受験英語/
じゅけんかいじょう /受験会場/
じゅけんかいすう /受験回数/
じゅけんかもく /受験科目/
じゅけんきかい /受験機会/
じゅけんきぼうしゃ /受験希望者/
じゅけんきょうそう /受験競争/
じゅけんきょかしょ /受験許可書/
じゅけんこう /受験校/
じゅけんさんぎょう /受験産業/
じゅけんさんこうしょ /受験参考書/
じゅけんざっし /受験雑誌/
じゅけんしかく /受験資格/
じゅけんしつ /受験室/
じゅけんしほん /授権資本/
じゅけんしゃ /受験者/受検者/
じゅけんしゃすう /受験者数/
じゅけんじゅんび /受験準備/
じゅけんすうがく /受験数学/
じゅけんせい /受験生/
じゅけんせんそう /受験戦争/
じゅけんち /受験地/
じゅけんばんごう /受験番号/
じゅけんひ /受験費/
じゅけんひょう /受験票/
じゅけんび /受験日/
じゅけんべんきょう /受験勉強/
じゅけんまえ /受験前/
じゅけんよう /受験用/
じゅけんりょう /受験料/
じゅげ /頌偈/
じゅげむ /寿限無/
じゅげん /呪言/
じゅこう /受講/樹高/受光/珠光;村田-/
じゅこうきげん /受講期限/
じゅこうしゃ /受講者/
じゅこうしゃていいん /受講者定員/
じゅこうせい /受講生/
じゅこうそし /受光素子/
じゅこうとうろくしゃ /受講登録者/
じゅこうひょう /受講票/
じゅこうぶ /受光部/
じゅこうぶぶん /受光部分/
じゅこうめん /受光面/
じゅこうめんせき /受光面積/
じゅこうよていしゃ /受講予定者/
じゅこうりょう /受講料/
じゅこん /樹根/
じゅごん /呪禁/儒艮/
じゅごんし /呪禁師/
じゅさつ /呪殺/
じゅさん /授産/
じゅさんしせつ /授産施設;vocational aid centre/
じゅし /樹脂/樹枝/呪師/孺子;青二才/豎子;=孺子/儒子/
じゅしせい /樹脂製/樹脂性;resinous/
じゅしどう /樹脂道/
じゅしゃ /儒者/
じゅしゅ /樹種/
じゅしょ /儒書/
じゅしょう /受賞;†(貰う)/授賞;†(授ける)/受章;†勲章を貰う/綬章;†ribbon/受傷;ケガする/
じゅしょうこうえん /受賞講演/
じゅしょうさく /受賞作/
じゅしょうさくひん /受賞作品/
じゅしょうしき /授賞式/
じゅしょうしゃ /受賞者/授賞者;授ける人/
じゅしょうたいしょう /授賞対象/
じゅしん /受信;⇔送信/受診;健診の-/樹心/受身;うけみ/
じゅしんかいすう /受信回数/
じゅしんかいろ /受信回路/
じゅしんかんど /受信感度/
じゅしんがわ /受信側/
じゅしんき /受信機/受信器/
じゅしんきょひ /受信拒否/
じゅしんけいしき /受信形式/
じゅしんけっか /受信結果/
じゅしんさき /受信先/
じゅしんしけん /受信試験/
じゅしんしゃ /受信者/受診者/
じゅしんしゅうはすう /受信周波数/
じゅしんしゅうはすうたい /受信周波数帯/
じゅしんじ /受信時/
じゅしんじっけん /受信実験/
じゅしんじょうきょう /受信状況/
じゅしんじょうたい /受信状態/
じゅしんせつび /受信設備/
じゅしんそうち /受信装置/
じゅしんたん /受信端/
じゅしんちてん /受信地点/
じゅしんちゅう /受信中/
じゅしんつうち /受信通知/
じゅしんてん /受信点/
じゅしんとも /受信共/
じゅしんにん /受信人/
じゅしんばこ /受信箱/
じゅしんび /受診日/
じゅしんふかのう /受信不可能/
じゅしんぶ /受信部/
じゅしんよう /受信用/
じゅしんりょう /受信料/
じゅしんりょうせいど /受信料制度/
じゅじ /誦持/
じゅじゅ /授受/受授;NB:漢文での使用。現代文では授受。/
じゅじゅつ /呪術/
じゅじゅつせい /呪術性/
じゅじゅつてき /呪術的/
じゅじょう /樹上;-生活/樹状;-突起/
じゅじょうとっき /樹状突起/
じゅすい /入水/
じゅすいじさつ /入水自殺/
じゅすいそう /受水槽;[建築]高置水槽に送る水を蓄えておくタンク/
じゅず /数珠/
じゅずだま /数珠玉/
じゅずつなぎ /数珠繋ぎ;-の渋滞/
じゅせい /受精;(♀) fertilisation/樹勢/授精;(♂) semination/寿星;Canopus/儒生/
じゅせいはい /受精胚/
じゅせいらん /受精卵/
じゅせいらんしんだん /受精卵診断;[医]embryo diagnosis/
じゅせいりつ /授精率/
じゅせん /受洗/
じゅぜん /受禅/
じゅそ /呪詛/受訴/呪咀;=呪詛 (NB:「咀」は噛むことなので本来は誤用)/
じゅそう /樹相/樹霜/
じゅそさいばんしょ /受訴裁判所/
じゅぞう /受贈/受像/
じゅぞうき /受像機/
じゅぞうしゃ /受贈者/
じゅたい /受胎/
じゅたいこくち /受胎告知;[キリスト教]annunciation/
じゅたいりつ /受胎率/
じゅたく /受託/
じゅたくさいばんかん /受託裁判官/
じゅたくしゃ /受託者/
じゅたくしゅうわいようぎ /受託収賄容疑/
じゅたくはんばい /受託販売/
じゅだい /入内/
じゅだく /受諾/
じゅだくしょ /受諾書/
じゅちゅう /受注/
じゅちゅうがく /受注額/
じゅちゅうざん /受注残/
じゅちゅうしゃ /受注者/
じゅちゅうせいさん /受注生産/
じゅちゅうび /受注日/
じゅちゅうりょう /受注量/
じゅちょう /受聴/
じゅちょうしゃ /受聴者/
じゅっかい /十戒/述懐/十階/十誡/
じゅっかいき /十回忌/
じゅっかいてん /十回転/
じゅっかんじゅうにし /十干十二支/
じゅっきゅう /恤救/
じゅっけい /術計/
じゅっこ /十個/
じゅっこう /熟考/
じゅっさく /術策/述作/
じゅっし /十指/
じゅっしゅうねん /十周年/
じゅっしん /十進/１０進/10進/
じゅっしんすう /十進数/10進数/
じゅっしんぶんるいほう /十進分類法/
じゅっしんほう /十進法/
じゅっすう /術数/
じゅっちゅう /術中/十中/
じゅっちゅうはっく /十中八九/
じゅっつう /十通/
じゅって /十手/
じゅっとく /拾得/十徳/
じゅっぱ /十把/十羽/
じゅっぱひとからげ /十把一絡げ/十把一絡/
じゅっぴき /十匹/
じゅっぷん /十分/
じゅっぷんかん /十分間/
じゅっぽ /十歩/
じゅつ /術;すべ/述;記述/朮;おけら/戌;(十二支の)いぬ/恤/
じゅつかい /述懐/
じゅつぎ /術技/
じゅつご /述語;†[文法]predicate/術後;†手術後。「-の経過」/術語;†term.「専門家の-」/
じゅつごきごう /述語記号/
じゅつごそうき /術後早期/
じゅつごていぎ /術語定義/
じゅつごぶ /述語部/
じゅつごろん /述語論/
じゅつごろんり /述語論理/
じゅつごろんりしき /述語論理式/
じゅつし /術士/術師/
じゅつしき /術式/
じゅつしゃ /術者/
じゅつぜん /術前/
じゅつちゅう /術中/
じゅつてき /術的/
じゅつぶ /述部/
じゅつほう /術法/
じゅつり /術理/
じゅでん /受電/
じゅどう /受動/
じゅどうきつえん /受動喫煙/
じゅどうせい /受動性/
じゅどうそう /受動相/
じゅどうたい /受動態/
じゅどうてき /受動的/
じゅなん /受難/
じゅなんきょく /受難曲/
じゅなんげき /受難劇;Passion/
じゅにく /受肉/
じゅにゅう /授乳/
じゅにゅうかんかく /授乳間隔/
じゅにゅうき /授乳期/
じゅにゅうふ /授乳婦/
じゅにん /受忍/
じゅにんげんど /受忍限度;[法]我慢の限界/
じゅねーぶ /壽府/
じゅねーぶぐんしゅくかいぎ /ジュネーブ軍縮会議/
じゅのう /受納/
じゅはい /受配/
じゅばく /呪縛/
じゅばん /襦袢/
じゅひ /樹皮/
じゅひょう /樹氷/
じゅひょうげん /樹氷原/
じゅふ /呪符/授付/
じゅふく /寿福/
じゅふくじ /寿福寺/
じゅふん /受粉/
じゅふんじゅ /受粉樹/
じゅぶつ /呪物;fetish/儒仏;儒教と仏教/
じゅへい /寿平/
じゅへんでん /受変電/
じゅほう /呪法/
じゅみょう /寿命/
じゅめい /受命/
じゅめいさいばんかん /受命裁判官/
じゅもく /樹木/
じゅもくい /樹木医/
じゅもくすうはい /樹木崇拝/
じゅもん /呪文/
じゅもんこうげき /呪文攻撃/
じゅよ /授与/
じゅよう /需要/受容/
じゅようか /需要家/
じゅようかいたく /需要開拓/
じゅようかんすう /需要関数/
じゅようき /受容器/
じゅようきょくせん /需要曲線/
じゅようこうぞう /需要構造/
じゅようしゃ /需要者/
じゅようたい /受容体/
じゅようたいきっこうざい /受容体拮抗剤/
じゅようぶ /受容部/
じゅようや /受容野/
じゅようよそく /需要予測/
じゅよしき /授与式/
じゅらい /入来/
じゅらき /ジュラ紀;[地質年代]Jurassic. 2080-1460万年前/
じゅらく /聚楽/入洛/
じゅらくだい /聚楽第;豊臣秀吉の京都の邸宅,ジュラクテイとも/
じゅらくやき /聚楽焼/
じゅり /受理/樹里/樹理/朱里/珠理/寿理/
じゅりき /受理機/
じゅりじょうたい /受理状態/
じゅりすう /受理数/
じゅりつ /樹立/
じゅりつうち /受理通知/
じゅりょう /受領/受療/授領/
じゅりょういん /受領印/
じゅりょうしょ /受領書/
じゅりょうしょう /受領証/
じゅりょうちたい /受領遅滞/
じゅりょく /呪力/
じゅりりつ /受理率/
じゅりん /樹林/
じゅりんたい /樹林帯/
じゅれい /樹齢/寿齢/樹苓/
じゅろう /入牢/
じゅろうじん /寿老人;七福神の一つ/
じゅわ /受話/
じゅわき /受話器/
じゅわしゃ /受話者/
じゅん /順/純/準/巡/馴;馴致/潤;潤色/閏;うるう/淳/醇;芳醇/惇/諄;諄々/遵;遵守/蓴;蓴菜/准;「準」の略字/凖;「準」の異体字/隼;(慣用音)はやぶさ/盾;矛盾/楯;たて/循;循環/旬;上旬/殉;殉職/徇;(したがう)/恂;(まこと)/洵;(まこと)/筍;たけのこ/笋;「筍」の異体字/荀;荀子/詢;交詢/篤;?/
じゅん> /準;(semi-) -決勝/純;(pure) -文学,-喫茶/順;(⇔逆) 順方向,順光線,順パス/准;(assistant) -士官,-教授/
じゅんあい /純愛/
じゅんあつ /順圧/
じゅんあつたいき /順圧大気/
じゅんあんくうこう /順安空港/
じゅんい /順位/準位;エネルギー-/准尉/準尉/遵依/
じゅんいがい /順位外/
じゅんいけってい /順位決定/
じゅんいじゅん /順位順/
じゅんいせん /順位戦/
じゅんいち /純一/淳一/順一/潤一/准一/遵一/
じゅんいちろう /純一郎/潤一郎/淳一郎/順一郎/
じゅんいつ /純一/
じゅんいてん /順位点/
じゅんいにん /準委任/
じゅんいはっぴょう /順位発表/
じゅんいひょう /順位表/
じゅんいよそう /順位予想/
じゅんいん /準員/
じゅんうりあげ /純売上/
じゅんえき /純益/準駅/
じゅんえつ /巡閲/
じゅんえん /順延/巡演/順縁/
じゅんおう /順応/
じゅんおうせい /順応性/
じゅんおおて /準大手/
じゅんおくり /順送り/
じゅんおん /純音/
じゅんか /純化;purify.「民族の-」/順化;acclimate.「高地-」/馴化;≒順化/醇化;influence.「大衆の-」/
じゅんかい /巡回/
じゅんかいいん /準会員/
じゅんかいいんとうろく /準会員登録/
じゅんかいぐん /巡回群/
じゅんかいし /巡回子/
じゅんかいちゅう /巡回中/
じゅんかいむりょう /巡回無料/
じゅんかつ /潤滑/
じゅんかつざい /潤滑剤/潤滑材/
じゅんかつせいのう /潤滑性能/
じゅんかつゆ /潤滑油/
じゅんかめい /準加盟/
じゅんかん /循環/旬刊;10日間毎の刊行/旬間;10日間/准看;[略語]准看護師/
じゅんかんかてい /循環過程;cycle/
じゅんかんがた /循環型/
じゅんかんがたしゃかい /循環型社会/
じゅんかんき /循環器/
じゅんかんきか /循環器科/
じゅんかんきかん /循環器官/
じゅんかんきけい /循環器系/
じゅんかんきしつ /循環気質/
じゅんかんきのう /循環機能/
じゅんかんけいとう /循環系統/
じゅんかんこきゅう /循環呼吸/
じゅんかんごし /准看護師;保健婦助産婦看護婦法一部改正による呼称変更/
じゅんかんごふ /准看護婦/
じゅんかんしき /循環式/
じゅんかんしょうすう /循環小数/
じゅんかんせん /循環線/
じゅんかんぜんじあい /準完全試合/
じゅんかんてき /循環的/
じゅんかんよう /循環用/
じゅんかんろんぽう /循環論法/
じゅんがくし /準学士/
じゅんきし /準棋士/
じゅんきっさ /純喫茶/
じゅんきゅう /準急/
じゅんきゅうこう /準急行/
じゅんきゅうていしゃえき /準急停車駅/
じゅんきゅうよう /準急用/
じゅんきょ /準拠/
じゅんきょう /殉教/順境/
じゅんきょうしゃ /殉教者/
じゅんきょうじゅ /准教授/準教授/
じゅんきょうち /殉教地/
じゅんきょうゆう /準共有/
じゅんきょすう /純虚数/
じゅんきょせい /準拠性/
じゅんきょほう /準拠法/
じゅんきょわく /準拠枠/
じゅんきん /純金/
じゅんきんせい /純金製/
じゅんきんちさんしゃ /準禁治産者/
じゅんぎゃく /順逆/
じゅんぎょう /巡業/巡行/
じゅんぎょうさき /巡業先/
じゅんぎん /純銀/
じゅんぎんせい /純銀製/
じゅんぐり /順繰り/
じゅんぐん /準群/
じゅんけい /純系/順慶/巡警/
じゅんけっしょう /準決勝/準結晶/
じゅんけっしょうせん /準決勝戦/
じゅんけつ /純潔;chaste/純血;pure blood/準決/
じゅんけつしゅ /純血種/
じゅんけつしゅぎ /純血主義/
じゅんけん /巡検/巡見/純絹/
じゅんげつ /旬月/
じゅんげん /純減/
じゅんこ /純子/順子/淳子/潤子/絢子/準子/惇子/醇乎/純乎/ＪＵＮＫＯ/
じゅんこう /巡航;cruise/巡行;circuit. 巡り歩く/順光;⇔逆光/順行;⇔逆行/巡幸;天皇の-/純項/
じゅんこうかん /巡航艦/
じゅんこうこく /準抗告/
じゅんこうしき /準公式/
じゅんこうじ /巡行時/
じゅんこうそく /準光速/
じゅんこうそくど /巡航速度;cruising speed/巡行速度;?/
じゅんこうちゅう /巡航中/巡行中/
じゅんこうみさいる /巡航ミサイル;cruise missile/
じゅんこうむいん /準公務員/
じゅんこく /殉国/
じゅんこくさん /純国産/
じゅんごうかん /準強姦/
じゅんごうとう /準強盗/
じゅんさ /巡査/
じゅんさい /蓴菜/
じゅんさいあか /ジュンサイ亜科/Cabomboideae/
じゅんさちょう /巡査長/
じゅんさつ /巡察/
じゅんさぶちょう /巡査部長/
じゅんさんそ /純酸素/
じゅんざや /順鞘;⇔逆鞘/
じゅんし /巡視/殉死/荀子;(BC298?-BC238) 性悪説/潤史/
じゅんしかん /准士官;将校と下士官との間の位/
じゅんしさん /純資産/
じゅんしせん /巡視船/
じゅんしてい /巡視艇/準指定/
じゅんしどういん /準指導員/
じゅんしゃく /巡錫/
じゅんしゅ /遵守/順守;≒遵守/醇酒/巡狩/巡守/順修/循守/巡酒/
じゅんしゅうにゅう /純収入;net income/
じゅんしゅじこう /遵守事項/
じゅんしゅつりょく /準出力/
じゅんしゅやく /準主役/
じゅんしょう /准将/順昭/
じゅんしょく /殉職/潤色/純色/
じゅんしょくしゃ /殉職者/
じゅんしょとく /純所得/
じゅんしん /純真/純心;NB:学校名など。「純真」の意味では誤字/順心;(学校名など)/
じゅんしんじょし /純心女子/順心女子/
じゅんしんじょしがくえん /順心女子学園/
じゅんしんじょしこうこう /純心女子高校/
じゅんしんむく /純真無垢/
じゅんじ /淳二/淳司/順治/順二/純二/順次/純司/純次/順司/純治/淳嗣/洵二/
じゅんじけんさく /順次検索/
じゅんじしゅっか /順次出荷/
じゅんじしんこう /順次進行/
じゅんじじっこう /順次実行/
じゅんじつ /旬日/閏日/
じゅんじゅん /順々/諄々;-と説く/準々/順順/諄諄/恂恂/循循/
じゅんじゅんけっしょう /準々決勝/準準決勝/
じゅんじゅんゆうしょう /準々優勝/
じゅんじょ /順序/
じゅんじょう /純情/
じゅんじょうかれん /純情可憐/
じゅんじょうは /純情派/
じゅんじょかいろ /順序回路/
じゅんじょかんけい /順序関係/
じゅんじょきかい /順序機械/
じゅんじょすう /順序数/
じゅんじょせい /順序性/
じゅんじょつい /順序対/
じゅんじょづけ /順序付/順序付け/
じゅんじょてき /順序的/
じゅんすい /純粋/純水;pure water/
じゅんすい> /純粋/
じゅんすいし /純粋詩;poesie pure/
じゅんすいしゅぎ /純粋主義;purism/
じゅんすいすうがく /純粋数学/
じゅんすいせん /準推薦/
じゅんすいばいよう /純粋培養/
じゅんすいりせい /純粋理性;[哲学]reine Vernunft(Kantの用語)/
じゅんすいりせいひはん /純粋理性批判;Kritik der reinen Vernunft,1781,Kant/
じゅんすいろんり /純粋論理/
じゅんせい /純正/準正/準星;[天文]quasar/順清/醇正/
じゅんせい> /純正;-部品,-ゴマ油,-インク/
じゅんせいいがい /純正以外/
じゅんせいじょう /準正常/
じゅんせいちょう /純正調/
じゅんせいちょうりつ /純正調律/
じゅんせいてき /準静的/
じゅんせいてきへんか /準静的変化/
じゅんせいないぞう /純正内蔵/
じゅんせいひん /純正品/
じゅんせいぶひん /純正部品/
じゅんせいようひん /純正用品/
じゅんせいりつ /純正律/
じゅんせつ /順接/
じゅんせん /準線/
じゅんせんけい /準線形/
じゅんせんもん /準専門/
じゅんせんゆう /準占有/
じゅんせんりゃく /純戦略/
じゅんぜいきん /準税金/
じゅんぜん /純然/
じゅんそう /順走/
じゅんそく /準則/
じゅんそん /純損/
じゅんそんえき /純損益/
じゅんそんしつ /純損失/
じゅんぞう /純増/淳三/
じゅんたいいん /準隊員/
じゅんたいじょし /準体助詞/
じゅんたく /潤沢/
じゅんたんしょく /準単色/
じゅんち /馴致/
じゅんちょう /順調/順潮/
じゅんて /順手/
じゅんていこう /純抵抗/
じゅんていじょう /準定常/
じゅんていれい /準定例/
じゅんてき /準的/
じゅんてん /順天/
じゅんてんこうこう /順天高校/
じゅんてんどう /順天堂/
じゅんてんどうだいがく /順天堂大学/
じゅんとう /順当/
じゅんとうしょう /順当勝/
じゅんとく /順徳/潤徳/
じゅんとくじょし /潤徳女子/
じゅんとくてんのう /順徳天皇/
じゅんど /純度/
じゅんどうけい /準同型/準同形/
じゅんな /純名/
じゅんなてんのう /淳和天皇/
じゅんなま /純生/
じゅんなん /殉難/
じゅんにゅうりょく /準入力/
じゅんにんてんのう /淳仁天皇/
じゅんねん /閏年/
じゅんのう /順応/
じゅんのうせい /順応性/
じゅんのすけ /淳之介/順之介/純之介/
じゅんばん /順番/
じゅんばんひょう /順番表/
じゅんばんまち /順番待ち/
じゅんぱい /巡拝/潤肺/
じゅんぱく /純白/
じゅんひぶ /順日歩/
じゅんひょうじゅん /準標準/
じゅんび /準備/
じゅんびい /準備委/
じゅんびいいん /準備委員/
じゅんびいいんかい /準備委員会/
じゅんびうんどう /準備運動/
じゅんびかい /準備会/
じゅんびかいごう /準備会合/
じゅんびかつどう /準備活動/
じゅんびかてい /準備過程/
じゅんびかんりょう /準備完了/
じゅんびがかり /準備係/
じゅんびきかん /準備期間/
じゅんびきょういく /準備教育/
じゅんびきん /準備金/
じゅんびこう /準備稿/
じゅんびこうじ /準備工事/
じゅんびごう /準備号/
じゅんびさぎょう /準備作業/
じゅんびしつ /準備室/
じゅんびしょめん /準備書面/
じゅんびじかん /準備時間/
じゅんびだんかい /準備段階/
じゅんびちゅう /準備中/
じゅんびてつづき /準備手続/
じゅんびとうこう /準備登校/
じゅんびばんたん /準備万端/
じゅんびぶそく /準備不足/
じゅんびょう /閏秒/
じゅんびよきんせいど /準備預金制度/
じゅんぴつりょう /潤筆料;漫画・文章を書いた報酬/
じゅんふどう /順不同/
じゅんぶん /純分/
じゅんぶんがく /純文学/
じゅんぶんしょ /準文書/
じゅんぷう /順風/淳風/醇風;=淳風/
じゅんぷうまんぱん /順風満帆/
じゅんへいげん /準平原/
じゅんへんせい /順編成/
じゅんぺい /順平/
じゅんほうがく /純邦楽/
じゅんほうこう /順方向/
じゅんぼく /純朴/淳朴;=純朴/
じゅんぽう /旬報/遵法/順法;=遵法/遵奉;固く守る/
じゅんまい /純米/
じゅんまいぎんじょう /純米吟醸/
じゅんまいぎんじょうしゅ /純米吟醸酒/
じゅんまいしゅ /純米酒/
じゅんまいだいぎんじょう /純米大吟醸/
じゅんめ /巡目/順目/
じゅんめん /純綿/
じゅんもう /純毛/
じゅんや /純也/潤也/順彌/潤哉/
じゅんゆう /巡遊/
じゅんゆうしょう /準優勝/
じゅんよ /旬余/閏余/
じゅんよう /準用/巡洋/
じゅんようかん /巡洋艦/
じゅんようきてい /準用規定/
じゅんようせんかん /巡洋戦艦/巡洋戰艦;「戦」旧字/
じゅんら /巡邏/
じゅんらん /巡覧/
じゅんり /純利/純理/
じゅんりえき /純利益/
じゅんりゅうさん /純硫酸/
じゅんりょう /純良/順良/純量/
じゅんりろんてき /純理論的/
じゅんれい /巡礼/
じゅんれいきゃく /巡礼客/
じゅんれいやど /巡礼宿;hospitium/
じゅんれき /巡歴/
じゅんれつ /順列/
じゅんろ /順路/
じゅんろちょう /順路帳/
じゅんわふう /純和風/
じゆう /自由/事由;reason/
じゆう> /自由;-選挙,-行動/
じゆういし /自由意志/自由意思;?/
じゆういしろん /自由意志論/
じゆういっぱん /自由一般/
じゆううんだい /自由雲台/
じゆうえん /自由円/
じゆうえんぎ /自由演技/
じゆうおうぼ /自由応募/
じゆうおんじょう /自由音場/
じゆうか /自由化/自由科/
じゆうかいとう /自由回答/
じゆうかったつ /自由闊達/
じゆうがおか /自由が丘/自由ヶ丘/
じゆうがくえん /自由学園/
じゆうがた /自由形/
じゆうきどう /自由軌道/
じゆうきまま /自由気儘/自由気まま/
じゆうきょういく /自由教育/
じゆうきょうそう /自由競争/
じゆうきょうそうしじょう /自由競争市場/
じゆうきょく /自由曲/
じゆうきょくめん /自由曲面/
じゆうぎょう /自由業/
じゆうくうかん /自由空間/
じゆうぐん /自由群/
じゆうけい /自由刑/
じゆうけいざい /自由経済/
じゆうけいやく /自由契約/
じゆうけいやくせんしゅ /自由契約選手/
じゆうけん /自由権/
じゆうけんきゅう /自由研究/
じゆうけんり /自由権利/
じゆうげんり /自由原理/
じゆうこう /自由港/
じゆうこうてい /自由行程/
じゆうこうどう /自由行動/
じゆうこくみんしゃ /自由国民社/
じゆうさいりょう /自由裁量/
じゆうさいりょうけん /自由裁量権/
じゆうさんか /自由参加/
じゆうざい /自由財;[経済]⇔経済財/
じゆうざいさん /自由財産/
じゆうし /自由詩/自由市/
じゆうしじょう /自由市場/
じゆうしそう /自由思想/
じゆうしゃかい /自由社会/
じゆうしゅぎ /自由主義/
じゆうしゅぎけいざい /自由主義経済/
じゆうしゅぎしゃ /自由主義者/
じゆうしゅぎしゃかい /自由主義社会/
じゆうしゅぎじんえい /自由主義陣営/
じゆうしゅぎてき /自由主義的/
じゆうしゅっきん /自由出勤/
じゆうしんしょうしゅぎ /自由心証主義/
じゆうしんぶん /自由新聞;[日本史](1882-85) 自由党の機関紙/
じゆうしんぽう /自由新報/
じゆうしんりょう /自由診療;⇔保険診療/
じゆうじかん /自由時間/
じゆうじざい /自由自在/
じゆうじっけん /自由実験/
じゆうじん /自由人/
じゆうすい /自由水/
じゆうせい /自由性/
じゆうせき /自由席/
じゆうせきけん /自由席券/
じゆうせきしゃ /自由席車/
じゆうせきとっきゅうけん /自由席特急券/
じゆうせんたく /自由選択/
じゆうたん /自由端/
じゆうちいき /自由地域/
じゆうちょう /自由帳/
じゆうでんし /自由電子/
じゆうとう /自由党/
じゆうとうこう /自由投稿/
じゆうとうろん /自由討論/
じゆうとし /自由都市;[世界史]commune/
じゆうど /自由度/
じゆうのめがみ /自由の女神;the Statue of Liberty/
じゆうは /自由派/自由波/
じゆうはつめい /自由発明/
じゆうば /自由場/
じゆうふく /自由服/
じゆうぶん /自由文/
じゆうぶんし /自由分子/
じゆうへんすう /自由変数/
じゆうほんぽう /自由奔放/
じゆうぼうえき /自由貿易/
じゆうぼうえききょうてい /自由貿易協定/
じゆうみん /自由民;[世界史]perioeci, freeman/
じゆうみんけん /自由民権/
じゆうみんしゅとう /自由民主党/
じゆうらっか /自由落下/
じゆうりつ /自由律;[文学]17,31文字に囚われない俳句・短歌/
じゆうりょういき /自由領域/
じゆうりょこう /自由旅行/
じゆうれん /自由練/
じゆうれんあい /自由恋愛/
じゆうれんごう /自由連合/
じゆうれんしゅう /自由練習/
じゆうれんそう /自由連想/
じゆうれんそうほう /自由連想法/
じゆうろん /自由論/
じゆうろんぶん /自由論文/
じゆうわく /自由枠/
じょ /序/助/所/女/如;如才/恕;(ゆるす)寛恕/洳/絮;わた/茹;ゆ・でる/汝;なんじ/叙;叙述/敍;「叙」の旧字(人名用漢字)/敘;「叙」の旧字2/徐;徐行/除;除算/蜍;蟾蜍(せんじょ,ヒキガエル)/抒;抒情/舒;(のべる)/鋤;すき/耡;≒鋤/莇;あざみ/杼/
じょ> /助/
じょい /女医/叙位/
じょいん /女陰/
じょう /上/情/錠/場/状/乗/条/嬢/畳/帖/城/常/判官;[律令制]/尉;[律令制](五衛府で)=判官/丈;10尺/杖;つえ/仗;儀杖兵/壌;土壌/穣;豊穣/譲;譲渡/醸;醸成/壤;「壌」の旧字/孃;「嬢」の旧字(人名用漢字)/攘;尊皇攘夷/禳;(はらう)/襄/驤/穰;「穣」の旧字(人名用漢字)/讓;「譲」の旧字(人名用漢字)/釀;「醸」の旧字(人名用漢字)/浄;浄化/静;静脈/瀞;とろ/淨;「浄」の旧字(人名用漢字)/靜;「静」の旧字(人名用漢字)/剰;過剰/剩;「剰」の旧字(人名用漢字)/乘;「乗」の旧字(人名用漢字)/定;案の定/諚;勅諚/丞;丞相/蒸;蒸留/拯/烝/繞;囲繞/遶;≒繞/蕘;きこり/饒;饒舌/滌;洗滌/絛;絛虫(=条虫)/條;「条」の旧字(人名用漢字)/茸;きのこ/聶;≒囁/躡;(ふむ)/冗;冗談/擾;擾乱/娘/仍;なお/嫋;たお・やか/嬲;なぶ・る/蟐;もみ?/縄;縄文/繩;「縄」の旧字/塲;「場」の異体字/疊;「畳」の旧字(人名用漢字)/疉;「畳」の旧字2/疂;「畳」の旧字3/貞;(慣用音)貞永式目/成;(呉音)成仏/盛;(呉音)繁盛/生/星;明星/
じょう> /上/娘;娘語,娘細胞/
じょうあい /情愛/情合/
じょうあつ /常圧/
じょうい /上位/攘夷/情意/譲位/上意;-下達/上衣/上医/
じょうい> /上位;-概念,-分野,-ビット/
じょういうち /上意討ち/
じょういかいそう /上位階層/
じょういかたつ /上意下達/
じょういがいねん /上位概念/
じょういき /浄域/
じょういきかく /上位規格/
じょういきしゅ /上位機種/
じょういけいさい /上位掲載/
じょういげんご /上位言語/
じょういこう /上位校/
じょういご /上位語/
じょういごかん /上位互換/
じょういごかんき /上位互換機/
じょういごかんせい /上位互換性/
じょういしめい /上位指名/
じょういしゃ /上位者/
じょういじん /上位陣/
じょういそう /上位層/
じょういち /譲一/
じょういどうし /上位同士/
じょういどくせん /上位独占/
じょういにゅうしょう /上位入賞/
じょういにゅうしょうしゃ /上位入賞者/
じょういにんき /上位人気/
じょういば /上位馬/
じょういばん /上位版/
じょういひょう /上位票/
じょういろん /攘夷論/
じょういん /乗員/上院/剰員;余分な人員/冗員;=剰員/畳韻/
じょういんぎいん /上院議員/
じょううち /常打/
じょうえ /浄衣/浄穢/
じょうえい /上映/貞永;年号(1232-1233)/
じょうえいかい /上映会/
じょうえいきんし /上映禁止/
じょうえいけん /上映権/
じょうえいしきもく /貞永式目/
じょうえいじ /上映時/
じょうえいじかん /上映時間/
じょうえいちゅう /上映中/
じょうえつ /上越/上謁/
じょうえつこくさい /上越国際/
じょうえつし /上越市/
じょうえつしんかんせん /上越新幹線/
じょうえつせん /上越線/
じょうえつせんえんせん /上越線沿線/
じょうえつほうめん /上越方面/
じょうえん /上演/情炎/
じょうえんけん /上演権/
じょうえんちゅう /上演中/
じょうおう /女王/貞応;年号(1222-1224)/
じょうおうへいか /女王陛下/
じょうおく /場屋/
じょうおん /常温/上音;overtone/
じょうおんかくゆうごう /常温核融合/
じょうおんほぞん /常温保存/
じょうか /浄化/城下/情歌/浄火/情火/情科/上下/
じょうかい /上階/常会/上界/場開/浄界/
じょうかく /城郭;城の郭,全体/娘核;[生物]daughter nucleus/城閣;城の物見/城廓;=城郭/定格;=ていかく/
じょうかけん /情科研/
じょうかさいりよう /浄化再利用/
じょうかさよう /浄化作用/
じょうかそう /浄化槽/
じょうかそうち /浄化装置/
じょうかそうほう /浄化槽法/
じょうかた /城方/
じょうかのうりょく /浄化能力/
じょうかまち /城下町/城下街/
じょうかるび /上カルビ/
じょうかん /上巻/情感/上官/城館/乗艦/上燗/条款/上浣;月の上旬/常関/冗官;無用の役人/上澣;=上浣/
じょうかんてき /情感的/
じょうかんぱん /上甲板/
じょうがい /場外/城外/
じょうがいせん /場外戦/
じょうがいはつばいしょ /場外発売所/
じょうがいはつばいじょ /場外発売所/
じょうがいらんとう /場外乱闘/
じょうがく /上顎/
じょうがくおん /上顎音;[音声学]硬口蓋音/
じょうがくら /城ケ倉/
じょうがさき /城ケ崎/
じょうがしま /城ヶ島/
じょうがん /貞観;年号(859-877)/情願/
じょうがんきゃくしき /貞観格式/
じょうがんじがわ /常願寺川/
じょうがんじだい /貞観時代;859-877/
じょうき /上記/蒸気/上気/条規/常軌;-を逸する/常規/蒸氣;「気」旧字/情機/
じょうきあつ /蒸気圧/
じょうきあて /上記宛/
じょうきあん /上記案/
じょうきいがい /上記以外/
じょうきおう /蒸氣王/
じょうきかいごう /上記会合/
じょうきがま /蒸気缶/
じょうききかん /蒸気機関/上記期間/
じょうききかんしゃ /蒸気機関車/
じょうききかんない /上記期間内/
じょうきぎり /蒸気霧/
じょうきくどう /蒸気駆動/
じょうきげん /上機嫌/上喜元/
じょうきさんしょう /上記参照/
じょうきしき /蒸気式/
じょうきしつもん /上記質問/
じょうきしょうじょう /上記症状/
じょうきじょうけん /上記条件/
じょうきせいめい /上記声明/
じょうきせん /蒸気船/
じょうきてじゅん /上記手順/
じょうきないよう /上記内容/
じょうきはつげん /上記発言/
じょうきひょう /蒸気表/
じょうきぶんしょう /上記文章/
じょうきほうほう /上記方法/
じょうきほん /情機本/
じょうきもくてき /上記目的/
じょうきゃく /乗客/上客/常客/
じょうきゃくすう /乗客数/
じょうきゃくぞう /乗客増/
じょうきゃくるい /橈脚類/
じょうきゅう /上級/承久/上丘/
じょうきゅうかいいん /上級会員/
じょうきゅうき /上級機/
じょうきゅうさいばんしょ /上級裁判所/
じょうきゅうざい /上級財;[経済]superior goods/
じょうきゅうしかく /上級資格/
じょうきゅうしかん /上級士官/
じょうきゅうしきかん /上級指揮官/
じょうきゅうしゃ /上級者/
じょうきゅうしゃいじょう /上級者以上/
じょうきゅうしゃむけ /上級者向/
じょうきゅうしゃよう /上級者用/
じょうきゅうしょく /上級職/
じょうきゅうしょくいん /上級職員/
じょうきゅうしん /上級審/
じょうきゅうせい /上級生/
じょうきゅうひん /上級品/
じょうきゅうへん /上級編/
じょうきゅうよう /上級用/
じょうきょう /状況/上京/情況;≒状況/貞享;年号(1684-1688)/常況;常態/情教;情報教育?/
じょうきょういぞん /状況依存/
じょうきょういぞんせい /状況依存性/
じょうきょういみろん /状況意味論/
じょうきょうか /状況下/
じょうきょうかんさつ /状況観察/
じょうきょうしだい /状況次第/
じょうきょうしょうこ /状況証拠/情況証拠/
じょうきょうせってい /状況設定/
じょうきょうせつめい /状況説明/
じょうきょうそうてい /状況想定/
じょうきょうてきにんち /状況的認知/
じょうきょうはんだん /状況判断/
じょうきょうびょうしゃ /状況描写/
じょうきょうほうこく /状況報告/
じょうきょうりろん /状況理論/
じょうきょうろんてき /状況論的/
じょうきようりょう /上記要領/
じょうきよく /蒸気浴;sauna/
じょうきりゆう /上記理由/
じょうきれんらくさき /上記連絡先/
じょうきろんぶん /上記論文/
じょうきん /常勤/
じょうぎ /定規/情誼/情義/情宜/
じょうぎざ /定規座;Norma(Nor)/
じょうぎょう /常行/
じょうぎょうざんまい /常行三昧;[仏教]/
じょうぎょうどう /常行堂;[仏教]/
じょうく /冗句/畳句/
じょうくう /上空/
じょうぐう /上宮/
じょうけい /情景/上掲/上計/常経/場景/常形/杖刑/
じょうけいびょうしゃ /情景描写/
じょうけん /条件/條件/情研/
じょうけんいはん /条件違反/
じょうけんえんざんし /条件演算子/
じょうけんおんど /条件温度/
じょうけんか /条件下/
じょうけんしき /条件式/
じょうけんしだい /条件次第/
じょうけんすう /条件数/
じょうけんせってい /条件設定/
じょうけんせん /条件戦/
じょうけんたんさく /条件探索/
じょうけんつき /条件付/条件付き/
じょうけんつきかくりつ /条件付確率/
じょうけんつきぶんぷ /条件付き分布/
じょうけんづけ /条件付け/条件付/
じょうけんていじ /条件提示/
じょうけんてき /条件的/
じょうけんとうそう /条件闘争/
じょうけんとくべつ /条件特別/
じょうけんはんしゃ /条件反射/
じょうけんはんしゃてき /条件反射的/
じょうけんはんだん /条件判断/
じょうけんば /条件馬/
じょうけんぶ /条件部/
じょうけんぶぶん /条件部分/
じょうけんぶん /条件文/
じょうけんぶんき /条件分岐/
じょうけんぶんきめいれい /条件分岐命令/
じょうけんへんこう /条件変更/
じょうけんへんすう /条件変数/
じょうけんほう /条件法;conditional(conditionel)/條件法/
じょうけんめい /条件名/
じょうげ /上下/
じょうげいどう /上下移動/
じょうげうんどう /上下運動/
じょうげかん /上下巻/
じょうげかんかく /上下間隔/
じょうげかんけい /上下関係/
じょうげさゆう /上下左右/↑↓←→/
じょうげすい /上下水/
じょうげすいどう /上下水道/
じょうげせん /上下線/
じょうげどう /上下動/
じょうげぶんかつ /上下分割/
じょうげぶんさつ /上下分冊/
じょうげほう /上下法/
じょうげほうこう /上下方向/
じょうげめん /上下面/
じょうげやじるし /上下矢印/
じょうげん /上限/上弦;-の月/上元;陰暦正月15日/貞元;年号(976-978)/
じょうげんいない /上限以内/
じょうげんかかく /上限価格/
じょうげんかげん /上限下限/
じょうげんがく /上限額/
じょうげんすう /上限数/
じょうげんち /上限値/
じょうこ /上古/杖鼓/上戸/
じょうこう /条項/乗降/上皇/情交/情工/上向/上行/
じょうこうきゃく /乗降客/
じょうこうきゃくすう /乗降客数/
じょうこうぐち /乗降口/
じょうこうしゃ /乗工社/
じょうこうじかん /乗降時間/
じょうこうせい /上向性/
じょうこうはん /上甲板;=じょうかんぱん/
じょうこうよう /乗降用/
じょうこく /上告/
じょうこくきかん /上告期間/
じょうこくききゃく /上告棄却/
じょうこくさいばんしょ /上告裁判所/
じょうこくしん /上告審/
じょうこくちゅう /上告中/
じょうこくにん /上告人/
じょうこくもうしたてしょ /上告申立書/
じょうこしゃそ /城狐社鼠/
じょうこん /上根/乗根/条痕/定根/
じょうこんばん /条痕板/
じょうご /上戸/漏斗/畳語/冗語/剰語/常語/
じょうごう /乗号/
じょうごほう /畳語法/
じょうごわ /情強/
じょうさい /城塞/城砦;=城塞/城西;地名/攘災;-招福/条西;?/
じょうさいだい /城西大/
じょうさいだいがく /城西大学/
じょうさいぼう /娘細胞;[生物]daughter cell.⇔母細胞/嬢細胞;=娘細胞/
じょうさく /上策/上作/城柵/縄索/
じょうさし /状差し/状差/
じょうさま /上様/嬢様/
じょうさん /蒸散/乗算;じょうざん/
じょうさんめいれい /乗算命令/
じょうざ /上座/定座/常座/
じょうざい /錠剤/浄財/常在/浄罪/杖罪/剰剤/
じょうざいせんじょう /常在戦場/
じょうざぶ /上座部/
じょうざん /乗算/常山;地名,→恒山/
じょうざんえんざん /乗算演算/
じょうざんかいすう /乗算回数/
じょうざんかいろ /乗算回路/
じょうざんき /乗算器/
じょうざんけい /定山渓/
じょうし /上司/城址/上肢/上梓;publish/城市/上使/情死/上士/情シ;[略語]「情報システム(部門)」か/情子/上巳/
じょうしき /常識/定式/上式/常式/
じょうしきいぜん /常識以前/
じょうしきか /常識化/常識家/
じょうしきじん /常識人/
じょうしきちゅう /常識中/
じょうしきてき /常識的/
じょうしきまく /定式幕/
じょうしきん /上肢筋/
じょうした /城下/
じょうしつ /上質/
じょうしつし /上質紙/
じょうしゃ /乗車/盛者/浄写/
じょうしゃいち /乗車位置/
じょうしゃえき /乗車駅/
じょうしゃかのう /乗車可能/
じょうしゃきゃく /乗車客/
じょうしゃきょひ /乗車拒否/
じょうしゃきろく /乗車記録/
じょうしゃきんし /乗車禁止/
じょうしゃくかん /乗車区間/
じょうしゃぐち /乗車口/
じょうしゃけいろ /乗車経路/
じょうしゃけん /乗車券/
じょうしゃけんるい /乗車券類/
じょうしゃこうりつ /乗車効率/
じょうしゃじ /乗車時/
じょうしゃじかん /乗車時間/
じょうしゃじんいん /乗車人員/
じょうしゃせいりけん /乗車整理券/
じょうしゃせん /乗車船/
じょうしゃせんよう /乗車専用/
じょうしゃそうち /乗車装置/
じょうしゃたいけん /乗車体験/
じょうしゃていいん /乗車定員/
じょうしゃとびら /乗車扉/
じょうしゃにんずう /乗車人数/
じょうしゃひっすい /盛者必衰/
じょうしゃひょう /乗車票/
じょうしゃび /乗車日/
じょうしゃへんこう /乗車変更/
じょうしゃほうほう /乗車方法/
じょうしゃまえ /乗車前/
じょうしゃりつ /乗車率/
じょうしゃりょう /乗車料/
じょうしゃりょうきん /乗車料金/
じょうしゅ /城主/情趣/
じょうしゅう /常習/上州/常州/城州/
じょうしゅうきつえんしゃ /常習喫煙者/
じょうしゅうしゃ /常習者/
じょうしゅうじ /上州路/
じょうしゅうてき /常習的/
じょうしゅうはん /常習犯/
じょうしゅうや /上州屋/
じょうしゅかく /城主格/
じょうしゅく /定宿;NB:「じょうやど」が一般的/
じょうしゅてき /情趣的/
じょうしゅび /上首尾/
じょうしょ /上書/浄書/情緒/情処/条書/
じょうしょう /上昇/常勝/丞相/上声/
じょうしょうおん /上昇音/
じょうしょうかく /上昇角/
じょうしょうかん /上昇管/
じょうしょうがた /上昇型/
じょうしょうきりゅう /上昇気流/
じょうしょうけいこう /上昇傾向/
じょうしょうけいれつ /上昇系列/
じょうしょうしこう /上昇志向/
じょうしょうじ /上昇時/
じょうしょうせん /上昇線/
じょうしょうちゅう /上昇中/
じょうしょうど /上昇度/
じょうしょうはば /上昇幅/
じょうしょうりつ /上昇率/
じょうしょうりょう /上昇量/
じょうしょかい /情処会/
じょうしょがっかい /情処学会/
じょうしょく /常食/
じょうしょしょうがい /情緒障害/
じょうしょてんめん /情緒纏綿/
じょうしょぶ /情処部/
じょうしょろん /情処論/
じょうしん /上新/上唇/上申/浄心/上進/
じょうしんえつ /上信越/
じょうしんえつどう /上信越道/
じょうしんえつほうめん /上信越方面/
じょうしんこ /上新粉/
じょうしんしょ /上申書/
じょうしんでんき /上新電機;[企業名]/
じょうしんでんてつ /上信電鉄/
じょうじ /譲二/常時/貞治;年号(1365-1368)/丈二/情事/丈治/畳字/条二/丈嗣/常児/
じょうじかいてん /常時回転/
じょうじかいほう /常時開放/
じょうじかんし /常時監視/
じょうじけいたい /常時携帯/
じょうじしよう /常時使用/
じょうじじゅうでん /常時充電/
じょうじせいたい /常磁性体/
じょうじせつぞく /常時接続/
じょうじつ /情実/
じょうじてんとう /常時点灯/
じょうじてんとうしき /常時点灯式/
じょうじま /城島/
じょうじゅ /成就/譲受/上寿;100歳/
じょうじゅう /常住/
じょうじゅうふだん /常住不断/
じょうじゅつ /上述/杖術/
じょうじゅにん /譲受人/
じょうじゅん /上旬/
じょうじゅんごろ /上旬頃/
じょうじょ /乗除/
じょうじょう /上々/上場/情状/上上/上乗/常常/常状/烝烝/条条/畳畳/嫋嫋/常情/穣穣/擾擾/
じょうじょうかぶしき /上場株式/
じょうじょうがいしゃ /上場会社/
じょうじょうきぎょう /上場企業/
じょうじょうきち /上々吉/
じょうじょうしゃくりょう /情状酌量/
じょうじょうはいし /上場廃止/
じょうじょうらい /上場来/
じょうじょざん /乗除算/
じょうじん /常人/情人/成尋/
じょうすい /浄水;clean water/上水;tap waer/定水/
じょうすいき /浄水器/浄水機/
じょうすいご /浄水後/
じょうすいじょう /浄水場/
じょうすいじょうせいび /浄水場整備/
じょうすいせいのう /浄水性能/
じょうすいち /浄水池/
じょうすいどう /上水道/
じょうすいのうりょく /浄水能力/
じょうすいほうしき /浄水方式/
じょうすう /乗数;multiplier/常数;constant/条数/定数;ていすう?/剰数;?/
じょうすうけん /情数研/
じょうすうこうか /乗数効果/
じょうすうじかん /定数時間/
じょうすうち /定数値/
じょうすうばい /定数倍/
じょうすけ /譲介/
じょうず /上手/上図;figure above/
じょうずへた /上手下手/
じょうせい /情勢/醸成/城西/上製/上清/状勢;=情勢/上声;じょうしょう/
じょうせいほん /上製本/情制本/
じょうせき /定石/上席/城跡/定跡;[将棋]/定席/上積/乗積/鐘石/城蹟;=城跡/攘斥/
じょうせきか /定跡化/
じょうせきけい /定石形/
じょうせきしゅう /定石集/
じょうせきてき /定石的/
じょうせきひょう /乗積表/
じょうせきぶん /上積分/
じょうせきもん /縄蓆文/
じょうせつ /常設/
じょうせついん /浄雪院/
じょうせつかん /常設館/
じょうせつてん /常設展/
じょうせつてんじ /常設展示/
じょうせつばしょ /常設場所/
じょうせん /乗船/情宣;情報宣伝/上船/
じょうせんけん /乗船券/
じょうせんしょくたい /常染色体;[生物]autosome/
じょうせんりょう /乗船料/
じょうせんわりびきけん /乗船割引券/
じょうぜつ /饒舌/
じょうぜん /定禅/
じょうぜんじ /定禅寺/
じょうぜんじどおり /定禅寺通り/定禅寺通/
じょうぜんみずのごとし /上善如水/
じょうそ /上訴/上疏/
じょうそう /上層/情操/常総/上奏/情想/
じょうそううん /上層雲/
じょうそうがくいん /常総学院/
じょうそうきょういく /情操教育/
じょうそうご /上層語/
じょうそうぶ /上層部/
じょうそく /常則/
じょうそけん /上訴権/
じょうぞう /醸造/
じょうぞうしゅ /醸造酒/
じょうぞうしょ /醸造所/
じょうぞうじょ /醸造所/
じょうぞうす /醸造酢/
じょうぞうもと /醸造元/
じょうぞうよう /醸造用/
じょうた /饒多/
じょうたい /状態;state/上体/常態;normal state.「汚職の-化」/常体;⇔敬体/情態;state of mind/上腿/
じょうたいいってい /状態一定/
じょうたいか /常態化/
じょうたいくうかん /状態空間/
じょうたいしゅうごう /状態集合/
じょうたいじょうほう /状態情報/
じょうたいすう /状態数/
じょうたいず /状態図/
じょうたいせんい /状態遷移/
じょうたいせんいかんすう /状態遷移関数/
じょうたいせんいず /状態遷移図/
じょうたいち /状態値/
じょうたいはん /状態犯/
じょうたいへんか /状態変化/
じょうたいへんすう /状態変数/
じょうたいべくとる /状態ベクトル/
じょうたいほうていしき /状態方程式/
じょうたいりょう /状態量/
じょうたつ /上達/
じょうたん /上端/
じょうだい /上代/城代/
じょうだいご /上代語/
じょうだいとくしゅかなづかい /上代特殊仮名遣い/
じょうだいぶんがく /上代文学/
じょうだま /上玉/
じょうだん /冗談/上段/
じょうだんぬき /冗談抜き/冗談抜;?/
じょうだんはんぶん /冗談半分/
じょうち /上智/上知/上地/常置/城地/情痴/情致/
じょうちそつ /上智卒/
じょうちだい /上智大/
じょうちだいがく /上智大学/
じょうちばしょ /常置場所/
じょうちゃく /蒸着/
じょうちゃくそう /蒸着層/
じょうちゃくまく /蒸着膜/
じょうちゃん /嬢ちゃん/
じょうちゅう /常駐/焼酎;(連濁)/静注/城中/
じょうちゅうかいじょ /常駐解除/
じょうちゅうがた /常駐型/
じょうちゅうげ /上中下/
じょうちゅうご /常駐後/
じょうちゅうじ /常駐時/
じょうちゅうぶ /常駐部/
じょうちゅうもの /常駐物/
じょうちゅうりょう /常駐量/
じょうちょ /情緒/
じょうちょう /冗長/場長/上長/情調/上聴/
じょうちょうか /冗長化/
じょうちょうせい /冗長性/
じょうちょうど /冗長度/
じょうちょうぶぶん /冗長部分/
じょうちょく /常直/
じょうちょせい /情緒性/
じょうちょてき /情緒的/
じょうちょふあんてい /情緒不安定/
じょうちょろん /情緒論/
じょうつう /情通/
じょうつうけん /情通研/
じょうてい /上程/上帝/上底/
じょうていめん /上底面/
じょうてもの /上手物/
じょうてん /上天/
じょうてんき /上天気/
じょうでき /上出来/
じょうでんけん /情電研/
じょうと /譲渡/
じょうとう /上等/城東/常套/上棟/上道/
じょうとうく /常套句/城東区/
じょうとうしき /上棟式/
じょうとうしゅだん /常套手段/
じょうとうせん /城東線/
じょうとうへい /上等兵/
じょうとうらがき /譲渡裏書/
じょうとえき /譲渡益/
じょうとかのうていきよきんしょうしょ /譲渡可能定期預金証書/
じょうとく /常徳/
じょうとくい /上得意;良いお得意さん/常得意;いつものお得意さん/
じょうとさき /譲渡先/
じょうとしょうしょ /譲渡証書/
じょうとしょうめい /譲渡証明/
じょうとしょうめいしょ /譲渡証明書/
じょうとしょとく /譲渡所得/
じょうとせい /譲渡性/
じょうとせいよきん /譲渡性預金;negotiable deposit/
じょうとぜい /譲渡税/
じょうとぞん /譲渡損/
じょうとたんぽ /譲渡担保/
じょうど /浄土/
じょうどいん /浄土因/
じょうどう /情動/常道/成道;成仏得道/杖道/
じょうどうきょく /常動曲/
じょうどうしょう /常同症/
じょうどがはま /浄土ヶ浜/
じょうどきょう /浄土教/
じょうどしゅう /浄土宗/
じょうどしんしゅう /浄土真宗/
じょうどじ /浄土寺/
じょうどもん /浄土門/
じょうない /場内/城内/
じょうないそうぜん /場内騒然/
じょうないだいかんせい /場内大歓声/
じょうないばくしょう /場内爆笑/
じょうないほうそう /場内放送/
じょうなん /城南/
じょうなんちょう /城南町/
じょうなんでんき /城南電器;[企業名]/
じょうなんどう /上南洞/
じょうにん /常任/常人/
じょうにん> /常任;-理事,-幹事,-委員会/
じょうにんいいん /常任委員/
じょうにんしきしゃ /常任指揮者/
じょうにんりじ /常任理事/
じょうにんりじこく /常任理事国;安保理/
じょうねつ /情熱/
じょうねつか /情熱家/
じょうねつてき /情熱的/
じょうねん /情念/
じょうの /上の/
じょうのう /上納/
じょうのうきん /上納金/
じょうのうち /城之内/
じょうはいじく /上胚軸/
じょうはく /上白;「-米」「-糖」/上膊;上腕部/上拍;[音楽]arsis,upbeat/
じょうはくとう /上白糖/
じょうはつ /蒸発/
じょうはつげんしょう /蒸発現象/
じょうはつざら /蒸発皿/
じょうはつせんねつ /蒸発潜熱/
じょうはつそうち /蒸発装置/
じょうはつそくど /蒸発速度/
じょうはつねつ /蒸発熱;[化学]≒気化熱/
じょうはな /城端/
じょうはり /浄玻璃/
じょうはん /畳半/上半/
じょうはんしん /上半身/
じょうはんしんはだか /上半身裸/
じょうば /乗馬/
じょうばこ /状箱/
じょうばふく /乗馬服/
じょうばん /常磐/定盤/
じょうばんかいそく /常磐快速/
じょうばんかいそくせん /常磐快速線/
じょうばんこうそく /常磐高速/
じょうばんじどうしゃどう /常磐自動車道/
じょうばんせん /常磐線/
じょうばんせんあやせえき /常磐線綾瀬駅/
じょうばんせんかいそく /常磐線快速/
じょうばんせんない /常磐線内/
じょうばんせんほうめん /常磐線方面/
じょうばんたんこうぶし /常磐炭坑節/
じょうばんどう /常磐道/
じょうひ /上皮/冗費/
じょうひしょうたい /上皮小体;[解剖]parathyroid gland/
じょうひそしき /上皮組織;[生物]epithelial tissue/
じょうひょう /上表/上平/
じょうひん /上品/
じょうび /常備/
じょうびぐん /常備軍/
じょうびさい /常備菜/
じょうびたき /尉鶲/
じょうびぶん /常微分/
じょうびぶんほうていしき /常微分方程式/
じょうびやく /常備薬/
じょうふ /情婦/情夫/上布/丈夫/
じょうふく /条幅/浄福/
じょうふんべつ /上分別/
じょうぶ /丈夫/上部/
じょうぶくろ /状袋/
じょうぶこうぞう /上部構造/
じょうぶつ /成仏/
じょうぶん /条文/上分;[日本史]年貢/上文;sentence above/上聞/冗文/
じょうぶんきてい /条文規定/
じょうへい /城兵/
じょうへき /城壁/
じょうへん /上辺/城辺/上編/上篇/
じょうほ /譲歩/
じょうほう /情報/上方/定法/乗法/常法/城宝/城堡/城寳;「宝」旧字/
じょうほうあっしゅく /情報圧縮/
じょうほういがい /情報以外/
じょうほういん /情報員/
じょうほういんぺい /情報隠蔽/
じょうほうえんしゅうしつ /情報演習室/
じょうほうおうよう /情報応用/
じょうほうか /情報化/情報科/
じょうほうかいじ /情報開示/
じょうほうかいせき /情報解析/
じょうほうかいせきがく /情報解析学/
じょうほうかいせきぎじゅつ /情報解析技術/
じょうほうかいはつしつ /情報開発室/
じょうほうかがく /情報科学/
じょうほうかがくか /情報科学科/
じょうほうかがくかんけい /情報科学関係/
じょうほうかがくきょうしつ /情報科学教室/
じょうほうかがくけんきゅうか /情報科学研究科/
じょうほうかがくしゃ /情報科学者/
じょうほうかがくじてん /情報科学辞典/
じょうほうかがくせんこう /情報科学専攻/
じょうほうかがくてき /情報科学的/
じょうほうかがくぶ /情報科学部/
じょうほうかがっか /情報科学科/
じょうほうかくさ /情報格差/
じょうほうかくめい /情報革命/
じょうほうかしゃかい /情報化社会/
じょうほうかた /情報過多/
じょうほうかつどう /情報活動/
じょうほうかでん /情報家電/
じょうほうかん /情報館/情報官/
じょうほうかんきょう /情報環境/
じょうほうかんけい /情報関係/
じょうほうかんり /情報管理/
じょうほうかんりがっか /情報管理学科/
じょうほうかんりしせつ /情報管理施設/
じょうほうかんれん /情報関連/
じょうほうがく /情報学/
じょうほうがくぶ /情報学部/
じょうほうがくるい /情報学類/
じょうほうがっか /情報学科/
じょうほうきおく /情報記憶/
じょうほうきか /情報幾何/
じょうほうきき /情報機器/
じょうほうききぶ /情報機器部/
じょうほうきじ /情報記事/
じょうほうきそ /情報基礎/
じょうほうきそかがく /情報基礎科学/
じょうほうきょういく /情報教育/
じょうほうきょうゆう /情報共有/
じょうほうきょく /情報局/
じょうほうぎじゅつ /情報技術/
じょうほうぎじゅつか /情報技術科/
じょうほうぎじゅつかいはつ /情報技術開発/
じょうほうぎじゅつぶんや /情報技術分野/
じょうほうぎょうれつ /情報行列/
じょうほうけい /情報系/
じょうほうけいがっか /情報系学科/
じょうほうけつらく /情報欠落/
じょうほうけん /情報研/
じょうほうけんきゅうしょ /情報研究所/
じょうほうけんきゅうじょ /情報研究所/
じょうほうけんさく /情報検索/
じょうほうげん /情報源/
じょうほうこう /情報工/
じょうほうこうかい /情報公開/
じょうほうこうかいほう /情報公開法/
じょうほうこうかん /情報交換/
じょうほうこうかんかい /情報交換会/
じょうほうこうかんよう /情報交換用/
じょうほうこうがく /情報工学/
じょうほうこうがくか /情報工学科/
じょうほうこうがくかてい /情報工学課程/
じょうほうこうがくきょうしつ /情報工学教室/
じょうほうこうがくけい /情報工学系/
じょうほうこうがくけんきゅうか /情報工学研究科/
じょうほうこうがくじっけん /情報工学実験/
じょうほうこうがくぶ /情報工学部/
じょうほうこうがくぶんや /情報工学分野/
じょうほうこうがっか /情報工学科/
じょうほうこうぞう /情報構造/
じょうほうさいぜんせん /情報最前線/
じょうほうさんぎょう /情報産業/
じょうほうさんぎょうろん /情報産業論/
じょうほうざっし /情報雑誌/
じょうほうし /情報誌;magazine/情報紙;paper/
じょうほうしげん /情報資源/
じょうほうしつ /情報室/
じょうほうしゃかい /情報社会/
じょうほうしゃかいがく /情報社会学/
じょうほうしゃだん /情報遮断/
じょうほうしゅうしゅう /情報収集/
じょうほうしゅうしゅうかつどう /情報収集活動/
じょうほうしゅうせい /上方修正/
じょうほうしょう /情報相/情報省/
じょうほうしょり /情報処理/
じょうほうしょりえんしゅう /情報処理演習/
じょうほうしょりか /情報処理科/
じょうほうしょりかてい /情報処理過程/
じょうほうしょりかんけい /情報処理関係/
じょうほうしょりがいろん /情報処理概論/
じょうほうしょりがく /情報処理学/
じょうほうしょりがっかい /情報処理学会/
じょうほうしょりきかい /情報処理機械/
じょうほうしょりきき /情報処理機器/
じょうほうしょりきこう /情報処理機構/
じょうほうしょりきのう /情報処理機能/
じょうほうしょりきょういく /情報処理教育/
じょうほうしょりぎじゅつしゃ /情報処理技術者;-試験,第2種-/
じょうほうしょりけんきゅう /情報処理研究/
じょうほうしょりこうざ /情報処理講座/
じょうほうしょりさぎょう /情報処理作業/
じょうほうしょりしけん /情報処理試験/
じょうほうしょりのうりょく /情報処理能力/
じょうほうしょりぶんや /情報処理分野/
じょうほうしょりほう /情報処理法/
じょうほうしょりようご /情報処理用語/
じょうほうしりょう /情報資料/
じょうほうじ /浄法寺/
じょうほうじっけんしつ /情報実験室/
じょうほうじゃくしゃ /情報弱者/
じょうほうすうがく /情報数学/
じょうほうすうり /情報数理/
じょうほうすうりがっか /情報数理学科/
じょうほうすじ /情報筋/
じょうほうせいさんしゃ /情報生産者/
じょうほうせん /情報戦/
じょうほうせんこう /情報専攻/
じょうほうせんしんこく /情報先進国/
じょうほうせんたー /情報センター/
じょうほうせんりゃく /情報戦略/
じょうほうそうさ /情報操作/
じょうほうたんさく /情報探索/
じょうほうたんまつ /情報端末/
じょうほうだい /情報大/情報第/
じょうほうだいがく /情報大学/
じょうほうちかん /上方置換;水に溶けやすく空気より軽い気体の収集法/
じょうほうちくせき /情報蓄積/
じょうほうちしき /情報知識/
じょうほうちしきがっかい /情報知識学会/
じょうほうちず /情報地図/
じょうほうちゅうしゅつ /情報抽出/
じょうほうつう /情報通/
じょうほうつうしん /情報通信/
じょうほうつうしんかがく /情報通信科学/
じょうほうつうしんきき /情報通信機器/
じょうほうつうしんけんきゅう /情報通信研究/
じょうほうつうしんぶ /情報通信部/
じょうほうていきょう /情報提供/
じょうほうていきょうがいしゃ /情報提供会社/
じょうほうていきょうけいたい /情報提供形態/
じょうほうていきょうしせつ /情報提供施設/
じょうほうていきょうしゃ /情報提供者/
じょうほうていきょうよう /情報提供用/
じょうほうてき /情報的/乗法的/
じょうほうてんそう /情報転送/
じょうほうでんたつ /情報伝達/
じょうほうでんたつがく /情報伝達学/
じょうほうでんたつのうりょく /情報伝達能力/
じょうほうとう /情報棟/
じょうほうとうごう /情報統合/
じょうほうとうせい /情報統制/
じょうほうどうし /情報同士/
じょうほうないよう /情報内容/
じょうほうなど /情報等/
じょうほうにゅうしゅ /情報入手/
じょうほうはいふ /情報配布/
じょうほうはっしん /情報発信/
じょうほうはっしんげん /情報発信源/
じょうほうばいたい /情報媒体/
じょうほうばん /情報板/
じょうほうばんぐみ /情報番組/
じょうほうひょうげん /情報表現/
じょうほうひょうじ /情報表示/
じょうほうぶ /情報部/
じょうほうぶいん /情報部員/
じょうほうぶそく /情報不足/
じょうほうぶつりがく /情報物理学/
じょうほうぶんや /情報分野/
じょうほうぶんるい /情報分類/
じょうほうへんかん /情報変換/
じょうほうほんぶ /情報本部/
じょうほうめでぃあ /情報メディア/
じょうほうもう /情報網/
じょうほうもと /情報元/
じょうほうや /情報屋/
じょうほうようりょう /情報容量/
じょうほうりがく /情報理学/
じょうほうりこうがく /情報理工学/
じょうほうりゅうつう /情報流通/
じょうほうりょう /情報量;information content/情報料;information fee/
じょうほうりょうきん /情報料金/
じょうほうりょく /情報力/
じょうほうりろん /情報理論/
じょうほうろうえい /情報漏洩/
じょうほうろん /情報論/
じょうほうろんり /情報論理/
じょうほうろんりがく /情報論理学/
じょうほく /城北/常北/
じょうほくせん /城北線/
じょうぼう /上房/
じょうぼく /上木;publish/縄墨;-を改廃せず/
じょうぼん /常凡/
じょうぼんれんだいじ /上品蓮台寺/
じょうまい /上米/
じょうまえ /錠前/
じょうまん /冗漫/
じょうみ /情味/
じょうみの /上ミノ/
じょうみゃく /静脈/
じょうみゃくけつ /静脈血/
じょうみゃくさんぎょう /静脈産業/
じょうみゃくちゅうしゃ /静脈注射/
じょうみゃくべん /静脈弁;venous valve/
じょうみゃくりゅう /静脈瘤/
じょうみょう /定命/
じょうみん /常民/
じょうむ /常務;-取締役/乗務;-員/
じょうむいん /乗務員/
じょうむいんくみあい /乗務員組合/
じょうむいんしつ /乗務員室/
じょうむいんよう /乗務員用/
じょうむしつ /常務室/
じょうむとりしまりやく /常務取締役/
じょうむりじ /常務理事/
じょうめん /上面/尉面;老翁の能面の総称/
じょうめんぞう /上面像/
じょうめんはっこう /上面醗酵/
じょうもう /上毛/
じょうもうでんてつ /上毛電鉄/
じょうもく /条目/
じょうもの /上物/
じょうもん /縄文/城門/定紋/
じょうもんいぜん /縄文以前/
じょうもんこうき /縄文後期/
じょうもんご /縄文語/
じょうもんしきどき /縄文式土器/
じょうもんじだい /縄文時代/
じょうもんじだいぜんき /縄文時代前期/
じょうもんじん /縄文人/
じょうもんすぎ /縄文杉/
じょうもんぜんき /縄文前期/
じょうもんどき /縄文土器/
じょうもんぶんか /縄文文化/
じょうもんまえ /縄文前/
じょうや /常夜/長夜;無明-/
じょうやく /条約/定役/
じょうやくいはん /条約違反/
じょうやくかいせい /条約改正/
じょうやくかめいこく /条約加盟国/
じょうやくていけつ /条約締結/
じょうやくは /条約派/
じょうやとい /常雇い/
じょうやとう /常夜灯/常夜燈/
じょうやど /定宿/常宿/
じょうゆ /醤油/上諭/
じょうゆいしきろん /成唯識論/
じょうゆう /城邑/
じょうよ /剰余/譲与/丈余/剩餘;旧字/
じょうよう /常用/乗用/城陽/常陽/上陽/
じょうようかんじ /常用漢字/
じょうようかんじひょう /常用漢字表/
じょうようぎんこう /常陽銀行/
じょうようしゃ /乗用車/常用者/
じょうようしゃよう /乗用車用/
じょうようじ /常用字/
じょうようたいすう /常用対数/
じょうよかち /剰余価値/
じょうよきん /剰余金/
じょうよきんしょぶんあん /剰余金処分案;財務諸表の1つ/
じょうよく /情欲/情慾;別字/
じょうよけい /剰余系/
じょうよるい /剰余類/
じょうよろうどう /剰余労働;[経済]Mehrarbeit/
じょうらく /上洛/常楽/
じょうらくかい /情洛会/
じょうらん /上欄;column above/擾乱/上覧/
じょうらんずもう /上覧相撲/
じょうり /条理;reason/条里;区画/情理/常理/杖履/
じょうりく /上陸/
じょうりくさくせん /上陸作戦/
じょうりせい /条里制/
じょうりつ /乗率/
じょうりゃく /上略/
じょうりゅう /上流/蒸留/蒸溜/
じょうりゅうかいきゅう /上流階級/
じょうりゅうき /蒸留器/
じょうりゅうきぞく /上流貴族/
じょうりゅうさいと /上流サイト/
じょうりゅうしゃかい /上流社会/
じょうりゅうしゅ /蒸留酒/
じょうりゅうじょ /蒸留所/
じょうりゅうすい /蒸留水/
じょうりゅうふじん /上流夫人/
じょうりゅうほうめん /上流方面/
じょうりょう /丈量/
じょうりょく /常緑/
じょうりょくこうぼく /常緑高木/
じょうりょくこうようじゅりん /常緑広葉樹林/
じょうりょくしんようじゅ /常緑針葉樹/
じょうりょくじゅ /常緑樹/
じょうりょくていぼく /常緑低木/
じょうるり /浄瑠璃/
じょうるりひめものがたり /浄瑠璃姫物語/
じょうるりぼん /浄瑠璃本/
じょうれい /条例;†自治体の法/条令;†箇条書きの法令/常例/上例/浄霊/
じょうれいあん /条例案/
じょうれいしゅう /条例集/
じょうれいじゅつ /浄霊術/
じょうれん /常連/定連;≒常連/
じょうれんきゃく /常連客/
じょうれんさん /常連さん/
じょうれんたち /常連達/
じょうれんとうこうしゃ /常連投稿者/
じょうろ /如雨露/如露;=如雨露/女郎/
じょうろう /城楼/上臈/上臘;「臈」異体字/
じょうろきょう /上路橋/
じょうろく /丈六/
じょうろん /諍論/
じょうわ /情話/貞和;年号(1345-1350)/
じょうわん /上腕/
じょうわんこつ /上腕骨/
じょうわんさんとうきん /上腕三頭筋/
じょうわんにとうきん /上腕二頭筋/
じょうわんぶ /上腕部/
じょえん /助演/
じょえんじょゆう /助演女優/
じょえんじょゆうしょう /助演女優賞/
じょえんだんゆう /助演男優/
じょえんだんゆうしょう /助演男優賞/
じょおう /女王/
じょおうあり /女王蟻/
じょおうごう /女王号/
じょおうさま /女王様/
じょおうばち /女王蜂/
じょおうへいか /女王陛下/
じょおん /助音/
じょか /序歌/
じょかい /叙階/
じょかく /除核/
じょかん /女官/
じょかんとく /助監督/
じょがい /除外/
じょがいきてい /除外規定/
じょがいば /除外馬/
じょがく /女楽/
じょがくいん /女学院/
じょがくえん /女学園/
じょがくせい /女学生/
じょがっかん /女学館/
じょがっこう /女学校/女學校;「学」旧字/
じょきゃく /除却/
じょきゅう /女給/
じょきょ /除去/
じょきょう /助教/
じょきょうじゅ /助教授/
じょきょうじゅしつ /助教授室/
じょきょきそく /除去規則/
じょきょく /序曲/
じょきょざい /除去剤/除去材/
じょきょのうりょく /除去能力/
じょきょほう /除去法/
じょきん /除菌/助勤/
じょく /辱;侮辱/溽;溽暑/縟;縟礼/蓐;蓐瘡/褥;産褥/
じょくしょ /溽暑/
じょくせ /濁世/
じょくそう /褥瘡;[医]bedsore. 床擦れ/蓐瘡;=褥瘡/辱創;?/
じょくち /辱知/
じょくふ /褥婦/
じょくれい /縟礼/
じょくん /叙勲/
じょけい /女系/叙景/
じょけいてき /叙景的/
じょけつ /女傑/
じょけん /女権/
じょけんはんけつ /除権判決/
じょげん /助言/序言/
じょげんしゃ /助言者/
じょこう /徐行/女工/女皇/除光;-液/
じょこうあいし /女工哀史;細井和喜蔵/
じょこううんてん /徐行運転/
じょこうえき /除光液;マニキュア落とし/
じょこうじ /徐行時/
じょこつ /鋤骨;[解剖](鼻の)vomer/
じょご /助語/
じょごう /除号/
じょさい /助祭/如才/
じょさいぼう /助細胞/
じょさん /除算;じょさん/
じょさんき /除算器/
じょさんし /助産師;保健婦助産婦看護婦法一部改正による呼称変更/
じょさんぷ /助産婦/
じょざい /助剤/助材/
じょざん /除算/
じょざんかいろ /除算回路/
じょざんき /除算器/
じょし /女子/女史/助詞/序詞/序詩/
じょし> /女子;-プロ,-テニス,-生徒/
じょしい /女子医/
じょしえいようだいがく /女子栄養大学;www.eiyo.ac.jp/
じょしがくいん /女子学院/
じょしがくえん /女子学園/
じょしがくせい /女子学生/
じょしき /女色/
じょしきょうえい /女子競泳/
じょしけいむしょ /女子刑務所/
じょしこう /女子校/女子高/
じょしこうこう /女子高校/
じょしこうこうせい /女子高校生/
じょしこうせい /女子高生/
じょしさべつてっぱいじょうやく /女子差別撤廃条約/
じょししゃいん /女子社員/
じょししょうぎょう /女子商業/
じょしじゅんけっしょう /女子準決勝/
じょしせいがくいん /女子聖学院/
じょしせいと /女子生徒/
じょしせんしゅ /女子選手/
じょしたいそう /女子体操/
じょしたんだい /女子短大/
じょしだい /女子大/
じょしだいがく /女子大学/
じょしだいせい /女子大生/
じょしだいせいやく /女子大生役/
じょしちゅうがくせい /女子中学生/
じょしちゅうせい /女子中生/
じょしつ /除湿/
じょしつき /除湿機/
じょしつきのう /除湿機能/
じょしてんいん /女子店員/
じょしといれ /女子トイレ/
じょしはつ /女子初/
じょしび /女子美/
じょしびじゅつだいがく /女子美術大学/
じょしぶ /女子部/
じょしぶいん /女子部員/
じょしぷろ /女子プロ/
じょしべん /女子便;女子便所のこと/
じょしべんじょ /女子便所/
じょしめい /女子名/
じょしゃく /叙爵/
じょしやきゅうぶ /女子野球部/
じょしゅ /助手/
じょしゅう /女囚/徐州/除臭/
じょしゅかい /助手会/
じょしゅしつ /助手室/
じょしゅせき /助手席/
じょしゅせきがわ /助手席側/
じょしゅせきよう /助手席用/
じょしょう /序章/女将/
じょしょく /女色/
じょしょくばい /助触媒;[化学]co-catalyst/
じょしよう /女子用/
じょしりょう /女子寮/
じょしん /女真/女神/
じょしんもじ /女真文字/
じょじ /女児/叙事/助字/助辞/序次/
じょじし /叙事詩/
じょじしてき /叙事詩的/
じょじゅつ /叙述/
じょじょ /徐々/序々;?/
じょじょう /叙情/抒情;=叙情/如上/
じょじょうし /抒情詩/叙情詩/
じょじょうてき /叙情的/
じょじょうふ /女丈夫/
じょじょに /徐々に/
じょじよう /女児用/
じょすい /如水/除水/
じょすう /序数;⇔基数/除数;divisor/助数/
じょすうし /助数詞;numerative/序数詞;⇔基数詞/
じょせい /女性/助成/女声;female voice/女婿/助勢/
じょせいあて /女性宛/
じょせいいっぱん /女性一般/
じょせいうんてんし /女性運転士/
じょせいか /女性化/
じょせいかしゅ /女性歌手/
じょせいかん /女性観/
じょせいかんけい /女性関係/
じょせいがく /助成額/女性学;women's study/
じょせいがた /女性型/女性方/
じょせいがっしょう /女声合唱/
じょせいがっしょうだん /女声合唱団/
じょせいがわ /女性側/
じょせいき /女性器/
じょせいきゃく /女性客/
じょせいきょうし /女性教師/
じょせいきょうふしょう /女性恐怖症/
じょせいきょうゆ /女性教諭/
じょせいきん /助成金/
じょせいきんがく /助成金額/
じょせいぎいん /女性議員/
じょせいぐん /女性軍/
じょせいけい /女性形/女性系/
じょせいこうほ /女性候補/
じょせいこようしゃ /女性雇用者/
じょせいご /女性語/
じょせいさっか /女性作家/
じょせいさべつ /女性差別/
じょせいさべつてっぱいじょうやく /女性差別撤廃条約/
じょせいさんかしゃ /女性参加者/
じょせいざっし /女性雑誌/
じょせいし /女性誌/女性史/
じょせいしかん /女性士官/
じょせいしゃいん /女性社員/
じょせいしゃしょう /女性車掌/
じょせいしゅうかんし /女性週刊誌/
じょせいしゅしょう /女性首相/
じょせいしんり /女性心理/
じょせいしんりがく /女性心理学/
じょせいじしん /女性自身/
じょせいじょうい /女性上位/
じょせいじょういじだい /女性上位時代/
じょせいじん /女性陣/
じょせいせい /女性性/
じょせいせんしゅ /女性選手/
じょせいせんよう /女性専用/
じょせいせんようしゃ /女性専用車/
じょせいせんようしゃりょう /女性専用車両/
じょせいせんようれっしゃ /女性専用列車/
じょせいそう /女性層/
じょせいぞう /女性像/
じょせいたち /女性達/
じょせいたんどく /女性単独/
じょせいだいかんげい /女性大歓迎/
じょせいてき /女性的/
じょせいと /女生徒/
じょせいとたち /女生徒達/
じょせいどうし /女性同士/
じょせいひ /助成費/
じょせいひとり /女性一人/
じょせいひょう /女性票/
じょせいび /女性美/
じょせいふたり /女性二人/
じょせいぶ /女性部/
じょせいへんれき /女性遍歴/
じょせいべっし /女性蔑視/
じょせいほるもん /女性ホルモン/
じょせいむけ /女性向け/
じょせいめい /女性名/
じょせいめいし /女性名詞/
じょせいもんだい /女性問題/
じょせいゆうい /女性優位/
じょせいゆうせん /女性優先/
じょせいよう /女性用/
じょせいより /女性寄り/
じょせいりじ /女性理事/
じょせいりょうきん /女性料金/
じょせいれき /女性歴/
じょせいろうどうしゃ /女性労働者/
じょせき /除籍/除斥/
じょせききかん /除斥期間/
じょせつ /除雪/序説/叙説/絮説/
じょせつき /除雪機/
じょせつしゃ /除雪車/
じょせん /女専;[略語]女子専門学校/
じょそう /女装/除草/助走;run-up/序奏;intro/助奏;[音楽]obbligato/除装;disarm/
じょそうざい /除草剤/
じょそうぶ /序奏部/
じょそんだんぴ /女尊男卑/
じょたい /除隊/女体/所帯/
じょたんぱく /除蛋白/
じょちゅう /女中/除虫;debug/
じょちゅうぎく /除虫菊/
じょちゅうべや /女中部屋/
じょちょう /助長/
じょつう /除痛/
じょてい /女帝/
じょてんいん /女店員/
じょどう /女童/
じょどうし /助動詞/
じょなん /女難/
じょにだん /序二段/
じょにん /叙任/
じょのくち /序の口/序ノ口/
じょはきゅう /序破急/
じょばす /女バス/
じょばん /序盤/序番/
じょばんせん /序盤戦/
じょひ /女卑/
じょひょう /除票/除表/
じょぶん /序文/
じょへん /徐変/
じょへんすう /助変数;[数学]parameter. パラメータ/
じょほう /除法;÷/叙法;[言語]mode/
じょまく /除幕;unveil/序幕;prologue/
じょまくしき /除幕式/
じょみゃく /徐脈/
じょめい /除名/助命/
じょめいしょぶん /除名処分/
じょめいてんのう /舒明天皇/
じょもう /除毛/
じょもうざい /除毛剤/
じょや /除夜/
じょやく /助役/
じょやなべ /除夜鍋/
じょやのかね /除夜の鐘/
じょゆう /女優/
じょゆうしょう /女優賞/
じょゆうやく /女優役/
じょりゅう /女流/
じょりゅうきし /女流棋士/
じょりゅうさっか /女流作家/
じょりゅうぶんがく /女流文学/
じょりゅうめいじん /女流名人/
じょりょく /助力/
じょれい /除霊/
じょれいし /除霊師/
じょれつ /序列/
じょろう /女郎/
じょろうぐも /女郎蜘蛛/
じょろうや /女郎屋/
じょろん /序論/
じょんがらぶし /じょんがら節;[民謡]津軽-/
じよ /自余;その他/爾余;=自余/時余;一時間ちょっと/
じよう /滋養/自用/次葉/自養/
じようきょうそう /滋養強壮/
じらい /地雷/爾来/
じらいげん /地雷原/
じらいしょり /地雷処理/
じらいじょきょ /地雷除去/
じらいや /児雷也/
じり /事理/自利/尻/
じりき /自力/地力/
じりきかいけつ /自力解決/
じりきかいはつ /自力開発/
じりきこうかん /自力交換/
じりきこうこう /自力航行/
じりきしゅう /自力宗/
じりきそうこうふのう /自力走行不能/
じりきゆうしょう /自力優勝/
じりだか /じり高/ジリ高;[相場]/
じりつ /自立;independence/自律;autonomy/而立;30歳/侍立;そばに控えて立つ/持律;[仏教]戒律を守る/
じりつくんれん /自律訓練/
じりつくんれんほう /自律訓練法;[精医]autogenic training/
じりつご /自立語/
じりつしき /自立式/
じりつしん /自立心;independence/自律心/
じりつしんけい /自律神経/
じりつしんけいけい /自律神経系/
じりつしんけいしっちょうしょう /自律神経失調症/
じりつせい /自立性;independence/自律性;autonomy/
じりつてき /自律的/
じりつぶんさん /自律分散/
じりつぶんさんせいぎょ /自律分散制御/
じりひん /ジリ貧/じり貧/
じりゃく /治暦;年号(1065-1069)/
じりやす /じり安/ジリ安;[相場]/
じりゅう /時流/自流/
じりゅうち /自留地/
じりょう /寺領/
じりょく /磁力/恃力/
じりょくかいそう /自力回送/
じりょくきゅうさい /自力救済/
じりょくけい /磁力計/
じりょくせん /磁力線/
じりん /辞林/字林/
じる /汁/
じるい /字類/
じるいしょう /字類抄;平安時代の国語辞典/
じるこにうむ /Zirconium/Zr/
じるし /印/
じれい /事例/辞令/自励/辞礼;?/
じれいしき /自励式/
じれいしゅう /事例集/
じれいしょうかい /事例紹介/
じれいすう /事例数/
じれいてき /事例的/
じれいはっしん /自励発振/
じれいほうこく /事例報告/
じれき /事歴/
じれつ /字列/
じれん /自連/
じろ /字路/
じろう /痔瘻/耳漏/次郎/二郎/治郎/二朗/次朗/治朗/子郎/
じろうかじゃ /次郎冠者/
じろうものがたり /次郎物語/
じろちょう /次郎長/
じろん /持論/時論;時代の世論/
じろんどは /ジロンド派;[世界史]Girondins/
じわり /地割/地割り/
じわれ /地割れ/
じん /人/陣/仁/腎/神;(連濁)/迅;迅速/訊;尋問/尋;尋問/潯/蕁;蕁麻疹/燼;灰燼/盡;「尽」の旧字(人名用漢字)/贐;はなむけ/儘;まま/侭;「儘」の異体字/尽;尽力/壬;みずのえ/恁/荏;荏原/刃;凶刃/刄;「刃」の異体字/靭;靭帯/仞/仭;「仞」の異体字/靱;強靭/甚;甚大/糂;糂汰/塵;粉塵/臣;大臣/進;(連濁)精進/稔;(漢音)/
じんあい /仁愛/塵埃/
じんい /人為/人意/
じんいさいがい /人為災害/
じんいしょく /腎移植/
じんいせんたく /人為選択/
じんいち /仁一/塵一/
じんいてき /人為的/
じんいん /人員/
じんいんさくげん /人員削減/
じんいんせいり /人員整理/
じんいんぶそく /人員不足/
じんいんぼしゅう /人員募集/
じんう /腎盂/
じんうえん /腎盂炎/
じんえい /陣営/
じんえん /腎炎/人煙/
じんか /人家/
じんかい /塵芥/人界/人海;「-戦術」/塵界;俗世間/燼灰;「-に帰す」/
じんかいせんじゅつ /人海戦術/
じんかいは /塵芥破/
じんかく /人格/
じんかくか /人格化/
じんかくかいぞう /人格改造/
じんかくきょういく /人格教育/
じんかくけいせい /人格形成/
じんかくけいせいき /人格形成期/
じんかくけいせいじょう /人格形成上/
じんかくけん /人格権/
じんかくこうげき /人格攻撃/
じんかくしゃ /人格者/
じんかくしょうがい /人格障害;[精医]personality disorder(PD)/
じんかくしん /人格神;[宗教]personal God/
じんかくてき /人格的/
じんかくてきりえき /人格的利益/
じんかくむし /人格無視/
じんかん /人間;世の中/人勧;[略語]人事院勧告. 「-制度」/人感;-センサ/腎管;[解剖]nephric tubule/
じんがい /人外/塵外/
じんがいきょう /人外境/
じんがいまきょう /人外魔境/
じんがさ /陣笠/
じんき /神亀;年号(724-729)/
じんきのう /腎機能/
じんきのうしょうがい /腎機能障害/
じんきょ /腎虚/人居/
じんきょう /人境/
じんぎ /仁義/神器/神祇;天神と地祇/人技/
じんぎかん /神祇官/
じんぎすかん /成吉思汗;大帝国の基礎を築いたモンゴルの指導者/
じんく /甚句/神供/
じんくん /人君/
じんぐう /神宮/神功/神供/
じんぐうきゅうじょう /神宮球場/
じんぐうこうごう /神功皇后/
じんぐうしちょう /神宮司庁/
じんぐうじ /神宮寺/
じんぐうまえ /神宮前/
じんけい /陣形/仁恵/仁兄/
じんけっせき /腎結石/
じんけつ /人傑/
じんけん /人権/人件/人絹/
じんけんいいんかい /人権委員会/
じんけんいしき /人権意識/
じんけんかいぎ /人権会議/
じんけんかんかく /人権感覚/
じんけんがいこう /人権外交;human-rights diplomacy/
じんけんききん /人権基金/
じんけんきやく /人権規約/
じんけんきゅうさい /人権救済/
じんけんきょういく /人権教育/
じんけんしそう /人権思想/
じんけんしんがい /人権侵害/
じんけんしんぱん /人権侵犯/
じんけんじゅうりん /人権蹂躙/
じんけんじょう /人権上/
じんけんせんげん /人権宣言/
じんけんせんしんこく /人権先進国/
じんけんそんちょう /人権尊重/
じんけんだんたい /人権団体/
じんけんひ /人件費/
じんけんほご /人権保護/
じんけんもんだい /人権問題/
じんけんようご /人権擁護/
じんけんよくあつ /人権抑圧/
じんげん /人言/
じんこ /仁子/神庫/
じんこう /人口;†population.「-20万人」/人工;†artificial.「-衛星」/沈香/人皇/樒;(植物名として)=沈香/櫁;「樒」の異体字/塵垢/
じんこう> /人工;(artificial) -栄養,雪,授粉/
じんこううみ /人工海/
じんこうえいせい /人工衛星/
じんこうえいよう /人工栄養;artificial feeding. 点滴,粉ミルクetc/
じんこうえさ /人工餌/
じんこうおんせい /人工音声/
じんこうか /人工化/
じんこうかいすい /人工海水/
じんこうかみつ /人口過密/
じんこうかん /人工感/
じんこうかんじょう /人工感情/
じんこうかんみりょう /人工甘味料/
じんこうき /塵劫記/塵功記;?/
じんこうけい /人工系/
じんこうけつえき /人工血液/
じんこうげんご /人工言語/
じんこうげんしょう /人口減少/
じんこうげんじつ /人工現実/
じんこうげんじつかん /人工現実感/
じんこうこ /人工湖/
じんこうこうう /人工降雨/
じんこうこうせい /人口構成/
じんこうこうせつ /人工降雪/
じんこうこうせつき /人工降雪機/
じんこうこうぞう /人口構造/
じんこうこうもん /人工肛門/
じんこうこきゅう /人工呼吸/
じんこうこきゅうき /人工呼吸器/
じんこうこつ /人工骨/
じんこうしこん /人工歯根/
じんこうしば /人工芝/
じんこうしんけい /人工神経/
じんこうしんけいかいろもう /人工神経回路網/
じんこうしんぞう /人工心臓/
じんこうしんぱい /人工心肺/
じんこうじ /人工耳/
じんこうじしん /人工地震/
じんこうじばん /人工地盤;artificial ground/
じんこうじゅうりょく /人工重力/
じんこうじゅせい /人工授精/人工受精/
じんこうじんぞう /人工腎臓;[医]artificial kidney/
じんこうすう /人口数/
じんこうすな /人工砂/
じんこうずのう /人工頭脳/
じんこうせいめい /人工生命/
じんこうせいめいけんきゅう /人工生命研究/
じんこうせいめいたい /人工生命体/
じんこうぞう /人口増/
じんこうぞうか /人口増加/
じんこうぞうかりつ /人口増加率/
じんこうぞうき /人工臓器/
じんこうぞうきかいはつ /人工臓器開発/
じんこうたつまき /人工竜巻/
じんこうちせい /人工知性/
じんこうちのう /人工知能/
じんこうちのうがっかい /人工知能学会/
じんこうちのうぎじゅつ /人工知能技術/
じんこうちのうけんきゅう /人工知能研究/
じんこうちのうけんきゅうしつ /人工知能研究室/
じんこうちゅうぜつ /人工中絶/
じんこうちょうさ /人口調査/
じんこうちょうせつ /人口調節/
じんこうてき /人工的/
じんこうとう /人工島/
じんこうとうけい /人口統計/
じんこうとうせき /人工透析/
じんこうとうせきりょうほう /人工透析療法/
じんこうどうたい /人口動態/
じんこうにゅう /人工乳/
じんこうにんしんちゅうぜつ /人工妊娠中絶/
じんこうばくはつ /人口爆発/
じんこうひ /人口比/
じんこうふか /人工孵化;artificial hatching/
じんこうぶつ /人工物/
じんこうぶつこうがく /人工物工学/
じんこうぶんぷ /人口分布/
じんこうへき /人工壁/
じんこうほうそく /人口法則/
じんこうみっしゅうちいき /人口密集地域/
じんこうみつど /人口密度/
じんこうむのう /人工無能/人工無脳/
じんこうもんだい /人口問題/
じんこうゆき /人工雪/
じんこうよくせい /人口抑制/
じんこうよくせいさく /人口抑制策/
じんこうりん /人工林/
じんこうろん /人口論/
じんこうわくせい /人工惑星/
じんこつ /人骨/
じんご /人語/人後/
じんごうき /塵劫記/
じんごけいうん /神護景雲;年号(767-770)/
じんごじ /神護寺/
じんごろう /甚五郎/
じんさい /人災/
じんざい /人材/人財;(造語)/
じんざいいくせい /人材育成/
じんざいかいはつぶ /人材開発部/
じんざいぎんこう /人材銀行/
じんざいけいせい /人材形成/
じんざいなん /人材難/
じんざいはいち /人材配置/
じんざいはけん /人材派遣/
じんざいはけんぎょう /人材派遣業/
じんざいぼしゅう /人材募集/
じんざいめん /人材面/
じんざいようせい /人材養成/
じんざぶろう /甚三郎/
じんし /人士/尋思/
じんしっかんかんじゃ /腎疾患患者/
じんしゅ /人種/
じんしゅかくり /人種隔離/
じんしゅかくりせいさく /人種隔離政策/
じんしゅかん /人種間/
じんしゅがく /人種学/
じんしゅこくせき /人種国籍/
じんしゅさ /人種差/
じんしゅさべつ /人種差別/
じんしゅさべつてき /人種差別的/
じんしゅさべつてっぱいじょうやく /人種差別撤廃条約/
じんしゅさべつもんだい /人種差別問題/
じんしゅしゅぎ /人種主義/
じんしゅてき /人種的/
じんしゅてきへんけん /人種的偏見/
じんしゅもんだい /人種問題/
じんしょ /陣所/
じんしょう /腎症/人証/
じんしん /人身;†person.「-売買」「-攻撃」/人心;†people's mind.「-の掌握」/壬申/人臣/
じんしんくぎ /人身供犠/
じんしんこうげき /人身攻撃/
じんしんじこ /人身事故/
じんしんのじゆう /人身の自由;憲法31条/
じんしんばいばい /人身売買/
じんしんほごほう /人身保護法/
じんじ /人事/神事/仁慈/
じんじいいんかい /人事委員会/
じんじいどう /人事異動/
じんじいん /人事院/
じんじいんかんこく /人事院勧告/
じんじいんきそく /人事院規則/
じんじか /人事課/
じんじかん /人事官;人事院の認証官(3名)/
じんじがかり /人事掛/
じんじきょういくぶ /人事教育部/
じんじけん /人事権/
じんじこうか /人事考課/
じんじこうりゅう /人事交流/
じんじせいど /人事制度/
じんじそうむ /人事総務/
じんじそしょう /人事訴訟;婚姻、養子縁組、親子関係などに関する民事訴訟/
じんじたんとう /人事担当/
じんじたんとうしゃ /人事担当者/
じんじつ /尽日/人日/
じんじはいち /人事配置/
じんじふせい /人事不省;意識不明/
じんじぶ /人事部/
じんじぶちょう /人事部長/
じんじぶもん /人事部門/
じんじもんだい /人事問題/
じんじゃ /神社/
じんじゃけんちく /神社建築/
じんじゃぶっかく /神社仏閣/
じんじゃほんちょう /神社本庁/
じんじゅ /人寿/仁寿;年号(851-854)/
じんじゅう /人獣/
じんじゅつ /仁術/
じんじょ /仁恕/
じんじょう /尋常/晨朝/
じんじょういちよう /尋常一様/
じんじょうこうとうしょうがっこう /尋常高等小学校/
じんじょうしょうがっこう /尋常小学校/
じんじょうちゅうがっこう /尋常中学校/
じんじん /仁人/
じんすい /尽瘁/腎水/
じんすけ /甚介/
じんずう /神通/
じんせい /人生/人性;『-論』(Hume)/人世;ひとのよ/人声;ひとごえ/仁政/靭性/
じんせいかん /人生観/
じんせいくん /人生訓/
じんせいけいけん /人生経験/
じんせいけいけんほうふ /人生経験豊富/
じんせいげきじょう /人生劇場/
じんせいこうろ /人生行路/
じんせいさいだい /人生最大/
じんせいせっけい /人生設計/
じんせいぜんぱん /人生全般/
じんせいそうだん /人生相談/
じんせいそうだんてき /人生相談的/
じんせいてき /人生的/
じんせいてつがく /人生哲学/
じんせいとうにょう /腎性糖尿/
じんせいもんだい /人生問題/
じんせいろん /人生論/
じんせき /人跡/神石/
じんせきみとう /人跡未踏/
じんせん /人選/仁川/仁山/
じんせんぬま /神仙沼/
じんぜん /人前/荏苒/
じんぜんけっこんしき /人前結婚式/
じんぜんしき /人前式/
じんぜんじ /秦泉寺/
じんそく /迅速/
じんそくか /迅速化/
じんそくしょり /迅速処理/
じんそくせい /迅速性/
じんぞう /腎臓/人造/
じんぞう> /人造;-大理石,-バター,-人間/
じんぞうえん /腎臓炎/
じんぞうけっせき /腎臓結石/
じんぞうこ /人造湖/
じんぞうだいりせき /人造大理石;imitation marble/
じんぞうとうせき /腎臓透析/
じんぞうにんげん /人造人間/
じんぞうびょう /腎臓病/
じんたい /人体/靭帯/靱帯;異体字/
じんたいかいぼう /人体解剖/
じんたいかいぼうず /人体解剖図/
じんたいじっけん /人体実験/
じんたいそんしょう /靭帯損傷/
じんたいもけい /人体模型/
じんたん /仁丹/
じんだい /甚大/神代/
じんだいこ /陣太鼓/
じんだいじ /深大寺/
じんだいめいし /人代名詞/
じんだいもじ /神代文字/
じんち /陣地/人知/人智/
じんちく /人畜/
じんちくむがい /人畜無害/
じんちけん /人知研/
じんちゅう /陣中/尽忠/人中/
じんちゅうほうこく /尽忠報国/
じんちゅうみまい /陣中見舞/
じんちょう /刃長/晨朝/
じんちょうげ /沈丁花/
じんつう /陣痛/
じんつうがわ /神通川/
じんつうそくしんざい /陣痛促進剤/
じんつうゆうはつざい /陣痛誘発剤/
じんつうりき /神通力/
じんてい /人定/
じんていしつもん /人定質問/
じんていじんもん /人定尋問/
じんてき /人的/
じんてきかしつ /人的過失/
じんてきこうりゅう /人的交流/
じんてきしげん /人的資源/
じんてきしほん /人的資本;human capital/
じんてきしょうこ /人的証拠/
じんてきとうし /人的投資/
じんてきようそ /人的要素/
じんてん /人天/
じんとう /人頭/陣頭/
じんとうしき /陣頭指揮/
じんとうせき /腎透析/
じんとうぜい /人頭税/
じんとく /人徳/仁徳/仁篤/
じんとり /陣取り/神取/陣取/
じんとりがっせん /陣取り合戦/
じんど /塵土/
じんどう /人道/仁道/
じんどうえんじょ /人道援助/
じんどうしえん /人道支援/
じんどうしゅぎ /人道主義;humanitarianism/
じんどうしゅぎしゃ /人道主義者/
じんどうてき /人道的/
じんどうてきけんち /人道的見地/
じんどうてきしえん /人道的支援/
じんどうもんだい /人道問題/
じんどくせい /腎毒性/
じんない /陣内/
じんなん /神南/
じんにく /人肉/
じんにくしょく /人肉食/
じんにゅう /人乳/
じんにょう /人尿;⇔人糞/
じんにん /神人/
じんのうしょうとうき /神皇正統記;北畠親房著/
じんはい /塵肺/
じんば /人馬/神馬/陣場/
じんばおり /陣羽織/
じんばきゅう /人馬宮;[十二宮]いて座(11.22-12.21)/
じんぱい /塵肺/じん肺/
じんぱち /甚八/
じんぴ /靭皮/人肥/深秘/じん皮/
じんぴん /人品/
じんぴんこつがら /人品骨柄/
じんふぜん /腎不全/
じんぶつ /人物/
じんぶつが /人物画/
じんぶつさつえい /人物撮影/
じんぶつしょうかい /人物紹介/
じんぶつぞう /人物像/
じんぶつでんき /人物伝記/
じんぶつはんてい /人物判定/
じんぶつひょう /人物評/
じんぶん /人文/
じんぶんかがく /人文科学/
じんぶんかがくけい /人文科学系/
じんぶんかがくてき /人文科学的/
じんぶんかがくぶ /人文科学部/
じんぶんがく /人文学/
じんぶんがくしゃ /人文学者/
じんぶんけい /人文系/
じんぶんけん /人文研/
じんぶんしゅぎ /人文主義/
じんぶんしょ /人文書/
じんぶんちり /人文地理/
じんぶんちりがく /人文地理学/
じんぷう /仁風/陣風/
じんぷく /尋腹/
じんぷん /人糞/
じんべい /甚平;甚兵衛/
じんべえ /甚兵衛/
じんぺい /仁平;年号(1151-1154)/甚平/
じんほけん /人保険/
じんぼ /神保/
じんぼあきら /神保彰/
じんぼう /人望/神保/
じんぼうちょう /神保町/
じんぼうちょうえき /神保町駅/
じんぼちょう /神保町/
じんぼつ /陣没/
じんぽ /神保/
じんぽんしゅぎ /人本主義/
じんまく /陣幕/
じんましん /蕁麻疹/
じんみゃく /人脈/
じんみん /人民/
じんみんかいほうぐん /人民解放軍/
じんみんきょうわこく /人民共和国/
じんみんぐん /人民軍/
じんみんけんしょう /人民憲章;People's Charter/
じんみんげん /人民元/
じんみんしゅぎ /人民主義/
じんみんだいかいどう /人民大会堂/
じんみんちゅうごく /人民中国/
じんみんとう /人民党/
じんみんにっぽう /人民日報/
じんみんふく /人民服;中国の-/
じんみんぶんがく /人民文学/
じんみんへい /人民幣/
じんむ /神武/
じんむけいき /神武景気/
じんむちょう /神武朝/
じんむてんのう /神武天皇/
じんむてんのうさい /神武天皇祭;4.3/
じんめい /人名;name/人命;life/神明/神名/
じんめいきゅうじょ /人命救助/
じんめいぐん /人名群/
じんめいじしょ /人名辞書/
じんめいじてん /人名辞典/
じんめいぼ /人名簿/
じんめいゆうせん /人命優先/
じんめいよう /人名用/
じんめいろく /人名録/
じんめん /人面/
じんめんいわ /人面岩/
じんめんじゅうしん /人面獣心/人面獣身;?/
じんめんそ /人面疽/
じんもう /人毛/
じんもん /尋問/訊問;=尋問/陣門/
じんや /陣屋/
じんよう /陣容/
じんよく /人欲;desir humain/
じんらい /迅雷/人籟/
じんりき /人力/尽力/
じんりきき /人力機/
じんりきしゃ /人力車/俥/
じんりきひこうき /人力飛行機/
じんりゅう /神竜/
じんりょく /尽力/人力/
じんりん /人倫/
じんるい /人類/
じんるいあい /人類愛/
じんるいがく /人類学/
じんるいがくてき /人類学的/
じんるいきょうつう /人類共通/
じんるいしじょう /人類史上/
じんるいしんかろん /人類進化論/
じんるいぜんたい /人類全体/
じんるいどうし /人類同士/
じんるいはっせい /人類発生/
じんるいはんえい /人類繁栄/
じんるいふへん /人類普遍/
じんるいめつぼう /人類滅亡/
じんれつ /陣列/
じんろう /人狼/塵労/
じんろく /甚六/
じんわ /人和/
す /素/巣;nest/酢/簾;すだれ/須;必須/醋;=酢/簀;むしろ。「簀の子」/鬆;大根に-が入る/栖;≒巣/子;(唐音)/州/洲;中洲/守;(慣用音)/主;(呉音)/笥;箪笥/諏;諏訪/数;(漢音)/籔;(呉音) やぶ/寿;「寿司」の一部?/壽;「寿」の旧字(人名用漢字)/過;動詞語幹?/棲;動詞語幹?/
すーあんこ /四暗刻;[麻雀]役満/
すーあんこー /四暗刻/
すーつすがた /スーツ姿/
すーぷざら /スープ皿/
すーぷに /スープ煮/
すーほんぱい /四風牌/
すあげ /素揚げ/
すあし /素足/
すあな /巣穴/
すあま /素甘/
すあらい /酢洗い;鰺を-する/
すい /粋/水/錐;三角錐/錘;つむ/垂/睡/炊;炊飯/吹;吹奏/酔;酔眼/膵;膵臓/翠;翡翠/翆;「翠」の異体字/悴;憔悴/忰;「悴」の異体字/瘁/萃/粹;「粋」の旧字(人名用漢字)/醉;「酔」の旧字(人名用漢字)/隹;とり/推;推薦/騅/誰;誰何/捶/陲/遂;遂行/邃;深邃/燧;ひうち/衰;衰退/榱;たるき/彗;彗星/綏/帥;元帥/出;出納帳/穂;ほ/埀;「垂」の旧字/酸い/
すいあげ /吸上げ/
すいあつ /水圧/
すいい /推移/水位/
すいいかくりつぎょうれつ /推移確率行列/
すいいき /水域/
すいいけい /水位計/推移系/
すいいじょうしょう /水位上昇/
すいいせい /推移性/
すいいそく /推移則/
すいいてき /推移的/
すいいひょう /推移表/
すいいりつ /推移律/
すいう /水宇/
すいうん /水運/水雲;流水行雲/衰運/
すいえい /水泳/
すいえいたいかい /水泳大会/
すいえいぶ /水泳部/
すいえいぶいん /水泳部員/
すいえいよう /水泳用/
すいえん /膵炎/水煙/垂涎;すいぜんの慣用読み/水鉛;molybdenum/炊煙/翠煙/
すいおん /水温/
すいおんけい /水温計/
すいおんちょうせつ /水温調節/
すいか /西瓜/水火/垂下/誰何/酔歌/翠霞;green mist/水瓜/水禍/水和;(唐音) hydration/
すいかい /水塊;water mass/水界/
すいかずら /忍冬/
すいかわり /スイカ割り/
すいかん /水管/水干/酔漢/吹管/
すいが /酔臥;酔って寝転ぶ/睡臥;横になって寝る/
すいがい /水害/
すいがら /吸殻/吸い殻/吸いがら/
すいがん /膵癌/酔眼/膵がん/水眼/
すいがんもうろう /酔眼朦朧/
すいき /水気/
すいきゃく /酔客/醉客;「酔」旧字/
すいきゅう /水球/推究/
すいきょ /推挙/
すいきょう /酔狂/粋狂/酔郷/
すいきん /水禽/水金/
すいきんくつ /水琴窟/
すいぎゅう /水牛/
すいぎょ /水魚/
すいぎょう /水行/
すいぎょうざ /水餃子/
すいぎょく /翠玉;emerald/水玉;crystal/
すいぎん /水銀/Hg/Mercury/
すいぎんかごうぶつ /水銀化合物/
すいぎんせいりゅうき /水銀整流器/
すいぎんちゅう /水銀柱/
すいぎんでんち /水銀電池/
すいぎんとう /水銀灯/
すいくち /吸い口/吸口/
すいくん /垂訓/
すいぐん /水軍/
すいぐんせん /水郡線/
すいけい /水系/推計/錐形/
すいけいがく /推計学/
すいけいでんせん /水系伝染/
すいけん /水圏/酔拳/推件/
すいげい /酔鯨/
すいげつ /水月/
すいげん /水源/酔言/
すいげんかいはつ /水源開発/
すいげんぜい /水源税/
すいげんち /水源地/
すいこ /推古/水滸/出挙;[律令制]稲等のローン。事実上の税金/
すいこう /遂行/推敲/水耕;[農業]hydroponics/水行/推考;guess/垂鉤;fishing/
すいこうさいばい /水耕栽培/
すいこうしゃ /水交社;†旧海軍のOB会。⇔偕行社/水光社;†[企業名]/
すいこうちゅう /遂行中/
すいこうねつひ /水光熱費/
すいこてんのう /推古天皇/
すいこでん /水滸伝/
すいこみ /吸い込み/
すいご /酔語/垂語/
すいごう /水郷/水濠/
すいごうちたい /水郷地帯/
すいさい /水彩/水災/水砕/
すいさいえのぐ /水彩絵の具;water/水彩絵具/
すいさいが /水彩画/
すいさいちょう /水彩調/
すいさつ /推察/
すいさん /水産/推算/炊爨/推参/水酸/推讃/
すいさんか /水酸化/
すいさんか> /水酸化/
すいさんかぶつ /水酸化物/
すいさんかぶついおん /水酸化物イオン;[化学]OH-/
すいさんき /水酸基;-OH/
すいさんぎょう /水産業/
すいさんけんきゅうしょ /水産研究所/
すいさんしげん /水産資源/
すいさんだい /水産大/
すいさんだいがっこう /水産大学校;農水省。www.fish-u.ac.jp/
すいさんちょう /水産庁/
すいさんぶつ /水産物/
すいざん /衰残/
すいし /水死/垂死;瀕死/
すいしたい /水死体/
すいしつ /水質/
すいしつあっか /水質悪化/
すいしつおせん /水質汚染/
すいしつおだく /水質汚濁/
すいしつおだくぼうしほう /水質汚濁防止法/
すいしつかいぜん /水質改善/
すいしつきじゅん /水質基準/
すいしつちょうさ /水質調査/
すいしゃ /水車/
すいしゃごや /水車小屋/
すいしゅ /水腫/
すいしょ /水書/粋書/
すいしょう /推奨;†recommend/水晶/推賞;†褒めて推す。「候補作を-する」/推称;†=推賞/水漿;飲み物/
すいしょうあん /推奨案/
すいしょうきじゅん /推奨基準/
すいしょうきゅう /水晶宮/
すいしょうこんしき /水晶婚式;15周年/
すいしょうしんどうし /水晶振動子/
すいしょうじこう /推奨事項/
すいしょうたい /水晶体/
すいしょうだま /水晶玉/
すいしょうち /推奨値/
すいしょうどう /水晶堂/
すいしょうはっしん /水晶発振/
すいしょうはっしんき /水晶発振器/
すいしょうはっしんし /水晶発振子/
すいしょうふく /推奨服/
すいしょく /水色/衰色/
すいしん /推進/水深/垂心/
すいしんい /推進委/
すいしんいいんかい /推進委員会/
すいしんうんてん /推進運転/
すいしんか /推進課/
すいしんかいぎ /推進会議/
すいしんがわ /推進側/
すいしんき /推進機/推進器/
すいしんきかん /推進機関/
すいしんきこう /推進機構/
すいしんきょうぎかい /推進協議会/
すいしんこうりつ /推進効率/
すいしんざい /推進剤/
すいしんしつ /推進室/
すいしんしゃ /推進者/
すいしんじぎょうぶ /推進事業部/
すいしんたいせい /推進体制/
すいしんだんたい /推進団体/
すいしんねんりょう /推進燃料/
すいしんは /推進派/
すいしんぶ /推進部/
すいしんほうさく /推進方策/
すいしんほんぶ /推進本部/
すいしんやく /推進役/
すいしんりょく /推進力/
すいじ /炊事/垂示/
すいじか /炊事可/
すいじば /炊事場/
すいじゃく /衰弱/垂迹/
すいじゅん /水準/
すいじゅんいじょう /水準以上/
すいじゅんかん /水循環/
すいじゅんかんじ /水準漢字/
すいじゅんき /水準器/
すいじゅんぎ /水準儀/
すいじゅんすう /水準数/
すいじゅんち /水準値/
すいじゅんはば /水準幅/
すいじょう /水上/穂状;ほじょう/錐状;きりじょう/
すいじょうかじょ /穂状花序/
すいじょうき /水蒸気/水上機/
すいじょうきあつ /水蒸気圧/
すいじょうきぶんあつ /水蒸気分圧/
すいじょうきょうぎ /水上競技;water sports/
すいじょうきりょう /水蒸気量/
すいじょうせいかつ /水上生活/
すいじょうせいかつしゃ /水上生活者/
すいじょうせんとう /水上戦闘/
すいじょうたい /錐状体;[生物]cone/
すいじょうちかん /水上置換;水に溶けにくい気体の収集法/
すいじょうは /水上葉/
すいじょうぶたい /水上部隊/
すいじよう /炊事用/
すいじん /水神/粋人/酔人;drunk/
すいじんしょう /水腎症;[医]/
すいす /瑞西;Suisse/
すいすせい /スイス製/
すいず /水津/
すいせい /水性;-ペン/彗星;comet/水星;Mercury/水生;-動植物/水棲;-動物/水勢;water force/水成;-岩/衰勢/水声;水音/
すいせいかく /彗星核/
すいせいがん /水成岩/
すいせいせいぶつ /水生生物/
すいせいぞう /彗星像/
すいせいとりょう /水性塗料/
すいせいどうぶつ /水棲動物/
すいせいぺん /水性ペン/
すいせいむし /酔生夢死/
すいせいろん /水成論/
すいせき /水石/燧石;火打ち石/
すいせん /推薦/水仙;narcissus/水洗;†flush.「-便所」/水栓;†faucet.「混合-」/垂線/
すいせんいいん /推薦委員/
すいせんかなぐ /水栓金具/
すいせんしき /水洗式/
すいせんしゃ /推薦者/
すいせんしょ /推薦書/
すいせんじゅか /スイセンジュ科/Tetracentraceae/
すいせんじょう /推薦状/
すいせんせんしゅ /推薦選手/
すいせんち /推薦値/
すいせんちゅう /水栓柱/
すいせんちょうしょ /推薦調書/
すいせんといれ /水洗トイレ/
すいせんにゅうがく /推薦入学/
すいせんにゅうし /推薦入試/
すいせんにん /推薦人/
すいせんば /推薦馬/
すいせんばん /推薦盤/推薦版/
すいせんばんぐみ /推薦番組/
すいせんぶん /推薦文/
すいせんべんじょ /水洗便所/
すいせんぼん /推薦本/
すいせんりゆう /推薦理由/
すいせんわく /推薦枠/
すいぜいてんのう /綏靖天皇/
すいぜん /垂涎/吹禅/
すいぜんじ /水前寺/
すいぜんじこうえん /水前寺公園/
すいぜんじこうえんまえ /水前寺公園前/
すいぜんじのり /水前寺海苔/
すいぜんのまと /垂涎の的/
すいそ /水素/H/Hydrogen/
すいそいおん /水素イオン;[化学]H+/
すいそう /水槽/吹奏/水草/水層/水葬/垂層/水そう/
すいそうがく /吹奏楽/
すいそうがくだん /吹奏楽団/
すいそうがくぶ /吹奏楽部/
すいそうぞく /吹奏族/
すいそうぶんれつ /垂層分裂/
すいそうよう /水槽用/
すいそうれいきゃく /水槽冷却/
すいそかく /水素核/
すいそがす /水素ガス/
すいそきゅうぞうごうきん /水素吸蔵合金/
すいそく /推測/
すいそけつごう /水素結合/
すいそげんし /水素原子/
すいそぞうかん /水素増感/
すいそちくでんち /水素蓄電池/
すいそでんち /水素電池/
すいそばくだん /水素爆弾/
すいそん /水損/
すいぞう /膵臓/酔象/
すいぞうがん /膵臓癌/膵臓がん/
すいぞくえん /水族園/
すいぞくかん /水族館/
すいた /吹田/
すいたい /衰退/錐体;cone/推戴/酔態/衰頽;≒衰退 (「頽」はくずれること)/
すいたいき /衰退期/
すいたいさいぼう /錐体細胞/
すいたいろ /錐体路/
すいたし /吹田市/
すいだし /吸出し/吸い出し/
すいだん /推断/
すいち /推知/
すいちゅう /水中/水柱/
すいちゅうおんきょう /水中音響/
すいちゅうか /水中花/
すいちゅうかんそく /水中観測/
すいちゅうさつえい /水中撮影/
すいちゅうさつえいよう /水中撮影用/
すいちゅうしゃしん /水中写真/
すいちゅうしゃしんか /水中写真家/
すいちゅうせいかつ /水中生活/
すいちゅうせんとう /水中戦闘/
すいちゅうとし /水中都市/
すいちゅうは /水中葉/
すいちゅうめがね /水中眼鏡/
すいちゅうよう /水中用/水中葉;[植物]/
すいちゅうよくせん /水中翼船/
すいちょう /水鳥/推重/
すいちょうこうけい /翠帳紅閨/
すいちょく /垂直/⊥/
すいちょくかいぞうど /垂直解像度/
すいちょくかんせん /垂直感染/
すいちょくきせん /垂直帰線/
すいちょくけつごう /垂直結合/
すいちょくこうりょく /垂直抗力/
すいちょくしこう /垂直思考;vertical thinking/
すいちょくしゅうはすう /垂直周波数/
すいちょくじく /垂直軸/
すいちょくせい /垂直性/
すいちょくせん /垂直線/
すいちょくてき /垂直的/
すいちょくどうき /垂直同期/
すいちょくどうきしんごう /垂直同期信号/
すいちょくにゅうしゃ /垂直入射/
すいちょくびよく /垂直尾翼/
すいちょくぶんぷ /垂直分布;[生物]vertical distribution/
すいちょくほうこう /垂直方向/
すいちょくよく /垂直翼/
すいちょくりりく /垂直離陸/
すいづ /水津/
すいてい /推定/水底/
すいてい> /推定;-位置,-年収/
すいていき /推定機/
すいていけっか /推定結果/
すいていごさ /推定誤差/
すいていしき /推定式/
すいていせいど /推定精度/
すいていそうぞくにん /推定相続人/
すいていち /推定値/
すいていねんれい /推定年齢/
すいていはんい /推定範囲/
すいていほう /推定法/
すいていほうほう /推定方法/
すいていむざい /推定無罪/
すいていゆうざい /推定有罪/
すいていりょう /推定量/
すいてき /水滴/
すいてきちゅう /水滴中/
すいてん /水天/
すいてんぐう /水天宮/
すいてんぐうまえ /水天宮前/
すいてんほうふつ /水天彷彿/水天髣髴/
すいでん /水田/
すいと /水都;Venezia/
すいとう /出納/水稲/水筒/水痘;[医]varicella/膵島;[解剖]pancreatic island/
すいとうがかり /出納係/
すいとうしょう /水頭症/
すいとうちょう /出納帳;†cashbook/出納長;†chief cashier/
すいとうぼ /出納簿/
すいとりがみ /吸い取り紙/吸取り紙/
すいとん /水団;[料理]/水遁;-の術/
すいどう /水道/隧道;tunnel/
すいどうかん /水道管/
すいどうきょう /水道橋;古代ローマ/
すいどうきょく /水道局/
すいどうぐち /水道口/
すいどうこうじ /水道工事/
すいどうこうねつひ /水道光熱費/
すいどうしせつ /水道施設/
すいどうしようりょう /水道使用量/
すいどうじぎょう /水道事業/
すいどうすい /水道水/
すいどうせつび /水道設備/
すいどうせん /水道栓/
すいどうだい /水道代/
すいどうばし /水道橋/
すいどうばしえき /水道橋駅/
すいどうほう /水道法/
すいどうめーたー /水道メーター/
すいどうりょう /水道料/
すいどうりょうきん /水道料金/
すいなん /水難/
すいなんじこ /水難事故/
すいにょう /夊繞/
すいにん /推認/
すいにんてんのう /垂仁天皇/
すいのう /水嚢/
すいのみ /吸い飲み/吸飲み/
すいは /水波/
すいはん /炊飯/垂範/水飯/
すいはんき /炊飯器/
すいはんきゅう /水半球/
すいはんじゃー /炊飯ジャー/
すいばいか /水媒花/
すいばく /水爆/
すいばら /水原/杉原/
すいばん /水盤/推挽/
すいひ /水簸/水肥/
すいひつ /水筆/
すいび /衰微/翠微;山の中腹(の空気の色)/粋美/
すいふ /水夫/水府/炊婦/炊夫/炊フ/
すいふく /推服/
すいふくべ /吸い瓢/
すいふよう /酔芙蓉/
すいぶん /水分/
すいぶんかっせい /水分活性;Aw/
すいぶんでんかいしつ /水分電解質/
すいぶんほきゅう /水分補給/
すいぶんりょう /水分量/
すいへい /水平/水兵/
すいへいいち /水平位置/
すいへいいどう /水平移動/
すいへいかいぞうど /水平解像度/
すいへいかくさん /水平拡散/
すいへいかんせん /水平感染;[医]horizontal infection.⇔垂直感染/
すいへいき /水平器;(level) 面が水平か測定する計器/
すいへいきょくせん /水平曲線/
すいへいきょり /水平距離/
すいへいしこう /水平思考;lateral thinking/
すいへいしゃ /水平社/
すいへいしゃせんげん /水平社宣言/
すいへいしゅうはすう /水平周波数/
すいへいじく /水平軸/
すいへいじょうたい /水平状態/
すいへいせいぶん /水平成分/
すいへいせん /水平線/
すいへいそくど /水平速度/
すいへいたいこう /水平対向;ポルシェやスバルでよく使われてるエンジンのスタイル/
すいへいたぶ /水平タブ/
すいへいどう /水平動/
すいへいどうき /水平同期/
すいへいどうきしんごう /水平同期信号/
すいへいはっさん /水平発散/
すいへいばん /水平板/
すいへいひこう /水平飛行/
すいへいびよく /水平尾翼/
すいへいふく /水兵服;sailor suit/
すいへいぶんぷ /水平分布;[生物]horizontal distribution/
すいへいへんこう /水平偏向/
すいへいへんぱ /水平偏波/
すいへいほうこう /水平方向/
すいへいぼう /水兵帽;sailor cap/
すいへいめん /水平面/
すいへいめんじょう /水平面上/
すいへいりょく /水平力/
すいへん /水辺/
すいほ /酔歩/推歩/
すいほう /水泡/水疱/水胞/
すいぼう /水防/衰亡/酔眸/
すいぼうほう /水防法/
すいぼく /水墨/
すいぼくが /水墨画/
すいぼつ /水没/
すいま /睡魔/水魔/
すいまつ /水沫/
すいみつ /水密/水蜜/
すいみつかくへき /水密隔壁/
すいみつとう /水蜜桃/
すいみつひ /水密扉/
すいみゃく /水脈/
すいみん /睡眠/酔眠;よっぱらって眠る/
すいみんしょうがい /睡眠障害/
すいみんじかん /睡眠時間/
すいみんじむこきゅうしょうこうぐん /睡眠時無呼吸症候群/
すいみんじょうたい /睡眠状態/
すいみんちゅう /睡眠中/
すいみんぶそく /睡眠不足/
すいみんぶそくぎみ /睡眠不足気味/
すいみんぶっしつ /睡眠物質/
すいみんやく /睡眠薬/
すいむ /酔夢/睡夢/水霧/
すいめい /水明/吹鳴/
すいめつ /衰滅/
すいめん /水面/錐面/睡眠;[仏教] 五蓋のひとつ/
すいめんか /水面下/
すいめんじょう /水面上/
すいめんは /水面波/
すいもく /水木/
すいもくきん /水木金/
すいもじ /推文字/
すいもの /吸い物/吸物/
すいものわん /吸い物椀/
すいもん /水門/水紋/
すいもんがく /水文学;hydrology/
すいやく /水薬/
すいよ /酔余/睡余/
すいよう /水曜/水溶/
すいようえき /水溶液/水様液/
すいようざい /水溶剤/
すいようせい /水溶性/
すいようび /水曜日/
すいようびはつ /水曜日発/
すいよく /水浴/
すいらい /水雷/
すいらいせん /水雷戦/
すいらいせんたい /水雷戦隊/
すいらいてい /水雷艇/
すいらん /翠嵐/
すいり /推理/水利/
すいりがく /水理学;hydraulics/
すいりきがく /水力学;hydraulic/
すいりく /水陸/
すいりけん /水利権/
すいりさっか /推理作家/
すいりしょう /推理賞/
すいりしょうせつ /推理小説/
すいりゅう /水流/水竜/垂柳/
すいりゅうし /水龍士/
すいりょう /水量/推量/
すいりょく /水力/推力/翠緑/
すいりょくせいぎょ /推力制御/
すいりょくはつでん /水力発電/
すいりょくはつでんしょ /水力発電所/
すいれい /水冷/
すいれいか /水冷化/
すいれいしき /水冷式/
すいれん /睡蓮/水練/
すいれんあか /スイレン亜科/Nymphaeoideae/
すいれんか /スイレン科/Nymphaeaceae/
すいろ /水路/
すいろぶ /水路部/
すいろん /推論/水論/
すいろんかてい /推論過程/
すいろんきこう /推論機構/
すいろんきそく /推論規則/
すいろんちしき /推論知識/
すいろんのうりょく /推論能力/
すいろんぶ /推論部/
すいろんほうしき /推論方式/
すいわ /水和;hydration. 「-剤,-数,-反応」/
すいわざい /水和剤/
すいわぶつ /水和物/
すう /数/趨;趨勢/雛;ひな/芻;反芻/鄒;春秋時代の国名/崇;崇高/嵩;かさ/菘;すずな/陬;すみ/枢;中枢/樞;「枢」の旧字/數;「数」の旧字/四;(si)中国音/
すう> /数/
すうあんこ /四暗刻/
すうあんこう /四暗刻/
すうい /趨異/
すういんすう /数引数/
すうぇーでん /瑞典;Sweden/
すうぇーでんご /スウェーデン語;フィンランドでも使われる/
すうぇーでんじん /スウェーデン人/
すうえき /数駅/
すうおく /数億/
すうおん /数音/
すうかい /数回/
すうかいけん /数解研/数理解析研究所;※abbrev/
すうかいさんか /数回参加/
すうかいしよう /数回使用/
すうかいちょう /数階調/
すうかいていど /数回程度/
すうかげつ /数ヶ月/数カ月/数か月/
すうかげつかん /数カ月間/数か月間/
すうかげつまえ /数カ月前/数か月前/数箇月前/
すうかしょ /数カ所/数箇所/数ヶ所/数個所/
すうかん /数巻/
すうがく /数学/
すうがくか /数学科/
すうがくかい /数学会/
すうがくかん /数学観/
すうがくかんけい /数学関係/
すうがくかんけいしゃ /数学関係者/
すうがくかんすう /数学関数/
すうがくがいねん /数学概念/
すうがくがくしゅう /数学学習/
すうがくきごう /数学記号/±;「+-」「ぷらまい」/×;「x」「かける」/÷;「-:」「わる」/∞;infinity,「oo」「むげんだい」/∝;「ひれい」/∴;therefore,「よって」/∵;because,「なぜなら」/⇒;「=>」「ならば」/⇔;equiv,「<=>」「どうち」/∀;all,「にんい」/∃;exist,「ある」/∂;d,partial/Δ;Delta/∇;nabla,「なぶら」/√;root,sqrt,「るーと」/∫;integral,「せきぶん」/∬;「にじゅうせきぶん」/≡;equiv,「ごうどう」/∽;similar,「そうじ」/≒;「やく」「=:」/≠;neq,「!=」/≦;「<=」/≧;「>=」/≪;「<<」/≫;「>>」/∈;include/∋;include/⊆;subseteq/⊇;superseteq/⊂;subset/⊃;superset「ならば」/∪;sum,「わしゅうごう」/∩;cap,「まじわり」/∧;and,「れんげん」/∨;or,「せんげん」/¬;not,「ひてい」/∠;angle,「かく」/⌒;arc,「えんこ」/⊥;vertical,「すいちょく」/
すうがくきそ /数学基礎/
すうがくきそろん /数学基礎論/
すうがくきょういく /数学教育/
すうがくきょうし /数学教師/
すうがくきょうしつ /数学教室/
すうがくけい /数学系/
すうがくけんてい /数学検定/
すうがくけんていきょうかい /数学検定協会/
すうがくけんていしけん /数学検定試験/
すうがくげんご /数学言語/
すうがくご /数学語/
すうがくし /数学史/
すうがくしゃ /数学者/
すうがくしょ /数学書/
すうがくしょう /数学賞/
すうがくしんりがく /数学心理学/
すうがくじてん /数学辞典/数学事典/
すうがくじゅけん /数学受験/
すうがくせんこう /数学専攻/
すうがくせんもん /数学専門/
すうがくぜんたい /数学全体/
すうがくたいけい /数学体系/
すうがくちしき /数学知識/
すうがくてき /数学的/
すうがくてきがいねん /数学的概念/
すうがくてききそ /数学的基礎/
すうがくてききのうほう /数学的帰納法/
すうがくてきこうぞう /数学的構造/
すうがくてきしこう /数学的思考/
すうがくてきしんり /数学的真理/
すうがくてきそうさ /数学的操作/
すうがくてきそくめん /数学的側面/
すうがくてきたいしょう /数学的対象/
すうがくてきちしき /数学的知識/
すうがくてきのうりょく /数学的能力/
すうがくてきほうほう /数学的方法/
すうがくてきりろん /数学的理論/
すうがくとしょしつ /数学図書室/
すうがくにゅうもん /数学入門/
すうがくのうりょく /数学能力/
すうがくばたけ /数学畑/
すうがくぶ /数学部/
すうがくぶんや /数学分野/
すうがくもでる /数学モデル/
すうがくや /数学屋/
すうがくよう /数学用/
すうがくようご /数学用語/
すうがくりょく /数学力/
すうがくりろん /数学理論/
すうがくろん /数学論/
すうがそ /数画素/
すうがっか /数学科/
すうがっかい /数学会/
すうがめん /数画面/
すうき /数奇/数機/数基/数期/枢機/
すうきかん /数機関/
すうききょう /枢機卿/
すうきょうきょう /数教協/
すうきょく /数曲/数局/
すうきろ /数キロ/
すうぎょう /数行/
すうけい /崇敬/
すうけた /数桁/
すうけん /数件/数軒/数研/数理解析研究所;※abbrev/
すうげき /数撃/
すうこ /数個/数戸/
すうこう /崇高/数校/数項/趨向/
すうこく /数刻/
すうご /数語/
すうごう /数号/
すうさく /数作/
すうさつ /数冊/
すうざん /嵩山;地名,五岳の一。中岳/
すうし /数詞/
すうしあい /数試合/
すうしいほう /四喜和/
すうしき /数式/
すうしきかんきょう /数式環境/
すうしききごう /数式記号/
すうしきしょり /数式処理/
すうしきしょりげんご /数式処理言語/
すうしきてき /数式的/
すうしきひょうじ /数式表示/
すうしきへんしゅう /数式編集/
すうしきもーど /数式モード/
すうしきよう /数式用/
すうしゃ /数社/
すうしゃしゅ /数車種/
すうしゅ /数種/
すうしゅう /数週/数周/
すうしゅうかん /数週間/
すうしゅうかんご /数週間後/
すうしゅうかんまえ /数週間前/
すうしゅうまえ /数週前/数周前/
すうしゅるい /数種類/
すうしゅん /数瞬/
すうしょうせつ /数小節/
すうじ /数字/数次/
すうじいじょう /数字以上/
すうじかん /数時間/
すうじかんご /数時間後/
すうじかんていど /数時間程度/
すうじく /枢軸/樞軸/
すうじくこく /枢軸国/
すうじしてい /数字指定/
すうじじたい /数字自体/
すうじじょう /数字上/
すうじっかい /数十回/
すうじっかしょ /数十箇所/
すうじっこ /数十個/
すうじっつう /数十通/
すうじっぷん /数十分/
すうじっぽん /数十本/
すうじつ /数日/
すうじついない /数日以内/
すうじつかん /数日間/
すうじつご /数日後/
すうじつちゅう /数日中/
すうじつぶん /数日分/
すうじつまえ /数日前/
すうじつらい /数日来/
すうじてき /数字的/
すうじにんしき /数字認識/
すうじゅう /数十/
すうじゅうえん /数十円/
すうじゅうおく /数十億/
すうじゅうおくねんまえ /数十億年前/
すうじゅうじかん /数十時間/
すうじゅうだい /数十台/
すうじゅうにん /数十人/
すうじゅうねん /数十年/
すうじゅうねんまえ /数十年前/
すうじゅうばい /数十倍/
すうじゅうび /数十尾/
すうじゅうびょう /数十秒/
すうじゅうびょうかん /数十秒間/
すうじゅうまい /数十枚/
すうじゅうまん /数十万/
すうじゅうまんえん /数十万円/
すうじゅうまんにん /数十万人/
すうじゅっかい /数十回/
すうじゅっき /数十機/
すうじゅっこ /数十個/
すうじゅっさつ /数十冊/
すうじゅっしゅるい /数十種類/
すうじゅっつう /数十通/
すうじゅっぷん /数十分/
すうじゅっぷんかん /数十分間/
すうじゅっぷんまえ /数十分前/
すうじゅっぽん /数十本/
すうじょう /数条/
すうじれつ /数字列/
すうせい /趨勢/
すうせいき /数世紀/
すうせいきご /数世紀後/
すうせいきまえ /数世紀前/
すうせみ /数セミ/
すうせん /数千/数戦/
すうせんえん /数千円/
すうせんおく /数千億/
すうせんかい /数千回/
すうせんさつ /数千冊/
すうせんじかん /数千時間/
すうせんち /数センチ/
すうせんにん /数千人/
すうせんねん /数千年/
すうせんねんまえ /数千年前/
すうせんぼん /数千本/
すうせんまい /数千枚/
すうせんまん /数千万/
すうせんまんえん /数千万円/
すうせんまんにん /数千万人/
すうた /数多/
すうたい /数体/素謡/
すうたいけい /数体系/
すうだい /数台/
すうだいまえ /数代前/数台前/
すうだん /数段/
すうだんうえ /数段上/
すうち /数値/
すうちいがい /数値以外/
すうちえんざん /数値演算/
すうちえんざんかんすう /数値演算関数/
すうちか /数値化/
すうちかい /数値解/
すうちかいせき /数値解析/
すうちかいせきけっか /数値解析結果/
すうちかいせきほう /数値解析法/
すうちかいほう /数値解法/
すうちけいさん /数値計算/
すうちしょしき /数値書式/
すうちしょり /数値処理/
すうちじっけん /数値実験/
すうちせきぶん /数値積分/
すうちちず /数値地図/
すうちていすう /数値定数/
すうちてき /数値的/
すうちてきけんきゅう /数値的研究/
すうちでーた /数値データ/
すうちにゅうりょく /数値入力/
すうちひょうげん /数値表現/
すうちもでる /数値モデル/
すうちょくせん /数直線/
すうちよほう /数値予報/
すうちりゅうたいりきがく /数値流体力学/
すうちれい /数値例/
すうつう /数通/
すうて /数手/
すうていれきしょ /崇禎暦書/
すうてき /数的/数滴/
すうてん /数点/数店/
すうとう /数等/数頭/
すうど /数度/
すうどく /数独/
すうどん /素饂飩/
すうにち /数日/
すうにちかん /数日間/
すうにん /数人/
すうにんていど /数人程度/
すうにんぶん /数人分/
すうねん /数年/
すうねんかん /数年間/
すうねんご /数年後/
すうねんさき /数年先/
すうねんほどまえ /数年程前/
すうねんまえ /数年前/
すうねんらい /数年来/
すうはい /崇拝/
すうはいしゃ /崇拝者/
すうはいぶつ /崇拝物/
すうはつ /数発/
すうば /数馬/
すうばい /数倍/
すうぱい /数牌/
すうひき /数匹/
すうひゃく /数百/
すうひゃくえん /数百円/
すうひゃくえんていど /数百円程度/
すうひゃくじかん /数百時間/
すうひゃくだい /数百台/
すうひゃくにち /数百日/
すうひゃくにん /数百人/
すうひゃくねん /数百年/
すうひゃくねんいじょう /数百年以上/
すうひゃくねんご /数百年後/
すうひゃくねんさき /数百年先/
すうひゃくばい /数百倍/
すうひゃくぺーじ /数百頁/
すうひゃくまん /数百万/
すうひゃくまんにん /数百万人/
すうひゃくまんねん /数百万年/
すうひゃくまんまい /数百万枚/
すうひゃくめい /数百名/
すうひゃっかい /数百回/数百階/
すうひゃっき /数百機/
すうひょう /数表/数票/
すうひょうき /数表記/
すうびょう /数秒/
すうびょうかん /数秒間/
すうびょうご /数秒後/
すうふん /数分/
すうふんいない /数分以内/
すうふんかん /数分間/
すうふんご /数分後/
すうぶつ /数物/崇仏/
すうぶつけい /数物系/
すうへいほう /数平方/
すうぺーじ /数ページ/
すうほ /数歩/
すうほう /崇奉/
すうほん /数本/
すうまい /数枚/
すうまん /数万/
すうまんえん /数万円/
すうまんえんていど /数万円程度/
すうまんにん /数万人/
すうまんにんたんい /数万人単位/
すうまんねん /数万年/
すうまんねんまえ /数万年前/
すうまんばい /数万倍/
すうみつ /枢密/
すうみついん /枢密院/
すうみつど /数密度/
すうみり /数ミリ/
すうめーとる /数メートル/
すうめい /数名/
すうめいいじょう /数名以上/
すうめいぶん /数名分/
すうもじ /数文字/
すうもん /数問/
すうよう /枢要/
すうり /数理/数理情報科学;※abbrev/
すうりかい /数理解/
すうりかいせき /数理解析/
すうりかいせきけん /数理解析研/
すうりかいせきけんきゅうしょ /数理解析研究所/
すうりかがく /数理科学/
すうりかがくけんきゅうか /数理科学研究科/
すうりかがくてき /数理科学的/
すうりかがっか /数理科学科/
すうりがく /数理学/
すうりがっか /数理学科/
すうりぎけん /数理技研/
すうりけい /数理系/
すうりけいかくほう /数理計画法/
すうりけいかくもんだい /数理計画問題/
すうりけいざいがく /数理経済学;mathematical economics/
すうりけん /数理研/数理解析研究所;※abbrev/
すうりげんごがく /数理言語学/
すうりこうがく /数理工学/
すうりこうがくか /数理工学科/
すうりこうがっか /数理工学科/
すうりしすてむ /数理システム/
すうりじょうほう /数理情報/
すうりじょうほうかがく /数理情報科学/
すうりじょうほうがく /数理情報学/
すうりじょうほうがっか /数理情報学科/
すうりせいぶつがく /数理生物学/
すうりてき /数理的/
すうりてききそ /数理的基礎/
すうりてつがく /数理哲学/
すうりとうけい /数理統計/
すうりとうけいがく /数理統計学/
すうりもでる /数理モデル/
すうりょう /数量/
すうりょうか /数量化/
すうりょうかんけい /数量関係/
すうりょうてき /数量的/
すうりろんり /数理論理/
すうりろんりがく /数理論理学/
すうれい /数例/
すうれつ /数列/
すうれつめ /数列目/
すうろん /数論/
すうろんてき /数論的/
すうわ /数話/
すうわぶん /数話分/
すうわり /数割/
すえ /末/陶/甄/裔;末裔/須恵/据/
すえあし /末脚/末足/
すえいし /末石/
すえお /末男/季雄/
すえおか /末岡/
すえおき /据置き/据え置き/据置/
すえおきがた /据置型/
すえかね /末包/
すえかわ /末川/
すえき /須恵器/陶器;=須恵器/末木/
すえきち /末吉/
すえごろ /末頃/
すえざき /末崎/
すえじ /末治/
すえじま /末島/
すえぜん /据え膳/
すえたに /末谷;姓/
すえっこ /末っ子/
すえつぐ /末次/
すえつけ /据付/据え付け/据付け/
すえつむはな /末摘花/
すえなが /末永/
すえの /末野/
すえはず /末弭/末筈/
すえひろ /末広/末弘/
すえひろがり /末広がり/
すえひろちょう /末広町/
すえまさ /末政/
すえまつ /末松/
すえみつ /末光/
すえむすめ /末娘/
すえもの /陶物/
すえものし /陶物師/
すえやす /末安/
すえよし /末吉/末善/
すおう /周防/蘇芳/蘇枋/須王/蘇方/素袍/素襖/
すおういろ /蘇芳色/
すおうなだ /周防灘/
すおうのないし /周防内侍;春の夜の ゆめばかりなる 手枕に かひなくたたむ 名こそをしけれ/
すかがわ /須賀川/
すかさず /透かさず/
すかし /透かし;電子-/
すかしぼり /透かし彫り/
すかゆ /酸ヶ湯/酢ケ湯/
すからーせき /スカラー積;[数学]scalar product. 内積/
すからーば /スカラー場/
すからざ /スカラ座;劇団/
すかんじうむ /Sc/Scandium/
すかんぴん /素寒貧/
すかんぽ /酸模/
すが /菅/須賀/須ヶ/管/
すがい /菅井/須貝/酢貝/
すがえ /菅江/
すがえますみ /菅江真澄/
すがお /素顔/菅尾/
すがさわ /菅澤/
すがすが /清々/
すがすがしさ /清々しさ/
すがた /姿/菅田/
すがたえ /姿絵/
すがたかたち /姿形/
すがたずし /姿寿司/
すがたに /姿煮/
すがたみ /姿見/
すがたやき /姿焼/姿焼き;伊勢エビの-/
すがたり /素語り/
すがだいら /菅平/
すがちょう /須賀町/
すがぬま /菅沼/
すがの /菅野/
すがはら /菅原/
すがむら /管村/
すがめ /眇/
すがも /巣鴨/
すがもかん /巣鴨間/
すがもと /菅本/
すがや /菅谷/
すがわ /須川/
すがわら /菅原;姓,-道真/管原/
すがわらのみちざね /菅原道真/
すき /隙/鋤/数寄/漉/犂;≒鋤 (字義:牛に曳かせるすき)/耒;(字義:土に筋をつけるすき)/鍬;(くわ)/須木/好き/犁;「犂」異体字/
すきーいた /スキー板/
すきーきゃく /スキー客/
すきーぐつ /スキー靴/
すきーじょう /スキー場/
すきうつし /透き写し/
すきかって /好き勝手/
すききらい /好き嫌い/
すきぎ /透木/
すきぐし /梳櫛/篦/
すきごころ /好き心/
すきしゃ /数寄者/
すきずき /好き好き/好きずき/
すきっぱら /空きっ腹/
すきなべ /鋤鍋/
すきばら /空腹/
すきほうだい /好き放題/
すきま /隙間/すき間/透き間/
すきまかぜ /隙間風/
すきまさんぎょう /隙間産業/
すきみ /透き見/透見/剥き身/
すきもの /好き者/数寄者/
すきや /数奇屋/
すきやき /鋤焼/すき焼き/
すきやづくり /数寄屋造り;[建築]/数寄屋造;[建築]/
すきやばし /数寄屋橋/数奇屋橋/
すきやぼうず /数寄屋坊主/
すぎ /杉/椙;国字/過ぎ/
すぎうち /杉内/
すぎうら /杉浦/
すぎえ /杉江/
すぎおか /杉岡/
すぎかふん /杉花粉/スギ花粉/
すぎかふんしょう /杉花粉症/
すぎかわ /杉皮/
すぎがき /杉垣/
すぎき /杉木/
すぎさき /杉崎/
すぎさわ /杉沢/
すぎざい /杉材/
すぎざき /杉崎/
すぎした /杉下/
すぎた /杉田/
すぎたげんぱく /杉田玄白/
すぎたこ /杉タコ/
すぎたに /杉谷/
すぎつま /杉妻/
すぎと /杉戸/
すぎとう /杉藤/
すぎど /杉戸/
すぎなみ /杉並/
すぎなみき /杉並木/
すぎなみく /杉並区/
すぎなみこうこう /杉並高校/
すぎなみびょう /杉並病/
すぎぬま /杉沼/
すぎの /杉野/
すぎのした /杉之下/
すぎのはら /杉ノ原/
すぎのり /杉海苔/
すぎはら /杉原/
すぎはらがみ /杉原紙/
すぎばし /杉箸/
すぎばやし /杉林/
すぎまち /杉町/
すぎむら /杉村/
すぎもと /杉本/
すぎもとちょう /杉本町/
すぎやま /杉山/椙山/
すぎやまさんぷう /杉山杉風/
すぎりょうたろう /杉良太郎/
すぎわら /杉原/
すく /少/秀句/
すくい /救い/
すくいあみ /掬い網;金魚掬いの-/
すくいなげ /掬い投げ/
すくいぬし /救い主/
すくいのて /救いの手;-を差し伸べる/
すくごう /宿業;=しゅくごう/
すくせ /宿世/
すくな /少な/
すくない /少ない/
すくなからず /少なからず/
すくなくとも /少なくとも/
すくなめ /少な目/少なめ/
すくね /宿禰/
すくも /宿毛;地名,愛知県/粭/糘/
すくよう /宿曜;二十八宿と七曜/
すくようどう /宿曜道/
すくらんぶるこうさてん /スクランブル交差点/
すぐ /直ぐ/
すぐき /酸茎/
すぐきな /酸茎菜/
すぐさま /直ぐ様/直ぐ樣;「様」旧字/
すぐは /直刃/
すぐり /村主/酸塊;gooseberry/
すぐる /卓/勝/英/俊/
すぐれもの /優れ物/
すけ /助/介/佐/資/祐/佑/亮/輔/甫/丞/次官;[律令制] NB:人名の[助介佐資祐佑亮輔丞]等は全てこの種別/典侍;[律令制]/
すけーとぐつ /スケート靴/
すけーとじょう /スケート場/
すけかつ /資勝/
すけがわ /助川/
すけさこ /助迫/
すけすけ /透け透け/
すけそうだら /助惣鱈/
すけだち /助太刀/
すけっと /助っ人/助人/
すけて /助手/
すけとうだら /介党鱈/
すけのぶ /助信/
すけばん /スケ番/
すけべえ /助兵衛/
すけべごころ /スケベ心/
すけむね /助宗/
すけやす /祐安;姓/
すけよし /祐好/
すけろく /助六/
すけん /素見/
すけんぶつ /素見物/
すげ /菅/素気;-なく/
すげかわ /菅河/
すげがさ /菅笠/
すげぬま /菅沼/
すこし /少し/
すこしも /少しも/
すこっとらんど /蘇格蘭/
すこぶる /頗る/頗/
すこぶるつき /頗る付き/
すこやか /健やか/
すこらがく /スコラ学;scholasticism/
すこらてつがく /スコラ哲学;scholastic philosophy/
すこんぶ /酢昆布/
すご /凄/
すごい /凄い/
すごう /菅生/
すごうせん /菅生戦/
すごうで /凄腕/
すごさ /凄さ/
すごしかた /過ごし方/
すごみ /凄み/凄味/
すごもり /巣籠/巣籠り/
すごろく /双六/
すさ /須佐/
すさか /須坂/
すさき /須崎/洲崎/
すさのおのみこと /須佐之男命/素戔嗚尊/
すさびごと /遊び事/
すさまじさ /凄まじさ/
すさみ /須佐美/
すざい /巣材/
すざか /須坂/
すざき /洲崎/寿崎/
すざく /朱雀/
すざくいん /朱雀院;[源氏物語]/
すざくおおじ /朱雀大路;朱雀門〜羅生門/
すざくてんのう /朱雀天皇/
すざくもん /朱雀門/
すざわ /須沢/
すし /寿司/鮨/鮓/
すしだね /鮨種/
すしづめ /寿司詰め/
すしてん /寿司店/
すしめし /寿司飯/鮨飯/
すしや /寿司屋/鮨屋/
すしゅんてんのう /崇峻天皇/
すじ /筋/
すじあい /筋合い/筋合/
すじかい /筋交い/筋違い;[建築]軸組に入れる斜材/
すじがき /筋書/筋書き/
すじがね /筋金/
すじがねいり /筋金入り/
すじきり /筋切り/
すじぐも /筋雲/
すじこ /筋子/
すじだて /筋立/
すじちがい /筋違い/
すじにく /筋肉/
すじぼね /筋骨/
すじぼり /筋彫り/
すじみち /筋道/
すじむかい /筋向い/筋向かい/
すじむこう /筋向こう/筋向う/
すじめ /筋目/酢締め/
すじゃく /朱雀/
すじや /筋屋/
すじょう /素性/巣状/素姓/素場/
すじょうゆ /酢醤油/
すじんてんのう /崇神天皇/
すす /煤/
すすいろ /煤色/
すすき /薄/芒/
すすきた /薄田/
すすきの /薄野/
すすけ /煤け/
すすたけ /煤竹/
すすたけいろ /煤竹色/
すすはき /煤掃き/
すすはらい /煤払い/
すすみかた /進み方/
すすみぐあい /進み具合/
すすむ /進/晋/奨/晉/
すすめ /勧め/
すすめかた /進め方/
すすりなき /啜り泣き/
すず /鈴;bell/錫;tin/篠;細い竹/篶;=篠/珠洲;地名,石川県/鑾;天子の馬車につける鈴/Sn/Tin/
すずい /鈴井/
すずおき /鈴置/
すずか /鈴鹿/鈴香/
すずかけ /鈴懸/
すずかしない /鈴鹿市内/
すずかぜ /涼風/
すずかとうげ /鈴鹿峠/
すずき /鈴木/鱸/
すずきあぐり /鈴木亜久里/
すずきかんたろう /鈴木貫太郎/
すずきだいせつ /鈴木大拙/
すずきほなみ /鈴木保奈美/
すずぐち /鈴口/
すずこんしき /錫婚式;10周年/
すずし /生絹/
すずしま /鈴嶋/
すずしろ /蘿蔔;七草の一。大根。/
すずたけ /篠竹/
すずたに /鈴谷/
すずたん /鈴丹/
すずな /鈴菜/菘/
すずなり /鈴なり/鈴生り/
すずのすけ /鈴之助/
すずはく /錫箔/
すずひこ /鈴彦/
すずみ /涼み/
すずみだい /涼み台/
すずみぶね /涼み船/
すずむし /鈴虫/
すずむら /鈴村/
すずめ /雀/
すずめいろ /雀色;茶褐色/
すずめが /天蛾/雀蛾/
すずめがおか /雀ヶ丘/
すずめばち /雀蜂/
すずや /鈴谷/
すずやま /鈴山/
すずよ /鈴世/
すずらん /鈴蘭/
すずらんこうげん /鈴蘭高原/
すずらんとう /鈴蘭灯/
すずり /硯/
すずりいし /硯石/
すずりばこ /硯箱/
すずりや /硯屋/
すずろ /漫ろ/
すそ /裾/
すそあげ /裾上げ/
すそとり /裾取り/
すその /裾野/
すそのし /裾野市/
すそはらい /裾払い/
すそもよう /裾模様/
すそよけ /裾除け/
すそわけ /裾分け/
すたーがた /スター型/
すたーせんしゅ /スター選手/
すたじおろくおん /スタジオ録音/
すたまご /酢卵/
すためんおち /スタメン落ち/
すたり /廃り/
すたりもの /廃り物;流行り物は-/
すたれ /廃れ/
すたんどせき /スタンド席/
すたんふぉーどだいがく /スタンフォード大学;Stanford University. www.stanford.edu/
すたんれーでんき /スタンレー電気/
すだ /須田/巣田/
すだこ /酢蛸/
すだち /巣立ち/酢橘/酸橘/
すだつ /須達/
すだま /須玉/魑魅/
すだれ /簾/
すちーるかん /スチール缶/
すちーるげん /スチール弦/
すっきりかん /スッキリ感/すっきり感/
すったもんだ /擦った揉んだ/
すっとんきょう /素頓狂/
すっぱ /素破;spy/透波;=素破/素っ破;=素破/
すっぱだか /素っ裸/
すっぽぬけ /すっぽ抜け;フォークボールの-/
すっぽん /鼈/
すづけ /酢漬け;キャベツの-(Sauerkraut)/酢漬/
すてーじいしょう /ステージ衣装/
すてありんさん /ステアリン酸;[化学]stearic acid. C17H35COOH/
すていし /捨て石/
すていぬ /捨て犬/
すていん /捨て印/捨印/
すてうり /捨て売り/
すてがね /捨て金/
すてき /素敵/素的;=素敵 (「素敵」「素的」ともに当て字)/
すてご /捨て子/捨子/棄て児/棄て子/
すてごま /捨て駒/
すてぜに /捨て銭/
すてぜりふ /捨て台詞/
すてどころ /捨て所/
すてね /捨て値/
すてねこ /捨て猫/
すてはい /捨牌;[麻雀]/捨て牌/
すてば /捨て場/
すてばち /捨て鉢/
すてぱい /捨て牌/捨牌;[麻雀]/
すてみ /捨て身/
すてやく /捨役/
すてんれすこう /ステンレス鋼;stainless steel/
すてんれすせい /ステンレス製/
すで /素手/既/已/
すでに /既に/已に/
すとーりーせい /ストーリー性/
すとあてつがく /ストア哲学;Stoicism/
すとあは /ストア派/
すとう /須藤/周東/
すとく /崇徳/
すとくいん /崇徳院/
すとくてんのう /崇徳天皇/
すとけん /スト権;ストライキ権/
すとっぷだか /ストップ高/
すとっぷやす /ストップ安/
すとやぶり /スト破り/
すとらいきけん /ストライキ権;争議権/
すとりーとけい /ストリート系/
すとれすかいしょう /ストレス解消/
すとれすはっさん /ストレス発散/
すとろんちうむ /Sr/Strontium/
すどう /須藤/
すどうふ /酢豆腐/
すどおし /素通し/
すどおり /素通り/
すどまり /素泊まり/素泊り/
すな /砂/沙/
すなあそび /砂遊び/
すなあらし /砂嵐/
すないろ /砂色/
すなえ /砂絵/
すなお /素直/砂緒/淳/
すなおとこ /砂男/
すなかけばばあ /砂掛婆/
すなかぶり /砂被り;[相撲]/
すなかべ /砂壁;[建築]sand coat/
すなかわ /砂川/
すなかわえき /砂川駅/
すなが /須永/
すながわ /砂川/
すながわちょう /砂川町/
すなぎも /砂肝/
すなくら /砂倉/
すなけし /砂ケシ/
すなけむり /砂煙/
すなこ /砂子/
すなご /砂子/沙子/
すなざら /砂皿;実験用具/
すなじ /砂地/
すなずり /砂摺り/砂摩り/
すなだ /砂田/
すなち /砂地/
すなっくがし /スナック菓子/
すなっぷしゃしん /スナップ写真/
すなつぶ /砂粒/
すなづるあか /スナヅル亜科/Cassythoideae/
すなどけい /砂時計/
すなどりねこ /漁り猫/
すなぬき /砂抜き/
すなのおんな /砂の女;安部公房/
すなはち /即ち/則ち/
すなはま /砂浜/
すなはら /砂原/
すなば /砂場/
すなばこ /砂箱/
すなぶくろ /砂袋;sand bag/砂嚢;(鳥の)さのう/
すなぶろ /砂風呂/
すなぼこり /砂埃/
すなみ /角南/巣南/
すなむし /砂蟲/
すなめり /鯆/砂滑/
すなやま /砂山/
すなゆ /砂湯;砂風呂/
すなわち /即ち/則ち/乃ち/曾ち/曽ち;「曾」の異体字/
すなわら /砂原/
すにん /数人/
すね /脛/臑;=脛/
すねあて /脛当て/臑当て/
すねお /スネ夫;名,漫画「ドラえもん」の登場人物/
すねかじり /臑齧り/臑かじり/
すねげ /すね毛/スネ毛/
すねもの /拗ね者/
すのこ /簀の子/
すのはら /春原/須野原/
すのまた /墨俣/
すのもの /酢の物/
すはだ /素肌/
すはだか /素裸/
すはま /州浜/洲浜;=州浜/
すはら /須原/栖原/寿原/
すばこ /巣箱/
すばなし /素話/
すばなれ /巣離れ/
すばやさ /素早さ/
すばやし /素囃子;謡なし/
すばる /昴/
すぱいえいせい /スパイ衛星/
すぱっと /スパッと/
すぱるたきょういく /スパルタ教育;Spartan education/
すぱるたしき /スパルタ式/
すびき /巣引/
すびつ /炭櫃/
すぴーどいはん /スピード違反/
すぴーどかん /スピード感/
すぴーどきょう /スピード狂/
すふぉるつぁんど /sforzando;その音を特に強く/
すぶた /酢豚/
すぶり /素振り/
すぷらいんきょくせん /スプライン曲線/
すぷれーかん /スプレー缶/
すべ /術/
すべからく /須らく/須く/
すべがみ /皇神/
すべすべ /滑々;NB:「ぬめぬめ」と同形/滑滑/
すべて /全て/総て/凡て/総/總;「総」の旧字/
すべての /∀/
すべらがみ /皇神/
すべり /辷/
すべりこみ /滑り込み/
すべりだい /滑り台/すべり台/
すべりだし /滑り出し/
すべりどめ /滑り止め/
すぺいん /西班牙;Spain/
すぺいんご /スペイン語/
すぺいんじん /スペイン人/
すぺいんりょうり /スペイン料理/
すぺくとるかいせき /スペクトル解析/
すぺくとるがた /スペクトル型;spectral type/
すぺくとるせん /スペクトル線/
すぺくとるぶんせき /スペクトル分析;[科技]spectral analysis/
すほん /素本/
すぼし /素干し/
すぼり /素掘り/
すぽーついがく /スポーツ医学;sports medicine/
すぽーつがり /スポーツ刈り;男性の髪型/
すぽーつし /スポーツ紙/スポーツ誌/
すぽーつしんぶん /スポーツ新聞;報知やスポニチなど/
すぽーつしんりがく /スポーツ心理学/
すぽーつせんしゅ /スポーツ選手/
すぽこん /スポ根/
すぽっとようせつ /スポット溶接;spot welding/
すぽんじじょう /スポンジ状/
すま /須磨;地名,神戸/須万;[魚]/
すまい /住まい/営/住居/住い/相撲/
すまえき /須磨駅/
すまき /簀巻き;-にして東京湾に抛り込む/簀巻/
すましじる /澄まし汁/すまし汁/
すまた /素股/寸又/
すまたきょう /寸又峡/
すまちょう /須磨町/
すまない /済まない/
すみ /隅/炭/墨/角/済/済み/須美;人名/須見;人名/陬/純/住/寿/澄/澂;「澄」の異体字/濟;「済」の旧字/
すみいし /隅石/
すみいろ /墨色/
すみうち /墨打ち/
すみえ /墨絵/澄江/寿美江/純恵/スミ恵/
すみお /澄夫/澄雄/純雄/
すみか /住処/住みか/棲み家/住み家/住み処/住化;住友化学/鈴美香/
すみかえ /住替え/
すみかわ /澄川/
すみがま /炭窯/
すみきん /住金/
すみぎん /住銀/
すみこ /澄子/純子/寿美子/
すみこみ /住み込み/住込み/
すみごこち /住み心地/
すみさわ /隅沢/
すみしょう /住商/
すみじ /墨字/
すみずみ /隅々/
すみそ /酢味噌/
すみそあえ /酢味噌和え/
すみぞめ /墨染/
すみた /住田/角田/
すみだ /墨田/隅田/住田/
すみだがわ /隅田川/墨田川/
すみだく /墨田区/
すみだん /須弥壇/
すみっこ /隅っこ/
すみつき /墨付/
すみつきかっこ /隅付き括弧/【/】/
すみつぎ /墨継ぎ/
すみつぼ /墨壺/
すみてまえ /炭手前;[茶道]/
すみでん /住電/
すみと /澄人/
すみとも /住友/
すみともかがく /住友化学;[企業名]/
すみともかがくこうぎょう /住友化学工業;[企業名]/
すみともきんぞく /住友金属/
すみともきんぞくこうぎょう /住友金属工業;[企業名]/
すみともぎんこう /住友銀行/
すみともけんせつ /住友建設;[企業名]/
すみともしょうじ /住友商事;[企業名]/
すみともせいやく /住友製薬;[企業名]/
すみともせめんと /住友セメント/
すみともそうこ /住友倉庫/
すみともでんきこうぎょう /住友電気工業;[企業名]/
すみともでんこう /住友電工;[企業名]/
すみともふどうさん /住友不動産/
すみながし /墨流し/
すみなわ /墨縄/
すみぬり /墨塗り/
すみの /角野/墨野/
すみのえ /住之江/住江/
すみのくら /角倉/
すみのくらぼん /角倉本/
すみのどう /住道/
すみひき /墨引き/
すみひら /住平/
すみび /炭火/
すみびやき /炭火焼/炭火焼き/
すみぶくろ /墨袋/
すみぶと /墨太/
すみません /済みません/
すみむね /隅棟;[建築]寄棟 >―< での > と < にあたる棟/
すみもと /住本/住元/
すみや /角屋/隅谷/住谷/墨屋/
すみやか /速やか/澄みやか/
すみやき /炭焼き/炭焼/
すみやきごや /炭焼き小屋/
すみよ /純代/
すみよう /住用/
すみよし /住吉/澄義/
すみよしえき /住吉駅/
すみよしがわ /住吉川/
すみよしじんじゃ /住吉神社/
すみよしだい /住吉台/
すみよしちょう /住吉町/
すみよしづくり /住吉造り;[建築]/住吉造;[建築]/
すみよしものがたり /住吉物語/
すみれ /菫/
すみれいろ /菫色/
すみれもく /スミレ目/Violales/
すみわけ /棲み分け/
すめかみ /皇神/
すめがみ /皇神/
すめし /酢飯/
すめらぎ /天皇/皇/
すめん /素面/
すもう /相撲/角力/
すもうかい /相撲界/
すもうきょうかい /相撲協会/
すもうけん /相撲券/
すもうじんく /相撲甚句/
すもうせんしゅけん /相撲選手権/
すもうちゅうけい /相撲中継/
すもうぢゃや /相撲茶屋/
すもうとり /相撲取り/相撲取/相撲とり/
すもうにんき /相撲人気/
すもうば /相撲場/
すもうぶ /相撲部/
すもうべや /相撲部屋/
すもうもじ /相撲文字/
すもぐり /素潜り/
すもと /洲本/栖本/須本/
すものがたり /素物語/
すもも /李/酸桃/
すもん /守門/
すや /須屋/
すやき /素焼き;biscuit. 「-の器,-鉢」/素焼/
すやま /陶山/巣山/須山/隅山/
すよう /須要/
すら /／/
すらいどせい /スライド制/
すらっしゅ /／/
すらむか /スラム化/
すらむがい /スラム街/
すり /摺/刷/掏摸/修理/
すりあがり /刷り上がり/
すりあし /摺り足/
すりいろ /刷色/
すりえ /擂り餌/
すりかえ /掏り替え/すり替え/
すりがらす /磨りガラス/
すりきず /擦傷/擦り傷/
すりきり /擦り切り;計量カップ-一杯/擦切り/
すりこぎ /擂り粉木/擂粉木/摺子木/
すりこみ /刷り込み;[生物]imprinting/刷込み/
すりごま /擂り胡麻/
すりしき /修理職/
すりっとこう /スリット光/
すりっとぞう /スリット像/
すりつぶ /すり潰/
すりぬけ /すり抜け/
すりのかみ /修理大夫/
すりはく /摺箔/
すりばち /擂鉢/擂り鉢/摺鉢/すり鉢/
すりほん /刷本/
すりみ /摺身/擂り身/
すりむか /スリム化/
すりもの /刷り物/刷物/
する /駿/
するが /駿河/
するがぎんこう /駿河銀行/
するがだい /駿河台/
するがだいした /駿河台下/
するがばん /駿河版/
するがや /駿河屋/
するがわん /駿河湾/
するどさ /鋭さ/
するめ /鯣/
するめいか /鯣烏賊/するめイカ/
すれ /擦れ/
すれすれ /擦々/摩々/
すれちがい /擦れ違い/すれ違い/
すろうにん /素浪人/
すわ /諏訪/須羽/
すわおんせん /諏訪温泉/
すわこ /諏訪湖/
すわし /諏訪市/
すわじんじゃ /諏訪神社/
すわたいしゃ /諏訪大社/
すわちほう /諏訪地方/
すわっぷとりひき /スワップ取引/
すわとう /汕頭;(Swatow) 広東省の港湾都市/
すわない /諏訪内/
すわひりご /スワヒリ語;タンザニア・ケニアの公用語/
すわみなみ /諏訪南/
すわやま /諏訪山/
すわやり /魚条/楚割/
すわり /座り;-が悪い(=不安定)/
すわりかた /座り方/
すわりこみ /座り込み;sit-in (strike)/
すわりごこち /座り心地/
すん /寸/
すんいん /寸陰/
すんか /寸暇/
すんけい /寸勁/
すんげき /寸劇;skit/寸隙;-を縫って/
すんげん /寸言/
すんこく /寸刻/
すんごう /寸毫/
すんし /寸志/
すんしゃく /寸借/寸尺/
すんしゃくさぎ /寸借詐欺/
すんしゅう /駿州/
すんしょ /寸書/
すんしんしゃくたい /寸進尺退/
すんじ /寸時/
すんずん /寸寸/
すんぜん /寸前/
すんぜんしゃくま /寸善尺魔/
すんたらず /寸足らず/
すんだい /駿台/
すんだいがくえん /駿台学園/
すんだいせい /駿台生/
すんだいもし /駿台模試/
すんだん /寸断/
すんち /寸地/
すんづまり /寸詰まり/寸詰り/
すんてつ /寸鉄/
すんで /既/
すんとう /駿東/
すんど /寸土/
すんどめ /寸止め/
すんにーは /スンニー派/
すんには /スンニ派/
すんばとうじん /寸馬豆人/
すんひょう /寸評/
すんびょう /寸描/寸秒/
すんぴょう /寸評/
すんぶん /寸分/
すんぷ /駿府/
すんぷじょう /駿府城/
すんぽう /寸法/
すんぽうせん /寸法線/
すんぽうち /寸法値/
すんれつ /寸裂/
すんわ /寸話/
ず /図/頭/酢/圖;「図」の旧字/厨;(呉音)厨子/廚;「厨」の異体字/逗;(呉音)逗子/豆;(呉音)大豆/事;好事家/津;会津/鶴/寿;?/讐;(呉音) 復讐/讎;「讐」の異体字/Figure/
ず# /図#1/
ずあん /図案/
ずい /髄;骨の-/隋;中国の王朝(581-619)/随;随分/隨;「随」の旧字/隧;隧道(=トンネル)/膸;(背脂)/髓;「髄」の旧字/瑞;瑞兆/惴;(おそ・れる)/蕊;しべ/蘂;「蕊」の異体字1/蕋;「蕊」の異体字2/
ずいい /随意/
ずいいきん /随意筋/
ずいいけいやく /随意契約/
ずいいすじ /随意筋/
ずいいち /随一/
ずいいてきしょうひ /随意的消費/
ずいいん /随員/
ずいうん /瑞雲/瑞運/
ずいえき /髄液/
ずいえん /随縁/隋圜/
ずいおう /瑞応/
ずいかく /瑞鶴/
ずいかん /随感/
ずいき /随喜/芋茎/
ずいきまつり /瑞饋祭/芋茎祭/
ずいこう /随行/瑞光/
ずいこういん /随行員/
ずいしつ /髄質/
ずいしょ /随所/隋書;二十一史/隨處;旧字/
ずいしょう /瑞祥/
ずいじ /随時/
ずいじうけつけ /随時受付/
ずいじはっぴょう /随時発表/
ずいじゅう /随従/
ずいじゅん /随順/
ずいじょう /髄状/
ずいじん /随身/
ずいせい /瑞星;lucky star/
ずいせつ /瑞雪/
ずいせんじ /瑞泉寺/
ずいそう /随想/瑞相/
ずいそうしゅう /随想集/
ずいそうろく /随想録/
ずいだい /隋代/
ずいだん /随談/
ずいちょう /瑞兆/瑞鳥/
ずいどう /隧道/
ずいのう /髄脳/
ずいはん /随伴/
ずいはんしょくぶつ /随伴植物;[園芸]companion plants/
ずいひつ /随筆/隨筆;「随」旧字/
ずいひつか /随筆家/
ずいひつしゅう /随筆集/
ずいぶん /随分/隨分;「随」旧字/
ずいぶん> /随分/
ずいぶんいぜん /随分以前/
ずいぶんまえ /随分前/
ずいぶんむかし /随分昔/
ずいほうしょう /瑞宝章/
ずいほうでん /瑞鳳殿/
ずいまく /髄膜/
ずいまくえん /髄膜炎/
ずいむ /瑞夢/
ずいむし /螟虫/
ずいり /図入り/
ずうたい /図体/
ずえ /図絵;†≒図画/図会;†絵を集めたもの。「名所-」/
ずか /図化/
ずかい /図解/
ずかいしょ /図解書/
ずかん /図鑑/
ずかんそくねつ /頭寒足熱/
ずかんるい /図鑑類/
ずが /図画/
ずがい /頭蓋/
ずがいこつ /頭蓋骨/
ずがいこつこっせつ /頭蓋骨骨折/
ずがく /図学/
ずがら /図柄/
ずきょう /誦経/
ずきん /頭巾/
ずく /木菟;みみずく/尽く;納得-,欲得-/尽/
ずけ /付;※仮名遣い「づけ」/附;※仮名遣い「づけ」/
ずけい /図形/徒刑/◆/
ずけいきじゅつ /図形記述/
ずけいしゅつりょく /図形出力/
ずけいしょり /図形処理/
ずけいてき /図形的/
ずけいはいち /図形配置/
ずけいひょうじ /図形表示/
ずけいへんしゅう /図形編集/
ずけいもじ /図形文字/
ずけいようそ /図形要素/
ずけらん /瑞慶覧/
ずけん /図研/
ずこう /図工/頭光;「仏像の-」/頭香;荒行/図功/
ずこうしつ /図工室/
ずさくせい /図作成/
ずさん /杜撰/
ずざい /徒罪/
ずざん /杜撰/
ずし /図示/逗子;†地名,神奈川県/厨子;†棚の一種/寿司;(連濁)/鮨;(連濁)/図師/呪師/
ずしかいがん /逗子海岸/
ずしき /図式/
ずしきか /図式化/
ずしきてき /図式的/
ずしほうめん /逗子方面/
ずしゅう /豆州;伊豆/
ずしょ /図書/調所;人名/
ずしょうりゃく /図省略/
ずしょのかみ /図書頭/
ずしょりょう /図書寮/
ずしん /図心/
ずじ /図示/
ずじゅう /頭重/
ずじょう /頭上/図上/
ずせつ /図説/
ずぞう /図像/
ずぞうがく /図像学/
ずたずた /寸々/寸寸/
ずだ /頭陀/
ずだぎょう /頭陀行/
ずだけ /図竹;雅楽器の調律道具/
ずだぶくろ /頭陀袋/
ずだやくしゅ /喘息薬種;[植物]/
ずちゅう /図中/
ずつう /頭痛/
ずつうもち /頭痛持ち/
ずつうやく /頭痛薬/
ずつき /頭突き/
ずてき /図的/
ずどり /図取り/
ずのう /頭脳/図嚢/
ずのうしゅうだん /頭脳集団;think tank/
ずのうてき /頭脳的/
ずのうない /頭脳内/
ずのうは /頭脳派/
ずのうめいせき /頭脳明晰/
ずのうりゅうしゅつ /頭脳流出/
ずのうろうどう /頭脳労働;⇔肉体労働/
ずはん /図版/
ずばん /図版;ずはん/図番/
ずばんごう /図番号/
ずばんしゅう /図版集/
ずひょう /図表/
ずひょうばんごう /図表番号/
ずひょうるい /図表類/
ずふ /図譜/
ずぶぬれ /ずぶ濡れ/ズブ濡れ/
ずぶねり /頭捻り/
ずへい /図柄/
ずべこう /ズベ公/ずべ公/
ずほう /図法/修法/
ずぼし /図星/
ずぼんした /ズボン下/
ずぼんつり /ズボン吊り;suspender/
ずみ /済/桷/済み/濟;「済」の旧字/
ずめ /詰;※仮名遣い「づめ」/
ずめん /図面/
ずめんかんり /図面管理/
ずめんちょう /図面帳/
ずもう /相撲/
ずよう /図様/
ずり /刷/
ずりょう /受領/
ずろく /図録/
ずわいがに /ズワイ蟹/ずわい蟹/
ずわり /座り/
ずん /寸/
ずんどう /寸胴/
ずんどうなべ /寸胴鍋/
せ /世/背/瀬/施/畝;面積の単位(0.1段)/脊;≒背/勢;(呉音)/衰;(呉音)/畆;「畝」の異体字/丗;「世」の異体字/
せーぬ /塞納;Seine/折奴/
せーらーふく /セーラー服/
せあぶら /背脂/背油/
せい /生;life/性;sex/姓;surname/精/正/聖/制;制度/製;製造/世/所為;「君の-だ」/星/声/背/成/盛/斉/西/勢;勢力/政;政治/征;征服/整;整数/婿;むこ/青;青春/晴;晴天/静;安静/靜;「静」の旧字(人名用漢字)/請;申請/清;清浄/靖;靖国/鯖;さば/錆;さび/瀞;とろ/情;(漢音)風情/睛;画竜点睛/菁;(あおな)/蜻;蜻蛉/牲;犠牲/旌;はた/甥;おい/誠;誠実/筬;おさ/晟;あきら・か/逝;逝去/誓;誓願/醒;覚醒/惺;さと・る/腥;なまぐさ/齎;もたら・す/臍;へそ/擠;排擠/躋;のぼ・る/韲;なます/齏;「韲」の異体字/齊;「斉」の旧字(人名用漢字)/井;市井/穽;陥穽/栖;隠栖/棲;同棲/凄;凄絶/淒;「凄」の異体字/悽;悽惨/萋;草が繁るさま/嘶;いなな・く/撕;提撕/掣;掣肘/犀;さい/鉦;かね,しょう/省;反省/歳;歳暮/貰;もら・う/丗;「世」の異体字/聲;「声」の旧字/
せい#かくけい /正#3角形/
せい#かっけい /正#3角形/
せい> /正/聖;聖家族,聖少女,聖ペテロ/成;(adult) 成獣,成豚,成猫/静;(static) -電力,-力学/製;製管,製陶,製畳(せいじょう)/西/性/
せいあ /井蛙;井の中の蛙。井蛙不可以語於海/
せいあい /性愛;eros/聖愛;agape/
せいあく /性悪/
せいあくせつ /性悪説/
せいあつ /制圧/静圧;static pressure/
せいあん /成案/西安/
せいい /誠意/勢威/征夷/凄異/
せいいき /聖域/西域/声域/整域;[数学]integral domain/
せいいきせい /整域性/
せいいく /生育;大きくなる・する/成育;成長する・させる/
せいいくご /成育後/
せいいそう /正位相/
せいいたいしょうぐん /征夷大将軍/
せいいち /正位置/誠一/清一/精一/聖一/正一/誓一/誠市/
せいいちろう /誠一郎/清一郎/精一郎/晴一郎/
せいいっぱい /精一杯/精いっぱい/
せいいつ /斉一/
せいいぶつ /聖遺物/
せいいん /成因;factor/成員;member/正員;qualified member/
せいう /晴雨/
せいうけい /晴雨計;barometer/
せいうち /海象/
せいうん /星雲;nebula/青雲;青空、また高い官位。「-の志」/盛運;prosperity/
せいうんしゃ /星雲社;[出版社名]現・鳥影社/
せいうんしょう /星雲賞/
せいうんせいだん /星雲星団/
せいうんのこころざし /青雲の志/
せいうんまる /青雲丸/
せいえい /精鋭/清栄/盛栄/
せいえき /精液/
せいえつ /誠悦/凄咽/
せいえん /声援/製塩/西遠/正円/凄艶/
せいえんぎょう /製塩業/
せいおう /西欧/聖王/
せいおうがた /西欧型/
せいおうしょこく /西欧諸国/
せいおうじん /西欧人/
せいおうてき /西欧的/
せいおうぶんめい /西欧文明/
せいおうりゅう /西欧流/
せいおおぜき /正大関/
せいおん /静穏;calm/清音;⇔濁音/静音;[新語]音の静かな/声音/生温/整音;ピアノの-/正音/
せいおんか /静音化/
せいか /成果/精華/製菓/生花/青果/生家/聖歌/盛夏/聖火/清華/青花/生化;生化学/正課/精化/製靴/正価/聖化;sanctify/世家/正佳/西夏/声価/青華;=青花/成香/斉家;修身-/惺窩/正貨/
せいかい /正解/政界/盛会/青海/制海/精解/
せいかいいん /正会員/
せいかいけん /制海権/
せいかいさいへん /政界再編/
せいかいしゃ /正解者/
せいかいしょ /正楷書/
せいかいちず /政界地図/
せいかいらく /性快楽/
せいかいりつ /正解率/
せいかがく /生化学;biochemistry/性科学;sex science/
せいかがくか /生化学科/
せいかがくじてん /生化学辞典/
せいかがくてき /生化学的/
せいかがくてきしゅほう /生化学的手法/
せいかぎょう /製菓業/
せいかく /性格/正確/精確/製革/正格/政客/
せいかくいじょう /性格異常/
せいかくけいせい /性格形成/
せいかくげき /性格劇;(Fr)theatre de caractere/
せいかくしんだん /性格診断/
せいかくじょう /性格上/
せいかくせい /正確性/
せいかくせいじゅうし /正確性重視/
せいかくせってい /性格設定/
せいかくづけ /性格付/
せいかくてき /性格的/
せいかくむひ /正確無比/
せいかけん /製科研/
せいかさんぎょう /西華産業;[企業名]/
せいかしゅぎ /成果主義/
せいかじゅう /静荷重/
せいかぞく /聖家族;[キリスト教]Holy Family. イエス・マリア・ヨセフ/
せいかたい /聖歌隊/
せいかたんでん /臍下丹田/
せいかだい /聖火台/
せいかちょう /精華町/
せいかっこう /背格好/背恰好;=背格好/
せいかつ /生活/正割;[数学]sec/
せいかついしき /生活意識/
せいかつか /生活科/
せいかつかいご /生活介護/
せいかつかいぜんやく /生活改善薬/
せいかつかがく /生活科学/
せいかつかがくぶ /生活科学部/
せいかつかん /生活感/生活環/
せいかつかんきょう /生活環境/
せいかつかんけい /生活関係/
せいかつかんれん /生活関連/
せいかつかんれんじょうほう /生活関連情報/
せいかつがっこう /生活学校/
せいかつきはん /生活規範/
せいかつきばん /生活基盤/
せいかつきゅう /生活給/
せいかつきょういく /生活教育/
せいかつく /生活苦/
せいかつくうかん /生活空間/
せいかつけん /生活圏;biosphere/生活権;subsistence right/
せいかつこうどう /生活行動/
せいかつこうぼう /生活工房/
せいかつこんきゅう /生活困窮/
せいかつざっか /生活雑貨/
せいかつざんぎょう /生活残業/
せいかつし /生活史;life history/生活誌/
せいかつしえん /生活支援/
せいかつしえんいん /生活支援員/
せいかつしきん /生活資金/
せいかつしどう /生活指導/
せいかつしゃ /生活者/生活社;(企業名の一部)/
せいかつしゅう /生活臭/
せいかつしゅうかん /生活習慣/
せいかつしゅうかんびょう /生活習慣病/
せいかつしんじょう /生活信条/
せいかつじょう /生活上/
せいかつじょうきょう /生活状況/
せいかつじょうほう /生活情報/
せいかつすい /生活水/
せいかつすいじゅん /生活水準/
せいかつせかい /生活世界;Lebenswelt(独)/
せいかつせっけい /生活設計/
せいかつぜんぱん /生活全般/
せいかつたいど /生活態度/
せいかつてき /生活的/
せいかつとし /生活都市/
せいかつなど /生活等/
せいかつなん /生活難/
せいかつねんれい /生活年齢;chronological age/
せいかつは /生活派/
せいかつはいすい /生活排水/
せいかつひ /生活費/
せいかつひつじゅひん /生活必需品/
せいかつふうしゅう /生活風習/
せいかつふくし /生活福祉/
せいかつぶめん /生活部面/
せいかつほうしき /生活方式/
せいかつほごひ /生活保護費/
せいかつほごほう /生活保護法/
せいかつほしょう /生活保障/
せいかつぼうすい /生活防水/
せいかつめん /生活面/
せいかつようしき /生活様式;lifestyle/
せいかつようひん /生活用品/
せいかつりょく /生活力/
せいかつれっしゃ /生活列車/
せいかてん /成果展/
せいかな /正仮名/
せいかなし /成果無/
せいかぶつ /成果物/青果物/
せいかほうこくしょ /成果報告書/
せいかもじ /西夏文字/
せいかよう /製菓用/
せいかりれー /聖火リレー/
せいかん /生還/性感/精悍/静観/青函;青森・函館/星間/制汗/製缶;can making/製罐;=製缶/製管;pipe making/精管;[解剖]spermatic duct/清閑/西漢;=前漢/盛観/
せいかんうん /星間雲/
せいかんざい /制汗剤/
せいかんし /製管師/
せいかんせんしょう /性感染症;[医]sexually transmitted disease(STD)/
せいかんたい /性感帯/
せいかんとんねる /青函トンネル;青森-函館/
せいかんぶっしつ /星間物質/
せいかんぶんし /星間分子/
せいかんれんらくせん /青函連絡船/
せいかんろん /征韓論/
せいが /精華/清雅/星河;the Milky Way/聖画;icon/青蛾;火を恋う-/静臥/
せいがいは /青海波/
せいがいふ /聖骸布/
せいがく /声楽/星学;astrology/静学;statics/聖学/聖楽/声学/
せいがくいん /聖学院/
せいがくおんがく /声楽音楽/
せいがくか /声楽家/
せいがくきょく /声楽曲/
せいがくさくひん /声楽作品/
せいがくてき /静学的/
せいがくぶ /声楽部/
せいがん /請願;†petition.「都議会への-」/西岸/誓願;†vow.「四弘-」/晴眼;sighted.「-者」/正眼;-の構え/青眼;⇔白眼/制癌/制ガン/
せいがんきょうかいりゅう /西岸境界流/
せいがんけん /請願権/
せいがんざい /制癌剤/
せいがんしゃ /晴眼者/
せいがんじ /誓願寺;京都河原町横にある寺院/
せいき /世紀/正規/性器/生気;life/精気;spirit/精機;†精密機械/生起/盛期/西紀;西洋の紀元/製機;†機械の製造/精器;†精密機器/成樹;人名/正気/旌旗;色鮮やかなのぼり/青旗;酒屋の旗/成規;成文の規則/清規;[仏教]禅寺の生活規則/星紀;陰暦11月/聖記/制機/誠紀/盛基/
せいき> /正規;-軍,-商品,-表現/
せいきいぜん /世紀以前/
せいきうんちん /正規運賃/
せいきか /正規化/
せいきかかく /正規価格/
せいきかてい /生起過程/
せいきかりろん /正規化理論/
せいきかん /正帰還/
せいきがわ /正規側/
せいきき /性器期;[精医]genitale Phase (Freudの用語)/
せいききょくせん /正規曲線;[数学]normal curve. 正規分布の曲線/
せいきぐん /正規軍/
せいきけい /正規形/
せいきげんご /正規言語/
せいきこう /正規項/
せいきこうくうけん /正規航空券/
せいきこうはん /世紀後半/
せいきし /聖騎士/
せいきしゅうごう /正規集合/
せいきしょくいん /正規職員/
せいきじゅん /正規順/
せいきじゅんじょ /正規順序/
せいきすうはい /性器崇拝/
せいきせい /正規性/
せいきぞく /正規族/
せいきだいりてん /正規代理店/
せいきち /清吉/
せいきちょっこう /正規直交/
せいきちょっこうきてい /正規直交基底/
せいきちょっこうけい /正規直交系/
せいきてん /正規点/
せいきのう /性機能/
せいきばん /正規版/正規盤/
せいきひょうげん /正規表現/
せいきひょうげんけんさく /正規表現検索/
せいきひん /正規品/
せいきびょう /世紀病;[文化]mal du siecle/
せいきぶぶんぐん /正規部分群/
せいきぶんぷ /正規分布/
せいきほうていしき /正規方程式/
せいきまつ /世紀末/聖飢魔II/
せいきまつてき /世紀末的;fin de siecle.(欧州19世紀末のように)退廃的/
せいきゅう /請求/性急/制球/生休;生理休暇/
せいきゅうがく /請求額/
せいきゅうけん /請求権/
せいきゅうこう /請求項/
せいきゅうさき /請求先/
せいきゅうしゃ /請求者/
せいきゅうしょ /請求書/
せいきゅうしょるい /請求書類/
せいきゅうひょう /請求票/
せいきゅうほう /請求法/
せいきゅうりょく /制球力/
せいきゆにゅうしゃ /正規輸入車/
せいきゆにゅうもと /正規輸入元/
せいきょ /逝去/盛挙/
せいきょう /生協/盛況/正教;Orthodoxy.「ギリシャ-」/聖教;『-新聞』/精強/政教;政治と宗教。「-関係」/清興/生活協同組合/
せいきょういく /性教育/
せいきょうか /精強化/
せいきょうかい /正教会/
せいきょうしょくいん /生協職員/
せいきょうしょくどう /生協食堂/
せいきょうそうだいかい /生協総代会/
せいきょうそしき /生協組織/
せいきょうと /清教徒/正教徒/
せいきょうとかくめい /清教徒革命;[世界史](1640-60,イギリス)Puritan Revolution/
せいきょうぶんり /政教分離/
せいきょうり /盛況裡/
せいきょく /政局/正極/声曲/
せいきょくかい /制極界/
せいきらんすう /正規乱数/
せいきりょうきん /正規料金/
せいきろん /生気論/
せいきわりびき /正規割引/
せいきわりびきうんちん /正規割引運賃/
せいきん /生菌/精勤/
せいきんは /星菫派/
せいぎ /正義/性技;technique/性戯;play/生技;[略語]生産技術/精義/盛儀/西魏;[中国史](534-556)/声義/
せいぎかん /正義感;sense of justice/正義漢;man of justice/
せいぎけん /生技研/
せいぎしん /正義心/
せいぎぶ /生技部/
せいぎゃく /正逆/
せいぎょ /制御/成魚;adult fish/生魚;raw fish/制禦;=制御/井魚/
せいぎょう /生業;†なりわい。「塾講を-にする」/正業;†steady job.「-に就く」/盛業;†繁昌。「-中の店」/成業;†achieve.「学生の-」/聖業/
せいぎょか /制御化/
せいぎょかいろ /制御回路/
せいぎょかのう /制御可能/
せいぎょかんけい /制御関係/
せいぎょかんすう /制御関数/
せいぎょがい /制御外/
せいぎょき /制御機/制御器/
せいぎょきき /制御機器/
せいぎょきこう /制御機構/
せいぎょきのう /制御機能/
せいぎょぎじゅつ /制御技術/
せいぎょく /青玉/
せいぎょくどう /制御駆動/
せいぎょけい /制御系/
せいぎょけいたい /制御形態/
せいぎょけん /制御権/
せいぎょけんきゅう /制御研究/
せいぎょけんきゅうしつ /制御研究室/
せいぎょげんご /制御言語/
せいぎょこうがく /制御工学/
せいぎょこうがっか /制御工学科/
せいぎょこうぞう /制御構造/
せいぎょさんぎょう /制御産業/
せいぎょしき /制御式/
せいぎょしすてむ /制御システム/
せいぎょしつ /制御室/
せいぎょしゃ /制御車/
せいぎょしゅほう /制御手法/
せいぎょしんごう /制御信号/
せいぎょしんごうせん /制御信号線/
せいぎょじ /制御時/
せいぎょじかん /制御時間/
せいぎょじょうほう /制御情報/
せいぎょせん /制御線/
せいぎょせんりゃく /制御戦略/
せいぎょそうち /制御装置/
せいぎょそく /制御則/
せいぎょたいしょう /制御対象/
せいぎょたく /制御卓;console/
せいぎょたんし /制御端子/
せいぎょたんまつ /制御端末/
せいぎょてん /制御点/
せいぎょでんどうしゃ /制御電動車/
せいぎょどうさ /制御動作/
せいぎょにゅうりょく /制御入力/
せいぎょばん /制御盤/
せいぎょふごう /制御符号/
せいぎょふのう /制御不能/
せいぎょぶ /制御部/
せいぎょぶぶん /制御部分/
せいぎょぶん /制御文/
せいぎょへんすう /制御変数/
せいぎょほう /制御法/
せいぎょほうしき /制御方式/
せいぎょほうほう /制御方法/
せいぎょぼう /制御棒/
せいぎょめいれい /制御命令/
せいぎょもじ /制御文字/
せいぎょもんだい /制御問題/
せいぎょよう /制御用/
せいぎょりつ /制御率/
せいぎょりょう /制御量/
せいぎょりょういき /制御領域/
せいぎょりろん /制御理論/
せいぎょろん /制御論/
せいぎろん /正義論/
せいく /聖句/成句/
せいくう /制空/
せいくうけん /制空権/
せいくらべ /背比べ/
せいくん /正訓/請訓/
せいぐ /性具;大人のおもちゃ/
せいぐん /西軍/
せいけ /清家/
せいけい /整形/成形;†forming.「焼き物の-」/成型;†molding.「金型による-」/生計;「-を立てる」/政経/成蹊/西経;west longitude.「-142度」/星系/正経/正系;⇔傍系/
せいけいがた /成形型/
せいけいき /整形器/
せいけいぎじゅつ /成形技術/
せいけいげか /整形外科/
せいけいげかい /整形外科医/
せいけいげかしゅじゅつ /整形外科手術/
せいけいこうこう /成蹊高校/
せいけいしゅじゅつ /整形手術/
せいけいしゅつりょく /整形出力/
せいけいしょく /整形色/
せいけいだい /成蹊大/
せいけいだいがく /成蹊大学/
せいけいない /星系内/
せいけいひん /成形品/
せいけってい /性決定;[生物]sex determination/
せいけつ /清潔/
せいけつかん /清潔感/
せいけん /政権/生検;biopsy/聖剣/成犬/正拳/政見;-放送/聖賢;sages/精検;[略語]精密検査/制憲;憲法制定/生研;[略語]生物研究所/
せいけんか /政権下/
せいけんこうたい /政権交代/
せいけんこうやく /政権公約/
せいけんだつしゅ /政権奪取/
せいけんづき /正拳突き/
せいけんでんせつ /聖剣伝説/
せいけんとう /政権党/
せいけんほうそう /政見放送/
せいけんよとう /政権与党/
せいげん /制限/正弦/誓言;=せいごん/聖言;holy word/
せいげんいじょう /制限以上/
せいげんいない /制限以内/
せいげんかいじょ /制限解除/
せいげんかんすう /正弦関数;[数学]sine function/
せいげんきょくせん /正弦曲線/
せいげんくいき /制限区域/
せいげんけい /制限形/
せいげんこうそ /制限酵素/
せいげんこうもく /制限項目/
せいげんさいぼう /精原細胞;[生物]spermatogonium/
せいげんじかん /制限時間/
せいげんじこう /制限事項/
せいげんじゅうりょう /制限重量/
せいげんすう /制限数/
せいげんせんきょ /制限選挙;⇔普通選挙/
せいげんそくど /制限速度/
せいげんそくどいはん /制限速度違反/
せいげんそくどない /制限速度内/
せいげんそち /制限措置/
せいげんち /制限値/
せいげんていり /正弦定理;[数学]sine theorem/
せいげんてき /制限的/
せいげんてっぱい /制限撤廃/
せいげんない /制限内/
せいげんは /正弦波/
せいげんはしんごう /正弦波信号/
せいげんはてき /正弦波的/
せいげんわく /制限枠/
せいこ /聖子/西湖;地名,中国浙江省/
せいこう /成功/性向;†性質の傾向。「貯蓄-」/製鋼/精巧/性交/精工/性行;†性質と行い。「-不良」/正孔;[物理]electron hole/盛行/西郊/精鉱;mineral concentrate/生硬/生工/政綱;policy/精鋼;washed steel/正項/西行/清高/成稿/悽惶/星光/
せいこうい /性行為/
せいこういかんせんしょう /性行為感染症;[医](STD) 性病やAIDSなど/
せいこういご /成功以後/
せいこううき /晴好雨奇/
せいこううどく /晴耕雨読/
せいこうかくりつ /成功確率/
せいこうさく /成功作/
せいこうしゃ /成功者/
せいこうしょ /製鋼所/精工所/
せいこうしょう /性交渉/
せいこうしん /正更新/
せいこうじ /成功時/
せいこうじれい /成功事例/
せいこうだん /成功談/
せいこうとうてい /西高東低/
せいこうとうていがた /西高東低型/
せいこうどう /性行動/
せいこうほう /正攻法/
せいこうほうしゅう /成功報酬/
せいこうり /成功裏/成功裡/
せいこうりつ /成功率/
せいこうれい /成功例/
せいこく /正鵠/精穀;穀物の精白./
せいこつ /整骨/
せいこつし /整骨師/
せいこん /成婚/精魂;-込めて/聖痕/精根;-尽き果てる/
せいご /生後/正誤/成語/正吾/清吾/精吾/清悟/勢語/
せいごいちねん /生後一年/
せいごう /整合/正剛/正号;+/正合/
せいごうき /整合器/
せいごうせい /整合性/生合成/
せいごうてき /整合的/
せいごうはいれつ /整合配列/
せいごうほう /整合法/
せいごかくけい /正五角形/
せいごかっけい /正五角形/
せいごひょう /正誤表/
せいごぶん /正誤文/
せいごん /誓言/
せいさ /精査/性差/
せいさい /精細;fine/制裁/精彩;-を欠く/正妻/生彩;≒精彩/
せいさいきん /制裁金/
せいさいそち /制裁措置/
せいさいぼう /性細胞/精細胞/
せいさく /政策/制作;†create.「映画の-」/製作;†manufacture.「ラジオの-」/清作/精索/
せいさくいと /製作意図/
せいさくかがくか /政策科学科/
せいさくかだい /政策課題/
せいさくかつどう /制作活動/
せいさくかてい /制作過程/
せいさくがいしゃ /制作会社/製作会社/
せいさくがく /政策学/
せいさくがわ /制作側/製作側/
せいさくき /制作記/
せいさくきかん /制作期間/
せいさくきじ /製作記事/制作記事/
せいさくきんゆう /政策金融;policy finance. 各種公庫など/
せいさくけってい /政策決定/
せいさくげんば /製作現場/
せいさくこうい /制作行為/
せいさくしえん /政策支援/
せいさくしつ /制作室/
せいさくしゃ /製作者/制作者/
せいさくしゃがわ /製作者側/
せいさくしょ /製作所/
せいさくしんこう /制作進行/
せいさくじ /制作時/製作時/
せいさくじじょう /製作事情/
せいさくじゅん /製作順/
せいさくじょ /製作所/
せいさくじょう /政策上/製作上/
せいさくそうしき /制作総指揮/
せいさくたいせい /制作体制/製作体制/
せいさくたんとうしゃ /政策担当者/
せいさくたんとうひしょ /政策担当秘書/
せいさくちゅう /製作中/制作中/
せいさくちゅうし /製作中止/
せいさくちょさく /製作著作/
せいさくてき /政策的/
せいさくてんかん /政策転換/
せいさくとうかつかん /政策統括官/
せいさくとうしょ /製作当初/
せいさくとちゅう /製作途中/
せいさくはっぴょう /制作発表/
せいさくはんだん /政策判断/
せいさくひ /制作費;映画の-/製作費;部品の-/
せいさくひしょ /政策秘書/
せいさくひょうか /政策評価/
せいさくひょうめい /政策表明/
せいさくぶ /制作部/
せいさくへんこう /政策変更/
せいさくほうほう /製作方法/
せいさくもと /製作元/
せいさくりょう /製作料/
せいさくろんそう /政策論争/
せいさつ /省察/制札/精察;詳しく調べる/
せいさつよだつ /生殺与奪/
せいさべつ /性差別/
せいさん /生産/清算;†liquidate.「会社|過去を-する」/精算;†adjust.「運賃を-する」/凄惨/青酸;CN/制酸/聖餐;Sacrament/正餐;dinner/成算;chance/製産/悽惨;=凄惨/
せいさんかい /生産界/
せいさんかかく /生産価格/
せいさんかくけい /正三角形/
せいさんかくすい /正三角錐/
せいさんかじょう /生産過剰/
せいさんかっけい /正三角形/
せいさんかつどう /生産活動/
せいさんかてい /生産過程/
せいさんかり /青酸カリ;[化学]KCN. 毒薬の定番/青酸加里/
せいさんかんけい /生産関係;[経済]Produktionsverhaeltnisse (Marxの用語)/
せいさんかんすう /生産関数/
せいさんかんり /生産管理/
せいさんかんりょう /生産完了/
せいさんがいしゃ /清算会社/
せいさんがく /精算額/
せいさんき /精算機/
せいさんきすう /生産機数/
せいさんきばん /生産基盤/
せいさんきゅうし /生産休止/
せいさんきん /生産菌/
せいさんきんがく /精算金額/
せいさんぎじゅつ /生産技術/
せいさんぎじゅつぶ /生産技術部/
せいさんぎじゅつりょく /生産技術力/
せいさんぐち /清算口/
せいさんけいかく /生産計画/
せいさんけん /生産研/
せいさんこうがくぶ /生産工学部/
せいさんこうりつ /生産効率/
せいさんざい /生産財/
せいさんしき /聖餐式;[キリスト教]Communion/
せいさんしゃ /生産者/生産車/
せいさんしゃかかく /生産者価格/
せいさんしゅうりょう /生産終了/
せいさんしょ /精算書/
せいさんしょとく /清算所得/
せいさんじぎょうだん /清算事業団/
せいさんじょ /精算所/清算所/
せいさんすう /生産数/
せいさんせい /生産性/
せいさんせいぎじゅつ /生産性技術/
せいさんせつび /生産設備/
せいさんそしき /生産組織/
せいさんだいすう /生産台数/
せいさんだか /生産高/
せいさんだかひれいほう /生産高比例法/
せいさんだんかい /生産段階/
せいさんち /生産地/
せいさんちゅうし /生産中止/
せいさんてき /生産的/
せいさんにん /清算人/
せいさんねんれい /生産年齢;productive age/
せいさんひ /生産費/
せいさんひょう /精算表/清算表/
せいさんひん /生産品/
せいさんぶつ /生産物/
せいさんぶもん /生産部門/
せいさんぶん /精算分/
せいさんほうじん /清算法人/
せいさんようしき /生産様式/
せいさんようそ /生産要素/
せいさんらいん /生産ライン/
せいさんりょう /生産量/
せいさんりょく /生産力/
せいさんりれき /生産履歴/
せいざ /星座/正座/静座/静坐/正坐/
せいざい /製剤/製材/
せいざいかい /政財界/
せいざいかん /政財官/政・財・官/
せいざいしょ /製材所/
せいざうらない /星座占い/
せいざえもん /清左衛門/
せいざじょうたい /正座状態/
せいざず /星座図/
せいざはやみ /星座早見;天体観測のお供/
せいざぶろう /清三郎/征三郎/
せいざん /青山/
せいし /静止/生死/製紙/精子/制止/正視/正史;国家の著した歴史/製糸/清史/整枝/勢至/姓氏/誠史/聖史/青史/誓詞/正使/青紫/西施;人名,越の美女/静思/聖旨/誓紙/生歯/正矢;[数学]versine/西詩;西洋詩/
せいしえいせい /静止衛星/
せいしかい /静止解/
せいしかく /静止核/
せいしが /静止画/
せいしがぞう /静止画像/
せいしき /正式/清拭/整式/制式/
せいしきうらがき /正式裏書/
せいしきうんよう /正式運用/
せいしきかめい /正式加盟/
せいしきき /制式機/
せいしきけいやく /正式契約/
せいしきけってい /正式決定/
せいしきこうかい /正式公開/
せいしきこうにん /正式公認/
せいしきさいばん /正式裁判/
せいしきさいよう /正式採用/
せいしきしゅっか /正式出荷/
せいしきしゅもく /正式種目/
せいしきどう /静止軌道/
せいしきはっぴょう /正式発表/
せいしきばん /正式版/
せいしきぶんしょ /正式文書/
せいしきほっそく /正式発足/
せいしきめい /正式名/
せいしきめいしょう /正式名称/
せいしけい /静止系/
せいしげき /聖史劇;mystere/
せいしこうじょう /製紙工場/
せいしざひょう /静止座標/
せいしざひょうけい /静止座標系/
せいししつりょう /静止質量/
せいししょ /製紙所/製糸所/
せいしじょうたい /静止状態/
せいしちゅうしん /静止中心/
せいしつ /性質/声質/正室/
せいしつさ /性質差/
せいしつじょう /性質上/
せいしつりょう /性質量/正質量/
せいしでんい /静止電位;[生物]resting potential/
せいしぶったい /静止物体/
せいしぶつ /静止物/
せいしぼさつ /勢至菩薩/
せいしまさつ /静止摩擦/
せいしまさつけいすう /静止摩擦係数;[物理]F=μmg・cosθ の μ/
せいしまさつりょく /静止摩擦力/
せいしめんたい /正四面体/
せいしゃ /生者/斉射/精射/
せいしゃいん /正社員/
せいしゃえい /正射影/
せいしゅ /清酒/
せいしゅう /清秀/青州/勢州;伊勢/
せいしゅうき /性周期/
せいしゅく /静粛/星宿/静淑/整粛/静肅/
せいしゅん /青春/静瞬/
せいしゅんえいが /青春映画/
せいしゅんしょうせつ /青春小説/
せいしゅんじ /青春時/
せいしゅんじだい /青春時代/
せいしゅんへん /青春編/
せいしゅんものがたり /青春物語/
せいしょ /聖書/清書/誓書/成書/正書/青書/盛暑/整書/
せいしょう /斉唱/清祥/西湘/清勝/正賞;⇔副賞/政商/星章/精漿/制勝/精詳/
せいしょうき /西廂記/
せいしょうじ /斉唱時/
せいしょうどう /性衝動/
せいしょうなごん /清少納言/
せいしょうねん /青少年/
せいしょうねんかいかん /青少年会館/
せいしょうねんきょういく /青少年教育/
せいしょかいしゃく /聖書解釈/
せいしょかんけい /聖書関係/
せいしょがく /聖書学/
せいしょき /清書機/
せいしょく /生殖/聖職/青色/生食/声色/製織/生色/清色;⇔濁色/星蝕/
せいしょくいりょう /生殖医療/
せいしょくかくめい /生殖革命/
せいしょくき /生殖器/生殖期/
せいしょくきかん /生殖器官/
せいしょくぎじゅつ /生殖技術/
せいしょくこうい /生殖行為/
せいしょくこうぞう /生殖構造/
せいしょくこうどう /生殖行動/
せいしょくさいぼう /生殖細胞/
せいしょくし /生殖枝/
せいしょくしゃ /聖職者/
せいしょくせん /生殖腺/
せいしょくそう /生殖巣/
せいしょくのうりょく /生殖能力/
せいしょくもくてき /生殖目的/
せいしょけい /清書系/
せいしょしゃくぎ /聖書釈義/
せいしょほう /正書法/
せいしょよう /清書用/
せいしろう /誠志郎/
せいしん /精神/誠心/清心/清新/制振/聖心/西進/政審;政策審議/星辰/西晋;[中国王朝]/生新/誠信/成心/
せいしんあんてい /精神安定/
せいしんあんていざい /精神安定剤/
せいしんい /精神医/
せいしんいがく /精神医学/
せいしんいじょう /精神異常/
せいしんいじょうしゃ /精神異常者/
せいしんいぞん /精神依存/
せいしんえいせい /精神衛生/
せいしんえいせいじょう /精神衛生上/
せいしんか /精神科/精神化/
せいしんかい /精神科医/精神界/
せいしんかいちょう /政審会長/
せいしんかがく /精神科学;mental science/
せいしんかつどう /精神活動/
せいしんかん /正心館/
せいしんかんてい /精神鑑定/
せいしんかんのう /精神感応/
せいしんがく /精神学/
せいしんくうかん /精神空間/
せいしんげんしょう /精神現象/
せいしんこうぞう /精神構造/
せいしんし /精神史/
せいしんしっかん /精神疾患/
せいしんしゃ /青心社;[出版社名]www.seishinsha-online.co.jp/
せいしんしゅうちゅう /精神集中/
せいしんしゅぎ /精神主義/
せいしんしょうがい /精神障害;-者,-を持つ/
せいしんしょうがいしゃ /精神障害者/
せいしんしょうがいじ /精神障害児/
せいしんしょぼう /誠信書房/
せいしんしんけいしょう /精神神経症;[精医]psychoneurosis/
せいしんじょう /精神上/
せいしんじょうきょう /精神状況/
せいしんじょうたい /精神状態/
せいしんじょがくいん /聖心女学院/
せいしんじょしがくいん /聖心女子学院/
せいしんじょしだいがく /聖心女子大学/
せいしんすいじゃく /精神衰弱/
せいしんせい /精神性/
せいしんせいい /誠心誠意/
せいしんせいかつ /精神生活;inner life/
せいしんせかい /精神世界/
せいしんそくてい /精神測定/
せいしんちたい /精神遅滞;[精医]retardation/
せいしんちゅうおう /西神中央/
せいしんてき /精神的/
せいしんてきがいしょう /精神的外傷/
せいしんてきくつう /精神的苦痛/
せいしんてきけんこう /精神的健康/
せいしんてきこうか /精神的効果/
せいしんてきこうふん /精神的興奮/
せいしんてきしょうがい /精神的障害/
せいしんてきじゆう /精神的自由/
せいしんてきそんがい /精神的損害/
せいしんてきよゆう /精神的余裕/
せいしんとういつ /精神統一/
せいしんねんれい /精神年齢/
せいしんはくじゃく /精神薄弱/
せいしんはくじゃくしゃ /精神薄弱者/
せいしんはったつしょうがい /精神発達障害/
せいしんはついく /精神発育/
せいしんびょう /精神病/
せいしんびょういん /精神病院/
せいしんびょうかんじゃ /精神病患者/
せいしんびょうしつ /精神病質/
せいしんびょうしゃ /精神病者/
せいしんびょうり /精神病理/
せいしんびょうりがく /精神病理学/
せいしんぶつりがく /精神物理学;psychophysics/
せいしんぶんか /精神文化/
せいしんぶんせき /精神分析/
せいしんぶんせきい /精神分析医/
せいしんぶんせきか /精神分析家/
せいしんぶんせきがく /精神分析学/
せいしんぶんせきにゅうもん /精神分析入門/
せいしんぶんせきりょうほう /精神分析療法/
せいしんぶんせきりろん /精神分析理論/
せいしんぶんめい /精神文明/
せいしんぶんれつびょう /精神分裂病;NB:「統合失調症」に改称/
せいしんへんちょう /精神変調/
せいしんほけん /精神保健/
せいしんほけんふくしほう /精神保健福祉法/
せいしんほけんほう /精神保健法/
せいしんめん /精神面/
せいしんやく /精神薬/
せいしんりょうほう /精神療法/
せいしんりょく /精神力/
せいしんろん /精神論/
せいじ /政治/生時/青磁/正時/正字/盛時/製磁/斉次/盛事/政事/誠司;人名/誠二/誠治/清治/清二/清司/精二/清次/聖司/征治/青児/征二/聖二/征爾/成二/成治/征司/青嗣/征士/静二/整司/星史/聖次/斎次/
せいじいしき /政治意識/
せいじいろ /青磁色;celadon green/
せいじか /政治家/政治化;politicalise/
せいじかいかく /政治改革/
せいじかいけつ /政治解決/
せいじかくめい /政治革命/
せいじかだい /政治課題/
せいじかつどう /政治活動/
せいじかてい /政治過程/
せいじかん /政治観/
せいじがく /政治学/
せいじがくしゃ /政治学者/
せいじきかん /政治機関/
せいじきこう /政治機構/
せいじきょういく /政治教育/
せいじけいざいがく /政治経済学;political economics/
せいじけいたい /政治形態/
せいじけっしゃ /政治結社/
せいじけっちゃく /政治決着/
せいじけんきん /政治献金/
せいじけんりょく /政治権力/
せいじし /政治史/
せいじしきん /政治資金/
せいじしきんきせいほう /政治資金規正法/
せいじしゃかい /政治社会/
せいじしゅう /政治囚/
せいじしゅうだん /政治集団/
せいじしゅほう /政治手法/
せいじしゅわん /政治手腕/
せいじしょく /政治色/
せいじじょう /政治上/
せいじじょうきょう /政治状況/
せいじじょうほう /政治情報/
せいじせい /政治性;-の強いコメント/
せいじせいど /政治制度/
せいじせいめい /政治生命;political life/
せいじせきにん /政治責任/
せいじせんそう /政治戦争/
せいじそう /政治層/
せいじそしき /政治組織/
せいじたいせい /政治体制/
せいじだい /生時代/
せいじだんたい /政治団体/
せいじっすう /正実数/
せいじつ /誠実/凄日/
せいじてき /政治的/
せいじてきいみ /政治的意味/
せいじてきかつどう /政治的活動/
せいじてきぎろん /政治的議論/
せいじてきけんり /政治的権利/
せいじてきしゅほう /政治的手法/
せいじてきしんじょう /政治的信条/
せいじてきじょうきょう /政治的状況/
せいじてきたちば /政治的立場/
せいじてきはんだん /政治的判断/
せいじてきぶんみゃく /政治的文脈/
せいじてきもんだい /政治的問題/
せいじてきようそ /政治的要素/
せいじてきりゆう /政治的理由/
せいじてつがく /政治哲学/
せいじどうとく /政治道徳/
せいじなんみん /政治難民/
せいじは /静磁波/
せいじはん /政治犯/
せいじはんざい /政治犯罪/
せいじば /静磁場/
せいじばちゅう /静磁場中/
せいじひょう /政治評/
せいじひょうろんか /政治評論家/
せいじふうど /政治風土/
せいじふしん /政治不信/
せいじふはい /政治腐敗/
せいじぶもん /政治部門/
せいじぶんか /政治文化;political culture/
せいじほう /正字法;orthography/
せいじまんが /政治漫画/
せいじめん /政治面/
せいじもくてき /政治目的/
せいじもんだい /政治問題/
せいじもんだいか /政治問題化/
せいじゃ /聖者/正邪/
せいじゃく /静寂/
せいじや /政治屋/
せいじゅ /聖寿/誠樹/
せいじゅう /聖獣/成獣/西戎/
せいじゅうにめんたい /正十二面体/
せいじゅうろう /清十郎/
せいじゅく /成熟/
せいじゅくき /成熟期/
せいじゅくど /成熟度/
せいじゅくぶんれつ /成熟分裂/
せいじゅくらん /成熟卵/
せいじゅん /清純/正準/正順/
せいじゅんか /正準化/
せいじゅんけい /正準形/
せいじゅんこう /正準項/
せいじゅんは /清純派/
せいじゅんほうていしき /正準方程式/
せいじょ /聖女/整序;sort/聖所/成女;女性の成人/整除;exact division/正女;[律令制]21-60歳の女子/西序/
せいじょう /正常/清浄/性状;人や物の性質/性情;気立て/政情;political situation/成城/星状;stellate☆/星条;-旗/聖上;天子様/
せいじょうい /正常位/
せいじょううえ /正条植え/
せいじょうか /正常化/清浄化/
せいじょうかん /成城間/
せいじょうがくえん /成城学園/
せいじょうがくえんまえ /成城学園前/
せいじょうき /星条旗/
せいじょうきのう /正常機能/
せいじょうけい /正常系/
せいじょうさいぼう /正常細胞/
せいじょうざい /正常財;[経済]normal goods/
せいじょうしゃ /正常者/
せいじょうしゅうりょう /正常終了/
せいじょうせい /正常性/
せいじょうそしき /正常組織/
せいじょうたい /星状体/正常体/
せいじょうだい /成城大/
せいじょうだいがく /成城大学/
せいじょうち /正常値;normal value/
せいじょうどうさ /正常動作/
せいじょうはんいない /正常範囲内/
せいじょうふあん /政情不安/
せいじょうもう /星状毛/
せいじょしき /成女式/
せいじりょく /政治力/
せいじれい /正事例/
せいじろう /清次郎/征二郎/
せいじろん /政治論/
せいじん /成人/聖人/星人/西人;Espanol/
せいじんえいが /成人映画/
せいじんきょういく /成人教育/
せいじんくんし /聖人君子/
せいじんくんしゅ /聖人君主/
せいじんご /成人後/
せいじんしき /成人式/
せいじんしてい /成人指定/
せいじんじょし /成人女子/
せいじんじょせい /成人女性/
せいじんだんし /成人男子/
せいじんだんせい /成人男性/
せいじんのひ /成人の日;一月の第二月曜日/
せいじんびょう /成人病/
せいじんむけ /成人向け/
せいすい /盛衰/聖水/整水/清水/静水/精粋/
せいすいき /整水器/清水器/製水器/
せいすいし /盛衰史/
せいすいせき /青水石/
せいすう /整数;integer/正数;positive number/
せいすうかい /整数解/
せいすうがた /整数型/
せいすうけいかく /整数計画/
せいすうじ /整数次/
せいすうぜんたい /整数全体/
せいすうち /整数値/
せいすうばい /整数倍/
せいすうひ /整数比/
せいすうぶ /整数部/
せいすうぶぶん /整数部分/
せいすうへんかん /整数変換/
せいすうれつ /整数列/
せいすうろん /整数論/
せいすけ /誠亮/清助/
せいず /製図/星図/
せいずい /精髄/
せいずこう /製図工/
せいずだい /製図台/
せいずどうぐ /製図道具/
せいずばん /製図板/
せいせい /生成/精製/清々;気が-する/正々/生々/済々;多士-/済済/整正/西征/征西/整斉/正声/凄凄/悽悽/
せいせいえん /精製塩/
せいせいかく /生成核/
せいせいかつ /性生活/
せいせいかてい /生成過程/
せいせいかのう /生成可能/
せいせいがた /生成型/
せいせいき /生成器/
せいせいきこう /生成機構/
せいせいきそく /生成規則/
せいせいけい /生成系/
せいせいげん /生成元/
せいせいこうこう /悽悽惶惶/
せいせいさんさん /凄凄惨惨/
せいせいじ /生成時/
せいせいすい /精製水/
せいせいすう /正整数/生成数/
せいせいせつせつ /凄凄切切/
せいせいそく /生成則/
せいせいたこうしき /生成多項式/
せいせいだんめんせき /生成断面積/
せいせいてき /生成的/
せいせいどうどう /正々堂々/正正堂堂/
せいせいねつ /生成熱;[化学]heat of formation/
せいせいぶ /生成部/
せいせいぶつ /生成物/
せいせいぶんぽう /生成文法/
せいせいほう /生成法/
せいせいほうほう /生成方法/
せいせいまえ /精製前/
せいせいりつ /生成率/
せいせいりょう /生成量/
せいせいりょうりょう /凄凄涼涼/
せいせいるてん /生生流転/生々流転/
せいせいれい /生成例/
せいせき /成績/聖蹟/聖石/聖跡/
せいせきしょうめいしょ /成績証明書/
せいせきしょり /成績処理/
せいせきじゅん /成績順/
せいせきじょうい /成績上位/
せいせきていめい /成績低迷/
せいせきてき /成績的/
せいせきひょう /成績表/
せいせきふしん /成績不振/
せいせきべつ /成績別/
せいせきゆうしゅう /成績優秀/
せいせきゆうしゅうしゃ /成績優秀者/
せいせっかい /生石灰/
せいせつ /正接/正節/
せいせつかんすう /正接関数/
せいせつきょくせん /正接曲線/
せいせん /生鮮/聖戦/精選/清泉;清水/井泉;井戸(水)/性腺;[解剖]gonad/製銑/精線;wire/政戦;politics/征戦;「古来-幾人か回る」/聖遷;[イスラム]Hegirae/西遷;中共の-/成選/精銭;⇔悪銭/腥羶;なまぐさ/聖戰;「戦」旧字/
せいせんし /聖戦士/
せいせんしゅ /正選手/
せいせんしょくたい /性染色体/
せいせんしょくりょうひん /生鮮食料品/
せいせんじょしだい /清泉女子大/
せいせんじょしだいがく /清泉女子大学/
せいせんやさい /生鮮野菜/
せいぜい /精々;こんなもんが-だろ/精精/
せいぜつ /凄絶;ものすごい/悽絶;とても物哀しい/
せいぜつさ /凄絶さ/
せいぜん /整然/生前/正善/性善/西漸/凄然/井然/悽然/
せいぜんこうい /生前行為/
せいぜんしょぶん /生前処分/
せいぜんせつ /性善説/
せいぜんそう /生前葬/
せいそ /清楚/精粗/世祖/整礎;[数学]well-founded/凄楚;身に沁みてつらい/成素/
せいそう /清掃/正装;†formal dress.「-で列席する」/精巣/政争/星霜/成層/盛装;†(adorn)派手に着飾る。「-して遊びに行く」/正相/清爽/悽愴;凄まじくいたましい/凄愴;=悽愴/斉奏/
せいそういん /清掃員/
せいそうかざん /成層火山/
せいそうかつどう /清掃活動/
せいそうき /西廂記/
せいそうきょく /清掃局/
せいそうぎょう /清掃業/
せいそうぎょうむ /清掃業務/
せいそうけん /成層圏/
せいそうこうか /清掃効果/
せいそうこうじょう /清掃工場/
せいそうしゃ /清掃車/清掃者/
せいそうしょくいん /清掃職員/
せいそうじぎょう /清掃事業/
せいそうじむしょ /清掃事務所/
せいそうちゅう /清掃中/
せいそうねん /青荘年/
せいそうひ /清掃費/
せいそうひよう /清掃費用/
せいそうほうし /清掃奉仕/
せいそうようぐ /清掃用具/
せいそうようひん /清掃用品/
せいそく /生息;生物の-/正則/棲息;動物の-/栖息;=棲息/悽惻;悲しみ悼む/
せいそくいき /生息域/
せいそくか /正則化/
せいそくかんすう /正則関数/
せいそくきょくせん /正則曲線/
せいそくぎょうれつ /正則行列/
せいそくげん /正則元/
せいそくげんご /正則言語/
せいそくこう /正則項/
せいそくすう /生息数/
せいそくせい /正則性/
せいそくち /生息地/棲息地/
せいそくてき /正則的/
せいそくひょうげん /正則表現/
せいそくみつど /生息密度/
せいそんぽ /生損保;[略語]生命保険と損害保険(会社)/
せいぞう /製造/聖像/西蔵;地名,Tibet/清三/清蔵/誓三/
せいぞうかいしゃめい /製造会社名/
せいぞうかてい /製造過程/
せいぞうかんりぶ /製造管理部/
せいぞうがいしゃ /製造会社/
せいぞうがわ /製造側/
せいぞうき /製造機/
せいぞうぎじゅつ /製造技術/
せいぞうぎじゅつしゃ /製造技術者/
せいぞうぎじゅつぶ /製造技術部/
せいぞうぎょう /製造業/
せいぞうぎょうしゃ /製造業者/
せいぞうげんか /製造原価/
せいぞうこうじょう /製造工場/
せいぞうこうてい /製造工程/
せいぞうさき /製造先/
せいぞうしじしょ /製造指示書/
せいぞうしゃ /製造者/
せいぞうしゃせきにん /製造者責任/
せいぞうしゃめい /製造社名/
せいぞうしゅうりょうご /製造終了後/
せいぞうしょ /製造所/
せいぞうじ /製造時/
せいぞうじき /製造時期/
せいぞうじっしゅう /製造実習/
せいぞうじゅん /製造順/
せいぞうじょ /製造所/
せいぞうじょう /製造上/
せいぞうだんかい /製造段階/
せいぞうちゅう /製造中/
せいぞうちゅうし /製造中止/
せいぞうでんりょく /製造電力/
せいぞうぬし /製造主/
せいぞうねん /製造年/
せいぞうねんがっぴ /製造年月日/
せいぞうねんげつ /製造年月/
せいぞうはんばい /製造販売/
せいぞうはんばいもと /製造販売元/
せいぞうばんごう /製造番号/
せいぞうひ /製造費/
せいぞうび /製造日/
せいぞうぶ /製造部/
せいぞうぶつ /製造物/
せいぞうぶつせきにん /製造物責任/
せいぞうぶつせきにんほう /製造物責任法/
せいぞうほう /製造法/
せいぞうほうほう /製造方法/
せいぞうもと /製造元/
せいぞうりょう /製造量/
せいぞく /正続/聖俗/
せいぞろい /勢揃い/勢ぞろい/
せいぞん /生存/
せいぞんかくりつ /生存確率/
せいぞんきかん /生存期間/
せいぞんきょうそう /生存競争/
せいぞんけん /生存権/
せいぞんしゃ /生存者/
せいぞんじかん /生存時間/
せいぞんせい /生存性/
せいぞんほけん /生存保険;pure endowment/
せいぞんりつ /生存率/
せいた /背板/清田/清太/
せいたい /生態;†mode of life.「粘菌の-」/生体;†living body.「-解剖」/整体/声帯/成体;adult.「-ラット」/政体;regime/聖体;[キリスト教]host/静態;static/正対/臍帯/青黛/正体/
せいたいいしょく /生体移植/
せいたいかんきょう /生態環境/
せいたいかんさつ /生態観察/
せいたいがく /生態学/
せいたいけい /生態系;†ecosystem.「熱帯雨林の-」/生体系;†biologic system.「-と機械系」/
せいたいけいかんきょう /生態系環境/
せいたいけいぜんたい /生態系全体/
せいたいけん /性体験/生態研/
せいたいこう /西太后;(1835-1908)清末の摂政/
せいたいこうがく /生体工学/
せいたいこうぶんし /生体高分子/
せいたいざいりょう /生体材料/
せいたいし /整体師/
せいたいしょ /政体書/
せいたいじっけん /生体実験/
せいたいじば /生体磁場/
せいたいじょうほう /生体情報/
せいたいじょうほうがく /生体情報学/
せいたいじょうほうこうがく /生体情報工学/
せいたいじょうほうしょり /生体情報処理/
せいたいちょうさ /生態調査/
せいたいてき /生体的/
せいたいでんき /生体電気;bioelectricity/
せいたいでんし /生体電子/
せいたいない /生体内/
せいたいにんしょう /生体認証/
せいたいのうしゅく /生体濃縮/
せいたいは /声帯波/
せいたいはいりょう /聖体拝領/
せいたいはんのう /生体反応/
せいたいぶんし /生体分子/
せいたいへんか /生態変化/
せいたいほぞん /静態保存/
せいたいぼうぎょきこう /生体防御機構/
せいたいまく /生体膜/
せいたいもしゃ /声帯模写/
せいたか /背高;-のっぽ/
せいたかあわだちそう /背高泡立草/
せいたかくけい /正多角形/
せいたかっけい /正多角形/
せいたかのっぽ /背高のっぽ/
せいたく /請託/
せいためんたい /正多面体/
せいたろう /清太郎/
せいたん /生誕/西端/製炭/
せいたんきょく /聖譚曲;oratorio/
せいたんさい /聖誕祭/
せいだい /盛大/正大/聖代/
せいだく /清濁/
せいだん /星団/政談;政治の話/清談;世俗を離れた話/聖壇/
せいだんそう /正断層/
せいち /生地/聖地/精緻/整地/静置/正値/整治/正置/
せいちあんこう /生知安行/
せいちく /成竹;計画/
せいちじゅんれい /聖地巡礼;サドゥーの-/
せいちせい /正値性/
せいちゃ /製茶/
せいちゃく /正着/正嫡/
せいちゃくりつ /生着率/
せいちゅう /成虫/正中/掣肘/誠忠/精虫/
せいちゅうしんけい /正中神経/
せいちゅうせん /正中線/
せいちゅうめん /正中面/
せいちょう /成長/生長;†(特に生物が)大きくなること/清澄/整腸/成鳥/政庁/政調;政策調査/正調/静聴;†静かに聴くこと/清聴;†聴いてくれること/声調;[言語]tone/性徴;第二次-/清朝;字体の一/正庁/整調;ボートの-/聖寵/清帳/清張;人名/
せいちょうかいちょう /政調会長/
せいちょうかてい /成長過程/
せいちょうかぶ /成長株/
せいちょうき /成長期/
せいちょうきどう /成長軌道/
せいちょうきょくせん /成長曲線/
せいちょうきろく /成長記録/
せいちょうご /成長後/
せいちょうさんぎょう /成長産業/
せいちょうざい /整腸剤/
せいちょうしじょう /成長市場/
せいちょうじょうきょう /成長状況/
せいちょうせい /成長性/
せいちょうせき /正長石;orthoclase/成長石/
せいちょうそくしん /生長促進/
せいちょうだんかい /成長段階/生長段階/
せいちょうつう /成長痛/
せいちょうてん /生長点/
せいちょうとじょう /成長途上/
せいちょうぶつ /成長物/
せいちょうぶん /成長分/
せいちょうほう /成長法/
せいちょうものがたり /成長物語/
せいちょうりつ /成長率/
せいちょうりょく /成長力/
せいつう /精通/
せいつうしゃ /精通者/
せいてい /制定/静定;†static/聖帝/正丁;[律令制]21-60歳の男子。課税対象/
せいていし /斉停止/
せいていじ /制定時/
せいていすう /整定数/
せいていち /正定値/
せいていほう /制定法/
せいていり /性定理/
せいてき /性的/静的/政敵/正嫡/清適/
せいてきかいせき /静的解析/
せいてきかんけい /性的関係/
せいてきがた /静的型/
せいてきぎゃくたい /性的虐待/
せいてきこうふん /性的興奮/
せいてきじゅうりょく /静的重力/
せいてきとうさく /性的倒錯;inversion,perversion/
せいてきへんすう /静的変数/
せいてきぼうりょく /性的暴力/
せいてきやくわりぶんたん /性的役割分担/
せいてきようそ /性的要素/
せいてきよくぼう /性的欲望/
せいてつ /製鉄/製鐵;「鉄」旧字/
せいてつぎょう /製鉄業/
せいてつしょ /製鉄所/製鐵所;「鉄」旧字/
せいてつじょ /製鉄所/
せいてん /晴天/聖典;holy book/正典;canon/青天;青空。「-の霹靂」/性典;sex manual/盛典;盛大な儀式/星点/征典;人名?/
せいてんいき /晴天域/
せいてんか /聖典化/
せいてんかん /性転換/
せいてんし /聖天子/
せいてんじ /晴天時/
せいてんたいせい /斉天大聖/
せいてんのへきれき /青天の霹靂/
せいてんはくじつ /青天白日/
せいてんはくじつき /青天白日旗;中国・国民党の旗/
せいてんりつ /晴天率/
せいでん /静電/正伝/正殿/聖伝/聖殿/井田/星電/
せいでんき /静電気/正電気/
せいでんきがく /静電気学/
せいでんきじょきょ /静電気除去/
せいでんきたいさく /静電気対策/
せいでんげん /正電源/
せいでんば /静電場/
せいでんゆうどう /静電誘導/
せいでんようりょう /静電容量/
せいと /生徒/成都;Chengdu/聖徒;saints/聖都;holy city/征途/星斗/
せいとう /政党/正当;†rightful.「-な主張」/正統;†orthodox.「-の後継者」/正答;correct answer/製糖;†suger production/精糖;†refined suger/製陶;†pottery/征討/青鞜/盛唐/征東/
せいとうか /正当化/
せいとうぎょう /製糖業/
せいとうぎょうむこうい /正当業務行為/
せいとうこうふきん /政党交付金/
せいとうしじ /政党支持/
せいとうしゅぎ /正統主義/
せいとうじゆう /正当事由/
せいとうじょ /製陶所/
せいとうせい /正当性;†(justice)法の-, (validity)議論の-/正統性;†(orthodoxy)後継者の-/
せいとうせいじ /政党政治/
せいとうた /性淘汰/
せいとうたんい /政党単位/
せいとうてき /正統的/
せいとうない /政党内/
せいとうないかく /政党内閣/
せいとうは /正統派/青鞜派;bluestocking/正当派;※「正統派」の誤り?/
せいとうほう /政党法/
せいとうぼうえい /正当防衛/
せいとうやじん /斉東野人/
せいとうりつ /正答率/
せいとうりゆう /正当理由/
せいとかい /生徒会/
せいとかいしつ /生徒会室/
せいとかいちょう /生徒会長/
せいとかいちょうせんきょ /生徒会長選挙/
せいとかんり /生徒管理/
せいとく /生得/聖徳/成徳/政徳/盛徳/
せいとくがくえん /成徳学園/
せいとくせつ /生得説/
せいとくたんだい /成徳短大/
せいとくてき /生得的/
せいとこころえ /生徒心得/
せいとしどう /生徒指導/
せいとしどうしつ /生徒指導室/
せいとじしん /生徒自身/
せいとじち /生徒自治/
せいとすう /生徒数/
せいとたち /生徒達/
せいとてちょう /生徒手帳/
せいとぼしゅう /生徒募集/
せいとん /整頓/
せいど /制度/精度/西土/
せいどいじょう /精度以上/
せいどう /聖堂/正道/制動/青銅/政道/正堂/生動/聖道/声道/精銅/
せいどういつせいしょうがい /性同一性障害;gender identity disorders(GID)/
せいどうかじゅう /制動荷重/
せいどうかん /制動感/
せいどうき /青銅器/制動機/
せいどうきじだい /青銅器時代/
せいどうきょり /制動距離/
せいどうけいじょう /声道形状/
せいどうこうか /制動効果/
せいどうちゅう /制動中/
せいどうちょう /声道長/
せいどうとう /制動灯/
せいどうとく /性道徳/
せいどうにゅう /制導入/
せいどうほうしゃ /制動放射/
せいどうほうしゃせん /制動放射線/
せいどうよう /制動用/
せいどうりょく /制動力/
せいどか /制度化/制度下/
せいどく /精読/西独/
せいどこうじょう /精度向上/
せいどしゃ /青土社;[出版社名]雑誌『現代思想』。www.seidosha.co.jp/
せいどじたい /制度自体/
せいどじっしご /制度実施後/
せいどじょう /制度上/
せいどてき /制度的/
せいどひはん /制度批判/
せいどみなおし /制度見直し/
せいどみにこ /聖ドミニコ/
せいどみにこがくえん /聖ドミニコ学園/
せいどめん /制度面/
せいどもんだい /制度問題/
せいどん /晴曇/
せいなる /聖なる/
せいなん /西南/勢南/
せいなんがくいんだいがく /西南学院大学/
せいなんせい /西南西/
せいなんせんそう /西南戦争;1877/
せいなんだい /西南大/
せいなんにほん /西南日本/
せいなんぶ /西南部/
せいにく /精肉/
せいにくてん /精肉店/
せいにじゅうめんたい /正二十面体/
せいにゅう /生乳/
せいねい /西寧/
せいねいてんのう /清寧天皇/
せいねん /青年/成年/生年/盛年/
せいねんかいがいきょうりょくたい /青年海外協力隊;JICA/
せいねんかいぎ /青年会議/
せいねんかん /青年館/
せいねんがっこう /青年学校/
せいねんがっぴ /生年月日/
せいねんき /青年期/
せいねんざっし /青年雑誌/
せいねんし /青年誌/
せいねんしき /成年式/
せいねんしゃ /成年者/
せいねんしんりがく /青年心理学/
せいねんじだい /青年時代/
せいねんだん /青年団/
せいねんだんし /成年男子/青年男子/
せいねんぶ /青年部/
せいねんまんが /青年漫画/
せいの /清野/
せいのう /性能/西濃/
せいのうあんていせい /性能安定性/
せいのううんゆ /西濃運輸/
せいのうかいぜん /性能改善/
せいのうきょくせん /性能曲線/
せいのうきょくせんず /性能曲線図/
せいのうこうじょう /性能向上/
せいのうさ /性能差/
せいのうしょげん /性能諸元/
せいのうじょう /性能上/
せいのうじょうけん /性能条件/
せいのうそくてい /性能測定/
せいのうち /性能値/
せいのうていか /性能低下/
せいのうてき /性能的/
せいのうとくせい /性能特性/
せいのうはっき /性能発揮/
せいのうひ /性能比/
せいのうひかく /性能比較/
せいのうひょう /性能表/
せいのうひょうか /性能評価/
せいのうひょうかけっか /性能評価結果/
せいのうひょうじ /性能表示/
せいのうぶそく /性能不足/
せいのうほしょう /性能保証/
せいのうめん /性能面/
せいのうようきゅう /性能要求/
せいのうれっか /性能劣化/
せいのすけ /誠之助/
せいは /制覇/
せいはい /聖杯/成敗;成功と失敗/儕輩;同輩/
せいはく /精白;polish/精薄;[略語]精神薄弱/清白;pure/製箔/生魄/
せいはくしょく /青白色/
せいはくじ /青白磁/
せいはくぶあい /精白歩合/
せいはくまい /精白米/
せいはご /制覇後/
せいはちめんたい /正八面体/
せいはつ /整髪/
せいはつざい /整髪剤/
せいはつりょう /整髪料/
せいはん /製版/整版;版木を彫る印刷方法/正犯;⇔従犯/正反/
せいはんごう /正反合/
せいはんざい /性犯罪/
せいはんざいしゃ /性犯罪者/
せいはんしゃ /正反射;[光学]⇔乱反射/
せいはんたい /正反対/
せいはんぼん /整版本/
せいばい /成敗/
せいばく /精麦/
せいばつ /征伐/
せいばん /製番/
せいぱん /製パン/
せいひ /成否;成功・不成功/正否;正誤,正不正/性比/西彼;地名/西肥/正妃/正比/青皮/政費/請罷/
せいひこ /聖彦/
せいひつ /静謐/聖櫃/省筆/
せいひょう /製氷/星表/製表/青票;反対票。⇔白票/旌表/
せいひょうい /生標委/
せいひょうき /製氷機/製氷器/
せいひょうげん /性表現/
せいひょうこ /製氷庫/
せいひょうざら /製氷皿/
せいひょうしつ /製氷室/
せいひれい /正比例/
せいひん /製品/清貧/精品;fine goods/正賓/
せいひんいがい /製品以外/
せいひんか /製品化/
せいひんかいはつ /製品開発/
せいひんかいはつじ /製品開発時/
せいひんかいはつぶ /製品開発部/
せいひんかいりょう /製品改良/
せいひんかがくけんきゅうしょ /製品科学研究所/
せいひんかん /製品間/
せいひんかんり /製品管理/
せいひんきょうそうりょく /製品競争力/
せいひんごと /製品毎/
せいひんしょうかい /製品紹介/
せいひんしよう /製品仕様/
せいひんじょうほう /製品情報/
せいひんぜんたい /製品全体/
せいひんてんじ /製品展示/
せいひんばん /製品版/
せいひんばんごう /製品番号/
せいひんひかく /製品比較/
せいひんひょうか /製品評価/
せいひんふりょう /製品不良/
せいひんめい /製品名/
せいひんれい /製品例/
せいび /整備/星美/精美/精微/
せいびいがい /整備以外/
せいびいん /整備員/
せいびか /整備科/
せいびかいせつしょ /整備解説書/
せいびかくちょう /整備拡張/
せいびがくえん /星美学園/
せいびき /正引き/
せいびきろくぼ /整備記録簿/
せいびぎょう /整備業/
せいびけいひ /整備経費/
せいびこう /整備工/
せいびこうじょう /整備工場/
せいびし /整備士/
せいびしきん /整備資金/
せいびしつ /整備室/
せいびしめんきょ /整備士免許/
せいびしょ /整備書/
せいびしんかんせん /整備新幹線/
せいびじぎょう /整備事業/
せいびじゅつ /整備術/
せいびじょうきょう /整備状況/
せいびじょうたい /整備状態/
せいびせい /整備性/
せいびたんとうしゃ /整備担当者/
せいびちゅう /整備中/
せいびちょう /整備長/
せいびづくえ /整備机/
せいびてちょう /整備手帳/
せいびてんけん /整備点検/
せいびとちゅう /整備途中/
せいびどうしゅっぱん /成美堂出版;[出版社名]/
せいびなど /整備等/
せいびひ /整備費/
せいびひよう /整備費用/
せいびふりょう /整備不良/
せいびへい /整備兵/
せいびほうしん /整備方針/
せいびょう /性病/聖廟/
せいびょうか /性病科/
せいびょうしゃ /性描写/
せいびよう /整備用/
せいふ /政府/正負/
せいふあん /政府案/
せいふいいん /政府委員;NB:1999年に廃止/
せいふう /清風/西風/
せいふうぞく /性風俗/
せいふぇろもん /性フェロモン;[生物]sex pheromone/
せいふかいはつえんじょ /政府開発援助;ODA/
せいふかん /政府間/政府館;†「万博の-」/
せいふかんけいしゃ /政府関係者/
せいふかんこうきょく /政府観光局/
せいふかんこうちょう /政府観光庁/
せいふかんこうぶつ /政府刊行物/
せいふかんしょうけんこうほけん /政府管掌健康保険/
せいふかんぶ /政府幹部/
せいふがわ /政府側/
せいふきかん /政府機関/
せいふく /制服;†uniform/征服;†conquer/整復/正副/清福/正服;†儀式用の礼服/
せいふくぐみ /制服組/
せいふくご /征服後/
せいふくしゃ /征服者/
せいふくすがた /制服姿/
せいふくちゃくよう /制服着用/
せいふくみんぞく /征服民族/
せいふくよく /征服欲/
せいふぐん /政府軍/
せいふけい /政府系/
せいふこうかん /政府高官/
せいふこうにん /政府公認/
せいふこうほう /政府広報/
せいふごう /正符号/
せいふしゅっし /政府出資/
せいふしゅのう /政府首脳/
せいふじみんとう /政府自民党/
せいふすじ /政府筋/
せいふせいめい /政府声明/
せいふせんようき /政府専用機;Air Force One/
せいふそしき /政府組織/
せいふたんきしょうけん /政府短期証券/
せいふちゅうすう /政府中枢/
せいふてんぷく /政府転覆/
せいふとうきょく /政府当局/
せいふどうし /政府同士/
せいふない /政府内/
せいふのしっぱい /政府の失敗;[経済]government failure/
せいふぶもん /政府部門/
せいふほしょうさい /政府保証債/
せいふまい /政府米/
せいふよとう /政府与党/
せいふより /政府寄り/
せいふん /製粉/
せいふんしょ /製粉所/
せいぶ /西部;western/西武;[企業名]/声部/
せいぶいけぶくろ /西武池袋/
せいぶいけぶくろせん /西武池袋線/
せいぶえん /西武園/
せいぶがわ /西武側/
せいぶきゅうじょう /西武球場/
せいぶけい /西武系/
せいぶけいさつ /西部警察/
せいぶけんせつ /西武建設;[企業名]/
せいぶげき /西部劇/
せいぶげきじょう /西武劇場/
せいぶしんじゅく /西武新宿/
せいぶしんじゅくえき /西武新宿駅/
せいぶしんじゅくせん /西武新宿線/
せいぶじどうしゃ /西武自動車;[企業名]/
せいぶせん /西武線/西武戦/
せいぶせんせん /西部戦線/
せいぶつ /生物/静物/
せいぶつか /生物科/
せいぶつかい /生物界/
せいぶつかがく /生物化学/生物科学/
せいぶつかがくけい /生物科学系/
せいぶつかがくてき /生物化学的/
せいぶつかがくへいき /生物化学兵器;BC兵器/
せいぶつかがっか /生物化学科/
せいぶつかん /生物間/生物観/
せいぶつかんけい /生物関係/
せいぶつかんれん /生物関連/
せいぶつが /静物画/
せいぶつがく /生物学/
せいぶつがくしゃ /生物学者/
せいぶつがくじてん /生物学辞典/生物学事典/
せいぶつがくじょせつ /生物学序説/
せいぶつがくせんこう /生物学専攻/
せいぶつがくてき /生物学的/
せいぶつがくてきげんしょう /生物学的現象/
せいぶつがくてきこんきょ /生物学的根拠/
せいぶつがくてきぶんせき /生物学的分析/
せいぶつけい /生物系/
せいぶつけん /生物圏;biosphere/生物研/
せいぶつこうがく /生物工学;biological engineering(BE)/
せいぶつしゃかい /生物社会/
せいぶつしゅ /生物種/
せいぶつしょり /生物処理/
せいぶつじょうほう /生物情報/
せいぶつじょうほうかがく /生物情報科学/
せいぶつじょうほうしょり /生物情報処理/
せいぶつそう /生物相/
せいぶつちりがく /生物地理学;biogeography/
せいぶつてき /生物的/
せいぶつどけい /生物時計/
せいぶつのうやく /生物農薬/
せいぶつぶ /生物部/
せいぶつぶつり /生物物理/
せいぶつぶつりがく /生物物理学/
せいぶつぶつりがくてき /生物物理学的/
せいぶつぶんかい /生物分解/
せいぶつへいき /生物兵器/
せいぶつや /生物屋/
せいぶてつどう /西武鉄道/
せいぶひゃっかてん /西武百貨店/
せいぶほんしゃ /西部本社/
せいぶやなぎさわえき /西武柳沢駅/
せいぶゆうらくちょうせん /西武有楽町線/
せいぶん /成分;ingredient/正文;official text/成文;†written.「-法」/精分/
せいぶんおん /成分音/
せいぶんか /成文化;codify/性分化;[生物]sex differentiation/
せいぶんかい /生分解/
せいぶんかいせい /生分解性/
せいぶんけいさん /成分計算/
せいぶんけんけつ /成分献血/
せいぶんけんぽう /成文憲法;written constitution/
せいぶんちょうせい /成分調整/
せいぶんどうしんこうしゃ /誠文堂新光社/
せいぶんひょう /成分表/
せいぶんひょうじ /成分表示/
せいぶんぴつえき /性分泌液/
せいぶんぶんせき /成分分析/
せいぶんほう /成文法/
せいぶんむちょうせい /成分無調整/
せいへい /生平/清平/精兵/静平/正兵/生兵/政柄/
せいへき /性癖/青碧/
せいへん /政変/正編/
せいへんか /聖変化;[キリスト教]consecration/
せいべえ /清兵衛;名/
せいべつ /性別;sex/聖別;consecration/生別;⇔死別/
せいほ /生保;[略語]生命保険/
せいほう /製法/西方;west/正法;正当な法/正方;square/青峰/
せいほうきょうかい /西方教会/
せいほうぎょうれつ /正方行列/
せいほうけい /正方形/
せいほうこう /正方向/
せいほうしょうけい /正方晶系;[化学]tetragonal system/
せいほうとっきょ /製法特許/
せいほく /西北/
せいほくせい /西北西/
せいほくぶ /西北部/
せいほしゅ /正捕手;[野球]レギュラーのキャッチャー/
せいほるもん /性ホルモン;[生物]sex hormone. 男性ホルモンと女性ホルモン/
せいほん /製本/正本/
せいほんき /製本機/製本噐/
せいほんじ /製本時/
せいほんのう /性本能/
せいほんや /製本屋/
せいぼ /歳暮/聖母/生母/声母/清保/
せいぼう /制帽/声望/
せいぼうりょく /性暴力;sexual violence/
せいぼさいぼう /精母細胞;[生物]spermatocyte/
せいぼし /聖母子;[キリスト教]Madonna and Child/
せいぼつ /生没/生歿;=生没/
せいぼつねん /生没年/生歿年;=生没年/
せいぼひしょうてん /聖母被昇天/
せいま /製麻/
せいまい /精米/
せいまいき /精米機/
せいまいご /精米後/
せいまいじ /精米時/
せいまいじょ /精米所/
せいまいぶあい /精米歩合/
せいまいほうほう /精米方法/
せいまく /成膜/
せいまさつ /静摩擦/
せいまさつけいすう /静摩擦係数/
せいみつ /精密/
せいみつか /精密化/
せいみつかがく /精密科学/
せいみつきかい /精密機械/
せいみつきき /精密機器/
せいみつけんさ /精密検査/
せいみつこうがく /精密工学/
せいみつこうがっか /精密工学科/
せいみつぶひん /精密部品/
せいみや /清宮/
せいみょう /精妙/
せいみん /済民/
せいむ /政務/世務/性夢/星霧;星雲/
せいむかん /政務官/
せいむじかん /政務次官/
せいむてんのう /成務天皇/
せいむにっか /聖務日課/
せいめい /生命/声明/姓名/清明;([二十四節気]4.5頃)/晴明;安倍-/性命;性質・生命/盛名;盛んな名声/声名;≒名声/
せいめいいじ /生命維持/
せいめいいじそうち /生命維持装置/
せいめいかがく /生命科学/
せいめいかつどう /生命活動/
せいめいかん /生命感/生命観/
せいめいがく /生命学/
せいめいけい /生命刑;死刑. cf.身体刑,自由刑/
せいめいけいたい /生命形態/
せいめいけん /生命研/生命工学工業技術研究所;※abbrev/
せいめいげんしょう /生命現象/
せいめいこうがく /生命工学/
せいめいこうがくこうぎょうぎじゅつけんきゅうしょ /生命工学工業技術研究所/
せいめいしょ /声明書/
せいめいしんか /生命進化/
せいめいせん /生命線/
せいめいたい /生命体/
せいめいはんだん /姓名判断/
せいめいひょう /生命表/
せいめいぶん /声明文/
せいめいほけん /生命保険/
せいめいほけんがいしゃ /生命保険会社/
せいめいほけんぎょうかい /生命保険業界/
せいめいほけんりょう /生命保険料/
せいめいりょく /生命力/
せいめいりんり /生命倫理/
せいめいろん /生命論/
せいめん /製麺/
せいもう /製網/性毛/
せいもく /井目;[囲碁]/
せいもくふうりん /井目風鈴/
せいもん /正門/声紋/誓文/声門/
せいもんおん /声門音;[音声学]glottal/
せいもんひだりて /正門左手/
せいもんまえ /正門前/
せいや /聖夜;Xmas/星夜;starry night/清夜/晴夜/征野;戦場/誠也;人名/星矢;[アニメ]聖闘士-/聖矢/生也/靖也/星谷/青夜/
せいやく /制約/製薬/成約/誓約/生薬;しょうやく/
せいやくがいしゃ /製薬会社/
せいやくがく /製薬学/
せいやくしょ /誓約書/
せいやくじこう /制約事項/
せいやくじゅうそく /制約充足/
せいやくじゅうそくもんだい /制約充足問題/
せいやくじょう /制約上/
せいやくじょうけん /制約条件/
せいやくつき /制約付き/
せいやくりつ /成約率/
せいやくろんり /制約論理/
せいやこう /星野光/
せいゆ /精油/製油/聖油/
せいゆう /声優/西友;[企業名]/西遊/清遊/
せいゆうかい /政友会;[日本史]立憲政友会/
せいゆうじん /声優陣/
せいゆうすとあー /西友ストアー/
せいゆしょ /製油所/
せいゆじょ /製油所/
せいよう /西洋/静養/整容/正用;⇔誤用/
せいよう> /西洋;-文明,-医学/
せいよういがく /西洋医学/
せいよういりょう /西洋医療/
せいようおんがく /西洋音楽/
せいようかがく /西洋科学/
せいようかぼちゃ /西洋南瓜/
せいようかん /西洋館/
せいようが /西洋画/
せいようがく /西洋学/
せいようがし /西洋菓子;洋菓子/
せいようがっき /西洋楽器/
せいようけい /西洋系/
せいようけん /精養軒/
せいようけんちく /西洋建築/
せいようご /西洋語/
せいようし /西洋史/西洋紙/
せいようしがく /西洋史学/
せいようしき /西洋式/
せいようしそう /西洋思想/
せいようじん /西洋人/
せいようてき /西洋的/
せいようてつがく /西洋哲学/
せいようてつがくし /西洋哲学史/
せいようてんもんがく /西洋天文学/
せいようなし /西洋梨;洋梨/
せいようびじゅつ /西洋美術/
せいようびじゅつかん /西洋美術館/
せいようふう /西洋風/
せいようぶんか /西洋文化/
せいようぶんめい /西洋文明/
せいようやさい /西洋野菜;セロリ・ブロッコリー・アスパラガスetc/
せいようりょうり /西洋料理/
せいようわがし /西洋和菓子/
せいよく /性欲/制欲/
せいら /聖良/
せいらい /生来/性来;≒生来(の性質) NB:副詞的には使わない/
せいらいてき /生来的/
せいらん /青嵐/晴嵐/青藍/青蘭/清覧/
せいり /整理/生理/
せいりかい /整理会/
せいりかいしゅうきこう /整理回収機構/
せいりかっせいぶっしつ /生理活性物質/
せいりがく /生理学/性理学;†=宋学/
せいりがくてき /生理学的/
せいりきがく /静力学/
せいりきこう /生理機構/
せいりきゅうか /生理休暇/
せいりけん /整理券/
せいりけんせい /整理券制/
せいりけんはっこうき /整理券発行機/
せいりけんばんごう /整理券番号/
せいりげんしょう /生理現象/
せいりしょくえんすい /生理食塩水/
せいりせいとん /整理整頓/
せいりだな /整理棚/
せいりちゅう /整理中/生理中/
せいりつ /成立/正立/声律/
せいりついぜん /成立以前/
せいりつう /生理痛/
せいりつかてい /成立過程/
せいりつかのう /成立可能/
せいりつご /成立後/
せいりつしき /正立式/
せいりつじ /成立時/
せいりつじてん /成立時点/
せいりつじょうけん /成立条件/
せいりつぞう /正立像/
せいりつねんがっぴ /成立年月日/
せいりつねんだい /成立年代/
せいりつはいけい /成立背景/
せいりつふせいりつ /成立不成立/
せいりつまえ /成立前/
せいりてき /生理的/
せいりてきけんお /生理的嫌悪/
せいりてきけんおかん /生理的嫌悪感/
せいりてきげんしょう /生理的現象/
せいりてきこうか /生理的効果/
せいりとうごう /整理統合/
せいりばんごう /整理番号/
せいりび /生理日/
せいりふじゅん /生理不順/
せいりぶもん /生理部門/
せいりほう /整理法/
せいりほうほう /整理方法/
せいりぽすと /整理ポスト;上場廃止銘柄が一時的に置かれるポスト/
せいりゃく /政略/
せいりゃくけっこん /政略結婚/
せいりゃくてき /政略的/
せいりや /整理屋/
せいりゅう /清流/整流;「-回路」/青龍/青竜/成龍/精留;「アルコールの-」/
せいりゅうき /整流器/整流機/
せいりゅうし /整流子/
せいりゅうとう /青竜刀/
せいりゅうばん /整流板/
せいりょ /征旅/
せいりょう /清涼/声量/星陵;†(こざと)/星稜;†(のぎへん)/青陵/清陵/精良/凄涼/凄寥/青龍/
せいりょういんりょう /清涼飲料/
せいりょういんりょうすい /清涼飲料水/
せいりょうかいかん /星陵会館/星陵会舘;異体字/
せいりょうかん /清涼感/
せいりょうざい /清涼剤/
せいりょうじ /清涼寺/
せいりょうだい /星陵台/
せいりょうちょう /星陵町/
せいりょうてき /声量的/
せいりょうでん /清涼殿/
せいりょく /勢力/精力/
せいりょくか /勢力下/
せいりょくきんこう /勢力均衡;power balance/
せいりょくけん /勢力圏/
せいりょくざい /精力剤/
せいりょくしょく /青緑色/
せいりょくず /勢力図/
せいりょくぜつりん /精力絶倫/
せいりょくぞうしん /精力増進/
せいりょくてき /精力的;vigorous/勢力的;勢力から判断して/
せいりょくはくちゅう /勢力伯仲/
せいりょくはんい /勢力範囲/
せいりよう /生理用/
せいりようひん /生理用品/
せいりん /青林/
せいりんしょいん /青林書院;[出版社名]www.seirin.co.jp/
せいりんどう /青林堂/
せいるい /生類/声涙/
せいれい /政令/精霊;spirit/聖霊;Holy Ghost/蜻蛉;とんぼ/聖隷/精励;-恪勤/生霊;いきりょう/制令/清麗/正例/悽戻/
せいれいかっきん /精励恪勤/
せいれいしていとし /政令指定都市/
せいれいしんこう /精霊信仰;aminism/
せいれいてん /聖礼典/
せいれいとし /政令都市/
せいれき /西暦/
せいれき#ねん /西暦#0年/西暦#1年/西暦#2年/西暦#3年/
せいれきなんねん /西暦何年/
せいれきねんがっぴ /西暦年月日/
せいれつ /整列;line up/清冽;limpid/星列/
せいれつかのう /整列可能/
せいれつこうか /整列効果/
せいれつじゅん /整列順/
せいれつほうほう /整列方法/
せいれん /精錬;金属の純度を高める/製錬;原料から金属を抽出する/精練;繊維から夾雑物を除く/清廉;「-潔白」/製練;?</
せいれんけっぱく /清廉潔白/
せいれんしょ /精錬所/
せいれんじこ /青蓮寺湖/
せいれんじょ /精錬所/
せいろ /蒸籠/征露/蒸篭;「籠」異体字/
せいろう /晴朗/蒸篭/蒸籠/聖篭/清朗/青楼/精蝋/
せいろがん /正露丸/征露丸/
せいろく /西麓/
せいろくめんたい /正六面体/
せいろっかくけい /正六角形/
せいろっかっけい /正六角形/
せいろん /正論/政論/
せいろんり /正論理/
せいわ /清和/西和/勢和/
せいわげんじ /清和源氏/
せいわだい /清和台/
せいわてんのう /清和天皇/
せう /召/抄/招/消/焼/焦/照/笑/紹/肖/詔/
せうお /瀬魚/
せお /瀬尾/妹尾/
せおい /背負/
せおいなげ /背負い投げ/
せおと /瀬音/
せおよぎ /背泳ぎ/
せかい /世界/
せかいいさん /世界遺産/
せかいいさんいいんかい /世界遺産委員会/
せかいいさんほごじょうやく /世界遺産保護条約/
せかいいち /世界一/
せかいいっしゅう /世界一周/
せかいいっしゅうりょこう /世界一周旅行/
せかいおうざ /世界王座/
せかいおうじゃ /世界王者/
せかいかいよう /世界海洋/
せかいかくこく /世界各国/
せかいかくち /世界各地/
せかいかっこく /世界各国/
せかいかようさい /世界歌謡祭/
せかいかん /世界観/
せかいきしょうきかん /世界気象機関;WMO/
せかいきぼ /世界規模/
せかいきゅうせいきょう /世界救世教/
せかいきょうこう /世界恐慌/
せかいきょうつう /世界共通/
せかいきろく /世界記録/
せかいぎんこう /世界銀行/
せかいくっし /世界屈指/
せかいけいざい /世界経済/
せかいこうぞう /世界構造/
せかいご /世界語/
せかいさいきょう /世界最強/
せかいさいこ /世界最古/
せかいさいこう /世界最高/
せかいさいこうそく /世界最高速/
せかいさいしょ /世界最初/
せかいさいしょう /世界最小/
せかいさいそく /世界最速/
せかいさいた /世界最多/
せかいさいだい /世界最大/
せかいさいちょう /世界最長/
せかいし /世界史/
せかいしじょう /世界市場/世界史上/
せかいしぜんいさん /世界自然遺産/
せかいしぜんほごききん /世界自然保護基金;www.wwf.org/
せかいしみん /世界市民/
せかいしゅうきょう /世界宗教/
せかいしゅぎ /世界主義/
せかいしょくりょうけいかく /世界食糧計画/
せかいしん /世界新/
せかいしんしゅつ /世界進出/
せかいじ /世界時/
せかいじたい /世界自体/
せかいじゅ /世界樹/
せかいじゅう /世界中/
せかいじょうせい /世界情勢/
せかいじんけんかいぎ /世界人権会議/
せかいじんけんせんげん /世界人権宣言/
せかいじんこうかいぎ /世界人口会議/
せかいじんるい /世界人類/
せかいせいさく /世界政策/
せかいせいしん /世界精神;[哲学]Weltgeist/
せかいせいは /世界制覇/
せかいせいふ /世界政府;world government/
せかいせいふく /世界征服/
せかいせいふくせんげん /世界征服宣言/
せかいせん /世界戦;†world war/世界選;†world title/世界線;†(相対論などの)world line/
せかいせんしゅけん /世界選手権/
せかいせんりゃく /世界戦略/
せかいぜんたい /世界全体/
せかいぜんど /世界全土/
せかいぞう /世界像/
せかいたいかい /世界大会/
せかいたいせん /世界大戦/
せかいだいきょうこう /世界大恐慌/
せかいちず /世界地図/
せかいちつじょ /世界秩序/
せかいちてきしょゆうけんきかん /世界知的所有権機関;WIPO/
せかいちゃんぴおん /世界チャンピオン/
せかいちょう /世界長/
せかいていこく /世界帝国/
せかいてき /世界的/
せかいてききぼ /世界的規模/
せかいとういつ /世界統一/
せかいどう /世界堂/
せかいない /世界内/
せかいないそんざい /世界内存在;[哲学]In-der-Welt-Sein/
せかいにっぽう /世界日報/
せかいにんしき /世界認識/
せかいはつ /世界初/
せかいはつとうさい /世界初搭載/
せかいひょうじゅん /世界標準/
せかいびじゅつぜんしゅう /世界美術全集/
せかいふうけい /世界風景/
せかいぶんがく /世界文学/
せかいぶんがくぜんしゅう /世界文学全集/
せかいへいきん /世界平均/
せかいへいわ /世界平和/
せかいほけんきかん /世界保健機関;WHO/
せかいぼうえき /世界貿易/
せかいぼうえききかん /世界貿易機関;WTO (World Trade Organisation)/
せかいもじ /世界文字/
せかいゆうすう /世界有数/
せかいりくじょう /世界陸上/
せかいりょこう /世界旅行/
せかっこう /背格好/背恰好;=背格好/
せがき /施餓鬼/
せがしら /瀬頭/
せがみ /瀬上/
せがれ /倅/伜/悴/
せがわ /瀬川/背革/瀬河/
せき /席/咳/積/責/籍/関/堰/隻;(船の数)/石/赤/瀬木/夕;一朝一夕/汐;潮汐/斥;斥力/析;分析/晰;明晰/淅/皙;白皙/蜥;蜥蜴(せきえき・とかげ)/績;実績/蹟;遺蹟/勣;≒績/磧;かわら/脊;脊髄/瘠;や・せる/蹐;跼蹐/鶺;鶺鴒/昔;むかし/惜;惜敗/藉;か・す(「籍」とは別)/跡;痕跡/迹;≒跡/裼/錫;すず/寂;寂寥/戚;親戚/碩;碩学/蹠;対蹠/跖;≒蹠/蓆;むしろ/螫;(虫が)さ・す/潟;かた/關;「関」の旧字/×;x,かける/威;戚?/晢;皙?/
せきあい /惜愛/
せきあく /積悪/
せきい /赤緯/赤衣/
せきいん /石印/
せきうち /関内/
せきうら /関浦/
せきうん /積雲/
せきえい /石英/隻影/
せきえん /積怨/
せきお /世紀夫/
せきおう /石黄;[鉱]orpiment/
せきか /石化/赤化/石果/
せきかえ /席替え/
せきかく /刺客/
せきかっしょく /赤褐色/
せきかわ /関川/
せきかん /石棺/
せきがい /赤外/
せきがいきゅうしゅう /赤外吸収/
せきがいこう /赤外光/
せきがいせん /赤外線/
せきがいせんさつえい /赤外線撮影/
せきがいせんしゃしん /赤外線写真/
せきがいせんほうしき /赤外線方式/
せきがいほうしゃ /赤外放射;IR/
せきがいりょういき /赤外領域/
せきがえ /席替え/
せきがきゅう /赤芽球/
せきがく /碩学/
せきがね /関金/
せきがはら /関ヶ原/関ケ原/
せきがわ /関川/
せきがん /赤岩/隻眼/
せきく /隻句/
せきくうかん /積空間/
せきぐち /関口/
せきぐん /赤軍/
せきこ /潟湖/
せきこう /赤光/積項/
せきこく /石斛;=せっこく/
せきご /隻語/
せきさい /積載/
せきさいかじゅう /積載荷重;live load/
せきさいじゅうりょう /積載重量/
せきさいせい /積載性/
せきさいのうりょく /積載能力/
せきさいぶつ /積載物/
せきさいぼう /石細胞/
せきさいりょう /積載量/
せきさく /脊索/
せきさくどうぶつ /脊索動物/
せきさん /積算/
せきざい /石材/
せきざいてん /石材店/
せきざわ /関沢/
せきし /積志;長年の志/赤子;人民/
せきしつ /石室/石質;lithic,stone type/赤漆/
せきしま /関島/
せきしゅ /隻手/
せきしゅう /石州;石見/
せきしゅうごう /積集合/∩/
せきしゅつ /析出/
せきしゅん /惜春/
せきしょ /関所/尺書/
せきしょう /石勝/
せきしょうし /赤松子/
せきしょうせん /石勝線/
せきしょく /赤色/
せきしょくかいてん /赤色回転/
せきしょくかいてんとう /赤色回転灯/
せきしょくきょせい /赤色巨星/
せきしょくけい /赤色系/
せきしょくこう /赤色光/
せきしょくてろ /赤色テロ/
せきしょくとう /赤色灯/赤色燈/
せきしょやぶり /関所破り/
せきしん /赤心/
せきじ /席次/昔時/
せきじつ /昔日/
せきじひょう /席次表/
せきじま /関島/
せきじゅう /石獣/石絨;asbestos/
せきじゅうじ /赤十字/
せきじゅうじしゃ /赤十字社/
せきじゅうじじょうやく /赤十字条約;ジュネーブ条約/
せきじゅん /席順/石筍/
せきじょ /石女/
せきじょう /席上/関城/関上/惜譲/
せきじょうし /赤縄子/
せきすい /積水/
せきすいかがくこうぎょう /積水化学工業;[企業名]/
せきすいはうす /積水ハウス;[企業名]/
せきすう /席数/隻数/
せきずい /脊髄/
せきずいえん /脊髄炎;[医]/
せきずいしょう /脊髄症/
せきずいしんけい /脊髄神経/
せきずいはんしゃ /脊髄反射/
せきずいろう /脊髄癆/
せきせい /石製/
せきせいひん /石製品/
せきせつ /積雪/赤雪/
せきせつき /積雪期/
せきせつじょうきょう /積雪状況/
せきせつじょうほう /積雪情報/
せきせつりょう /積雪量/
せきせつろ /積雪路/
せきせん /関銭/
せきぜん /関前/積善/寂然/
せきぜんかい /責善会/
せきそう /積層/
せきそうひん /積送品/
せきぞう /石像/石造/
せきぞく /石鏃/
せきた /関田/
せきたに /関谷/
せきたん /石炭/
せきたんがす /石炭ガス;coal gas/
せきたんがら /石炭殻/
せきたんき /石炭紀;[地質年代]Carboniferous.36700-28900万年前/
せきたんさん /石炭酸/
せきたんゆそう /石炭輸送/
せきだ /席駄/雪駄/
せきだい /席題/席代/
せきちく /石竹/
せきちくいろ /石竹色/
せきちゅう /脊柱/石柱/
せきちん /赤沈/
せきつい /脊椎/
せきついえん /脊椎炎;[医]/
せきついがわわんしょう /脊椎側湾症/
せきついこてい /脊椎固定/
せきついどうぶつ /脊椎動物/
せきづか /関塚/
せきてい /石庭/席亭/
せきてっこう /赤鉄鉱/
せきとう /石塔/
せきとり /関取/
せきど /関戸/
せきどう /赤道/
せきどうか /赤道下/
せきどうかいりゅう /赤道海流;equatorial current/
せきどうぎ /赤道儀/
せきどうちょっか /赤道直下/
せきどうはんけい /赤道半径/
せきどうはんりゅう /赤道反流;equatorial countercurrent/
せきどめ /咳止め;鎮咳剤/
せきにん /責任/
せきにんか /責任下/
せきにんかいひ /責任回避/
せきにんかん /責任感/
せきにんしゃ /責任者/
せきにんじゅうだい /責任重大/
せきにんじゅんびきん /責任準備金/
せきにんじょう /責任上/
せきにんたいせい /責任体制/
せきにんたんとう /責任担当/
せきにんついきゅう /責任追及/
せきにんてんか /責任転嫁/
せきにんねんれい /責任年齢;[法]満14歳以上/
せきにんのうりょく /責任能力/
せきにんのがれ /責任逃れ/
せきにんはんいない /責任範囲内/
せきにんばらい /責任払い/
せきにんぶんたん /責任分担/
せきにんほうき /責任放棄/
せきにんほけん /責任保険/
せきにんむのうりょくしゃ /責任無能力者/
せきにんもんだい /責任問題/
せきにんろんぎ /責任論議/
せきね /関根/
せきねつ /赤熱/
せきねん /積年/昔年/
せきの /関野/
せきのみや /関宮/
せきのやま /関の山/
せきはい /惜敗/
せきはいりつ /惜敗率/
せきはん /赤飯/
せきばく /寂寞/寂莫/
せきばらい /咳払い/
せきばん /石版;lithograph/石板;slate/石盤;=石板/
せきばんいんさつ /石版印刷/
せきばんが /石版画/
せきひ /石碑/
せきひつ /石筆/石櫃/
せきひん /赤貧/
せきふ /石斧/
せきふだ /席札/関札/
せきぶつ /石仏/
せきぶん /積分/石文/∫/∬/
せきぶんかいろ /積分回路/
せきぶんかのうせい /積分可能性/
せきぶんかん /積文館/
せきぶんかんすう /積分関数/
せきぶんがた /積分型/
せきぶんき /積分器/
せきぶんきごう /積分記号/
せきぶんけい /積分型/
せきぶんこうしき /積分公式/
せきぶんしき /積分式/
せきぶんち /積分値/
せきぶんていすう /積分定数/
せきぶんていり /積分定理/
せきぶんはんい /積分範囲/
せきぶんへんかん /積分変換/
せきぶんほう /積分法/
せきぶんほうていしき /積分方程式/
せきぶんろ /積分路/
せきぶんろん /積分論/
せきへい /積弊/
せきへき /赤壁/
せきへきのたたかい /赤壁の戦い;[三国志](208)/
せきへきのふ /赤壁賦;蘇軾/
せきべ /関部/
せきべつ /惜別/
せきほうたい /赤報隊/
せきほうへんい /赤方偏移/
せきほく /石北/
せきほくせん /石北線/
せきほくほんせん /石北本線/
せきほん /石本/
せきぼく /石墨/
せきまえ /関前;姓/
せきまち /関町/
せきみず /関水/
せきむ /責務/夕霧/
せきめ /関目/
せきめん /赤面/石綿/
せきめんきょうふしょう /赤面恐怖症/
せきめんし /石綿糸/
せきめんはい /石綿肺/
せきもと /関本/
せきもり /関守/
せきもん /責問/
せきもんけん /責問権/
せきや /関谷/関屋/
せきやきねん /関屋記念/
せきやど /関宿/
せきやま /関山/
せきゆ /石油/
せきゆいぞんど /石油依存度/
せきゆおう /石油王/
せきゆかかく /石油価格/
せきゆがいしゃ /石油会社/
せきゆがす /石油ガス;oil gas/
せきゆきき /石油危機/
せきゆきょうきゅう /石油供給/
せきゆぎょうかい /石油業界/
せきゆこうだん /石油公団/
せきゆしゅうえき /石油収益/
せきゆしょう /石油省/石油相;†大臣/
せきゆしょくぶつ /石油植物;石油代替の高エネルギー物質を算出する植物/
せきゆしょっく /石油ショック/
せきゆすとーぶ /石油ストーブ/
せきゆせいさん /石油生産/
せきゆせいせい /石油精製/
せきゆせいひん /石油製品/
せきゆぜい /石油税/
せきゆたんさ /石油探査/
せきゆゆしゅつこくきこう /石油輸出国機構;OPEC/
せきゆるい /石油類/
せきら /赤裸/
せきらら /赤裸々/赤裸裸/
せきらんうん /積乱雲/
せきり /赤痢/石理/
せきりつ /積率/
せきりゅう /石榴/
せきりょう /席料/寂寥/脊梁/責了/
せきりょうかん /寂寥感/
せきりょうさんみゃく /脊梁山脈/
せきりょく /斥力/赤緑/
せきりょくしきじゃく /赤緑色弱/
せきりょくしきもう /赤緑色盲/
せきりょくしょく /赤緑色/
せきりん /赤燐/
せきるい /石塁/
せきれい /鶺鴒/
せきれき /石礫/
せきろう /石蝋/
せきわ /積和/
せきわえんざん /積和演算/
せきわけ /関脇/
せきわけいか /関脇以下/
せきわん /隻腕/
せぎょう /施行/施業/
せぎょうほう /施業法/
せぎん /世銀/
せくしょん /§/
せくたすう /セクタ数/
せくとしゅぎ /セクト主義/
せぐち /瀬口/
せぐめんとか /セグメント化/
せぐめんとじょうほう /セグメント情報/
せけん /世間/
せけんいっぱん /世間一般/
せけんいっぱんてき /世間一般的/
せけんぎ /世間気/
せけんさま /世間様/
せけんし /世間師/
せけんしらず /世間知らず/
せけんじょうしき /世間常識/
せけんずれ /世間擦れ/
せけんち /世間知/世間智/
せけんてい /世間体/
せけんてき /世間的/
せけんなみ /世間並/
せけんばなし /世間話/
せこ /世故/瀬古/世古/瀬虎/
せこう /施工;工事の-/施行;法の-/
せこうかんり /施工監理/
せこうしえん /施工支援/
せこうじき /施行時期/
せこうず /施工図/
せこうせい /施工性/
せこうぬし /施工主/
せこうひ /施工費/
せこうび /施行日/
せこうほう /施工法/
せこうまえ /施行前/
せこうれい /施行令/施工例/
せこぐち /世古口/
せさい /世才/
せし /セ氏/
せしうむ /Cs/Cesium/
せしゅ /施主/
せしゅう /世襲/
せしゅうざいさん /世襲財産/
せしゅうせい /世襲制/
せじ /世事/世辞/
せじざい /世自在/
せじざいおうぶつ /世自在王仏/
せじゅつ /施術/
せじゅつしょ /施術所/
せじょう /施錠/世情/世上/
せじり /瀬尻/
せじん /世人/世塵/
せすじ /背筋/
せすなき /セスナ機;Cessna/
せせつ /世説;世説新語/
せせつしんご /世説新語;劉義慶/
せせらわらい /せせら笑い/
せぜ /世々/
せそう /世相/
せそうご /世相語/
せそうてき /世相的/
せそん /世尊/
せぞく /世俗/
せぞくか /世俗化/
せぞくしゅぎ /世俗主義/
せぞくてき /世俗的/
せた /瀬田/勢多/
せたい /世帯/世態/
せたいごと /世帯毎/
せたいすう /世帯数/
せたいすうひょう /世帯数表/
せたいにんじょう /世態人情/
せたいぬし /世帯主/
せたえきまえ /瀬田駅前/
せたか /瀬高/
せたがや /世田谷/
せたがやく /世田谷区/
せたがやくみん /世田谷区民/
せたがやせん /世田谷線/
せたがやだいた /世田谷代田/
せたがやびじゅつかん /世田谷美術館/
せたけ /背丈/
せたこうさてん /瀬田交差点/
せたな /瀬棚/
せだ /瀬田/
せだい /世代/
せだいかくさ /世代格差/
せだいかん /世代間/
せだいこうたい /世代交代/
せだいてき /世代的/
せだいめ /世代目/
せち /節/世知/世智/折/窃/褻/
せちえ /節会/
せちだ /雪駄/
せちばる /世知原/
せちみ /節忌/
せちょう /背丁/
せぢか /瀬近/
せっ /接/
せっか /石化/雪花/赤化/石火;電光-/石貨/接架/赤禍/
せっかい /石灰/切開/節介/石塊/雪塊/
せっかいか /石灰化;calcination.「骨の-」/
せっかいがん /石灰岩/
せっかいすい /石灰水/
せっかいせき /石灰石/
せっかいほう /切開法/
せっかく /折角/刺客/石槨/石核/切角/
せっかせっこう /雪花石膏/
せっかはんりゅう /折花攀柳/
せっかん /石棺/折檻/摂関/切換/
せっかんけ /摂関家/
せっかんじだい /摂関時代;藤原時代/
せっき /石器/節気/節季/赤旗/
せっきじだい /石器時代/
せっきゃく /接客/隻脚/
せっきゃくぎょう /接客業/
せっきゃくせつび /接客設備/
せっきゃくたいど /接客態度/
せっきょう /説教/説経;†経義を説くこと/
せっきょうしゃ /説教者/
せっきょうぶし /説経節/
せっきょく /積極/
せっきょくかかん /積極果敢/
せっきょくさく /積極策/
せっきょくざいさん /積極財産/
せっきょくしせい /積極姿勢/
せっきょくすいしん /積極推進/
せっきょくせい /積極性/
せっきょくてき /積極的/
せっきょくてきさんせい /積極的賛成/
せっきょくろん /積極論/
せっきん /接近/
せっきんせん /接近戦/接近戰;「戦」旧字/
せっきんそうぐう /接近遭遇/
せっく /節句/節供;=節句/隻句;片言-/
せっくつ /石窟/
せっけ /摂家/
せっけい /設計/雪渓/雪景/切形/雪溪;旧字/
せっけいか /設計課/設計家/
せっけいかいし /設計開始/
せっけいかいはつ /設計開発/
せっけいかいはつしゃ /設計開発者/
せっけいかいはつぶ /設計開発部/
せっけいがい /設計外/
せっけいがっか /設計学科/
せっけいきじゅつ /設計記述/
せっけいきじゅん /設計基準/
せっけいぎじゅつ /設計技術/
せっけいぎじゅつかいはつ /設計技術開発/
せっけいぎじゅつぶ /設計技術部/
せっけいけんきゅうしつ /設計研究室/
せっけいけんしょう /設計検証/
せっけいこうてい /設計工程/
せっけいし /設計士/
せっけいしえん /設計支援/
せっけいしき /設計式/
せっけいしそう /設計思想/
せっけいしだい /設計次第/
せっけいしつ /設計室/
せっけいしゃ /設計者/
せっけいしゅほう /設計手法/
せっけいしょ /設計書/
せっけいしょき /設計初期/
せっけいじ /設計時/
せっけいじてん /設計時点/
せっけいじむしょ /設計事務所/
せっけいじょう /設計上/
せっけいじょうけん /設計条件/
せっけいず /設計図/
せっけいせいさく /設計製作/
せっけいせいさん /設計生産/
せっけいせいず /設計製図/
せっけいせこう /設計施工/
せっけいたんい /設計単位/
せっけいだいいちぶ /設計第一部/
せっけいだんかい /設計段階/
せっけいち /設計値/
せっけいちゅう /設計中/
せっけいとしょ /設計図書/
せっけいにゅうもん /設計入門/
せっけいひ /設計費/
せっけいぶ /設計部/
せっけいぶもん /設計部門/
せっけいぶんしょ /設計文書/
せっけいへんこう /設計変更/
せっけいほう /設計法/
せっけいほうしん /設計方針/
せっけいほうほう /設計方法/
せっけいみす /設計ミス/
せっけいもくひょう /設計目標/
せっけいもじ /楔形文字/
せっけいよう /設計用/
せっけいようそ /設計要素/
せっけいりょう /設計料/
せっけいれい /設計例/
せっけいろん /設計論/
せっけっきゅう /赤血球/
せっけん /石鹸/席巻/接見/席捲/節倹/
せっけんえき /石鹸液/
せっけんこうじょう /石鹸工場/
せっけんすい /石鹸水/
せっけんせき /石鹸石/
せっけんせんざい /石鹸洗剤/
せっけんばこ /石鹸箱/
せっけんまく /石鹸膜/
せっこう /石膏;plaster/拙稿/斥候/拙攻;[スポーツ]まずい攻撃/浙江;Zhejiang/石工;mason/
せっこうぞう /石膏像/
せっこく /石斛/
せっこつ /接骨/
せっこつい /接骨医/
せっこついん /接骨院/
せっさ /切磋/
せっさく /切削/拙作/拙策/
せっさくこうぐ /切削工具/
せっさたくま /切磋琢磨/切瑳琢磨/
せっし /摂氏/切歯/窃視/℃/
せっし#ど /摂氏#0度/
せっし> /摂氏;Celsius/
せっしおんど /摂氏温度;摂氏,セ氏,Celsius/
せっしかた /接し方/
せっしゃ /接写/拙者/
せっしゃじ /接写時/
せっしやくわん /切歯扼腕/
せっしゅ /摂取;absorb/接種/窃取;steal/節酒/拙守;[スポーツ]まずい守備/截取;cut/
せっしゅう /接収/雪舟/摂州;摂津/
せっしゅご /接種後/摂取後/
せっしゅばしょ /接種場所/
せっしゅりつ /接種率/
せっしゅりょう /摂取量/
せっしょう /折衝/殺生/摂政/
せっしょうかい /殺生戒;[仏教]五戒の一つ/
せっしょうせき /殺生石/
せっしょく /接触/摂食/節食/接觸/
せっしょくあつ /接触圧/
せっしょくかんせん /接触感染/
せっしょくがた /接触型/
せっしょくしょうがい /摂食障害/
せっしょくじ /接触時/
せっしょくじこ /接触事故/
せっしょくていこう /接触抵抗/
せっしょくでんいさ /接触電位差/
せっしょくふりょう /接触不良/
せっしょくぶ /接触部/
せっしょくぶぶん /接触部分/
せっしょくめんせき /接触面積/
せっしょくりょういき /接触領域/
せっしん /切診/接心/
せっすい /節水/
せっせい /節制/摂生/拙生/摂制/
せっせん /接戦;close match/接線;tangent/折線;=おれせん/切線;=接線/雪線/雪山/
せっせんほうこう /接線方向/
せっそう /節操/切創/拙僧/節奏/拙走;[野球]まずい走塁/
せっそく /拙速/節足;-動物/
せっそくどうぶつ /節足動物/
せっそん /折損/
せった /雪駄/
せったい /接待/摂待/
せったいひ /接待費/
せったいよう /接待用/
せったく /拙宅/
せっち /設置/接地/
せっちあつ /接地圧/
せっちいち /設置位置/
せっちかもく /設置科目/
せっちかん /接地感/
せっちかんかく /設置間隔/
せっちきじゅん /設置基準/
せっちこうじ /設置工事/
せっちご /設置後/
せっちさぎょう /設置作業/
せっちしゃ /設置者/
せっちじゅんび /設置準備/
せっちじゅんびいいんかい /設置準備委員会/
せっちじょう /設置上/
せっちじょうけん /設置条件/
せっちじょうたい /設置状態/
せっちすう /設置数/
せっちせん /接地線/
せっちたい /接地帯/
せっちだいすう /設置台数/
せっちていこう /接地抵抗/
せっちてん /設置店/接地点/
せっちはば /接地幅/
せっちばしょ /設置場所/
せっちぶぶん /接地部分/
せっちほうほう /設置方法/
せっちほぞん /設置保存/
せっちめん /接地面/
せっちめんせき /接地面積/
せっちゃく /接着/
せっちゃくかしょ /接着箇所/
せっちゃくざい /接着剤/接着材/
せっちゃくぶ /接着部/
せっちゃくめん /接着面/
せっちゃくめんせき /接着面積/
せっちゃくりょく /接着力/
せっちゅう /折衷/雪中/折中/
せっちゅうあん /折衷案/
せっちゅうしゅぎ /折衷主義;eclecticism/
せっちゅうじ /接中辞;[言語]infix/
せっちゅうてき /折衷的/
せっちょ /拙著/
せっちょうしゅう /節用集/
せっちよてい /設置予定/
せっちよていち /設置予定地/
せっちん /雪隠/
せっつ /摂津/
せっついずみ /摂津和泉/
せっつう /切通/
せっつしき /摂津職/
せってい /設定/
せっていいがい /設定以外/
せっていか /設定可/
せっていかくにん /設定確認/
せっていかのう /設定可能/
せっていがめん /設定画面/
せっていきょうりょく /設定協力/
せっていぎょう /設定行/
せっていこうい /設定行為/
せっていこうもく /設定項目/
せっていご /設定後/
せっていさぎょう /設定作業/
せっていしだい /設定次第/
せっていしゃ /設定者/
せっていしりょう /設定資料/
せっていしりょうしゅう /設定資料集/
せっていじ /設定時/
せっていじかん /設定時間/
せっていじこく /設定時刻/
せっていじたい /設定自体/
せっていじょう /設定上/
せっていじょうきょう /設定状況/
せっていじょうたい /設定状態/
せっていすう /設定数/
せっていずみ /設定済み/
せっていち /設定値/
せっていちゅう /設定中/
せっていどうさ /設定動作/
せっていないよう /設定内容/
せっていなど /設定等/
せっていねんれい /設定年齢/
せっていふぁいる /設定ファイル/
せっていふび /設定不備/
せっていふりょう /設定不良/
せっていへんこう /設定変更/
せっていほう /設定法/
せっていほうほう /設定方法/
せっていよう /設定用/
せっていりゆう /設定理由/
せっていれい /設定例/
せってん /接点/節点/
せってんすう /節点数/
せってんふりょう /接点不良/
せってんめい /節点名/
せっとう /窃盗/接頭/竊盜/
せっとうこうい /窃盗行為/
せっとうご /接頭語/
せっとうざい /窃盗罪/
せっとうじ /接頭辞/
せっとうだん /窃盗団/
せっとうぶ /接頭部/
せっとく /説得/
せっとくざいりょう /説得材料/
せっとくじゅつ /説得術/
せっとくりょく /説得力/
せっとくりょくぶそく /説得力不足/
せっとはんばい /セット販売/
せっともの /セット物/
せっぱ /切羽/説破/
せっぱく /切迫/雪白/
せっぱくかん /切迫感/
せっぱくりゅうざん /切迫流産/
せっぱん /折半/
せっぴ /雪庇/切皮/
せっぴつ /拙筆/
せっぴょう /雪氷/
せっぷ /節婦;貞淑な女/雪膚;白いはだ/
せっぷう /雪風/
せっぷく /切腹/折伏/説伏/説服/
せっぷくもの /切腹物/
せっぷん /接吻/
せっぺん /切片/雪片/
せっぽう /説法/
せつ /説/節/雪/設;設備/切;切断/窃;窃盗/竊;「窃」の旧字/折;挫折/浙;浙江/晢;(あきらか)/接;内接/椄;(つぎき)/泄;排泄/渫;浚渫/紲;きずな/緤;=紲/絏;=紲/洩;(漢音) も・れる/摂;摂取/攝;「摂」の旧字(人名用漢字)/拙;稚拙/截;直截/殺;(呉音)殺生/刹;刹奈/啜;すす・る/楔;くさび/薛/褻;け/鱈;たら/屑;くず/卩;(ふしづくり)/§;section/晰;?/
せつあい /切愛/
せつい /褻衣/切意/
せついっさいうぶ /説一切有部/
せつえい /設営/雪影/拙詠/
せつえん /節煙/
せつお /節夫/節男/節雄/
せつかん /節間/
せつがい /雪害/
せつがん /接岸/接眼/切願/
せつがんぶ /接眼部/
せつがんれんず /接眼レンズ;eyepiece/
せつぎ /節義/拙技/
せつくうかん /接空間/
せつぐう /接遇/
せつけいしき /節形式/
せつけいもじ /楔形文字/
せつげつか /雪月花/
せつげん /節減/雪原/接舷/切言/
せつこ /節子/説乎/
せつこうぞう /節構造/
せつごう /接合/
せつごうし /接合子/
せつごうたい /接合体/
せつごうてん /接合点/
せつごうぶ /接合部/
せつごうようりょう /接合容量/
せつざん /雪山/
せつしゅうごう /節集合/
せつじ /説示/接辞/
せつじつ /切実/
せつじゅ /接受/
せつじゅつ /説述/
せつじょ /切除/
せつじょう /雪上/
せつじょうしゃ /雪上車/
せつじょうせいのう /雪上性能/
せつじょく /雪辱/
せつじょくせん /雪辱戦/
せつじょしゅじゅつ /切除手術/
せつじょじゅつ /切除術/
せつせつ /切々/切切/
せつぜい /節税/
せつぜん /截然/切前/
せつぞう /雪像/
せつぞく /接続/
せつぞくあいて /接続相手/
せつぞくあいてさき /接続相手先/
せつぞくえき /接続駅/
せつぞくか /接続可/
せつぞくかのう /接続可能/
せつぞくかのうせい /接続可能性/
せつぞくかんきょう /接続環境/
せつぞくかんけい /接続関係/
せつぞくき /接続器/
せつぞくきき /接続機器/
せつぞくきょうど /接続強度/
せつぞくきょく /接続局/接続曲;divertissement/
せつぞくぎょうしゃ /接続業者/
せつぞくけいたい /接続形態/
せつぞくけいやく /接続契約/
せつぞくけんさ /接続検査/
せつぞくご /接続語/接続後/
せつぞくさーびす /接続サービス/
せつぞくさき /接続先/
せつぞくさぎょう /接続作業/
せつぞくし /接続詞/
せつぞくしゃ /接続者/
せつぞくしょうがい /接続障害/
せつぞくしょり /接続処理/
せつぞくしんせい /接続申請/
せつぞくしんせいしょ /接続申請書/
せつぞくじ /接続時/
せつぞくじかん /接続時間/
せつぞくじっけん /接続実験/
せつぞくじっせき /接続実績/
せつぞくじゅんじょ /接続順序/
せつぞくじょうきょう /接続状況/
せつぞくじょうけん /接続条件/
せつぞくじょうたい /接続状態/
せつぞくじょうほう /接続情報/
せつぞくじょし /接続助詞/
せつぞくじれい /接続事例/
せつぞくすう /接続数/
せつぞくず /接続図/
せつぞくずみ /接続済/
せつぞくせい /接続性/
せつぞくせん /接続線/
せつぞくそくど /接続速度/
せつぞくたんし /接続端子/
せつぞくだいすう /接続台数/
せつぞくちゅう /接続中/
せつぞくてじゅん /接続手順/
せつぞくてん /接続点/
せつぞくばしょ /接続場所/
せつぞくびん /接続便/
せつぞくふかのう /接続不可能/
せつぞくぶ /接続部/
せつぞくぶひん /接続部品/
せつぞくほう /接続法/
せつぞくほうほう /接続方法/
せつぞくもう /接続網/
せつぞくよう /接続用/
せつぞくりょう /接続料/
せつぞくりょうきん /接続料金/
せつぞくれい /接続例/
せつぞくれっしゃ /接続列車/
せつたんい /節単位/
せつだい /設題/
せつだん /切断/截断/
せつだんじゅつ /切断術/
せつだんてん /切断点/
せつだんめん /切断面/
せつてん /節点/
せつでん /節電/
せつど /節度/
せつどう /摂動/雪洞/
せつどうけいさん /摂動計算/
せつどうこう /摂動項/
せつどうこうか /摂動効果/
せつどうほう /摂動法/
せつどうろん /摂動論/
せつな /刹那/
せつない /切ない/
せつなしゅぎ /刹那主義/
せつなしん /刹那心/
せつなてき /刹那的/
せつなん /摂南/
せつに /切に/
せつび /設備/接尾;suffix/折尾;?/
せつびかんり /設備管理/
せつびかんりしゃ /設備管理者/
せつびきき /設備機器/
せつびけいかく /設備計画/
せつびこうじ /設備工事/
せつびこうにゅう /設備購入/
せつびご /接尾語/
せつびしきん /設備資金;equipment fonds. ⇔運転資金/
せつびしせつ /設備施設/
せつびじ /接尾辞/
せつびじょうきょう /設備状況/
せつびぜんたい /設備全体/
せつびてき /設備的/
せつびとうし /設備投資/
せつびひ /設備費/
せつびひよう /設備費用/
せつびびひん /設備備品/
せつびびひんひ /設備備品費/
せつびぶ /設備部/
せつびりょうきん /設備料金/
せつぶん /節分/説文/拙文/
せつぶんさい /節分祭;鬼は外/
せつへいめん /接平面/
せつぼう /切望/
せつめい /説明/
せつめいいん /説明員/
せつめいえいぞう /説明映像/
せつめいかい /説明会/
せつめいかのう /説明可能/
せつめいきじ /説明記事/
せつめいきのう /説明機能/
せつめいぎむ /説明義務/
せつめいげんり /説明原理/
せつめいこう /説明項/
せつめいご /説明後/説明語;述語/
せつめいしょ /説明書/
せつめいしょあり /説明書有り/
せつめいしょつき /説明書付き/
せつめいしょなし /説明書無し/
せつめいしょるい /説明書類/
せつめいしりょう /説明資料/
せつめいじかん /説明時間/
せつめいず /説明図/
せつめいせきにん /説明責任/
せつめいてき /説明的/
せつめいふじゅうぶん /説明不十分/
せつめいふよう /説明不要/
せつめいぶ /説明部/
せつめいぶそく /説明不足/
せつめいぶん /説明文/
せつめいぶんしょ /説明文書/
せつめいぶんちゅう /説明文中/
せつめいほう /説明法/
せつめいほうほう /説明方法/
せつめいよう /説明用/
せつめん /雪面/接面/
せつめんどうろ /接面道路/
せつもん /設問/説文/
せつもんかいじ /説文解字/
せつもんしゃ /設問者/
せつや /摂也/
せつやく /節約/拙訳/
せつやくかのう /節約可能/
せつやくがく /節約額/
せつやくがた /節約型/
せつやくこうか /節約効果/
せつやくじゅつ /節約術/
せつやくぶん /節約分/
せつやくほうほう /節約方法/
せつゆ /説諭/
せつよう /節用/窃用/切要/
せつようしゅう /節用集/
せつようすい /雪溶水/
せつようもんじ /節用文字/
せつよく /節欲/
せつり /摂理;自然の-/節理/切離/
せつりつ /設立/
せつりついぜん /設立以前/
せつりつきねん /設立記念/
せつりつしゅいしょ /設立趣意書/
せつりつしゅし /設立趣旨/
せつりつじ /設立時/
せつりつじゅんび /設立準備/
せつりつそうかい /設立総会/
せつりつとうじ /設立当時/
せつりつりゆう /設立理由/
せつりゅう /設立/
せつれつ /拙劣/
せつろん /拙論/切論/
せつわ /説話/
せつわしゅう /説話集;今昔物語集、沙石集など/
せつわちょう /説話調/
せつわぶんがく /説話文学/
せと /瀬戸/
せとう /瀬藤/
せとうち /瀬戸内/
せとうちえんがん /瀬戸内沿岸/
せとうちさん /瀬戸内産/
せとうちじゃくちょう /瀬戸内寂聴/
せとうちちほう /瀬戸内地方/
せとえき /瀬戸駅/
せとおおはし /瀬戸大橋/
せとおおはしせん /瀬戸大橋線/
せとがらつ /瀬戸唐津/
せとぎわ /瀬戸際/
せとぎわがいこう /瀬戸際外交;brinkmanship/
せとぎわせいさく /瀬戸際政策;brinkmanship/
せとぐち /瀬戸口/
せとぐろ /瀬戸黒/
せとし /瀬戸市/
せとせ /瀬戸瀬/
せとせん /瀬戸線/
せとだ /瀬戸田/
せとちょう /瀬戸町/
せとないかい /瀬戸内海/
せともの /瀬戸物/
せど /背戸/
せどう /世道/
せどうか /旋頭歌/
せどうじんしん /世道人心/
せどり /背取り;†古書の転売/瀬取り;†積荷の小船への移し替え/競取り;†売買の中継ぎ/糶取り;†=競取り/
せどりぶね /瀬取り船/
せな /瀬女/
せなか /背中/
せなかあわせ /背中合わせ/背中合せ/
せなかがわ /背中側/
せなかぜんたい /背中全体/
せにく /背肉/
せにゅう /施入/
せぬき /背抜き/
せの /瀬野/
せのう /瀬能/
せのお /妹尾/
せのおえき /妹尾駅/
せのがわ /瀬野川/
せのきみ /背の君/
せのび /背伸び/背伸/
せはば /背幅/
せばた /瀬端/
せばんごう /背番号/
せひ /施肥/
せひょう /世評/
せびょうし /背表紙/
せびらき /背開き/
せびれ /背鰭/
せびろ /背広/
せびろくみ /背広組/
せびろぐみ /背広組/
せびろすがた /背広姿/
せびろふう /背広風/
せぴあいろ /セピア色/
せふ /妾/捷/渉/
せふり /背振/
せぶし /背節/
せぶみ /瀬踏み/
せぼね /背骨/
せま /瀬間/
せまきもん /狭き門/
せまめ /狭め/
せみ /蝉/
せみおれ /蝉折れ/
せみくじら /背美鯨;bowhead/
せみしぐれ /蝉時雨/
せみなーしつ /セミナー室/
せみね /瀬峰/
せみまる /蝉丸/
せむ /世務/
せむごぞく /セム語族;[言語]Semitic/
せむし /傴僂/
せむぞく /セム族;Semite/
せむら /瀬村/
せめ /攻め/責/責め/
せめあい /攻め合い/
せめぎあい /鬩ぎ合い/
せめく /責め苦/責苦/
せめくち /攻め口/
せめぐ /責め具/責具/
せめて /攻め手/
せめどうぐ /責め道具/
せめんとがわら /セメント瓦/
せめんとしつ /セメント質;[解剖]cementum/
せもじ /背文字/
せもたれ /背凭れ/背もたれ/
せもつ /施物/
せもん /背紋/
せや /瀬谷/
せやく /施薬/瀬谷区/
せやくいん /施薬院/
せやま /瀬山/
せゆう /施釉/
せよ /施与/
せら /世羅/世良/
せらにし /世羅西/
せり /競り/芹/競/糶;=競(り)/世利/
せりあげ /競上げ/
せりいち /競り市/
せりうむ /Ce/Cerium/
せりうり /競り売り/
せりか /芹香/セリ科/芹科;[植物]umbelliferae/
せりかわ /芹川/
せりざわ /芹沢/芹澤/
せりざわかも /芹沢鴨/
せりだし /迫り出し;舞台の-/
せりふ /台詞/科白/
せりふまわし /台詞回し/
せりもく /セリ目/Apiales/Umbelliflorae/
せりもち /迫持;(建築の)アーチ/
せりょう /施療/芹生/
せるが /セル画/
せれん /Se/Selenium/
せろ /世路/
せろん /世論/
せろんちょうさ /世論調査/
せわ /世話/
せわがかり /世話係/
せわた /背腸;エビの-を取る/
せわにん /世話人/
せわにんかい /世話人会/
せわびと /世話人/
せわもの /世話物/
せわやき /世話焼き/
せわやく /世話役/
せわり /背割/背割り/
せん /線/戦/栓/千/銭/専/船/先/尖;尖端/選/撰/饌;神饌/泉/腺;分泌腺/湶;「泉」の異体字/阡;「千」の大字/仟/川/巛;「川」の異体字/鮮;新鮮/蘚;こけ/癬;疥癬/洗;洗顔/銑;銑鉄/跣;跣足/筅;茶筅/筌;うえ/詮;所詮/痊;(いえる)/銓;銓衡/潜;潜航/僭;僭主/僣;僭越/潛;「潜」の旧字1/濳;「潜」の旧字2/仙;仙人/疝;疝気/遷;遷移/僊;≒仙/韆;鞦韆/占;占領/苫;とま/沾;うるお・う/煎;煎茶/箭;(arrow) 火箭/擶/揃;そろ・う/剪;剪定/翦;≒剪/扇;扇状地/煽;あお・る/蝉;せみ/嬋/戰;「戦」の旧字(人名用漢字)/闡;闡明/倩;つらつら/旃;あかはた/栴;栴檀/專;「専」の旧字(人名用漢字)/槫/甎;しきがわら/磚;≒甎/宣;宣言/亘;わた・る/瞻;瞻仰/贍;(たりる)/蟾;蟾蜍(ひきがえる)/譫;譫言/擅;擅断/氈;毛氈/羶;(なまぐさい)/顫;顫動/栫/荐/斬/槧/繊;繊維/纖;「繊」の旧字(人名用漢字)/纎;「繊」の旧字2/孅/殲;殲滅/殱;「殲」の異体字/籤;抽籤/籖;「籤」の異体字/浅;浅薄/淺;「浅」の旧字/濺;そそ・ぐ/箋;処方箋/牋;「箋」の異体字/綫;「線」の異体字/賤;賤業/賎;「賤」の異体字/践;実践/踐;「践」の旧字/錢;「銭」の旧字/餞;餞別/孱;孱弱/潺/僉;(みな)/簽;(かご)/舛/刋;(きる)/吮;(すう)/尠;すくな・い/暹/涎;垂涎/燹;(野火)/鐫;彫鐫/陝;陝西省/舩;「船」の異体字/茜;あかね/釧;くしろ/染;染料/旋;旋風/穿;穿鑿/羨;羨望/薦;推薦/閃;閃光/喘;喘息/銛;もり/
せん> /先;先言,先25日,先先先代(３代前)/千/
せんあえんこう /閃亜鉛鉱;sphalerite/
せんい /繊維/遷移/戦意/線維;(主に[生物][医]) ≒繊維/船医/瞻依;敬い従う/
せんいかくりつ /遷移確率/
せんいかてい /遷移過程/
せんいかんすう /遷移関数/
せんいき /戦域/
せんいきそく /遷移規則/
せんいぎょうれつ /遷移行列/
せんいさいぼう /繊維細胞;[生物]fiber cell/
せんいし /繊維糸/
せんいしつ /繊維質/
せんいじかん /遷移時間/
せんいじょう /繊維状/
せんいじょうたい /遷移状態/
せんいず /遷移図/
せんいそ /繊維素;[化学]cellulose/線維素/
せんいそうしつ /戦意喪失/
せんいそく /繊維束/
せんいそしき /繊維組織;[生物]fiber tissue/
せんいちやものがたり /千一夜物語;アラビアンナイト/
せんいつ /専一/
せんいばん /繊維板/
せんいひょう /遷移表/
せんいん /船員/
せんいんたち /船員達/
せんいんほう /船員法/
せんいんほけん /船員保険/
せんうん /戦雲/
せんえい /先鋭;radical/鮮鋭;vivid/尖鋭;≒先鋭/千映/
せんえいか /先鋭化/
せんえいち /先鋭値/
せんえいぶつ /先鋭物/
せんえき /戦役/
せんえつ /僭越/
せんえん /千円/遷延/潺湲;水や涙の流れるさま/
せんえんいか /千円以下/
せんえんくらい /千円位/
せんえんさつ /千円札/
せんえんぜんご /千円前後/
せんえんたんい /千円単位/
せんえんだい /千円台/
せんえんていど /千円程度/
せんえんなり /千円也/
せんえんぶん /千円分/
せんおう /専横/先王/僭王/擅横/
せんおうしょく /鮮黄色/
せんおく /千億/
せんおくえん /千億円/
せんおん /顫音/
せんおんそく /遷音速/
せんか /専科;special course/戦火;†war.「-を交える」/戦果;†war results.「-を上げる」/戦禍;†war damage.「-を蒙る」/選果/選科;selected course/銭貨/泉下/選歌/撰歌/仙家/線化/戰果;「戦」旧字/戰火;「戦」旧字/
せんかい /旋回/浅海/千回/先回/仙界/
せんかいうんどう /旋回運動/
せんかいえん /旋回円/
せんかいしき /旋回式/
せんかいせいのう /旋回性能/
せんかいちゅう /旋回中/
せんかいはんけい /旋回半径/
せんかいほうとう /旋回砲塔/
せんかいりつ /旋回率/
せんかく /線画/尖閣/先覚/
せんかくしゃ /先覚者/
せんかくしょとう /尖閣諸島/
せんかこ /線過去/
せんかし /泉貨紙/
せんかじゅう /線荷重/
せんかた /詮方;-ない/為ん方;=詮方/爲ん方;「為」旧字/
せんかち /先勝;[六輝]「せんしょう」/
せんかわ /千川/仙川/
せんかわえき /千川駅/
せんかん /戦艦/選管;†選挙管理(委員会)/専管;†専属管轄/線間/潜函/潺湲/戰艦;「戦」旧字/
せんかんき /戦間期/
せんかんぶりあき /先カンブリア紀/
せんかんぶりあじだい /先カンブリア時代;[地質年代]Precambrian. 地球誕生-5.5億年前/
せんかんやまと /戦艦大和/
せんが /線画/千賀/
せんがい /選外/船外/
せんがいかつどう /船外活動;EVA/
せんがいき /船外機;outboard engine/
せんがいきょう /山海経/
せんがか /線画化/
せんがき /線描き/
せんがく /浅学/先学/
せんがくじ /泉岳寺/
せんがくひさい /浅学非才/
せんがぞう /線画像/
せんがわ /仙川/
せんがん /洗顔/洗眼;†eye-washing/千貫/腺癌/先願/
せんがんざい /洗顔剤;†face wash/洗眼剤;†eye wash/
せんがんしゅぎ /先願主義/
せんがんせっけん /洗顔石鹸/
せんがんりょう /洗顔料/
せんき /戦記;chronicle.『ガリア-』/戦機;「-は熟した」/戦旗;「翻る-」/先期/疝気/
せんきち /詮吉/
せんきものがたり /戦記物語/
せんきゃく /先客/船客/
せんきゃくばんらい /千客万来/
せんきゅう /選球/仙宮/
せんきゅうがん /選球眼;[野球]/
せんきょ /選挙/占拠/船渠;dock/占居/
せんきょいいんかい /選挙委員会/
せんきょいはん /選挙違反/
せんきょう /宣教/戦況/船橋/泉郷/
せんきょうし /宣教師/
せんきょうんえい /選挙運営/
せんきょうんどう /選挙運動/
せんきょうんどうきかん /選挙運動期間/
せんきょかー /選挙カー/
せんきょかつどう /選挙活動/
せんきょかんけい /選挙関係/
せんきょかんり /選挙管理/
せんきょかんりいいん /選挙管理委員/
せんきょかんりいいんかい /選挙管理委員会/
せんきょかんりきかん /選挙管理機関/
せんきょきょうりょく /選挙協力/
せんきょく /選曲/選挙区/戦局/選局/
せんきょくいがい /選挙区以外/
せんきょくない /選挙区内/
せんきょくわり /選挙区割/
せんきょけっか /選挙結果/
せんきょけん /選挙権/
せんきょこうほう /選挙公報/選挙広報;?/
せんきょご /選挙後/
せんきょせいど /選挙制度/
せんきょせいどかいかく /選挙制度改革/
せんきょせん /選挙戦/
せんきょそくほう /選挙速報/
せんきょそしょう /選挙訴訟/
せんきょたいさく /選挙対策/
せんきょたちあいにん /選挙立会人/
せんきょちょう /選挙長/
せんきょにん /選挙人/
せんきょにんめいぼ /選挙人名簿/
せんきょほう /選挙法/
せんきょまえ /選挙前/
せんきょみん /選挙民/
せんきょむこう /選挙無効/
せんきん /千金/千鈞/
せんぎ /詮議/先議/僉議/
せんぎく /千菊/
せんぎょ /鮮魚/
せんぎょう /専業/賤業/瞻仰/
せんぎょうか /専業化/
せんぎょうしゅふ /専業主婦/専業主夫/
せんぎょうしゅふぎょう /専業主婦業/
せんぎょうのうか /専業農家/
せんぎょてん /鮮魚店/
せんぎり /千切り/
せんく /先駆/線区/選句/
せんくかん /線区間/
せんくしゃ /先駆者/
せんくしゃてき /先駆者的/
せんくち /先口/
せんくてき /先駆的/
せんくん /戦訓/先君/
せんぐ /船具/
せんぐう /遷宮/
せんぐらふ /線グラフ/
せんぐん /線群/
せんぐんばんば /千軍万馬/
せんけ /千家/仙家;=せんか/
せんけい /線形/線型;=線形/扇形/船型/尖形/戦形/
せんけいえんざんし /線形演算子/
せんけいおうとう /線型応答/
せんけいか /線形化/線型化/
せんけいかいりょう /線形改良/
せんけいかいろ /線形回路/
せんけいきんじ /線形近似/
せんけいくうかん /線形空間/線型空間/
せんけいけい /線形系/
せんけいけいかく /線型計画/
せんけいけいかくほう /線形計画法/
せんけいけいしき /線形形式/
せんけいけつごう /線形結合/線型結合/
せんけいさいしょうじじょう /線形最小二乗/
せんけいしゃぞう /線型写像/
せんけいじかん /線形時間/
せんけいじょうびぶんほうていしき /線型常微分方程式/
せんけいせい /線形性/線型性/
せんけいぞうふく /線形増幅/
せんけいだいすう /線形代数/線型代数/
せんけいだいすうがく /線形代数学/
せんけいどくりつ /線形独立/
せんけいぶぶんくうかん /線形部分空間/
せんけいぶんぽう /線形文法/
せんけいへんかん /線形変換/
せんけいほう /線形法/
せんけいほうていしき /線型方程式/
せんけいほかん /線形補間/
せんけいよそく /線形予測/
せんけいよそくぶんせき /線形予測分析/
せんけいりろん /線形理論/
せんけいろんり /線形論理/線型論理/
せんけいわ /線形和/
せんけつ /先決/専決;一人で決める/鮮血/潜血;[医]occult blood.「-反応」/
せんけつごう /線結合/
せんけつじこう /専決事項/
せんけつはんのう /潜血反応/
せんけん /先遣/先見/専権/先験/浅見/淺見;「浅」旧字/先件/嬋娟;-たる美女/仙建/擅権/選研/選鉱精錬研究所;※abbrev/
せんけんさそうち /線検査装置/
せんけんじこう /専権事項/
せんけんせい /先見性/
せんけんたい /先遣隊/
せんけんてき /先験的;a priori/先見的;foresight/
せんけんのめい /先見の明/
せんげ /遷化/宣下/
せんげつ /先月/繊月/
せんげつごう /先月号/
せんげつすえ /先月末/
せんげつちゅうじゅん /先月中旬/
せんげつちゅうもん /先月注文/
せんげつど /先月度/
せんげつはつばい /先月発売/
せんげつぶん /先月分/
せんげつまつ /先月末/
せんげん /宣言/線源;ratiation source/泉源;spring/譫言;うわごと/選言;[論理]disjunction.「あるいは」/先言/浅間/∨;or/
せんげんがた /宣言型/
せんげんし /宣言子/
せんげんじんじゃ /浅間神社/
せんげんだい /千間台/
せんげんてき /宣言的;declarative/選言的;disjunctive/
せんげんばんご /千言万語/
せんげんぶ /宣言部/
せんげんぶん /宣言文/
せんこ /千古/
せんこう /先行/専攻/選考;select/線香/閃光/先攻/穿孔/選好;prefer/潜行;creep/戦功/染工/潜航;submerge/先公;[俗]学校教師の賤称/選鉱/潜降;(ダイビングで)潜ること/鮮紅;bright red/せん孔/専行;独断-/先考/銓衡/旋光/先皇/繊巧/浅紅;shallow red/踐行/詮衡;「銓衡」の誤用/銑鋼/
せんこう> /先行;-文献,-研究,-予約/
せんこういいんかい /選考委員会/
せんこうおん /先行音/
せんこうか /専攻科/
せんこうかい /選考会/
せんこうかいぎ /専攻会議/
せんこうかせい /専攻科生/
せんこうき /穿孔機/
せんこうきじゅん /選考基準/
せんこうけい /先行系/
せんこうけんきゅう /先行研究/
せんこうげん /線光源/
せんこうこうかい /先行公開/
せんこうさぎょう /先行作業/
せんこうさく /先行策/
せんこうし /先行詞/先行誌/先行子/
せんこうしすう /先行指数/
せんこうしひょう /先行指標/
せんこうしゃ /先行者;†foregoer.「-の業績」/先行車;†car ahead.「-に追突」/
せんこうしゅうろく /先行収録/
せんこうしゅにん /専攻主任/
せんこうしょく /鮮紅色/
せんこうじゅん /選考順/
せんこうじょうえい /先行上映/
せんこうせい /先行性/旋光性/
せんこうたい /先行隊/
せんこうたいしょう /選考対象/
せんこうたて /線香立て/
せんこうだい /線香代/
せんこうち /先行値/
せんこうちゅう /選考中/
せんこうてい /潜航艇/
せんこうとう /閃光灯;strobe/
せんこうとうし /先行投資/
せんこうどうさ /先行動作/
せんこうにゅうりょく /先行入力/
せんこうはつばい /先行発売/
せんこうはなび /線香花火/
せんこうば /先行馬/
せんこうばゆうり /先行馬有利/
せんこうひょうか /先行評価/
せんこうび /選考日/
せんこうべつ /専攻別/
せんこうめい /専攻名/
せんこうよやく /先行予約/
せんこうりょく /先行力/
せんこうれっしゃ /先行列車/
せんこく /宣告/先刻/
せんこくごしょうち /先刻御承知/
せんこくしょうち /先刻承知/
せんこくゆうよ /宣告猶予/
せんこつ /仙骨/
せんこふえき /千古不易/
せんご /戦後/先後/選語/戰後;「戦」旧字/譫語/
せんごう /瞻仰/
せんごく /戦国/千石/仙石/戰國;旧字/
せんごくき /戦国期/
せんごくさく /戦国策;劉向・編/
せんごくじえいたい /戦国自衛隊/
せんごくじだい /戦国時代/
せんごくだいみょう /戦国大名/
せんごくつうしょう /千石通商;[企業名]/
せんごくぶしょう /戦国武将/
せんごくぶね /千石船/
せんごくやろう /戦国野郎/
せんごし /戦後史/
せんごしょり /戦後処理/
せんごせい /戦後製/
せんごは /戦後派/
せんごばん /先後番/
せんごほう /選語法/
せんごほしょう /戦後補償/
せんごほしょうもんだい /戦後補償問題/
せんごみんしゅしゅぎ /戦後民主主義/
せんさ /千差/
せんさい /繊細/戦災/先妻/浅才/
せんさいこじ /戦災孤児/
せんさいちゃ /仙斎茶/
せんさく /詮索;詳しく調べる/穿鑿;孔を開ける。うるさく調べる。NB:「詮索」はこちらの転化/
せんさばんべつ /千差万別/
せんさま /先様/
せんざい /潜在/洗剤/千歳;名を-に残す/千載;-一遇/宣材;[略語]宣伝材料/前栽;庭の植込/煎剤;煎じ薬/
せんざい> /潜在;-需要,-意識/
せんざいいしき /潜在意識/
せんざいいちぐう /千載一遇/
せんざいがくしゅう /潜在学習/
せんざいしつぎょう /潜在失業/
せんざいしゅう /千載集/
せんざいじゅよう /潜在需要/
せんざいじんこう /潜在人口/
せんざいてき /潜在的/
せんざいのうりょく /潜在能力/
せんざいふよう /洗剤不要/
せんざいりょう /洗剤量/
せんざいりょく /潜在力/
せんざいわかしゅう /千載和歌集/
せんざき /先崎/
せんざん /仙山/
せんざんこう /穿山甲/
せんざんせん /仙山線/
せんざんばんすい /千山万水/
せんし /戦士;soldier/戦死;death in war/戦史;war history/穿刺/先史;prehistory/先師/賤視/戦志/千思;-万考/千士/擅恣;arbitrary/戰死;「戦」旧字/
せんしがく /先史学;prehistory/
せんしきめん /線織面/
せんしけい /戦士系/
せんししゃ /戦死者/
せんししょう /戦士賞/
せんしじだい /先史時代/
せんしたい /戦死体/戰死體/
せんしたち /戦士達/
せんしつ /泉質/船室/線質/
せんしつがわ /船室側/
せんしつけいすう /線質係数/
せんしつけん /船室券/
せんしばんこう /千紫万紅;色取り取りの花々/千思万考;あれこれ思い巡らす/
せんしばんたい /千姿万態/
せんしふう /戦士風/
せんしゃ /戦車;tank/洗車;car washing/占者/戰車;「戦」旧字/
せんしゃき /洗車機/
せんしゃく /浅酌;-低唱/
せんしゃくていしょう /浅酌低唱/
せんしゃじょう /洗車場/
せんしゃせん /戦車戦/
せんしゃたい /戦車隊/
せんしゃはくぶつかん /戦車博物館/
せんしゃへい /戦車兵/
せんしゃや /洗車屋/
せんしやく /戦士役/
せんしゅ /選手/先取/船首/腺腫;[医]adenoma/船主/線種;CADの-/船種/僭主;tyrannos/専守/繊手/
せんしゅいちらん /選手一覧/
せんしゅう /先週/専修/泉州/選集/千秋/撰集/撰修;著作・編集/
せんしゅう> /先週;-日曜日,-末/
せんしゅうかようび /先週火曜日/
せんしゅうがっこう /専修学校/
せんしゅうこうかい /先週公開/
せんしゅうごう /先週号/
せんしゅうだい /専修大/
せんしゅうだいがく /専修大学/
せんしゅうちゅう /先週中/
せんしゅうどようび /先週土曜日/
せんしゅうはつばい /先週発売/
せんしゅうばんぜい /千秋万歳/
せんしゅうぶん /先週分/
せんしゅうまつ /先週末/
せんしゅうらく /千秋楽/
せんしゅかい /千趣会/選手会/
せんしゅかいちょう /選手会長/
せんしゅかん /選手間/
せんしゅがわ /選手側/
せんしゅきよう /選手起用/
せんしゅけん /選手権/
せんしゅけんしゃ /選手権者/
せんしゅけんじあい /選手権試合/
せんしゅけんじゃ /選手権者/
せんしゅけんじゅんけっしょう /選手権準決勝/
せんしゅけんたいかい /選手権大会/
せんしゅこうたい /選手交代/
せんしゅしょうかい /選手紹介/
せんしゅじしん /選手自身/
せんしゅじゅみょう /選手寿命/
せんしゅすう /選手数/
せんしゅせいめい /選手生命/
せんしゅせんこう /選手選考/
せんしゅせんせい /選手宣誓/
せんしゅぜんいん /選手全員/
せんしゅぜんたい /選手全体/
せんしゅそう /選手層/
せんしゅたち /選手達/
せんしゅだん /選手団/
せんしゅつ /選出/
せんしゅつとうひょう /選出投票/
せんしゅつば /選出馬/
せんしゅつび /選出日/
せんしゅつほうほう /選出方法/
せんしゅてん /先取点/
せんしゅとくゆう /選手特有/
せんしゅどうし /選手同士/
せんしゅにゅうじょう /選手入場/
せんしゅにゅうじょうしき /選手入場式/
せんしゅひとりひとり /選手一人一人/
せんしゅほきょう /選手補強/
せんしゅほんにん /選手本人/
せんしゅぼうえい /専守防衛/
せんしゅむら /選手村/
せんしゅめい /選手名/
せんしゅめいかん /選手名鑑/
せんしゅりゅうしゅつ /選手流出/
せんしゅん /浅春/
せんしょ /選書/戦書/
せんしょう /戦勝/先勝/戦傷/選奨/僭称;勝手に名乗る/戦捷;≒戦勝/先蹤;前例/賤称;賤しめる呼称。「アメ公」「露助」「先公」の類/僭上/戦賞/尠少/戰捷;「戦」旧字/
せんしょうこく /戦勝国/
せんしょく /染色;dyeing/染織;fabric and dyeing/
せんしょくこうじょう /染色工場/
せんしょくたい /染色体/
せんしょくたいいじょう /染色体異常/
せんしん /先進/専心/線審/撰進/潜心;没頭/千進/
せんしんこく /先進国/
せんしんしょこく /先進諸国/
せんしんせい /先進性/鮮新世;[地質年代]Pliocene. 520-164万年前/
せんしんだいがく /先進大学/
せんしんちいき /先進地域/
せんしんてき /先進的/
せんしんばんく /千辛万苦/
せんしんほう /千進法/
せんじ /戦時;wartime/宣旨/潜時;latent time.「反応-」/煎じ/戦事;military/戰時;「戦」旧字/
せんじいない /千字以内/
せんじか /戦時下/
せんじがき /宣旨書き/
せんじがみ /宣旨紙/
せんじぐすり /煎じ薬/
せんじちゃ /煎じ茶/
せんじちゅう /戦時中/戰時中;「戦」旧字/
せんじつ /先日/
せんじつとうこう /先日投稿/
せんじつはつばい /先日発売/
せんじつらい /先日来/
せんじのつかい /宣旨の使/
せんじます /宣旨升/
せんじもん /千字文/
せんじゃ /選者/撰者/千社/
せんじゃく /繊弱/
せんじゃふだ /千社札/
せんじゅ /千住;地名,足立区/千手;-観音/仙寿/千種/専修;[仏教]念仏のみを唱える/
せんじゅう /先住/専従/煎汁/
せんじゅうしゃ /専従者/
せんじゅうしゃきゅうよ /専従者給与/
せんじゅうしょう /撰集抄/
せんじゅうじ /千手寺/
せんじゅうみん /先住民/
せんじゅうみんぞく /先住民族/
せんじゅかんのん /千手観音/
せんじゅつ /戦術;strategy/先述;mentioned above/占術;うらない/仙術;仙人の術/撰述;著作する/戰術;「戦」旧字/
せんじゅつか /戦術家/
せんじゅつかく /戦術核/
せんじゅつき /戦術機/
せんじゅつきゅう /戦術級/
せんじゅつせい /戦術性/
せんじゅつてき /戦術的/
せんじゅんい /先順位/
せんじょ /剪除/
せんじょう /洗浄/戦場/船上;on board/線上;on the line/線状;linear/仙丈/扇状;fan/千畳/千丈/線条;line/洗滌;≒洗浄,=せんでき/扇情/煽情;=扇情/繊条;filament/戰場;「戦」旧字/
せんじょうえき /洗浄液/
せんじょうえきちゅう /洗浄液中/
せんじょうき /洗浄器/洗浄機/
せんじょうこん /線条痕/
せんじょうざい /洗浄剤/
せんじょうじき /千畳敷/
せんじょうすい /洗浄水/
せんじょうせい /線状性/
せんじょうだけ /仙丈岳/
せんじょうだん /扇状弾/
せんじょうち /扇状地/
せんじょうちゅう /洗浄中/
せんじょうてき /扇情的/煽情的;=扇情的/
せんじょうばんたい /千状万態/
せんじょうよう /洗浄用/
せんじょうりょく /洗浄力/
せんじん /先人;foregoer/先陣;vanguard/千尋;-の谷/戦塵/戦陣;battlefield/
せんじんあらそい /先陣争い/
せんす /扇子/
せんすい /潜水/泉水/仙水/線錐;beam/
せんすいかん /潜水艦/
せんすいかんぶたい /潜水艦部隊/
せんすいきぐ /潜水器具/
せんすいぎじゅつ /潜水技術/
せんすいし /潜水士/
せんすいじかん /潜水時間/
せんすいちゅう /潜水中/
せんすいてい /潜水艇/
せんすいとうげ /仙水峠/
せんすいびょう /潜水病/
せんすいふ /潜水夫/
せんすいふく /潜水服/
せんすうひゃく /千数百/
せんすうひゃくえん /千数百円/
せんず /線図/
せんずけい /線図形/
せんずるところ /詮ずる所/
せんせい /先生/先制/宣誓/専制/占星/専政;†専制政治/潜勢;latent.「-力」/陝西;地名,中国の省/
せんせいがく /占星学/
せんせいがた /先生方/
せんせいくんしゅ /専制君主/
せんせいくんしゅせい /専制君主制/
せんせいこうげき /先制攻撃/
せんせいしょ /宣誓書/
せんせいしよう /先制使用/
せんせいじゅつ /占星術/
せんせいじゅつし /占星術師/
せんせいせいじ /専制政治/
せんせいぞう /先生像/
せんせいだ /先制打/
せんせいてきじだ /先制適時打/
せんせいてん /先制点/
せんせいやく /先生役/
せんせいよう /先生用/
せんせいりょく /潜勢力/
せんせき /戦績/戦跡/船籍/仙石;(宮城の)仙台・石巻/仙籍/
せんせきこう /船籍港/
せんせきせん /仙石線/
せんせきてき /戦績的/
せんせきぶん /線積分/
せんせつ /洗雪/
せんせん /戦線/宣戦/先占/先々/戦々/閃々/戰線;「戦」旧字/宣戰;「戦」旧字/戰々;旧字/
せんせんきょうきょう /戦々恐々/戦々兢々/戦戦恐恐/戦戦兢兢/
せんせんげつ /先々月/先先月/
せんせんしゅう /先々週/先先週/
せんせんしゅとく /先占取得/
せんせんじつ /先先日/
せんせんだい /先々代/
せんせんふこく /宣戦布告/
せんせんふっき /戦線復帰/
せんせんりだつ /戦線離脱/
せんぜい /蝉蛻/
せんぜん /戦前/戰前;「戦」旧字/
せんぜんせだい /戦前世代/
せんぜんせんご /戦前戦後/
せんぜんは /戦前派/
せんそ /践祚/線素/
せんそう /戦争/船倉/線装/船窓/船艙;=船倉/先走/戰爭;旧字/
せんそうえいが /戦争映画/
せんそうかくだい /戦争拡大/
せんそうかんれん /戦争関連/
せんそうぎせいしゃ /戦争犠牲者/
せんそうけいけん /戦争経験/
せんそうけいぞく /戦争継続/
せんそうこうい /戦争行為/
せんそうご /戦争後/
せんそうさんび /戦争賛美/
せんそうしょき /戦争初期/
せんそうじ /浅草寺/戦争時/
せんそうじょうたい /戦争状態/
せんそうせきにん /戦争責任/
せんそうせきにんもんだい /戦争責任問題/
せんそうたいけん /戦争体験/
せんそうちゅう /戦争中/
せんそうとうじ /戦争当時/
せんそうはんざい /戦争犯罪/戰爭犯罪;旧字/
せんそうはんざいにん /戦争犯罪人/
せんそうはんたい /戦争反対/
せんそうばいしょう /戦争賠償/
せんそうひがい /戦争被害/
せんそうひがいしゃ /戦争被害者/
せんそうほりょ /戦争捕虜/
せんそうまっき /戦争末期/
せんそうもくてき /戦争目的/
せんそうもんだい /戦争問題/
せんそうや /戦争屋/
せんそか /線素化/
せんそく /洗足/船側/栓塞/戦速/線束/跣足;はだし/
せんぞ /先祖/
せんぞい /線沿い/線沿/
せんぞう /潜像;[写真]latent image/潜蔵;隠す・隠れる/線増/仙三/
せんぞうもよう /潜像模様/
せんぞがえり /先祖返り/
せんぞく /専属/洗足/
せんぞくいけ /洗足池/
せんぞくえき /洗足駅/
せんぞくかんかつ /専属管轄/
せんぞくがくえん /洗足学園/
せんぞくがくえんだい /洗足学園大/
せんぞさま /先祖様/
せんぞだいだい /先祖代々/
せんたーがい /センター街/
せんたーしけん /センター試験/
せんたーない /センター内/
せんたい /戦隊;squadron/船体/選対;[略語]選挙対策(委員会)/船隊;fleet/蘚苔/浅堆/
せんたいしょう /線対称/
せんたいもの /戦隊物/
せんたく /選択/洗濯/撰択;<rare>/宣託/
せんたくいた /洗濯板/
せんたくか /選択可/
せんたくかご /洗濯籠/洗濯カゴ/
せんたくかのう /選択可能/
せんたくかもく /選択科目/
せんたくがめん /選択画面/
せんたくき /洗濯機/
せんたくきじゅん /選択基準/
せんたくきのう /選択機能/
せんたくぐん /選択群/
せんたくけっか /選択結果/
せんたくけん /選択権/
せんたくこうもく /選択項目/
せんたくこうり /選択公理/
せんたくさいけん /選択債権/
せんたくし /選択肢/選択子/
せんたくしき /選択式/
せんたくしょうひ /選択消費/
せんたくしんごう /選択信号/
せんたくじ /選択時/
せんたくじかん /洗濯時間/
せんたくじょうけん /選択条件/
せんたくじょうしゃ /選択乗車/
せんたくじょうたい /選択状態/
せんたくすう /選択数/
せんたくせい /選択性/
せんたくせっけん /洗濯石鹸/
せんたくそう /洗濯漕/
せんたくだい /洗濯代/
せんたくちゅう /選択中/洗濯中/
せんたくてき /選択的/
せんたくてきしょうひ /選択的消費/
せんたくてん /選択点/
せんたくにゅうりょく /選択入力/
せんたくねっと /洗濯ネット/
せんたくはば /選択幅/
せんたくはんい /選択範囲/
せんたくばさみ /洗濯挟み/洗濯バサミ/
せんたくひっしゅう /選択必修/
せんたくひょうじ /選択表示/
せんたくびより /洗濯日和/
せんたくふかのう /選択不可能/
せんたくぶ /選択部/
せんたくぶぶん /選択部分/
せんたくほう /選択法/
せんたくほうしき /選択方式/
せんたくほうほう /選択方法/
せんたくまえ /洗濯前/
せんたくもの /洗濯物/
せんたくもんだい /選択問題/
せんたくや /洗濯屋/
せんたくよう /洗濯用/選択用/
せんたくようせんざい /洗濯用洗剤/
せんたくようそ /選択要素/
せんたくりょう /洗濯量/
せんたくわく /選択枠/
せんたろう /煎太郎/
せんたん /先端/尖端;とがった端/戦端;-を開く(=開戦する)/
せんたんい /千単位/
せんたんいりょう /先端医療/
せんたんかがく /先端科学/
せんたんかがくぎじゅつ /先端科学技術/
せんたんかがくぎじゅつけんきゅうせんたー /先端科学技術研究センター/
せんたんきょうふしょう /尖端恐怖症/先端恐怖症;常用漢字による書き換え/
せんたんぎじゅつ /先端技術/
せんたんぎじゅつけんきゅう /先端技術研究/
せんたんけいじょう /先端形状/
せんたんけん /先端研/
せんたんだい /先端大/
せんたんてき /先端的/
せんたんぶ /先端部/
せんだ /千田/仙田/煎田;人名 姓/
せんだい /仙台/先代/船台/先帝/川内;地名/千台/
せんだいいくえい /仙台育英/
せんだいいち /仙台一/
せんだいえいぎょうしょ /仙台営業所/
せんだいえき /仙台駅/
せんだいえきにしぐち /仙台駅西口/
せんだいかん /仙台間/
せんだいくうこう /仙台空港/
せんだいこう /仙台港/
せんだいこくぜいきょく /仙台国税局/
せんだいざか /仙台坂/
せんだいし /仙台市/
せんだいしない /仙台市内/
せんだいしみん /仙台市民/
せんだいしりつ /仙台市立/
せんだいじょう /仙台城/
せんだいたいかい /仙台大会/
せんだいたなばた /仙台七夕/
せんだいだい /仙台大/
せんだいちかてつ /仙台地下鉄/
せんだいちく /仙台地区/
せんだいてん /仙台店/
せんだいでんぱ /仙台電波/
せんだいでんぱこうせん /仙台電波高専/
せんだいにこう /仙台二高/
せんだいはつ /仙台発/
せんだいひら /仙台平/
せんだいべん /仙台弁/
せんだいほうそう /仙台放送/
せんだいほうめん /仙台方面/
せんだいまつど /専大松戸/
せんだいみそ /仙台味噌/
せんだいみやぎ /仙台宮城/
せんだがや /千駄ヶ谷/千駄谷/
せんだぎ /千駄木/
せんだち /先達/
せんだって /先達て/
せんだつ /先達/蝉脱/
せんだまち /千田町/
せんだん /船団/剪断;shear. ずれ/栴檀;[植物]sandalwood/専断;fiat/擅断;=専断/
せんだんおうりょく /剪断応力;[物理][建築]/
せんだんりょく /せん断力/
せんち /戦地/糎;cm/泉地/centi;[SI接頭語]c,10^-2/
せんちぐらむ /甅/
せんちめーとる /糎/
せんちゃ /煎茶/
せんちゃく /先着/
せんちゃくじゅん /先着順/
せんちゅう /戦中/船中/線虫/
せんちゅうは /戦中派/
せんちゅうはく /船中泊/
せんちょう /船長/線長/千兆/
せんちょうがん /閃長岩;syenite/
せんちょうしつ /船長室/
せんちりっとる /竰/
せんつい /仙椎;[解剖]sacral spine/
せんつう /疝痛/千通/
せんて /先手/
せんてい /選定/剪定;prune.「庭木の-」/船底;ship bottom/先帝/船艇;ships and boats/泉亭/撰定;「歌集の-」/
せんていこう /選帝侯/
せんていこうけんにん /選定後見人/
せんていさい /先帝祭/
せんていさぎょう /選定作業/
せんていしゃ /選定者/
せんていじょうけん /選定条件/
せんていとうじしゃ /選定当事者/
せんていどき /尖底土器/
せんていば /選定馬/
せんてごて /先手後手/
せんてせんて /先手先手/
せんてつ /銑鉄/先哲/仙鉄/鮮鉄/
せんてばん /先手番/
せんてひっしょう /先手必勝/
せんてゆうり /先手有利/
せんてん /先天/千点/旋転/尖点;[数学]cusp/
せんてんせい /先天性/
せんてんてき /先天的/
せんてんてきしょうがい /先天的障害/
せんてんてきようそ /先天的要素/
せんでき /洗滌/
せんでん /宣伝/
せんでんかつどう /宣伝活動/
せんでんこうか /宣伝効果/
せんでんこうこくひ /宣伝広告費/
せんでんたんとう /宣伝担当/
せんでんばいたい /宣伝媒体/
せんでんひ /宣伝費/
せんでんぶ /宣伝部/
せんでんぶそく /宣伝不足/
せんでんぶたい /宣伝部隊/
せんでんぶちょう /宣伝部長/
せんでんぶもん /宣伝部門/
せんでんぶん /宣伝文/
せんでんもんく /宣伝文句/
せんでんや /宣伝屋/
せんでんよう /宣伝用/
せんでんりょく /宣伝力/
せんと /遷都/仙都/¢;cent/
せんとう /先頭/戦闘/銭湯/尖塔/千頭/仙洞/尖頭/千灯/宣統/先登/剪刀/船頭/船灯/専当/銭刀/戰闘;「戦」だけ旧字/
せんとうあらそい /先頭争い/
せんとういん /戦闘員/
せんとうかいし /戦闘開始/
せんとうかいしじ /戦闘開始時/
せんとうかん /戦闘艦/
せんとうがめん /戦闘画面/
せんとうき /戦闘機;fighter/尖頭器;旧石器時代の-/戦闘旗;battle flag/
せんとうきどうし /戦闘機同士/
せんとうきょく /戦闘曲/
せんとうきろく /戦闘記録/
せんとうぎじゅつ /戦闘技術/
せんとうぎょう /先頭行/
せんとうくんれん /戦闘訓練/
せんとうけいかく /戦闘計画/
せんとうこうい /戦闘行為/
せんとうご /戦闘後/
せんとうごしょ /仙洞御所/
せんとうさいかい /戦闘再開/
せんとうしゃ /先頭車/
せんとうしゃりょう /先頭車両/
せんとうしゅうだん /先頭集団/
せんとうじ /戦闘時/
せんとうじょう /戦闘場/
せんとうじょうたい /戦闘状態/
せんとうせんしゅ /先頭選手/
せんとうそう /仙洞草/
せんとうだしゃ /先頭打者/
せんとうちいき /戦闘地域/
せんとうちゅう /戦闘中/
せんとうてい /宣統帝/
せんとうてき /戦闘的/
せんとうのうりょく /戦闘能力/
せんとうはっせい /戦闘発生/
せんとうはん /戦闘班/
せんとうふく /戦闘服/
せんとうふのう /戦闘不能/
せんとうぶ /先頭部/
せんとうぶぶん /先頭部分/
せんとうぼう /戦闘帽;field cap/
せんとうゆうどういん /先頭誘導員/
せんとうよう /戦闘用/
せんとうりょく /戦闘力/
せんとらるがらす /セントラル硝子/
せんど /鮮度/先度/尖度/先途/千度/
せんどう /先導/船頭/仙道/扇動/煽動/千堂/羨道/千同/顫動;trill/
せんどうおん /顫動音;[音声学]trill/
せんどうか /旋頭歌/
せんどうし /線同士/
せんどうしゃ /先導車/
せんどうてき /先導的/
せんどうふう /船頭風/
せんどうやく /先導役/
せんどきじだい /先土器時代/
せんない /船内/線内/
せんないせいかつ /船内生活/
せんなん /泉南/仙南/
せんにく /鮮肉/
せんにち /千日/
せんにちせんそう /千日戦争/
せんにちて /千日手/
せんにちどう /千日堂/
せんにちまえ /千日前/
せんにちまえせん /千日前線/
せんにゅう /潜入/先入/穿入/仙入/
せんにゅうかん /先入観/
せんにゅうかんねん /先入観念/
せんにゅうけん /先入見/
せんにゅうしゅ /先入主/
せんにょ /仙女/
せんにん /専任/選任/仙人/千人/先任/
せんにんいじょう /千人以上/
せんにんかしかん /先任下士官/
せんにんきょうじゅ /専任教授/
せんにんぎり /千人斬り/
せんにんけん /選任権/
せんにんこうし /専任講師/
せんにんしゃ /専任者/
せんにんしょう /仙人掌/
せんにんしょうこう /先任将校/
せんにんばり /千人針/
せんにんりき /千人力/
せんぬき /栓抜き/
せんねつ /潜熱/
せんねん /専念/千年/先年/
せんねんいじょうまえ /千年以上前/
せんねんおうこく /千年王国/
せんねんかん /千年間/
せんねんき /千年紀;millennium/
せんねんたんい /千年単位/
せんのう /洗脳/先王/先皇/
せんのうき /洗脳機/
せんのりきゅう /千利休/
せんはた /千畑/
せんはつめい /先発明/
せんはば /線幅/
せんはら /千原/
せんば /船場/仙波/千羽/仙葉/
せんばい /専売/
せんばいいじょう /千倍以上/
せんばいけん /先買権;[金融]first option/
せんばいこうしゃ /専売公社/
せんばいせい /専売制/
せんばいとっきょ /専売特許/
せんばがん /選馬眼/
せんばこき /千把扱き/
せんばしょ /先場所/
せんばじる /船場汁/
せんばつ /選抜/
せんばつこうこうやきゅう /選抜高校野球/
せんばつしけん /選抜試験/
せんばつたいかい /選抜大会/
せんばづる /千羽鶴/
せんばやしかん /千林間/
せんばりき /千馬力/
せんばん /千万/旋盤/先番/先晩/
せんばんこう /旋盤工/
せんぱい /先輩/戦敗/
せんぱいがた /先輩方/
せんぱいこうはい /先輩後輩/
せんぱいたち /先輩達/
せんぱく /船舶/浅薄/銭帛/
せんぱくあんぜんほう /船舶安全法/
せんぱくかんりにん /船舶管理人/
せんぱくきょうゆうしゃ /船舶共有者/
せんぱくぎょうかい /船舶業界/
せんぱくこうがく /船舶工学;marine engineering/
せんぱくこくせきしょうしょ /船舶国籍証書/
せんぱくしょくいん /船舶職員/
せんぱくでんわ /船舶電話/
せんぱくほう /船舶法/
せんぱくほけん /船舶保険/
せんぱくめんきょ /船舶免許/
せんぱつ /先発/洗髪/染髪/
せんぱつかいひ /先発回避/
せんぱつかんとう /先発完投/
せんぱつかんとうがた /先発完投型/
せんぱつし /先発枝/
せんぱつしゅつじょう /先発出場/
せんぱつじん /先発陣/
せんぱつぜんいんあんだ /先発全員安打/
せんぱつたい /先発隊/
せんぱつだい /洗髪台/
せんぱつとうしゅ /先発投手/
せんぱつとうしゅじん /先発投手陣/
せんぱつひん /先発品/
せんぱつよそう /先発予想/
せんぱつりょう /洗髪料/
せんぱん /先般/戦犯/戰犯;「戦」旧字/
せんひき /線引き/線引/
せんひゃく /千百/
せんび /船尾/戦備/
せんびき /線引き/線引/
せんびきこぎって /線引小切手;crossed cheque/
せんびょう /線描/
せんびょうが /線描画/
せんびょうし /戦病死/
せんびょうしつ /腺病質/
せんびん /船便/先便/
せんぴ /戦費/鮮卑/先非/
せんぴつ /染筆/
せんぴょう /戦評/選評/線表/先表/
せんぶ /先負;[六輝]/宣撫/旋舞/
せんぶり /千振/
せんぶん /線分/千分/撰文/
せんぶんか /線分化/
せんぶんじょう /線分上/
せんぶんず /線分図/
せんぶんりつ /千分率/
せんぷ /宣布/戦斧/先負;[六輝]/先夫/
せんぷう /旋風/
せんぷうき /扇風機/
せんぷうよう /旋風葉/
せんぷく /潜伏/線幅;linewidth/船腹;bottom/船幅;beam/先腹;先妻の子/
せんぷくが /潜伏芽/
せんぷくき /潜伏期/
せんぷくきかん /潜伏期間/
せんぷくさき /潜伏先/
せんぷくりん /千輻輪/
せんべい /煎餅/
せんべいぶとん /煎餅布団/
せんべつ /選別;selection/餞別;はなむけ/
せんべつひん /選別品/
せんべん /先鞭/
せんべんばんか /千変万化/
せんぺい /尖兵/先兵/
せんぺんいちりつ /千篇一律/千編一律/
せんぺんばんか /千変万化/
せんほく /泉北/
せんぼう /羨望/懺法/
せんぼうきょう /潜望鏡/
せんぼく /泉北;地名,大阪/仙北;地名,秋田/占卜/
せんぼつ /戦没/戦歿;=戦没/潜没;dive/
せんぼつしゃ /戦没者/
せんぼん /千本/
せんぼんざくら /千本桜/
せんぼんはま /千本浜/
せんぽう /先方/戦法/先鋒/旋法/占法/尖峰/
せんぽうもち /先方持ち/
せんぽく /泉北/
せんまい /千枚/洗米/
せんまいじ /洗米時/
せんまいだ /千枚田/
せんまいだけ /千枚岳/
せんまいづけ /千枚漬/千枚漬け/
せんまいどおし /千枚通し/
せんまけ /先負;[六輝]/
せんまや /千厩/
せんまん /千万/
せんまんげん /千万言/
せんまんにん /千万人/
せんまんむりょう /千万無量/
せんみつ /繊密/千三つ/
せんみつど /線密度/
せんみょう /宣命/
せんみん /選民;選ばれた民/賤民;いやしい民/賎民;「賤」異体字/
せんみんしそう /選民思想/
せんむ /専務/占夢/
せんむとりしまりやく /専務取締役/
せんめい /鮮明/船名/線名/宣明/闡明/
せんめつ /殲滅/殱滅;「殲」異体字/剪滅/
せんめん /洗面/扇面/線面/
せんめんき /洗面器/
せんめんけしょうだい /洗面化粧台/
せんめんしつ /洗面室/
せんめんじょ /洗面所/
せんめんだい /洗面台/
せんもう /繊毛;[生物]cilium/線毛;[生物]pilus/旋毛;つむじ/譫妄/腺毛;[植物]glandular hair/剪毛/
せんもううんどう /繊毛運動/
せんもうせん /釧網線/
せんもうちゅう /旋毛虫/
せんもうほんせん /釧網本線/
せんもじ /線文字/
せんもん /専門/泉門;[解剖]fontanel/羨門/
せんもんい /専門医/
せんもんいいん /専門委員/
せんもんいいんかい /専門委員会/
せんもんいいんちょう /専門委員長/
せんもんいん /専門員/
せんもんか /専門家/専門化/
せんもんかいがい /専門家以外/
せんもんかてい /専門課程/
せんもんかもく /専門科目/
せんもんかん /専門官/
せんもんかんけい /専門関係/
せんもんがい /専門外/
せんもんがっこう /専門学校/
せんもんがっこうせい /専門学校生/
せんもんきかん /専門機関/
せんもんきょういく /専門教育/
せんもんご /専門語/
せんもんざっし /専門雑誌/
せんもんし /専門誌/専門紙/
せんもんしけん /専門試験/
せんもんしゅっぱんしゃ /専門出版社/
せんもんしょ /専門書/
せんもんしょうしゃ /専門商社/
せんもんしょく /専門職/
せんもんしょくいん /専門職員/
せんもんしょせき /専門書籍/
せんもんじしょ /専門辞書/
せんもんせい /専門性/
せんもんだんたい /専門団体/
せんもんちしき /専門知識/
せんもんてき /専門的/
せんもんてきちしき /専門的知識/
せんもんてん /専門店/
せんもんてんがい /専門店街/
せんもんてんがた /専門店型/
せんもんとしょかん /専門図書館/
せんもんひん /専門品/
せんもんぶかい /専門部会/
せんもんぶんや /専門分野/
せんもんめい /専門名/
せんもんよう /専門用/
せんもんようご /専門用語/
せんもんりょういき /専門領域/
せんもんわく /専門枠/
せんや /千夜/戦野/先夜/
せんやいちや /千夜一夜/
せんやいちやものがたり /千夜一夜物語;Alf layla wa layla/
せんやく /先約/仙薬;卓効/煎薬/
せんゆう /占有;occupation/専有;sole possesion/戦友/先憂/
せんゆうか /占有下/
せんゆうきょか /占有許可/
せんゆうけん /占有権/専有権/
せんゆうこうらく /先憂後楽/
せんゆうしゃ /占有者/
せんゆうじかん /占有時間/
せんゆうじょうほう /専有情報/
せんゆうぶつ /占有物/
せんゆうぶぶん /専有部分;⇔共用部分/
せんゆうめんせき /占有面積/
せんゆうや /占有屋;[時事]競売物件などを占拠して立ち退き料を要求します/
せんゆうりつ /占有率/
せんゆうりょう /占有量/
せんよう /専用/占用/宣揚/閃耀/
せんよう> /専用;-端末/
せんようおんげん /専用音源/
せんようかいせん /専用回線/
せんようかもつ /専用貨物/
せんようがいしゃ /専用会社/
せんようき /専用機/
せんようきどう /専用軌道/
せんようくうこう /専用空港/
せんようこうぐ /専用工具/
せんようしゃ /専用車/
せんようしゃりょう /専用車両/
せんようしゅうのう /専用収納/
せんようしょく /専用色/
せんようせん /専用線/
せんようせんよう /専用線用/
せんようそ /線要素/
せんようたんまつ /専用端末/
せんようちいき /専用地域/
せんようちゅうしゃじょう /専用駐車場/
せんようどう /専用道/
せんようどうぐ /専用道具/
せんようどうろ /専用道路/
せんようないぞうがた /専用内蔵型/
せんようば /専用馬/
せんようばん /専用版/
せんようひん /専用品/
せんようめんきょ /専用免許/
せんようれっしゃ /専用列車/
せんらん /戦乱/
せんり /千里/戦利/
せんりがん /千里眼/
せんりこう /千里膏/
せんりせん /千里線/
せんりちゅうおう /千里中央/
せんりちゅうおうえき /千里中央駅/
せんりつ /旋律/戦慄/先立/
せんりつてき /旋律的/
せんりつぶ /旋律部/
せんりどうふう /千里同風/
せんりはまかいがん /千里浜海岸/
せんりはんきゅう /千里阪急/
せんりはんきゅうほてる /千里阪急ホテル/
せんりひん /戦利品/
せんりゃく /戦略/
せんりゃくかく /戦略核/
せんりゃくかくへいき /戦略核兵器/
せんりゃくきゅう /戦略級/
せんりゃくくうぐん /戦略空軍/
せんりゃくじょう /戦略上/
せんりゃくせい /戦略性/
せんりゃくちしき /戦略知識/
せんりゃくてき /戦略的/
せんりゃくてきしこう /戦略的思考/
せんりゃくてきじょうほう /戦略的情報/
せんりゃくばくげき /戦略爆撃/
せんりゃくぶっし /戦略物資/
せんりやま /千里山/
せんりゅう /川柳/潜龍/千流/
せんりょ /浅慮/千慮/
せんりょう /占領/染料/線量/千両/選良/
せんりょうか /占領下/センリョウ科/Chloranthaceae/
せんりょうぐん /占領軍/
せんりょうけい /線量計/
せんりょうけいかく /占領計画/
せんりょうご /占領後/
せんりょうしはい /占領支配/
せんりょうじょうたい /占領状態/
せんりょうせいさく /占領政策/
せんりょうそくてい /線量測定/
せんりょうち /占領地/
せんりょうちいき /占領地域/
せんりょうちゅう /占領中/
せんりょうとうりょう /線量当量/
せんりょうばこ /千両箱/
せんりょうみん /占領民/
せんりょうやくしゃ /千両役者/
せんりょうりつ /線量率/
せんりょく /戦力/浅緑/鮮緑/
せんりょくがい /戦力外/
せんりょくがん /閃緑岩;diorite/
せんりょくこうそう /戦力構想/
せんりょくひ /戦力比/
せんりん /線輪/
せんりんかく /線輪郭/
せんるい /蘚類/
せんれい /洗礼/先例/船齢/鮮麗/繊麗/
せんれいどう /洗礼堂;baptistry/
せんれいめい /洗礼名;Christian name/
せんれき /戦歴/
せんれつ /鮮烈/戦列/
せんれん /洗練/洗錬;=洗練/洗煉;=洗練/
せんれんか /洗練化/
せんれんけつ /線連結/
せんろ /線路/
せんろあと /線路跡/
せんろう /船楼/
せんろぎじゅつ /線路技術/
せんろぎわ /線路際/
せんろしき /線路敷/
せんろした /線路下/
せんろじょう /線路上/
せんろじょうきょう /線路状況/
せんろじょうけん /線路条件/
せんろぞい /線路沿/
せんろはば /線路幅/
せんろほうこう /線路方向/
せんろようりょう /線路容量/
せんろよこ /線路横/
せんろわき /線路脇/
せんわく /煽惑/
ぜ /是/
ぜーた /ζ;zeta/Ζ;Zeta/
ぜあみ /世阿弥/
ぜい /税/勢/贅/説;(慣用音)遊説/脆;脆弱/筮;筮竹/噬;(かむ)/
ぜいいん /税印/
ぜいか /脆化/
ぜいかん /税関/
ぜいかんしんこくしょ /税関申告書/
ぜいかんちょう /税関長/
ぜいがく /税額/
ぜいがくこうじょ /税額控除/
ぜいがくひょう /税額表/
ぜいきん /税金/
ぜいきんいがい /税金以外/
ぜいきんかんけい /税金関係/
ぜいきんこうじょ /税金控除/
ぜいきんどろぼう /税金泥棒/
ぜいきんぶん /税金分/
ぜいきんもんだい /税金問題/
ぜいきんりつ /税金率/
ぜいきんるい /税金類/
ぜいげん /税源/贅言/
ぜいげんいじょう /税源移譲/
ぜいこみ /税込/税込み/
ぜいご /贅語/
ぜいしゅう /税収/
ぜいしゅうげん /税収減/
ぜいしゅうぞう /税収増/
ぜいしゅうにゅう /税収入/
ぜいしゅうひ /税収比/
ぜいしょうめい /税証明/
ぜいじゃく /脆弱/
ぜいじゃくせい /脆弱性/
ぜいせい /税制/脆性/
ぜいせいかいかく /税制改革/
ぜいせいじょう /税制上/
ぜいせいちょうさかい /税制調査会/
ぜいせいど /税制度/
ぜいたく /贅沢/
ぜいたくざんまい /贅沢三昧/
ぜいたくひん /贅沢品/
ぜいたくびょう /贅沢病/
ぜいちく /筮竹;易者の使う/
ぜいちょう /税調/
ぜいにく /贅肉/ぜい肉/
ぜいぬき /税抜/税抜き/
ぜいびき /税引き;-後/
ぜいびきまえとうきりえき /税引前当期利益/
ぜいふたん /税負担/
ぜいぶつ /贅物/
ぜいべつ /税別/
ぜいべつかかく /税別価格/
ぜいほう /税法/
ぜいほうじょう /税法上/
ぜいむ /税務/
ぜいむしょ /税務署/税務所/
ぜいむじむしょ /税務事務所/
ぜいむだいがっこう /税務大学校;国税庁。www.ntc.nta.go.jp/
ぜいむだいりし /税務代理士/
ぜいむちょうさ /税務調査/
ぜいり /税理/税吏/
ぜいりし /税理士/
ぜいりしほう /税理士法/
ぜいりつ /税率/
ぜいろく /贅六/
ぜえた /Ζ/
ぜえろく /贅六/
ぜがい /是界/
ぜがひでも /是が非でも/
ぜき /関/關;「関」の旧字/
ぜげん /女衒/
ぜせい /是正/
ぜせいそち /是正措置/
ぜぜ /膳所/
ぜぜこう /膳所高/
ぜぜこうこう /膳所高校/
ぜぜひひ /是是非非;是を是とし非を非とす(荀子)/是々非々;道理(是非)による判断/
ぜた /zetta;[SI接頭語]Z,10^21/
ぜっか /舌下/絶佳/舌禍/絶家/
ぜっかい /絶海/
ぜっかしんけい /舌下神経/
ぜっきょう /絶叫/絶境/
ぜっきん /舌筋;[解剖]lingual muscle/
ぜっく /絶句/
ぜっけ /絶家/
ぜっけい /絶景/
ぜっこう /絶好;-の/絶交;-する/舌口/舌耕/
ぜっこうきゅう /絶好球/
ぜっこうせんげん /絶交宣言/
ぜっこうちょう /絶好調/
ぜっこつ /舌骨/
ぜっこん /舌根/
ぜっさん /絶賛/絶讃/絶讚/
ぜっさんじょうえいちゅう /絶賛上映中/
ぜっさんはつばいちゅう /絶賛発売中/
ぜっさんほうえいちゅう /絶賛放映中/
ぜっしょう /絶唱/絶勝/
ぜっしょく /絶食/
ぜっせい /絶世/
ぜっせん /舌先/舌戦/舌尖/
ぜっそく /絶息/
ぜったい /絶対/舌苔/絶体;†「-絶命」/
ぜったい> /絶対;-悪,-座標/
ぜったいあく /絶対悪/
ぜったいあんせい /絶対安静/
ぜったいいち /絶対位置/
ぜったいうずど /絶対渦度/
ぜったいおうせい /絶対王政/
ぜったいおん /絶対音/
ぜったいおんかん /絶対音感/
ぜったいおんがく /絶対音楽/
ぜったいおんど /絶対温度/
ぜったいか /絶対化/
ぜったいかく /絶対格/
ぜったいくんしゅ /絶対君主/
ぜったいくんしゅせい /絶対君主制/
ぜったいけい /絶対系/
ぜったいけいご /絶対敬語;「奏す」「啓す」など/
ぜったいけん /絶対権/
ぜったいけんりょく /絶対権力/
ぜったいごさ /絶対誤差/
ぜったいざひょう /絶対座標/
ぜったいし /絶対視/
ぜったいしき /絶対式/
ぜったいしつど /絶対湿度/
ぜったいしゃ /絶対者/
ぜったいしゅうそく /絶対収束/
ぜったいしゅぎ /絶対主義/
ぜったいじかん /絶対時間/
ぜったいじゅうよう /絶対重要/
ぜったいじょうけん /絶対条件/
ぜったいすう /絶対数/
ぜったいせいしけい /絶対静止系/
ぜったいせいしん /絶対精神;[哲学]absoluter Geist (NB:Hegelの用語)/
ぜったいせいのう /絶対性能/
ぜったいぜつめい /絶体絶命/
ぜったいぜん /絶対善/
ぜったいそし /絶対阻止/
ぜったいそん /絶対損/
ぜったいたすう /絶対多数/
ぜったいたんいけい /絶対単位系/
ぜったいだいじょうぶ /絶対大丈夫/
ぜったいだめ /絶対駄目/
ぜったいち /絶対値/絶対知;[哲学]absolutes Wissen(独)/
ぜったいてき /絶対的/
ぜったいてきけんりょく /絶対的権力/
ぜったいてきしんり /絶対的真理/
ぜったいてきふそく /絶対的不足/
ぜったいてきゆういせい /絶対的優位性/
ぜったいとうきゅう /絶対等級/
ぜったいとうせん /絶対当選/
ぜったいのうりょく /絶対能力/
ぜったいはんたい /絶対反対/
ぜったいばんち /絶対番地;[電算]absolute address/
ぜったいぱす /絶対パス/
ぜったいぱすめい /絶対パス名/
ぜったいひつよう /絶対必要/
ぜったいひょうか /絶対評価/
ぜったいひょうげん /絶対表現/
ぜったいふくじゅう /絶対服従/
ぜったいまけ /絶対負/
ぜったいむてき /絶対無敵/
ぜったいむり /絶対無理/
ぜったいりょう /絶対量/
ぜったいれいど /絶対零度/
ぜったいれんぞく /絶対連続/
ぜったいろん /絶対論/
ぜったん /舌端/
ぜっちょう /絶頂/
ぜっちょうかん /絶頂感/
ぜっちょうき /絶頂期/
ぜっとう /絶倒/舌頭/絶島/
ぜっとき /Ｚ旗/
ぜっとじく /Ｚ軸/Z軸/
ぜっとへんかん /Ｚ変換/
ぜっぱい /舌背/
ぜっぱん /絶版/
ぜっぴつ /絶筆/
ぜっぴん /絶品/
ぜっふうん /絶不運/
ぜっふちょう /絶不調/
ぜっぺき /絶壁/
ぜっぽう /舌鋒/
ぜつ /絶/舌/説/
ぜつ> /絶/
ぜつあい /絶愛/
ぜつあつし /舌圧子/
ぜついき /絶域/
ぜついん /舌咽/
ぜついんしんけい /舌咽神経/
ぜつえん /絶縁;insulate/舌炎;[医]glossitis/絶遠;far-off/
ぜつえんえきたい /絶縁液体/
ぜつえんざい /絶縁材/
ぜつえんじょう /絶縁状/
ぜつえんせい /絶縁性/
ぜつえんせんげん /絶縁宣言/
ぜつえんたい /絶縁体/
ぜつえんてーぷ /絶縁テープ/
ぜつえんていこう /絶縁抵抗/
ぜつえんふりょう /絶縁不良/
ぜつえんぶ /絶縁部/
ぜつおん /舌音/
ぜつがん /舌癌/
ぜつぎ /絶技/舌技/
ぜつげん /絶絃/絶弦/
ぜつご /絶後/
ぜつじょうか /舌状花/
ぜつだい /絶大/舌代;挨拶文/絶待;[仏教]⇔相待/
ぜつび /絶美/
ぜつふちょう /絶不調/
ぜつぼう /絶望/
ぜつぼうかん /絶望感/
ぜつぼうし /絶望視/
ぜつぼうてき /絶望的/
ぜつみょう /絶妙/
ぜつむ /絶無/
ぜつめい /絶命/
ぜつめつ /絶滅/
ぜつめつきぐしゅ /絶滅危惧種/
ぜつめつしゅ /絶滅種/
ぜつめつすんぜん /絶滅寸前/
ぜつめつどうぶつ /絶滅動物/
ぜつめん /舌面/
ぜつりん /絶倫/
ぜに /銭/錢;旧字/
ぜにあおい /銭葵/
ぜにうしない /銭失い/
ぜにかね /銭金/
ぜにかんじょう /銭勘定/
ぜにがた /銭形/
ぜにがたあざらし /銭形海豹/
ぜにがたへいじ /銭形平次/
ぜにがめ /銭亀/
ぜにげば /銭ゲバ;[口]/
ぜにごけ /銭苔/
ぜにずく /銭尽く/
ぜにたかぐみ /錢高組/
ぜにだいこ /銭太鼓/
ぜにばこ /銭函/銭箱/
ぜにもうけ /銭儲け/
ぜにん /是認/
ぜねらるせきゆ /ゼネラル石油;[企業名]/
ぜひ /是非/
ぜひいちど /是非一度/
ぜひごきょうりょく /是非御協力/
ぜひさんか /是非参加/
ぜひしょうかい /是非紹介/
ぜひぜひ /是非是非;-頼んます/
ぜひとも /是非とも/
ぜひよく /是非欲/
ぜぷと /zepto;[SI接頭語]z,10^-21/
ぜみ /蝉/
ぜみしつ /ゼミ室/
ぜみしりょう /ゼミ資料/
ぜめ /攻め/
ぜらちんしつ /ゼラチン質/
ぜりーじょう /ゼリー状/
ぜりふ /台詞/
ぜろ /零/〇;漢数字のゼロ/
ぜろいんし /零因子/
ぜろかいとう /ゼロ回答/
ぜろきんり /ゼロ金利/
ぜろくうかん /零空間/
ぜろげん /零元/
ぜろさい /ゼロ歳/
ぜろさいじ /ゼロ歳児/
ぜろじ /０次/
ぜろせいちょう /ゼロ成長/
ぜろせん /零戦;NB:本来は「れいせん」/ゼロ戦;(zero fighter) 零式艦上戦闘機/
ぜろてん /ゼロ点/零点/
ぜん /善/前/全/膳;お-/禅;Zen Buddhism/然/千;(連濁)/冉/苒/髯;ひげ。鬚髯/喘;喘息/蠕;蠕動/漸;漸次/嶄/繕;修繕/譱;「善」の異体字/蝉;せみ/禪;「禅」の旧字(人名用漢字)/
ぜん> /前/全/
ぜんあく /善悪/
ぜんあつ /前圧/全圧/
ぜんい /善意/前位/禅位/
ぜんいいん /全委員/
ぜんいき /全域/
ぜんいきてき /全域的/
ぜんいしき /前意識/
ぜんいしゅとく /善意取得/
ぜんいち /善一/
ぜんいつ /全一/
ぜんいでんし /全遺伝子/
ぜんいん /全員/禅院/善因/
ぜんいんいっち /全員一致/
ぜんいんきょうつう /全員共通/
ぜんいんさんか /全員参加/
ぜんいんしゅうごう /全員集合/
ぜんいんしんにん /全員信任/
ぜんいんぜんか /善因善果/
ぜんいんちゃくせき /全員着席/
ぜんいんひっしゅう /全員必修/
ぜんいんぶん /全員分/
ぜんうちゅう /全宇宙/
ぜんうりあげ /全売上/
ぜんえい /前衛/全英/
ぜんえい> /前衛;(avant-garde) -映画,-詩,-音楽/
ぜんえいえいが /前衛映画/
ぜんえいおんがっか /前衛音楽家/
ぜんえいてき /前衛的/
ぜんえいは /前衛派/
ぜんえいびじゅつ /前衛美術/
ぜんえいぶとう /前衛舞踏/
ぜんえき /全駅/
ぜんえん /前縁/全縁/全円/千円/
ぜんおう /全欧/
ぜんおん /全音/
ぜんおんいき /全音域/
ぜんおんいん /全音韻/
ぜんおんおんかい /全音音階;whole-tone scale/
ぜんおんかい /全音階/
ぜんおんぷ /全音符/
ぜんか /前科/全課/全科/全家/漸化;-式/善果/
ぜんかい /前回/全開/全快/全壊/全会/全回/全階/全解/全潰/
ぜんかいいっち /全会一致/
ぜんかいいん /全会員/
ぜんかいかいじょう /前回会場/
ぜんかいきどう /前回起動/
ぜんかいこうえん /前回公演/
ぜんかいこうひょう /前回好評/
ぜんかいしょうかい /前回紹介/
ぜんかいじゅんい /前回順位/
ぜんかいじょう /全会場/
ぜんかいせんたく /前回選択/
ぜんかいそう /全階層/
ぜんかいたんさく /全解探索/
ぜんかいちゅうもん /前回注文/
ぜんかいてんいき /全回転域/
ぜんかいとうこう /前回投稿/
ぜんかいとうしゃ /全回答者/
ぜんかいどうよう /前回同様/
ぜんかいはっぴょう /前回発表/
ぜんかいぶん /前回分/
ぜんかいまで /前回迄/
ぜんかいよこく /前回予告/
ぜんかいれいかい /前回例会/
ぜんかいろず /全回路図/
ぜんかく /全角/前核/禅客/
ぜんかくうんどうりょう /全角運動量/
ぜんかくえいすうじ /全角英数字/
ぜんかくか /全角化/
ぜんかくかな /全角仮名/
ぜんかくき /前核期/
ぜんかくこう /前各項/
ぜんかくてい /全確定/
ぜんかくにゅうりょく /全角入力/
ぜんかくはんかく /全角半角/
ぜんかくもじ /全角文字/
ぜんかさん /全加算/
ぜんかさんき /全加算器/
ぜんかし /全歌詞/
ぜんかしき /漸化式/
ぜんかもの /前科者/
ぜんかん /全巻/全館/前漢;中国の王朝名(BC202-AD8)/前巻/全艦/前官/善感/
ぜんかんきんえん /全館禁煙/
ぜんかんしよう /全館使用/
ぜんかんじょ /前漢書/
ぜんかんちゅういぎむ /善管注意義務;善良な管理者の注意義務/
ぜんかんとく /前監督/
ぜんかんりにん /前管理人/
ぜんがく /全額/全学/前額;forehead/禅学/
ぜんがくきふ /全額寄付/
ぜんがくしきゅう /全額支給/
ぜんがくしょう /全楽章/
ぜんがくせい /全学生/
ぜんがくてき /全学的/
ぜんがくふたん /全額負担/
ぜんがくぶ /全学部/
ぜんがくへんきん /全額返金/
ぜんがくぼっしゅう /全額没収/
ぜんがくめんじょ /全額免除/
ぜんがくれん /全学連/
ぜんがっき /前学期/
ぜんがめん /全画面/
ぜんがめんひょうじ /全画面表示/
ぜんき /前期;⇔後期/前記;mentioned above/全期;whole period/全機/前季/
ぜんき> /前期;-試験,-旧石器/
ぜんきかてい /前期課程/
ぜんきかん /全期間/
ぜんきがた /前期型/
ぜんきしけん /前期試験/
ぜんきしゃ /前期車/
ぜんきしゅ /全機種/
ぜんきしゅせいは /全機種制覇/
ぜんきじ /全記事/前記事/
ぜんきち /善吉/
ぜんきにってい /前期日程/
ぜんきばん /前期版/
ぜんきひ /前期比/
ぜんきゃく /前脚/
ぜんきゅう /全休/冉求;孔子の弟子/
ぜんきゅうし /前臼歯/
ぜんきゅうしゅうがくせい /全九州学生/
ぜんきゅうだん /全球団/
ぜんきゅうふ /全休符/
ぜんきゆうしょう /前期優勝/
ぜんきょうだい /全兄弟;父母共に同じである(異父・異母でない)兄弟/
ぜんきょうとう /全共闘/
ぜんきょうれん /全共連;[略語]全国共済農業協同組合連合会/
ぜんきょく /全曲/全局/全極/
ぜんきょくえんそう /全曲演奏/
ぜんきょくがた /全極型/
ぜんきょくさくし /全曲作詞/
ぜんきょくしゅう /全曲集/
ぜんきょくすう /全曲数/
ぜんきょくちゅう /全曲中/
ぜんきょくばん /全曲版/
ぜんきよう /前期用/
ぜんきろく /全記録/
ぜんきん /前金/漸近/
ぜんきんあんていせい /漸近安定性/
ぜんきんしき /漸近式/
ぜんきんせん /漸近線/
ぜんきんだい /前近代/
ぜんきんだいてき /前近代的/
ぜんきんち /漸近値/
ぜんきんてき /漸近的/
ぜんきんほう /漸近法/
ぜんぎ /前戯/
ぜんぎいん /全議員/前議員/
ぜんぎょう /前行/
ぜんぎろん /全議論/
ぜんぎん /全銀/
ぜんぎんきょう /全銀協/
ぜんぎんてじゅん /全銀手順/
ぜんく /前駆/全区/
ぜんくうかん /全空間/
ぜんくかん /全区間/前区間/
ぜんくたい /前駆体/
ぜんくつ /前屈/
ぜんくみあわせ /全組合せ/
ぜんくろう /善九郎/
ぜんぐん /全軍/全郡/前群/
ぜんけ /禅家/
ぜんけい /全景/前掲/前傾/前景/全形/全系/
ぜんけいさん /全計算/
ぜんけいしせい /前傾姿勢/
ぜんけいしょ /前掲書/
ぜんけいしょく /前景色/
ぜんけいじ /全掲示/
ぜんけいせいそう /前形成層/
ぜんけいど /前傾度/
ぜんけいよう /前景用/
ぜんけいろ /全経路/
ぜんけつ /全血/
ぜんけん /全県/全権/前件/全検/
ぜんけんいにんじょう /全権委任状/
ぜんけんぶ /前件部/
ぜんげつ /前月/
ぜんげつひ /前月比/
ぜんげつぶん /前月分/
ぜんげん /前言/漸減/善言/
ぜんげんてっかい /前言撤回/
ぜんげんほう /漸減法/
ぜんこ /全戸/前古/
ぜんこう /前項/全校/全高/善行/
ぜんこうがく /全光学/
ぜんこうき /前後期/
ぜんこうざ /全講座/
ぜんこうしきせん /全公式戦/
ぜんこうしゃりん /前後車輪/
ぜんこうじ /善光寺/
ぜんこうせい /前向性/
ぜんこうせいと /全校生徒/
ぜんこうせつ /前後節/
ぜんこうだいいちごう /前項第一号/
ぜんこうてい /全行程;†「旅行の-」/全工程;†「製造の-」/全肯定/
ぜんこうはん /前後半/
ぜんこうへん /前後編/
ぜんこうほ /前候補/全候補/
ぜんこうもく /全項目/
ぜんこく /全国/
ぜんこく> /全国/
ぜんこくいち /全国一/
ぜんこくいっせい /全国一斉/
ぜんこくかくち /全国各地/
ぜんこくきぼ /全国規模/
ぜんこくきょうつう /全国共通/
ぜんこくく /全国区/
ぜんこくこうかい /全国公開/
ぜんこくこうこう /全国高校/
ぜんこくこうこうたいかい /全国高校大会/
ぜんこくこうせん /全国高専/
ぜんこくし /全国紙/
ぜんこくじゅうだん /全国縦断/
ぜんこくじんこう /全国人口/
ぜんこくせいは /全国制覇/
ぜんこくせんばつ /全国選抜/
ぜんこくそしき /全国組織/
ぜんこくたいかい /全国大会/
ぜんこくたんい /全国単位/
ぜんこくちゅうけい /全国中継/
ぜんこくちょうさ /全国調査/
ぜんこくてき /全国的/
ぜんこくてんかい /全国展開/
ぜんこくはつ /全国初/
ぜんこくはつばい /全国発売/
ぜんこくはんばい /全国販売/
ぜんこくばん /全国版/
ぜんこくへいきん /全国平均/
ぜんこくほうえい /全国放映/
ぜんこくほうそう /全国放送/
ぜんこくみん /全国民/
ぜんこくれんらくかい /全国連絡会/
ぜんこたい /全個体/
ぜんこっく /全国区/
ぜんこみぞう /前古未曾有/
ぜんこようしゃ /全雇用者/
ぜんこん /善根/前根/
ぜんご /前後/善後;†「-策」/漸悟;[仏教]⇔頓悟/善吾;人名/禅語/
ぜんごう /前号/全豪/善業/
ぜんごえき /前後駅/
ぜんごかんけい /前後関係/
ぜんごぎゃく /前後逆/
ぜんごさ /前後差/
ぜんごさく /善後策/
ぜんごさゆう /前後左右/
ぜんごじく /前後軸/
ぜんごどう /前後動/
ぜんごどうさ /前後動作/
ぜんごどうじ /前後同時/
ぜんごはんとし /前後半年/
ぜんごふかく /前後不覚/
ぜんごぶんかつ /前後分割/
ぜんごへん /前後編/
ぜんごほうこう /前後方向/
ぜんごりん /前後輪/
ぜんさい /前菜/前妻/
ぜんさぎょう /全作業/
ぜんさく /前作/
ぜんさくじょ /全削除/
ぜんさくちゅう /前作中/
ぜんさくひん /全作品/
ぜんさくひんちゅう /全作品中/
ぜんさつ /禅刹/
ぜんさりん /前左輪/
ぜんさんか /全参加/
ぜんさんかしゃ /全参加者/
ぜんさんかん /全三巻/
ぜんさんぎょうちゅう /全産業中/
ぜんざ /前座/
ぜんざい /善哉/
ぜんざいさん /全財産/
ぜんざじあい /前座試合/
ぜんざん /全山/前残/
ぜんざんじ /前山寺/
ぜんし /全市/前史/全紙/前肢;forelimb/前翅;forewing/禅師/全姉;父母共に同じである(異父・異母でない)姉/全姿/
ぜんしーずん /前シーズン/
ぜんしあい /全試合/前試合/
ぜんしぜんぐん /全市全郡/
ぜんしつ /前室/禅室/
ぜんしつきんえん /全室禁煙/
ぜんしつりょう /全質量/
ぜんしゃ /前者/全社/全車/前車/全射;[数学]surjection/漸写/
ぜんしゃいん /全社員/
ぜんしゃく /前借/
ぜんしゃしてい /全車指定/
ぜんしゃしていせき /全車指定席/
ぜんしゃしゅ /全車種/
ぜんしゃてき /全社的/
ぜんしゃふべん /善者不弁;老子81章「善者不弁、弁者不善」/善者不辯/
ぜんしゃりょう /全車両/
ぜんしゅ /善趣/髯鬚/
ぜんしゅう /全集/前週/禅宗/全周/全州/膳羞/
ぜんしゅうはすう /全周波数/
ぜんしゅうばん /全集版/
ぜんしゅうもの /全集物/
ぜんしゅうろく /全収録/
ぜんしゅしょう /前首相/
ぜんしゅつ /前出/
ぜんしゅるい /全種類/
ぜんしょ /全書/善処/全所/善書/
ぜんしょう /全勝/全焼/前章/前哨/前生/全章/全称;⇔特称/前檣/∀/
ぜんしょうがい /全生涯/
ぜんしょうきごう /全称記号/
ぜんしょうきょ /全消去/
ぜんしょうせん /前哨戦/
ぜんしょうとう /前照灯/
ぜんしょうば /全勝馬/
ぜんしょうひん /全商品/
ぜんしょうめい /全証明/
ぜんしょうゆうしょう /全勝優勝/
ぜんしょく /前職/前蜀;[中国史]十国の一(907-925)/
ぜんしょくぎょう /前職業/
ぜんしょちょう /前所長/
ぜんしょり /全処理/
ぜんしろう /善四郎/
ぜんしん /全身;whole body/前進;advance/前身;predecessor/漸進;gradual advance/善神/前震;foreshock.⇔本震/前信;previous letter/善心/前審/
ぜんしんうんどう /全身運動/
ぜんしんがた /前進型/
ぜんしんけい /全神経/
ぜんしんごう /全信号/
ぜんしんしゃしん /全身写真/
ぜんしんしゅび /前進守備/
ぜんしんせい /漸新世;[地質年代]Oligocene. 3540-2330万年前/
ぜんしんぜんれい /全身全霊/
ぜんしんだぼく /全身打撲/
ぜんしんちゅう /前進中/
ぜんしんてき /漸進的/
ぜんしんますい /全身麻酔/
ぜんしんやけど /全身火傷/
ぜんしんよく /全身浴/
ぜんじ /漸次/禅師/善司/善事/
ぜんじぎょう /全事業/
ぜんじく /全軸/
ぜんじこく /全時刻/
ぜんじたい /前時代/
ぜんじだい /前時代/
ぜんじだいてき /前時代的/
ぜんじちたい /全自治体/
ぜんじっけん /前実験/
ぜんじつ /前日/全日/
ぜんじつせつえい /前日設営/
ぜんじつひ /前日比/
ぜんじつらい /前日来/
ぜんじどう /全自動/
ぜんじどうか /全自動化/
ぜんじどうせんたくき /全自動洗濯機/
ぜんじゅうきょ /前住居/
ぜんじゅうりょう /全重量/
ぜんじゅつ /前述/
ぜんじゅん /前順/
ぜんじゅんい /全順位/
ぜんじゅんじょ /全順序/前順序/
ぜんじょ /全女/
ぜんじょう /前条/禅定/禅譲/善場/
ぜんじょうきゃく /全乗客/
ぜんじょうに /禅定尼/
ぜんじょうもん /禅定門/
ぜんじょせい /全女性/
ぜんじろう /善次郎/善二郎/
ぜんじん /全人;†whole person.「-教育」/前人;†predecessors.「-未踏」/
ぜんじんいん /全人員/
ぜんじんかいぎ /善人会議/
ぜんじんかく /全人格/
ぜんじんかくてき /全人格的/
ぜんじんきょういく /全人教育/
ぜんじんこう /全人口/
ぜんじんてき /全人的/
ぜんじんみとう /前人未踏/
ぜんじんるい /全人類/
ぜんじんるいてき /全人類的/
ぜんすう /全数/
ぜんすうちょうさ /全数調査/
ぜんず /全図/
ぜんせ /前世/
ぜんせい /全盛/善政/前世/全勢/
ぜんせいき /全盛期/前世紀/
ぜんせいけん /前政権/
ぜんせいじ /全盛時/
ぜんせいじだい /全盛時代/
ぜんせいせき /全成績/
ぜんせいせつ /前成説;[生物]/
ぜんせいは /全制覇/
ぜんせいひん /全製品/
ぜんせいぶん /全成分/
ぜんせいめいたい /全生命体/
ぜんせいりょく /全勢力/
ぜんせかい /全世界/前世界/
ぜんせかいきょうつう /全世界共通/
ぜんせかいたいおう /全世界対応/
ぜんせかいてき /全世界的/
ぜんせき /全席/前席/
ぜんせききんえん /全席禁煙/
ぜんせきこしつ /全席個室/
ぜんせきしてい /全席指定/
ぜんせきじゆう /全席自由/
ぜんせきじゆうせき /全席自由席/
ぜんせきにん /全責任/
ぜんせたい /全世帯/
ぜんせだい /前世代/
ぜんせつ /前節/前説/
ぜんせりょうほう /前世療法/
ぜんせん /前線/全線/善戦/全戦/
ぜんせんかいぎょう /全線開業/
ぜんせんかいつう /全線開通/
ぜんせんきょく /全選挙区/
ぜんせんしゅ /全選手/
ぜんせんしゅさんか /全選手参加/
ぜんせんぜんえき /全線全駅/
ぜんせんたんせん /全線単線/
ぜんせんちか /全線地下/
ぜんせんでんか /全線電化/
ぜんせんふくせん /全線複線/
ぜんせんふつう /全線不通/
ぜんぜつ /前舌/
ぜんぜつぼいん /前舌母音;[音声学]front vowel. 「イ」/
ぜんぜん /全然/前々/前前/全々/
ぜんぜんかい /前々回/前前回/
ぜんぜんげつ /前々月/
ぜんぜんしつ /前々室/
ぜんぜんしゅう /前々週/
ぜんぜんじつ /前々日/
ぜんぜんそう /前前走/
ぜんぜんだめ /全然駄目/
ぜんぜんへいき /全然平気/
ぜんぜんべつ /全然別/
ぜんぜんもんだい /全然問題/
ぜんそ /髯蘇/
ぜんそう /前走/前奏/禅僧/全層/全奏/
ぜんそうきょく /前奏曲/
ぜんそうきょくさくひん /前奏曲作品/
ぜんそうきょくしゅう /前奏曲集/
ぜんそうこうきょり /全走行距離/
ぜんそうご /前走後/全奏後/
ぜんそうさ /全操作/
ぜんそうしゃ /前走者/前走車/
ぜんそうなだれ /全層雪崩/
ぜんそうなみ /前走並/
ぜんそく /喘息/全速/
ぜんそくりょく /全速力/
ぜんそん /全損/全村/
ぜんぞう /漸増/
ぜんたい /全体/全隊/
ぜんたいいき /全帯域/
ぜんたいかいぎ /全体会議/
ぜんたいかんり /全体管理/
ぜんたいこうげき /全体攻撃/
ぜんたいこうせい /全体構成/
ぜんたいし /全体子/
ぜんたいしゅうごう /全体集合/
ぜんたいしゅぎ /全体主義/
ぜんたいしゅぎしゃ /全体主義者/
ぜんたいしゅぎてき /全体主義的/
ぜんたいじゅう /全体重/
ぜんたいじょうほう /全体情報/
ぜんたいすう /全体数/
ぜんたいず /全体図/
ぜんたいせい /全体性/
ぜんたいぞう /全体像/
ぜんたいてき /全体的/
ぜんたいひょうか /全体評価/
ぜんたいほうしん /全体方針/
ぜんたいろん /全体論/
ぜんたろう /善太郎/
ぜんたん /前端/
ぜんたんしゃ /全単射/
ぜんたんまつ /全端末/
ぜんだい /前代/
ぜんだいじん /前大臣/
ぜんだいひょう /前代表/
ぜんだいみもん /前代未聞/
ぜんだおん /前打音/
ぜんだせき /全打席/
ぜんだて /膳立て/
ぜんだてん /全打点/
ぜんだな /膳棚/
ぜんだま /善玉/
ぜんだまきん /善玉菌;⇔悪玉菌/
ぜんだまこれすてろーる /善玉コレステロール/
ぜんだん /前段/全段/
ぜんだんかい /前段階/
ぜんだんぶ /前段部/
ぜんだんめんせき /全断面積/
ぜんち /全治/前置/全地/全知/
ぜんちきゅう /全地球/
ぜんちく /全地区/善竹/
ぜんちし /前置詞/
ぜんちしき /善知識/
ぜんちぜんのう /全知全能/
ぜんちゅう /蠕虫/
ぜんちゅううら /全中裏/
ぜんちょ /前著/
ぜんちょう /全長/前兆/全町/
ぜんちょうげんしょう /前兆現象/
ぜんちょさく /全著作/
ぜんつう /全通/
ぜんつうじ /善通寺/
ぜんつうじし /善通寺市/
ぜんてい /前提/前庭;まえにわ/
ぜんていしき /前提式/
ぜんていじょうけん /前提条件/
ぜんていそう /前庭窓;[解剖]fenestra ovalis/
ぜんていちしき /前提知識/
ぜんてき /全摘;-手術/全的/
ぜんてきしゅつ /全摘出;complete removal. 「子宮を-,-手術」/
ぜんてつ /前轍/
ぜんてん /全店/全天/前転/全点/
ぜんてんこう /全天候;all-weather/
ぜんてんこうがた /全天候型/
ぜんてんしゅう /全天周/
ぜんてんとう /全点灯/
ぜんでら /禅寺/
ぜんでん /前殿;⇔後宮/
ぜんでんか /全電化/
ぜんでんげん /全電源/
ぜんと /前途/全都/
ぜんとう /前頭/全島/全頭/漸騰/
ぜんとうきん /前頭筋/
ぜんとうけんさ /全頭検査/
ぜんとうぶ /前頭部/
ぜんとうよう /前頭葉/
ぜんとうれんごうや /前頭連合野/
ぜんとくてん /全得点/
ぜんとそう /全塗装/
ぜんとたなん /前途多難/
ぜんとむこう /前途無効/
ぜんとようよう /前途洋々/
ぜんとりょうえん /前途遼遠/
ぜんど /全土/髯奴/
ぜんどう /全道/蠕動/善導;善い方へ導く/善道;善い道 (また=善導)/禅堂/禅道/
ぜんどううんどう /蠕動運動/
ぜんな /禅那/
ぜんなん /善男/
ぜんなんかん /全何巻/
ぜんなんぜんにょ /善男善女/
ぜんに /禅尼/
ぜんにこう /前二項/
ぜんにごう /前二号/
ぜんにじゅう /全二重/
ぜんにち /全日/
ぜんにちせい /全日制/
ぜんにっくう /全日空/
ぜんにっくうびん /全日空便/
ぜんにってい /全日程/
ぜんにっていしゅうりょう /全日程終了/
ぜんにっぽん /全日本/
ぜんにっぽんくうゆ /全日本空輸;[企業名]/
ぜんにほん /全日本/
ぜんにほんがくせい /全日本学生/
ぜんにほんくうゆ /全日本空輸;[企業名]/
ぜんにほんこくみん /全日本国民/
ぜんにほんじつぎょうだん /全日本実業団/
ぜんにほんじょし /全日本女子/
ぜんにほんせんしゅ /全日本選手/
ぜんにほんせんばつ /全日本選抜/
ぜんにほんそうごう /全日本総合/
ぜんにゅう /全入;[略語]全員入学/
ぜんにょ /善女/
ぜんにん /善人/前任/
ぜんにんしゃ /前任者/
ぜんにんち /前任地/
ぜんねん /前年/
ぜんねんど /前年度/
ぜんねんどけっさん /前年度決算/
ぜんねんどひ /前年度比/
ぜんねんひ /前年比/
ぜんねんぶん /前年分/
ぜんねんわれ /前年割れ/
ぜんのーど /全ノード/
ぜんのう /前納/全能/全農/全納/全脳/前脳;forebrain/
ぜんのうしゃ /全能者/
ぜんのうせい /全能性/
ぜんのうりょく /全能力/
ぜんのすけ /善之助/
ぜんはい /全廃/前胚/
ぜんはく /前膊/
ぜんはくぎゅう /冉伯牛;孔子の弟子/
ぜんはっせい /全発声/
ぜんはん /前半/全版/
ぜんはんい /全範囲/
ぜんはんき /前半期/
ぜんはんこうはん /前半後半/
ぜんはんころ /前半頃/
ぜんはんごろ /前半頃/
ぜんはんさいご /前半最後/
ぜんはんしゃ /全反射/
ぜんはんしゅうりょう /前半終了/
ぜんはんせい /前半生/
ぜんはんせん /前半戦/
ぜんはんぶ /前半部/
ぜんはんぶぶん /前半部分/
ぜんはんぶん /前半分/
ぜんば /前場/全馬/
ぜんばん /全判/前版/
ぜんばんぐみ /全番組/
ぜんぱい /全廃/全敗/
ぜんぱく /前泊/全泊/
ぜんぱん /全般/前半;ぜんはん?/
ぜんぱんてき /全般的/
ぜんひてい /全否定/
ぜんひょう /全表/全票/
ぜんび /善美/全備/
ぜんびけ /前引け;[相場]/
ぜんびじゅうりょう /全備重量/
ぜんびん /全便/前便/
ぜんびんうんきゅう /全便運休/
ぜんぴ /前非/
ぜんぴょう /前表/全豹/
ぜんぴん /全品/
ぜんぴんけんさ /全品検査/
ぜんふくじこうえん /善福寺公園/
ぜんふつ /全仏/
ぜんふつう /全普通/
ぜんふれんけつ /全不連結/
ぜんふんにゅう /全粉乳/
ぜんぶ /全部/前部/膳部/
ぜんぶいんよう /全部引用/
ぜんぶおおもじ /全部大文字/
ぜんぶこうかん /全部交換/
ぜんぶざせき /前部座席/
ぜんぶしょうりゃく /全部省略/
ぜんぶすう /全部数/
ぜんぶにゅうりょく /全部入力/
ぜんぶはいし /全部廃止/
ぜんぶはんけつ /全部判決/
ぜんぶふよう /全部不要/
ぜんぶへんかん /全部変換/
ぜんぶへんこう /全部変更/
ぜんぶりゃく /全部略/
ぜんぶん /全文;†full-text.「-検索」/前文;†preamble.「憲法-」/
ぜんぶんいんよう /全文引用/
ぜんぶんけん /全文献/
ぜんぶんけんさく /全文検索/
ぜんぶんや /全分野/
ぜんぷ /前夫/
ぜんぷく /全幅/
ぜんぷれ /全プレ;全員プレゼント/
ぜんへい /全閉/
ぜんへいじ /全閉時/
ぜんへんかん /全変換/
ぜんへんきょく /全編曲/
ぜんへんどう /全変動/
ぜんべい /全米/
ぜんべいいち /全米一/
ぜんべいかくち /全米各地/
ぜんべいがくせい /全米学生/
ぜんべいこうかい /全米公開/
ぜんべいじょし /全米女子/
ぜんべいせんしゅけん /全米選手権/
ぜんべいだいひょう /全米代表/
ぜんぺーじ /前ページ/全ページ/前頁/
ぜんぺい /全閉/
ぜんぺき /前壁/
ぜんぺん /前編/全編/前篇/全篇/
ぜんほうい /全方位/
ぜんほうこう /全方向/
ぜんほうしき /全方式/
ぜんほうそうきょく /全放送局/
ぜんほそう /全舗装/
ぜんぼいん /全母音/
ぜんぼう /全貌/
ぜんぼうず /禅坊主/
ぜんぽう /前方/
ぜんぽういっち /前方一致/
ぜんぽうかいてん /前方回転/
ぜんぽうこうえんふん /前方後円墳/
ぜんぽうさゆう /前方左右/
ぜんぽうさんしょう /前方参照/
ぜんぽうさんらんこう /前方散乱光/
ぜんぽうしかい /前方視界/
ぜんぽうしょうがいぶつ /前方障害物/
ぜんぽうじ /善宝寺/
ぜんぽうていい /前方定位/
ぜんぽうふちゅうい /前方不注意/
ぜんぽうやく /前方約/
ぜんぽん /善本/
ぜんまい /薇;(山菜)/発条;spring/撥条;=発条/全妹;父母共に同じである(異父・異母でない)妹/發条;「発」旧字/
ぜんまく /善悪/
ぜんみ /禅味/
ぜんみりょく /全魅力/
ぜんみん /全民/
ぜんみんぞく /全民族/
ぜんめい /喘鳴/
ぜんめいがら /全銘柄/
ぜんめいじん /前名人/
ぜんめつ /全滅/
ぜんめつすんぜん /全滅寸前/
ぜんめん /全面;(overall) -戦争/前面;(front) -に押し出す/
ぜんめんうんきゅう /全面運休/
ぜんめんか /全面可/
ぜんめんかいしゅう /全面回収/
ぜんめんかいてい /全面改定/
ぜんめんかぶ /前面下部/
ぜんめんかんつう /前面貫通/
ぜんめんきんえん /全面禁煙/
ぜんめんきんし /全面禁止/
ぜんめんこうこく /全面広告/
ぜんめんさんか /全面参加/
ぜんめんさんせい /全面賛成/
ぜんめんせんそう /全面戦争/
ぜんめんたいけつ /全面対決/
ぜんめんだか /全面高/
ぜんめんちゅうし /全面中止/
ぜんめんちゅうしゃきんし /全面駐車禁止/
ぜんめんつうこうきんし /全面通行禁止/
ぜんめんてき /全面的/
ぜんめんてききょうりょく /全面的協力/
ぜんめんてったい /全面撤退/
ぜんめんてんぼう /前面展望/
ぜんめんはいし /全面廃止/
ぜんめんやす /全面安/
ぜんもう /全盲/全毛/
ぜんもん /全問;all the questions/前問;previous question/前門;front gate/禅門/
ぜんもんかいとう /全問解答/
ぜんもんせいかい /全問正解/
ぜんもんどう /禅問答/
ぜんや /前夜/善也/
ぜんやく /全訳/前約/善役/
ぜんやさい /前夜祭/
ぜんゆ /全癒/
ぜんゆう /善友;⇔悪友/
ぜんゆうかい /全有界/
ぜんゆうきたんそりょう /全有機炭素量/
ぜんゆうれん /全遊連/
ぜんよう /全容/前葉/善用/冉雍;孔子の弟子/
ぜんようかいめい /全容解明/
ぜんようそ /全要素/
ぜんようたい /前葉体/
ぜんようりょう /全容量/
ぜんよく /前翼/
ぜんら /全裸/
ぜんらく /漸落/
ぜんらなんどう /全羅南道;地名,(cholla-nam-do) 韓国/
ぜんらほくどう /全羅北道;地名,(cholla-buk-do) 韓国/
ぜんらん /全卵/
ぜんりつ /全律/
ぜんりつせん /前立腺/
ぜんりつせんがん /前立腺癌/前立腺がん/前立腺ガン/
ぜんりつせんひだい /前立腺肥大/
ぜんりつせんひだいしょう /前立腺肥大症/
ぜんりゃく /前略/全略/
ぜんりゅうふん /全粒粉/
ぜんりょう /善良/全量/全寮/
ぜんりょういき /全領域/
ぜんりょうせい /全寮制/
ぜんりょく /全力/
ぜんりょくうんてん /全力運転/
ぜんりょくかそく /全力加速/
ぜんりょくしっそう /全力疾走/
ぜんりょくとうきゅう /全力投球/
ぜんりょてい /全旅程/
ぜんりん /前輪/善隣/禅林/
ぜんりんかじゅう /前輪荷重/
ぜんりんがいこう /善隣外交;good-neighbor policy/
ぜんりんがわ /前輪側/
ぜんりんくどう /前輪駆動/
ぜんれい /前例/全例/全霊/全零/
ぜんれいちゅう /全冷中/
ぜんれき /前歴/
ぜんれっしゃ /全列車/
ぜんれっしゃていしゃ /全列車停車/
ぜんれつ /前列/全裂/
ぜんろう /全労/
ぜんろうさい /全労済;[略語]全国労働者共済生活協同組合連合会。www.zenrosai.or.jp/
ぜんろせん /全路線/
ぜんわ /全話/禅話/
ぜんわくせい /全惑星/
ぜんわだい /前話題/
ぜんわろくが /全話録画/
ぜんわん /前腕;forearm/前弯/全湾/
そ /素/疎/楚;中国の王朝/粗;raw/祖;ancestor/租;tax/組;pair/狙;狙撃/阻;阻害/俎;俎上/爼;「俎」の異体字/姐;あね/岨;嶮岨/咀;咀嚼/徂;荻生徂徠/沮;沮喪/疽;壊疽/詛;呪詛/齟;齟齬/塑;可塑性/遡;遡及的/溯;≒遡/愬;≒訴. うったえ/泝;≒遡. さかのぼ・る/訴;訴訟/曾/曽;「曾」の異体字/噌;味噌/囎/祚;践祚/胙;ひもろぎ/酢;す/措;措置/醋;す/疏;疏註/蔬;蔬菜/酥;煮詰めた乳/蘇;蘇生/蘓;「蘇」の異体字/甦;≒蘇/礎;基礎/麁;≒粗/踈;「疎」の異体字/鼡;「鼠」の異体字/鼠;ねずみ/想;(慣用音) 愛想/
そ> /粗;(crude) 粗鉄,粗脂肪率,粗製品/
そーすいため /ソース炒め/
そーすに /ソース煮/
そーず /索子/
そーだ /曹達/
そーだすい /ソーダ水;soda/
そーぷじょう /ソープ嬢/
そーらんぶし /ソーラン節/
そあく /粗悪/
そあくひん /粗悪品/
そあん /素案/
そい /粗衣/添い/
そいずみ /祖泉/
そいそしょく /粗衣粗食/
そいちち /添い乳/
そいね /添い寝/添寝/
そいん /素因;factor/訴因;[法]count/疎音/
そいんし /素因子/
そいんすう /素因数/
そいんすうぶんかい /素因数分解/
そう /層/総/相/僧/躁;⇔鬱/想/宋/草/荘;トキワ荘/装;武装/走/葬/騒/送/早/艘;(助数詞) 舟を数える/双/雙;「双」の旧字/槽;浴槽/曹;曹操/漕;こ・ぐ/糟;かす/遭;遭遇/艚;こぶね/聡/總/聰;「聡」の旧字/挿;挿入/插;「挿」の旧字/漱;漱石/嗽;うがい/抓;つね・る/笊;ざる/掻;掻爬/蚤;のみ/騷;「騒」の旧字(人名用漢字)/簇;簇生/蔟;まぶし/叢;叢書/薮;やぶ/籔;ざる/竈;かまど/竃;「竈」の異体字/屮/艸;くさ/奏;演奏/湊;みなと/輳;輻輳/霜;しも/孀;やもめ/廂;ひさし/箱;はこ/巣;卵巣/勦;勦討/樔/噌;味噌/曾;曾祖父/曽;「曾」の異体字/贈;(漢音) 寄贈/甑;こしき/宗;宗家/崇;崇拝/綜;錯綜/淙/踪;失踪/庄/壮;壮絶/壯;「壮」の旧字(人名用漢字)/奘/弉;「奘」の異体字/莊;「荘」の旧字(人名用漢字)/裝;「装」の旧字(人名用漢字)/掃;掃除/帚;ほうき/箒;ほうき/菷;「帚」の異体字/争;戦争/爭;「争」の旧字(人名用漢字)/崢/箏;こと/筝;「箏」の異体字/諍;いさかい/惣;惣菜/葱;ねぎ/偬/匆/怱;(いそぐ)/愡;(「惚」とは別)/捜;捜査/痩;痩身/叟;おきな/嫂;あによめ/搜;「捜」の旧字(人名用漢字)/歃;すする/繰;く・る/操;操作/燥;乾燥/藻;藻類/噪;喧噪/懆/澡;あらう/譟;さわぐ/髞/創;創造/倉;倉庫/槍;やり/鎗;やり/蒼;蒼穹/愴;悲愴/搶/滄;滄海/瘡;かさ/艙;船艙/蹌;蹌踉/匝/剏/嗾;使嗾/妝;よそおう/掫/梍;さいかち/赱;「走」の異体字/鯵;あじ/扱;あつか・う/桑;桑田/喪;喪失/爽;爽快/窓;車窓/窗;「窓」の異体字/爪;つめ/炒;いた・める/笙;しょう/然う/然;?/左右/将;(呉音)/漿;(呉音) 漿液/滝;?/瀧;「滝」の旧字(人名用漢字)/
そう> /総/双/
そうあい /相愛/
そうあげ /総揚げ/
そうあたり /総当たり/総当り/
そうあたりせん /総当たり戦/
そうあん /草案;draft/草庵;hut/創案;invent/操安;[略語]操縦安定性/僧庵;priest's hut/
そうあんせい /操安性/
そうい /相違/創意;invention/総意;consensus/相異;≒相違/僧衣;(ころも)/僧位;(くらい)/創痍;満身-/
そういくふう /創意工夫/
そういち /宗一/壮一/聡一/宗市/
そういちじ /双一次/
そういちろう /宗一郎/総一郎/総一朗/聡一郎/壮一郎/惣一郎/
そういっそう /層一層/
そういてん /相違点/相異点/
そういれかえ /総入れ替え/
そういれば /総入れ歯/
そういん /僧院/総員/掃引;sweep/挿引;?/
そううつ /躁鬱/
そううつしつ /躁鬱質/
そううつびょう /躁鬱病/
そううりあげ /総売上/
そううりあげだか /総売上高/
そううん /層雲/叢雲;むらくも/曾雲/
そううんきょう /層雲峡/
そうえん /荘園/桑園/装苑/操演/蒼鉛/
そうえんそう /総演奏/
そうえんちょう /総延長/
そうえんふん /双円墳;○○/
そうおう /相応/
そうおく /草屋/
そうおん /騒音/噪音/宋音/相恩/
そうおんきせい /騒音規制/
そうおんきせいほう /騒音規制法/
そうおんけい /騒音計/
そうおんげん /騒音源/
そうおんせいぎょ /騒音制御/
そうおんそくてい /騒音測定/
そうおんたいさく /騒音対策/
そうおんひょうか /騒音評価/
そうおんぼうし /騒音防止/
そうおんもんだい /騒音問題/
そうおんれべる /騒音レベル/
そうか /草加;地名,埼玉/創価;宗教団体/装花;花の飾り付け/層化/相加;-平均/装荷/喪家;喪中の家/僧伽/総科/挿花/痩果/葬歌;requiem/送荷/総嫁;streetwalker/
そうかい /総会/爽快;refreshing/壮快;exciting/蒼海/滄海;-桑田/掃海/僧階/
そうかいかん /爽快感/
そうかいしゅうりょうご /総会終了後/
そうかいじょう /層階状/
そうかいせつ /総解説/
そうかいそうでん /滄海桑田/
そうかいてい /掃海艇/
そうかいや /総会屋/
そうかがっかい /創価学会/
そうかく /総画/総角;(髪型)/双角/
そうかくさくいん /総画索引/
そうかくすう /総画数/
そうかこうこう /創価高校/
そうかし /草加市/
そうかせい /走化性;[生物]/
そうかだいがく /創価大学/
そうかつ /総括/総轄/
そうかつてき /総括的/
そうかつはん /総括班/
そうかつひょう /総括表/
そうかへいきん /相加平均/
そうかん /創刊/相関/壮観/総監/送還/相姦/層間/送棺/
そうかんかんけい /相関関係/
そうかんかんすう /相関関数/
そうかんき /相関器/
そうかんぎょうれつ /相関行列/
そうかんけいすう /相関係数/
そうかんごう /創刊号/
そうかんしゃ /相姦者/
そうかんじょう /総勘定/
そうかんじょうもとちょう /総勘定元帳/
そうかんず /相関図/
そうかんせい /相関性/総完成/
そうかんとく /総監督/
そうかんど /相関度/
そうが /装画/挿画/爪牙/草画/
そうがい /窓外/霜害/
そうがかり /総掛り/
そうがく /総額/奏楽/宋学/
そうがく> /総額/
そうがくどう /奏楽堂/
そうがくひょうじ /総額表示/
そうがそすう /総画素数/
そうがな /草仮名/
そうがわ /総革/
そうがん /双眼/
そうがんきょう /双眼鏡/
そうき /早期/想起/総記/送気/装軌/
そうき> /早期;-発見,-治療,-警戒/
そうきかいけつ /早期解決/
そうきがん /早期癌/
そうききょういく /早期教育/
そうきけいかい /早期警戒/
そうきけっちゃく /早期決着/
そうきさくせい /早期作成/
そうきじすう /総記事数/
そうきじつようか /早期実用化/
そうきぜせいそち /早期是正措置/
そうきたいおう /早期対応/
そうきたいしょく /早期退職/
そうきはっけん /早期発見/
そうきば /双牙/
そうきひじゅん /早期批准/
そうきへい /槍騎兵/
そうきゃく /双脚/
そうきゅう /早急/送球/蒼穹/躁急/
そうきゅうるい /双弓類/
そうきょ /壮挙/巣居/
そうきょう /曾鞏;1019-1083/
そうきょういく /早教育/
そうきょく /総局/箏曲/双曲/双極/
そうきょくし /双極子/
そうきょくせん /双曲線/
そうきょくせんかんすう /双曲線関数/
そうきょくちょう /総局長/
そうきょくほうしゃ /双極放射/
そうきょくめん /双曲面/
そうきん /送金/鎗金/
そうきんがく /送金額/
そうきんだい /送金代/
そうきんだいこう /送金代行/
そうきんほうほう /送金方法/
そうきんりつ /送金率/
そうきんりょう /送金料/
そうきんるい /藻菌類/
そうぎ /葬儀/争議/
そうぎいん /総議員/
そうぎけん /争議権/
そうぎこうい /争議行為/
そうぎしゃ /葬儀社/
そうぎじょう /葬儀場/
そうぎゃ /僧伽/
そうぎや /葬儀屋/
そうぎょ /双魚/草魚/
そうぎょう /創業;found/操業;operate/僧形/早暁/
そうぎょうしゃ /創業者/
そうぎょうたんしゅく /操業短縮/
そうぎょうとうじ /創業当時/
そうぎょうど /操業度/
そうぎょうひ /創業費/
そうぎょきゅう /双魚宮;[十二宮]うお座(2.19-3.20)/
そうぎり /総桐/
そうぎん /相銀;[略語]相互銀行/
そうく /走狗/痩躯/
そうくう /蒼空/
そうくうかん /相空間/
そうくかく /総区画/
そうくずれ /総崩れ/
そうくつ /巣窟/
そうくん /宗薫/
そうぐ /装具/僧供/
そうぐう /遭遇/
そうぐうりつ /遭遇率/
そうぐち /荘口;姓/
そうぐん /総軍/
そうけ /宗家/
そうけい /総計/早計/早慶/
そうけいせん /早慶戦/
そうけいめい /早慶明/
そうけっき /総決起/
そうけっきしゅうかい /総決起集会/
そうけっさん /総決算/
そうけつ /総結/
そうけつごう /総結合/
そうけん /総研;[略語]総合研究所/創建/送検/壮健/総見/双肩/創見/想見/
そうけんしゅっぱん /総研出版;[出版社名]/
そうげい /送迎/
そうげいかい /送迎会/
そうげいばす /送迎バス/
そうげいよう /送迎用/
そうげつ /草月/
そうげん /草原/創元/荘厳;「そうごん」又は「しょうげん」?/
そうげんしゃ /創元社;[出版社名]www.sogensha.co.jp/
そうげんすいりぶんこ /創元推理文庫/
そうげんたいご /壮言大語/
そうげんちたい /草原地帯/
そうげんてん /総減点/
そうげんばん /創元版/
そうげんぶんこ /創元文庫/
そうこ /倉庫/操觚;文筆/
そうこう /走行/装甲/壮行/草稿/送稿;「メールで-する」/奏功;success.「策が-する」/奏効;effect.「薬が-する」/走向;地層の方向/操行/霜降;[二十四節気]10.24頃/爪甲/糟糠;-の妻/倉口;=艙口/艙口;hatch/曹洪;人名,三国志/蒼惶/相好/綜絖/然う斯う/
そうこうあんぜんせい /走行安全性/
そうこうあんていせい /走行安定性/
そうこうおん /走行音/
そうこうか /走行可/
そうこうかい /壮行会;送り出す会/走行会;バイクの-/
そうこうかのう /走行可能/
そうこうかんきょう /走行環境/
そうこうきせい /走行規制/
そうこうきょり /走行距離/
そうこうきょりすう /走行距離数/
そうこうくかん /走行区間/
そうこうくぶん /走行区分/
そうこうぐんだん /装甲軍団/
そうこうけい /走行系/
そうこうけっか /走行結果/
そうこうげき /総攻撃/
そうこうご /走行後/
そうこうしゃ /装甲車/走行車/
そうこうしゃせん /走行車線/
そうこうしゅ /走攻守/
そうこうじ /走行時/
そうこうじあい /壮行試合/
そうこうじかん /走行時間/
そうこうじょうきょう /走行状況/
そうこうじょうけん /走行条件/
そうこうじょうたい /走行状態/
そうこうせい /走行性/走光性;[生物]phototaxis/
そうこうせいのう /走行性能/
そうこうそくど /走行速度/
そうこうちゅう /走行中/
そうこうちょくご /走行直後/
そうこうていこう /走行抵抗/
そうこうのつま /糟糠の妻;-堂を下さず(<後漢書)/
そうこうばん /装甲板/装甲鈑/
そうこうひ /総工費/
そうこうふのう /走行不能/
そうこうふりょう /走行不良/
そうこうまえ /走行前/
そうこうめん /走行面/
そうこうもくすう /総項目数/
そうこうよう /走行用/
そうこうろ /走行路/
そうこえいぎょう /倉庫営業/
そうこがい /倉庫街/
そうこがいしゃ /倉庫会社/
そうこぎょう /倉庫業/
そうこぎょうしゃ /倉庫業者/
そうこく /相克/相剋;=相克/宗国/
そうこしょう /双虎掌/
そうこしょうけん /倉庫証券/
そうこすう /総戸数/
そうこすと /総コスト/
そうこだい /倉庫代/
そうこつ /痩骨/
そうこばん /倉庫番/
そうこほうし /桑弧蓬矢/
そうこん /早婚/草根/愴恨/
そうご /相互/壮語/総吾;人名/總吾/双吾/
そうご> /相互/
そうごいぞん /相互依存/
そうごう /総合/綜合;=総合(別字)/相好/
そうごう> /総合;-保険,-研究所/
そうごうあんないじょ /総合案内所/
そうごううんどうじょう /総合運動場/
そうごうえいようしょく /総合栄養食/
そうごうかがく /総合科学/
そうごうかがくか /総合科学科/
そうごうかがくぶ /総合科学部/
そうごうかくとうぎ /総合格闘技/
そうごうかぜい /総合課税/
そうごうかもく /総合科目/
そうごうかんぼうやく /総合感冒薬/
そうごうがくえん /総合学園/
そうごうきかくぶ /総合企画部/
そうごうぎじゅつ /総合技術/
そうごうけい /総合計/
そうごうけっか /総合結果/
そうごうけんきゅう /総合研究/
そうごうけんきゅうしょ /総合研究所/
そうごうけんきゅうじょ /総合研究所/
そうごうげいじゅつ /総合芸術;Gesamtkunst. 演劇・ゲームなど。/
そうごうこう /総合校/
そうごうこうざ /総合口座/総合講座/
そうごうこうざていき /総合口座定期/
そうごうさく /総合策/
そうごうし /総合誌/
そうごうしかい /総合司会/
そうごうしけんじょ /総合試験所/
そうごうしせつ /総合施設/
そうごうしゅい /総合首位/
そうごうしょうしゃ /総合商社;疑惑の/
そうごうしょく /総合職/
そうごうしれいじょ /総合指令所/
そうごうじゅんい /総合順位/
そうごうじょうほう /総合情報/
そうごうじょうほうしょり /総合情報処理/
そうごうせいさく /総合政策/
そうごうせいさくがく /総合政策学/
そうごうせいさくがくぶ /総合政策学部/
そうごうせいせき /総合成績/
そうごうだいがく /総合大学/
そうごうち /総合値/
そうごうちょうさ /総合調査/
そうごうちょうしゃ /総合庁舎/
そうごうつうしんもう /総合通信網/
そうごうてき /総合的/綜合的/
そうごうてきかんてん /総合的観点/
そうごうてきけんきゅう /総合的研究/
そうごうてすと /総合テスト/
そうごうてん /総合点/
そうごうとうろん /総合討論/
そうごうとくてん /総合得点/
そうごうとしょかん /総合図書館/
そうごうにんげんがくぶ /総合人間学部/
そうごうのうりょく /総合能力/
そうごうはんだん /総合判断/
そうごうひょう /総合表/
そうごうひょうか /総合評価/
そうごうひょうかひょう /総合評価表/
そうごうびょういん /総合病院/
そうごうほけん /総合保険/
そうごうゆうしょう /総合優勝/
そうごうりこう /総合理工/
そうごうりょく /総合力/
そうごうんよう /相互運用/
そうごうんようきょうてい /相互運用協定/
そうごうんようせい /相互運用性/
そうごえいきょう /相互影響/
そうごかしだし /相互貸出/
そうごかん /相互間/
そうごかんけい /相互関係/
そうごかんしょう /相互干渉/
そうごがいしゃ /相互会社/
そうごきょうりょく /相互協力/
そうごぎんこう /相互銀行/
そうごけつごう /相互結合/
そうごけつごうがた /相互結合型/
そうごけつごうもう /相互結合網/
そうごこうかん /相互交換/
そうごこうしん /相互交信/
そうごこうりゅう /相互交流/
そうごごかい /相互誤解/
そうごさよう /相互作用/
そうごさんしょう /相互参照/
そうごしえん /相互支援/
そうごしゅぎ /相互主義/
そうごしんらい /相互信頼/
そうごせい /相互性/
そうごせつぞく /相互接続/
そうごせつぞくじっけん /相互接続実験/
そうごせつぞくせい /相互接続性/
そうごそうかん /相互相関/
そうごそうかんかんすう /相互相関関数/
そうごちょくつう /相互直通/
そうごちょくつううんてん /相互直通運転/
そうごつうこう /相互通行/
そうごのりいれ /相互乗り入れ/相互乗入れ/相互乗入/
そうごはいじょ /相互排除/
そうごはっちゃく /相互発着/
そうごひはん /相互批判/
そうごふじょ /相互扶助/
そうごへんかん /相互変換/
そうごほうもん /相互訪問/
そうごほけん /相互保険/
そうごゆうづう /相互融通/
そうごゆうどう /相互誘導/
そうごよくせい /相互抑制/
そうごりかい /相互理解/
そうごりよう /相互利用/
そうごりんく /相互リンク/
そうごれいき /相互励起/
そうごれんらく /相互連絡/
そうごん /荘厳/
そうさ /操作/捜査/走査;scan/匝瑳;千葉県匝瑳郡/
そうさい /総裁/葬祭/相殺/
そうさいけん /相殺権/
そうさいじょう /葬祭場/
そうさいせいふ /総裁政府;[世界史](1795-99)Le Directoire/
そうさいせん /総裁選/
そうさいっか /捜査一課/
そうさいっかちょう /捜査一課長/
そうさいりょう /葬祭料/
そうさいん /捜査員/操作員/
そうさおん /操作音/
そうさかのう /操作可能/
そうさかん /捜査官/操作感/
そうさかんきょう /操作環境/
そうさきかん /捜査機関/
そうさきょく /捜査局/
そうさきろく /操作記録/
そうさぎょう /総作業/
そうさく /創作/捜索/
そうさくかつどう /創作活動/捜索活動;search effort/
そうさくけい /創作系/
そうさくしょうねん /創作少年/
そうさくしんわ /創作神話/
そうさくじょう /創作上/
そうさくせい /創作性/
そうさくたい /捜索隊/
そうさくちゅう /捜索中/創作中/
そうさくてき /創作的/
そうさくにん /創作人/
そうさくねがい /捜索願/
そうさくぶつ /創作物/
そうさくぼん /創作本/
そうさくよう /創作用/
そうさくりょうり /創作料理/
そうさくりょく /創作力/
そうさけい /操作系/
そうさけん /捜査権/
そうさげんご /操作言語/
そうさし /操作子/
そうさしゃ /操作者/
そうさしゅうはすう /走査周波数/
そうさしゅぎ /操作主義;operationalism/
そうさじっこう /操作実行/
そうさじゅつ /操作術/
そうさじょう /操作上/捜査上/
そうさじん /捜査陣/
そうさせい /操作性/
そうさせつめいしょ /操作説明書/
そうさせん /捜査線;†『大-』/走査線;†scanline/
そうさせんじょう /捜査線上/走査線上/
そうさせんすう /走査線数/
そうさせんもん /捜査専門/
そうさぜんぱん /操作全般/
そうさそうち /走査装置/
そうさそくど /走査速度/
そうさたいけい /操作体系/
そうさたいしょう /操作対象/
そうさたく /操作卓/
そうさちゅう /捜査中/操作中/走査中/
そうさつ /相殺;=そうさい/
そうさていど /操作程度/
そうさてき /操作的/
そうさてきいみ /操作的意味/
そうさてきいみろん /操作的意味論/
そうさてじゅん /操作手順/
そうさてつづき /操作手続/操作手続き/
そうさとうきょく /捜査当局/
そうさはば /走査幅/
そうさはん /捜査班/
そうさはんい /走査範囲/
そうさば /操作場/
そうさばん /操作盤/
そうさぶ /操作部/
そうさぶん /走査分/
そうさほう /操作法/走査法/
そうさほうしき /走査方式/
そうさほうほう /操作方法/
そうさほんぶ /捜査本部/
そうさめい /操作名/
そうさもう /捜査網/
そうさらすう /総皿数/
そうさりょう /操作量/
そうされい /操作例/
そうされいじょう /捜査令状/
そうざい /惣菜/
そうざいや /惣菜屋/
そうざらい /総浚い/
そうざん /早産/
そうざんじ /早産児/
そうし /双子;=ふたご/冊子;≒草子/草子/草紙;≒草子/総司/創始/相思/荘子;=そうじ/宗子/壮士;valiant/双糸/双紙;≒草子/壮志/宋史;二十一史/宗師/繰糸/曾子;BC505-?/宋詞/宗祀/
そうしあげ /総仕上げ/
そうしかいめい /創氏改名/
そうしき /葬式/総指揮/相識/
そうしきかん /総指揮官/
そうしきだい /葬式代/
そうしきゅう /総支給/
そうしきゅうがく /総支給額/
そうしさん /総資産/
そうししゃ /創始者/総支社/
そうしそうあい /相思相愛/
そうしち /惣七/
そうしつ /喪失/
そうしつかん /喪失感/
そうしはいにん /総支配人/
そうしほん /総資本/
そうしほんかいてんりつ /総資本回転率/
そうしもく /双翅目;[生物]Diptera/総翅目;Thysanoptera/
そうしゃ /奏者;player/走者;runner/掃射/操車/壮者/葬車/双射;[数学]bijection/喪車;=葬車/
そうしゃいっそう /走者一掃/
そうしゃえき /総社駅/
そうしゃじょう /操車場/
そうしゅ /宗主/双手/漕手/操守/
そうしゅう /総集/早秋/爽秋/荘周/相州;相模/総州;上総(かずさ|かみつふさ)・下総(しもうさ|しもつふさ)/
そうしゅうえき /総収益/
そうしゅうにゅう /総収入/
そうしゅうへん /総集編/
そうしゅけん /宗主権/
そうしゅこく /宗主国/
そうしゅご /総主語/
そうしゅっかだいすう /総出荷台数/
そうしゅつ /創出/送出/早出/走出/簇出/
そうしゅつえん /総出演/
そうしゅつけん /送出権/
そうしゅつし /走出枝/
そうしゅつじ /送出時/
そうしゅん /早春/
そうしゅんふ /早春賦/
そうしょ /叢書/双書/草書/宋書;二十一史/奏書/
そうしょう /総称/創傷/相生/争訟/宗匠/相承/創唱/相称/
そうしょうかんすう /総称関数/
そうしょうきん /総賞金/
そうしょうてき /総称的/
そうしょうひ /総消費/
そうしょき /総書記/
そうしょく /装飾/草食/僧職/
そうしょくおん /装飾音/
そうしょくか /装飾花;[植物]ornamental flower/
そうしょくきょう /装飾経/
そうしょくご /装飾後/
そうしょくじゅう /草食獣/
そうしょくせい /草食性/
そうしょくてき /装飾的/
そうしょくどうぶつ /草食動物/
そうしょくひん /装飾品/
そうしょくびじゅつ /装飾美術;decolative art/
そうしょくほう /装飾法/
そうしょくまえ /装飾前/
そうしょくもじ /装飾文字/
そうしょくよう /装飾用/
そうしょたい /草書体/
そうしょだい /叢書第/
そうしょとく /総所得/
そうしょようじかん /総所要時間/
そうしよう /双子葉/
そうしようしょくぶつ /双子葉植物/
そうしようるい /双子葉類/
そうしれいかん /総司令官/
そうしれいぶ /総司令部/総指令部;?/
そうしん /送信/痩身;slim/喪神;stun/総身;全身/装身;ornament/喪心;=喪神/壮心;bravery/双親/
そうしんあいて /送信相手/
そうしんあてさき /送信宛先/
そうしんおん /送信音/
そうしんかのう /送信可能/
そうしんかのうか /送信可能化/
そうしんかのうかけん /送信可能化権;[法](著作権法92条2など)/
そうしんがわ /送信側/
そうしんき /送信機/送信器/捜神記/
そうしんきけいとうず /送信機系統図/
そうしんきのう /送信機能/
そうしんきろく /送信記録/
そうしんぎょう /送信行/
そうしんくうちゅうせん /送信空中線/
そうしんぐ /装身具/
そうしんけん /送信権/
そうしんげき /総進撃/
そうしんご /送信後/
そうしんさき /送信先/
そうしんしき /送信式/
そうしんしゃ /送信者/
そうしんしゅうはすう /送信周波数/
そうしんしゅだん /送信手段/
そうしんしゅつりょく /送信出力/
そうしんしょり /送信処理/
そうしんじ /送信時/
そうしんじかん /送信時間/
そうしんじょ /送信所/
そうしんじょう /送信状/
そうしんじょうたい /送信状態/
そうしんそくど /送信速度/
そうしんちゅう /送信中/
そうしんてん /送信点/
そうしんひょう /送信票/送信表/
そうしんぶ /送信部/
そうしんぶぶん /送信部分/
そうしんぼたん /送信ボタン/
そうしんまえ /送信前/
そうしんもじれつ /送信文字列/
そうしんもと /送信元/
そうしんよう /送信用/
そうしんようきゅう /送信要求/
そうじ /掃除/相似/双児/走時/送辞/荘子;=そうし/僧寺/荘司/宗司/挿耳/操持/∽;similar/
そうじうお /掃除魚/
そうじうんそう /相次運送/
そうじかん /総時間/
そうじがた /挿耳型/
そうじき /掃除機/
そうじきゅう /双児宮;[十二宮]ふたご座(5.21-6.20)/
そうじきょくせん /走時曲線/
そうじきよう /掃除機用/
そうじくけっしょう /双軸結晶/
そうじけい /相似形/
そうじさ /走時差/
そうじしょく /総辞職/
そうじじ /総持寺/
そうじせい /相似性/
そうじせんたく /掃除洗濯/
そうじちゅう /掃除中/
そうじつ /桑実/
そうじつはい /桑実胚/
そうじて /総じて/
そうじてん /相似点/
そうじでら /総持寺/
そうじとうばん /掃除当番/
そうじどうぐ /掃除道具/
そうじひ /相似比/
そうじふ /掃除夫/掃除婦/
そうじへんかん /相似変換/
そうじほうほう /掃除方法/
そうじめ /総締め/
そうじゃ /総社/壮者/
そうじや /掃除屋/
そうじゅ /送受/双樹/奏授/
そうじゅう /操縦/層重/
そうじゅうかん /操縦桿/操縦竿/
そうじゅうぎじゅつ /操縦技術/
そうじゅうし /操縦士/
そうじゅうしつ /操縦室/
そうじゅうしゃ /操縦者/
そうじゅうせい /操縦性/
そうじゅうせき /操縦席/
そうじゅうほう /操縦法/
そうじゅうりょう /総重量/
そうじゅうりん /操縦輪/
そうじゅき /送受器/
そうじゅく /早熟/
そうじゅくば /早熟馬/
そうじゅしん /送受信/
そうじゅしんかのう /送受信可能/
そうじゅしんき /送受信機/
そうじゅしんきのう /送受信機能/
そうじゅしんじょうたい /送受信状態/
そうじゅしんせつび /送受信設備/
そうじゅつ /槍術/
そうじゅとも /送受共/
そうじゅわ /送受話/
そうじゅわき /送受話器/
そうじゅん /宗純/走順/
そうじょ /層序/
そうじょう /相乗/層状/僧正/奏上/騒擾/相生/総状/双調;[音楽]/早場/僧上;?/
そうじょうかじょ /総状花序/
そうじょうこうか /相乗効果/
そうじょうざい /騒擾罪/
そうじょうせき /相乗積/
そうじょうたい /躁状態/
そうじょうてき /相乗的/
そうじょうへいきん /相乗平均/
そうじょうほうりょう /総情報量/
そうじようぐ /掃除用具/
そうじろう /宗次郎/
そうじん /騒人/
そうじんこう /総人口/
そうすい /総帥/送水/
そうすいかん /送水管/
そうすう /総数/層数/双数/曹嵩/
そうすかん /総スカン;-を喰う/総すかん/総好かん/
そうず /僧都/挿図/索子/
そうせい /創成/創生/創製/創世;-記/早世/叢生;群がり生える/早逝/走性;[生物]taxis/双星;diaster/奏請/葬制/双生/早成/簇生;=叢生/
そうせいき /創世記;Genesis/創成期;early days/創世紀;?/
そうせいさくひ /総製作費/
そうせいさんすう /総生産数/
そうせいさんりょう /総生産量/
そうせいしんわ /創世神話/創成神話;?/
そうせいじ /双生児/早生児/
そうせいせい /早成性/
そうせいそく /双正則/
そうせき /漱石/僧籍/踪跡/
そうせきうん /層積雲/
そうせきちんりゅう /漱石枕流/
そうせきにんしゃ /総責任者/
そうせつ /創設/総説/霜雪/
そうせついらい /創設以来/
そうせつご /創設後/
そうせつしゃ /創設者/
そうせつじ /創設時/
そうせつとうじ /創設当時/
そうせつひ /創設費/
そうせつろんぶん /総説論文/
そうせん /操船/
そうせんきょ /総選挙/
そうせんけい /双線型/
そうぜい /総勢/
そうぜつ /壮絶/
そうぜん /騒然/蒼然;古色-/愴然;打ち拉がれる様子/
そうぜんじ /崇禅寺/
そうそ /曾祖/
そうそう /早々/葬送/草々;「前略」等で始めた手紙の結び/草創/錚々;-たるメンバー/曹操;三国時代・魏の太祖/草叢/喪葬;喪と葬式/送葬;葬送/滄桑;-の変/層々/蒼々/総々;全部/簇々/匆々/鏘々/怱々/愴々;悲しむ様子/淙々/蹌々/草草/錚錚/早早/総総;全部/蒼蒼/層層/匆匆/怱怱/淙淙/簇簇/鏘鏘/蹌蹌/愴愴;悲しむ様子/然う然う/
そうそうき /草創期/
そうそうきょく /葬送曲/
そうそうこうきょり /総走行距離/
そうそうこうしんきょく /葬送行進曲/
そうそうこうじかん /総走行時間/
そうそうのへん /滄桑の変/
そうそく /総則/相即/
そうそくふり /相即不離/
そうそつ /倉卒/怱卒;=倉卒/
そうそふ /曾祖父/
そうそふぼ /曾祖父母/
そうそぼ /曾祖母/
そうそん /曾孫/
そうぞう /創造;create/想像;imagine/総々/総総/送像/莊三/
そうぞういじょう /想像以上/
そうぞうかい /想像界;[精医]l'imaginaire/
そうぞうがい /想像外/
そうぞうこうい /創造行為/
そうぞうしゃ /創造者/
そうぞうしゅ /創造主/
そうぞうしん /創造神/
そうぞうず /想像図/
そうぞうせい /創造性/
そうぞうせつ /創造説/
そうぞうてき /創造的;†creative/想像的;†imaginary/
そうぞうてきげいじゅつ /創造的芸術/
そうぞうてきこうい /創造的行為/
そうぞうどおり /想像通り/
そうぞうにんしん /想像妊娠/
そうぞうぶつ /創造物/
そうぞうりょく /想像力;imagination/創造力;creativity/
そうぞく /相続/装束/僧俗/宗族/相續;「続」旧字/
そうぞくあらそい /相続争い/
そうぞくかいふく /相続回復/
そうぞくけん /相続権/
そうぞくさいけんしゃ /相続債権者/
そうぞくざいさん /相続財産/
そうぞくしゃ /相続者/
そうぞくぜい /相続税/
そうぞくぜいほう /相続税法/
そうぞくにん /相続人/
そうぞくぶん /相続分/
そうぞくほう /相続法/
そうぞくほうき /相続放棄/
そうたい /総体;total/相対;relative/早退/双対;dual/総隊/草体/僧体/
そうたい> /相対;-主義,-年代/
そうたいいち /相対位置/
そうたいうずど /相対渦度/
そうたいうんどう /相対運動/
そうたいおん /相対音/
そうたいおんかん /相対音感/
そうたいか /相対化/双対化/
そうたいかかく /相対価格/
そうたいかんけい /相対関係/
そうたいきけんど /相対危険度/
そうたいきょり /相対距離/
そうたいくうかん /双対空間/
そうたいけん /相対権/
そうたいごさ /相対誤差/
そうたいざひょう /相対座標/
そうたいしつど /相対湿度/
そうたいしゅぎ /相対主義/
そうたいじかん /相対時間/
そうたいせい /相対性/双対性;duality/
そうたいせいげんり /相対性原理/
そうたいせいりろん /相対性理論/
そうたいそくど /相対速度/
そうたいち /相対値/
そうたいてき /相対的;relative/総体的;total/
そうたいてきかち /相対的価値/
そうたいてきはいち /相対的配置/
そうたいばんち /相対番地;[電算]relative address/
そうたいぱす /相対パス/
そうたいひ /相対比/
そうたいひょうか /相対評価/
そうたいろん /相対論/
そうたいろんてき /相対論的/
そうたつ /送達/宗達/
そうたん /操短/
そうたんかん /総胆管/
そうだ /操舵/早田/宗田/左右田/曹達/崇田/
そうだい /壮大/総代/早大/相待;[仏教]⇔絶待/早稲田大学;※abbrev/
そうだいいん /早大院/
そうだいかい /総代会/
そうだいしゅっぱんぶ /早大出版部;[出版社名]/
そうだいしょう /総大将/
そうだいせん /早大戦/
そうだいりこう /早大理工/
そうだいりてん /総代理店/
そうだおれ /総倒れ/
そうだか /総高/
そうだかん /操舵感/
そうだがつお /宗太鰹/
そうだしつ /操舵室/
そうだち /総立ち/
そうだつ /争奪/
そうだつせん /争奪戦/
そうだりん /操舵輪/
そうだん /相談/装弾/僧団/早弾/
そうだんあいて /相談相手/
そうだんいん /相談員/
そうだんか /相談可/
そうだんかい /相談会/
そうだんごと /相談事/
そうだんしつ /相談室/
そうだんしゃ /相談者/
そうだんしょ /相談所/
そうだんじょ /相談所/
そうだんすう /装弾数/
そうだんないよう /相談内容/
そうだんび /相談日/
そうだんまどぐち /相談窓口/
そうだんやく /相談役/
そうち /装置/送致/葬地/
そうちけい /装置系/
そうちこうじょう /装置工場/
そうちぜんたい /装置全体/
そうちばんごう /装置番号/
そうちほんたい /装置本体/
そうちめい /装置名/
そうちゃく /装着/早着/
そうちゃくいち /装着位置/
そうちゃくえき /装着液/
そうちゃくか /装着可/
そうちゃくかくにん /装着確認/
そうちゃくかのう /装着可能/
そうちゃくかん /装着感/
そうちゃくがた /装着型/
そうちゃくぎむ /装着義務/
そうちゃくしゃ /装着車/
そうちゃくじ /装着時/
そうちゃくじかん /装着時間/
そうちゃくじょうたい /装着状態/
そうちょう /早朝/総長/曹長/荘重/宋朝/双調/宗澄/
そうちょうしんや /早朝深夜/
そうちょうせき /曹長石;albite/
そうちょうたい /宋朝体/
そうちょうばんぐみ /早朝番組/
そうちょうびん /早朝便/
そうつい /双対/相対/
そうついくうかん /双対空間/
そうついてき /双対的/
そうついてん /相対点/
そうつう /相通/
そうてい /想定/装丁/装幀;=装丁/漕艇/送呈/壮丁;壮年男性/装釘;=装丁/
そうていがい /想定外/
そうていじょう /想定上/
そうていじょうけん /想定条件/
そうていず /想定図/
そうていずみ /想定済み/
そうていもんだいしゅう /想定問題集/
そうてつ /相鉄/蒼鉄/
そうてつせん /相鉄線/
そうてつどう /総鉄道/
そうてつやまとえき /相鉄大和駅/
そうてん /争点/蒼天/装填/総点/操典/
そうてんい /相転移/層転移/
そうてんかんりょう /装填完了/
そうてんけん /総点検/
そうてんねんしょく /総天然色/
そうで /総出/
そうでん /送電/相伝/叢伝/
そうでんけい /送電系/
そうでんせん /送電線/
そうでんもう /送電網/
そうと /僧徒/壮途;†勇ましい出立/壮図;†壮大な企て/
そうとう /相当/総統/掃討/双頭/相等/争闘/想到/掃蕩/総当/
そうとう> /相当;-悪質,-重い/
そうとうあくしつ /相当悪質/
そうとういんがかんけい /相当因果関係/
そうとうかくご /相当覚悟/
そうとうがく /相当額/
そうとうきけん /相当危険/
そうとうこうすう /総投稿数/
そうとうさくせん /掃討作戦/
そうとうざん /相当算/
そうとうしがく /総投資額/
そうとうしゅう /曹洞宗/
そうとうしんこく /相当深刻/
そうとうすう /相当数/
そうとうせい /相等性/
そうとうせん /総統選/
そうとうたいへん /相当大変/
そうとうひょうしゃ /総投票者/
そうとうひょうすう /総投票数/
そうとうひん /相当品/
そうとうふ /総統府/
そうとうへんか /相当変化/
そうとうまえ /相当前/
そうとうむり /相当無理/
そうとうめんどう /相当面倒/
そうとうりょう /相当量/
そうとく /総督/
そうとくてん /総得点/
そうとくふ /総督府/
そうとめ /早乙女/
そうどう /騒動/相同/草堂/僧堂/
そうどういん /総動員/
そうどうし /相動詞/
そうどうせん /双胴船/
そうどり /総取り/
そうない /層内/
そうなめ /総なめ/総ナメ/総嘗め/
そうなん /遭難/
そうなんき /遭難機/
そうなんしゃ /遭難者/
そうなんじ /遭難時/
そうなんじこ /遭難事故/
そうに /僧尼/
そうにかい /総二階;[建築]一階と二階の床の形が同じ/
そうにっすう /総日数/
そうにゅう /挿入/総入/
そうにゅうか /挿入歌/総入荷/
そうにゅうかしゅう /挿入歌集/
そうにゅうがた /挿入型/
そうにゅうきょく /挿入曲/
そうにゅうく /挿入句/
そうにゅうぐち /挿入口/
そうにゅうご /挿入後/
そうにゅうさくじょ /挿入削除/
そうにゅうじ /挿入時/
そうにゅうちょくご /挿入直後/
そうにゅうてん /挿入点/
そうにゅうほう /挿入法/
そうにゅうほうこう /挿入方向/
そうにゅうほうほう /挿入方法/
そうにゅうよう /挿入用/
そうにょう /走繞;[部首]「趣」の繞/爪繞;[部首]「爬」の繞/
そうにんかん /奏任官/
そうねん /壮年/想念/早年/
そうねんき /壮年期/
そうねんだんし /壮年男子/
そうは /走破/争覇/掻爬/
そうはい /送配/
そうはいきりょう /総排気量/
そうはく /蒼白/糟粕/
そうはくそ /曾伯祖/
そうはせい /走破性/
そうはち /壮八/
そうはつ /創発/双発/早発/総髪/
そうはつき /双発機/
そうはつてき /創発的/
そうはつでんりょう /総発電量/
そうはん /相反/
そうはんかんけい /相反関係/
そうば /相場/
そうばい /早梅/層倍/
そうばかん /相場観/
そうばし /相場師/
そうばつ /挿抜/
そうばな /総花/
そうばなてき /総花的/
そうばひょう /相場表/
そうばん /早晩/
そうばんちょう /総番長/
そうひ /曹丕;魏の皇帝/
そうひょう /総評/
そうひよう /総費用/
そうひん /送品/
そうび /装備/壮美/薔薇/
そうびかのう /装備可能/
そうびしゃ /装備車/創美社;[出版社名]/
そうびち /装備値/
そうびひん /装備品/
そうびまんさい /装備満載/
そうびょう /躁病/宗廟/
そうびん /聡敏/双鬢/
そうふ /送付/総譜;score/孀婦;widow/奏譜;?/
そうふう /送風/
そうふうき /送風機/
そうふうこう /送風口/
そうふきん /送付金/
そうふく /僧服/
そうふくしゅう /総復習/
そうふさき /送付先/
そうふほう /送付法/
そうぶ /総武/創部/
そうぶかいそく /総武快速/
そうぶかいそくせん /総武快速線/
そうぶかんこうせん /総武緩行線/
そうぶせん /総武線/
そうぶせんかんこう /総武線緩行/
そうぶだい /相武台/
そうぶてつどう /総武鉄道/
そうぶほんせん /総武本線/
そうぶん /宋文/奏聞;=そうもん/奏文;=上奏文/処分;財産分与/
そうへい /僧兵;armed monk.「比叡山の-」/操兵;兵の訓練/
そうへいこう /相平衡;[物理]phase equilibrium/
そうへいりょく /総兵力/
そうへき /双璧/
そうべつ /送別/層別/壮瞥;地名/
そうべつかい /送別会/
そうほ /相補/宗歩/
そうほう /双方/奏法/走法/総苞/双峰/葬法/総包/宗豊/遭逢/
そうほうこう /双方向/
そうほうこうせい /双方向性/
そうほうこうつうしん /双方向通信/
そうほうこうへんかん /双方向変換/
そうほうしゅうせい /総報酬制/
そうほうだいり /双方代理/
そうほうなっとく /双方納得/
そうほうへん /総苞片/
そうほかんけい /相補関係/
そうほさ /相補鎖/
そうほせい /相補性/
そうほせいげんり /相補性原理/
そうほてき /相補的/
そうほぶんぷ /相補分布;[言語]complementary distribution/
そうほん /草本/装本/
そうほんけ /総本家/
そうほんざん /総本山/
そうほんすう /総本数/
そうほんせい /草本性/
そうほんてん /総本店/
そうほんぶ /総本部/
そうぼう /双眸/相貌/僧坊;僧侶の住居/僧房;=僧坊/蒼氓;人民/蒼茫;青々として広い/僧帽;-筋/想望/怱忙/
そうぼうきん /僧帽筋/
そうぼうべん /僧帽弁/
そうぼり /総掘り/
そうま /相馬/
そうまい /相米;姓/草昧/
そうまいすう /総枚数/
そうまぎょふう /相馬御風;1883-1950/
そうまくり /総捲り/
そうまとう /走馬灯/走馬燈/
そうみ /総身/
そうむ /総務/双務/創夢/
そうむか /総務課/
そうむかいちょう /総務会長/
そうむかかり /総務掛/
そうむがかり /総務掛/
そうむけいやく /双務契約/
そうむしつ /総務室/
そうむしょう /総務省;NB:総務庁、自治省、郵政省が2001年1月の中央省庁再編で再編されたもの/総務相;†大臣/
そうむたんとう /総務担当/
そうむちょう /総務庁;NB:2001年1月の中央省庁再編で総務省に再編された/
そうむてき /双務的/
そうむはん /総務班/
そうむひ /総務費/
そうむぶ /総務部/
そうむぶそうむか /総務部総務課/
そうむぶちょう /総務部長/
そうむら /荘村/
そうめい /聡明/早明/聰明;旧字/
そうめいきょく /奏鳴曲/
そうめいせん /早明戦/
そうめつ /掃滅/剿滅/
そうめん /素麺/双面/創面/索麺/
そうめんせき /総面積/
そうもく /草木/総目/
そうもくじ /総目次/
そうもくばい /草木灰;plant ash. (肥料にする)/
そうもくろく /総目録/
そうもじ /草文字/
そうもん /総門;main gate/惣門;=総門/相聞;-歌/奏聞;天子に奏上する/桑門;[仏教]修行者/僧門;=仏門/艸門;?/
そうもんか /相聞歌;万葉集のラブソング/
そうや /宗谷/
そうやかいきょう /宗谷海峡/
そうやく /創薬/装薬;銃の-/草薬/
そうやま /相山/
そうやみさき /宗谷岬/
そうゆ /総湯;⇔内湯/
そうゆう /総有;[法]/曾遊/
そうゆそうりょう /総輸送量/
そうよう /装用/掻痒;痒いところを掻く。「隔靴-」/相擁/
そうようしゃ /装用者/
そうようりょう /総容量/
そうよく /双翼/
そうよさん /総予算/
そうらく /相楽/
そうらん /総覧/騒乱;†riot.「デモ隊の-」/争乱;†war-torn.「-の世」/総攬/奏覧/
そうらんざい /騒乱罪/
そうり /総理/層理;[地質]bedding/總理;「総」旧字/
そうりえき /総利益/
そうりかんてい /総理官邸/
そうりきょうせい /相利共生;[生物]mutualism/
そうりだいじん /総理大臣/
そうりつ /創立/総立/
そうりつきねんび /創立記念日/
そうりつしゃ /創立者/
そうりふ /総理府;NB:2001年1月の中央省庁再編で内閣府に再編された/
そうりふれい /総理府令/
そうりめん /層理面;[地質]bedding plane/
そうりゅう /層流/蒼龍/双龍/蒼竜/総流/宗留/
そうりゅうざん /早流産/
そうりゅうしゃ /蒼竜社;[出版社名]/
そうりゅうでん /創竜伝/
そうりゅうよく /層流翼/
そうりょ /僧侶/
そうりょう /送料/総量/総領/惣領/爽涼/
そうりょうきせい /総量規制/
そうりょうきせいせいど /総量規制制度/
そうりょうこみ /送料込/
そうりょうさくげんけいかく /総量削減計画/
そうりょうじ /総領事/
そうりょうじかん /総領事館/
そうりょうふたん /送料負担/
そうりょうぶん /送料分/惣領分/
そうりょうべっと /送料別途/
そうりょうべつ /送料別/
そうりょうむりょう /送料無料/
そうりょうりちょう /総料理長/
そうりょく /総力/走力/
そうりょくせん /総力戦/
そうりょふう /僧侶風/
そうりん /装輪;⇔キャタピラ/相輪;仏塔の-/双輪;-となって/叢林;bush/総輪/霜林/僧林;大寺/
そうりんかんけい /相隣関係/
そうりんしゃ /相隣者/
そうるい /藻類/走塁/草類/
そうるび /総ルビ/
そうれい /壮麗/葬礼/壮齢/
そうれつ /葬列/壮烈/
そうれん /操練/
そうれんしゅう /総練習/
そうろ /走路/草露/
そうろう /候/早漏/早老/蹌踉/層楼/
そうろうてい /滄浪亭;中国蘇州の名園/
そうろうぶん /候文/
そうろん /総論/争論/
そうろんさんせい /総論賛成/
そうろんり /総論理/
そうわ /総和/挿話/送話/Σ;Sigma/
そうわき /送話器/
そうわく /総枠/
そうわぐち /送話口/
そうわん /双腕/
そえ /添え/副/添/酘/貮;「弐」の異体字/儲;?/
そえいし /添石/
そえうた /諷歌/
そえかみ /添上/
そえがき /添え書き/添書/
そえき /素液/
そえぎ /添え木/添木/
そえしょ /添書/
そえじ /添字/添え字/
そえじしき /添字式/
そえじま /副島/
そえじょう /添状/添え状/
そえだ /添田/
そえだせん /添田線/
そえぢ /添乳/
そえつどうしゅう /楚越同舟/
そえの /添野/
そえばしら /添え柱;[建築]柱のそばの小柱/
そえぶみ /添文/
そえもの /添え物/
そえや /添谷/
そえん /疎遠/
そお /赭/囎唹;地名,鹿児島/
そおに /赭土/
そか /粗菓/
そかい /疎開/租界/素懐/
そかいさき /疎開先/
そかぎょ /溯河魚/遡河魚/
そかく /組閣/疎隔/素核/阻隔/
そかつ /疎闊/
そが /曽我/蘇我/曾我/疎画/
そがい /阻害/疎外/鼠害;ネズミの害/阻碍;≒阻害/
そがいかん /疎外感/
そがいざい /阻害剤/
そがいせい /疎外性/
そがいよういん /阻害要因/
そがえき /蘇我駅/
そがかん /蘇我間/
そがきょうだい /曽我兄弟/
そがく /訴額/
そがしょうはく /曾我蕭白/
そがのうまこ /蘇我馬子/
そがのえみし /蘇我蝦夷/
そがべ /曽我部/
そがものがたり /曾我物語/
そがん /訴願/
そきゃく /阻却;当該行為の違法性を-するものではない/
そきゅう /訴求;appeal.「消費者に-する」/遡及;retrospective.「-効果」/遡求;遡って請求する。「小切手の-」/
そきゅうこう /遡及効/
そきゅうりょく /訴求力/
そぎ /枌/
そぎぎり /削ぎ切り;斜め薄切り.「鶏肉の-」/
そぎょう /祖業/礎業/
そぎょうれつ /疎行列/
そく /即/速/足/則;法則/側;側面/測;測定/惻;惻隠/息;消息/熄;終熄/束;拘束/仄;平仄/促;催促/捉;捕捉/塞;閉塞/喞;(虫の鳴き声)/蔟;まぶし/
そく> /即;即涅槃,即処刑,即ゲット/
そくあつ /側圧/
そくい /即位;accession.「皇帝の-」/測位;positioning.「全地球-システム(GPS)」/側位/
そくいはん /即違反/
そくいん /惻隠;-の情/仄韻/
そくえい /即詠/
そくえん /測鉛/
そくおう /即応/
そくおん /促音;っ/側音;lateral/
そくおんき /足温器/
そくおんびん /促音便/
そくかんばい /即完売/
そくが /側臥/側芽/
そくがい /即買い;[口]/
そくき /測器/
そくぎれ /即切れ/
そくぎん /即吟/
そくこつ /足骨/
そくこん /側根/
そくさ /側鎖/
そくさい /息災/
そくさいえんめい /息災延命/
そくさん /速算/
そくざ /即座/
そくし /即死/側枝/足趾/側視;[医]lateral vision/
そくしこう /即施行/
そくしつ /側室/
そくしゃ /速射/速写/即車/
そくしゃせい /速射性/
そくしゃほう /速射砲/
そくしゅう /束脩/
そくしゅうせい /即修正/
そくしょくけい /測色計/
そくしん /促進/即身/測深/
そくしんがっきゅう /促進学級/
そくしんき /測深器/
そくしんざい /促進剤/
そくしんじょうぶつ /即身成仏/
そくしんすい /測深錘/
そくしんぜぶつ /即心是仏/
そくしんそくぶつ /即心即仏/
そくしんてき /促進的/
そくしんねんぶつ /即心念仏/
そくしんぶつ /即身仏/
そくしんぼだい /即身菩提/
そくしんらん /束心蘭/
そくじ /即時/即自;[哲学]an sich/即事/
そくじがた /即時型/
そくじく /側軸/
そくじこうこく /即時抗告/
そくじしゅとく /即時取得/
そくじせい /即時性/
そくじっこう /即実行/
そくじつ /即日/
そくじつうしん /即時通信/
そくじつかいひょう /即日開票/
そくじつかのう /即日可能/
そくじつこうふ /即日交付/
そくじてき /即時的;immediate/即自的;an sich/
そくじはん /即時犯/
そくじょ /息女/
そくすい /測錘/
そくせい /促成;†force.「-栽培」/速成;†quick job.「-コース」/側生/即製;†instant.「-チーム」/仄声/
そくせいさいばい /促成栽培/
そくせいどうぶつ /側生動物/
そくせいはん /即成犯/
そくせき /即席/足跡/足蹠/
そくせきめん /即席麺/
そくせこう /即施行/
そくせん /塞栓/側線/測線/
そくせんき /側線器/
そくせんしょう /塞栓症;[医]embolism/
そくせんそっけつ /速戦即決/
そくせんりょく /即戦力/
そくそう /惻愴/
そくそく /促促;慌ただしい/惻惻;悼ましい/促々/惻々/測々/
そくたい /束帯/
そくたいばつ /即体罰/
そくたいほ /即逮捕/
そくたつ /速達/
そくだい /即題/
そくだく /即諾/
そくだん /即断;†即座に決める/速断;†素早く決める/
そくだんそっけつ /即断即決/
そくち /測地/即値/
そくちがく /測地学;geodesy/
そくちけい /測地系/
そくちせん /測地線/
そくちゅうせいし /速中性子/
そくづみ /即詰/
そくづめ /即詰/
そくてい /測定/足底/
そくていかのう /測定可能/
そくていがく /測定学/
そくていき /測定器/測定機/
そくていきぐ /測定器具/
そくていきじゅん /測定基準/
そくていきょり /測定距離/
そくていきよう /測定機用/
そくていきんまく /足底筋膜/
そくていけい /測定系/
そくていけっか /測定結果/
そくていごさ /測定誤差/
そくていし /即停止/
そくていじ /測定時/
そくていじかん /測定時間/
そくていじょうけん /測定条件/
そくていせいど /測定精度/
そくていそうち /測定装置/
そくていたいしょう /測定対象/
そくていち /測定値/
そくていちゅう /測定中/
そくていてん /測定点/
そくていはんい /測定範囲/
そくていぶ /測定部/
そくていぶつ /測定物/
そくていほう /測定法/
そくていほうほう /測定方法/
そくていめん /測定面/
そくていや /測定屋/
そくていよう /測定用/
そくていりょう /測定量/
そくていれい /測定例/
そくてん /測点/側転/
そくてんきょし /則天去私/
そくてんぶこう /則天武后;624?-705/
そくとう /即答/側頭/足刀/速答/側倒/
そくとうせい /即答性/
そくとうにゅう /即投入/
そくとうぶ /側頭部/
そくとうよう /側頭葉/
そくど /速度/測度;measure/束度/
そくどいき /速度域/
そくどいはん /速度違反/
そくどう /側道/速動/
そくどかいぜん /速度改善/
そくどかん /速度感/
そくどきごう /速度記号;[音楽] (eg. Moderato)/
そくどきせい /速度規制/
そくどきろく /速度記録/
そくどく /速読/
そくどけい /速度計/
そくどけいそく /速度計測/
そくどげん /速度源/
そくどこうじょう /速度向上/
そくどごうせい /速度合成/
そくどさ /速度差/
そくどしてい /速度指定/
そくどしんごう /速度信号/
そくどじょうしょう /速度上昇/
そくどせいげん /速度制限/
そくどせいげんひょうしき /速度制限標識/
そくどせいのう /速度性能/
そくどせいぶん /速度成分/
そくどせってい /速度設定/
そくどそくてい /速度測定/
そくどちょうか /速度超過/
そくどちょうせい /速度調整/
そくどちょうせつ /速度調節/
そくどていか /速度低下/
そくどてき /速度的/
そくどとりしまり /速度取締り/
そくどとりしまりき /速度取締機/
そくどば /速度場/
そくどひ /速度比/
そくどひょうか /速度評価/
そくどひょうご /速度標語/
そくどぶんさん /速度分散/
そくどぶんぷ /速度分布/
そくどむせいげん /速度無制限/
そくどゆうせん /速度優先/
そくどろん /測度論/
そくのう /即納/
そくは /側波/
そくはく /促迫/束帛/
そくはたい /側波帯/
そくはっしん /速発進/
そくはつ /即発/束髪/
そくはら /束原/
そくはん /測範/
そくはんかい /即販会/
そくばい /即売/即買/
そくばいかい /即売会/
そくばいきゃく /即売却/
そくばいじょ /即売所/
そくばく /束縛/幾許/若干/
そくばくうんどう /束縛運動/
そくばくかいてん /束縛回転/
そくばくかん /束縛感/
そくばくじょうけん /束縛条件/
そくばくへんすう /束縛変数/
そくばくりょく /束縛力/
そくばん /測板/
そくひつ /速筆/
そくひにょいち /即非如一/
そくび /足尾/素首/
そくぶ /側部/
そくぶつ /即物/
そくぶつせい /即物性/
そくぶつてき /即物的/
そくぶん /仄聞/
そくへき /側壁/
そくへん /側辺/
そくほ /速歩/
そくほう /速報/側方/
そくほうせい /速報性/
そくほうち /速報値/
そくほうつうか /側方通過/
そくほうや /速報屋/
そくまく /側膜/
そくまくたいざ /側膜胎座/
そくまくたいざもく /Parietales/
そくみゃく /側脈/
そくみょう /即妙/
そくめつ /熄滅/
そくめん /側面/
そくめんしえん /側面支援/
そくめんしょうとつ /側面衝突/
そくめんず /側面図/
そくもん /足紋/
そくよう /粗供養/
そくよく /足浴;foot bath/
そくよくせい /側抑制/
そくりき /足力/
そくりゅう /測流/
そくりょう /測量/
そくりょうかんけい /測量関係/
そくりょうき /測量器/
そくりょうきかい /測量器械/
そくりょうぎじゅつ /測量技術/
そくりょうし /測量士/
そくりょうじゅつ /測量術/
そくりょうせん /測量船/
そくりょうほう /測量法/
そくりょく /速力/
そくろ /側路/
そくろう /足労/側廊/
そくろん /束論/
そくろんてき /束論的/
そくわん /側弯/
そくわんしょう /側弯症/
そけい /鼠径/祖型/鼠蹊;=鼠径/
そけいぶ /鼠蹊部;下腹部の足と接する部分/
そけつごう /疎結合/
そけつごうがた /疎結合型/
そけん /訴権/素見/素絹/訴件/
そげき /狙撃/
そげきしゃ /狙撃者/
そげきしゅ /狙撃手/
そげきへい /狙撃兵/
そげん /遡源/溯源/
そこ /底/其処/其所/
そこあげ /底上げ/
そこい /底意/
そこいじ /底意地/
そこいた /底板/
そこいれ /底入れ/
そこう /素行/遡行/粗鋼/遡航/粗稿/鼠口;-終に象牙なし/
そこうお /底魚/
そこうけん /租鉱権/
そこうち /底打ち/
そこうちょうさ /素行調査/
そこうふりょう /素行不良/
そこく /祖国/
そこくあい /祖国愛/
そこくら /底倉/
そこここ /其処此処/
そこじゃり /底砂利/
そこせんよう /底専用/
そこち /底地/
そこぢから /底力/
そこつ /粗忽/
そこつち /底土/
そこつもの /粗忽者/
そこづみ /底積み/
そこなし /底無し/底なし/
そこなしぬま /底無し沼/底なし沼/
そこなだれ /底雪崩;⇔表層雪崩/
そこに /底荷/
そこぬけ /底抜け/
そこね /底値/
そこば /若干/幾許/
そこばく /若干/幾許/
そこひ /内障/底翳/
そこびえ /底冷え/
そこびかり /底光り/
そこびき /底引き/底引/
そこびきあみ /底引き網/底曳網/底引網/底曳き網/
そこら /其処ら/
そこらじゅう /そこら中/
そご /齟齬/祖語/
そさい /蔬菜/
そさつ /粗擦/
そざい /素材/礎材/
そざいけん /素材研/
そざいしゅう /素材集/
そざいじたい /素材自体/
そざいてき /素材的/
そざつ /粗雑/
そし /阻止/素子/祖師/粗視/素志/
そしか /粗視化/
そしかん /素子間/
そしがや /祖師ヶ谷/
そしがやおおくら /祖師ヶ谷大蔵/
そしき /組織/素式/
そしきえき /組織液;[生物]tissue fluid/
そしきか /組織化/
そしきかつどう /組織活動/
そしきかん /組織間/
そしきがい /組織外/
そしきがく /組織学/
そしきがわ /組織側/
そしききのう /組織機能/
そしききゅう /組織球/
そしきけい /組織系/
そしきげんり /組織原理/
そしきこうがく /組織工学/
そしきこうぞう /組織構造/
そしきじょう /組織上/
そしきじん /組織人/
そしきず /組織図/
そしきぜんたい /組織全体/
そしきたい /組織体/
そしきてき /組織的/
そしきてきごうせい /組織適合性/
そしきてきへんか /組織的変化/
そしきない /組織内/
そしきないがい /組織内外/
そしきはんざい /組織犯罪/
そしきひょう /組織票;block vote/組織表;organisation chart/
そしきぶんか /組織文化/
そしきへんこう /組織変更/
そしきぼうりょく /組織暴力/
そしきめい /組織名/
そしきめん /組織面/
そしきもう /組織網/
そしきりつ /組織率/
そしきりょく /組織力/
そしきろん /組織論/
そしじしん /素子自身/
そしたいよう /麁枝大葉/
そしつ /素質/
そして /然して/
そしどう /祖師堂/
そしな /粗品/
そしのう /阻止能/
そしめい /素子名/
そしゃく /咀嚼/租借/
そしゃくきん /咀嚼筋/
そしゃくち /租借地/
そしゅ /粗酒/
そしゅう /蘇州/
そしょう /訴訟/粗鬆/酢漿/
そしょうきろく /訴訟記録/
そしょうこうい /訴訟行為/
そしょうこくち /訴訟告知/
そしょうさんか /訴訟参加/
そしょうしき /訴訟指揮/
そしょうじけん /訴訟事件/
そしょうじょうけん /訴訟条件/
そしょうたいしょう /訴訟対象/
そしょうだいりにん /訴訟代理人/
そしょうちゅう /訴訟中/
そしょうてつづき /訴訟手続/
そしょうのうりょく /訴訟能力/
そしょうひよう /訴訟費用/
そしょうぶつ /訴訟物/
そしょうほう /訴訟法/
そしょうもんだい /訴訟問題/
そしょく /粗食/素食/蘇軾;(1036-1101) 文人・書家。『赤壁賦』/疎植;⇔密植/
そしらぬ /そ知らぬ;-顔で/素知らぬ;「素」当て字/
そしり /謗り/誹り/
そしりぐさ /謗り種/
そしりつ /阻止率/
そしりょう /粗飼料/
そしん /祖神/蘇秦/
そじ /素地/楚辞;古代中国の詩集/措辞;言葉づかい/十路/
そじゅつ /祖述/
そじゅん /蘇洵;1009-66/
そじょう /遡上/訴状/俎上;-に載せる/溯上;=遡上/爼上;「俎」異体字/
そすい /疎水;⇔親水。「-基」／=疏水/疏水;水を通す。水路。/
そすいき /疎水基/
そすいせい /疎水性/
そすう /素数/
そすうていり /素数定理/
そせい /組成/蘇生/塑性;plastic.「-合金」/素性;=すじょう/粗製/甦生;=蘇生/疎性;loose/
そせいこうぞう /素性構造/
そせいしき /組成式/
そせいじゅつ /蘇生術/
そせいち /素性値/蘇生地/
そせいひん /粗製品;crude material.⇔精製品/
そせいほう /蘇生法/
そせいめい /素性名/
そせいらんぞう /粗製濫造/粗製乱造/
そせき /礎石/組積;masonry/
そせきぞう /組積造/
そせつ /素雪/
そせん /祖先/
そせんすうはい /祖先崇拝/
そぜい /租税/
そぜいこうか /租税公課;[会計]勘定科目。tax and dues/
そぜいじょうやく /租税条約/
そぜいとくべつそちほう /租税特別措置法/
そぜいほう /租税法/
そそ /楚楚/楚々/素々/
そそう /粗相;mistake/祖宗;monarch/阻喪;意気-/沮喪;=阻喪/楚愴/
そそぎ /曽々木/
そそぎぐち /注ぎ口/
そそん /祖孫/
そぞう /塑像/
そぞろ /漫/
そぞろあるき /漫ろ歩き;promenade/
そた /曽田/
そだ /曽田;人名/粗朶/麁朶/
そだい /粗大/措大/
そだいごみ /粗大ゴミ/
そだち /育ち/
そだちざかり /育ち盛り/
そだて /育て/
そだてかた /育て方/
そだてのおや /育ての親;生みの親より-/
そち /措置/帥;[律令制]太宰府長官/其方;-も悪よのお/埣/
そちこち /其方此方/
そちにゅういん /措置入院/
そちゃ /粗茶/
そっか /足下/
そっかん /速乾/
そっかんせい /速乾性/
そっき /測器/速記/
そっきしゃ /速記者/測機舎/
そっきじゅつ /速記術/
そっきぼん /速記本/
そっきゅう /速球/即急/速急/
そっきょ /測距/卒去/
そっきょう /即興/
そっきょうえんそう /即興演奏/
そっきょうおんがく /即興音楽/
そっきょうきょく /即興曲/
そっきょうげき /即興劇/
そっきょうし /即興詩/
そっきょうしじん /即興詩人;Inprovisatoren,Andersen(1835)/
そっきょうせい /即興性/
そっきょうてき /即興的/
そっきょぎ /測距儀/
そっきょてん /測距点/
そっきろく /速記録/
そっきん /側近/即金/速筋;fast muscle. =白筋/
そっくび /素っ首/
そっけ /素気/
そっけつ /即決/
そっけつさいばん /即決裁判/
そっけつせい /即決性/
そっこう /速攻;†swift attack/即効;†immediate effect/速効;†quick effect/側溝;gutter/測光;phonometry/即行;go at once/
そっこうき /測光器;†photometer/測高器;†height gauge/
そっこうけい /測光系/
そっこうしき /測光式/
そっこうじょ /測候所/
そっこうせい /即効性;†瞬時に効く/速効性;†速く効く/
そっこうせいひりょう /速効性肥料;[園芸]/
そっこうてき /即効的/
そっこうぶ /測光部/
そっこうやく /即効薬/
そっこく /即刻/
そっこつ /足骨/
そっこん /即今/
そっせん /率先/
そっせんきゅうこう /率先躬行/
そっせんすいはん /率先垂範/
そっちゅう /卒中/
そっちょく /率直/卒直;?/
そって /沿って/
そっとう /卒倒/
そっぱ /反っ歯/反歯/
そっぷがた /ソップ形/
そっぽ /外方/
そっぽう /外方;=そっぽ/
そつ /卒;卒業/率;統率/卆;「卒」の異体字/猝;(にわか)/
そつい /訴追/
そつう /疎通/疏通/
そつえん /卒園/
そつえんしき /卒園式/
そつぎょう /卒業/
そつぎょうあるばむ /卒業アルバム/
そつぎょういわい /卒業祝/卒業祝い/
そつぎょうけんきゅう /卒業研究/
そつぎょうけんきゅうせい /卒業研究生/
そつぎょうけんしゅう /卒業研修/
そつぎょうけんてい /卒業検定/
そつぎょうご /卒業後/
そつぎょうしき /卒業式/
そつぎょうしけん /卒業試験/
そつぎょうしゃ /卒業者/
そつぎょうしゃしん /卒業写真/
そつぎょうしょうしょ /卒業証書/
そつぎょうしょうめいしょ /卒業証明書/
そつぎょうせい /卒業生/
そつぎょうせいさく /卒業制作/
そつぎょうたんい /卒業単位/
そつぎょうねん /卒業年/
そつぎょうねんじ /卒業年次/
そつぎょうねんど /卒業年度/
そつぎょうび /卒業日/
そつぎょうぶんしゅう /卒業文集/
そつぎょうへん /卒業編/
そつぎょうみこみ /卒業見込/卒業見込み/
そつぎょうりょこう /卒業旅行/
そつぎょうろんぶん /卒業論文/
そつけん /卒研/
そつけんしつ /卒研室/
そつけんせい /卒研生/
そつけんはっぴょう /卒研発表/
そつご /卒後;postgraduate. 「-教育,-研修」/
そつじ /卒爾/
そつじゅ /卒寿;90歳/
そつぜん /卒然/率然/
そつだん /卒団/
そつだんしき /卒団式/
そつだんせい /卒団生/
そつどく /卒読;一夜にして卒読した/
そつぶ /卒部/
そつろん /卒論/
そつろんせい /卒論生/
そつろんはっぴょう /卒論発表/
そつろんはっぴょうかい /卒論発表会/
そてい /措定/
そてつ /蘇鉄;[植物]/蘇轍;人名,(1039-1112)/
そてつあこう /Cycadidae/
そてつこう /ソテツ綱/Cycadopsida/
そてつしだもく /ソテツシダ目/Cycadofilicales/
そてん /素点/
そで /袖/
そであみ /袖網/
そでかんばん /袖看板/
そでがうら /袖ヶ浦/袖ケ浦/
そでがき /袖垣/
そでがらみ /袖搦み/
そでがわら /袖瓦/
そでき /袖木/
そでぐち /袖口/
そでぐり /袖刳り/
そでしょう /袖章/
そでたけ /袖丈/
そでだたみ /袖畳み/
そでつけ /袖付け/
そでなし /袖無し/
そでのした /袖の下/
そではば /袖幅;[服飾]/
そでべい /袖塀;門の脇の塀/
そでまく /袖幕/
そでやま /袖山/
そでんか /素電荷/
そと /外/
そと> /外;外海,外風呂,外割引/
そとあし /外足/
そとあしかじゅう /外足荷重/外足加重/
そといた /外板/
そとう /粗糖/蘇東/
そとうば /卒塔婆/蘇東坡;=蘇軾/
そとうみ /外海/
そとうら /外浦/
そとおもて /外表/
そとかいてん /外回転/
そとかわ /外皮/
そとかん /外環/
そとかんだ /外神田/
そとがけ /外掛け/
そとがこい /外囲い/
そとがた /外型/
そとがま /外釜;風呂の-/
そとがまえ /外構え/
そとがわ /外側/
そとくぼ /外久保/
そとこば /外木場/
そとこまた /外小股/
そとさぶらい /外侍/
そとぜい /外税/
そとだんねつ /外断熱/
そとだんねつこうほう /外断熱工法;[建築]/
そとつけ /外付け/
そとづけ /外付け/外付/
そとづけき /外付機/
そとづつ /外筒/
そとづら /外面/
そとで /外出/
そととびら /外扉/
そとどい /外樋/
そとねこ /外猫/
そとのり /外法;外法寸法/
そとはちもんじ /外八文字/
そとば /卒塔婆/外刃/外葉/卒都婆/率塔婆/率堵婆/
そとばき /外履き/
そとばこ /外箱/
そとばこいり /外箱入り/
そとばこまち /卒都婆小町/
そとばり /外張り/
そとびらき /外開き/
そとぶた /外蓋/
そとぶろ /外風呂/
そとぼう /外房/
そとぼうせん /外房線/
そとぼうせんそが /外房線蘇我/
そとぼり /外堀/外濠/外壕/
そとま /外間/
そとまき /外巻/外巻き/
そとまご /外孫/
そとまた /外股/
そとまど /外窓/
そとまわり /外回り/
そとみ /外見/
そとむき /外向き/
そとむそう /外無双/
そとめ /外目/外海/
そともうこ /外蒙古/
そとものみち /山陰道;地名/
そともも /外股/外腿/
そとやま /外山/
そとゆ /外湯;⇔内湯/
そとわく /外枠/
そどう /粗銅/
そどうめい /ソ同盟/蘇同盟/
そどく /素読/
そなえ /備え/供え/
そなえつけ /備え付け/備付/備付け/
そなえもの /供え物/供物/
そなた /其方/
そなたけいしき /ソナタ形式;[音楽](sonata) NB:提示部→展開部→再現部(→終結部)/
そに /曾爾/
そにーぎんこう /ソニー銀行/
そにちは /疎日派/
そにん /訴人/
そね /曽根/曾根/曽祢/埣/埆;痩せた土地/
そねおか /曽根岡/
そねざき /曽根崎/曾根崎/
そねざきしんじゅう /曾根崎心中;近松門左衛門,1703/
そねつ /粗熱/
そねのよしただ /曾禰好忠;由良のとを わたる舟人 かぢをたえ ゆくへも知らぬ 恋の道かな/
そねみ /嫉み/
その /園/苑/其の/其/曾野/薗;「園」の旧字(人名用漢字)/
その# /その#1/
その> /其の;-筋,-上,-[一二三...]/
そのあと /その後/
そのあやこ /曾野綾子/
そのう /園生/
そのうえ /その上/
そのうち /その内/
そのお /園生;名/
そのかた /其の方;(要ルビ)/その方/
そのかわ /園川/
そのかん /その間/
そのき /その気/
そのぎ /彼杵/
そのぐち /園口/薗口/
そのこ /その子/園子/苑子/
そのころ /その頃/
そのご /その後/
そのさい /その際/
そのじつ /其の実/
そのすじ /其の筋/
そのた /その他/其の他/
そのだ /園田/薗田/苑田/
そのつき /其月/
そのて /その手/
そのてん /その点/
そのとき /その時/
そのときそのとき /その時その時/
そのとし /その年/
そのな /その名/
そののち /その後/
そのば /その場/
そのばかぎり /其の場限り/
そのばしのぎ /其の場凌ぎ/
そのばそのば /その場その場/
そのひぐらし /その日暮らし/其の日暮し/其の日暮らし/
そのぶん /その分/
そのへん /その辺/
そのべ /園部/
そのほう /その方/其の方/
そのほか /その他/
そのまえ /その前/
そのまま /其の儘/
そのみち /其の道/
そのむら /園村/
そのもの /その物/其の物/
そのやま /園山/
そのよう /其の様/
そはん /組版/
そはんのう /素反応/
そば /蕎麦/側/傍;≒側/岨;切り立った斜面/
そばお /曽場尾/
そばかす /蕎麦滓/
そばがき /蕎麦掻き/蕎麦がき/
そばがら /蕎麦殻/
そばこ /蕎麦粉/そば粉/
そばちゃ /蕎麦茶/
そばちょく /蕎麦猪口/
そばつゆ /蕎麦汁/
そばづかえ /側仕え/
そばはら /側腹/
そばめ /側女/側妻;=側女/側目;はた目/
そばや /蕎麦屋/そば屋/
そばやく /側役/
そばゆ /蕎麦湯/
そばようにん /側用人/
そばん /礎盤/
そひつ /粗筆/
そびえとれんぽう /ソビエト連邦/
そびょう /素描;(彩色しない)dessin/祖廟/粗描;大雑把な描写/
そびょうばんが /素描版画/
そびら /背/
そふ /祖父/
そふえ /祖父江/
そふく /粗服/
そふけん /ソフ研/
そふとうぇあかがく /ソフトウェア科学/
そふとぶ /ソフト部/
そふとぼーるぶ /ソフトボール部/
そふとぼう /ソフト帽;soft hat/
そふとめい /ソフト名/
そふとめん /ソフト面/ソフト麺/
そふぼ /祖父母/
そぶ /蘇武/
そぶえ /祖父江/
そぶり /素振り/
そぶん /処分/
そへん /素片/
そほう /粗放/
そほうか /素封家/
そほに /赭土/
そほん /祖本;原本/粗笨;≒粗雑/
そぼ /祖母/
そぼう /粗暴/
そぼく /素朴/粗朴;=素朴/粗樸;=粗朴/
そぼくしゅうごうろん /素朴集合論/
そぼくしんりがく /素朴心理学/
そま /杣/
そまぎ /杣木/
そまつ /粗末/
そまびと /杣人;きこり/
そまみち /杣道/
そみつ /粗密/疎密;≒粗密. 「-波」/
そみつは /疎密波/
そみや /曽宮/
そみんしょうらい /蘇民将来/
そむく /乖/
そめ /染め/染/
そめい /疎明/染井/疏明/
そめいよしの /染井吉野/
そめいろ /染め色/
そめき /染め木/染木/
そめたろう /染太郎/
そめち /染地/
そめつけ /染付け/染め付け/
そめのすけ /染乃助/
そめもの /染物/染め物/
そめものし /染物師/
そめもよう /染模様/
そめや /染谷/染屋/染め屋/
そめわけ /染め分け/染分け/
そめん /粗面/
そめんがん /粗面岩/
そも /抑/
そもじ /其文字/
そもそも /抑々/抑抑/抑/
そや /粗野/
そやつ /其奴/
そやま /曽山/
そよう /素養/蘇陽/
そようちょう /租庸調/
そよかぜ /微風/そよ風/
そよご /冬青/
そら /空/
そらあい /空合/空合い/
そらい /徂徠/
そらいろ /空色/
そらおぼえ /空覚え/
そらぎき /空聞き/
そらぐみ /宙組/
そらごと /空言/虚言/
そらせいもん /空誓文/
そらだのみ /空頼み/
そらち /空知/
そらなき /空泣き/
そらなみだ /空涙/
そらに /空似/
そらね /空音/空寝/
そらほうこう /空方向/
そらまめ /空豆/蚕豆;=空豆/
そらみみ /空耳/
そらみみのおか /空耳の丘/
そらめ /空目/
そらものがたり /空物語/
そらもよう /空模様/
そらゆめ /空夢/
そらよみ /空読み/
そらわらい /空笑い/
そり /反り/橇/艝/轌/
そりあと /剃り跡;ヒゲの-/
そりじたおん /反舌音;[音声学]retroflex/
そりた /返田/
そりのこし /剃り残し/
そりはし /反橋/
そりまち /反町/
そりみ /反り身/
そりゃく /粗略/疎略;≒粗略/
そりゅうし /素粒子/
そりゅうしかん /素粒子間/
そりゅうしぶつり /素粒子物理/
そりゅうしぶつりがく /素粒子物理学/
そりゅうしりろん /素粒子理論/
そりゅうしろん /素粒子論/
そりゅうど /粗粒度/
そりん /疎林/
それ /其/其れ/
それ> /其れ;-切り,-迄/
それい /祖霊/
それがし /某/
それがしかれがし /某彼某/
それそうおう /其れ相応/
それぞれ /夫々/其其/夫夫/其々/
それとなく /其と無く/
それどころ /其処/
それほど /それ程/其れ程/
それゆえ /それ故/其れ故/
それら /其れ等/
それん /ソ連/ソ聯/蘇聯/蘇連/
それんへい /ソ連兵/
それんぽう /ソ連邦;USSR/ソ聯邦/
そろい /揃い/揃/
そろいぶみ /揃い踏み/
そろう /疎漏/粗漏/
そろえ /揃え/
そろばん /算盤/十露盤/
そわ /曽和/岨/
そん /損/村/尊/孫/存/巽;[八卦]陽陽陰/遜;謙遜/拵;こしら・える/忖;忖度(そんたく)/邨;「村」の異体字/樽;たる/蹲;蹲踞/噂;うわさ/鱒;ます/
そんい /尊意/
そんえい /村営/尊影/尊詠/
そんえき /損益/
そんえきかんじょう /損益勘定/
そんえきけいさんしょ /損益計算書;財務諸表の1つ/
そんえきつうさん /損益通算/
そんえきぶんきてん /損益分岐点/
そんか /尊家/尊下/
そんかい /損壊/村会/
そんかいぎいん /村会議員/
そんがい /損害/村外/
そんがいとう /損害等/
そんがいばいしょう /損害賠償/
そんがいばいしょうがく /損害賠償額/
そんがいばいしょうさいばん /損害賠償裁判/
そんがいばいしょうせいきゅう /損害賠償請求/
そんがいばいしょうせきにん /損害賠償責任/
そんがいほけん /損害保険/
そんがいほけんがいしゃ /損害保険会社/
そんがいほけんりょう /損害保険料/
そんがん /尊顔/
そんき /尊貴/損気;短気は-/
そんきょ /蹲踞/
そんきり /損切り/
そんきん /損金/
そんぎ /村議/存疑/
そんぎかい /村議会/
そんぎり /損切り/
そんけい /尊敬/尊兄/
そんけいご /尊敬語/
そんけいしん /尊敬心/
そんけん /孫権;三国時代・呉の初代皇帝/
そんげん /尊厳/
そんげんし /尊厳死/
そんこう /損耗/存稿/
そんごう /尊号/
そんごくう /孫悟空/
そんざい /存在/∃/
そんざいいき /存在域/
そんざいいぎ /存在意義/
そんざいいち /存在位置/
そんざいいみ /存在意味/
そんざいか /存在下/
そんざいかくりつ /存在確率/
そんざいかち /存在価値/
そんざいかん /存在感/
そんざいきごう /存在記号/
そんざいきばん /存在基盤/
そんざいしゃ /存在者/
そんざいしょうめい /存在証明/
そんざいじたい /存在自体/
そんざいせい /存在性/
そんざいていり /存在定理/
そんざいとじかん /存在と時間;Sein und Zeit,1927,Heidegger/
そんざいばしょ /存在場所/
そんざいひ /存在比/
そんざいぶつ /存在物/
そんざいようしき /存在様式/
そんざいりゆう /存在理由/
そんざいろん /存在論/
そんざいろんてき /存在論的/
そんし /孫子;春秋時代の呉の将軍/尊師/尊子/損紙/尊司/
そんしつ /損失/
そんしつかんすう /損失関数/
そんしつがく /損失額/
そんしつけいさん /損失計算/
そんしつしょり /損失処理/
そんしつじかん /損失時間/
そんしつていげん /損失低減/
そんしつほしょう /損失補償;indemnity/
そんしつほてん /損失補填/
そんしゃ /村社/
そんしゃさんゆう /損者三友/
そんしゅ /尊守/
そんしょ /尊書/
そんしょう /損傷/尊称/尊勝/
そんしょうかん /損傷艦/
そんしょうど /損傷度/
そんしょうひん /損傷品/
そんしょうりつ /損傷率/
そんしょく /遜色/
そんしん /尊信/
そんじゃ /尊者/
そんじゅく /村塾/
そんじょう /尊攘;尊王攘夷/
そんすう /尊崇/
そんせい /村政;†村の政治/村勢/村制/
そんぜい /村税/
そんぜん /尊前/
そんそせっしょう /樽俎折衝/
そんぞう /尊像/
そんぞく /存続/尊属/
そんぞくがいしゃ /存続会社/
そんぞくきかん /存続期間/
そんぞくきかんちゅう /存続期間中/
そんぞくきかんない /存続期間内/
そんぞくさつじん /尊属殺人/
そんぞくもんだい /存続問題/
そんたい /尊体/
そんたく /忖度/尊宅/
そんだい /尊大/
そんだいご /尊大語/
そんち /存置/
そんちょう /尊重/村長/
そんちょうせんきょ /村長選挙/
そんてん /尊天/
そんとく /損得/
そんとくかんじょう /損得勘定/
そんどう /村道/尊堂/
そんない /村内/
そんのう /尊皇/尊王/
そんのうじょうい /尊皇攘夷/尊王攘夷/
そんぱい /存廃/
そんぴ /存否/尊卑/村費/
そんぴぶんみゃく /尊卑分脈;編纂本朝尊卑分明図/
そんぶ /孫武/
そんぶん /孫文/
そんぷ /尊父/
そんぷうし /村夫子/
そんぼう /存亡/損亡;loss/
そんぽ /損保/
そんぽう /尊奉/尊報;お返事/
そんぽがいしゃ /損保会社/
そんみん /村民/
そんみんぜい /村民税/
そんめい /尊名;おなまえ/尊命;おおせ/
そんもう /存亡;皇国の-/損耗;人員の-/損亡;利益の-/
そんもうぶん /損耗分/
そんゆう /村有/村邑/損友/
そんよう /尊容/
そんらく /村落/
そんらくきょうどうたい /村落共同体/
そんらん /尊覧/
そんり /村里/
そんりつ /存立/村立/
そんりょ /尊慮/
そんりょう /損料/
ぞ /曾;(呉音の一つ)/曽;「曾」の異体字/祖;「先祖」の一部?/
ぞい /沿い/沿/
ぞう /像;†image/象;†elephant/増/造/贈/蔵;くら/雑/臓;臓器/贓;贓物(盗品)/僧;(連濁)/憎/慥/梍;さいかち/臧/賍;「贓」の異体字/襍;「雑」の異体字/雜;「雑」の旧字(人名用漢字)/藏;「蔵」の旧字(人名用漢字)/臟;「臓」の旧字(人名用漢字)/三;(人名用?)/噌;ソウ?/曾;ソウ?/曽;「曾」の異体字,?/
ぞう> /増;増感,増血,増音程/贈/
ぞうあい /憎愛/
ぞうあく /増悪/造悪/
ぞうい /贈位/
ぞういん /増員/
ぞういんようきゅう /増員要求/
ぞうえい /造影;[医]contrast/造営;build/
ぞうえいざい /造影剤/
ぞうえき /増益/
ぞうえん /造園/増援/
ぞうえんがかり /造園係/
ぞうえんぎょう /造園業/
ぞうえんぶたい /増援部隊/
ぞうお /憎悪/
ぞうおんてい /増音程/
ぞうか /増加/造花;imitation flower/造化;creation.「-の神」/増価/
ぞうかかんすう /増加関数/
ぞうかきょくせん /増加曲線/
ぞうかけいこう /増加傾向/
ぞうかてき /増加的/
ぞうかぶん /増加分/
ぞうかりつ /増加率/
ぞうかりょう /増加量/
ぞうかれつ /増加列/
ぞうかん /増刊/増感/
ぞうかんげんぞう /増感現像/
ぞうかんごう /増刊号/
ぞうかんざい /増感剤;[写真]sensitizer/
ぞうかんし /増感紙/
ぞうかんしょり /増感処理/
ぞうかんすう /像関数/
ぞうかんほう /増感法/
ぞうがく /増額/
ぞうがめ /象亀/
ぞうがん /象嵌/象眼;=象嵌/造龕/
ぞうき /臓器/雑木/造機/
ぞうきいしょく /臓器移植/
ぞうきいしょくほう /臓器移植法/
ぞうきいしょくよう /臓器移植用/
ぞうきかんかく /臓器感覚/
ぞうきていきょう /臓器提供/
ぞうきばいばい /臓器売買/
ぞうきばやし /雑木林/
ぞうきゅう /増給/
ぞうきょう /増強/
ぞうきょうりょう /増強量/
ぞうきん /雑巾/
ぞうきんがけ /雑巾掛け/
ぞうけい /造形;molding/造型;=造形/造詣;-が深い/
ぞうけいか /造形家/
ぞうけいきかく /造形企画/
ぞうけいげいじゅつ /造形芸術/
ぞうけいひょうげん /造形表現/
ぞうけいび /造形美/
ぞうけいびじゅつ /造形美術/
ぞうけつ /造血;血を作る。「-器官」/増結;「電車の-」/増血;血を増やす。「-剤」/
ぞうけつかんさいぼう /造血幹細胞;[生物]hemopoietic stem cell/
ぞうけつき /造血器/
ぞうけつきかん /造血器官/
ぞうけつざい /増血剤/
ぞうけつぶん /増結分/
ぞうけつやく /造血薬/
ぞうけつよう /増結用/
ぞうげ /象牙/
ぞうげい /雑芸/
ぞうげいろ /象牙色/
ぞうげかいがん /象牙海岸/
ぞうげしつ /象牙質;[解剖]dentin/
ぞうげのとう /象牙の塔;ivory tower(=academism)/
ぞうげん /増減/雑言/造言/
ぞうこく /増石/
ぞうご /造語/
ぞうごう /贈号/
ぞうごのうりょく /造語能力/
ぞうごりょく /造語力/
ぞうごん /雑言/
ぞうさ /造作/雑作/
ぞうさく /造作/増作/
ぞうさつ /増刷/
ぞうさつじ /増刷時/
ぞうさん /増産/
ぞうざい /造材/
ぞうざん /造山/
ぞうざんうんどう /造山運動/
ぞうざんたい /造山帯/
ぞうし /増資/草子/草紙/双紙/
ぞうしがや /雑司ヶ谷/
ぞうしき /雑色/
ぞうしゃ /増車/
ぞうしゅ /造酒/
ぞうしゅう /増収/贈収;-賄/
ぞうしゅうわい /贈収賄/
ぞうしゅつ /造出/
ぞうしょ /蔵書/
ぞうしょいん /蔵書印/
ぞうしょう /蔵相/増床;(床面積|病院のベッド)を増やす/贈賞/
ぞうしょうさんご /造礁珊瑚/
ぞうしょく /増殖/
ぞうしょくそくど /増殖速度/
ぞうしょくちゅう /増殖中/
ぞうしょくほう /増殖法/
ぞうしょくろ /増殖炉/
ぞうしょこうせい /蔵書構成/
ぞうしょすう /蔵書数/
ぞうしん /増進/
ぞうじ /造寺/造字/造次/
ぞうじてんぱい /造次顛沛/
ぞうじょう /増上/
ぞうじょうじ /増上寺/
ぞうじょうてん /増長天/
ぞうじょうまん /増上慢/
ぞうじるし /象印;[企業名]/
ぞうす /蔵主/
ぞうすい /雑炊/増水/
ぞうせい /造成/増勢/増生/
ぞうせいき /造精器/蔵精器;=造精器/
ぞうせいち /造成地/
ぞうせいちゅう /造成中/
ぞうせつ /増設;expansion.「メモリの-」/造設;creation/雑説;噂/
ぞうせつかのう /増設可能/
ぞうせつじ /増設時/
ぞうせつとびら /増設扉/
ぞうせつぶぶん /増設部分/
ぞうせつよう /増設用/
ぞうせん /造船/
ぞうせんかい /造船界/
ぞうせんじょ /造船所/
ぞうぜい /増税/増勢/
ぞうそく /増速/
ぞうぞう /造像/
ぞうたん /増反/増炭/
ぞうだ /造田;姓/
ぞうだい /増大/
ぞうちく /増築/
ぞうちくこうじ /増築工事/
ぞうちくちゅう /増築中/
ぞうちぜい /増地税/
ぞうちょう /増長/増徴;税の-/
ぞうちょうてん /増長天/
ぞうてい /贈呈/増訂/
ぞうていしき /贈呈式/
ぞうていばん /増訂版/
ぞうてん /像点/
ぞうとう /贈答/造塔/
ぞうとうひん /贈答品/
ぞうとうよう /贈答用/
ぞうとく /蔵匿/
ぞうに /雑煮/
ぞうにん /雑人/
ぞうねん /増粘/
ぞうねんざい /増粘剤/
ぞうねんたとうるい /増粘多糖類/
ぞうは /増派/
ぞうはい /増配/
ぞうはくざい /増白剤/
ぞうはつ /増発/
ぞうはつぶん /増発分/
ぞうはつよう /増発用/
ぞうはん /造反/蔵版/増版/
ぞうはんしゃ /造反者/
ぞうはんゆうり /造反有理/
ぞうばい /増倍/
ぞうばいかん /増倍管/
ぞうばいりつ /増倍率/
ぞうひ /象皮/
ぞうひびょう /象皮病/
ぞうひょう /雑兵/
ぞうひょうたち /雑兵達/
ぞうひょうものがたり /雑兵物語/
ぞうび /増備/
ぞうびがた /増備型/
ぞうびしゃ /増備車/
ぞうびん /増便/
ぞうふ /臓腑/
ぞうふく /増幅/
ぞうふくき /増幅器/
ぞうふくきのう /増幅機能/
ぞうふくど /増幅度/
ぞうふくりつ /増幅率/
ぞうぶつ /造物;creation/造仏/贓物;[法]stolen goods/
ぞうぶつしゃ /造物者/
ぞうぶつしゅ /造物主/
ぞうぶん /増分/
ぞうぶんち /増分値/
ぞうへい /造幣/造兵/
ぞうへいきょく /造幣局/
ぞうへいしょう /造兵廠;arsenal/
ぞうほ /増補/
ぞうほう /増俸/
ぞうほうたい /造胞体/
ぞうほかいてい /増補改訂/
ぞうほかいていばん /増補改訂版/
ぞうほばん /増補版/
ぞうほん /蔵本/造本/
ぞうぼう /像法;[仏教]/
ぞうぼく /雑木/
ぞうまえ /像前/
ぞうむし /象虫/
ぞうめんわんきょく /像面湾曲/
ぞうもう /増毛/
ぞうもつ /臓物/雑物/
ぞうよ /贈与/
ぞうよう /雑用;ざつよう/雑徭;[律令制]/
ぞうよしゃ /贈与者/
ぞうよぜい /贈与税/
ぞうらんき /造卵器/蔵卵器;=造卵器/
ぞうり /草履/
ぞうりとり /草履取り;信長の-/
ぞうりむし /草履虫/
ぞうりょう /増量/
ぞうりょうかのう /増量可能/
ぞうりょく /増力/
ぞうりょくざい /増力剤/
ぞうりん /造林/
ぞうりんち /造林地/
ぞうわい /贈賄/
ぞうわいざい /贈賄罪/
ぞうわく /増枠/
ぞえ /添/
ぞく /続/族/賊/属/俗/粟;あわ/續;「続」の旧字/屬;「属」の旧字/束;(連濁)装束/足;(連濁)満足/
ぞくあく /俗悪/
ぞくうけ /俗受け/
ぞくえい /続映/
ぞくえん /続演/俗縁/
ぞくおん /属音/
ぞくか /俗化/
ぞくかい /俗界/続開/
ぞくがいこん /族外婚;exogamy/
ぞくがく /俗学/
ぞくがら /続柄/
ぞくがん /俗眼/
ぞくぎいん /族議員/
ぞくぐ /属具/
ぞくぐん /賊軍/
ぞくけ /俗気/
ぞくげん /俗言/俗諺/続弦;(男の)再婚/
ぞくご /俗語/
ぞくごしゅう /俗語集/
ぞくさい /続載/
ぞくさんへんど /粟散辺土/
ぞくし /続紙/賊子/
ぞくしち /属七/
ぞくしゅ /俗手/
ぞくしゅう /属州/俗臭;vulgarity/俗習;vulgar habit/俗衆;crowd/
ぞくしゅつ /続出/
ぞくしょ /俗書/
ぞくしょう /俗称/族称;戦前の華族・士族・平民の称号/
ぞくしん /続伸/俗信/賊臣/俗心/
ぞくじ /俗字;⇔正字/俗事;mundanity.「-にかまける」/俗耳;-に入り易い/
ぞくじょう /俗情/
ぞくじん /俗人/属人/俗塵/族人/
ぞくじんてき /属人的/
ぞくする /∈/∋;(ぞくされる)/
ぞくせ /俗世/
ぞくせい /属性/俗世/族制/俗姓;=ぞくしょう/族生/簇生;=族生/
ぞくせいしゅぎ /属性主義;⇔業績主義/
ぞくせいじょうけん /属性条件/
ぞくせいち /属性値/
ぞくせいひょうか /属性評価/
ぞくせいぶんぽう /属性文法/
ぞくせいへんか /属性変化/
ぞくせいめい /属性名/
ぞくせかい /俗世界/
ぞくせき /族籍;caste/
ぞくせけん /俗世間/
ぞくせつ /俗説/
ぞくぞく /続々/
ぞくたい /俗諦/俗体/
ぞくだん /俗談/
ぞくち /属地/俗知/
ぞくちしゅぎ /属地主義/
ぞくちほう /属地法/
ぞくちょう /族長/属調;[音楽]dominant/俗調/
ぞくでん /俗伝/
ぞくと /賊徒/
ぞくとう /続投/属島/続騰;⇔続落/
ぞくないこん /族内婚;endogamy/
ぞくに /俗に/
ぞくねん /俗念/
ぞくはい /俗輩/
ぞくはく /粟帛/
ぞくはつ /続発/
ぞくはつせい /続発性/
ぞくばなれ /俗離れ/
ぞくふ /族譜/
ぞくぶつ /俗物/
ぞくぶつずかん /俗物図鑑/
ぞくぶん /俗文/
ぞくへい /賊兵/
ぞくへん /続編/続篇/
ぞくへんぐん /続編群/
ぞくほう /続報/
ぞくみょう /俗名/
ぞくむ /俗務/
ぞくめい /属名/俗名/賊名/
ぞくめつ /族滅/
ぞくよう /俗謡/俗用/
ぞくらく /続落/
ぞくり /俗吏/属吏/
ぞくりゅう /粟粒/俗流/
ぞくりょう /属領/属僚/俗了/
ぞくりょうち /属領地/
ぞくろん /俗論/続論/
ぞくわおん /属和音/
ぞこ /底/
ぞっか /俗化/俗家/
ぞっかい /俗界/続開/俗解/
ぞっかく /属格;[文法]genitive/
ぞっかん /続刊/属官/俗間/
ぞっきぼん /ぞっき本/
ぞっきや /ぞっき屋/
ぞっきょう /俗境/
ぞっきょく /俗曲/
ぞっこう /続行/続稿/
ぞっこうかのう /続行可能/
ぞっこうちゅう /続行中/
ぞっこく /属国/
ぞの /園/薗;「園」の旧字(人名用漢字)/
ぞめ /初め/
ぞら /空/
ぞろあすたーきょう /ゾロアスター教/
ぞろい /揃い/
ぞろめ /ゾロ目/ぞろ目/
ぞん /損/存/
ぞんい /存意/
ぞんがい /存外/
ぞんじ /存知/存じ/
ぞんじあたり /存じ当り/
ぞんじょう /存生/
ぞんじより /存じ寄り/
ぞんせい /存星;漆塗/
ぞんち /存知/
ぞんぢ /存知/
ぞんねん /存念/
ぞんぶん /存分/
ぞんめい /存命/
ぞんめいちゅう /存命中/
た /他/田/多/太/手/汰;沙汰/夛;「多」の異体字/詫;わびる/詑;あざむく/侘;わびる/佗;(ひく) NB:「わび」は「侘」との混同/咤;叱咤激励/它/蛇;へび/躱;かわ・す/朶;耳朶/岔;別れ道/
た> /多/他/
たーすーしー /大四喜/
たあい /他愛/
たあいしょう /多相性/
たあちゃ /他家/
たあはい /多牌/
たい /他意/隊/鯛/対/体/態/帯/胎/耐/田井/田居/泰;泰山/逮;逮捕/隶;およぶ/靆;靉靆/大;†おおきい/太;†ふとい/汰;淘汰/怠;怠慢/苔;こけ/台;台風/颱;颱風/殆;ほとんど/駘;駘蕩/紿/擡;もた・げる/抬;「擡」の異体字/堆;堆積/碓;うす/退;退場/褪;褪色/腿;大腿/滞;滞納/滯;「滞」の旧字(人名用漢字)/帶;「帯」の旧字(人名用漢字)/岱;岱山/袋;ふくろ/代;(漢音)/玳;玳瑁/貸;賃貸/替;代替/戴;いただく/待;待機/黛;まゆずみ/諦;(呉音)/頽;退廃/對;「対」の旧字/躰;「体」の異体字1/軆;「体」の異体字2/體;「体」の旧字/
たい> /対/耐/
たいあたり /体当たり/体当り/
たいあつ /耐圧/
たいあつけんさ /耐圧検査/
たいあつしけん /耐圧試験/
たいあつせい /耐圧性/
たいあん /大安;[六輝]/対案/泰安/
たいあんきちじつ /大安吉日/
たいい /体位/大意;synopsis/大尉;lieutenant/退位/胎位;[医]fetal position/大医/
たいいき /帯域;band/大域;global.「-変数」/
たいいきかくだい /帯域拡大/
たいいきざつおん /帯域雑音/
たいいきしょうめい /大域照明/
たいいきせい /大域性/
たいいきせいげん /帯域制限/
たいいきだっしゅつ /大域脱出/
たいいきつうか /帯域通過/
たいいきてき /大域的/
たいいきとくせい /帯域特性/
たいいきない /帯域内/
たいいきはば /帯域幅/
たいいきぶんかつ /帯域分割/
たいいきへんすう /大域変数/
たいいく /体育/
たいいくかい /体育会/
たいいくかいがくせい /体育会学生/
たいいくかいけい /体育会系/
たいいくかがくけい /体育科学系/
たいいくかん /体育館/
たいいくかんない /体育館内/
たいいくがく /体育学/
たいいくがくけんきゅう /体育学研究/
たいいくきょうし /体育教師/
たいいくきょく /体育局/
たいいくけい /体育系/
たいいくさい /体育祭/
たいいくじつぎ /体育実技/
たいいくずわり /体育座り;部屋の隅で/
たいいくのひ /体育の日;十月の第二月曜日/
たいいち /太一/対一/
たいいへんかん /体位変換/
たいいほう /対位法/
たいいほうてき /対位法的/
たいいん /隊員/退院/太陰/退隠/
たいいんいわい /退院祝/退院祝い/
たいいんせい /耐陰性/
たいいんたいようれき /太陰太陽暦/
たいいんたち /隊員達/
たいいんれき /太陰暦/
たいう /大雨/
たいえい /大栄;地名/退嬰/
たいえいてき /退嬰的/
たいえき /体液/退役/
たいえきぐんじん /退役軍人/
たいえつ /大悦/
たいえん /対円/退園/
たいおう /対応/滞欧;stay in Europe/対欧;vs. Europe/對應;「対応」旧字/
たいおう> /対応/
たいおうか /対応可/
たいおうかのう /対応可能/
たいおうかんけい /対応関係/
たいおうがた /対応型/
たいおうきしゅ /対応機種/
たいおうきそく /対応規則/
たいおうけんばいき /対応券売機/
たいおうさく /対応策/
たいおうしゃ /対応車/
たいおうしゃしゅ /対応車種/
たいおうしゃりょう /対応車両/
たいおうしゅだん /対応手段/
たいおうじょうきょう /対応状況/
たいおうじょうほう /対応情報/
たいおうず /対応図/
たいおうずみ /対応済/
たいおうづけ /対応付け/
たいおうてん /対応点/
たいおうどりょく /対応努力/
たいおうばん /対応版/
たいおうばんぐみ /対応番組/
たいおうひょう /対応表/
たいおうひん /対応品/
たいおうふかのう /対応不可能/
たいおうぶつ /対応物/
たいおうぶひん /対応部品/
たいおうほう /対応法/
たいおうよてい /対応予定/
たいおせんせい /耐汚染性/
たいおとし /体落とし/
たいおん /体温/
たいおんけい /体温計/
たいおんじょうしょう /体温上昇/
たいおんそくてい /体温測定/
たいおんちょうせい /体温調整/
たいおんちょうせつ /体温調節/
たいか /対価/大家/耐火/退化/大火/大化;年号(645-650) 「-の改新」/大過;-なく/大厦;異体字/大廈;大きな建物/帯化;[園芸]fasciation. 茎が帯状になる奇形/滞貨;stock/袋果;[植物]follicle/耐過/
たいかい /大会/退会/大海/
たいかいいいんちょう /大会委員長/
たいかいかいさい /大会開催/
たいかいかいじょう /大会会場/
たいかいかんじ /大会幹事/
たいかいきかんちゅう /大会期間中/
たいかいけっしょう /大会決勝/
たいかいご /大会後/
たいかいさんか /大会参加/
たいかいさんかしゃ /大会参加者/
たいかいさんかひ /大会参加費/
たいかいしゃ /退会者/
たいかいしゅうりょうご /大会終了後/
たいかいしゅつじょう /大会出場/
たいかいしん /大会新;大会新記録/
たいかいしんきろく /大会新記録/
たいかいじむきょく /大会事務局/
たいかいぜんたい /大会全体/
たいかいぜんぱん /大会全般/
たいかいっそう /滞貨一掃/
たいかいへん /大会篇/
たいかいほんぶ /大会本部/
たいかいまえ /大会前/
たいかいめい /大会名/
たいかいやくいん /大会役員/
たいかいようこう /大会要項/
たいかく /体格/対角;diagonal/対格;[文法]accusative/台閣/
たいかくか /対角化/
たいかくぎょうれつ /対角行列/
たいかくぎょがん /対角魚眼/
たいかくこう /対角項/
たいかくさ /体格差/
たいかくせいぶん /対角成分/
たいかくせん /対角線/
たいかくせんじょう /対角線上/
たいかくせんろんぽう /対角線論法/
たいかくてき /体格的/
たいかくようそ /対角要素/
たいかけんちく /耐火建築;fireproof building/
たいかこうぞう /耐火構造;[建築]RC造などの耐火材による構造。fireproof/
たいかこうろう /大廈高楼/
たいかざい /耐火材/
たいかざいりょう /耐火材料/
たいかせい /耐火性/
たいかせいのう /耐火性能/
たいかぜんだい /大化前代/
たいかど /耐火度/
たいかひふく /耐火被覆;[建築]/
たいかれんが /耐火煉瓦;建築よりは工業向け/
たいかん /体感/大観/耐寒/退官/体幹/戴冠/退館/対艦/大鑑/大官/大患;「修善寺の-」/大旱/
たいかんおんど /体感温度/
たいかんきねん /退官記念/
たいかんこうげき /対艦攻撃/
たいかんこく /対韓国/
たいかんしき /戴冠式/
たいかんしよう /耐寒仕様/
たいかんじかん /体感時間/
たいかんせい /耐寒性/
たいかんそくど /体感速度/
たいかんちあん /体感治安/
たいかんてき /体感的/
たいかんみんこく /大韓民国/
たいが /大河/大雅/大我;⇔小我/胎芽/大牙/
たいがい /大概/対外;外部に対する。「-援助」/体外;カラダの外。「-受精」/大外;?/
たいがいかつどう /対外活動/
たいがいかんけい /対外関係/
たいがいさいむ /対外債務/
たいがいじあい /対外試合/
たいがいじゅせい /体外受精/
たいがいせっしょう /対外折衝/
たいがいせんでん /対外宣伝/
たいがいてき /対外的/
たいがいぶ /対外部/
たいがいぼうえき /対外貿易/
たいがく /退学/
たいがくかんこく /退学勧告/
たいがくしょぶん /退学処分/
たいがくとどけ /退学届/
たいがしょうせつ /大河小説/
たいがため /体固め/
たいがどらま /大河ドラマ/
たいがん /対岸/大願/対顔/
たいがんじょうじゅ /大願成就/
たいき /大気/待機/大器/隊旗/大樹;地名/対気/
たいきあつ /大気圧/
たいきおせん /大気汚染/
たいきおせんたいさく /大気汚染対策/
たいきおせんぼうしほう /大気汚染防止法/
たいきおん /帯気音;[音声学]aspirate sound/
たいきけん /大気圏/
たいきけんがい /大気圏外/
たいきけんさいとつにゅう /大気圏再突入/
たいきけんない /大気圏内/
たいきげんしょう /大気現象/
たいきこう /大気光/
たいきしゃ /大氣社;[企業名]/大気社/
たいきじ /待機時/待機児/
たいきじどう /待機児童;保育所の定員にあぶれた児童/
たいきじょうたい /待機状態/
たいきそくど /対気速度/
たいきそせい /大気組成/
たいきだいじゅんかん /大気大循環/
たいきだいじゅんかんもでる /大気大循環モデル/
たいきちゅう /大気中/待機中/
たいきでんりょく /待機電力/
たいきばんせい /大器晩成/
たいきばんせいがた /大器晩成型/
たいきゃく /退却/
たいきゃくちゅう /退却中/
たいきゅう /耐久/
たいきゅうしけん /耐久試験/
たいきゅうしょうひざい /耐久消費財/
たいきゅうせい /耐久性/
たいきゅうせいのう /耐久性能/
たいきゅうせんしゅけん /耐久選手権/
たいきゅうりょく /耐久力/
たいきょ /退去/大挙/退居;⇔入居/太虚;sky/大虚;=太虚/
たいきょう /体協/胎教/滞京/
たいきょうさん /対共産/
たいきょうよう /胎教用/
たいきょく /対局;囲碁の-/対極;opposite/大局;-観/大曲/太極/大極;≒太極/
たいきょくかん /大局観/
たいきょくき /太極旗/
たいきょくけん /太極拳/
たいきょくし /大局視/
たいきょくしゃ /対局者/
たいきょくしゃめい /対局者名/
たいきょくすう /対局数/
たいきょくちゅう /対局中/
たいきょくてき /大局的/対極的/大極的/
たいきょめいれい /退去命令/
たいきりゅうし /大気粒子/
たいきろく /タイ記録;tied record/
たいきん /大金/退勤/
たいきんじ /退勤時/
たいきんてつ /対近鉄/
たいきんてつせん /対近鉄戦/
たいぎ /大義;†cause.「戦争の-」/大儀;†effort.「-であった」/体技/
たいぎご /対義語/
たいぎめいぶん /大義名分/
たいぎめいぶんろん /大義名分論/
たいぎゃく /大逆/
たいぎゃくざい /大逆罪/
たいぎゃくじけん /大逆事件/
たいぎゃくむどう /大逆無道/
たいぎょ /大魚/
たいぎょう /大業/怠業/
たいく /体躯/
たいくう /対空/滞空/体腔/
たいくうかき /対空火器/
たいくうしゃげき /対空射撃/
たいくうじかん /滞空時間/
たいくうだん /対空弾/
たいくうない /体腔内/
たいくうへいき /対空兵器/
たいくうほう /対空砲/
たいくうほうか /対空砲火/
たいくうぼうぎょ /対空防御/
たいくうりょく /対空力/
たいくつ /退屈/
たいくつおとこ /退屈男/
たいくつしのぎ /退屈凌ぎ/
たいくん /大君/
たいぐ /大愚/
たいぐう /待遇/対偶;[論理]A⊃B に対する ¬B⊃¬A/
たいぐうかいぜん /待遇改善/
たいぐうひょうげん /待遇表現;[言語]honorifics. 敬語など/
たいぐん /大群;†hordes.「イナゴの-」/大軍;large army.「ロシアの-」/大郡;†large county/
たいぐんか /大群化/
たいけ /大家/
たいけい /体系;†system.「コード体系」/体型;†体形のタイプ/大系;†corpus.「古典文学-」/体形;†body shape/大兄/大計/大慶/隊形/体刑/隊型;?/腿頚/
たいけいか /体系化/
たいけいがく /体系学/
たいけいず /体系図/
たいけいせい /体系性/
たいけいてき /体系的/
たいけいどうぶつ /袋形動物;aschelminthes/
たいけいない /体系内/
たいけいろん /体系論/
たいけつ /対決/
たいけつじょう /対決場/
たいけん /体験/大剣/大権/大賢/大圏/帯剣/
たいけんがくしゅう /体験学習/
たいけんき /体験記/
たいけんきおく /体験記憶/
たいけんしゃ /体験者/
たいけんじょう /体験上/
たいけんだん /体験談/
たいけんばん /体験版/
たいけんへん /体験編/
たいけんれい /体験例/
たいけんれぽーと /体験レポート/
たいげ /帯下/
たいげん /体現/体言/大言/
たいげんそうご /大言壮語/
たいげんどめ /体言止め/
たいこ /太鼓/太古/大戸/奈子/鯛子/大呼/
たいこう /対抗;†rival.「相手に-する」/大綱/大公/対向;†facing.「-車線」/退行/太閤/体高/耐候/対校;学校対学校/太后/体腔/大功/退校/大行/大興/大江/退紅/褪紅/帯鉤/体講/体育講義;※abbrev/
たいこういしき /対抗意識/
たいこううせつしゃ /対向右折車/
たいこうき /太閤記/
たいこうぎょ /大口魚/
たいこうくうき /対航空機/
たいこうけんち /太閤検地;[日本史](1582-98)/
たいこうこく /大公国;ルクセンブルク―/
たいこうさく /対抗策/対抗作/
たいこうしき /対向式/
たいこうしゃ /対向車/対抗者/
たいこうしゃせん /対向車線/
たいこうしゃせんがわ /対向車線側/
たいこうしゅだん /対抗手段/
たいこうしょうひん /対抗商品/
たいこうしょく /退紅色/
たいこうしん /対抗心/
たいこうじあい /対抗試合/
たいこうじく /対抗軸/
たいこうじょう /対抗上/
たいこうせい /耐候性/退行性/
たいこうせん /対抗戦/
たいこうそち /対抗措置/
たいこうたいごう /太皇太后/
たいこうち /太鼓打;水棲昆虫/
たいこうてんのう /大行天皇;死亡した天皇/
たいこうはんしゃ /対光反射/
たいこうば /対抗馬/
たいこうぶんか /対抗文化;counterculture/
たいこうぼう /太公望;周王朝の臣で、魯の開祖/
たいこうようけん /対抗要件/
たいこうりょく /対抗力/
たいこうれっしゃ /対向列車/
たいこく /大国/
たいこくかん /大国間/
たいこくしゅぎ /大国主義/
たいこざ /太鼓座/
たいこしょう /耐故障/
たいこしょうせい /耐故障性/
たいこたい /太鼓隊/
たいこたたき /太鼓叩き;drummer/
たいこだい /太古代;[地質年代]Archeozoic. 38-25億年前/
たいこばし /太鼓橋;arched bridge/
たいこばら /太鼓腹/
たいこばん /太鼓判/
たいこへん /大古編/
たいこもち /幇間/太鼓持ち/太鼓持/
たいこやき /太鼓焼/
たいご /タイ語/大悟;=だいご/対語/隊伍/大語/
たいごう /対合/
たいごく /大獄/
たいごてってい /大悟徹底/
たいさ /大差/大佐;colonel/
たいさい /大祭/大才/太歳;[陰陽道]八将神の一。木星/体菜/
たいさいじつ /大祭日/
たいさいぼう /体細胞/
たいさいぼうぶんれつ /体細胞分裂;[生物]somatic mitosis/
たいさく /対策/大作/
たいさくあん /対策案/
たいさくいいんかい /対策委員会/
たいさくきょうぎかい /対策協議会/
たいさくご /対策後/
たいさくそうち /対策装置/
たいさくひ /対策費/
たいさくひん /対策品/
たいさくぶひん /対策部品/
たいさくほう /対策法/
たいさくほうほう /対策方法/
たいさくほんぶ /対策本部/
たいさくまえ /対策前/
たいさくよう /対策用/
たいさつ /大冊/
たいさなし /大差無/
たいさん /退散/耐酸;-性/
たいさんこう /耐酸鋼/
たいさんせい /耐酸性/
たいざ /対座/退座/胎座/対坐/
たいざい /滞在/大罪/
たいざいかのう /滞在可能/
たいざいがたりょこう /滞在型旅行/
たいざいきかん /滞在期間/
たいざいきかんちゅう /滞在期間中/
たいざいきょか /滞在許可/
たいざいけいけん /滞在経験/
たいざいさき /滞在先/
たいざいしゃ /滞在者/
たいざいじかん /滞在時間/
たいざいち /滞在地/
たいざいちゅう /滞在中/
たいざいにっすう /滞在日数/
たいざいひ /滞在費/
たいざいび /滞在日/
たいざん /泰山/大山/太山/岱山;地名,(Tai Shan) =泰山/鯛山/
たいざんほくと /泰山北斗/
たいざんめいどう /大山鳴動/
たいし /大使/太子/大師/大志/太史/大史/太始/対し/
たいしかん /大使館/
たいしかんりょうじぶ /大使館領事部/
たいしきちょう /太食調/
たいしこう /太史公;司馬遷/
たいしせん /大師線/
たいした /大した/
たいしつ /体質/退室/耐湿/対質/
たいしつかいぜん /体質改善/
たいしつかいぞう /体質改造/
たいしつてき /体質的/
たいして /大して;古語では「甚しい」様/
たいしどう /太子堂/大師堂/
たいしぼう /体脂肪/
たいしぼうけい /体脂肪計/
たいしぼうりつ /体脂肪率/
たいしゃ /代謝/退社/大社;出雲-/大赦;[法]特定の〈犯罪〉の刑罰を赦免/対者/代赭;(顔料名,Fe2O3)/
たいしゃいじょう /代謝異常;[医]dysbolism/
たいしゃいろ /代赭色/
たいしゃく /貸借/帝釈;-天/
たいしゃくきょう /帝釈峡/
たいしゃくたいしょうひょう /貸借対照表;財務諸表の1つ/
たいしゃくてん /帝釈天/
たいしゃくとりひき /貸借取引/
たいしゃづくり /大社造り;[建築]/大社造;[建築]/
たいしゃび /退社日/
たいしゃりつ /代謝率/
たいしゃりょう /代謝量/
たいしゅ /太守/大酒/対手/
たいしゅう /大衆/体臭/大周/対州;対馬/
たいしゅううんどう /大衆運動/
たいしゅうおんがく /大衆音楽/
たいしゅうか /大衆化/
たいしゅうかん /大修館/
たいしゅうかんしょてん /大修館書店/
たいしゅうぎょ /大衆魚;アジ・イワシ/
たいしゅうごらく /大衆娯楽/
たいしゅうさかば /大衆酒場/
たいしゅうし /大衆紙/大衆誌/
たいしゅうしゃ /大衆車/
たいしゅうしゃかい /大衆社会;mass society/
たいしゅうしょうせつ /大衆小説/
たいしゅうしょくどう /大衆食堂/
たいしゅうしんり /大衆心理/
たいしゅうせい /大衆性/
たいしゅうてき /大衆的/
たいしゅうてきにんき /大衆的人気/
たいしゅうぶんか /大衆文化/
たいしゅうぶんがく /大衆文学/
たいしゅうやく /大衆薬;風邪薬や胃薬の類/
たいしゅか /大酒家/
たいしゅつ /退出;†quit.「議会から-する」/帯出;†take out.「本の-」/貸出;?/体出;?/
たいしゅつしゃ /退出者/
たいしゅつれい /退出例/
たいしょ /対処/退所;⇔入所/大書/大暑;[二十四節気]7.23頃/大所/太初/対蹠;たいせき/台書/
たいしょあん /対処案/
たいしょう /対象;†target.「研究-」/大正;年号(1912-26)/大賞/大将/対照;†contrast.「-実験」/対称;†symmetry.「線-」/大勝/大笑/対症;-療法/隊商/大捷;≒大勝/大詔/胎生;[仏教]/
たいしょう#ねん /大正#0年/大正#1年/大正#2年/大正#3年/
たいしょう> /対象;-群,-行,-団体/
たいしょういけ /大正池/
たいしょうえび /大正海老/
たいしょうか /対象化/
たいしょうがい /対象外/
たいしょうがいせい /耐障害性/
たいしょうがた /対称型/
たいしょうがんねん /大正元年/
たいしょうき /大正期/
たいしょうきかん /対象期間/
たいしょうきしゅ /対象機種/
たいしょうぎょうれつ /対称行列/
たいしょうくかん /対象区間/
たいしょうぐん /大将軍/対照群;†control group/対称群;†symmetric group/
たいしょうけい /対称形/
たいしょうげき /耐衝撃/
たいしょうげんご /対象言語/
たいしょうげんごがく /対照言語学;contractive linguistics/
たいしょうこう /対象項/
たいしょうこく /対象国/
たいしょうごと /大正琴/
たいしょうざっし /対象雑誌/
たいしょうしてい /対象指定/
たいしょうしゃ /対象者/対象車/
たいしょうしゃりょう /対象車両/
たいしょうしゅうだん /対象集団/
たいしょうしんじん /大賞新人/
たいしょうじく /対称軸/
たいしょうじだい /大正時代/
たいしょうじっけん /対照実験/
たいしょうじどうしゃ /対象自動車/
たいしょうじんいん /対象人員/
たいしょうすうりょう /対象数量/
たいしょうせい /対称性;†symmetry/対象性;†objectivity/
たいしょうせいやく /大正製薬;[企業名]/
たいしょうせかい /対象世界/
たいしょうせんしゅ /対象選手/
たいしょうそう /対象層/
たいしょうたいかい /対象大会/
たいしょうちいき /対象地域/
たいしょうちいきない /対象地域内/
たいしょうちしき /対象知識/
たいしょうてき /対照的;†contrastive/対称的;†symmetrical/対象的;?/対症的/
たいしょうてんのう /大正天皇/
たいしょうど /対称度/
たいしょうにんしき /対象認識/
たいしょうねんど /対象年度/
たいしょうねんれい /対象年齢/
たいしょうひょう /対照表/
たいしょうぶつ /対象物/
たいしょうへんすう /対象変数/
たいしょうまっき /大正末期/
たいしょうめい /対象名/
たいしょうめん /対称面/
たいしょうやど /隊商宿/
たいしょうりつ /対称律/
たいしょうりょういき /対象領域/
たいしょうりょうほう /対症療法/
たいしょかのう /対処可能/
たいしょく /退職/体色;body colour/退色/大食/褪色;≒退色/耐食;anticorrosion.「-性」/耐蝕;=耐食/
たいしょくかん /大食漢/
たいしょくきゅうふ /退職給付/
たいしょくきゅうふひきあてきん /退職給付引当金/
たいしょくきん /退職金/
たいしょくきんきてい /退職金規定/
たいしょくけいじ /退職刑事/
たいしょくご /退職後/
たいしょくさいぼう /大食細胞;[生物]histiocyte (=macrophage)/
たいしょくしゃ /退職者/
たいしょくしょとく /退職所得;retirement income/
たいしょくじゆう /退職事由/
たいしょくせい /耐食性/耐蝕性/
たいしょくてあて /退職手当/
たいしょくねがい /退職願/
たいしょくねんきん /退職年金/
たいしょくび /退職日/
たいしょくりゆう /退職理由/
たいしょこうしょ /大所高所/
たいしょせい /耐暑性/
たいしょてき /対蹠的/
たいしょほう /対処法/
たいしょほうほう /対処方法/
たいしょりょうほう /対処療法;※対症療法?/
たいしん /耐震/対震/対審/大信/大震/大身/太信/
たいしんくう /対真空/
たいしんこうぞう /耐震構造;[建築]/
たいしんしんだん /耐震診断/
たいしんせい /耐震性/
たいしんせいのう /耐震性能/
たいしんせっけい /耐震設計/
たいしんへき /耐震壁/
たいしんりっぽうこうし /体心立方格子;body-centred cubic lattice/
たいじ /退治/胎児/対峙/対自;[哲学]fur sich/太地;地名/大治;年号(1126-1131)/泰司/泰次/泰二/帯磁/胎仔/
たいじく /体軸/
たいじそしき /胎児組織/
たいじてき /対自的/
たいじゅ /大樹/大儒/
たいじゅう /体重/
たいじゅういどう /体重移動/
たいじゅうけい /体重計/
たいじゅうさ /体重差/
たいじゅうしんちょう /体重身長/
たいじゅうそくてい /体重測定/
たいじゅうべつ /体重別/
たいじゅうりょう /耐重量/
たいじゅく /退塾/
たいじゅつ /体術/
たいじゅん /泰淳/
たいじゅんかん /体循環;[医]systemic circulation/
たいじょう /退場/帯状/
たいじょうかい /帯状回/
たいじょうしゃ /退場者/
たいじょうしょぶん /退場処分/
たいじょうじゅん /退場順/
たいじょうほうしん /帯状疱疹/
たいじん /対人/退陣/対陣/大人/タイ人/泰人/
たいじんかんけい /対人関係/
たいじんきょうふしょう /対人恐怖症;[精医]/
たいじんけん /対人権/
たいじんじらい /対人地雷/
たいじんじらいぜんめんきんしじょうやく /対人地雷全面禁止条約/
たいじんてき /対人的/
たいすい /耐水/大水/大酔/退水/
たいすいせい /耐水性/
たいすう /対数;log/大数;large number.「-の法則」/
たいすうかんすう /対数関数/
たいすうじく /対数軸/
たいすうち /対数値/
たいすうのほうそく /大数の法則;[数学]law of large numbers/
たいすうひょう /対数表/
たいすうめもり /対数目盛/
たいすけ /泰介/退助/泰祐/泰佑/
たいする /対する/
たいずし /鯛鮨/
たいせい /体制;†system.「政治-」/大成;「研究者として-する」/態勢;†readiness.「準備-」/耐性/体勢;†posture.「-が崩れる」/大勢;†trend.「-が決する」/大聖/大政;-奉還/対生;[植物]distichous/胎生;[生物]⇔卵生/大青;[植物]woad/泰西;the West/退勢/頽勢;≒退勢/大声/体性/
たいせいいでんし /耐性遺伝子/
たいせいか /体制下/体制化/
たいせいかんかく /体性感覚/
たいせいかんかくや /体性感覚野/
たいせいがわ /体制側/
たいせいきん /耐性菌/
たいせいぎょ /胎生魚;[生物]live-bearer/
たいせいけんせつ /大成建設;[企業名]/
たいせいこうこう /大成高校/
たいせいしっこ /大声疾呼/
たいせいてき /体制的/
たいせいどう /大盛堂/
たいせいひはん /体制批判/
たいせいぶせん /対西武戦/
たいせいぶつ /対生物/
たいせいほうかん /大政奉還/
たいせいまる /大成丸/
たいせいよう /大西洋/
たいせいようかんたい /大西洋艦隊/
たいせいようがん /大西洋岸/
たいせいようけんしょう /大西洋憲章;[世界史]Atlantic Charter(1941)/
たいせいようせん /大西洋線/
たいせいよくさんかい /大政翼賛会/
たいせき /体積/堆積;pile.「土砂の-」/退席/対蹠/滞積;stack up.「業務が-する」/大石/堆石;moraine/対席/
たいせきがん /堆積岩/
たいせきじ /大石寺/
たいせきそう /堆積層/
たいせきそくど /体積速度/
たいせきは /体積波/
たいせきぶつ /堆積物/
たいせきようそ /体積要素/
たいせきりょく /体積力/
たいせつ /大切/大雪;[二十四節気]12.8頃/体節/
たいせつさ /大切さ/
たいせん /対戦/大戦;great war/対潜;antisubmarine/苔癬/大船/大戰;「戦」旧字/
たいせんあいて /対戦相手/
たいせんかいすう /対戦回数/
たいせんがた /対戦型/
たいせんがたかくとう /対戦型格闘/
たいせんけいしき /対戦形式/
たいせんけっか /対戦結果/
たいせんげーむ /対戦ゲーム/
たいせんご /大戦後/対戦後/
たいせんしゃ /対戦者/対戦車/
たいせんしゃほう /対戦車砲/
たいせんしゃぼしゅうちゅう /対戦者募集中/
たいせんじ /対戦時/
たいせんすう /対戦数/
たいせんせいせき /対戦成績/
たいせんちゅう /大戦中/対戦中/
たいせんちゅうるい /苔蘚虫類/
たいせんとちゅう /対戦途中/
たいせんひょう /対戦表/
たいせんひわ /大戦秘話/
たいせんまっき /大戦末期/
たいせんりつ /対旋律/
たいぜい /大勢/
たいぜん /大全/泰然/
たいぜんくつ /体前屈/
たいぜんじじゃく /泰然自若/
たいそ /太祖/
たいそう /体操/大層/大宗;権威/太宗;廟号の一つ/大喪;天皇の葬儀/大葬;天皇・太皇太后・皇太后・皇后の葬儀/太簇;[音楽]/
たいそう> /大層;(副詞)/
たいそうきょうぎ /体操競技/
たいそうぎ /体操着/
たいそうのれい /大喪の礼;天皇の葬儀/
たいそうふく /体操服/
たいそうぶ /体操部/
たいそく /体側/大息/
たいそしき /体組織/
たいぞう /退蔵;資本の-/胎蔵;[仏教]/泰三;人名/泰造/泰蔵/大蔵/大造/諦三/太造/
たいぞうかい /胎蔵界/
たいぞうかいまんだら /胎蔵界曼荼羅;garbha-kosa mandala/
たいた /対他/
たいだ /怠惰/
たいだん /対談/退団/
たいだんきじ /対談記事/
たいだんけいしき /対談形式/
たいだんしゅう /対談集/
たいち /対置/対地/太一/多一/
たいちこうげき /対地攻撃/
たいちしえん /対地支援/
たいちそくど /対地速度/
たいちゅう /対中;対・中国/台中;地名,台湾/
たいちゅうごく /対中国/
たいちゅうにちせん /対中日戦/
たいちょ /大著/
たいちょう /体調/隊長/体長/退庁/退潮/
たいちょういへん /体調異変/
たいちょうかく /対頂角/
たいちょうかんり /体調管理/
たいちょうたち /隊長達/
たいちょうばんぜん /体調万全/
たいちょうふじゅうぶん /体調不十分/
たいちょうふちょう /体調不調/
たいちょうふりょう /体調不良/
たいちよう /退治用/
たいちろう /太一郎/
たいてい /大抵/大帝/退廷/
たいてい> /大抵;(副詞)/
たいてき /大敵/対敵/
たいてろ /対テロ/
たいてん /退店/大典/退転/
たいでん /帯電/
たいと /泰斗/大都/
たいとう /対等/台頭/台東;地名,東京/帯刀/対当;opposition/擡頭;=台頭/台糖;[企業名]/駘蕩;春風-/頽唐;退廃/体当;?/
たいとういじょう /対等以上/
たいとうかんけい /対等関係/
たいとうがく /対当額/
たいとうきょう /対東京/
たいとうく /台東区/
たいとうせい /対等性/
たいとく /体得/大徳/
たいとしん /対都心/
たいとるせん /タイトル戦/
たいど /態度/大度/胎土/
たいどう /胎動/帯同/
たいどく /胎毒/
たいどひょうめい /態度表明/
たいどみてい /態度未定/
たいどる /対ドル/
たいない /体内/胎内/対内;「-政策」/隊内/
たいないどけい /体内時計/
たいないぶ /体内部/
たいなごや /対名古屋/
たいなん /台南;地名,台湾/
たいにし /対西/
たいにち /対日/滞日/
たいにちさんせん /対日参戦/
たいにん /退任/大任/体認/
たいにんげん /対人間/
たいねつ /耐熱/
たいねつがらす /耐熱ガラス/
たいねつざら /耐熱皿/
たいねつしょり /耐熱処理/
たいねつせい /耐熱性/
たいねつようき /耐熱容器/
たいねん /耐年/
たいのう /滞納/怠納;怠って納めない/
たいのうしゃ /滞納者/怠納者;<rare> 怠って納めない人/
たいのうしょぶん /滞納処分/
たいは /大破/
たいはい /大敗/退廃/頽廃;=退廃/大盃/頽廢;旧字/
たいはいてき /退廃的/頽廃的;=退廃的/
たいはいび /頽廃美/
たいはく /太白/
たいはくく /太白区/
たいはくさん /太白山/
たいはくせい /太白星;金星/
たいはん /大半/大藩/
たいばつ /体罰/
たいばつきょうし /体罰教師/
たいばつもんだい /体罰問題/
たいばん /胎盤/
たいひ /対比/堆肥/退避;逃げ去る。「火山から-する」/待避;退いて待つ。「特急を-する」/貸費/
たいひえき /退避駅;?/
たいひか /堆肥化/
たいひかん /退避艦/
たいひごう /待避壕/
たいひじょ /待避所;通過待ちする場所/退避所;避難場所/
たいひせつび /待避設備/退避設備/
たいひせん /待避線/退避線;?/
たいひつとくしょ /大筆特書/
たいひづくり /堆肥作り/
たいひてき /対比的/
たいひひょう /対比表/
たいひょう /体表/
たいひょうめん /体表面/
たいひょうめんせき /体表面積/
たいひよう /退避用/
たいひりょういき /退避領域/
たいひろしま /対広島/
たいびょう /大病/
たいびょうせい /耐病性/
たいふ /大夫/大輔/
たいふう /台風/颱風/
たいふう#ごう /台風#0号/
たいふういっか /台風一過/
たいふうか /台風下/
たいふうじょうりく /台風上陸/
たいふうせい /耐風性/
たいふうせっきんちゅう /台風接近中/
たいふく /大幅/大腹;=ふとっぱら/太腹;=ふとっぱら/
たいぶ /大部;大部分。大冊。「だいぶ」とも/体部/退部/
たいぶつ /対物/
たいぶつれんず /対物レンズ;objective/
たいぶとどけ /退部届/
たいぶん /大分/
たいぶんすう /帯分数/
たいへい /太平/泰平/大兵/大平/
たいへいき /太平記/
たいへいこうぎょう /太平工業;[企業名]/
たいへいざん /太平山/
たいへいどう /太平道;[中国史]黄巾の乱を起こした宗教。首領は張角/
たいへいよう /太平洋/
たいへいようおうだん /太平洋横断/
たいへいようがわ /太平洋側/
たいへいようこうきあつ /太平洋高気圧/
たいへいようせん /太平洋線/
たいへいようせんそう /太平洋戦争/
たいへいようせんそうまえ /太平洋戦争前/
たいへいようちいき /太平洋地域/
たいへいらく /太平楽/
たいへん /大変/対辺/大編/大篇/
たいへん> /大変;-困難,-楽,-便利/
たいへんかんしゃ /大変感謝/
たいへんきけん /大変危険/
たいへんきょうしゅく /大変恐縮/
たいへんけっこう /大変結構/
たいへんこんなん /大変困難/
たいへんごめいわく /大変御迷惑/
たいへんざんねん /大変残念/
たいへんしつれい /大変失礼/
たいへんしんせつ /大変親切/
たいへんじゅうよう /大変重要/
たいへんふゆかい /大変不愉快/
たいへんべんり /大変便利/
たいへんまんぞく /大変満足/
たいへんめいわく /大変迷惑/
たいへんゆうめい /大変有名/
たいべい /対米/滞米/
たいべいこく /対米国/
たいべつ /大別/
たいべん /大弁;雄弁/胎便/
たいぺい /台北/
たいほ /逮捕/退歩/
たいほう /大砲/大豊/大宝;年号(701-704)/大峰/大鵬/
たいほうぐん /帯方郡;地名,楽浪郡南部/
たいほうやくひん /大鵬薬品;[企業名]/
たいほうりつりょう /大宝律令/
たいほかんきんざい /逮捕監禁罪/
たいほく /台北/
たいほくおうふく /台北往復/
たいほげき /逮捕劇/
たいほしゃ /逮捕者/
たいほじょう /逮捕状/
たいほれき /逮捕歴/
たいぼ /太母/
たいぼう /待望/大望/耐乏/体貌/
たいぼうろん /待望論/
たいぼく /大木/
たいま /大麻;hemp/当麻;地名/対馬;[将棋]互角/
たいまい /大枚/タイ米/玳瑁/
たいまつ /松明/
たいまつぎょうれつ /松明行列/
たいまとりしまりほう /大麻取締法/
たいまもうせい /耐磨耗性/
たいまん /怠慢/
たいみつ /台密/
たいむ /隊務/
たいめい /大命/台命/待命/岱明/泰明;名/
たいめいがっき /体鳴楽器/
たいめし /鯛飯/
たいめん /対面;†/体面;†honor.「-を保つ」/泰緬;Thai and Burma/
たいめんがた /対面型/
たいめんしき /対面式/
たいめんつうこう /対面通行/
たいめんはんばい /対面販売/
たいもう /体毛/大網/大望/
たいや /逮夜/
たいやき /鯛焼/
たいやく /対訳/大役/大約/大厄/
たいやくしゅう /対訳集/
たいゆーろ /対ユーロ/
たいゆう /大雄/大勇/大邑/
たいよ /貸与/
たいよう /太陽/大洋/態様/体用/大要/耐用/大用;大仕事/太洋;人名?/大陽;地名?/
たいようかつどう /太陽活動/
たいようかつどうしゅうき /太陽活動周期/
たいようぎょぎょう /大洋漁業/
たいようけい /太陽系/
たいようけいがい /太陽系外/
たいようけいしょうてんたい /太陽系小天体/
たいようけいぜんたい /太陽系全体/
たいようけいていこく /太陽系帝国/
たいようけいない /太陽系内/
たいようこう /太陽光/
たいようこうか /太陽光下/
たいようこうせん /太陽光線/
たいようこうはつでん /太陽光発電/
たいようこうべ /太陽神戸/
たいようこくてん /太陽黒点/
たいようしゅう /大洋州/
たいようしょぼう /大洋書房;[出版社名]/
たいようしん /太陽神/
たいようしんけいそう /太陽神経叢/
たいようしんこう /太陽信仰/
たいようじ /太陽時/
たいようじば /太陽磁場/
たいようすうはい /太陽崇拝/
たいようせきゆ /太陽石油;[企業名]/
たいようせん /大洋戦/
たいようぞく /太陽族/
たいようでんち /太陽電池/
たいようでんちしき /太陽電池式/
たいようでんちはつでん /太陽電池発電/
たいようとう /太陽灯/
たいようとしょ /大洋図書;[出版社名]/
たいようねつ /太陽熱/
たいようねつおんすいき /太陽熱温水器/
たいようねつりよう /太陽熱利用/
たいようねん /太陽年/
たいようねんすう /耐用年数/
たいようはつでん /太陽発電/
たいようふう /太陽風/
たいようゆうでん /太陽誘電/
たいようゆし /太陽油脂/
たいようれき /太陽暦/
たいようろ /太陽炉/
たいよかのう /貸与可能/
たいよく /大欲/
たいよけん /貸与権/
たいよこはま /対横浜/
たいよこはません /対横浜戦/
たいら /平/平ら/
たいらか /平らか/
たいらがい /平貝/
たいらのかねもり /平兼盛/
たいらのきよもり /平清盛/
たいらのまさかど /平将門/
たいらん /大乱/台覧/頽瀾/
たいり /大利/
たいりく /大陸/
たいりくいどうせつ /大陸移動説/
たいりくおうだん /大陸横断/
たいりくけい /大陸系/
たいりくさん /大陸産/
たいりくしき /大陸式/
たいりくしょぼう /大陸書房/
たいりくしんしゅつ /大陸進出/
たいりくせい /大陸性/
たいりくだな /大陸棚/
たいりくてき /大陸的/
たいりくなんぶ /大陸南部/
たいりくはっけん /大陸発見/
たいりくぶんか /大陸文化/
たいりくほう /大陸法/
たいりつ /対立/
たいりついけん /対立意見/
たいりついでんし /対立遺伝子/
たいりつかんけい /対立関係/
たいりつがいねん /対立概念/
たいりつこうぞう /対立構造/
たいりつこうほ /対立候補/
たいりつしゃ /対立者/
たいりつじく /対立軸/
たいりつてん /対立点/
たいりゃく /大略/
たいりゅう /滞留/対流/
たいりゅうけん /対流圏/
たいりゅうちょうせつ /対流調節/
たいりょ /大呂/
たいりょう /大量/大漁/退寮/大猟/
たいりょう> /大量;-生産,-殺人/
たいりょういんさつ /大量印刷/
たいりょうぎゃくさつ /大量虐殺/
たいりょうこうにゅう /大量購入/
たいりょうこうにゅうわりびき /大量購入割引/
たいりょうさいよう /大量採用/
たいりょうさつじん /大量殺人/
たいりょうし /大量死/
たいりょうしってん /大量失点/
たいりょうしゅっけつ /大量出血/
たいりょうしょうひ /大量消費/
たいりょうしよう /大量使用/
たいりょうせいさん /大量生産/
たいりょうせいさんひん /大量生産品/
たいりょうぜつめつ /大量絶滅/
たいりょうてん /大量点/
たいりょうとうこう /大量投稿/
たいりょうとうにゅう /大量投入/
たいりょうとくてん /大量得点/
たいりょうにゅうりょく /大量入力/
たいりょうはいき /大量廃棄/
たいりょうはいきしゃかい /大量廃棄社会/
たいりょうはかいへいき /大量破壊兵器/
たいりょうはっせい /大量発生/
たいりょうはっそう /大量発送/
たいりょうはっちゅう /大量発注/
たいりょうはんばい /大量販売/
たいりょうばた /大漁旗/
たいりょうぶし /大漁節;[民謡]/
たいりょうほゆうほうこくしょ /大量保有報告書/
たいりょうゆそう /大量輸送/
たいりょうゆそうきかん /大量輸送機関/
たいりょうり /タイ料理/
たいりょく /体力/耐力;[建築]外力に耐えられる力(の限界)/
たいりょくかいふく /体力回復/
たいりょくかべ /耐力壁/
たいりょくこうじょう /体力向上/
たいりょくしょうぶ /体力勝負/
たいりょくしょうもう /体力消耗/
たいりょくそくてい /体力測定/
たいりょくぞうしん /体力増進/
たいりょくてき /体力的/
たいりょくぶそく /体力不足/
たいりょくへき /耐力壁;[建築]構造として有効な壁/
たいりょくめん /体力面/
たいりょくようせい /体力養成/
たいりん /大輪;-の花/大倫;人の道/台臨;皇族の臨席/
たいるい /苔類/
たいるばり /タイル張り/タイル貼り/
たいれい /大礼/耐冷/胎齢/
たいれいせい /耐冷性/
たいれつ /隊列/
たいろ /退路/対露;対Russia/
たいろう /大老/
たいろん /対論/
たいわ /対話/大和/対和/
たいわがた /対話型/
たいわけいしき /対話形式/
たいわげき /対話劇;dialogue/
たいわしき /対話式/
たいわしゃ /対話者/
たいわしょり /対話処理/
たいわちょう /大和町/
たいわてき /対話的/
たいわへん /対話篇/
たいわほうしき /対話方式/
たいわよう /対話用/
たいわん /台湾/
たいわんかいきょう /台湾海峡/
たいわんさん /台湾産/
たいわんしゅっぺい /台湾出兵;[日本史]1871/
たいわんしょご /台湾諸語/
たいわんじん /台湾人/
たいわんせい /台湾製/
たいわんそうとく /台湾総督/
たいわんそうとくふ /台湾総督府/
たいん /多淫/
たう /多雨/τ;tau/Τ;Tau/
たうえ /田植/田植え/田上/
たうた /田歌/
たうち /田内/田打ち;[農業]耕すこと/
たうら /田浦/
たうりゅうし /τ粒子/
たうんし /タウン誌;[新語]地域誌/
たえ /妙/栲;(布)/
たえこ /妙子/多恵子/
たえず /絶えず/
たえだえ /絶え絶え/
たえて /絶えて/
たえま /絶え間/当麻/絶えま/
たお /田尾/垰/嵶/
たおか /田岡/
たおやか /嫋やか/
たおやめ /手弱女/
たおやめぶり /手弱女振り;⇔益荒男振り/
たおれ /倒れ/
たおんせつ /多音節/
たか /鷹/高/多寡/多価;polyvalent/尚/任/隆/貴/宇/孝/敬/崇/臣/亨/嵩/尭/孚/
たか> /高;高殿,高天井,高御座/
たかあがり /高上がり/
たかあき /孝明/隆明/貴章/貴昭/学聡/孝哲/
たかあし /高足/
たかあしがに /高足蟹/
たかあら /高荒/
たかい /他界/高井/
たかいし /高石/
たかいずみ /高泉/
たかいそう /多階層/
たかいち /高市/隆一/
たかいど /高井戸/
たかいびき /高鼾/
たかうじ /尊氏/
たかうち /高内/
たかえだ /高枝/
たかお /高尾/孝雄/隆夫/孝夫/高雄/隆雄/孝男/隆男/貴雄/貴男/貴生/高夫/貴夫/貴士/崇夫/尚夫/貴朗/孚夫/鷹生;名/
たかおえき /高尾駅/
たかおか /高岡/高丘/高岳/
たかおかえき /高岡駅/
たかおかし /高岡市/
たかおかしょてん /高岡書店/
たかおかせいさくしょ /高岳製作所;[企業名]/
たかおかちょう /高岡町/
たかおさん /高尾山/
たかおさんぐち /高尾山口/
たかおざん /高尾山/
たかおの /高尾野/
たかか /多花果/
たかかげ /隆景/
たかかず /剛一/剛和/
たかかわ /高河/
たかかんすう /多価関数/
たかが /高が/
たかがき /高垣/
たかがみね /鷹峯/
たかがり /鷹狩/
たかき /高木/高来/高樹/孝紀/
たかぎ /高木/高城/高樹/喬木/高来/都木;姓/鷹木/
たかぎあきみつ /高木彬光/
たかぎし /高岸/
たかぎわ /高際/
たかく /多角/高久/
たかくか /多角化/
たかくけい /多角形/
たかくけいえい /多角経営/
たかくしょうじょう /他覚症状;⇔自覚症状/
たかくすい /多角錐/
たかくちゅう /多角柱/
たかくてき /多角的/
たかくら /高倉/高蔵/
たかくらけん /高倉健/
たかくらだい /高倉台/
たかくらてんのう /高倉天皇/
たかくらやま /高倉山/
たかくわ /高桑/高鍬/
たかげた /高下駄/
たかこ /貴子/孝子/多香子/隆子/敬子/高子/多賀子/堂子/
たかこう /高高/
たかこくご /多ヶ国語/多カ国語/
たかさ /高さ/
たかさか /高坂/
たかさき /高崎/
たかさきせいし /高崎製紙;[企業名]/
たかさきせん /高崎線/
たかさきせんみやはら /高崎線宮原/
たかさきはまがわ /高崎浜川/
たかさきほうめん /高崎方面/
たかさご /高砂/
たかさごかん /高砂間/
たかさごご /高砂語/
たかさごしゃこ /高砂車庫/
たかさごだい /高砂台/
たかさせいげん /高さ制限/
たかさと /高郷/
たかさわ /高沢/高澤/
たかざわ /高沢/
たかし /鷹師/高志/隆志/隆史/隆司/喬/貴志/貴史/孝司/孝志/貴司/尚志/崇史/隆/孝/大/高/尚/敬/貴/卓/崇/洪/孝史/高史/尚史/貴士/高士/隆士/高師/高司/卓史/敬士/敬史/岳史/尚司/隆資/恭士/多加史/
たかしお /高潮/高汐/
たかしな /高科/高品/
たかしま /高島/高嶋/鷹島/
たかしまだ /高島田/
たかしまだいら /高島平/
たかしまちょう /高島町/
たかしまや /高島屋;[企業名]/
たかしみず /高清水/
たかしろ /高城/鷹城/
たかじょう /鷹匠/高城/
たかす /高鷲/鷹栖/高須/
たかすが /高須賀/
たかすぎ /高杉/
たかすぎしんさく /高杉晋作/
たかすみ /高住/
たかずみ /敬済/
たかせ /高瀬/
たかせい /多花性;[植物]/多価性;polyvalency/
たかせがわ /高瀬川/
たかせぶね /高瀬舟/
たかた /高田/田方/
たかたまゆこ /高田万由子/
たかだ /高田/
たかだい /高台/
たかだか /高々/
たかだかかさん /高々可算/
たかだし /高田市/
たかだて /高館/
たかだのばば /高田馬場/
たかだのばばえき /高田馬場駅/
たかだのばばしてん /高田馬場支店/
たかだのばばてん /高田馬場店/
たかだま /高玉/
たかちほ /高千穂/
たかちほきょう /高千穂峡/高千穂峽/
たかちほせん /高千穂線/
たかちほのみね /高千穂峰/
たかちょうし /高調子/
たかっけい /多角形/
たかつ /高津/
たかつか /高塚/
たかつかこうこう /高塚高校/
たかつかさ /鷹司/
たかつき /高槻/高月/高坏/
たかつきし /高槻市/
たかつきしみん /高槻市民/
たかつきてん /高槻店/
たかつく /高津区/
たかつぐ /高嗣/
たかて /高手/
たかてこて /高手小手/
たかとう /高遠/高藤/
たかとうりき /貴闘力/
たかとお /高遠/
たかとき /高時/
たかとし /隆俊/孝俊/孝利/隆利/孝寿/
たかとび /高飛び/高跳び/
たかとびこみ /高飛び込み;high dive/
たかとみ /高富/孝富/
たかとも /鷹友/
たかとり /高取/高鳥/
たかとりこうじょう /鷹取工場/
たかとりやき /高取焼/
たかどの /高殿/楼/
たかどまり /高止まり/
たかな /高菜/
たかなお /高直/高尚/
たかなか /高中/
たかなし /高梨/小鳥遊;姓/
たかなべ /高鍋/
たかなみ /高波/高浪/
たかなり /高鳴り/
たかなわ /高輪/高縄/
たかなわぐち /高輪口/
たかに /高荷/
たかにし /高西/
たかね /高値/高嶺;-の花/高根;=高嶺/高音/
たかねあんてい /高値安定/
たかねざわ /高根沢/
たかねのはな /高嶺の花/
たかねびけ /高値引け;[相場]/
たかの /高野/鷹野/高乃/
たかのがわ /高野川/
たかのす /鷹巣/鷹の巣/
たかのせん /高野線/
たかのぞみ /高望み/
たかのつめ /鷹の爪/
たかのなみ /貴ノ浪/
たかのは /鷹羽/
たかのはな /貴ノ花/
たかのはら /高の原/
たかのばし /タカノ橋/
たかのふじ /孝乃富士/
たかのぶ /孝信/貴信/敬信/
たかのり /孝則/隆則/孝徳/高徳/孝典/孝憲/隆典/崇徳/敬典/孝規/敬則/
たかは /タカ派/高羽/鷹派;強硬派/
たかはぎ /高萩/
たかはし /高橋/高梁;地名,岡山/
たかはしけいこ /高橋恵子/
たかはしこれきよ /高橋是清/
たかはしせいさくしょ /高橋製作所;[企業名]/
たかはしでいしゅう /高橋泥舟;1835-1903/
たかはしまりこ /高橋真梨子/
たかはしみちつな /高橋三千綱/
たかはしゆいち /高橋由一;(1828-94) 洋画家/
たかはた /高畠/高畑/
たかはたふどう /高幡不動/高畑不動/
たかはな /高鼻/高花/
たかはなだ /貴花田/
たかはま /高浜/高濱/
たかはまきょし /高浜虚子/
たかはら /高原/
たかはる /高原/高春/
たかば /高場/
たかばた /高機/
たかばたけ /高畠/
たかばなし /高話/
たかばやし /高林/
たかひく /高低/
たかひこ /隆彦/貴彦/孝彦/高彦/
たかひさ /貴久/隆久/高尚/
たかひで /貴英/
たかひと /貴仁/隆仁/隆人/
たかひら /高平/高比良/
たかひろ /隆弘/貴裕/隆博/隆宏/貴博/貴大/孝浩/孝宏/高広/貴広/貴浩/孝広/隆浩/隆寛/隆広/貴宏/孝洋/高宏/崇博/高裕/敬弘/隆啓/
たかびしゃ /高飛車/
たかふだ /高札/
たかふみ /隆文/隆史/貴文/貴史/孝文/孝史/
たかべ /高部/
たかぼうし /高帽子/
たかまがはら /高天原/
たかまくら /高枕/
たかまさ /孝政/孝昌/高政/隆政/隆征/
たかまつ /高松/
たかまつえき /高松駅/
たかまつかん /高松間/
たかまつこう /高松港/
たかまつこくぜいきょく /高松国税局/
たかまつし /高松市/
たかまつしない /高松市内/
たかまつしょう /高松商/
たかまつじょう /高松城/
たかまつづかこふん /高松塚古墳;奈良/
たかまつのみや /高松宮/
たかまつのみやはい /高松宮杯/高松宮盃/
たかまど /高窓/
たかまどのみや /高円宮/
たかまのはら /高天原/
たかまる /鷹丸/
たかみ /高見/高み/孝美/
たかみくら /高御座/
たかみさわ /高見沢/
たかみざわ /高見沢/
たかみす /高見州/
たかみすぎ /隆三杉/
たかみず /高水/
たかみち /隆道/孝通/尊道/
たかみつ /貴光/隆充/
たかみね /高峰/高嶺/嵩嶺/
たかみねじょうきち /高峰譲吉/
たかみねひでこ /高峰秀子/
たかみや /高宮/
たかむこのくろまろ /高向玄理/
たかむしろ /簟/
たかむね /高宗/
たかむら /篁/高村/竹叢/
たかむらこううん /高村光雲/
たかむらこうたろう /高村光太郎/
たかむらものがたり /篁物語/
たかめ /高目/高め/
たかもと /高本/
たかもり /高森/隆盛/鷹森/高盛/
たかもりかん /高森間/
たかや /高屋/高谷/隆也/隆弥/
たかやす /高安/貴康/
たかやなぎ /高柳/
たかやま /高山/鷹山/
たかやまかん /高山間/
たかやません /高山線/
たかやまちょう /高山町/
たかやまほうめん /高山方面/
たかやまほんせん /高山本線/
たかやままつり /高山祭/
たかゆか /高床;-式(住居)/
たかゆかしき /高床式/
たかゆき /孝之/貴之/隆之/隆行/孝行/隆幸/孝幸/貴行/敬之/崇之/貴幸/高行/高之/崇行/高幸/尊之/敬行/能之/
たかようじ /高楊枝/
たかよし /隆義/孝允/孝義/隆吉/高良/孝佳;名/高好/貴良/隆克/
たから /宝/財/寶;「宝」の旧字1/寳;「宝」の旧字2/
たからい /宝井/
たからか /高らか/
たからがい /宝貝/
たからがいけ /宝が池/
たからくじ /宝くじ/
たからさがし /宝探し/
たからしゅぞう /宝酒造;[企業名]/寳酒造/
たからじま /宝島/
たからずか /宝塚;※仮名遣い「たからづか」/
たからずかきねんば /宝塚記念馬;※仮名遣い「たからづか」/
たからずかしょうじょかげき /宝塚少女歌劇;※仮名遣い「たからづか」/
たからずかだいげきじょう /宝塚大劇場;※仮名遣い「たからづか」/
たからだ /宝田/
たからだま /宝玉/
たからづか /宝塚/
たからづかおんせん /宝塚温泉/
たからづかかげき /宝塚歌劇/
たからづかきねん /宝塚記念/
たからづかきねんば /宝塚記念馬/
たからづかし /宝塚市/
たからづかしょう /宝塚賞/
たからづかしょうじょかげき /宝塚少女歌劇/
たからづかせん /宝塚線/
たからづかだいげきじょう /宝塚大劇場/
たからづかほうめん /宝塚方面/
たからづかみなみぐち /宝塚南口/
たからばこ /宝箱/
たからぶね /宝船/
たからべ /財部/
たからまち /宝町/
たからもと /宝本/
たからもの /宝物/
たかわらい /高笑い/
たかん /多感/多環/
たかんしょう /多汗症/
たかんせつ /多関節/
たが /箍/他我/多賀;地名/
たがい /互い/互/違い;difference/
たがいしゃ /他会社/
たがいせん /互先;[囲碁]/互い先;[囲碁]ハンディキャップ(置き)なし/
たがいちがい /互い違い/
たがいに /互いに/
たがき /田垣/
たがく /多額/
たがくぶ /他学部/
たがしら /田頭;姓/
たがじょう /多賀城/
たがじょうし /多賀城市/
たがた /田方/
たがたぐん /田方郡/
たがっか /他学科/
たがね /鏨/
たがひ /違ひ/互/
たがみ /田上/
たがや /多賀谷/
たがらす /田烏/
たがりゅう /多賀竜/
たがろぐご /タガログ語;Tagalog/
たがわ /田川/田河/多川/
たがわすいほう /田河水泡/
たがん /多眼/
たがんし /多眼視/
たき /滝/多岐;-に亘る/瀧;「滝」の旧字(人名用漢字)/瀑;≒滝/多紀/多喜/
たきあせ /滝汗/
たきあわせ /炊き合わせ/炊き合せ/
たきい /滝井/
たきいえき /滝井駅/
たきうち /滝内/瀧内/
たきお /滝尾/多喜夫/
たきかわ /滝川/瀧川/
たきかわえき /滝川駅/
たきがわ /滝川/瀧川/多岐川/
たきぎ /薪/焚き木/
たきぎのう /薪能/
たきぐち /滝口/瀧口/焚き口/
たきこみごはん /炊込みご飯/
たきさわ /滝沢/滝澤/
たきざわ /滝沢/滝澤/瀧沢/
たきざわばきん /滝沢馬琴;南総里見八犬伝/
たきざわりんどう /滝沢林道/
たきしゅ /他機種/多機種/
たきしゅよう /他機種用/
たきた /滝田/瀧田/
たきたて /炊き立て;-の冷飯/
たきだ /瀧田/
たきだし /炊き出し/炊出し/
たきつけ /焚き付け/焚付け/
たきつせ /滝つ瀬/
たきつぼ /滝壷;「壺」異体字/滝壺/
たきとう /多気筒/
たきなみ /滝波/
たきね /滝根/
たきの /滝野/瀧野/多喜乃/
たきのう /多機能/他機能;other functions/
たきのうか /多機能化/
たきのうせい /多機能性/
たきのうでんわ /多機能電話/
たきのがわ /滝野川/瀧野川/
たきのがわじょしがくえん /瀧野川女子学園/
たきはら /滝原/
たきひろ /滝広/
たきび /焚き火/焚火/
たきぼうよう /多岐亡羊/
たきもと /滝本/瀧本/
たきもの /焚物/焚き物/薫物/
たきや /滝谷/
たきやま /滝山/瀧山/
たきゅう /田久/
たきゅうじょう /他球場/
たきゅうだん /他球団/
たきょう /田京/他郷/
たきょく /他局/多極/
たきょくか /多極化/
たきょてん /他拠点/
たきれんたろう /滝廉太郎/
たぎ /多義/
たぎご /多義語/
たぎせい /多義性/
たぎてき /多義的/
たぎょう /タ行/た行/
たぎょうしゅ /他業種/
たぎり /田切/
たく /宅/卓/多久;地名,佐賀県/拓;開拓/託;委託/托;托卵/択;選択/擇;「択」の旧字/鐸;銅鐸/鈬;「鐸」の異体字/沢;(さわ)沢山/澤;「沢」の旧字/濯;洗濯/擢;抜擢/戳/啄;(つつく)啄木/琢;(みがく)彫琢/柝;撃柝/拆/倬/啅/磔;磔刑/謫;流謫/魄;(呉音の一つ) たましい/度/柘;?/
たくあき /卓明/
たくあつかい /宅扱い/
たくあん /沢庵/
たくい /宅井/
たくいつ /択一/
たくいつしき /択一式/
たくえつ /卓越/
たくえつふう /卓越風/
たくお /卓夫/卓雄/拓雄/
たくき /琢己/
たくけい /磔刑/
たくげん /託言/
たくさい /卓才/
たくさり /田鎖/
たくさん /沢山/
たくし /卓子;table/拓志/卓史/度支/托子/
たくしき /卓識/
たくしゅつ /卓出/
たくしょ /謫所/
たくしょう /托生;一蓮-/
たくしょく /拓殖/
たくしょくだい /拓殖大/
たくしょくだいがく /拓殖大学/
たくしょくだいがくだいいちこうこう /拓殖大学第一高校/
たくしろう /卓四郎/
たくしん /宅診/託身/
たくじ /託児/卓司/卓治/卓爾/拓史/拓嗣/琢爾/
たくじしせつ /託児施設/
たくじしつ /託児室/
たくじしょ /託児所/
たくじじょ /託児所/
たくじょう /卓上/
たくじょうかれんだー /卓上カレンダー/
たくじょうがた /卓上型/
たくじょうち /卓状地/
たくせつ /卓説/
たくせん /託宣/
たくせんしょ /託宣所/
たくぜつ /卓絶/
たくそう /託送/拓宋/
たくそうてにもつ /託送手荷物/
たくぞう /卓三/卓造/
たくだいいちこう /拓大一高/
たくち /宅地/
たくちかいはつ /宅地開発/
たくちぞうせい /宅地造成/
たくちたてものとりひきぎょうほう /宅地建物取引業法/
たくちたてものとりひきしゅにんしゃ /宅地建物取引主任者;宅建/
たくちなみかぜい /宅地並課税/
たくと /琢人/
たくないよう /宅内用/
たくはい /宅配/
たくはいきぼう /宅配希望/
たくはいびん /宅配便/
たくはいびんぎょうしゃ /宅配便業者/
たくはいびんりょうきん /宅配便料金/
たくはつ /托鉢/
たくばつ /卓抜;outstand/択抜;select/
たくふ /卓布/
たくほん /拓本/
たくぼ /田久保/田窪/
たくぼく /啄木/
たくま /琢磨/詫間/宅間/託間/
たくまでんぱこうせん /詫間電波高専/
たくみ /匠/巧/拓海/内匠/拓美/卓己/琢巳/琢美/琢弥/巧み/
たくみのかみ /内匠頭/
たくや /拓也/拓哉/卓也/琢也/卓哉/卓弥/
たくよう /托葉/
たくら /田倉/
たくらく /拓落;-失路/
たくらくしつろ /拓落失路/
たくらみ /企み/
たくらん /托卵;カッコウの-/
たくりつ /卓立/
たくろう /拓郎/卓朗/
たくろうしょ /宅老所/託老所/
たくろく /宅録/
たくろん /卓論/
たくわえ /蓄え/貯え/
たくわん /沢庵/
たぐい /類/類い/疇/畴/
たぐいまれ /類稀/類い稀/
たぐうち /タグ打ち/
たぐす /田楠/
たぐち /田口/
たぐり /田栗/
たぐん /多群/
たけ /竹/丈/茸/岳/嶽;「岳」の旧字/他家/武/健/雄/毅/威/斌;?/
たけい /多型;[医学][化学]塩基-/武井/竹井/武居/多形/竹居/他系/
たけいし /武石/
たけいち /武市/竹市/武一/
たけいれつ /他系列/
たけうち /竹内/武内/
たけうちがいし /竹内外史/
たけうま /竹馬/
たけお /武雄/武夫/丈夫/武男/健夫/竹尾/健郎/健生/威雄/竹生/毅雄/竹雄/竹男/岳男/竹夫/岳生/武朗/丈生/
たけおおんせん /武雄温泉/
たけおか /竹岡/
たけおかせん /竹岡戦/
たけかご /竹籠/
たけかず /丈和/
たけかわ /竹川/武川/竹河/
たけかんむり /竹冠/
たけがき /竹垣/
たけがた /竹形/
たけがはら /竹ヶ原/
たけがり /茸狩/
たけがわ /竹河/
たけき /健樹/
たけくに /武邦/
たけくらべ /丈比べ;背比べ/
たけぐし /竹串/
たけぐち /竹口/
たけこ /武子;名/
たけこし /竹越/竹腰/
たけさか /竹坂/
たけざいく /竹細工/
たけざお /竹竿/
たけざき /竹崎/
たけざわ /竹澤/竹沢/
たけし /武/健/剛/猛/豪/毅/岳/英/武士/剛志/威/武志/武史/武司/剛史/丈史/健志/健史/岳史/武石/武嗣/丈司/竹志/威志/毅史/毅之/
たけした /竹下/
たけしたけいこ /竹下景子/
たけしたのぼる /竹下登/
たけしば /竹芝/
たけしま /竹島/武島/
たけしょぼう /竹書房/
たけじ /武治/
たけじろう /竹次郎/
たけすえ /武居/
たけすだれ /竹簾/
たけぞえ /竹添/
たけぞの /竹園/
たけた /竹田/
たけたに /竹谷/
たけだ /武田/竹田/
たけだえき /竹田駅/
たけだし /竹田市/
たけだしんげん /武田信玄/
たけだたいじゅん /武田泰淳;作家。『ひかりごけ』/
たけだのみや /竹田宮/
たけち /武市/武智/
たけっしょう /多結晶/
たけつ /多血/
たけつぐ /健嗣/
たけつしつ /多血質/
たけづつ /竹筒/
たけと /岳人/健人/丈人/竹人/
たけとし /武俊/壮聡/
たけとみ /竹富/武富/
たけとみじま /竹富島/
たけとも /斌友/
たけとよ /武豊/
たけとよせん /武豊線/
たけとり /竹取/
たけとりのおきな /竹取翁/
たけとりものがたり /竹取物語/
たけとんぼ /竹とんぼ/竹トンボ/竹蜻蛉/
たけなお /武直/
たけなか /竹中/武中/
たけなかこうむてん /竹中工務店/
たけなが /丈長/
たけながほうしょ /丈長奉書/
たけなみ /竹並/
たけなり /雄成/丈成/
たけなわ /酣/闌;≒酣/竹縄/武縄;人名/
たけの /竹野/武野/
たけのうち /竹内/竹之内/
たけのうちかいどう /竹内街道;堺-橿原/
たけのこ /竹の子/筍/笋;「筍」の異体字/
たけのこめし /筍飯/
たけのだい /竹の台/
たけのはま /竹野浜/
たけのぶ /武信/健伸/
たけのり /武憲/武範/健雅/
たけはし /竹橋/
たけはしかいかん /竹橋会館/
たけはな /竹花/
たけはら /竹原/武原/
たけはる /丈晴/毅治/
たけばし /竹橋/竹箸/
たけばやし /竹林/
たけひこ /武彦/雄彦/健彦/毅彦/剛彦/竹彦/建彦/
たけひご /竹籤/竹ひご/
たけひさ /武久/竹久/
たけひさゆめじ /竹久夢二;(1884-1934) 画家/
たけひで /武英/武秀/
たけひと /武人/武仁/雄人/
たけひら /竹平/
たけひろ /武大/竹広/威裕/雄洋/武裕/威博/毅寛/
たけふ /武生/竹生/
たけふさ /竹房;姓/
たけふじ /武藤/武富士;[企業名]www.takefuji.co.jp/
たけふみ /武文/
たけぶえ /竹笛/
たけべ /建部/武部/竹部/
たけべあやたり /建部綾足/
たけべら /竹篦/
たけぼうき /竹箒/
たけまえ /竹前/
たけまさ /竹政;姓/
たけまつ /竹松/
たけみ /武見/武三/
たけみつ /武満/竹光/
たけみや /竹宮/武宮/
たけむら /竹村/武村/竹群/竹叢/
たけもち /威望/
たけもと /竹本/武本/武元/
たけもり /竹森/
たけや /竹屋/武谷/竹弥/
たけやぶ /竹薮/
たけやま /竹山/武山/
たけやり /竹槍/武鑓/
たけゆき /健幸/岳之/
たけよし /武吉/建美/
たけん /他県/他見/
たけんきゅうしつ /他研究室/
たけんれん /他県連/
たげい /多芸/
たげいたさい /多芸多才/
たげん /多元/多言/他言/
たげんか /多元化/
たげんご /多言語/他言語/
たげんごか /多言語化/
たげんごたいおう /多言語対応/
たげんせい /多元性/
たげんてき /多元的/
たげんむよう /他言無用/
たげんろん /多元論;pluralism/
たこ /蛸/凧;kite/胼胝;耳に-/多古;地名/章魚;=蛸/鮹;=蛸/鱆;=蛸/胝;=胼胝/
たこあげ /凧揚げ;天まで揚がれ/
たこあし /タコ足/蛸足;-配線/
たこあしはいせん /タコ足配線/蛸足配線/
たこいと /凧糸/
たこう /他校/多孔/多幸/他行/多項/
たこうかん /多幸感/
たこうしき /多項式/
たこうしきかいき /多項式回帰/
たこうしきかんすう /多項式関数/
たこうしきじかん /多項式時間/
たこうしつ /多孔質/
たこうしつざい /多孔質材/
たこうしょう /多幸症/
たこうせい /多孔性/他校生/
たこうてい /多工程/
たこうていり /多項定理;[数学]polynomial theorem/
たこく /他国/
たこくかん /多国間/
たこくかんきょうぎ /多国間協議/
たこくご /多国語/
たこくごか /多国語化/
たこくごたいおう /多国語対応/
たこくごばん /多国語版/
たこくさん /他国産/
たこくせき /多国籍/他国籍/
たこくせききぎょう /多国籍企業/
たこくせきぐん /多国籍軍/
たこじま /蛸島/
たこなぐり /タコ殴り/
たこのきもく /タコノキ目/Pandanales/
たこべや /タコ部屋/蛸部屋;軟禁飯場/
たこやき /たこ焼/タコ焼/蛸焼/
たこん /多恨/
たご /田子/多胡/多湖/多語/他語/
たごう /田郷;姓/
たごさく /田吾作/
たごのうら /田子の浦/
たごん /他言/多言/
たごんむよう /他言無用/
たさい /多彩/多才/多妻;一夫-/
たさいと /他サイト/
たさいぼう /多細胞/
たさいぼうせいぶつ /多細胞生物/
たさか /田坂/
たさき /田崎/
たさく /多作;⇔寡作/
たさくひん /他作品/
たさつ /他殺/
たさん /多産/
たざ /打坐/
たざい /多罪/
たざいたいせい /多剤耐性/
たざき /田崎/
たざけ /田酒/
たざせき /多座席/
たざわ /田沢/田澤/
たざわこ /田沢湖/
たざわこせん /田沢湖線/
たざわこはん /田沢湖畔/
たざわぬま /田沢沼/
たざん /他山/
たざんのいし /他山の石/
たし /他誌/他紙/足し/多士/多指/多死/多肢/
たしか /確か/慥か/
たしき /多識/
たしさいさい /多士済々/多士済済/
たしざん /足し算/足算/
たしせいせい /多士済済/多士済々/
たしつ /多湿/咤叱/
たしてん /多視点/
たしなみ /嗜み/
たしま /田嶋/
たしゃ /他者;l'autre,the other/他社;other companies/多謝;「助力-」/他車;other cars/
たしゃかん /他社間/
たしゃく /他借/
たしゃせい /他社製/他者性;[哲学]otherness/
たしゃせいひん /他社製品/
たしゃせん /他社線/
たしゃびん /他社便/
たしゅ /多種;various.「-多様」/他種;other species/
たしゅう /他宗/他州/
たしゅうだん /他集団/
たしゅせんゆう /他主占有;所有の意思なくしてする占有,賃借人の占有等,⇔自主占有/
たしゅたよう /多種多様/
たしゅつ /他出/
たしゅつりょく /多出力/
たしゅみ /多趣味/
たしゅるい /多種類/
たしょ /他所/他諸/他書/
たしょう /多少/他称/他生/多生/多祥/
たしょうえいきょう /多少影響/
たしょうかいぜん /多少改善/
たしょうきょうみ /多少興味/
たしょうちょう /他省庁/
たしょうてま /多少手間/
たしょうなん /多少難/
たしょうふあん /多少不安/
たしょうふぐあい /多少不具合/
たしょうふべん /多少不便/
たしょうむり /多少無理/
たしょく /多色/多食/
たしょくか /多色化/
たしょくずり /多色刷り/多色刷/他色刷;?/
たしろ /田代/
たしん /多芯/他心/
たしんきょう /多神教/
たしんぎ /多進木/
たしんせん /多芯線/
たしんぴ /多心皮/
たしんぴるい /Polycarpicae/
たしんろん /多神論/
たじ /他事;「-ながら」/多事;「-多難」/
たじか /田近/
たじげん /多次元/
たじげんか /多次元化/
たじげんしゃくどこうせいほう /多次元尺度構成法/
たじげんてき /多次元的/
たじげんはいれつ /多次元配列/
たじたたん /多事多端/
たじたなん /多事多難/
たじつ /他日/
たじま /但馬/田島/田嶋/田嶌/
たじまちほう /但馬地方/
たじみ /多治見/
たじめ /田治米;姓/
たじゅう /多重/多汁/
たじゅう> /多重/
たじゅうおん /多重音/
たじゅうか /多重化/
たじゅうかいぞうどかいせき /多重解像度解析/
たじゅうけいしょう /多重継承/
たじゅうけつごう /多重結合/
たじゅうこ /多重呼/
たじゅうさいむ /多重債務/
たじゅうさいむしゃ /多重債務者/
たじゅうさんらん /多重散乱/
たじゅうしょり /多重処理/
たじゅうじんかく /多重人格/
たじゅうじんかくしゃ /多重人格者/
たじゅうせい /多重性/
たじゅうせきぶん /多重積分/
たじゅうていぎ /多重定義/
たじゅうとうこう /多重投稿/
たじゅうど /多重度/
たじゅうは /多重波/
たじゅうほうそう /多重放送/
たじゅうろくおん /多重録音/
たじゅうろこう /多重露光/
たじゆうど /多自由度/
たじょう /多情/
たじょうけん /他条件/
たじょうたこん /多情多恨/
たじょうぶっしん /多情仏心/
たじょうほう /他情報/
たじり /田尻/
たじん /多人/
たす /足す/＋;plus/
たすいいき /他水域/
たすう /多数/
たすういけん /多数意見/
たすううんてん /多数運転/
たすうおうぼ /多数応募/
たすうかい /多数回/
たすうがわ /多数側/
たすうけつ /多数決/
たすうけつげんり /多数決原理/
たすうこ /多数個/
たすうさんか /多数参加/
たすうしゃ /多数者/
たすうしゅう /多数集/
たすうしよう /多数使用/
たすうそんざい /多数存在/
たすうだい /多数台/
たすうてん /多数点/
たすうとう /多数党/
たすうとうろく /多数登録/
たすうは /多数派/
たすうはいび /多数配備/
たすうはこうさく /多数派工作/
たすうはっせい /多数発生/
たすうみんぞく /多数民族/
たすき /襷/
たすきがけ /襷掛け/
たすきぞり /襷反り/
たすく /佑/相/輔/匡/弼/
たすけ /助け/太助/多助/
たすけあい /助け合い/
たすけぶね /助け船/
たず /田鶴/
たずき /方便/活計;生活手段/
たずな /手綱/
たずね /尋ね/
たずねびと /尋ね人/
たずねもの /尋ね物/
たせい /多声/
たせいおんがく /多声音楽/
たせいぶん /多成分/
たせかい /多世界/
たせかいかいしゃく /多世界解釈/
たせきてき /他責的/
たせん /他薦/多選/
たせんく /他線区/
たぜい /多勢/
たそ /誰そ/
たそう /多層/多相/
たそうか /多層化/
たそうがた /多相型/
たそうきばん /多層基板/
たそうこうぞう /多層構造/
たそうこうぞうなべ /多層構造鍋/
たそうしき /多層式/
たそうせい /多相性/
たそうてき /多相的/
たそうなべ /多層鍋/
たそうひょうひ /多層表皮/
たそがれ /黄昏/
たそがれづき /黄昏月/
たそがれどき /黄昏時/
たそがれどり /黄昏鳥/
たそく /多足/
たそくるい /多足類/
たそしき /他組織/
たぞえ /田添/田副/
たた /多々/
たた> /多々;(副詞)/
たたい /多胎/多体/多態/田多井/田々井/
たたいいち /多対一/
たたいけい /多体系/
たたいた /多対多/
たたいにんしん /多胎妊娠;[医]polycyesis/
たたいもんだい /多体問題/
たたえ /湛え/
たたかい /戦い;(字義:武器で敵を倒す)/闘い;(字義:二者が向き合い争う)/
たたき /三和土/叩き/
たたきあげ /叩き上げ/
たたきいし /叩き石/
たたきだい /叩き台/たたき台/
たたすく /他タスク/
たたずまい /佇まい/
たたど /多々戸/
たたに /田谷/
たたません /田玉線/
たたみ /畳/疊;「畳」の旧字(人名用漢字)/疂;「畳」の旧字2/疉;「畳」の旧字3/
たたみいわし /畳鰯/
たたみおもて /畳表/
たたみがえ /畳替え/
たたみがみ /畳紙/
たたみこみ /畳み込み/
たたみじき /畳敷き/畳敷/
たたみつき /畳付/畳付き/
たたみてん /畳店/
たたみはんぶん /畳半分/
たたみばり /畳針/
たたみべや /畳部屋/
たたみま /畳間/
たたみめ /畳目/畳み目/
たたみもの /畳物/
たたら /踏鞴;踏んで使うふいご/蹈鞴;=踏鞴/多々良;地名,福岡/多田羅/
たたり /祟り/祟/
たたりめ /祟り目;弱り目に-/
たたん /他端;⇔一端/多端;多事-/
たたんし /多端子/
ただ /唯/只/多田/無料;当て字/正/直/維/伊/忠/匡/但/惟/
ただ> /唯;-一匹/
ただあき /忠明/理顕/
ただい /多大/他大;他大学/
ただいがく /他大学/
ただいま /只今/ただ今/唯今/
ただいまさんじょう /只今参上/
ただお /忠夫/忠雄/忠男/維男/
ただおか /忠岡/
ただおき /忠興/
ただき /但木/只木/
ただくま /只熊/
ただけん /只券/タダ券/
ただごと /只事/ただ事/徒事/唯事/
ただごとうた /徒言歌/
ただし /但し/尚志/忠司/忠志/忠史/匡史/理/正/直/忠/是/貞/匡/禎/惟史/正し/
ただしがき /但し書き/但書/ただし書き/但し書/但書き/
ただす /匡/
ただすつかさ /弾正台/
ただせん /太多線/
ただたか /匡孝/
ただただ /只々/唯々/只只/唯唯/
ただちに /直ちに/
ただとし /忠利/正利/
ただなか /只中/ただ中/
ただの /只野/唯野/
ただのぶ /忠信/
ただのり /只乗り/忠度/忠則/匡孝/
ただはる /忠治/
ただばたらき /只働き/タダ働き/
ただひこ /忠彦/伊彦/
ただひさ /正久/
ただひとつ /唯一つ/
ただひとり /唯一人/
ただひら /忠平/
ただひろ /忠弘/忠宏/忠広/忠博/忠浩/
ただびと /只人/直人/徒人/
ただふみ /忠文/能文/
ただまさ /忠正/
ただみ /只見/
ただみせん /只見線/
ただみち /忠道/直道/
ただもと /忠元/
ただもの /只者/
ただや /多田屋/
ただゆき /忠行/忠之/忠幸/
ただよし /忠義/忠良/忠吉/忠儀/忠央/
ただれ /爛れ/
ただわか /唯若/
ただん /多段/
ただんかい /多段階/
ただんたい /他団体/
ただんとう /多弾頭/
たち /達/太刀/大刀;=太刀/質/館/立/多値/多知/多智/性質/城/舘;「館」の異体字/逹;「達」の異体字/立ち/
たちあい /立ち会い/立会/立ち合い/立合/
たちあいえんぜつ /立会演説/
たちあいがわ /立会川/
たちあいじょう /立会場;[相場]/
たちあいていし /立会停止/
たちあいにん /立会人/
たちあおい /立葵/
たちあがり /立ち上がり/立上り/
たちあがりじかん /立ち上がり時間/
たちあげ /立ち上げ/起ち上げ/
たちあらい /大刀洗/
たちい /立ち居/立居/起ち居/
たちいき /他地域/
たちいち /立ち位置/
たちいふるまい /立ち居振る舞い/立ち居振舞/立ち居振舞い/立居振舞/
たちいり /立ち入り/立入/立入り/
たちいりきんし /立入禁止/
たちいりきんしばしょ /立入禁止場所/
たちいりけんさ /立入検査/立ち入り検査/
たちいりちょうさ /立入調査;警察の-/
たちうお /太刀魚/
たちうち /太刀打ち/立射ち/
たちうり /立売/
たちえり /立ち襟;[服飾]/立襟/
たちおうじょう /立ち往生/立往生/
たちおくれ /立ち遅れ/立ち後れ/
たちおよぎ /立ち泳ぎ/
たちかけ /太刀掛/
たちかぜ /太刀風/
たちかた /立ち方/裁ち方/
たちかわ /立川/太刀川/
たちかわえき /立川駅/
たちかわし /立川市/
たちかわじょし /立川女子/
たちかわぶんこ /立川文庫/
たちかわほうめん /立川方面/
たちかわり /立ち代わり/立ち替わり/
たちかんすう /多値関数/
たちがみ /舘上/
たちがれ /立ち枯れ;[園芸]stand dead/立枯れ/
たちがれびょう /立枯れ病/立ち枯れ病/
たちき /立木/
たちぎ /立木/
たちぎえ /立ち消え/立消え/
たちぎき /立ち聞き/立聞き/
たちく /他地区/
たちくいやき /立杭焼/
たちくらみ /立ち眩み/
たちぐい /立ち食い/立食い/
たちぐいそば /立ち食いそば/
たちげいこ /立ち稽古/
たちさがり /立ち下がり/
たちさき /太刀先/
たちざわ /立沢/立澤/
たちしょうべん /立ち小便/
たちしょん /立ちション/
たちじゃこうそう /立麝香草/
たちすがた /立ち姿/
たちすじ /太刀筋/
たちせきとっきゅうけん /立席特急券/
たちどころ /立ち所/
たちぬい /裁ち縫い/
たちのうお /太刀の魚/
たちのき /立ち退き/
たちのきりょう /立退料/立ち退き料/立退き料/
たちのみ /立ち飲み/
たちはばとび /立ち幅跳び;両足を揃えた状態からの幅跳び/
たちはら /立原/
たちはらみちぞう /立原道造;詩人。『萱草に寄す』/
たちば /立場/立羽;姓/
たちばさみ /裁ち鋏;裁縫用/
たちばじょう /立場上/
たちばな /橘/立花/
たちばなし /立ち話/
たちばなわん /橘湾/
たちばん /立ち番/
たちひ /立飛/
たちまち /忽ち/立町/忽/立待ち/怱ち;?/
たちまちづき /立待月;陰暦十七日の月/
たちまわり /立ち回り/立回り/
たちみ /立ち見/立見/
たちみけん /立見券/
たちみせき /立見席/
たちめい /太刀銘/
たちもち /太刀持;[相撲]/
たちもの /断ち物/裁ち物/
たちもり /館盛/
たちや /達谷/
たちやく /立役/
たちやま /立山/
たちよみ /立ち読み/立読み/
たちろんり /多値論理/
たちわざ /立ち技;⇔寝技/立技/
たちんぼう /立ちん坊/
たっかん /達観/
たっきゅう /卓球/宅急/
たっきゅうだい /卓球台/
たっきゅうびん /宅急便;[商標]ヤマト運輸 NB:商標でない表現は「宅配便」/
たっきゅうぶ /卓球部/
たっきょ /謫居/
たっけい /磔刑/
たっけん /宅建;[略語]宅地建物取引主任者/卓見;ぬきんでた見識/達見;見通しのよい見識/
たっけんぎょう /宅建業/
たっこう /卓効/
たっし /達し/
たっしき /達識/
たっしゃ /達者/
たっせい /達成/
たっせいかのう /達成可能/
たっせいかん /達成感/
たっせいしゃ /達成者/
たっせいど /達成度/
たっせいりつ /達成率/
たった /立田/
たったいま /たった今/
たっちゅう /塔頭/
たっぱ /立端;高さ./
たっぴ /竜飛/龍飛/
たっぴかいていえき /竜飛海底駅/
たっぴつ /達筆/
たっぴみさき /竜飛岬/
たつ /龍;「竜」の旧字(人名用漢字)/竜/辰;[十二支]5/立/達;到達/逹;「達」の異体字/撻;鞭撻/韃;(むちうつ)/燵;炬燵/闥/斬;?/
たつあき /達明/
たつい /達意/
たついち /辰一/
たつお /達夫/達雄/辰夫/辰雄/達男/達郎/龍雄/龍夫/辰男/龍男/竜夫/竜雄/竜生/立雄/
たつおか /立岡/龍岡/竜岡/
たつおかもん /竜岡門/龍岡門/
たつおき /辰興/
たつかわ /立川/達川/
たつき /立木/方便;生活手段/活計;しがない-/
たつきち /辰吉/
たつきよ /達清/
たつくち /辰口/
たつぐち /辰口/
たつごう /竜郷/
たつし /達志/達史/辰史/
たつしま /立嶋/
たつじ /達治/達司/龍司/辰二/辰司/
たつじん /達人/
たつせ /立つ瀬/
たつた /龍田/竜田/立田/
たつたあげ /竜田揚げ/
たつたか /辰敬/
たつたがわ /竜田川/
たつとし /達利/達俊/
たつとり /立つ鳥;-跡を濁さず/
たつどし /辰年/
たつなみ /立浪/
たつなみべや /立浪部屋/
たつなり /達就/
たつにしき /龍錦/
たつの /辰野/龍野/竜野/
たつのくち /辰口/竜ノ口/
たつのくちちょう /辰口町/
たつのくちまち /辰口町/
たつのちょう /辰野町/
たつのにし /竜野西/
たつのひげ /竜の鬚/
たつのり /辰徳/辰則/達徳/達就/辰範/
たつひこ /龍彦/達彦/
たつひろ /達弘/
たつぶん /達文/
たつべん /達弁/
たつま /竜馬/辰馬/
たつまき /竜巻/
たつみ /巽/辰巳/辰己/立見/辰爾/竜実/
たつみことば /辰巳言葉/
たつみしゅっぱん /辰巳出版;[出版社名]/
たつや /達也/竜也/達哉/辰也/龍也/辰哉/立哉/立矢/立弥/
たつやま /龍山/竜山/
たつゆき /達之/達行/
たつるはま /田鶴浜/
たつろう /達郎/達朗/
たつんど /達人/
たづくり /田作り/手作り;手織りの木綿/
たづこ /田鶴子/
たづな /手綱/覊/
たづら /田面/
たて /縦/盾/楯;=盾/殺陣/経;経糸,経巻/竪;(鉛直) 竪琴,竪穴/立/立て/建/館/舘;異体字/蓼;たで/縱;「縦」の旧字(人名用漢字)/│;罫線 →たてせん/┃;太い罫線/
たて> /縦;縦社会,縦ノリ,縦画面/
たてあき /賢明/
たてあな /竪穴/縦穴/
たてあなしき /竪穴式/
たてあなしきじゅうきょ /竪穴式住居/
たてあなしきせきしつ /竪穴式石室/
たていし /立石/建石/
たていしでんき /立石電機;[企業名]/
たていた /立板/立て板;-に水/
たていち /縦位置/
たていちよう /縦位置用/
たていちれつ /縦一列/
たていと /縦糸/経糸/経/經;「経」の旧字/
たていわ /館岩/
たてうち /舘内/館内/
たてうま /立馬/
たてうり /建売/建て売り/建売り/
たてえぼし /立烏帽子/
たてお /建夫/立夫/建郎/
たておか /楯岡/
たておき /縦置き/縦置/
たてかえ /建て替え;rebuild.「マンションの-」/建替え/建替/立替;advence.「支払の-」/立て替え/立替え/
たてかえきん /立替金/
たてかた /立て方/建て方;[建築]構造部分の組上げ/建方/
たてかわ /立川/
たてかん /立看/立て看/
たてかんばん /立て看板;学祭の-/立看板/
たてがき /縦書き/
たてがた /縦型/竪型/
たてがみ /鬣;mane/
たてがめん /縦画面/
たてき /建樹/
たてぎょうじ /立行司/
たてぎょく /建玉/
たてぐ /建具/
たてぐみ /縦組/
たてぐや /建具屋/
たてけい /縦系/
たてけいしき /縦形式/
たてこう /立坑/竪坑/
たてこし /館腰/
たてごと /竪琴/
たてさわ /立澤/
たてざ /楯座;Scutum(Sct)/
たてざひょう /縦座標/
たてざん /竪桟/
たてし /殺陣師/
たてしお /立塩/立て塩/
たてしな /蓼科/立科/
たてしなやま /蓼科山/
たてしほうがため /縦四方固め/
たてしゃかい /縦社会;上下関係が重視される社会。中根千枝のターム/
たてしんどう /縦振動/
たてじく /縦軸/
たてじま /縦縞/
たてじょう /楯状/
たてじょうち /楯状地/
たてじょうよう /楯状葉/
たてじわ /縦皺/
たてすくろーる /縦スクロール/
たてすじ /縦筋/
たてずな /立砂/
たてせん /縦線/｜;pipe/│;罫線/
たてだし /点出し/
たてちゃ /点茶/立茶/
たてつけ /立て付け/建付/建て付け/建付け/立付け/建てつけ/
たてつづけ /立て続け/
たてつぼ /建坪/立坪/
たてづめ /立爪/立て爪/
たてどい /縦樋/竪樋;雨樋の水を地面(ドレイン)に流す樋/
たてなおし /建て直し;reconstruction/立て直し;recovery/
たてなが /縦長/
たてなががめん /縦長画面/
たてなみ /縦波/
たてぬき /経緯/
たてね /建値/
たての /立野/舘野/館野/
たてのだい /立野台/
たてはば /縦幅/
たてはら /立原/
たてばい /縦倍/
たてばいかく /縦倍角/
たてばやし /館林/
たてばやしし /館林市/
たてひこ /建彦/
たてひざ /立て膝/
たてふ /縦歩/
たてふだ /立て札/立札/
たてぶえ /縦笛/竪笛/
たてぶんれつ /縦分裂/
たてべ /建部/
たてほうこう /縦方向/
たてほり /縦堀/
たてぼう /縦棒/｜;pipe/│;罫線/
たてまえ /建前/建て前/点前;[茶道]/立て前/立前/
たてまえじょう /建前上/
たてまえろん /建前論/
たてまさ /建正/
たてまし /建て増し/建増し/
たてまち /立町/
たてまつ /立松/
たてむき /縦向き/
たてむすび /縦結び/
たてむら /舘村/
たてめ /縦目/
たてもの /建物/
たてものじたい /建物自体/
たてものちょうさ /建物調査/
たてものない /建物内/
たてものないぶ /建物内部/
たてものふぞくせつび /建物附属設備/
たてもよう /縦模様/
たてや /建屋/建家/
たてやくしゃ /立役者/
たてやない /建屋内/
たてやま /館山/立山/楯山/
たてやまさんろく /立山山麓/
たてやまでらおんせん /舘山寺温泉/
たてやまわん /館山湾/
たてゆれ /縦揺れ/
たてよこ /縦横/
たてよここんざい /縦横混在/
たてよこひ /縦横比/
たてわき /帯刀/
たてわり /縦割り/
たてわりぎょうせい /縦割行政/
たてん /他店/多点/
たで /蓼/
たでか /タデ科/
たでず /蓼酢/
たでもく /タデ目/Polygonales/
たと /田堵/田刀/
たとう /多頭/他党/多投/多党/
たとうかい /多島海/
たとうがみ /畳紙/
たとうすう /多頭数/
たとうせい /多党制/
たとうせいじ /多頭政治/
たとうせきふ /多頭石斧/
たとうたい /多糖体/
たとうるい /多糖類/
たとえ /例え/喩え/譬え/縦/仮令/縦令/
たとえうた /譬え歌/喩え歌/
たとえごと /譬え言/譬え事/
たとえづくし /譬喩尽/
たとえば /例えば/
たとえばなし /例え話/譬え話/
たとへば /例へば/
たとみ /田富/
たど /多度/
たどう /他動/
たどうし /他動詞/
たどうてき /他動的/
たどうろ /他道路/
たどく /多読/
たどころ /田所/
たどつ /多度津/
たどつえき /多度津駅/
たどつこうじょう /多度津工場/
たどん /炭団/
たな /棚/店/
たなあげ /棚上げ/
たなあみ /田名網/
たないけ /種池/
たないた /棚板/
たなうえ /棚上/
たなえ /田苗/
たなおろし /棚卸/棚卸し/店卸/店卸し/
たなおろししさん /棚卸資産;流動資産の1つ/たな卸資産/
たなおろしだか /棚卸高/
たなおろしひょう /棚卸表;inventory sheet/
たなか /田中;姓/田仲;姓/
たなかかくえい /田中角栄;人名/
たなかきぬよ /田中絹代;人名/
たなかぎいち /田中義一/
たなかだて /田中館/
たなき /棚木/
たなくら /棚倉/
たなぐも /棚雲/
たなぐら /棚倉/
たなこ /店子/
たなごおり /棚氷;南極の-/
たなごころ /掌/
たなさき /店前/手先/
たなざらし /店晒し/棚晒し/
たなざわ /棚沢/
たなし /田無/
たなそこ /手底/
たなだ /棚田/
たなちん /店賃/
たなはし /棚橋/
たなばた /七夕/
たなばたさま /七夕様/
たなばたしょう /七夕賞/
たなばただけ /七夕竹/
たなばたまつり /七夕祭り/七夕祭/
たなべ /田辺/田邉/
たなべせいやく /田辺製薬;[企業名]/
たなべはじめ /田辺元/
たなぼた /棚牡丹/棚ぼた/棚ボタ/
たなみ /棚見/
たなもの /店者/
たなわ /手縄/
たなん /多難/
たに /谷/渓/谿/溪/峪/
たにあい /谷間/
たにあし /谷脚/
たにい /谷井/溪井/
たにうち /谷内/
たにえ /谷江/
たにえき /谷駅/
たにおおつか /谷大塚/
たにおか /谷岡/
たにおり /谷折り;⇔山折り/
たにかぜ /谷風/
たにかわ /谷川/
たにかわしゅんたろう /谷川俊太郎/
たにがき /谷垣/
たにがみ /谷上/
たにがわ /谷川/谷側/谿/
たにがわがん /谷川雁;詩人(1923-95)/
たにがわごう /谷川号/
たにがわだけ /谷川岳/
たにがわだけてんじんだいら /谷川岳天神平/
たにく /多肉/
たにくけい /多肉茎/
たにくしょくぶつ /多肉植物;succulent plant. サボテンなど/
たにぐち /谷口/
たにぐみ /谷汲/
たにごえ /谷越え/
たにざき /谷崎/
たにざきじゅんいちろう /谷崎潤一郎/
たにざわ /谷沢/
たにし /田螺/
たにしきんぎょ /田螺金魚/
たにしげ /谷繁/
たにじま /谷島/
たにすじ /谷筋/
たにせ /谷瀬/
たにぞこ /谷底/
たにた /谷田/
たにだ /谷田/
たになか /谷中/
たにの /谷野/
たにはら /谷原/
たにふじ /谷藤/
たにま /谷間/渓間/
たにまち /谷町/
たにまちきゅうちょうめ /谷町九丁目/
たにまちせん /谷町線/
たにみず /谷水/
たにむら /谷村/
たにむらしんじ /谷村新司/
たにむらゆみ /谷村有美/
たにもと /谷本/
たにやま /谷山/
たにゅうりょく /多入力/
たにょう /多尿;[医]-症/
たにわき /谷脇/
たにん /他人/
たにんぎょうぎ /他人行儀/
たにんごと /他人事/
たにんさま /他人様/
たにんしほん /他人資本;負債/
たにんずう /多人数/
たにんずうどうじ /多人数同時/
たにんずうよう /多人数用/
たにんどうし /他人同士/
たにんどん /他人丼/
たにんどんぶり /他人丼/
たにんまかせ /他人任せ/
たにんめいぎ /他人名義/
たぬき /狸/貍/田貫/
たぬきうどん /狸饂飩/
たぬきおしょう /狸和尚/
たぬきおやじ /狸親父/
たぬきこうじ /狸小路/
たぬきざか /狸坂/
たぬきじる /狸汁/
たぬきそば /狸蕎麦/
たぬきねいり /狸寝入り/
たぬきばばあ /狸婆/
たぬきばやし /狸囃子;ぽんぽこぽんのぽん♪/
たぬし /田主/
たぬま /田沼/
たぬまおきつぐ /田沼意次/
たぬまじだい /田沼時代;1767-86/
たね /種/胤;血統(を伝える子)/種子/多根/
たねあかし /種明かし/種明し/
たねあき /種明/
たねあぶら /種油/
たねい /種井/
たねいた /種板/
たねいち /種市/
たねいも /種芋/
たねうし /種牛/
たねうま /種馬/
たねおみ /種臣/
たねかわ /種川/
たねがしま /種子島/
たねぎれ /種切れ/
たねごえ /種肥/
たねせん /種銭/
たねだ /種田/
たねださんとうか /種田山頭火/
たねつけ /種付け/
たねつけりょう /種付料/
たねとし /種敏/
たねとり /種取り/
たねなし /種無し;-ブドウ/
たねばん /種板/
たねび /種火/
たねほん /種本/
たねまき /種蒔き/種播き/種まき/
たねむら /種村/
たねもの /種物/
たねもみ /種籾/
たねん /多年/他年/他念/
たねんせい /多年生/
たねんせいそうほん /多年生草本/
たねんそう /多年草/
たの /他の/田野/多野/
たのう /多能/
たのうえ /田上/
たのうら /田浦/
たのかみ /田の神/
たのしさ /楽しさ/愉しさ/
たのしみ /楽しみ/愉しみ/
たのしみかた /楽しみ方/
たのなか /田野中/
たのはた /田野畑/
たのみごと /頼み事/
たのみのつな /頼みの綱/
たのもし /頼母子/頼もし/
たのもしこう /頼母子講/
たはた /田畑/
たはつ /多発/
たはつせい /多発性/
たはら /田原/
たば /束/他馬/田場/
たばい /多売/
たばいちょう /多倍長/
たばいちょうえんざん /多倍長演算/
たばいと /多バイト/
たばこ /煙草/莨/
たばこせん /煙草銭/
たばこぜい /たばこ税/
たばこぼん /煙草盆/
たばこや /煙草屋/
たばた /田畑/田端/太幡/
たばたかん /田端間/
たばつてき /他罰的/
たばね /束ね/
たばねがみ /束ね髪/
たばねばしら /束ね柱;[建築]cluster column/
たばやま /丹波山/
たばら /田原/
たばる /田原/
たばるざか /田原坂/
たひら /田平/
たひんしゅ /多品種/
たひんど /多頻度/
たび /度/旅/足袋/
たびかせぎ /旅稼ぎ/
たびがらす /旅烏/旅鴉/
たびげいにん /旅芸人/
たびこうぎょう /旅興行/
たびごころ /旅心/
たびごろも /旅衣/
たびさき /旅先/
たびじ /旅路/
たびじたく /旅支度/
たびすがた /旅姿/
たびそう /旅僧/
たびたび /度々/度度/
たびだち /旅立ち/
たびづかれ /旅疲れ/
たびどり /旅鳥/
たびのそら /旅の空/
たびびと /旅人/
たびまわり /旅回り/
たびょう /多病/
たびょういん /他病院/
たびら /田平/
たびらこ /田平子/
たふ /多夫;一妻-,-多妻/佗負/
たふけん /他府県/
たぶ /他部/椨/
たぶーし /タブー視/
たぶきょく /他部局/
たぶさ /髻/
たぶしょ /他部署/他部所/
たぶせ /田布施/
たぶち /田渕/田淵/
たぶつ /他物/
たぶね /田舟/
たぶのき /椨/
たぶふ /タブ譜/
たぶぶん /他部分/
たぶもん /他部門/
たぶろいどし /タブロイド紙/
たぶろいどばん /タブロイド判;普通の新聞の半分のサイズ/
たぶん /多分/多聞;†「博学-」/他聞;†「-を憚る」/
たぶん> /多分;-俺,-大丈夫,-OK/
たぶんか /多文化;†multiple cultures.「-の共存」/他文化;†other cultures.「-の尊重」/
たぶんかい /多分解/
たぶんかしゅぎ /多文化主義;multiculturalism/
たぶんぎ /多分木/
たぶんだいじょうぶ /多分大丈夫/
たぶんむり /多分無理/
たぶんや /他分野/多分野/
たぶんわたし /多分私/
たへんけい /多辺形/
たへんすう /多変数/
たへんすうかいせき /多変数解析/
たへんすうかんすう /多変数関数/
たへんりょう /多変量/
たへんりょうかいせき /多変量解析/
たべ /田部/多辺/
たべあるき /食べ歩き/
たべあわせ /食べ合わせ;鰻と梅干しは-が悪い/食べ合せ/
たべおさめ /食べ納め/
たべかた /食べ方/
たべごたえ /食べ応え/
たべごろ /食べ頃/
たべざかり /食べ盛り/
たべすぎ /食べ過ぎ/
たべずぎらい /食べず嫌い/
たべで /食べ出;ボリューム/
たべのこし /食べ残し/
たべほうだい /食べ放題/
たべもの /食べ物/食物/
たべものや /食べ物屋/
たべん /多弁/
たほう /他方/多方/多峰/
たほうせい /多峰性;⇔単峰性/
たほうとう /多宝塔/
たほうにょらい /多宝如来/
たほうめん /多方面/
たぼ /髱/
たぼう /多忙/多望/
たぼうちゅう /多忙中/
たま /玉/球;野球の-/弾;銃の-/多摩/珠;掌中の-,算盤の-/霊;御霊/偶;sometimes.「-の休み」/適;≒偶/珪;天子の与える三角形のたま/田万/彈;「弾」の旧字(人名用漢字)/靈;「霊」の旧字/
たまい /玉井/
たまいし /玉石/
たまいれ /玉入れ/
たまえ /玉江/玉恵/
たまお /玉緒/
たまおき /玉置/
たまかがみ /玉鏡/
たまかけ /玉掛/玉掛け/
たまかし /玉柏/
たまかしき /玉貸機/
たまかず /玉数/
たまかずら /玉鬘/
たまかわ /玉川/
たまがき /玉垣/
たまがわ /玉川/多摩川/田万川/
たまがわえん /多摩川園/
たまがわがくえん /玉川学園/
たまがわきょうりょう /多摩川橋梁/
たまがわぐち /玉川口/
たまがわさきこ /玉川紗己子;人名/
たまがわじょうすい /玉川上水/
たまがわせいがくいん /玉川聖学院/
たまがわせん /多摩川線/玉川線/
たまがわだい /玉川大/
たまがわだいがく /玉川大学/
たまがわてっきょう /多摩川鉄橋/
たまき /環/玉木/玉置/玉城/
たまきず /弾傷/
たまきゅうりょう /多摩丘陵/
たまぎぬ /玉衣/
たまぎれ /弾切れ/
たまく /多摩区/
たまくしげ /玉櫛笥/
たまぐしりょう /玉串料/
たまぐすく /玉城/
たまこ /多摩湖/
たまこし /玉越/
たまご /卵/玉子;(食材)/
たまごいろ /卵色/
たまごがた /卵形/卵型/
たまごがら /卵殻/
たまごごはん /卵ご飯/
たまござけ /卵酒/玉子酒/
たまごとじ /卵とじ/卵綴じ/玉子綴じ/
たまごどうふ /卵豆腐/玉子豆腐/
たまごどん /玉子丼/卵丼/
たまごどんぶり /玉子丼/卵丼/
たまごはだ /卵肌;つやつやの-/
たまごまき /卵巻/卵巻き/玉子巻/玉子巻き/
たまごやき /卵焼き/卵焼/
たまごりょうり /卵料理/
たまごるい /卵類/
たまごろも /玉衣/
たまさか /偶さか/適さか/
たまさきじんじゃ /玉前神社/
たまさと /玉里/
たまさぶろう /玉三郎/
たまし /多摩市/
たましい /魂/魄;†(字義:「魂」は精神、「魄」は肉体を司るたましい)/
たましま /玉島/
たまじゃり /玉砂利/
たますじ /球筋/玉筋/
たますだれ /玉簾/
たまずさ /玉梓/
たません /多摩線/
たまたいしょう /玉大賞/
たまたま /偶/偶々/適/
たまだ /玉田/
たまだい /多摩大/
たまち /田町/
たまちいき /多摩地域/
たまちえき /田町駅/
たまちえきひがしぐち /田町駅東口/
たまちく /多摩地区/
たまちでんしゃく /田町電車区/
たまつき /玉突き/玉突/玉撞き/球撞き/
たまつきじこ /玉突き事故/
たまつきてき /玉突的/
たまつくり /玉造/玉作/玉造り/
たまつくりぐん /玉造郡/
たまつくりべ /玉作部/玉造部/
たまつしま /玉津島;地名,和歌山/
たまつしまじんじゃ /玉津島神社/
たまつつみ /玉堤/
たまつばき /玉椿/
たまづつみ /玉堤/
たまてばこ /玉手箱/
たまで /玉手/
たまど /玉戸/
たまな /玉名/
たまなわ /玉縄/玉那覇/
たまに /偶に/
たまにきず /玉に瑕/
たまねぎ /玉葱/玉ねぎ/玉ネギ/
たまの /玉野/
たまのあせ /玉の汗/
たまのい /玉井/
たまのうてな /玉の台;華麗な御殿/
たまのうら /玉之浦/
たまのお /玉の緒/
たまのおぐし /玉の小櫛;『源氏物語-』源氏の注釈書。本居宣長/
たまのこし /玉の輿/
たまのし /玉野市/
たまのり /玉乗り;サーカス/
たまはがね /玉鋼/
たまはし /玉橋/
たまはら /玉原/
たまばはき /玉箒/
たまひめ /玉姫/
たまひめさま /玉姫様/
たまひろい /球拾い/
たまぶくろ /玉袋;[卑]/
たまぶさ /玉総/
たまぶち /玉縁/
たまほ /玉穂/
たまほり /玉堀/
たままき /玉牧/
たままつり /魂祭/霊祭/
たままゆ /玉繭/
たまみ /珠美/
たまみず /玉水/
たまみそ /玉味噌/
たまむし /玉虫/
たまむしいろ /玉虫色/
たまむら /玉村/
たまもと /玉本/
たまもの /賜物/賜/賚/
たまものまえ /玉藻前/
たまや /玉屋/
たまやま /玉山/
たまゆ /玉湯/
たまゆら /玉響/
たまよ /たま代/多満代/
たまよけ /弾除け/
たまらない /堪らない/
たまり /溜/澑;異体字/玉里/玉利/
たまりじょうゆ /溜まり醤油;たまり/
たまりば /溜まり場/たまり場/溜り場/
たまる /田丸/
たまれいえん /多磨霊園/
たみ /民/多美/
たみあき /民朗/
たみえ /民江/
たみお /民生/民夫/民雄/民男/
たみおか /民岡/
たみき /民喜/
たみくさ /民草/
たみこ /たみ子/
たみのつかさ /民部省;[律令制]三省/
たみや /田宮/
たみやじろう /田宮二郎/
たみるご /タミル語;インド・シンガポールの公用語の一つ/
たみんぞく /多民族/他民族/
たむけ /手向け/
たむし /田虫/
たむら /田村/田邑/党/屯/
たむろ /屯/
たむろじょ /屯所/
ため /為/溜め/溜/澑;異体字/爲;「為」の旧字(人名用漢字)/
ためいき /溜息/溜め息/ため息/
ためいけ /溜池/ため池/溜め池/
ためいけえき /溜池駅/
ためいけかん /溜池間/
ためいけこうさてん /溜池交差点/
ためうち /溜め撃ち/
ためがき /為書/為書き/
ためきよ /為清/
ためぐち /タメ口/
ためし /試し;try.「-にやってみる」/例;example.「上手くいった-がない」/様;=例/樣;「様」の旧字(人名用漢字)/
ためしぎり /試し斬り/
ためしげ /爲成;「為」旧字/
ためしざん /試し算/
ためつすがめつ /矯めつ眇めつ/
ためなが /為永/
ために /為に/
ためひろ /為広/
ためらい /躊躇い/
ためらいきず /躊躇い傷/
ためん /他面;the other side/多面;「-体」/
ためんせい /多面性/
ためんたい /多面体/
ためんてき /多面的/
たも /玉網/
たもうさく /多毛作/
たもうしょう /多毛症/
たもうるい /多毛類/
たもがわ /田茂川/
たもくてき /多目的/
たもくてきしつ /多目的室/
たもくてきほーる /多目的ホール/
たもつ /保/
たもと /袂/田本/
たもり /田守/田森/
たもろこ /田諸子/
たもん /多聞/他門/大紋;人名/
たもんてん /多聞天/
たや /田屋/田谷/多屋/
たやす /田安/
たやま /田山/
たやまかたい /田山花袋/
たゆ /斬/
たゆう /太夫/大夫/大輔/
たゆうこ /太夫子/
たよう /多様;various.「多種-」/多用;heavy use.「俗語を-する」/他用;他の用事。/
たようか /多様化/
たようがた /多様型/
たようせい /多様性/多用性/
たようたい /多様体/
たよく /多欲/
たより /便り/
たよりがい /頼り甲斐/
たら /鱈/太良;地名/鰔;たら,かれい,うぐい/膤;(国字) =鱈/大口魚/
たらい /盥/
たらいまわし /盥回し/
たらぎ /多良木/
たらこ /鱈子/
たらじる /鱈汁/
たらず /足らず/
たらちね /垂乳根;-の母/
たらばがに /鱈場蟹;ヤドカリの一種。実は蟹ではない。/多羅波蟹;=鱈場蟹/
たらふく /鱈腹;当て字/
たらま /多良間/
たらみ /多良見/
たらみちょう /多良見町/
たり /足り/
たりうむ /Tl/Thalium/
たりかつよう /タリ活用;形容動詞の活用形態/
たりき /他力/
たりきほんがん /他力本願/
たりきほんがんじ /他力本願寺/
たりきほんがんてき /他力本願的/
たりつ /他律/
たりつてき /他律的/
たりゅう /他流/
たりゅうし /多粒子/
たりゅうじあい /他流試合/
たりゅうど /多粒度/
たりょう /多量/
たりょういき /他領域/
たりんか /多輪花/
たる /樽/垂/
たるい /垂井/樽井/
たるがた /樽型/
たるき /垂木;[建築]/椽/榱/樽木;姓/架/
たるざかな /樽魚/
たるざけ /樽酒/
たるだい /樽代/
たるとがた /タルト型/
たるなま /樽生/
たるひ /垂氷/
たるほ /足穂/
たるみ /垂水/弛み/
たるみく /垂水区/
たるみず /垂水/
たるみずえき /垂水駅/
たるみずし /垂水市/
たれ /垂れ/誰/
たれいしき /他励式/
たれかべ /垂れ壁;[建築]部屋の上部のみを区切る壁。(LDKのリビングとキッチンの間など)/
たれがし /誰某/
たれがみ /垂れ髪/
たれぎぬ /垂れ絹/
たれこみ /垂れ込み/
たれつ /多列/
たれつき /タレ付き/
たれながし /垂れ流し/
たれまく /垂れ幕/垂幕/
たれみず /垂水/
たれみみ /垂れ耳;-の犬/
たれめ /垂れ目/タレ目/たれ目/
たれんそう /多連装/
たろいも /タロ芋;里芋など/
たろう /太郎/太朗/田老/太良/多郎/
たろうかじゃ /太郎冠者/
たろうまる /太郎丸/
たろせん /他路線/
たわ /撓/嵶/
たわい /他愛/
たわけ /戯け/田分け/白痴;当て字/
たわけもの /戯け者/たわけ者/
たわごと /戯言/
たわし /束子/
たわだいら /多和平/
たわぶれうた /戯れ歌/
たわみ /撓み/
たわむれ /戯れ/戯/
たわむれがき /戯れ書き/
たわむれごと /戯れ言/戯れ事/
たわら /俵/田原/太原/
たわらまち /俵万智;歌人/
たわらやそうたつ /俵屋宗達/
たわれうた /戯れ歌/
たわわ /撓わ/
たん /単/端/痰/反/嘆/歎;≒嘆/短/炭/淡/丹/探/堪;堪能/湛;たた・える/湍;湍流(≒急流)/猯;まみ/鍛;鍛錬/椴;とどまつ/緞;絨緞/毯;絨毯/啖;健啖/啗;「啖」の異体字/餤;くらう/壇;花壇/檀;檀家/亶/慱/摶/槫/耽;耽美/眈;虎視眈々/酖;(酒に)ふける/潭;ふち/覃;ふかい/譚;綺譚/但;ただ・し/坦;平坦/担;担当/擔;「担」の旧字/旦;元旦/疸;黄疸/袒/靼;韃靼/胆;きも/膽;「胆」の旧字/憺;惨憺/澹;暗澹/箪;瓢箪/單;「単」の旧字(人名用漢字)/憚;忌憚/殫/襌;ひとえ/褝;「襌」の異体字/鄲;邯鄲/誕;誕生/綻;破綻/蛋;蛋白質/攤/站;兵站/貪;(漢音)/賺;すか・す/彖/
たん# /単#0;-電池/
たん#でんち /単#0電池/
たん> /短/単;単年度,単結晶,単3(電池)/淡/
たんあつ /鍛圧;forge rolling/
たんあな /単穴/
たんい /単位/単為;-生殖/短衣/單位;旧字/
たんい> /単位/
たんいえん /単位円/
たんいえんばん /単位円板/
たんいかぶ /単位株/
たんいかぶせいど /単位株制度/
たんいかんきょう /単位環境/
たんいきゅう /単位球/
たんいぎょうれつ /単位行列/
たんいけい /単位系/
たんいげん /単位元/
たんいこうし /単位格子/
たんいしつりょう /単位質量/
たんいしゅうとく /単位修得/
たんいしゅとく /単位取得/
たんいしゅとくたいがく /単位取得退学/
たんいじかん /単位時間/
たんいじかんない /単位時間内/
たんいじげん /単位次元/
たんいすう /単位数/
たんいせい /単位制;-高校/
たんいせいこうこう /単位制高校/
たんいせいしょく /単為生殖/
たんいせつ /単位節/
たんいたいせき /単位体積/
たんいち /単一;D/
たんいちかんでんち /単一乾電池/
たんいちでんち /単一電池/
たんいちょう /単位長/
たんいつ /単一/
たんいつおうしゅうぎていしょ /単一欧州議定書/
たんいつか /単一化/
たんいつけいしょう /単一継承/
たんいつさいぼう /単一細胞/
たんいつたい /単一体/
たんいつみんぞく /単一民族/
たんいでんち /単位電池/
たんいにんてい /単位認定/
たんいふ /単位符/
たんいふごう /単位符号/
たんいべくとる /単位ベクトル/
たんいめんせき /単位面積/
たんいようりょう /単位容量/
たんいりったいかく /単位立体角/
たんいりょう /単位量/
たんいん /探韻/貪淫/貪婬;=貪淫/
たんえ /丹絵/
たんおうしょく /淡黄色/
たんおん /単音/短音/
たんおんかい /短音階/
たんおんがく /単音楽/
たんおんせつ /単音節/
たんか /単価/短歌/炭化/担架/啖呵/丹花/丹霞/譚歌/単果/單價/
たんかい /坦懐/
たんかか /単花果/
たんかく /短角/
たんかくそうしょ /丹鶴叢書/
たんかすいそ /炭化水素/
たんかだいがく /単科大学/
たんかっしょく /淡褐色/
たんかひ /単花被/
たんかひるい /Monochlamydeae/
たんかぶつ /炭化物/
たんかん /短観/胆管/単館/単管/単漢/
たんかんきょう /単環境/
たんかんじ /単漢字/
たんかんじじしょ /単漢字辞書/
たんかんじへんかん /単漢字変換/
たんかんじょうえい /単館上映/
たんがら /炭殻/
たんがん /嘆願/単眼/単願/歎願/
たんがんきょう /単眼鏡/
たんがんし /単眼視/
たんがんしょ /嘆願書/
たんがんてき /単眼的/
たんき /短期/短気/単騎/単機/単記/
たんき> /短期;-国債,-売買,-バイト/
たんきかしつけきん /短期貸付金/
たんきかりいれきん /短期借入金/
たんきかん /短期間/
たんきかんじゅう /短機関銃/
たんききおく /短期記憶/
たんききんり /短期金利/
たんきぎょう /単企業/
たんきけっせん /短期決戦/
たんきこくさい /短期国債/
たんきしゅ /単機種/
たんきしゅうちゅう /短期集中/
たんきしゅうちゅうがた /短期集中型/
たんきしゅうちゅうこうざ /短期集中講座/
たんきしゅうちゅうれんさい /短期集中連載/
たんきじこう /短期時効/
たんきせいけん /短期政権/
たんきたいざい /短期滞在/
たんきだいがく /短期大学/
たんきだいがくせい /短期大学生/
たんきだいがくぶ /短期大学部/
たんきてき /短期的/
たんきとう /単気筒/
たんきのう /単機能/
たんきばいばい /短期売買/
たんきゃく /単脚/
たんきゅう /探求;†(search)探し求める。「幸福の-」/探究;†(research)探り出し見極める。「真理の-」/単球/
たんきゅうしゃ /探求者;†/探究者;†/
たんきゅうしん /探究心;†/探求心;†/
たんきょく /単極/端局/
たんきょり /短距離/
たんきょりきょうそう /短距離競走;[陸上]50~400m/
たんきょりけっとう /短距離血統/
たんきょりせんもん /短距離専門/
たんきょりそう /短距離走/
たんきょりそうしゃ /短距離走者/
たんきょりば /短距離馬/
たんきょりらんなー /短距離ランナー/
たんきょりろせん /短距離路線/
たんきよ /たん清/
たんきよほう /短期予報/
たんきれんさい /短期連載/
たんきん /鍛金/単金/
たんぎょく /単玉/
たんぎん /断金/
たんく /短躯/短句/
たんくかん /短区間/
たんぐすてん /W/Tungsten/
たんぐすてんこう /タングステン鋼;tungsten steel/
たんぐつ /短靴/
たんけい /短径/短形/
たんけっしょう /単結晶/
たんけつごう /単結合/
たんけん /探検/探険;=探検/短剣/短見/
たんけんか /探検家/
たんけんたい /探検隊/探険隊;=探検隊/
たんけんちゅう /探検中/
たんけんてき /探検的/
たんけんふ /†/‡/短剣符/
たんけんぶ /探検部/
たんげ /丹下/
たんげい /端倪/
たんげさぜん /丹下左膳/
たんげん /単元/端厳/
たんげんしぶんし /単原子分子/
たんこう /炭鉱/炭坑/単孔/淡紅/淡黄/探鉱/単鉤/鍛工/単項/湛江/鍛鋼/単行/短光/炭鑛/単溝/単向/
たんこうえんざん /単項演算/
たんこうえんざんし /単項演算子/
たんこうがた /単溝型/
たんこうしき /単項式/
たんこうしょく /淡黄色/
たんこうてつどう /炭坑鉄道/
たんこうのうりょく /堪航能力/
たんこうぶし /炭坑節/
たんこうほんみしゅうろく /単行本未収録/
たんこうぼん /単行本/
たんこうぼんか /単行本化/
たんこうぼんみしゅうろく /単行本未収録/
たんこうるい /単孔類/
たんこうろうどうしゃ /炭鉱労働者/
たんこぶ /たん瘤/
たんころ /単コロ/
たんこん /単婚;monogamy. ⇔複婚,重婚/
たんこんたい /担根体/
たんご /単語/丹後/端午/
たんごおんせい /単語音声/
たんごおんせいにんしき /単語音声認識/
たんごかん /単語間/
たんごしゅう /単語集/
たんごすう /単語数/
たんごぜんたい /単語全体/
たんごたんい /単語単位/
たんごちょう /単語帳/
たんごとうろく /単語登録/
たんごない /単語内/
たんごにんしき /単語認識/
たんごのせっく /端午の節句;五月五日の背比べ/
たんごはんとう /丹後半島/
たんごひょう /単語表/
たんごへんかん /単語変換/
たんごりょく /単語力/
たんごん /端厳/
たんさ /探査/丹砂/
たんさい /淡彩;tint colour/単彩;monochrome/短才/
たんさいが /淡彩画/
たんさいぼう /単細胞/
たんさいぼうせいぶつ /単細胞生物/
たんさいぼうてき /単細胞的/
たんさき /探査機/
たんさく /探索/単作/探策/
たんさくきのう /探索機能/
たんさくぎ /探索木/
たんさくくうかん /探索空間/
たんさくけいろ /探索経路/
たんさくこうりつ /探索効率/
たんさくしゃ /探索者/
たんさくせんりゃく /探索戦略/
たんさくてき /探索的/
たんさくはんい /探索範囲/
たんさくほう /探索法/
たんさくほうこう /探索方向/
たんさくほうほう /探索方法/
たんさせん /探査船/
たんさわこ /丹沢湖/
たんさん /炭酸/単産/単三;AA/
たんさんあんこてい /炭酸暗固定/
たんさんいり /炭酸入/
たんさんいんりょう /炭酸飲料/
たんさんえん /炭酸塩/
たんさんかり /炭酸カリ/
たんさんかんでんち /単三乾電池/
たんさんがす /炭酸ガス;CO2/
たんさんすい /炭酸水/
たんさんせん /炭酸泉/
たんさんでんち /単三電池/
たんさんどうかさよう /炭酸同化作用/
たんさんわり /炭酸割り/
たんざ /単座;single-seat.「-戦闘機」/端座;きちんと座る/端坐;=端座/単坐;<rare> =単座/
たんざがた /単座型/
たんざき /単座機/
たんざく /短冊/
たんざくがた /短冊形/短冊型/
たんざくぎり /短冊切り;大根の-/
たんざわ /丹沢/
たんざん /湛山/
たんし /端子/短詩;versicle/譚詩;ballade/短資/淡紫/単糸;monomene/単子;monad/短枝/箪食;お弁当/
たんしお /タン塩/
たんしかん /端子間/
たんしかんでんあつ /端子間電圧/
たんしき /単式/
たんしきょく /譚詩曲/
たんしきん /担子菌/
たんしきんるい /担子菌類;松茸,椎茸,シメジetc/
たんしこしょう /箪食壺漿;民衆による軍隊の歓待/箪食壷漿;「壺」異体字/箪食瓠漿;?/
たんししゅつりょく /端子出力/
たんししょく /淡紫色/
たんしすう /端子数/
たんしせつぞく /端子接続/
たんしだい /端子台/
たんしつ /炭質/
たんしでんあつ /端子電圧/
たんしばん /単篩板/
たんしゃ /単車/単射/単写/丹砂/
たんしゃしょうけい /単斜晶系;[化学]monoclinic system/
たんしゃてき /単射的/
たんしゃれき /単車歴/
たんしゅう /丹州;丹波and／or丹後/但州;但馬/淡州;淡路/端舟;boat/騨州;飛騨/
たんしゅく /短縮/
たんしゅくか /短縮化/
たんしゅくけい /短縮形/短縮茎/
たんしゅくこうか /短縮効果/
たんしゅくじかん /短縮時間/
たんしゅくばん /短縮版/
たんしゅくりつ /短縮率/
たんしゅん /探春/
たんしょ /短所/端緒/探書/端書/
たんしょう /単勝/探勝/短小/短章/
たんしょうしき /単勝式/
たんしょうしじりつ /単勝支持率/
たんしょうてん /単焦点/
たんしょうとう /探照灯;searchlight/探照燈;異体字/
たんしょうはいとう /単勝配当/
たんしょうはんだん /単称判断/
たんしょうまんばけん /単勝万馬券/
たんしょく /単色/淡色/貪食/
たんしょくこう /単色光/
たんしょくし /探触子/
たんしょくやさい /淡色野菜/
たんしよう /単子葉/
たんしようしょくぶつ /単子葉植物/
たんしようしょくぶつこう /単子葉植物綱/Monocotyledoneae/
たんしようるい /単子葉類/
たんしろん /単子論/
たんしん /短信/単身/短針/探針;probe/
たんしんし /単振子/
たんしんしゃ /単身者/
たんしんどう /単振動/
たんしんふにん /単身赴任/
たんしんふにんしゃ /単身赴任者/
たんしんふにんちゅう /単身赴任中/
たんじ /丹治/単耳/
たんじかん /短時間/
たんじかんろこう /短時間露光/
たんじき /単時期/
たんじきょく /単磁極/
たんじく /単軸;single axis.「-結晶」/短軸;short axis. ⇔長軸/
たんじくけっしょう /単軸結晶/
たんじくじょう /単軸状/
たんじじつ /短時日/
たんじつ /短日/
たんじつげつ /短日月/
たんじつしょくぶつ /短日植物;short-day plant/
たんじつしょり /短日処理/
たんじゃく /短尺/
たんじゅう /胆汁/短銃/
たんじゅうさん /胆汁酸/
たんじゅうしつ /胆汁質/
たんじゅみょう /短寿命/
たんじゅん /単純/単順;[競馬]/
たんじゅんおうふく /単純往復/
たんじゅんおん /単純音/
たんじゅんか /単純化/
たんじゅんかこ /単純過去/
たんじゅんけい /単純系/
たんじゅんけいさん /単純計算/
たんじゅんこう /単純項/
たんじゅんご /単純語;⇔複合語/
たんじゅんさぎょう /単純作業/
たんじゅんししつ /単純脂質/
たんじゅんしじ /単純支持/
たんじゅんしょうにん /単純承認/
たんじゅんじせい /単純時制/
たんじゅんせい /単純性/
たんじゅんせん /単純泉/
たんじゅんどうさ /単純動作/
たんじゅんばり /単純梁;[建築]/
たんじゅんぶん /単純文/
たんじゅんへいきん /単純平均/
たんじゅんみす /単純ミス/
たんじゅんみらい /単純未来/
たんじゅんめいかい /単純明快/
たんじゅんろうどう /単純労働/
たんじゅんろん /単純論/
たんじょう /誕生/
たんじょういわい /誕生祝い/誕生祝/
たんじょうかい /誕生会/
たんじょうきねん /誕生記念/
たんじょうけん /端条件/
たんじょうご /誕生後/
たんじょうじ /誕生時/
たんじょうせき /誕生石/
たんじょうちょくご /誕生直後/
たんじょうつき /誕生月/
たんじょうねん /誕生年/
たんじょうび /誕生日/
たんじょうびきねん /誕生日記念/
たんじん /炭塵/
たんす /箪笥/
たんすい /淡水/
たんすいか /淡水化/
たんすいかぶつ /炭水化物/
たんすいぎょ /淡水魚/
たんすいこ /淡水湖/
たんすいしゃ /炭水車;tender/
たんすいせい /淡水性/
たんすいちゅう /淡水中/
たんすいろ /短水路/
たんすう /単数/
たんすうぐん /単数群/
たんすうけい /単数形/
たんすうふくすう /単数複数/
たんすちょきん /箪笥貯金/
たんすよきん /箪笥預金/タンス預金/
たんせい /丹精/端正;neat.「-な文字」/端整;handsome.「-な顔立ち」/丹青;red and blue/淡青;ice blue/嘆声/単性;unisexual/単声;[音楽] monophony/
たんせいか /単性花/
たんせいせいしょく /単性生殖;[生物]⇔両性生殖/
たんせいど /単精度/
たんせいぶおんがく /単声部音楽/
たんせいろん /単性論;Monophysitism/
たんせき /胆石/旦夕/痰咳/嘆惜/
たんせきしょう /胆石症;[医]/
たんせつ /鍛接/
たんせん /単線/段銭/
たんせんうんてん /単線運転/
たんせんか /単線化/
たんせんくかん /単線区間/
たんせんこう /単穿孔/単せん孔/
たんせんりつ /単旋律/
たんぜい /担税/
たんぜいりょく /担税力/
たんぜん /丹前/端然;neatly/淡然;dryly/
たんそ /炭素;C/炭疽;anthrax.「-菌」/歎訴/嘆訴;=歎訴/Carbon/C;炭素の原子記号/
たんそう /単相;†single-phase.「-モーター」/単層;†single-layer.「-膜」/炭層;coalbed/単走/担送/単奏/
たんそうがた /単相型/
たんそうこうりゅう /単相交流/
たんそうさんせんしき /単相三線式/
たんそかん /炭素間/
たんそきん /炭疽菌/
たんそく /嘆息/短足/歎息/探測/
たんそこう /炭素鋼/
たんそさ /炭素鎖/
たんそじゅんかん /炭素循環/
たんそせんい /炭素繊維/
たんそぜい /炭素税/
たんそどうかさよう /炭素同化作用/
たんそびょう /炭疽病;炭疽菌の起こす病気/
たんそぼう /炭素棒/
たんぞう /鍛造/胆臓/
たんたい /単体/担体/
たんたいかかく /単体価格/
たんたいてすと /単体テスト/
たんたいどうさ /単体動作/
たんたいはんばい /単体販売/
たんたいろしゅつけい /単体露出計/
たんたかばし /反高橋/
たんたる /Ta/Tantalum/
たんたん /淡々/淡淡/眈々;虎視-/眈眈/湛々;水の満ちた様子/坦々;平坦な様子/
たんたんめん /担々麺/担担麺/
たんだ /単打/短打/
たんだい /短大/探題/
たんだいせい /短大生/
たんだいそつ /短大卒/
たんだすう /単打数/
たんち /探知/丹治/
たんちき /探知機/探知器/
たんちゃめぶし /谷茶前節;[民謡]沖縄./
たんちょ /端緒;=たんしょ/単著/
たんちょう /単調/短調;[音楽]minor/探鳥/丹頂/単頂/
たんちょうかじょ /単頂花序/
たんちょうげんしょう /単調減少/
たんちょうこう /単調項/
たんちょうせい /単調性/
たんちょうぞうか /単調増加/
たんちょうづる /丹頂鶴/
たんつば /痰唾/
たんつぼ /痰壷/痰壺/
たんづつ /短筒;短銃/
たんてい /探偵/端艇/短艇/単蹄/
たんていえいが /探偵映画/
たんていぎょう /探偵業/
たんていしつ /探偵室/
たんていしゃ /探偵社/
たんていしょうせつ /探偵小説/
たんていじむしょ /探偵事務所/
たんていだん /探偵団/
たんていちょう /探偵帖/
たんていもの /探偵物/
たんていやく /探偵役/
たんてき /端的/胆摘/
たんてつ /鍛鉄/
たんてん /端点/
たんでき /耽溺/
たんでん /丹田;ヘソの下/炭田/
たんでんか /単電荷/
たんとう /担当/短刀/但東/丹東/単刀;―直入/探湯;くかたち/
たんとうい /担当医/
たんとういし /担当医師/
たんとういん /担当員/
たんとううけつけ /担当受付/
たんとうか /担当課/
たんとうかかりかん /担当係官/
たんとうかしょ /担当箇所/
たんとうかもく /担当科目/
たんとうかん /担当官/
たんとうかんじ /担当幹事/
たんとうかんりにん /担当管理人/
たんとうがい /担当外/
たんとうがかりめい /担当係名/
たんとうけんさつかん /担当検察官/
たんとうこうし /担当講師/
たんとうしゃ /担当者/
たんとうしゃこじん /担当者個人/
たんとうしゃしめい /担当者氏名/
たんとうしょう /担当相/
たんとうしょく /担当職/
たんとうじむ /担当事務/
たんとうちゅう /担当中/
たんとうちょくにゅう /単刀直入/
たんとうのうりょく /担当能力/
たんとうはんい /担当範囲/
たんとうび /担当日/
たんとうぶきょく /担当部局/
たんとうぶぶん /担当部分/
たんとうぶん /担当分/
たんとうぶんや /担当分野/
たんとうへんしゅう /担当編集/
たんとうへんしゅういいん /担当編集委員/
たんとうへんしゅうしゃ /担当編集者/
たんとうまどぐち /担当窓口/
たんとうるい /単糖類/
たんとうろんぶん /担当論文/
たんどう /胆道/
たんどうがん /胆道癌/
たんどく /単独/丹毒/耽読/單獨;旧字/
たんどくかいそん /単独海損/
たんどくけっさん /単独決算/
たんどくこう /単独行/
たんどくこうい /単独行為/
たんどくこうえん /単独公演/
たんどくこうどう /単独行動/
たんどくこうわ /単独講和/
たんどくしめい /単独指名/
たんどくしゅい /単独首位/
たんどくしゅぎ /単独主義/
たんどくじこ /単独事故/
たんどくせいけん /単独政権/
たんどくせいはん /単独正犯/
たんどくそうこう /単独走行/
たんどくそくい /単独測位/
たんどくはん /単独犯/
たんどくはんばい /単独販売/
たんどくらいにち /単独来日/
たんな /丹那/
たんなる /単なる/
たんなん /丹南/
たんに /単に/歎異/単二;―電池(C)/
たんにしょう /歎異抄/
たんにゅうかん /単乳管/
たんにん /担任/
たんにんさん /タンニン酸/
たんにんしゃ /担任者/
たんねん /丹念/単年/端然/
たんねんど /単年度/
たんねんどしゅぎ /単年度主義/
たんの /丹野/端野/
たんのう /堪能/胆嚢/単能/端脳;telencephalon/
たんのうえん /胆嚢炎;[医]/
たんのうしゃ /堪能者/
たんのはら /旦野原/
たんはちょう /短波長/
たんはんげんき /短半減期/
たんば /丹波/丹羽/
たんばい /単売/
たんばいち /丹波市/
たんばいろ /胆礬色/
たんばぐち /丹波口/
たんばばし /丹波橋/
たんばやき /丹波焼/
たんばら /丹原/
たんばん /単板/胆礬;chalcanthite/
たんぱ /短波/
たんぱく /蛋白/淡白/淡泊;=淡白/
たんぱくげん /蛋白源/
たんぱくしつ /蛋白質/タンパク質/
たんぱくせき /蛋白石/
たんぱくにょう /蛋白尿/
たんぱしょう /短波賞/
たんぱじゅしんき /短波受信機/
たんぱつ /単発/短髪/
たんぱつせい /単発性/
たんぱつてき /単発的/
たんぱほうそう /短波放送/
たんぱらじお /短波ラジオ/
たんぱん /短パン/
たんび /耽美/嘆美/歎美/度/
たんびしゅぎ /耽美主義/
たんびてき /耽美的/
たんびは /耽美派/
たんぴ /単肥/
たんぴょう /短評/単票/
たんぴん /単品/
たんふく /単複/
たんふりこ /単振り子/単振子/
たんぶ /端部/反歩/
たんぶん /短文/単文/探聞/
たんぶんか /短文化/
たんぶんしまく /単分子膜;[化学]monomolecular film/
たんぶんしょう /短文章/
たんぶんせつ /単文節/
たんぶんせつへんかん /単文節変換/
たんぷく /単複/
たんべん /単弁;[植物]univalve. ⇔重弁/
たんべんか /単弁花/
たんべんかるい /Monopetalae/
たんぺい /短兵/
たんぺいきゅう /短兵急/
たんぺん /短編/短篇/短辺/
たんぺんけっさくしゅう /短編傑作集/
たんぺんしゅう /短編集/短篇集/
たんぺんしょうせつ /短編小説/短篇小説/
たんぺんせいか /短編成化/
たんほう /探訪;たんぼう/
たんほうかい /探訪会/
たんほうこう /単方向/
たんほうせい /単峰性/
たんほんい /単本位/
たんぼ /田圃/田んぼ/
たんぼいん /短母音;[音声学]short vowel/単母音/
たんぼう /探訪/
たんぼく /単木/
たんぽ /担保/
たんぽけん /担保権/
たんぽせいきゅうけん /担保請求権/
たんぽつきしゃさい /担保付社債/
たんぽぶっけん /担保物権/
たんぽぶつ /担保物/
たんぽぽ /蒲公英/
たんぽぽいろ /蒲公英色/
たんまち /反町/
たんまちえき /反町駅/
たんまつ /端末/
たんまつか /端末化/
たんまつかん /端末間/
たんまつがわ /端末側/
たんまつき /端末機/
たんまつきき /端末機器/
たんまつきょく /端末局/
たんまつけい /端末系/
たんまつしつ /端末室/
たんまつじょう /端末上/
たんまつせってい /端末設定/
たんまつせつび /端末設備/
たんまつそうさ /端末操作/
たんまつそうち /端末装置/
たんまつぞくせい /端末属性/
たんまつひょうじ /端末表示/
たんまつまど /端末窓/
たんまつめい /端末名/
たんまつよう /端末用/
たんみ /単味/淡味/澹味/
たんみつど /単密度/
たんみん /短眠/蛋民/蜑民/
たんむ /坦務/
たんめい /短命/
たんめん /端面/湯麺/単面/
たんめんよう /単面葉/
たんもう /短毛/
たんもうしゅ /短毛種/
たんもの /反物/
たんや /短夜/
たんやく /丹薬/
たんゆう /胆勇/
たんよう /単葉/
たんようき /単葉機/
たんよく /貪欲/
たんよん /単四;―電池(AAA)/
たんらく /短絡/
たんらくしこう /短絡思考/
たんらくせん /短絡線/
たんらくてき /短絡的/
たんらん /貪婪/
たんり /単離/単利/
たんりつ /単立/
たんりゃく /胆略/
たんりゅう /単粒/
たんりゅうこうぞう /単粒構造;single-grained structure. ⇔団粒構造/
たんりゅうしゅ /短粒種;short-grained. 日本の米など ⇔長粒種/
たんりょ /短慮/
たんりょうたい /単量体/
たんりょく /淡緑/胆力/
たんりょくしょく /淡緑色/
たんりょくぼん /丹緑本/
たんれい /端麗/淡麗;†[新語]酒類があっさりしていること/
たんれつ /単列/
たんれん /鍛錬/鍛練;=鍛錬/単連/
たんれんけつ /単連結/
たんれんちゅう /鍛錬中/
たんろ /単路/
たんろくぼん /丹緑本/
たんわく /単枠/
たんわくしてい /単枠指定/
だ /駄/打/兌;[八卦]陰陽陽/田/妥/懦;怯懦/儺/堕;堕落/惰;惰性/楕;楕円/蛇;長蛇/陀;仏陀/舵;(かじ)操舵/柁;=舵/駝;駱駝/鴕;駝鳥/沱/佗/唾/騨/朶;耳朶/娜;婀娜/拿;拿捕/拏;「拿」の異体字/橢;=楕/陏/荼;荼毘/雫/墮;旧字/出/
だ> /駄;駄作,駄売り,駄スレ/
だい /大/第/題/台/代/醍/臺;「台」の旧字/餒;(うえる)/迺;(すなわち)/廼;「迺」の異体字/内/弟/戴/岱/梯;?/
だい# /第#3/第#2/第#1/第#0/第;?/
だい#い /第#1位/
だい#かい /第#1回/第#0回/第#2回/第#3回/第 #0 回/
だい#かいめ /第#1回目/第#0回目/
だい#かん /第#1巻/第#0巻/
だい#がくしょう /第#0楽章/第#3楽章/
だい#き /第#0期/第#1期/第#0紀/第#3紀/
だい#きぼう /第#0希望/
だい#きょく /第#0局/第#1局/第#3局/
だい#ぎょう /第#3行/第#0行/
だい#こう /第#1項/第#0項/第#3項/
だい#こうざ /第#3講座/
だい#こうほ /第#0候補/第 #0 候補/
だい#ごう /第#1号/第#0号/第#3号/
だい#し /第#3子/
だい#しあい /第#3試合/
だい#しぼう /第#3志望/
だい#しゅ /第#3種/第#1種/
だい#しゅう /第#1週/第#0集/
だい#しょう /第#0章/第#1章/第#2章/
だい#じ /第#2次/第#0次/第#1次/
だい#じょう /第#3条/第#1条/第#2条/第#0条/
だい#じょうの# /第#3条の#3/第#0条の#0/第#2条の#2/第#1条の#1/
だい#じん /第#1陣/
だい#すいじゅん /第#0水準/
だい#ず /第#1図/
だい#せだい /第#1世代/第#3世代/第 #0 世代/
だい#せつ /第#0節/第#1節/
だい#せん /第#3線/第#3戦/第#1戦/第#0戦/
だい#だいきゅうし /第#3大臼歯/
だい#だん /第#1弾/第#3弾/第#0段/第#3段/
だい#だんかい /第#3段階/
だい#ちゅう /第#3中/
だい#にち /第#0日/
だい#は /第#3波/
だい#はん /第#0版/第#1版/第#2版/第#1班/
だい#ばん /第#0版/第#1版/第#0番/第#2番/
だい#ばんめ /第#0番目/第#2番目/
だい#ぱ /第#3波/
だい#ぱん /第#0版/第#2版/
だい#ひきすう /第#0引数/第#1引数/
だい#びん /第#3便/
だい#ぶ /第#1部/第#0部/
だい#まく /第#3幕/
だい#めん /第#3面/
だい#や /第#3夜/
だい#れつ /第#3列/第#0列/
だい#わ /第#0話/
だい> /第/大/
だいあいじょう /大愛情/
だいあく /大悪/
だいあくま /大悪魔/
だいあん /代案/
だいあんじ /大安寺/
だいい /代位/題意/大尉;(旧海軍での呼び方) =たいい/
だいいき /大域/
だいいきてき /大域的/
だいいし /台石/
だいいせき /大遺跡/
だいいち /第一/第１/第1/
だいいちい /第一位/
だいいちいんしょう /第一印象/
だいいちうちゅうそくど /第一宇宙速度/
だいいちかいぎしつ /第一会議室/
だいいちかいそう /第一階層/
だいいちかいはつしつ /第一開発室/
だいいちかいはつぶ /第一開発部/
だいいちかもつ /第一貨物/
だいいちかんぎょうぎんこう /第一勧業銀行/
だいいちかんぎん /第一勧銀/
だいいちがくしょう /第一楽章/
だいいちきぼう /第一希望/
だいいちぎ /第一義/
だいいちぎじゅつぶ /第一技術部/
だいいちぎてき /第一義的/
だいいちけいひん /第一京浜/
だいいちけいひんこくどう /第一京浜国道/
だいいちけんきゅうしつ /第一研究室/
だいいちげんり /第一原理/
だいいちこう /第一項/
だいいちこうざ /第一講座/
だいいちこうしょう /第一興商/
だいいちこうほ /第一候補/第1候補/
だいいちごう /第一号/第１号/
だいいちざ /大一座/
だいいちしあい /第一試合/
だいいちしょうけん /第一證券/
だいいちしょうたい /第一小隊/
だいいちじ /第一次/
だいいちじしめきり /第一次締切/
だいいちじせかいたいせん /第一次世界大戦/
だいいちじたいせん /第一次大戦/
だいいちじょしこう /第一女子高/
だいいちじよせん /第一次予選/
だいいちじん /第一陣/
だいいちすいじゅん /第一水準/第1水準/
だいいちせいめい /第一生命/
だいいちせいやく /第一製薬;[企業名]/
だいいちせっけい /第一設計/
だいいちせっけいぶ /第一設計部/
だいいちせめんと /第一セメント/
だいいちだん /第一段/第一弾/第１弾/
だいいちだんかい /第一段階/第1段階/
だいいちちく /第一地区/
だいいちちょしゃ /第一著者/
だいいちとうじしゃ /第一当事者/
だいいちにち /第一日/第１日/
だいいちにちめ /第一日目/
だいいちにんしゃ /第一人者/
だいいちにんしょう /第一人称/
だいいちひきすう /第一引数/
だいいちびん /第一便/
だいいちぶ /第一部/
だいいちぶんがくぶ /第一文学部/
だいいちほうそく /第一法則/
だいいちほてる /第一ホテル/
だいいちもくてきち /第一目的地/
だいいちもん /第一問/
だいいちゆうせん /第一優先/
だいいちよういん /第一要因/
だいいちようそ /第1要素/
だいいちりゅう /第一流/
だいいちれいきじょうたい /第一励起状態/
だいいちろう /大一郎/
だいいちわ /第一話/
だいいっか /第一課/
だいいっかい /第一回/第１回/第1回/第一階/
だいいっかいじゅしょうしゃ /第一回受賞者/
だいいっかいちょうさ /第一回調査/
だいいっかいはいほん /第一回配本/
だいいっかいめ /第一回目/第１回目/
だいいっかん /第一巻/第一款/第一感/第一勘/
だいいっき /第一期/
だいいっきゅう /第一級/
だいいっこう /第一項/第一稿/
だいいっさく /第一作/
だいいっし /第一子/
だいいっししゅっさん /第一子出産/
だいいっしゅ /第一種/第1種/
だいいっしゅう /第一週/
だいいっしゅうめ /第一週目/
だいいっしょう /第一章/第1章/
だいいっしん /第一審/
だいいっせい /第一声/
だいいっせつ /第一節/
だいいっせん /第一線/第一戦/
だいいっせんきゅう /第一線級/
だいいってん /第一点/
だいいっぱ /第一波/
だいいっぱん /第一版/第1版/
だいいっぽ /第一歩/
だいいっぽう /第一報/
だいいとくみょうおう /大威徳明王/
だいいどう /大移動/
だいいべんさい /代位弁済/
だいいべんと /大イベント/
だいいん /代員/代印/
だいいんしん /大陰唇/
だいうちゅう /大宇宙/
だいうん /大運/
だいえ /大会/
だいえい /大栄/大映/大永;年号(1521-1528)/題詠/
だいえいだん /大英断/
だいえいていこく /大英帝国/
だいえいはくぶつかん /大英博物館/
だいえっとしょくひん /ダイエット食品/
だいえつ /大越;現ベトナム/
だいえり /台襟;[服飾]/
だいえん /大円/
だいえんかい /大宴会/
だいえんかいじょう /大宴会場/
だいえんきん /大円筋/
だいえんじょう /大円上/
だいえんぜつ /大演説/
だいおう /大王/大黄/
だいおうじょう /大往生/
だいおん /大恩/大音/大陰;[陰陽道]八将神の一。土星/
だいおんきょう /大音響/
だいおんじょう /大音声/
だいおんじん /大恩人/
だいおんせい /大音声/
だいおんりょう /大音量/
だいか /代価/台下/
だいかあん /代価案/
だいかいかく /大改革/
だいかいぎしつ /大会議室/
だいかいしょう /大海嘯/
だいかいじゅう /大怪獣/
だいかいじょう /大会場/
だいかいせい /大改正/
だいかいせん /大海戦/
だいかいぞう /大改造/
だいかいぞうけいかく /大改造計画/
だいかいぞく /大海賊/
だいかいてい /大改訂/
だいかいてん /大回転/
だいかいれい /大海令/
だいかえ /代替/
だいかえあん /代替案/
だいかく /大覚/
だいかくじ /大覚寺/
だいかくめい /大革命/
だいかこ /大過去/
だいかさい /大火災/
だいかし /代貸し/
だいかぞく /大家族/
だいかっこ /大括弧;［］/［/］/
だいかっさい /大喝采/
だいかっせん /大合戦/
だいかつ /大喝/
だいかついっせい /大喝一声/
だいかつやく /大活躍/
だいかつやくちゅう /大活躍中/
だいかひん /代価品/
だいかぶつ /代価物/
だいかべんさい /代価弁済/
だいかん /代官/大寒;[二十四節気]1.20頃/大韓/大巻/大缶/
だいかんきょほう /大艦巨砲/
だいかんげい /大歓迎/
だいかんげいかい /大歓迎会/
だいかんげき /大感激/
だいかんこうくう /大韓航空/
だいかんこうくうき /大韓航空機/
だいかんごりん /大漢語林/
だいかんさま /代官様/
だいかんしゃ /大感謝/
だいかんしゅう /大観衆/
だいかんしょ /代官所/
だいかんじょうせん /大環状線/
だいかんせい /大歓声/大喚声/
だいかんせん /大幹線/
だいかんそう /大観荘/
だいかんどう /大感動/
だいかんのんぞう /大観音像/
だいかんみんこく /大韓民国/
だいかんやま /代官山/
だいかんわ /大漢和/
だいかんわじてん /大漢和辞典/大漢和辭典/
だいがいしゃ /大会社/
だいがえ /代替え/代替/
だいがえくうこう /代替空港/
だいがえしゃ /代替車/
だいがえち /代替地/
だいがえゆそう /代替輸送/
だいがく /大学/大學;「学」旧字/
だいがくいがい /大学以外/
だいがくいがくぶ /大学医学部/
だいがくいこう /大学以降/
だいがくいちねんせい /大学一年生/
だいがくいも /大学芋;[料理]揚げて蜜をからめたサツマイモ/
だいがくいん /大学院/
だいがくいんがくせい /大学院学生/
だいがくいんきょういく /大学院教育/
だいがくいんざいがく /大学院在学/
だいがくいんしゅうりょうご /大学院修了後/
だいがくいんしんがくりつ /大学院進学率/
だいがくいんじゅうてんか /大学院重点化/
だいがくいんせい /大学院生/
だいがくいんだいがく /大学院大学/
だいがくいんにゅうし /大学院入試/
だいがくかいかん /大学会館/
だいがくかん /大学間/
だいがくかんけい /大学関係/
だいがくかんけいしゃ /大学関係者/
だいがくがくぶ /大学学部/
だいがくがわ /大学側/
だいがくきょういく /大学教育/
だいがくきょういん /大学教員/
だいがくきょうかん /大学教官/
だいがくきょうじゅ /大学教授/
だいがくきょうよう /大学教養/
だいがくきょうようていど /大学教養程度/
だいがくきょうようぶ /大学教養部/
だいがくきよう /大学紀要/
だいがくこうざ /大学講座/
だいがくこうない /大学構内/
だいがくごうかくりつ /大学合格率/
だいがくさい /大学祭/
だいがくざいがくちゅう /大学在学中/
だいがくしょてん /大学書店/
だいがくしょりん /大学書林/
だいがくしんがく /大学進学/
だいがくじ /大学時/
だいがくじだい /大学時代/
だいがくじゅけん /大学受験/
だいがくじゅけんあんない /大学受験案内/
だいがくじゅんきょうじゅ /大学准教授/
だいがくじょしゅ /大学助手/
だいがくじん /大学人/
だいがくせい /大学生/
だいがくせいかつ /大学生活/
だいがくせいきょう /大学生協/
だいがくせいきょうしょくどう /大学生協食堂/
だいがくせいじだい /大学生時代/
だいがくせいじょし /大学生女子/
だいがくせん /大学戦/
だいがくせんしゅけん /大学選手権/
だいがくぜい /大学勢/
だいがくぜんたい /大学全体/
だいがくぜんぱん /大学全般/
だいがくそしき /大学組織/
だいがくそつ /大学卒/
だいがくそつぎょう /大学卒業/
だいがくそつぎょういらい /大学卒業以来/
だいがくそつぎょうしゃ /大学卒業者/
だいがくそつぎょうていど /大学卒業程度/
だいがくたいこう /大学対抗/
だいがくちゅうたい /大学中退/
だいがくで /大学出/
だいがくとうきょく /大学当局/
だいがくとしょかん /大学図書館/
だいがくない /大学内/
だいがくにほんいち /大学日本一/
だいがくにゅうがく /大学入学/
だいがくにゅうし /大学入試/
だいがくにゅうしもんだい /大学入試問題/
だいがくのーと /大学ノート/
だいがくのかみ /大学頭/
だいがくはつ /大学発/
だいがくびょういん /大学病院/
だいがくびょういんまえ /大学病院前/
だいがくふんそう /大学紛争/
だいがくぶ /大学部/
だいがくまえ /大学前/
だいがくまち /大学町/
だいがくまんが /大学漫画/
だいがくめい /大学名/
だいがくやきゅう /大学野球/
だいがくりょう /大学寮;[律令制]/
だいがくれい /大学令/
だいがす /大ガス;[企業名]/
だいがっこう /大学校/
だいがっしょう /大合唱/
だいがめん /大画面/
だいがめんたいおう /大画面対応/
だいがらん /大伽藍/
だいがわり /代替わり;generational change/代替り/
だいがん /大願/
だいがんじょうじゅ /大願成就/
だいがんめん /大顔面/
だいき /大機/代機/乃毅;名/
だいきぎょう /大企業/
だいきぎょうびょう /大企業病/
だいきこう /大紀行/
だいきち /大吉/
だいきぼ /大規模/
だいきぼか /大規模化/
だいきぼけいさん /大規模計算/
だいきぼこうぞう /大規模構造/
だいきぼすうちけいさん /大規模数値計算/
だいきぼちしき /大規模知識/
だいきぼてん /大規模店/
だいきぼとうし /大規模投資/
だいきぼはつでん /大規模発電/
だいきぼへいれつ /大規模並列/
だいきゅう /代休/大弓;七尺五寸/
だいきゅうし /大休止/大臼歯/
だいきょう /大凶/大京;[企業名]/
だいきょういん /大教院/
だいきょうかい /大教会/
だいきょうかん /大叫喚/
だいきょうかんこう /大京観光;[企業名]/
だいきょうかんじごく /大叫喚地獄/
だいきょうきん /大胸筋/
だいきょうこう /大恐慌/
だいきょうしつ /大教室/
だいきょうすう /大凶数/
だいきょうそう /大競走/
だいきょうちょう /大京町/
だいきょうまち /大京町/
だいきらい /大嫌い/
だいきろく /大記録/
だいきん /代金/大金/
だいきんけっさい /代金決済/
だいきんこうぎょう /ダイキン工業;[企業名]/
だいきんとりたて /代金取立/
だいきんひきかえ /代金引換/
だいきんひきかえゆうびん /代金引換郵便/
だいきんぼし /大金星/
だいぎ /台木;[園芸]rootstock. 挿し木される台/代議/
だいぎいん /代議員/
だいぎいんかい /代議員会/
だいぎいんたいかい /代議員大会/
だいぎし /代議士/
だいぎせい /代議制/
だいぎせいじ /代議政治/
だいぎせいど /代議制度/
だいぎもん /大疑問/
だいぎゃくさつ /大虐殺/
だいぎゃくさつじけん /大虐殺事件/
だいぎゃくてん /大逆転/
だいぎゃくてんしょうり /大逆転勝利/
だいぎょうじ /大行事/
だいぎょうてん /大仰天/
だいぎょうれつ /大行列/
だいぎん /大吟/
だいぎんこう /大銀行/
だいぎんじょう /大吟醸/
だいく /大工/第九/
だいくうこう /大空港/
だいくかく /大区画/
だいくせん /大苦戦/
だいくまち /大工町/
だいぐうじ /大宮司/
だいぐさく /大愚作/
だいけい /台形/大慶;(daqing)地名,中国/大計/大型計算機;※abbrev/大型計算機センター;※abbrev/大計センター;※abbrev/
だいけいかく /大計画/
だいけいそく /台形則/
だいけっさく /大傑作/
だいけつ /代決/
だいけん /大検;[略語]大学入学資格検定/大建/
だいけんい /大権威/
だいけんきゅう /大研究/
だいけんこうぎょう /大建工業;[企業名]/
だいけんしゅうしつ /大研修室/
だいけんしょう /大憲章;Magna Carta/
だいけんとう /大健闘/
だいげき /大外記/
だいげきじょう /大劇場/
だいげきせん /大激戦/
だいげん /題言/代言/
だいげんかい /大言海/
だいげんすいへいか /大元帥陛下/
だいげんそく /大原則/
だいげんにん /代言人/
だいこ /太鼓/
だいこう /代行/大幸/代講/乃公;オレサマ。「-出でずんば」/
だいこううんてん /代行運転/
だいこうかい /大公開/大航海/大後悔/
だいこうかいじだい /大航海時代/
だいこうがた /代行型/
だいこうきょうきょく /大交響曲/
だいこうぎしつ /大講義室/
だいこうぎょう /代行業/
だいこうぎょうむ /代行業務/
だいこうけい /大口径/
だいこうけいぼうえん /大口径望遠/
だいこうけん /代行権/
だいこうこく /大広告/
だいこうざ /大講座/
だいこうしゃ /代行者/
だいこうしん /大行進/
だいこうじ /大工事/
だいこうずい /大洪水/
だいこうせい /大攻勢/
だいこうだいこう /大工大高/
だいこうてん /代行店/
だいこうどう /大講堂/
だいこうひょう /大好評/
だいこうふん /大興奮/
だいこうぶつ /大好物/
だいこうぼうせん /大攻防戦/
だいこうもく /大項目/
だいこうや /代行屋/
だいこうゆそう /代行輸送/
だいこうりょう /代行料/大光量/
だいこく /大黒/
だいこくさま /大黒様/
だいこくちょう /大国町/
だいこくてん /大黒天/
だいこくどう /大黒堂/
だいこくばしら /大黒柱/
だいこじ /大居士/
だいこん /大根/
だいこんあし /大根足/
だいこんおろし /大根下ろし/
だいこんざつ /大混雑/
だいこんせん /大混戦/大混線/
だいこんな /大根菜/
だいこんは /大根葉/
だいこんば /大根葉/
だいこんやくしゃ /大根役者/
だいこんらん /大混乱/
だいこんらんじょうたい /大混乱状態/
だいご /第五/醍醐/大子/大吾/大悟/第５/
だいごい /大語彙/
だいごう /題号/
だいごかい /大誤解/大語界/第５回/
だいごかん /第五巻/
だいごくでん /大極殿/
だいごさん /大誤算/醍醐山;地名/
だいごし /第五子/
だいごしあい /第五試合/
だいごしん /大誤審/
だいごじ /醍醐寺/
だいごせだい /第五世代/第５世代/
だいごせつ /第五節/
だいごせん /第五戦/
だいごてってい /大悟徹底/
だいごてんのう /醍醐天皇/
だいごみ /醍醐味/
だいごれつ /第五列/
だいごわくせい /第五惑星/
だいごんげん /大権現/
だいさ /大佐;(旧海軍での呼び方) =たいさ/
だいさーびす /大サービス/
だいさい /大祭/
だいさいがい /大災害/
だいさいなん /大災難/
だいさぎょう /大作業/
だいさく /代作/大作/
だいさくせん /大作戦/
だいさっか /大作家/
だいさっきょくか /大作曲家/
だいさつりく /大殺戮/
だいさぶろう /大三郎/
だいさん /第三/代参/第３/第3/第III/
だいさんいんすう /第三引数/
だいさんかい /第３回/
だいさんかいそう /第三階層/
だいさんかいはつぶ /第三開発部/
だいさんかん /第三巻/第三款/
だいさんがいこくご /第三外国語/
だいさんがくぐん /第三学群/
だいさんがくしょう /第三楽章/
だいさんき /第三期/第三紀/
だいさんきぼう /第三希望/
だいさんけいひん /第三京浜/
だいさんけんきゅうしつ /第三研究室/
だいさんげん /大三元/
だいさんこう /第三項/
だいさんこうざ /第三講座/
だいさんごく /第三国/
だいさんごくじん /第三国人/
だいさんさいむしゃ /第三債務者/
だいさんざい /大散財/
だいさんしあい /第三試合/
だいさんしゃ /第三者/
だいさんしゃきかん /第三者機関/
だいさんしゃてき /第三者的/
だいさんしゃわりあて /第三者割当/
だいさんしゅ /第三種/
だいさんしゅとくしゃ /第三取得者/
だいさんしゅゆうびんぶつ /第三種郵便物/
だいさんしょう /第三章/第3章/
だいさんしょかん /第三書館/
だいさんしん /第三審/
だいさんじ /大惨事/
だいさんじせかいたいせん /第三次世界大戦/
だいさんすいじゅん /第三水準/
だいさんせい /大賛成/
だいさんせいりょく /第三勢力/
だいさんせかい /第三世界/
だいさんせくたー /第三セクター/
だいさんせだい /第三世代/
だいさんせつ /第三節/
だいさんせん /第三戦/
だいさんだん /第三弾/第３段/第３弾/
だいさんにち /第三日/
だいさんにんしょう /第三人称/
だいさんばん /第三版/
だいさんぶ /第三部/
だいさんぶたい /第三舞台/
だいさんみぶん /第三身分;[世界史]le tiers etat/
だいさんわ /第三話/
だいざ /台座/
だいざい /題材/大罪/
だいざいてき /題材的/
だいざいばつ /大財閥/
だいざえもん /大左衛門/
だいざわ /代沢;地名/
だいざんさつ /大惨殺/
だいざんぱい /大惨敗/
だいし /台紙/台詞/大師/大志/大史;[律令制]主典(さかん)/大姉/題詞/題詩/第四/
だいしあい /大試合/
だいしいちばん /大死一番/
だいしがわら /大師河原/
だいしきゅう /大至急/
だいしきょう /大司教/
だいしぎんこう /第四銀行/
だいしごう /大師号/
だいしじん /大詩人/
だいしぜん /大自然/
だいしだい /大市大/
だいしっこう /代執行/
だいしったい /大失態/
だいしっぱい /大失敗/
だいしどう /大師堂/
だいしのう /大司農/
だいしへんけい /大四辺形/
だいしゃ /台車/代車/
だいしゃかん /台車間/
だいしゃこうかん /台車交換/
だいしゃっきん /大借金/
だいしゃない /台車内/
だいしゃめん /大斜面/
だいしゃりん /大車輪/
だいしゃわく /台車枠/
だいしゅ /大衆/
だいしゅうかい /大集会/
だいしゅうかく /大収穫/
だいしゅうごう /大集合/
だいしゅうそうぞく /代襲相続/
だいしゅうだん /大集団/
だいしゅくしゃく /大縮尺/
だいしゅじゅつ /大手術/
だいしゅぞく /大種族/
だいしゅっせ /大出世/
だいしゅっぱんしゃ /大出版社/
だいしゅっぴ /大出費/
だいしゅつげん /大出現/
だいしゅつりょく /大出力/
だいしゅぶ /大衆部/
だいしょ /代書/
だいしょう /大小/代償/大証;大阪証券取引所/大聖/代将/大将/
だいしょういちぶ /大証一部/
だいしょうかんけい /大小関係/
だいしょうがい /大障害/
だいしょうぐん /大将軍/
だいしょうさよう /代償作用/
だいしょうざん /大翔山/
だいしょうじ /大聖寺/
だいしょうだい /大商大/
だいしょうてん /大賞典/
だいしょうとつ /大衝突/
だいしょうにぶ /大証二部/
だいしょうねつじごく /大焦熱地獄/
だいしょうひかく /大小比較/
だいしょうほう /大翔鳳/
だいしょうり /大勝利/大捷利/
だいしょうわせいし /大昭和製紙;[企業名]/
だいしょくどう /大食堂/
だいしょっく /大ショック/
だいしょてん /大書店/
だいしょにん /代書人/
だいしょや /代書屋/
だいしん /代診/
だいしんいん /大審院/
だいしんさい /大震災/
だいしんでん /大神殿/
だいしんど /大深度/
だいしんどちか /大深度地下;[新語]地上の土地所有権の及ばない地下/
だいしんぱん /大信販;[企業名]/
だいしんぶん /大新聞/
だいしんゆう /大親友/
だいじ /大事/大字/大治/題字/大寺/大慈/大弐/題辞/
だいじけん /大事件/
だいじげん /大字源/
だいじこ /大事故/
だいじしん /大地震/
だいじせん /大辞泉;国語辞典/
だいじだいひ /大慈大悲/
だいじてん /大辞典/大事典/
だいじほう /大字報/
だいじゃ /大蛇/
だいじゃたいじ /大蛇退治/
だいじゅ /大樹;名/
だいじゅうたい /大渋滞/
だいじゅんかん /大循環/
だいじょう /大乗/台上/大丈/台状/大嘗/大判官/
だいじょうえ /大嘗会/
だいじょうかん /太政官/
だいじょうかんさつ /太政官札/
だいじょうかんちょう /太政官庁/太政官牒/
だいじょうかんにっし /太政官日誌/
だいじょうかんふこく /太政官布告/
だいじょうかんぷ /太政官符/
だいじょうきゅう /大嘗宮/
だいじょうきょう /大乗経/
だいじょうさい /大嘗祭/
だいじょうじ /大乗寺/
だいじょうだいじん /太政大臣/
だいじょうだん /大上段/
だいじょうてき /大乗的/
だいじょうてんのう /太上天皇/
だいじょうぶ /大丈夫/
だいじょうぶっきょう /大乗仏教/
だいじょうみゃく /大静脈/
だいじょきょく /大序曲/
だいじょゆう /大女優/
だいじり /台尻/
だいじりん /大辞林;国語辞典/
だいじろう /大二郎/
だいじん /大臣/大神/大尽/
だいじんかんぼう /大臣官房/
だいじんぐう /大神宮/
だいじんぐうした /大神宮下/
だいじんどう /大仁堂/
だいじんぶつ /大人物/
だいす /台子/
だいすーしー /大四喜/
だいすいがい /大水害/
だいすいせい /大彗星/
だいすう /代数/台数/大数/
だいすうかい /代数解/
だいすうかくだい /代数拡大/
だいすうかくほ /台数確保/
だいすうかんすう /代数関数/
だいすうがく /代数学/
だいすうがくしゃ /大数学者/
だいすうきか /代数幾何/
だいすうきかがく /代数幾何学/
だいすうきかてき /代数幾何的/
だいすうきょくせん /代数曲線/
だいすうけい /代数系/
だいすうこうか /台数効果/
だいすうこうぞう /代数構造/
だいすうしき /代数式/
だいすうたい /代数体/
だいすうたようたい /代数多様体/
だいすうち /代数値/
だいすうてき /代数的/
だいすうてきしよう /代数的仕様/
だいすうほうていしき /代数方程式/
だいすき /大好き/
だいすけ /大輔/大介/大助/大祐/大亮/
だいすたー /大スター/
だいず /大豆/
だいずかん /大図鑑/
だいずばたけ /大豆畑/
だいせーる /大セール/
だいせいうん /大星雲/
だいせいえん /大声援/
だいせいか /大成果/
だいせいかい /大正解/
だいせいきょう /大盛況/
だいせいこう /大成功/
だいせいとう /大政党/
だいせいどう /大聖堂/
だいせいりょく /大勢力/
だいせきはん /大赤斑;[天文]木星のエクボ/
だいせっきん /大接近/
だいせっけい /大雪渓/
だいせつ /大雪/
だいせつざん /大雪山/
だいせん /大仙;偉大な仙人。如来/台船/大山;地名,鳥取/
だいせんかん /大戦艦/
だいせんきょく /大選挙区/
だいせんしゅ /大選手/
だいせんせい /大先生/
だいせんそう /大戦争/
だいせんだつ /大先達/
だいせんだん /大船団/
だいせんでん /大宣伝/
だいせんぱい /大先輩/
だいせんぷう /大旋風/
だいせんりゃく /大戦略/
だいぜっきょう /大絶叫/
だいぜん /大膳/
だいぜんしゅう /大全集/
だいぜんてい /大前提/
だいそう /代走/代奏/体操/
だいそうげん /大草原/
だいそうげんのちいさないえ /大草原の小さな家;ドラマ名/
だいそうさく /大捜索/
だいそうさせん /大捜査線/
だいそうしょう /大僧正/
だいそうじょう /大僧正/
だいそうどう /大騒動/
だいそしき /大組織/
だいそつ /大卒/
だいそつしゃ /大卒者/
だいそつじょし /大卒女子/
だいそつだんし /大卒男子/
だいそれた /大それた/
だいそんがい /大損害/
だいぞう /大蔵/
だいぞういん /大増員/
だいぞうかん /大増刊/
だいぞうかんごう /大増刊号/
だいぞうげん /大増減/
だいた /代田/台田/
だいたい /代替/大体/大隊/大腿/
だいたい> /大体;(副詞)/
だいたいあん /代替案/
だいたいえねるぎー /代替エネルギー/
だいたいかいさい /代替開催/
だいたいき /代替機/
だいたいきかん /代替機関/
だいたいきん /大腿筋/
だいたいくうこう /代替空港/
だいたいけい /大腿頚/
だいたいこうか /代替効果/
だいたいこつ /大腿骨/
だいたいさく /代替策/
だいたいざい /代替財;[経済]⇔補完財。携帯とPHSなど/
だいたいしっこう /代替執行/
だいたいしとうきん /大腿四頭筋/
だいたいしゅだん /代替手段/
だいたいどうみゃく /大腿動脈/
だいたいどうろ /代替道路/
だいたいねんりょう /代替燃料/
だいたいひょうき /代替表記/
だいたいひょうげん /代替表現/
だいたいひん /代替品/
だいたいふろん /代替フロン/
だいたいぶ /大腿部/
だいたいぶつ /代替物/
だいたいぶひん /代替部品/
だいたいほう /代替法/
だいたいほうほう /代替方法/
だいたいりょうほう /代替療法/
だいたいろせん /代替路線/
だいたすう /大多数/
だいたばし /代田橋/
だいたろう /大太郎/
だいたん /大胆/
だいたんふてき /大胆不敵/
だいだ /代打/
だいだい /橙/代々/大々/代代/
だいだいいろ /橙色/だいだい色/
だいだいず /橙酢/
だいだいてき /大々的/
だいだいひょう /大代表/
だいだいみょう /大大名/
だいだいり /大内裏/
だいだげき /大打撃/
だいだじん /代打陣/
だいだっそう /大脱走/
だいだほんるいだ /代打本塁打/
だいだんえん /大団円/大団圓/
だいだんそう /大断層/
だいち /大地/台地/代地/大値/代置/
だいちえん /大遅延/
だいちこく /大遅刻/
だいちぼしん /大地母神/
だいちまお /大地真央/
だいちゅう /大中/
だいちゅうおう /台中央/
だいちゅうしゃじょう /大駐車場/
だいちゅうしょう /大中小/
だいちゅうだん /大中断/
だいちょう /台帳/大腸/
だいちょうえん /大腸炎/
だいちょうかんり /台帳管理/
だいちょうがん /大腸癌/大腸がん/大腸ガン/
だいちょうきん /大腸菌/
だいちょうない /大腸内/
だいちょうへん /大長編/
だいっきらい /大っ嫌い/
だいついせき /大追跡/
だいていこく /大帝国/
だいていたく /大邸宅/
だいていでん /大停電/
だいていり /大定理/
だいてつ /大哲/
だいてつじん /大鉄人/
だいてん /大典/大篆/題点/
だいてんかん /大転換/
だいてんさい /大天才/
だいてんし /大天使/大転子/
だいてんとう /大転倒/
だいてんほう /大店法;[法][略語]大規模小売店舗における小売業の事業活動の調整に関する法律。1998年廃止/
だいてんもく /台天目/
だいてんりっちほう /大店立地法;[法][略語]大規模小売店舗立地法/
だいでんつうだい /大電通大/
だいでんりゅう /大電流/
だいでんりょく /大電力/
だいと /大都/
だいとう /大東/大塔/大刀/大唐/大盗/
だいとうあ /大東亜/大東亞;旧字/
だいとうあきょうえいけん /大東亜共栄圏/
だいとうあせんそう /大東亜戦争/
だいとういつりろん /大統一理論/
だいとうがくえん /大東学園/
だいとうきょう /大東京/
だいとうきょうかさい /大東京火災/
だいとうさいいきき /大唐西域記;玄奘/
だいとうし /大東市/
だいとうじん /大東陣/
だいとうぞく /大盗賊/
だいとうだい /大東大/
だいとうぶんか /大東文化/
だいとうぶんかだい /大東文化大/
だいとうぶんかだいがく /大東文化大学/
だいとうぼうしょく /大東紡織/
だいとうりょう /大統領/
だいとうりょうきゅうでん /大統領宮殿/
だいとうりょうせん /大統領選/
だいとうりょうせんきょ /大統領選挙/
だいとうりょうふ /大統領府;ロシア-/
だいとうろん /大討論/
だいとかい /大都会/
だいとく /大徳/
だいとくい /大得意/
だいとくしゅう /大特集/
だいとくしゅうごう /大特集号/
だいとくじ /大徳寺/
だいとくじなっとう /大徳寺納豆/
だいとこうぎょう /大都工業;[企業名]/
だいとし /大都市/
だいとしかん /大都市間/
だいとしけん /大都市圏/
だいとしゃ /大都社;[出版社名]www.daitosha.jp/
だいとちしょゆう /大土地所有/
だいどう /大同;年号(806-810)/大道/
だいどうげい /大道芸/
だいどうげいにん /大道芸人/
だいどうこうはん /大同鋼板/
だいどうし /代動詞;[文法]pro-verb. eg.「行く？」「そうするか」の「する」/
だいどうしょうい /大同小異/
だいどうしょうにん /大道商人/
だいどうじ /大道寺/
だいどうだんけつ /大同団結/
だいどうみゃく /大動脈/
だいどうみゃくえんしょうこうぐん /大動脈炎症候群/
だいどく /代読/大毒/
だいどころ /台所/
だいどころじじょう /台所事情/
だいどころせんざい /台所洗剤/
だいどころよう /台所用/
だいなごん /大納言/
だいなし /台無し/台無/
だいなな /第七/
だいななかい /第７回/
だいななきょく /第七局/
だいななげいじゅつげきじょう /第七芸術劇場/
だいななしあい /第七試合/
だいななせつ /第七節/
だいなり /＞/≧/大なり/
だいなりいこーる /≧/
だいなん /大難/
だいなんかい /第何回/
だいなんじょう /第何条/
だいなんわ /第何話/
だいに /第二/大弐/第２/第2/
だいにいんくらぶ /第二院クラブ/
だいにうちゅうそくど /第二宇宙速度/
だいにかい /第二回/第2回/第2階/
だいにかいはつしつ /第二開発室/
だいにかいはつぶ /第二開発部/
だいにかいめ /第二回目/
だいにかん /第二巻/第二款/
だいにがいこくご /第二外国語/
だいにがくしょう /第二楽章/
だいにきぼう /第二希望/
だいにきょく /第二局/
だいにぎ /第二義/
だいにぎじゅつぶ /第二技術部/
だいにけいひん /第二京浜/
だいにけいひんこくどう /第二京浜国道/
だいにけんきゅうしつ /第二研究室/
だいにこう /第二項/
だいにこうざ /第二講座/
だいにこくどう /第二国道/
だいにごう /第二号/
だいにさく /第二作/
だいにしあい /第二試合/
だいにしゅ /第二種/第2種/
だいにしゅう /第二週/第2週/
だいにしょう /第二章/第2章/
だいにしん /第二審/
だいにしんそつ /第二新卒/
だいにじ /第二次/第2次/
だいにじぎょうぶ /第二事業部/
だいにじさんぎょう /第二次産業/
だいにじせいちょう /第二次性徴;胸が膨らみます/
だいにじせかいたいせん /第二次世界大戦/
だいにじたいせん /第二次大戦/
だいにすいじゅん /第二水準/第２水準/第2水準/
だいにすいじゅんかんじ /第二水準漢字/
だいにせだい /第二世代/
だいにせっけい /第二設計/
だいにせつ /第二節/
だいにたいいくかん /第２体育館/
だいにだん /第二弾/
だいにだんかい /第2段階/
だいにち /大日/
だいにちきょう /大日経;[仏教]大毘盧遮那成仏神変加持経/
だいにちぎん /第二地銀;[新語]第二地方銀行(旧相互銀行など)/
だいにちざかり /大日盛/
だいにちだけ /大日岳/
だいにちにょらい /大日如来/
だいにっぽん /大日本/
だいにっぽんいんさつ /大日本印刷;[企業名]/
だいにっぽんていこく /大日本帝国/
だいにっぽんていこくけんぽう /大日本帝国憲法/
だいにていせい /第二帝政;[世界史]le second Empire(1852-70)/
だいにてん /第二点/
だいにでんでん /第二電電/
だいにとうめい /第二東名/
だいににんしょう /第二人称/
だいにのさんみ /大弐三位;ありま山 ゐなの笹原 風吹けば いでそよ人を 忘れやはする/
だいにはん /第二版/
だいにぶ /第二部/
だいにほうそく /第二法則/
だいにほん /大日本/
だいにほんいんさつ /大日本印刷;[企業名]/
だいにほんかいが /大日本絵画/
だいにほんこもんじょ /大日本古文書/
だいにほんし /大日本史;1657着手、1906完成/
だいにほんちめいじしょ /大日本地名辞書/
だいにほんていこく /大日本帝国/
だいにゅーす /大ニュース/
だいにゅう /代入/
だいにゅうえんざん /代入演算/
だいにゅうえんざんし /代入演算子/
だいにゅうかのう /代入可能/
だいにゅうそうさ /代入操作/
だいにゅうぶん /代入文/
だいにゅうほう /代入法/
だいにゅうれい /代入例/
だいにようそ /第2要素/
だいにりょうしか /第二量子化/
だいにん /代人/大人/代任/
だいにんき /大人気/
だいにんずう /大人数/
だいねっきょう /大熱狂/
だいねっせん /大熱戦/
だいねんぶつ /大念仏/
だいの /大の/
だいのう /大脳/代納/
だいのうかい /大納会/
だいのうはんきゅう /大脳半球/
だいのうひしつ /大脳皮質/
だいのうへんえん /大脳辺縁/
だいのうへんえんけい /大脳辺縁系/
だいのおとこ /大の男/
だいのじ /大の字/
だいのはら /台原/
だいはいきりょう /大排気量/
だいはいきりょうしゃ /大排気量車/
だいはくしゅ /大拍手/
だいはくらんかい /大博覧会/
だいはくりょく /大迫力/
だいはち /大八/
だいはちぐるま /大八車/
だいはちしあい /第八試合/
だいはっかい /大発会/
だいはっけん /大発見/
だいはっせい /大発生/
だいはつこうぎょう /ダイハツ工業;[企業名]/
だいはつねはんぎょう /大般涅槃経;[仏教]Mahaparinirvana-sutra/
だいはつめい /大発明/
だいはどう /大波動/
だいはなびたいかい /大花火大会/
だいはらん /大波乱/
だいはんきょう /大反響/
だいはんせい /大反省/
だいはんたい /大反対/
だいはんたいうんどう /大反対運動/
だいはんてん /大飯店/
だいはんにゃきょう /大般若経;mahaprajna paramita-sutra/
だいば /台場/
だいばーげん /大バーゲン/
だいばいしん /大陪審/
だいばかり /台秤/
だいばくしょう /大爆笑/
だいばくはつ /大爆発/
だいばだった /提婆達多/
だいばってき /大抜擢/
だいばん /台盤/
だいぱにっく /大パニック/
だいひ /大悲/
だいひきゅう /大飛球/
だいひっと /大ヒット/
だいひっときょく /大ヒット曲/
だいひっとさく /大ヒット作/
だいひっとしょうひん /大ヒット商品/
だいひつ /代筆/
だいひつや /代筆屋/
だいひゃっか /大百科/
だいひょう /代表/大兵/
だいひょういいんかい /代表委員会/
だいひょうかく /代表格/
だいひょうかんじ /代表幹事/
だいひょうきょく /代表曲/
だいひょうぐみ /代表組/
だいひょうけい /代表型/
だいひょうけん /代表権/
だいひょうげん /大氷原/代表元/
だいひょうこう /代表校/
だいひょうこうほ /代表候補/
だいひょうさく /代表作/
だいひょうさくひん /代表作品/
だいひょうさんこま /代表産駒/
だいひょうしかく /代表資格/
だいひょうしゃ /代表者/
だいひょうしゃいん /代表社員/
だいひょうしゃかい /代表者会/
だいひょうしょく /代表色/
だいひょうせん /代表戦/代表選/
だいひょうせんしゅ /代表選手/
だいひょうそしょう /代表訴訟/
だいひょうだいこう /代表代行/
だいひょうだん /代表団/
だいひょうち /代表値/
だいひょうちょしゃ /代表著者/
だいひょうてき /代表的/
だいひょうてきさくひん /代表的作品/
だいひょうてきめいばん /代表的名盤/
だいひょうてん /代表点/
だいひょうでんわ /代表電話/
だいひょうでんわばんごう /代表電話番号/
だいひょうとりしまりやく /代表取締役/
だいひょうば /代表馬/
だいひょうばん /大評判/
だいひょうばんごう /代表番号;[略語]代表電話番号/
だいひょうぶ /代表部/
だいひょうめい /代表名/
だいひょうりゅう /大漂流/
だいひょうれい /代表例/
だいひん /代品/
だいひんしゅく /大顰蹙/
だいひんみん /大貧民/
だいびき /代引/代引き/
だいびょういん /大病院/
だいびょうにん /大病人/
だいぴんち /大ピンチ/
だいふ /代父/
だいふぁん /大ファン/
だいふく /大福/
だいふくじ /大福寺/
だいふくちゅう /大腹中/
だいふくちょう /大福帳/
だいふくもち /大福餅/
だいふごう /大富豪/
だいふだ /台札/
だいふっかつ /大復活/
だいふつか /第二日/
だいぶ /大分/大部;大部分。大冊。「たいぶ」とも/大夫/
だいぶーむ /大ブーム/
だいぶいぜん /大分以前/
だいぶきん /台布巾/
だいぶたい /大舞台/大部隊/
だいぶつ /大仏/代物/
だいぶつでん /大仏殿/
だいぶつべんさい /代物弁済/
だいぶつよう /大仏様;[建築] 東大寺南大門など/
だいぶぶん /大部分/
だいぶまえ /大分前/
だいぶむかし /大分昔/
だいぶもん /大部門/
だいぶれいく /大ブレイク/
だいぶん /大分/
だいぶんせつ /大文節/
だいぶんるい /大分類/
だいへいげん /大平原/
だいへいれつ /大並列/
だいへん /代返/
だいへんかく /大変革/
だいへんこう /大変更/
だいへんせい /大編成/
だいへんたい /大編隊/
だいへんどう /大変動/
だいへんらく /大変楽/
だいべん /代弁/大便/大弁;[律令制]弁官/
だいべんき /大便器/
だいべんしゃ /代弁者/
だいべんにん /代弁人/
だいほーる /大ホール/
だいほう /大宝/
だいほうえ /大法会/
だいほうけんせつ /大豊建設;[企業名]/
だいほうし /大法師/
だいほうしゅつ /大放出/
だいほうてい /大法廷/
だいほん /台本/
だいほんえい /大本営/
だいほんえいはっぴょう /大本営発表/
だいほんざん /大本山/
だいほんめい /大本命/
だいぼ /代母/
だいぼいんすいい /大母音推移;great vowel shift/
だいぼう /大坊/
だいぼうけん /大冒険/
だいぼうそう /大暴走/
だいぼうとう /大暴騰/大暴投/
だいぼうどう /大暴動/
だいぼうねんかい /大忘年会/
だいぼうらく /大暴落/
だいぼくじょう /大牧場/
だいぼさつ /大菩薩/
だいぼさつとうげ /大菩薩峠;地名,山梨県/
だいぼしゅう /大募集/
だいま /大間/
だいまおう /大魔王/
だいまきょう /大魔境/
だいまじん /大魔神/大魔人/
だいまる /大丸/
だいまるうめだ /大丸梅田/
だいまるとうきょうてん /大丸東京店/
だいまるまえ /大丸前/
だいまんぞく /大満足/
だいみてい /題未定/
だいみょう /大名/
だいみょうおろし /大名下ろし;[料理]/
だいみょうぎょうれつ /大名行列/
だいみょうじん /大明神/
だいみょうちく /大名竹/
だいみょうどうし /大名同士/
だいみょうやしき /大名屋敷/
だいみょうりょこう /大名旅行/
だいみんていこく /大明帝国/
だいめ /代目/台目/
だいめい /題名/大明/
だいめいきゅう /大迷宮/
だいめいし /代名詞/
だいめいどうし /代名動詞/
だいめいふめい /題名不明/
だいめいぶつ /大名物/
だいめいろ /大迷路/
だいめいわく /大迷惑/
だいめんせき /大面積/
だいもう /大網/
だいもく /題目/
だいもくひょう /大目標/
だいもくみてい /題目未定/
だいもつ /大物/代物/
だいもん /大門/大問;†「試験の-1」/代紋;†やくざの紋章/大紋;†ぬのひたたれ/
だいもんじ /大文字/
だいもんじやき /大文字焼/大文字焼き/
だいもんじやま /大文字山/
だいもんだい /大問題/
だいや /大谷/◆;菱形/◇;菱形/
だいやく /代役/
だいやくしん /大躍進/
だいやくまん /大役満/
だいやるしき /ダイヤル式/
だいゆうかい /大誘拐/
だいゆうざんせん /大雄山線/
だいよう /代用/大葉/大用;大便/
だいようかい /大妖怪/
だいようかのう /代用可能/
だいようかんごく /代用監獄/
だいようかんじ /代用漢字/
だいようさい /大要塞/
だいようしょく /代用食/
だいようひん /代用品/
だいようりょう /大容量/
だいようりょうか /大容量化/
だいよくじょう /大浴場/
だいよげん /大予言/
だいよそう /大予想/
だいよそく /大予測/
だいよっか /第四日/
だいよん /第四/第４/第4/
だいよんかい /第四回/
だいよんかいきゅう /第四階級;プロレタリア/
だいよんかいはつぶ /第四開発部/
だいよんかん /第四款/
だいよんかんひょうき /第四間氷期/
だいよんがくしょう /第四楽章/
だいよんき /第四紀/
だいよんきがく /第四紀学/
だいよんきょうわせい /第四共和制/
だいよんこう /第四項/
だいよんしあい /第四試合/
だいよんしょう /第四章/第4章/
だいよんせつ /第四節/
だいよんばん /第四版/
だいよんぺん /第四辺/
だいよんわくせい /第四惑星/
だいら /平/
だいらく /大楽/
だいらくしょう /大楽勝/
だいらんこう /大乱交/
だいらんせん /大乱戦/
だいらんとう /大乱闘/
だいらんぶ /大乱舞/
だいり /代理/内裏/大理/大利/
だいりーがー /大リーガー/
だいりーぐ /大リーグ/
だいりき /大力/
だいりくれい /大陸令/
だいりけん /代理権/
だいりこうい /代理行為/
だいりさま /内裏様/
だいりしき /内裏式/
だいりしつもん /代理質問/
だいりしゃ /代理者/
だいりしゅっさん /代理出産/
だいりしょう /代理商/
だいりせき /大理石/
だいりせんそう /代理戦争/
だいりせんゆう /代理占有/
だいりてん /代理店/
だいりてんがわ /代理店側/
だいりてんてすうりょう /代理店手数料/
だいりとうこう /代理投稿/
だいりとうひょう /代理投票/
だいりにん /代理人/
だいりはは /代理母/
だいりびな /内裏雛/
だいりぼ /代理母;「だいりはは」とも/
だいりゅうけつ /大流血/
だいりゅうこう /大流行/
だいりょう /大領/代料/
だいりょういき /大領域/
だいりょうはいきしゃかい /大量廃棄社会/
だいりょうふくせい /大量複製/
だいりょこう /大旅行/
だいれん /大連/
だいれんあい /大恋愛/
だいれんごう /大連合/
だいれんさ /大連鎖/
だいれんりつ /大連立/
だいろうさ /大労作/
だいろく /第六/第６/
だいろくしあい /第六試合/
だいろくせだい /第六世代/
だいろくせつ /第六節/
だいろっかい /第六回/第６回/
だいろっかん /第六感/
だいろっき /第六期/
だいろっきょく /第六局/
だいろまん /大浪漫/
だいろんぎ /大論議/
だいろんそう /大論争/
だいわ /大和/台輪/
だいわぎんこう /大和銀行/
だいわく /台枠/
だいわくじょう /台枠上/
だいわくせい /大惑星/
だいわしょうけん /大和証券;[企業名]www.daiwa.co.jp/大和證券;※「大和証券」表記が正式/
だいわだんち /大和団地/
だいわぼうせき /大和紡績/
だいわん /大彎/
だうへいきん /ダウ平均;[経済]Dow-Jones average/
だうん /朶雲;=朶翰(だかん)/
だうんしょう /ダウン症/
だうんろーどはんばい /ダウンロード販売/
だえき /唾液/
だえきせん /唾液腺/
だえん /楕円/橢円;「楕」異体字/橢圓;「楕」異体字,「円」旧字/
だえんうんどう /楕円運動/
だえんがた /楕円型/
だえんきどう /楕円軌道/
だえんきどうじょう /楕円軌道上/
だえんけい /楕円形/楕円型/
だえんこ /楕円弧/
だえんじょう /楕円状/
だえんたい /楕円体/
だえんめん /楕円面/
だおれ /倒れ;「掛け声-」「議論-」/
だか /高/
だかい /打開/
だかいさく /打開策/
だかつ /蛇蝎/蛇蠍;=蛇蝎/
だかん /兌換/蛇管;hose/打感/朶翰/
だかんけん /兌換券/
だかんしへい /兌換紙幣/
だがー /†;dagger/
だがく /打楽/
だがし /駄菓子/
だがしや /駄菓子屋/
だがっき /打楽器/駄楽器;仙波清彦による造語/
だがっきせんもんてん /打楽器専門店/
だがっきそうしゃ /打楽器奏者/
だき /唾棄/舵機/惰気/
だきあわせ /抱き合わせ/
だきごこち /抱き心地/
だきに /荼枳尼/
だきにてん /荼吉尼天/荼枳尼天/
だきにんぎょう /抱き人形/
だきばしら /抱柱/抱き柱/
だきまくら /抱き枕/
だきみょうが /抱茗荷/
だきゅう /打球/
だきゅうかん /打球感/
だきょう /妥協/
だきょうあん /妥協案/
だきょうがた /妥協型/
だきょうてん /妥協点/
だぎょう /ダ行/だ行/
だく /諾/濁/駄句/
だくい /諾意/
だくおん /濁音/
だくおんぷ /濁音符;がぎぐげご、の「゛」/゛/
だくしゅ /濁酒/
だくしょく /濁色;⇔清色/
だくすい /濁水/
だくせ /濁世/
だくせい /濁世/
だくだく /諾々/
だくてん /濁点/゛/
だくどけい /濁度計;turbidimeter/
だくひ /諾否/
だくりゅう /濁流/
だけ /岳/嶽/竹/
だけつ /妥結/
だけん /打鍵/駄犬/
だけんじ /打鍵時/
だけんすう /打鍵数/
だけんそくど /打鍵速度/
だげき /打撃/
だげきけい /打撃系/
だげきけっか /打撃結果/
だげきじん /打撃陣/
だげきせいせき /打撃成績/
だげきせん /打撃戦/
だげきとうしゅ /打撃投手/
だげきふしん /打撃不振/
だげきぶもん /打撃部門/
だげきめん /打撃面/
だげきりょく /打撃力/
だげきれんしゅう /打撃練習/
だげきわざ /打撃技/
だげん /打弦/
だこ /蛸/凧/
だこう /蛇行/
だこうとうてい /打高投低/
だこく /打刻/
だごく /堕獄/
ださ /打差/
ださく /駄作/
ださん /打算/
ださんてき /打算的/
だざい /太宰/堕罪/
だざいおさむ /太宰治/
だざいふ /太宰府;地名,福岡/大宰府;[律令制]/
だざいふてんまんぐう /太宰府天満宮/
だし /出汁/山車/出し/
だしいれ /出し入れ/
だしおしみ /出し惜しみ/
だしかた /出し方/
だしがら /出し殻/
だしこぶ /出し昆布/
だしじゃこ /出し雑魚/
だしじる /出し汁/だし汁/
だしぬけ /出し抜け/
だしまき /出し巻き/
だしまきたまご /出し巻き卵/だし巻き卵/
だしもの /出し物/演し物/
だしゃ /打者/
だしゃすう /打者数/
だしゃそうしゃ /打者走者/
だしゅ /舵手/
だしん /打診/
だじゃく /懦弱/
だじゃれ /駄洒落/
だじゅん /打順/
だじょうかん /太政官/
だじょうかんさつ /太政官札/
だじょうかんにっし /太政官日誌/
だじょうかんふこく /太政官布告/
だじょうだいじん /太政大臣/
だじょうてんのう /太上天皇/
だすう /打数/
だせい /惰性/打製/
だせいしん /惰性心/
だせいせっき /打製石器/
だせいそうこう /惰性走行/
だせいてき /惰性的/
だせき /打席/
だせきすう /打席数/
だせん /打線/
だそく /蛇足/
だそくへん /蛇足編/
だたい /堕胎/だ体;[国語学]だ・であるを用いる文体だ/
だたいざい /堕胎罪/
だたみ /畳/
だだ /駄々/
だだいこ /大太鼓;雅楽の太鼓の一/
だだっこ /駄々っ子/
だだもれ /ダダ漏れ/だだ漏れ/
だだゆき /忠幸/
だち /立ち/太刀/達/逹;「達」異体字/
だちょう /駝鳥/鴕鳥/
だちん /駄賃/
だっ /脱/
だっか /脱化/
だっかい /奪回/脱会/
だっかいさくせん /奪回作戦/
だっかいせん /奪回戦/
だっかく /奪格/
だっかん /奪還/脱簡/
だっき /妲己;中国古代，商の紂王(ちゅうおう)の妃(きさき)/
だっきゃく /脱却/
だっきゅう /脱臼/
だっこ /抱っこ/
だっこう /脱稿/脱肛/
だっこく /脱穀/
だっこくき /脱穀機/
だっこん /脱魂/
だっさい /獺祭/
だっさいき /獺祭忌/
だっさいぎょ /獺祭魚/
だっさん /脱酸/
だっし /脱脂/
だっしにゅう /脱脂乳/
だっしふんにゅう /脱脂粉乳/
だっしめん /脱脂綿/
だっしゅ /奪取/奪首;[新語]首位を奪うこと/
だっしゅう /脱臭/
だっしゅうき /脱臭器/
だっしゅうざい /脱臭剤/
だっしゅつ /脱出/
だっしゅつこう /脱出口/
だっしゅつしゅだん /脱出手段/
だっしゅつじ /脱出時/
だっしゅつそくど /脱出速度/
だっしゅつちょくご /脱出直後/
だっしゅつふかのう /脱出不可能/
だっしゅつほう /脱出法/
だっしゅつほうほう /脱出方法/
だっしょく /脱色/
だっしょくざい /脱色剤/
だっすい /脱水/
だっすいき /脱水機/
だっすいこうか /脱水効果/
だっすいしょう /脱水症/
だっすいしょうじょう /脱水症状/
だっすいそ /脱水素;[化学]dehydrogenation/
だっすいそう /脱水槽/
だっすいそこうそ /脱水素酵素;[生化学]dehydrogenase/
だっすいはんのう /脱水反応/
だっせん /脱線/
だっせんじこ /脱線事故/
だっそ /脱疽/
だっそう /脱走/
だっそうへい /脱走兵/
だったい /脱退/奪胎/
だったいご /脱退後/
だったいほうほう /脱退方法/
だったん /韃靼;Tatar/脱炭;decarbonise/
だっちつ /脱窒;denitrify/
だっちゃく /脱着/
だっちゃくか /脱着可/
だっちゃくしき /脱着式/
だっちょう /脱腸;[医]hernia/脱調;step-out/
だっと /脱兎/
だっとう /脱党/脱刀/
だっぱん /脱藩/
だっぴ /脱皮/
だっぴちゅう /脱皮中/
だっぷん /脱糞/
だっぽう /脱法/
だっぽうこうい /脱法行為/
だつ /脱/奪/獺;かわうそ/妲;妲己/怛;(いたむ)/
だつ> /脱/
だつあにゅうおう /脱亜入欧/
だつあろん /脱亜論;福沢諭吉,1885/
だつい /脱衣/
だついしつ /脱衣室/
だついじょ /脱衣所/
だついじょう /脱衣場/
だつえい /脱営/
だつえん /脱塩/
だつこうちく /脱構築;deconstruction.オタク用語/
だつご /脱誤/脱語/
だつごく /脱獄/
だつごくしゅう /脱獄囚/
だつさら /脱サラ/
だつさんしん /奪三振/
だつさんしんおう /奪三振王/
だつさんしんすう /奪三振数/
だつさんしんりつ /奪三振率/
だつさんそざい /脱酸素剤/
だつしゅりつ /奪取率/
だつじ /脱字/
だつぜい /脱税/
だつぜん /脱然/
だつぞく /脱俗/
だつぶん /脱文/
だつぶんか /脱分化/
だつほうこうい /脱法行為/
だつぼう /脱帽/
だつめい /脱盟/
だつもう /脱毛/
だつもうざい /脱毛剤/
だつもうしょう /脱毛症;[医]/
だつもうほうほう /脱毛方法/
だつらく /脱落/
だつらくしゃ /脱落者/脱落車/
だつり /脱離/
だつりゃく /奪略/奪掠/
だつりゅう /脱硫/
だつりゅうか /脱硫化/
だつりょく /脱力/
だつりょくかん /脱力感/
だつりん /脱輪/
だつろう /脱漏/脱牢/
だて /伊達/立て/建て/館/点;[茶道]/舘;「館」の異体字/
だておとこ /伊達男/
だておんな /伊達女/
だてがた /伊達方/
だてがわ /伊達川/
だてきみこ /伊達公子/
だてしゃ /伊達者/
だてすがた /伊達姿/
だてそうどう /伊達騒動;[日本史]1660-71/
だてどの /伊達殿/
だてまき /伊達巻/伊達巻き/
だてまさむね /伊達政宗/
だてもの /伊達者/
だてもんべつ /伊達紋別/
だてん /打点/
だてんおう /打点王/
だてんし /堕天使/
だでん /打電/
だとう /妥当/打倒/
だとうせい /妥当性/
だな /棚/
だに /壁蝨/谷/駄荷/
だにえるしょ /ダニエル書;[聖書]Daniel(Dan)/
だね /種/
だは /打破/
だはく /打拍/
だば /駄馬/
だひつ /惰筆/
だび /荼毘/
だびらひろ /太平広/
だふや /ダフ屋/だふ屋/
だぶつ /陀仏/
だぶるだがー /‡;doubledagger/
だぶん /駄文/
だべん /駄弁/
だほ /拿捕/
だほう /打法/
だほん /駄本/
だぼう /打棒/
だぼく /打撲/
だぼくしょう /打撲傷/
だぼはぜ /だぼ鯊;-の様な日本人/
だぼら /駄法螺/
だま /玉/球/弾/
だまし /騙し/
だましい /魂/
だましうち /騙し討ち/
だましえ /騙し絵;エッシャーの-/
だましだまし /騙し騙し/
だまり /溜り/
だみ /濃/彩;=濃/
だみえ /濃絵/彩絵/
だみごえ /濁声/ダミ声/だみ声/
だみん /惰眠/
だむこ /ダム湖/
だむだむだん /ダムダム弾;dumdum bullet/
だめ /駄目/溜め/
だめおし /駄目押し/ダメ押し/
だめだし /駄目出し/ダメ出し/
だめづまり /駄目詰まり/駄目詰り;[囲碁]/
だめにんげん /ダメ人間/駄目人間/
だめもと /駄目元;「-で言ってみる」(<駄目で元々)/
だめん /打面/
だもの /駄物/
だより /便り/
だら /鱈/
だらく /堕落/
だらに /陀羅尼/
だりつ /打率/
だりょく /打力/惰力/
だりん /舵輪/
だる /樽/
だるま /達磨/
だるまおとし /達磨落とし/達磨落し/
だるまだいし /達磨大師;Bodhidharma/
だれ /誰/
だれあて /誰宛/
だれか /誰か/
だれかさん /誰かさん/
だれかば /誰カバ/
だれかれ /誰彼/
だれそれ /誰某/
だれだれ /誰誰/誰々/
だれひとり /誰一人/
だれもかも /誰も彼も/
だれもかれも /誰も彼も/
だん /段/談/団/弾/暖/煖;≒暖/断/壇;花壇/檀;白檀/男/椴;とどまつ/騨;飛騨/彈;「弾」の旧字(人名用漢字)/斷;「断」の旧字/團;「団」の旧字(人名用漢字)/旦/灘;(慣用音)/
だん> /団/断;断乳,断穀/
だんあつ /弾圧/彈壓/
だんあつせいじ /弾圧政治/
だんあん /断案/
だんい /段位/
だんいしゅとく /段位取得/
だんいた /段板/
だんいほうしょく /暖衣飽食/
だんいん /団員/
だんいんしかく /団員資格/
だんいんばんごう /団員番号/
だんう /弾雨/
だんうん /断雲/
だんえん /団円/
だんおち /檀越/
だんおつ /檀越/
だんおん /弾音/
だんおんたい /暖温帯/
だんか /檀家/
だんかい /段階/団塊/暖海/
だんかいじゅにあ /団塊ジュニア/
だんかいせだい /団塊世代/
だんかいてき /段階的/
だんかいてきしょうさいか /段階的詳細化/
だんかいのせだい /団塊の世代/
だんかいろしゅつ /段階露出/
だんかん /断簡/段間/
だんかんれいぼく /断簡零墨/
だんがい /断崖/弾劾/彈劾/
だんがいさいばん /弾劾裁判/
だんがいさいばんしょ /弾劾裁判所/
だんがいぜっぺき /断崖絶壁/
だんがん /弾丸/彈丸;「弾」旧字/
だんがんとっきゅう /弾丸特急/
だんがんれっしゃ /弾丸列車/
だんき /暖気/暖機;-運転/断機;孟母-/団旗/弾機;ばね/
だんきうんてん /暖気運転/暖機運転/
だんきゅう /段丘/段級/檀弓/
だんきゅうい /段級位/
だんきろく /団鬼六/
だんきん /弾琴/断金/断琴/
だんぎ /談義/談議/
だんぎょ /団魚/
だんぎり /段切り/
だんぎれ /段切れ/
だんくみ /段組/
だんくん /檀君/
だんぐみ /段組/
だんけい /男系/
だんけつ /団結/
だんけつけん /団結権/
だんけつりょく /団結力/
だんげん /断言/断弦;妻の死/
だんげんてき /断言的;affirmative/
だんこ /断固/断乎/
だんこう /断行;†force.「改革を-する」/団交;[略語]団体交渉/断交;†sever.「隣国と-する」/断口;fracture/
だんこきょひ /断固拒否/
だんここうぎ /断固抗議/
だんこん /男根/弾痕/
だんこんき /男根期;[精医]phallische Phase (Freudの用語)/
だんこんすうはい /男根崇拝/
だんご /団子/
だんごう /談合/
だんごうこうい /談合行為/
だんごうざか /談合坂/
だんごく /暖国/
だんござか /団子坂;地名/
だんごじょう /団子状/
だんごじょうたい /団子状態/
だんごばな /団子鼻/だんご鼻/
だんごむし /団子虫/
だんさ /段差/
だんさい /断裁/
だんさいき /断裁機/
だんざい /断罪/
だんし /男子/談志/檀紙/弾指/弾子/弾糸/断嘴/
だんし> /男子;-ゴルフ,-バレー,-学生/
だんしがくせい /男子学生/
だんしきょう /弾指頃/
だんしけっしょう /男子決勝/
だんしこう /男子校/男子高/
だんしこうこう /男子高校/
だんししゃいん /男子社員/
だんしすいちく /弾糸吹竹/
だんしせいと /男子生徒/
だんしち /団七/
だんしちゅうがくせい /男子中学生/
だんしつ /暖室/煖室/
だんしといれ /男子トイレ/
だんしどうよう /男子同様/
だんしはつ /男子初/
だんしぶ /男子部/
だんしべん /男子便;男子便所のこと/
だんしべんじょ /男子便所/
だんしめい /男子名/
だんしゃ /檀車/
だんしゃく /男爵/
だんしゃくふじん /男爵夫人/
だんしゅ /断酒/断種/断首/檀主/
だんしゅう /男囚/団集/
だんしゅん /暖春/
だんしょ /壇所/
だんしょう /談笑/断章/男娼;aspro/男妾;gigolo/
だんしょうしゅぎ /断章取義/
だんしょく /暖色/男色/
だんしょくけい /暖色系/
だんしよう /男子用/
だんしりょう /男子寮/
だんしん /弾芯/
だんじ /男児/
だんじき /断食/
だんじきづき /断食月/
だんじく /段軸/
だんじくしき /段軸式/
だんじて /断じて/
だんじゅうろう /団十郎/團十郎/
だんじょ /男女/
だんじょいっしょ /男女一緒/
だんじょう /壇上/弾正/
だんじょうだい /弾正台/
だんじょかくさ /男女格差/
だんじょかん /男女間/
だんじょかんけい /男女関係/
だんじょきょうどうさんかくしゃかいきほんほう /男女共同参画社会基本法/
だんじょくべつ /男女区別/
だんじょけっしょう /男女決勝/
だんじょけんよう /男女兼用/
だんじょこうさい /男女交際/
だんじょこようきかいきんとうほう /男女雇用機会均等法/
だんじょこんごう /男女混合/
だんじょこんせい /男女混成/
だんじょさ /男女差/
だんじょさべつ /男女差別/
だんじょとも /男女共/
だんじょどういつちんぎん /男女同一賃金/
だんじょどうけん /男女同権/
だんじょひ /男女比/
だんじょびょうどう /男女平等/
だんじょべつ /男女別/
だんじょもんだい /男女問題/
だんじり /檀尻/
だんすい /断水/
だんすう /段数/弾数/
だんすきょうしつ /ダンス教室/
だんせい /男性/弾性/男声;male voice/
だんせいか /男性化/
だんせいかしゅ /男性歌手/
だんせいがく /男性学/弾性学/
だんせいがた /男性形/
だんせいがっしょう /男声合唱/
だんせいがっしょうだん /男声合唱団/
だんせいがわ /男性側/
だんせいき /男性器/
だんせいきつえんしゃ /男性喫煙者/
だんせいきのう /男性機能/
だんせいきゃく /男性客/
だんせいけい /男性形/弾性系/
だんせいけしょうひん /男性化粧品/
だんせいげんかい /弾性限界/
だんせいこういん /男性行員/
だんせいご /男性語/
だんせいさっか /男性作家/
だんせいさべつ /男性差別/
だんせいさんらん /弾性散乱/
だんせいし /男性誌/
だんせいしゃいん /男性社員/
だんせいしゃかい /男性社会/
だんせいしゃしょう /男性車掌/
だんせいしゅたい /男性主体/
だんせいしょうとつ /弾性衝突/
だんせいしょし /男性諸氏/
だんせいしんり /男性心理/
だんせいじん /男性陣/
だんせいせい /男性性/
だんせいせんよう /男性専用/
だんせいぞう /男性像/
だんせいたい /弾性体/
だんせいてき /男性的/
だんせいは /弾性波/
だんせいばん /弾性板/
だんせいひょう /男性票/
だんせいび /男性美/
だんせいふたり /男性二人/
だんせいほるもん /男性ホルモン/
だんせいむけ /男性向/
だんせいめい /男性名/
だんせいめいし /男性名詞/
だんせいよう /男性用/
だんせいようけしょうひん /男性用化粧品/
だんせいりつ /弾性率;[物理]応力÷歪み距離/
だんせいりょうきん /男性料金/
だんせいりょく /弾性力;[物理]elastic force/
だんせいろん /弾性論/
だんせいわしゃ /男性話者/
だんせん /断線/
だんぜつ /断絶/
だんぜん /断然/
だんぜんにんき /断然人気/
だんそう /断層/男装/弾倉/断想/弾奏/
だんそうがい /断層崖/
だんそうさつえい /断層撮影/
だんそうしゃしん /断層写真/
だんそうせん /断層線/
だんそうほう /断層法/
だんそうめん /断層面/
だんそん /男尊/
だんそんじょひ /男尊女卑/
だんぞう /檀像;白檀・紫檀・栴檀などで作る彫像/
だんぞく /断続/
だんぞくせっさく /断続切削/
だんぞくてき /断続的/
だんぞくへいこうせつ /断続平衡説/
だんたい /団体/暖帯/弾帯/彈帶;旧字/
だんたいうんちん /団体運賃/
だんたいえんぎ /団体演技/
だんたいかん /団体間/
だんたいきゃく /団体客/
だんたいきゃくよう /団体客用/
だんたいきょうぎ /団体競技/
だんたいけんきん /団体献金/
だんたいこうしょう /団体交渉/
だんたいこうしょうけん /団体交渉権/
だんたいこうどう /団体行動/
だんたいこうどうけん /団体行動権/
だんたいせん /団体戦/
だんたいせんよう /団体専用/
だんたいぜんたい /団体全体/
だんたいそうび /団体装備/
だんたいない /団体内/
だんたいほけん /団体保険/
だんたいめい /団体名/
だんたいよう /団体用/
だんたいよやく /団体予約/
だんたいりょうきん /団体料金/
だんたいりょこう /団体旅行/
だんたいりょこうきゃく /団体旅行客/
だんたいりよう /団体利用/
だんたいわく /団体枠/
だんたいわりびき /団体割引/
だんたにさんぎょう /段谷産業;[企業名]/
だんだ /段田/
だんだん /段々/
だんだんばたけ /段々畑/段段畑/
だんち /団地/暖地/
だんちがい /段違い/
だんちがいへいこうぼう /段違い平行棒/
だんちく /葮竹/暖竹/
だんちづま /団地妻/
だんちゃく /弾着/彈着;「弾」旧字/
だんちょう /団長/断腸/
だんちょうだいり /団長代理/
だんてい /断定/
だんていちょう /断定調/
だんていてき /断定的/
だんと /檀徒/
だんとう /暖冬/弾頭/彈頭;旧字/
だんとうだい /断頭台/
だんとつ /断トツ/
だんどう /弾道/彈道;「弾」旧字/
だんどううんどう /弾道運動/
だんどうがく /弾道学/
だんどうだん /弾道弾/
だんどうひこう /弾道飛行/
だんどうみさいる /弾道ミサイル/
だんどり /段取り/
だんな /旦那/檀那;=旦那/
だんなさま /旦那様/
だんなでら /檀那寺/
だんにゅう /断乳;‖サ変名詞[φs]/
だんねつ /断熱/
だんねつざい /断熱材/
だんねつせい /断熱性/
だんねつせいのう /断熱性能/
だんねつふく /断熱服/
だんねつへんか /断熱変化;[熱力学]adiabatic change/
だんねん /断念/
だんのうら /壇ノ浦/
だんばしご /段梯子/
だんばな /段鼻;[建築]階段などの端。滑り止めなどを施します/
だんばん /檀板/
だんぱつ /断髪/
だんぱつしき /断髪式/
だんぱん /談判/
だんびら /段平/
だんぴ /断臂/
だんぴつ /断筆/
だんふみ /檀ふみ/
だんぺん /断片/
だんぺんか /断片化/
だんぺんぐん /断片群/
だんぺんてき /断片的/
だんぺんてきちしき /断片的知識/
だんぼーる /段ボール/
だんぼーるばこ /段ボール箱/
だんぼう /暖房/煖房/
だんぼうき /暖房機/暖房器/
だんぼうきぐ /暖房器具/
だんぼうちゅう /暖房中/
だんぼうひ /暖房費/
だんぼうべんざ /暖房便座/
だんぼうよう /暖房用/
だんまく /弾幕/段幕/彈幕;旧字/
だんまつま /断末魔/断末摩;=断末魔/
だんまり /黙り/
だんみん /断眠/
だんめ /段目/
だんめつ /断滅/
だんめん /断面/
だんめんず /断面図/
だんめんせき /断面積/
だんもの /段物/
だんやく /弾薬/彈藥;「弾」旧字/
だんやくこ /弾薬庫/
だんゆう /男優/
だんゆうしょう /男優賞/
だんらく /段落/談楽/
だんらくかん /段落間/
だんらくめ /段落目/
だんらくめい /段落名/
だんらくわく /段落枠/
だんらん /団欒/団らん/檀欒/
だんりゅう /暖流/団粒/
だんりゅうこうぞう /団粒構造;crumbled structure. ⇔単構造粒/
だんりょく /弾力/
だんりょくせい /弾力性/
だんりょくてき /弾力的/
だんりん /檀林/談林/
だんりんは /談林派/檀林派;=談林派/
だんれいぼう /暖冷房/
だんれつ /断裂/
だんろ /暖炉/煖炉;「煖」のみ旧字/煖爐;旧字/
だんろん /談論/
だんろんふうはつ /談論風発/
だんろんぽう /段論法/
だんわ /談話/
だんわかい /談話会/
だんわご /談話語/
だんわしつ /談話室/
だんわりかい /談話理解/
ち /血/地;†ground/池;†pond/値/知/智/痴;痴呆/癡;「痴」の異体字/蜘;蜘蛛/踟/治/笞;笞刑/致;致死/緻;緻密/輊/遅;遅刻/遲;「遅」の旧字/稚;幼稚/穉;「稚」の異体字/馳;馳走/弛;弛緩/恥;恥部/耻;「恥」の異体字/質;言質/躓;つまず・く/魑;魑魅魍魎/黐;とりもち/置;放置/茅;かや/薙;な・ぐ/乳;胸乳/夂;(すいにょう)/褫;(うばう)/黹;(刺繍)/胝;胼胝/千;千代/家;ぼくん家/夊;?/岻;?/
ちー /吃;[麻雀]/
ちーずやき /チーズ焼き/
ちーちゃ /起家/
ちーほー /地和/
ちーむない /チーム内/
ちーむめい /チーム名/
ちあい /血合/血合い/
ちあき /千晶/千秋/千明/千亜紀/千昌/千章/
ちあゆ /稚鮎/
ちあん /治安/
ちあんいじ /治安維持/
ちあんいじほう /治安維持法/
ちあんかいふく /治安回復/
ちあんかつどう /治安活動/
ちあんきょく /治安局/
ちあんじょう /治安上/
ちあんじょうきょう /治安状況/
ちあんじょうたい /治安状態/
ちあんぶたい /治安部隊/
ちい /地位/地衣/地異/地維/
ちいお /千五百;[古語]たくさん/
ちいき /地域;area/値域;range/
ちいきいりょうしえんびょういん /地域医療支援病院/
ちいきか /地域化/
ちいきかいはつ /地域開発/
ちいきかくさ /地域格差/
ちいきかっせいか /地域活性化/
ちいきかん /地域間/
ちいきがい /地域外/
ちいきがた /地域型/
ちいきくぶん /地域区分/
ちいきけい /地域系/
ちいきけんさく /地域検索/
ちいきげんてい /地域限定/
ちいきげんていはつばい /地域限定発売/
ちいきこゆう /地域固有/
ちいきご /地域語/
ちいきさ /地域差/
ちいきしゃかい /地域社会/
ちいきしゅぎ /地域主義;regionalism/
ちいきしょく /地域色/
ちいきじゅうみん /地域住民/
ちいきじょうほう /地域情報/
ちいきじょうほうけんさく /地域情報検索/
ちいきせい /地域性/
ちいきせいかつ /地域生活/
ちいきせいしん /地域精神/
ちいきそうごかん /地域相互間/
ちいきたんい /地域単位/
ちいきだいひょう /地域代表/
ちいきだんたい /地域団体/
ちいきつうか /地域通貨/
ちいきてき /地域的/
ちいきとくゆう /地域特有/
ちいきない /地域内/
ちいきねつきょうきゅう /地域熱供給/
ちいきばん /地域版/
ちいきふくしけんりようごじぎょう /地域福祉権利擁護事業/
ちいきぶん /地域分/
ちいきぶんか /地域文化/
ちいきぶんぷ /地域分布/
ちいきべつ /地域別/
ちいきほうげん /地域方言/
ちいきほけんほう /地域保健法/
ちいきみっちゃく /地域密着/
ちいきめい /地域名/
ちいきょうてい /地位協定/
ちいく /知育/智育/
ちいこうじょう /地位向上/
ちいさな /小さな/
ちいといつ /七対子/
ちいほ /千五百;[古語]たくさん/
ちいほう /地和/
ちいみ /血忌/
ちいるい /地衣類/
ちいん /知音/
ちうみ /血膿/
ちぇーんてん /チェーン店/
ちぇこすろばきあ /捷克/
ちぇろくみきょく /チェロ組曲/
ちえ /知恵/智恵/智慧/知枝/千絵/知重/千枝/知江/知慧/千重/知衣/千英/知惠/
ちえおくれ /知恵遅れ;retarded/
ちえきけん /地役権/
ちえくらべ /知恵比べ/知恵競べ/
ちえこ /智恵子/千恵子/知恵子/千枝子/
ちえこしょう /智恵子抄/
ちえしゃ /知恵者/
ちえねつ /知恵熱/
ちえのわ /知恵の輪/
ちえぶくろ /知恵袋/
ちえみ /智枝美/智恵美/千恵美/千絵美/智栄美/
ちえもの /知恵者/
ちえり /智恵理/
ちえん /遅延/地縁/
ちえんじかん /遅延時間/
ちえんじょうきょう /遅延状況/
ちえんせん /遅延線/
ちえんは /遅延波/
ちえんひょうか /遅延評価/
ちえんりそく /遅延利息/
ちおも /乳母;[古語]/
ちおや /乳親/
ちおりゅうさん /チオ硫酸/
ちおん /地温/
ちおんいん /知恩院/
ちか /地下;underground/地価;land price/近/治下/値化/千夏/智佳/知夏/知佳/智香/智加/知華/知可/親/
ちか> /地下;-活動,-水脈,-四階/
ちかい /地階/地界/地塊;[地学]crustal block/誓い/近井/知解/邇/
ちかいっかい /地下一階/
ちかうんどう /地下運動/
ちかえき /地下駅/
ちかお /周夫/親雄/知馨夫/
ちかか /地下化/
ちかかこうじ /地下化工事/
ちかかつどう /地下活動/
ちかがい /地下街/
ちかきち /地下基地/
ちかきょく /地下局/
ちかく /知覚/地殻/地核/近く/
ちかくうかん /地下空間/
ちかくかてい /知覚過程/
ちかくかん /地下区間/
ちかくきこう /知覚機構/
ちかくくうかん /知覚空間/
ちかくこうぞう /地殻構造/
ちかくしょり /知覚処理/
ちかくしんけい /知覚神経/
ちかくしんりがく /知覚心理学/
ちかくじょう /知覚上/
ちかくせい /知覚性/
ちかくぞう /知覚像/
ちかくてき /知覚的/
ちかくどうし /知覚動詞/
ちかくないよう /知覚内容/
ちかくのうりょく /知覚能力/
ちかくへんどう /地殻変動/
ちかくまひ /知覚麻痺;[医]anesthesia/
ちかけい /地下茎/
ちかけいざい /地下経済/
ちかけん /地下権;[法]/
ちかげ /千影;名/
ちかこ /千賀子/千香子/睦子/智香子/知可子/ちか子/千加子/智加子/千嘉子/渠睦子/
ちかこうじ /地価公示/
ちかごと /誓言/
ちかごろ /近頃/
ちかざわ /近澤/
ちかし /近し/迩/
ちかしげん /地下資源/
ちかしつ /地下室/
ちかしゃこ /地下車庫/
ちかしょくどう /地下食堂/
ちかじか /近々/
ちかすい /地下水/
ちかすいみゃく /地下水脈/
ちかずみ /近角/
ちかせかい /地下世界/
ちかせん /地下線/
ちかぜい /地価税/
ちかぜいほう /地価税法/
ちかそうこ /地下倉庫/
ちかそしき /地下組織/
ちかだ /近田/
ちかちゅうしゃじょう /地下駐車場/
ちかちょうさ /地価調査/
ちかぢか /近々/
ちかって /誓って/
ちかつうろ /地下通路/
ちかてつ /地下鉄/
ちかてつあさしおばし /地下鉄朝潮橋/
ちかてついけぶくろえき /地下鉄池袋駅/
ちかてつえき /地下鉄駅/
ちかてつえんしん /地下鉄延伸/
ちかてつかくせん /地下鉄各線/
ちかてつきょうつう /地下鉄共通/
ちかてつぎんざせん /地下鉄銀座線/
ちかてつくかん /地下鉄区間/
ちかてつこうじ /地下鉄工事/
ちかてつしゃない /地下鉄車内/
ちかてつせん /地下鉄線/
ちかてつたにまちせん /地下鉄谷町線/
ちかてつつるまいせん /地下鉄鶴舞線/
ちかてつでんしゃ /地下鉄電車/
ちかてつとうざいせん /地下鉄東西線/
ちかてつはくぶつかん /地下鉄博物館/
ちかてつひがしやません /地下鉄東山線/
ちかてつめいじょうせん /地下鉄名城線/
ちかてつもう /地下鉄網/
ちかてつれんらくつうろ /地下鉄連絡通路/
ちかてつろせん /地下鉄路線/
ちかどう /地下道/
ちかどうくつ /地下洞窟/
ちかば /近場/
ちかひろ /近広/近廣/
ちかぶぶん /地下部分/
ちかぼち /地下墓地/
ちかま /近間/
ちかまつ /近松/
ちかまつもんざえもん /近松門左衛門;(1653-1724)歌舞伎・浄瑠璃脚本家。『曾根崎心中』/
ちかまわり /近回り/
ちかみち /近道/
ちかめ /近目/
ちかやま /近山/
ちかよう /地下用/
ちかよくせい /地価抑制/
ちから /力/税/主税/千賀良/
ちからいがい /力以外/
ちからいし /力石/
ちからいっぱい /力一杯/
ちからいと /力糸/
ちからおとし /力落とし/力落し/
ちからかげん /力加減/
ちからかんけい /力関係/
ちからがみ /力紙/
ちからがわ /力革/
ちからくらべ /力比べ/力競べ;辞書的表記/
ちからこぶ /力瘤/力こぶ/
ちからさ /力差/
ちからしごと /力仕事/
ちからじこく /力時刻/
ちからじまん /力自慢/
ちからずく /力ずく/力尽く;力まかせ、強引/
ちからずもう /力相撲/
ちからせいぎょ /力制御/
ちからせいぶん /力成分/
ちからぞえ /力添え/
ちからだけ /力竹/
ちからだのみ /力頼み/
ちからだめし /力試し/
ちからづよい /力強い/
ちからてき /力的/
ちからぬけ /力抜け/
ちからぶそく /力不足/
ちからまかせ /力任せ/
ちからまけ /力負け/
ちからみず /力水/
ちからもち /力持ち/力餅/力持/
ちからわざ /力技/力業/
ちかれんらくつうろ /地下連絡通路/
ちかろう /地下牢/
ちかろせん /地下路線/
ちかん /痴漢/置換/弛緩;しかん/地官;六官の一つ/遅緩;slow/
ちかんぐん /置換群/
ちかんこうい /痴漢行為/
ちかんご /置換後/
ちかんし /置換子/
ちかんはんのう /置換反応/
ちかんめい /置換名/
ちかんもじ /置換文字/
ちかんもじれつ /置換文字列/
ちが /千賀/違/
ちがい /稚貝/地外/違い/
ちがいだな /違い棚/
ちがいほうけん /治外法権/
ちがえ /違え/
ちがく /地学/
ちがくざっし /地学雑誌/
ちがくしつ /地学室/
ちがくぶ /地学部/
ちがさき /茅ヶ崎/
ちがさきし /茅ヶ崎市/
ちがっか /地学科/
ちがや /茅/
ちき /知己/稚気/稙/飭/
ちきしょう /畜生/
ちきゅう /地球/恥丘/
ちきゅうおんだんか /地球温暖化/
ちきゅうかがく /地球科学/地球化学;geochemistry/
ちきゅうかんきょう /地球環境/
ちきゅうかんきょうてき /地球環境的/
ちきゅうかんそくえいせい /地球観測衛星/
ちきゅうがい /地球外/
ちきゅうがいせいぶつ /地球外生物/
ちきゅうがいせいめい /地球外生命/
ちきゅうがた /地球型/
ちきゅうがたわくせい /地球型惑星;terrestrial planet/
ちきゅうがわ /地球側/
ちきゅうきこう /地球紀行/
ちきゅうきどうじょう /地球軌道上/
ちきゅうきぼ /地球規模/
ちきゅうぎ /地球儀/
ちきゅうぐん /地球軍/
ちきゅうけい /地球系/
ちきゅうけんきゅう /地球研究/
ちきゅうこく /地球国/
ちきゅうさいご /地球最後/
ちきゅうさいだい /地球最大/
ちきゅうさみっと /地球サミット/
ちきゅうしつりょう /地球質量/
ちきゅうしみん /地球市民/
ちきゅうしゃ /地球社/
ちきゅうしょう /地球照;[天文]earthshine/
ちきゅうしんりゃく /地球侵略/
ちきゅうじかん /地球時間/
ちきゅうじき /地球磁気;geomagnetism/
ちきゅうじしん /地球自身/
ちきゅうじば /地球磁場/
ちきゅうじょう /地球上/
ちきゅうじん /地球人/
ちきゅうじんどうし /地球人同士/
ちきゅうせい /地球製/
ちきゅうせいじん /地球星人/
ちきゅうせいふく /地球征服/
ちきゅうせいめい /地球生命/
ちきゅうせん /地球船/
ちきゅうぜんたい /地球全体/
ちきゅうたいき /地球大気/
ちきゅうちゅうしんかく /地球中心核/
ちきゅうていこく /地球帝国/
ちきゅうてき /地球的/
ちきゅうでんじき /地球電磁気/
ちきゅうどけい /地球時計/
ちきゅうはつ /地球発/
ちきゅうはんけい /地球半径/
ちきゅうぶつり /地球物理/
ちきゅうぶつりがく /地球物理学/
ちきゅうぶつりがっか /地球物理学科/
ちきゅうほうこう /地球方向/
ちきゅうほうしゃ /地球放射/
ちきゅうぼうえい /地球防衛/
ちきゅうぼうえいぐん /地球防衛軍/
ちきゅうみさき /地球岬/
ちきゅうりゅうたい /地球流体/
ちきゅうれんぽう /地球連邦/
ちきゅうれんぽうぐん /地球連邦軍/
ちきゅうわくせいぶつり /地球惑星物理/
ちきゅうわくせいぶつりがく /地球惑星物理学/
ちきょう /地峡/
ちきょうだい /乳兄弟/
ちきん /遅筋;slow muscle. =赤筋/
ちぎ /地祇;天神-/遅疑;hesitate.「-逡巡」/千木;[建築]社殿の屋根飾り/知木;=千木/鎮木;=千木/杠/
ちぎょ /稚魚/池魚/
ちぎょう /知行/
ちぎょうしょ /知行所/
ちぎょうち /知行地/
ちぎり /契り/契/千切/
ちぎれぐも /千切れ雲/
ちぎん /地銀;[略語]地方銀行/
ちく /地区/築/竹/畜;家畜/蓄;貯蓄/馳駆/筑;筑後/逐;放逐/矗;そびえる/
ちく> /築;築年数,(建築後の年数)築３年,(建築時期)築S60/
ちくあん /竹安/
ちくい /築井/
ちくいち /逐一/
ちくおんき /蓄音機/
ちくかん /竹簡/地区間/竹竿/
ちくきょう /地区協/
ちくきん /竹琴;楽器/
ちくけん /畜犬/
ちくご /筑後;福岡県南部/築後;建築後/逐語/
ちくごがわ /筑後川/
ちくごてき /逐語的/
ちくごやく /逐語訳/
ちくさ /千種/
ちくさく /千種区/竹柵/
ちくさつ /畜殺/
ちくさん /畜産/
ちくさんぎょう /畜産業/
ちくさんしけんじょう /畜産試験場/
ちくさんのうか /畜産農家/
ちくざい /竹材/蓄財/
ちくし /筑紫/竹紙/竹枝/
ちくしぐち /筑紫口/
ちくしじ /筑紫路/
ちくしてつや /筑紫哲也/
ちくしの /筑紫野/
ちくしゃ /畜舎/
ちくしゅ /畜主/
ちくしゅい /地区首位/
ちくしゅう /筑州;筑前・筑後/
ちくしょう /畜生/蓄妾/
ちくしょうどう /畜生道/
ちくじ /逐次/
ちくじか /逐次化/
ちくじかんこうぶつ /逐次刊行物/
ちくじがた /逐次型/
ちくじきんじ /逐次近似/
ちくじけいさん /逐次計算/
ちくじげんご /逐次言語/
ちくじこうひょう /逐次公表/
ちくじしょり /逐次処理/
ちくじじっこう /逐次実行/
ちくじせい /逐次性/
ちくじてき /逐次的/
ちくじにゅうりょく /逐次入力/
ちくじひょうか /逐次評価/
ちくじへんかん /逐次変換/
ちくじょう /築城/築上/逐条/
ちくじれんらく /逐次連絡/
ちくせき /蓄積/
ちくせきがた /蓄積型/
ちくせきそうち /蓄積装置/
ちくせん /地区戦/
ちくぜん /筑前/竹善/
ちくぜんに /筑前煮/
ちくぜんびわ /筑前琵琶/
ちくそう /竹槍/竹窓/竹叢/
ちくぞう /築造/蓄蔵/
ちくたいかい /地区大会/
ちくだいひょう /地区代表/
ちくちく /矗々/
ちくてい /築堤/築庭/
ちくてん /逐電/
ちくでん /蓄電/逐電/
ちくでんき /蓄電器/
ちくでんち /蓄電池/
ちくとうぼくせつ /竹頭木屑/
ちくない /地区内/
ちくなんねん /築何年/
ちくねつ /蓄熱/
ちくねつしき /蓄熱式/
ちくねん /逐年/
ちくねんすう /築年数/
ちくのう /蓄膿/
ちくのうしょう /蓄膿症/
ちくは /竹葉/
ちくはく /竹帛/
ちくば /竹馬/
ちくひ /竹皮/竹扉/
ちくひせん /筑肥線/
ちくび /乳首/
ちくふじん /竹夫人/
ちくべつ /地区別/
ちくほ /筑穂/
ちくほう /筑豊/
ちくほうたんでん /筑豊炭田/
ちくほうちほう /筑豊地方/
ちくほうでんてつ /筑豊電鉄/
ちくほうほんせん /筑豊本線/
ちくま /筑摩/
ちくまがわ /千曲川/
ちくましょぼう /筑摩書房;[出版社名]/
ちくめい /地区名/
ちくゆうしょう /地区優勝/
ちくよう /畜養/
ちくよせん /地区予選/
ちくら /千倉/
ちくりん /竹林/
ちくりんしょうじゃ /竹林精舎;釈迦の最初の僧院/
ちくるい /畜類/
ちくれい /蓄冷;-剤/
ちくれいざい /蓄冷剤/
ちくれいねつ /蓄冷熱/
ちくろく /逐鹿/
ちくわ /竹輪/
ちくわふ /竹輪麩/
ちくわぶ /竹輪麩;[料理]穴開き麩/
ちくん /治勲/
ちぐ /痴愚;stupid/値遇;めぐりあい/智愚;賢さと愚かさ/知愚;=智愚/
ちぐう /知遇/値遇;=ちぐ/
ちぐさ /千種/千草/乳草/
ちぐさいろ /千草色/
ちぐさく /千種区/
ちぐしん /痴愚神/
ちぐしんらいさん /痴愚神礼讃;Moriae encomium, 1511, Erasmus/
ちけい /地形/智計;知謀/地景/笞刑/
ちけいがく /地形学/
ちけいこうか /地形効果/
ちけいず /地形図/
ちけいてき /地形的/
ちけっとだい /チケット代/
ちけむり /血煙/
ちけん /知見/治験/地検;[略語]地方検察庁/知県/地圏/地券/智見/治権/智剣/
ちけんしゃ /地権者/
ちけんやく /治験薬/
ちげなべ /チゲ鍋/
ちこう /遅効/恥垢/地溝/知行/地皇/地窖/
ちこうごういつ /知行合一/
ちこうごういつせつ /知行合一説/
ちこうしひょう /遅行指標/
ちこうせい /遅効性/
ちこうせいひりょう /遅効性肥料;[園芸]/
ちこうふう /地衡風/
ちこうりゅう /地衡流/
ちこく /遅刻/治国/
ちこくげんきん /遅刻厳禁/
ちこくしどう /遅刻指導/
ちこくしゃ /遅刻者/
ちこつ /恥骨/
ちこつけつごうえん /恥骨結合炎/
ちご /稚児/児/乳児/稚子/
ちごものがたり /稚児物語/
ちさ /智佐/千沙/知砂/
ちさい /地裁/
ちさき /地先/
ちさく /千咲/
ちさこ /千佐子/知紗子/
ちさと /千里/
ちさん /治山/地産/遅参/治産/
ちさんちしょう /地産地消;[新語]地元で生産・地元で消費/
ちざい /知財;[略語]知的財産/笞罪/
ちざいけん /知財権/
ちざいこうさい /知財高裁;[略語]知的財産高等裁判所/
ちざいぶ /知財部/
ちざけ /血酒;ハブの-,スッポンの-/
ちし /致死/地誌;地域の文化/地史;地質学的歴史/智歯/致仕/
ちしいでんし /致死遺伝子;[生物]lethal gene/
ちしお /血潮/血汐/
ちしがく /地史学;geohistory/
ちしき /知識/智識/
ちしきいがい /知識以外/
ちしきかいきゅう /知識階級/
ちしきかがく /知識科学/
ちしきがく /知識学;Wissenschaftslehre/
ちしきぎのう /知識技能/
ちしきげん /知識源/
ちしきこうがく /知識工学/
ちしきこうがくてき /知識工学的/
ちしきこうぞう /知識構造/
ちしきしゃかいがく /知識社会学;Wissenssoziologie/
ちしきしゅうやくてき /知識集約的/
ちしきしゅどうがた /知識主導型/
ちしきしょり /知識処理/
ちしきじょうほうこうがく /知識情報工学/
ちしきじょうほうしょり /知識情報処理/
ちしきじん /知識人/
ちしきすいじゅん /知識水準/
ちしきそう /知識層/
ちしきたいけい /知識体系/
ちしきとう /知識等/
ちしきひょうげん /知識表現/
ちしきぶそく /知識不足/
ちしきべーす /知識ベース/
ちしきほうふ /知識豊富/
ちしきよく /知識欲/
ちしきりょう /知識量/
ちしせい /致死性/
ちしつ /地質/知悉/
ちしつがく /地質学/
ちしつがくてき /地質学的/
ちしつこうぞう /地質構造;[地学]tectonics/
ちしつじだい /地質時代;geologic time/
ちしつちょうさ /地質調査/
ちしつちょうさしょ /地質調査所/
ちしつねんだい /地質年代/
ちしてき /致死的/
ちしぶき /血飛沫/血しぶき/
ちしま /千島/
ちしまかいりゅう /千島海流/
ちしまざさ /千島笹/
ちしまれっとう /千島列島/
ちしゃ /知者/智者/治者;ruler/萵苣;lettuce/痴者;fool/苣/
ちしょ /地所/
ちしょう /地消/致傷/池沼/治承/知将/智将/地象/
ちしょうりょく /致傷力/
ちしりつ /致死率/
ちしりょう /致死量/
ちしる /乳汁/
ちしろ /千代/
ちしん /地心;geocentric/池心;池の真ん中/
ちしんじ /遅進児;「知恵遅れ」のニュートラルな言い換え語。cf.発達障害/
ちじ /知事/
ちじき /地磁気/
ちじきかんそくしょ /地磁気観測所/
ちじく /地軸/
ちじしつ /知事室/
ちじしょう /知事賞/
ちじせん /知事選/
ちじせんきょ /知事選挙/
ちじつ /遅日/
ちじゅつ /治術/
ちじゅんほう /置閏法/
ちじょ /痴女;[卑]/
ちじょう /地上/痴情/笞杖/
ちじょうい /知情意/
ちじょうえ /地上絵/
ちじょうえき /地上駅/
ちじょうきょく /地上局/
ちじょうくかん /地上区間/
ちじょうけい /地上茎/
ちじょうけん /地上権/
ちじょうこうげき /地上攻撃/
ちじょうこうげきよう /地上攻撃用/
ちじょうさいきょう /地上最強/
ちじょうさいだい /地上最大/
ちじょうしせつ /地上施設/
ちじょうせい /地上性/
ちじょうせつび /地上設備/
ちじょうせん /地上戦/地上線/
ちじょうは /地上波/
ちじょうはほうそう /地上波放送/
ちじょうぶ /地上部/
ちじょうぶたい /地上部隊/
ちじょうぶつ /地上物/
ちじょうぶぶん /地上部分/
ちじょうほうそう /地上放送/
ちじょうぼうえんきょう /地上望遠鏡/
ちじょうよう /地上用/
ちじょうわざ /地上技/
ちじょく /恥辱/
ちじん /知人/地人/痴人;idiot/地神/
ちじんかんけい /知人関係/
ちじんたく /知人宅/
ちじんたち /知人達/
ちすい /治水/池水/
ちすいかふう /地水火風/
ちすじ /血筋/
ちすわ /千須和/
ちず /地図/智頭/千寿/
ちずか /地図化/
ちずきゅうこう /智頭急行/
ちずこ /千鶴子/千寿子/知寿子/
ちずしき /地図式/
ちずじょう /地図上/
ちずじょうほう /地図情報/
ちずせん /智頭線/
ちずちょう /地図帳/
ちずてき /地図的/
ちずてつどう /智頭鉄道/
ちずてん /地図店/
ちずや /地図屋/
ちせ /知世/
ちせい /知性/地勢/治世/痴性/
ちせいか /知性化/
ちせいかせんそう /知性化戦争/
ちせいがく /地政学/
ちせいがくてき /地政学的/
ちせいじん /知性人;Homo sapiens/
ちせいたい /知性体/
ちせいてき /知性的/
ちせいは /知性派/
ちせき /地積;土地の面積/治績;政治の実績/
ちせこ /智勢子/
ちせつ /稚拙/
ちそ /地租/
ちそう /地層;stratum/馳走/地相;土地のありさま/
ちそかいせい /地租改正;[日本史]1873/
ちそく /遅速/知足/
ちぞめ /血染め/
ちた /知多/
ちたい /地帯/遅滞/痴態/
ちたいかん /地対艦/
ちたいくう /地対空/
ちたいち /地対地/
ちたいりょく /地耐力/
ちたぐん /知多郡/
ちたし /知多市/
ちたつ /遅達/笞撻/
ちたね /千種/
ちたねく /千種区/
ちたはんとう /知多半島/
ちたび /千度/
ちたん /Ti/Titanium/
ちだ /千田/
ちだい /地代/
ちだいやちん /地代家賃/
ちだまり /血溜まり/血溜り/
ちだらけ /血だらけ/
ちだるま /血達磨/血だるま/血ダルマ/
ちち /父/乳/遅々/義父/致知/
ちち> /父;父猫,父鹿,父デュマ(Dumas pere)/
ちちいろ /乳色/
ちちうえ /父上/
ちちうし /乳牛/
ちちおや /父親/
ちちおやさんかん /父親参観/
ちちおやじしん /父親自身/
ちちおやぞう /父親像/
ちちおやに /父親似/
ちちおやゆらい /父親由来/
ちちかた /父方/
ちちがた /父方/
ちちぎみ /父君/
ちちくさ /乳草/
ちちくび /乳首/
ちちこ /父子/父娘/
ちちこしょうひ /父子消費/
ちちご /父御/
ちちしぼり /乳搾り/
ちちしる /乳汁/
ちちじま /父島/
ちちとこ /父と子;Ottsy i deti,1862,Trugenev/
ちちなしご /父無し子/
ちちのひ /父の日;六月の第三日曜日/
ちちはる /斉斉哈爾/
ちちばなれ /乳離れ/
ちちぶ /秩父/
ちちぶさん /秩父山/
ちちぶし /秩父市/
ちちぶてつどう /秩父鉄道/
ちちぶのみや /秩父宮/
ちちまつ /千々松/
ちちむすめ /父娘/
ちちもみ /乳揉み/
ちちゃく /遅着/
ちちゅう /地中/
ちちゅうか /地中化/
ちちゅうかい /地中海/
ちちょう /地調/
ちぢ /千々/
ちぢみ /縮/縮み/
ちぢみおり /縮織/
ちぢれ /縮れ/
ちぢれげ /縮れ毛/
ちぢわ /千々石/
ちっか /窒化/
ちっかい /蟄懐/
ちっかこう /窒化鋼/
ちっかぶつ /窒化物/
ちっかん /竹簡/竹竿/
ちっかんもん /竹管文/
ちっきょ /蟄居/
ちっこう /築港/
ちっこうせん /築港線/
ちっし /窒死/
ちっそ /窒素/N/Nitrogen/
ちっそがす /窒素ガス/
ちっそく /窒息/
ちっそくし /窒息死/
ちっそこんごう /窒素混合/
ちっそさんかぶつ /窒素酸化物/
ちっそじゅうてん /窒素充填/
ちっそぶんあつ /窒素分圧/
ちっと /些と/
ちっとも /些とも/
ちっぷく /蟄伏/
ちっぷべつ /秩父別/
ちつ /膣;vagina/帙;本の覆い/秩;秩序/窒;窒素/蟄;啓蟄/腟;「膣」の異体字/
ちついり /帙入り/
ちつえん /膣炎;[医]vaginitis/
ちつがいしゃせい /膣外射精/
ちつけいれん /膣痙攣/
ちつじょ /秩序/
ちつじょいじ /秩序維持/
ちつせん /膣栓/
ちつづき /血続き/
ちつない /膣内/
ちつないしゃせい /膣内射精/
ちつぶんぴつえき /膣分泌液/
ちつへき /膣壁/
ちつみ /千津美/
ちづ /地図/
ちづか /千束/
ちづこ /千鶴子/
ちづる /千鶴/
ちてい /地底/
ちていこ /地底湖/
ちていじん /地底人/
ちてき /知的/
ちてきかつどう /知的活動/
ちてきかつどうしえん /知的活動支援/
ちてききょうみ /知的興味/
ちてきこうきしん /知的好奇心/
ちてきさぎょう /知的作業/
ちてきざいさん /知的財産/
ちてきざいさんけん /知的財産権/
ちてきざいさんこうとうさいばんしょ /知的財産高等裁判所/
ちてきしげき /知的刺激/
ちてきしゅうだん /知的集団/
ちてきしょうがい /知的障害/
ちてきしょうがいしゃ /知的障害者/
ちてきしょゆうけん /知的所有権/
ちてきしょり /知的処理/
ちてきじょうほうしょり /知的情報処理/
ちてきせいさん /知的生産/
ちてきせいめい /知的生命/
ちてきせいめいたい /知的生命体/
ちてきたんきゅう /知的探求/
ちてきにんしき /知的認識/
ちてきのうりょく /知的能力/
ちてきび /知的美/
ちてきふごうか /知的符号化/
ちてつ /地鉄/
ちてん /地点/
ちてんかん /地点間/
ちてんし /智天使;cherubim/
ちてんじょう /血天井/
ちと /少と/些と/
ちとく /知得/地徳/
ちとせ /千歳/千登世/
ちとせあめ /千歳飴/
ちとせからすやま /千歳烏山/
ちとせせん /千歳線/
ちとせづる /千歳鶴/
ちとせばし /千登世橋/
ちとせふなばし /千歳船橋/
ちどう /治道/
ちどうせつ /地動説/
ちどめ /血止め/
ちどり /千鳥/鵆/
ちどりあし /千鳥足/
ちどりがふち /千鳥ヶ淵/
ちどりそうこう /千鳥走行/
ちどりちょう /千鳥町/
ちどりはふ /千鳥破風;[建築]/
ちどりばし /千鳥橋/
ちどん /遅鈍/
ちな /知名/
ちなつ /千夏/
ちなみ /因/
ちなみに /因みに/
ちにく /血肉/
ちにち /知日/
ちにちは /知日派/
ちねつ /地熱/
ちねつはつでん /地熱発電/
ちねん /知念/
ちの /茅野/千野/
ちのあせ /血の汗;-流せ/
ちのあめ /血の雨;-を降らせる/
ちのいけ /血の池;地獄名物/
ちのう /知能/智能/
ちのうか /知能化/
ちのうかつどう /知能活動/
ちのうけい /知能系/
ちのうけんさ /知能検査/
ちのうしすう /知能指数/
ちのうしょうがい /知能障害/
ちのうしょうがいしゃ /知能障害者/
ちのうじょうほう /知能情報/
ちのうじょうほうしょり /知能情報処理/
ちのうていど /知能程度/
ちのうてき /知能的/
ちのうてすと /知能テスト/
ちのうねんれい /知能年齢;mental age/
ちのうはん /知能犯/
ちのうみ /血の海/
ちのえき /茅野駅/
ちのけ /血の気/
ちのし /茅野市/
ちのしお /地の塩;[キリスト教]「あなたがたは-である」/
ちのなみだ /血の涙/
ちのね /茅根/
ちのみご /乳飲み子/乳飲み児/乳呑み児/
ちのめぐり /血の巡り;-が悪い/
ちのり /血糊/地の利/
ちのわ /茅の輪/
ちはい /遅配/
ちはつ /遅発/薙髪/
ちはや /千早/
ちはやじょう /千早城/
ちはら /千原/茅原/
ちはらい /遅払い/
ちはる /千春/智春/
ちはん /池畔/
ちば /千葉/地場/
ちばいちりつ /千葉市立/
ちばえき /千葉駅/
ちばかん /千葉間/
ちばがわ /千葉側/
ちばきゅうこう /千葉急行/
ちばきゅうこうせん /千葉急行線/
ちばけん /千葉県/
ちばけんじん /千葉県人/
ちばけんたいかい /千葉県大会/
ちばけんみん /千葉県民/
ちばこうぎょうだいがく /千葉工業大学/
ちばこうだい /千葉工大/
ちばし /千葉市/
ちばししゃ /千葉支社/
ちばたいかい /千葉大会/
ちばだい /千葉大/
ちばだいがく /千葉大学/
ちばちゅうおう /千葉中央/
ちばな /知花/
ちばなれ /乳離れ/
ちばばん /千葉版/
ちばひがし /千葉東/
ちばひがしこうこう /千葉東高校/
ちばほうめん /千葉方面/
ちばん /地番/
ちひ /地被;-植物/
ちひしょくぶつ /地被植物;ground cover/
ちひつ /遅筆/
ちひょう /地表/
ちひょうじょう /地表上/
ちひょうすい /地表水/
ちひょうは /地表波/
ちひょうめん /地表面/
ちひろ /千尋/千裕/千紘/知宏/馳浩/
ちびっこ /ちびっ子/
ちふすきん /チフス菌/
ちふみ /千文/
ちふゆ /千冬/
ちぶ /恥部/知夫/
ちぶくら /乳脹/
ちぶくろ /血袋/乳袋/
ちぶさ /乳房/
ちぶつ /地物/地球物理/
ちぶつけん /地物研/
ちへい /地平/治平/
ちへいせん /地平線/
ちへいめん /地平面/
ちへど /血反吐/
ちへん /地変/
ちべっとご /チベット語/
ちべっとじん /チベット人/
ちべっとぶっきょう /チベット仏教/
ちべん /智辯/
ちほ /地歩/千穂/智保/
ちほう /地方/痴呆/
ちほうえんせい /地方遠征/
ちほうか /痴呆化/
ちほうかいさい /地方開催/
ちほうかいじょう /地方会場/
ちほうかん /地方官/
ちほうがわ /地方側/
ちほうきゅうじょう /地方球場/
ちほうきょく /地方局/
ちほうぎかい /地方議会/
ちほうぎょうせい /地方行政/
ちほうぎょうせいきかん /地方行政機関/
ちほうぎんこう /地方銀行/
ちほうく /地方区/
ちほうくうこう /地方空港/
ちほうけいば /地方競馬/
ちほうけんさつちょう /地方検察庁/
ちほうこう /地方校/
ちほうこうえいきぎょう /地方公営企業/
ちほうこうえいきぎょうほう /地方公営企業法/
ちほうこうきょうだんたい /地方公共団体/
ちほうこうぎょう /地方興行/
ちほうこうせいほごいいんかい /地方更生保護委員会/
ちほうこうつうせん /地方交通線/
ちほうこうふぜい /地方交付税/
ちほうこうふぜいこうふきん /地方交付税交付金/
ちほうこうむいん /地方公務員/
ちほうこうむいんほう /地方公務員法/
ちほうこくりつだいがく /地方国立大学/
ちほうご /地方語/
ちほうごうぞく /地方豪族/
ちほうごと /地方毎/
ちほうさ /地方差/
ちほうさい /地方債/
ちほうさいばんしょ /地方裁判所/
ちほうざいせい /地方財政/
ちほうざいせいほう /地方財政法/
ちほうし /地方紙/地方誌/
ちほうしぶんぶきょく /地方支分部局/
ちほうしゅっしん /地方出身/
ちほうしょう /痴呆症/
ちほうしょうひぜい /地方消費税/
ちほうしょく /地方色/
ちほうしんぶん /地方新聞/
ちほうじ /地方時/
ちほうじち /地方自治/
ちほうじちたい /地方自治体/
ちほうじちほう /地方自治法/
ちほうじむしょ /地方事務所/
ちほうじゅんぎょう /地方巡業;ドサ回り/
ちほうじょうたい /痴呆状態/
ちほうせい /地方性/
ちほうせいふ /地方政府/
ちほうせん /地方選/地方線/
ちほうせんきょ /地方選挙/
ちほうぜい /地方税/
ちほうぜいほう /地方税法/
ちほうぜいりつ /地方税率/
ちほうそしき /地方組織/
ちほうたいかい /地方大会/
ちほうだいがく /地方大学/
ちほうだいひょう /地方代表/
ちほうだんたい /地方団体/
ちほうつうしん /地方通信/
ちほうてき /地方的/
ちほうてつどう /地方鉄道/
ちほうてつどうほう /地方鉄道法/
ちほうとくさんひん /地方特産品/
ちほうとし /地方都市/
ちほうどう /地方道/
ちほうどくとく /地方独特/
ちほうば /地方馬/
ちほうばん /地方版/
ちほうぶん /地方分/
ちほうぶんけん /地方分権/
ちほうべつ /地方別/
ちほうめい /地方名/
ちほうめん /地方面/
ちほうりょこう /地方旅行/
ちほうれんらくぶ /地方連絡部/
ちほうろうどういいんかい /地方労働委員会/
ちほうろせん /地方路線/
ちぼう /智謀/知謀/
ちぼしん /地母神/
ちまき /粽/茅巻;=粽/茅巻き;=粽/千巻;(織機の部品名)/千巻き/粡;<rare> =粽/
ちまた /巷/岐;分かれ道/衢;=巷/
ちまつり /血祭り/血祭/
ちまなこ /血眼/
ちまみれ /血塗れ/血まみれ/
ちまめ /血豆/
ちみ /地味/魑魅/
ちみち /血道/
ちみつ /緻密/
ちみどろ /血みどろ/
ちみもうりょう /魑魅魍魎/
ちみゃく /地脈/
ちみん /治民/
ちむさーちょい /尖沙咀/
ちむら /地村/
ちめい /地名/知名;-度/致命;fatal/知命;50歳/
ちめいしょう /致命傷/
ちめいじてん /地名辞典/地名事典/
ちめいてき /致命的/
ちめいてきけっかん /致命的欠陥/
ちめいてきけってん /致命的欠点/
ちめいてきじゃくてん /致命的弱点/
ちめいど /知名度/
ちもう /恥毛/
ちもく /地目/
ちもじ /血文字/
ちもよう /血模様/
ちゃ /茶/咤;(呉音) 叱咤(しった)/
ちゃ> /茶;茶懐石,茶褐色,茶靴/
ちゃーしゅー /焼豚/叉焼/
ちゃーしゅーめん /叉焼麺/チャーシュー麺/
ちゃーたーき /チャーター機/
ちゃーたーびん /チャーター便/
ちゃーはん /炒飯/
ちゃーめん /炒麺/
ちゃあはん /炒飯/
ちゃいなふく /チャイナ服/
ちゃいれ /茶入/
ちゃいろ /茶色/
ちゃいろじ /茶色地/
ちゃいろとそう /茶色塗装/
ちゃう /茶宇/
ちゃうけ /茶請け/
ちゃうじま /茶宇縞/
ちゃうす /茶臼/
ちゃうすやま /茶臼山/
ちゃえん /茶園/茶圓;姓,「円」旧字/
ちゃお /找/
ちゃおず /餃子/
ちゃか /茶菓/茶化;(当て字) -す/
ちゃかい /茶会/
ちゃかっしょく /茶褐色/
ちゃかぶき /茶香服;[茶道]/茶歌舞伎;[茶道]/
ちゃがし /茶菓子/
ちゃがま /茶釜/
ちゃがゆ /茶粥/
ちゃがら /茶殻/
ちゃき /茶器/茶木/
ちゃきん /茶巾/
ちゃきんしぼり /茶巾絞り/
ちゃく /着/嫡/摘/
ちゃくい /着衣/着意/
ちゃくいえい /着衣泳/
ちゃくえき /着駅/
ちゃくかくにん /着確認/
ちゃくがい /着外/
ちゃくがん /着眼;-点/着岸;arrival/
ちゃくがんちゅう /着岸中/
ちゃくがんてん /着眼点/
ちゃくこう /着工/
ちゃくごえ /着声;[新語](携帯電話の)合成音声による着信音。ウザい/
ちゃくさ /着差/
ちゃくさい /着彩/嫡妻/
ちゃくざ /着座/
ちゃくざいち /着座位置/
ちゃくし /嫡子/
ちゃくしつ /嫡室/
ちゃくしゅ /着手/
ちゃくしゅつ /嫡出/
ちゃくしゅつし /嫡出子/
ちゃくしょう /着床/
ちゃくしょうぜんしんだん /着床前診断/
ちゃくしょうまえしんだん /着床前診断/
ちゃくしょく /着色/
ちゃくしょくよう /着色用/
ちゃくしょくりょう /着色料/
ちゃくしん /着信/
ちゃくしんおん /着信音/
ちゃくしんかいせん /着信回線/
ちゃくしんがわ /着信側/
ちゃくしんきょひ /着信拒否/
ちゃくしんしょり /着信処理/
ちゃくしんせってい /着信設定/
ちゃくしんりれき /着信履歴;携帯の-/
ちゃくじ /着磁/
ちゃくじこく /着時刻/
ちゃくじつ /着実/
ちゃくじゅん /着順/
ちゃくじゅんけいじばん /着順掲示板/
ちゃくすい /着水/
ちゃくせい /着生/
ちゃくせいこん /着生根/
ちゃくせき /着席/
ちゃくせきりつ /着席率/
ちゃくせつ /着雪/
ちゃくせん /着船/
ちゃくそう /着想/着装/
ちゃくそん /嫡孫/
ちゃくたい /着帯/
ちゃくだつ /着脱/
ちゃくだつかのう /着脱可能/
ちゃくだつしき /着脱式/
ちゃくだん /着弾/着彈;「弾」旧字/
ちゃくだんてん /着弾点/
ちゃくち /着地/
ちゃくちじ /着地時/
ちゃくちてん /着地点/
ちゃくちゃく /着々/着着/
ちゃくてい /着挺/
ちゃくてん /着点/
ちゃくでん /着電/
ちゃくとう /着到/
ちゃくなん /嫡男/
ちゃくに /着荷/
ちゃくにん /着任/
ちゃくにんしき /着任式/
ちゃくにんじ /着任時/
ちゃくはつ /着発/
ちゃくば /着馬/
ちゃくばらい /着払い/着払/
ちゃくひつ /着筆/
ちゃくひょう /着氷/
ちゃくふく /着服/
ちゃくぼ /嫡母/
ちゃくぼう /着帽/
ちゃくみ /茶くみ/
ちゃくめろ /着メロ/
ちゃくもく /着目/
ちゃくよう /着用/
ちゃくようぎむ /着用義務/
ちゃくようぎむか /着用義務化/
ちゃくようしゃ /着用者/
ちゃくようふか /着用不可/
ちゃくようりつ /着用率/
ちゃくりく /着陸/
ちゃくりくき /着陸機/
ちゃくりくしんにゅう /着陸進入/
ちゃくりくちょくぜん /着陸直前/
ちゃくりくてじゅん /着陸手順/
ちゃくりくふのう /着陸不能/
ちゃくりくりょう /着陸料;landing fee/
ちゃくりゅう /嫡流/
ちゃぐ /茶具/
ちゃけ /茶家/
ちゃこうろ /茶香炉/
ちゃこし /茶漉し/
ちゃさじ /茶匙/
ちゃしつ /茶室/
ちゃしぶ /茶渋/
ちゃしゃく /茶杓/
ちゃじ /茶事/
ちゃじしちしき /茶事七式;[茶道]/
ちゃじゅ /茶寿;108歳/
ちゃじゅう /茶頭/
ちゃじん /茶人/
ちゃせき /茶席/
ちゃせん /茶筅/茶筌/茶せん/
ちゃたく /茶托/
ちゃたてむし /茶立虫/茶柱虫/茶立て虫/
ちゃたん /北谷/
ちゃだい /茶代/
ちゃだな /茶棚/
ちゃだんす /茶箪笥/
ちゃちゃ /茶々/茶茶/
ちゃちゃまる /茶々丸/
ちゃっか /着火/着果;bearing. 「-不良」/着荷/着花;flowering/
ちゃっかそうち /着火装置/
ちゃっかてん /着火点/
ちゃっかん /着艦/
ちゃっきりぶし /ちゃっきり節;(昭和)/
ちゃっきん /着金/
ちゃっけん /着剣/
ちゃっこ /着呼/
ちゃっこう /着工/着香/
ちゃっこうだんかい /着工段階/
ちゃっこうりょう /着香料/
ちゃつう /茶通/
ちゃつぼ /茶壺/茶壷;異体字/
ちゃつみ /茶摘み/
ちゃづけ /茶漬/茶漬け/
ちゃづつ /茶筒/
ちゃてい /茶庭/
ちゃてん /茶店/
ちゃとう /茶湯/
ちゃどう /茶道/
ちゃどうぐ /茶道具/
ちゃどころ /茶所/
ちゃない /茶内/
ちゃにわ /茶庭/
ちゃのこ /茶の子;茶菓子/
ちゃのはら /茶之原/
ちゃのほん /茶の本;The Book of Tea,1906,岡倉天心/
ちゃのま /茶の間/
ちゃのみ /茶飲み/
ちゃのみともだち /茶飲み友達/
ちゃのみばなし /茶飲み話/
ちゃのゆ /茶の湯/
ちゃはる /察哈爾/
ちゃば /茶葉/
ちゃばおり /茶羽織/
ちゃばこ /茶箱/
ちゃばこだて /茶箱点て/
ちゃばしら /茶柱/
ちゃばたけ /茶畑/茶畠/
ちゃばな /茶花/
ちゃばなし /茶話/
ちゃばね /茶羽/
ちゃばら /茶腹/
ちゃばん /茶番/
ちゃばんげき /茶番劇/
ちゃぱつ /茶髪/
ちゃびん /茶瓶/
ちゃぶ /卓袱;zhuofu/
ちゃぶうとう /茶封筒/
ちゃぶくろ /茶袋;teabag/
ちゃぶだい /卓袱台/
ちゃぷすい /雑砕/
ちゃほ /茶舗/
ちゃぼうき /茶箒/
ちゃぼうず /茶坊主/
ちゃま /茶魔/
ちゃまめ /茶豆/
ちゃみ /茶味/茶美/茶見/
ちゃみず /茶水/
ちゃみせ /茶店/
ちゃめ /茶目/
ちゃめし /茶飯/
ちゃめっけ /茶目っ気/
ちゃや /茶屋/
ちゃやま /茶山/
ちゃやまだい /茶山台/
ちゃやまち /茶屋町/
ちゃやみち /茶屋道/
ちゃわ /茶話/
ちゃわん /茶碗/
ちゃわんたけ /茶碗茸/
ちゃわんむし /茶碗蒸し/茶碗蒸/
ちゃんご /杖鼓;Korean Hourglass Drum/
ちゃんすー /江蘇/Jiangsu/
ちゃんすう /昌洙/
ちゃんた /全帯/
ちゃんづけ /ちゃん付け/
ちやこ /千夜子/
ちゅ /丶/
ちゅーれんぱおとう /九連宝燈;[麻雀]1112345678999/九連宝灯/
ちゅう /中/注/宙/虫/昼/忠/駐;駐在/註;註釈/柱/誅;天誅/紂;殷の暴君/酎;焼酎/肘;掣肘/籌/躊;躊躇/儔;(ともがら)/鋳;鋳造/鑄;「鋳」の旧字(人名用漢字)/疇;範疇/畴;「疇」の異体字/仲/沖/冲;「沖」の異体字/衷;折衷/惆;(うらむ)/稠;稠密/綢/厨;厨房/廚;「厨」の異体字/丑;うし/紐;ひも/抽;抽出/紬;つむぎ/冑;甲冑/胄;胄子/冢;≒塚/籀/鍮;真鍮/寵;(呉音)/蟲;「虫」の旧字/晝;「昼」の旧字(人名用漢字)/※;こめじるし/
ちゅう# /中#0/中#2/
ちゅう> /中/駐/
ちゅうあい /忠愛/
ちゅうあいてんのう /仲哀天皇/
ちゅうあつ /中厚/
ちゅうい /注意/中尉/中位/
ちゅういかんき /注意喚起/
ちゅういがき /注意書き/
ちゅういがく /中医学/
ちゅういき /中域/
ちゅういぎむ /注意義務/
ちゅういしょ /注意書/
ちゅういしんごう /注意信号/
ちゅういじこう /注意事項/
ちゅういじんぶつ /注意人物/
ちゅういすう /中位数/
ちゅういち /中一/忠一/中１/中1/
ちゅういてん /注意点/
ちゅういてんとう /注意点等/
ちゅういひょうじ /注意表示/
ちゅういぶん /注意文/
ちゅういほう /注意報/
ちゅういほうかいじょ /注意報解除/
ちゅういほうほう /注意方法/
ちゅういりょく /注意力/
ちゅういりょくぶそく /注意力不足/
ちゅういん /中陰/
ちゅうう /中有/
ちゅうえい /中衛/中映/
ちゅうえつせんそう /中越戦争/
ちゅうおう /中央/中欧/紂王/
ちゅうおうあじあ /中央アジア/
ちゅうおうあめりか /中央アメリカ/
ちゅうおういいんかい /中央委員会/
ちゅうおういり /中央入/
ちゅうおうえき /中央駅/
ちゅうおうおろしうりしじょう /中央卸売市場/
ちゅうおうかいそくせん /中央快速線/
ちゅうおうかん /中央館/
ちゅうおうかんこうせん /中央緩行線/
ちゅうおうかんじょうせん /中央環状線/
ちゅうおうかんちょう /中央官庁/
ちゅうおうがい /中央街/
ちゅうおうがくいん /中央学院/
ちゅうおうがた /中央型/
ちゅうおうがわ /中央側/
ちゅうおうきょういくしんぎかい /中央教育審議会/
ちゅうおうきょく /中央局/
ちゅうおうきんこ /中央金庫/
ちゅうおうぎけん /中央技研/
ちゅうおうぎんこう /中央銀行/
ちゅうおうく /中央区/
ちゅうおうぐち /中央口/
ちゅうおうぐちてん /中央口店/
ちゅうおうぐん /中央軍/
ちゅうおうけいば /中央競馬/
ちゅうおうけいばかい /中央競馬会/
ちゅうおうけいばじょう /中央競馬場/
ちゅうおうけん /中央研/
ちゅうおうけんきゅうしょ /中央研究所/
ちゅうおうけんきゅうじょ /中央研究所/
ちゅうおうこうえん /中央公園/
ちゅうおうこうせいほごしんさかい /中央更生保護審査会/
ちゅうおうこうそく /中央高速/
ちゅうおうこうぞうせん /中央構造線/
ちゅうおうこうろん /中央公論/
ちゅうおうこうろんしゃ /中央公論社/
ちゅうおうさいせん /中央西線/
ちゅうおうした /中央下/
ちゅうおうしゃせん /中央車線/
ちゅうおうしゅうけん /中央集権/
ちゅうおうしゅうけんたいせい /中央集権体制/
ちゅうおうしゅうけんてき /中央集権的/
ちゅうおうしゅうちゅうがた /中央集中型/
ちゅうおうしゅっぱん /中央出版;[出版社名]/
ちゅうおうしょいん /中央書院;[出版社名]/
ちゅうおうしょうぎょう /中央商業/
ちゅうおうしょうちょう /中央省庁/
ちゅうおうしょうめん /中央正面/
ちゅうおうしょくどう /中央食堂/
ちゅうおうしょりそうち /中央処理装置/
ちゅうおうしんかんせん /中央新幹線/
ちゅうおうじどうしゃどう /中央自動車道/
ちゅうおうじゅうてんそっこう /中央重点測光/
ちゅうおうじょうほうきょく /中央情報局/
ちゅうおうせいふ /中央政府/
ちゅうおうせん /中央線/
ちゅうおうせんえんせん /中央線沿線/
ちゅうおうせんかいそく /中央線快速/
ちゅうおうせんない /中央線内/
ちゅうおうたい /中央帯/
ちゅうおうだい /中央大/
ちゅうおうだいがく /中央大学/
ちゅうおうだいがくすぎなみこうこう /中央大学杉並高校/
ちゅうおうち /中央値/
ちゅうおうちょう /中央町/
ちゅうおうつうろ /中央通路/
ちゅうおうでんし /中央電子/
ちゅうおうとう /中央党/
ちゅうおうとしょかん /中央図書館/
ちゅうおうとっかい /中央特快/
ちゅうおうとっぱ /中央突破/
ちゅうおうどう /中央道/
ちゅうおうどうはちおうじ /中央道八王子/
ちゅうおうどうろ /中央道路/
ちゅうおうにっぽう /中央日報/
ちゅうおうはつでん /中央発電/
ちゅうおうば /中央馬/
ちゅうおうばし /中央橋/
ちゅうおうばしょ /中央場所/
ちゅうおうひがしせん /中央東線/
ちゅうおうひょうじゅんじ /中央標準時/
ちゅうおうひろば /中央広場/
ちゅうおうふきん /中央付近/
ちゅうおうぶ /中央部/
ちゅうおうぶぶん /中央部分/
ちゅうおうぶんりたい /中央分離帯/
ちゅうおうほんせん /中央本線/
ちゅうおうみゃく /中央脈/
ちゅうおうゆうびんきょく /中央郵便局/
ちゅうおうよこ /中央横/
ちゅうおうよせ /中央寄せ/
ちゅうおうりん /中央輪/
ちゅうおうりんかん /中央林間/
ちゅうおうりんかんえき /中央林間駅/
ちゅうおうろうどういいんかい /中央労働委員会/
ちゅうおし /中押し;[囲碁]投了による終局/中押;[囲碁]/
ちゅうおしがち /中押し勝ち/
ちゅうおん /中温/中音/
ちゅうおんいき /中音域/
ちゅうか /中華/中夏/鋳貨/
ちゅうかい /仲介/注解/厨芥/鋳塊/
ちゅうかいぎしつ /中会議室/
ちゅうかいぎょうしゃ /仲介業者/
ちゅうかいしゃ /仲介者/
ちゅうかいてすうりょう /仲介手数料/
ちゅうかいてんいき /中回転域/
ちゅうかいぼうえき /仲介貿易;三国間貿易/
ちゅうかいやく /仲介役/
ちゅうかいりょう /仲介料/
ちゅうかがい /中華街/
ちゅうかがし /中華菓子/
ちゅうかく /中核/中隔/
ちゅうかくし /中核市;NB:人口30万人以上 (<地方自治法)/
ちゅうかくじぎょう /中核事業/
ちゅうかくてき /中核的/
ちゅうかくは /中核派/
ちゅうかけん /中華圏/
ちゅうかこうくう /中華航空/
ちゅうかざいりょう /中華材料/
ちゅうかざんまい /中華三昧/
ちゅうかしそう /中華思想/
ちゅうかじんみんきょうわこく /中華人民共和国/
ちゅうかすーぷ /中華スープ/
ちゅうかそば /中華蕎麦/
ちゅうかっこ /中括弧/｛/｝/［;大括弧?/］/中かっこ/
ちゅうかどん /中華丼/
ちゅうかどんぶり /中華丼/
ちゅうかなべ /中華鍋/
ちゅうかはん /中華飯/
ちゅうかひ /中果皮/
ちゅうかふう /中華風/
ちゅうかべんとう /中華弁当/
ちゅうかまんじゅう /中華饅頭/
ちゅうかみんこく /中華民国/中華民國/
ちゅうかみんぞく /中華民族/
ちゅうかめん /中華麺/
ちゅうかや /中華屋/
ちゅうから /中辛/
ちゅうかりょうり /中華料理/
ちゅうかりょうりてん /中華料理店/
ちゅうかりょうりや /中華料理屋/
ちゅうかん /中間/昼間/中巻/中環/中缶/忠諫/中浣;月の中旬/中澣;=中浣/
ちゅうかん> /中間;-考査,-生成物,-ファイル/
ちゅうかんいち /中間位置/
ちゅうかんえき /中間駅/
ちゅうかんおん /中間音/
ちゅうかんかいきゅう /中間階級/
ちゅうかんかいさつ /中間改札/
ちゅうかんかいそう /中間階層/
ちゅうかんかそく /中間加速/
ちゅうかんかんりしょく /中間管理職/
ちゅうかんがくしょう /中間楽章/
ちゅうかんがた /中間型/
ちゅうかんぎ /中間木/
ちゅうかんけっか /中間結果/
ちゅうかんけっさん /中間決算/
ちゅうかんけん /中間圏/
ちゅうかんげんご /中間言語/
ちゅうかんこう /中間項/
ちゅうかんこうさ /中間考査/
ちゅうかんさくしゅ /中間搾取/
ちゅうかんざい /中間財;[経済]intermediary goods/
ちゅうかんし /中間子/
ちゅうかんしけん /中間試験/
ちゅうかんしせつ /中間施設/
ちゅうかんしゃ /中間車/
ちゅうかんしゅうけい /中間集計/
ちゅうかんしゅうはすう /中間周波数/
ちゅうかんしょく /中間色/
ちゅうかんしょり /中間処理/
ちゅうかんしんこく /中間申告/
ちゅうかんしんさ /中間審査/
ちゅうかんじんこう /昼間人口/
ちゅうかんせいさんぶつ /中間生産物/
ちゅうかんせいせいぶつ /中間生成物;[化学]intermediate/
ちゅうかんせんきょ /中間選挙/
ちゅうかんそう /中間層/
ちゅうかんたい /中間体;[化学]intermediate/昼間帯;⇔夜間帯/中間態;[言語]middle voice/
ちゅうかんだいしゃ /中間台車/
ちゅうかんだな /中間棚/
ちゅうかんだんかい /中間段階/
ちゅうかんち /中間値/
ちゅうかんちてん /中間地点/
ちゅうかんちょう /中間調/
ちゅうかんていど /中間程度/
ちゅうかんてき /中間的/
ちゅうかんてすと /中間テスト/
ちゅうかんてん /中間点/
ちゅうかんとう /中間棟/
ちゅうかんとうしん /中間答申/
ちゅうかんとびら /中間扉/
ちゅうかんはいせん /中間配線/
ちゅうかんはいとう /中間配当/
ちゅうかんはっぴょう /中間発表/
ちゅうかんはっぴょうかい /中間発表会/
ちゅうかんはんけつ /中間判決/
ちゅうかんひょうげん /中間表現/
ちゅうかんぶ /中間部/
ちゅうかんへんすう /中間変数/
ちゅうかんほうこく /中間報告/
ちゅうかんほうこくしょ /中間報告書/
ちゅうかんほうこくてき /中間報告的/
ちゅうかんほうじん /中間法人/
ちゅうがい /中外/虫害/
ちゅうがいいがくしゃ /中外医学社/
ちゅうがいせいやく /中外製薬;[企業名]/
ちゅうがえり /宙返り/
ちゅうがく /中学/
ちゅうがくいらい /中学以来/
ちゅうがくえいご /中学英語/
ちゅうがくきょうし /中学教師/
ちゅうがくくらい /中学位/
ちゅうがくこうこう /中学高校/
ちゅうがくこうこうじだい /中学高校時代/
ちゅうがくこうちょう /中学校長/
ちゅうがくじだい /中学時代/
ちゅうがくじゅけん /中学受験/
ちゅうがくせい /中学生/
ちゅうがくせいあいて /中学生相手/
ちゅうがくせいいじょう /中学生以上/
ちゅうがくせいとかい /中学生徒会/
ちゅうがくせいばん /中学生版/
ちゅうがくそつぎょう /中学卒業/
ちゅうがくにゅうし /中学入試/
ちゅうがくにゅうしもんだい /中学入試問題/
ちゅうがくねん /中学年;小3-4/
ちゅうがくぶ /中学部/
ちゅうがた /中型/中形/
ちゅうがたいじょう /中型以上/
ちゅうがたか /中型化/
ちゅうがたき /中型機/
ちゅうがたぎょ /中型魚/
ちゅうがたけん /中型犬/
ちゅうがたげんてい /中型限定/
ちゅうがたしゃ /中型車/
ちゅうがたにりん /中型二輪/
ちゅうがたにりんめんきょ /中型二輪免許/
ちゅうがためんきょ /中型免許/
ちゅうがっこう /中学校/
ちゅうがっこういらい /中学校以来/
ちゅうがっこうじだい /中学校時代/
ちゅうがん /中観/
ちゅうがんは /中観派/
ちゅうき /中期/注記/駐機/中気/註記;=注記/抽気;-タービン/
ちゅうき> /中期;(midterm)-計画,-展望,-国債/
ちゅうきこくさい /中期国債/
ちゅうきさくひん /中期作品/
ちゅうきじょう /駐機場/
ちゅうきち /中吉/忠吉/
ちゅうきてき /中期的/
ちゅうきぼ /中規模/
ちゅうきぼうず /中規模渦/
ちゅうきゅう /中級/誅求/仲弓;冉雍/
ちゅうきゅうき /中級機/
ちゅうきゅうしゃ /中級者/
ちゅうきゅうしゃむけ /中級者向/
ちゅうきゅうしゃよう /中級者用/
ちゅうきゅうていど /中級程度/
ちゅうきゅうひん /中級品/
ちゅうきゅうへん /中級編/
ちゅうきょう /中京/中共/中凶/
ちゅうきょうかいさい /中京開催/
ちゅうきょうく /中京区/
ちゅうきょうけいばじょう /中京競馬場/
ちゅうきょうしば /中京芝/
ちゅうきょうしん /中教審;[略語]中央教育審議会/
ちゅうきょうじょしだいがく /中京女子大学/
ちゅうきょうだい /中京大/
ちゅうきょうだいがく /中京大学/
ちゅうきょうだいがくきょうじゅ /中京大学教授/
ちゅうきょうちく /中京地区/
ちゅうきょうてんのう /仲恭天皇/
ちゅうきょく /中曲/
ちゅうきょり /中距離/
ちゅうきょりきょうそう /中距離競走;[陸上]800m~1500m/
ちゅうきょりしゅもく /中距離種目/
ちゅうきょりだしゃ /中距離打者/
ちゅうきょりでんしゃ /中距離電車/
ちゅうきょりば /中距離馬/
ちゅうきん /駐禁;[略語]駐車禁止/鋳金/忠勤/
ちゅうきんせい /中近世/
ちゅうきんとう /中近東/
ちゅうきんとうしょこく /中近東諸国/
ちゅうぎ /忠義/
ちゅうぎがお /忠義顔/
ちゅうぎだて /忠義立て/
ちゅうぎょ /虫魚/
ちゅうぎんじょう /中吟醸/
ちゅうくう /中空/宙空/
ちゅうくうこうぞう /中空構造/
ちゅうくうしまく /中空糸膜/
ちゅうくらい /中位/中くらい/
ちゅうくん /忠君/
ちゅうくんあいこく /忠君愛国/
ちゅうぐう /中宮/
ちゅうぐん /中郡/
ちゅうけい /中継/中計/中啓;(扇)/仲兄/中繼;「継」旧字/
ちゅうけいき /中継器/
ちゅうけいきょく /中継局/
ちゅうけいけい /中継系/
ちゅうけいけん /中継権/
ちゅうけいしゃ /中継車/中継者/
ちゅうけいしゅうりょう /中継終了/
ちゅうけいしんごうき /中継信号機/
ちゅうけいじ /中継時/
ちゅうけいじょ /中継所/
ちゅうけいち /中継地/
ちゅうけいちてん /中継地点/
ちゅうけいてん /中継点/
ちゅうけいは /中継波/
ちゅうけいぼうえき /中継貿易/
ちゅうけん /中堅/忠犬/中研/
ちゅうけんきぎょう /中堅企業/
ちゅうけんしゃいん /中堅社員/
ちゅうけんしゅ /中堅手/
ちゅうけんほ /駐建保/
ちゅうげきじょう /中劇場/
ちゅうげん /中元/中原/忠言/中言/中間/
ちゅうこ /中古/中戸/
ちゅうこう /中高/中公;[企業名][略語]中央公論(社)/中興;「-の祖」/忠孝/中耕/鋳鋼/昼光;daylight.「-色」/昼行;dirunal.⇔夜行/
ちゅうこうあいぞうばん /中公愛蔵版/
ちゅうこういき /中高域/
ちゅうこういっかんこう /中高一貫校/
ちゅうこうおんいき /中高音域/
ちゅうこうかいさん /中興開山/
ちゅうこうきゅう /中高級/
ちゅうこうぎしつ /中講義室/
ちゅうこうしょく /昼光色/
ちゅうこうしんしょ /中公新書/
ちゅうこうせい /中高生/昼行性/鋳鋼製/
ちゅうこうそう /中高層;-ビル,-住居専用地域/
ちゅうこうそく /中高速/
ちゅうこうねん /中高年/
ちゅうこうねんそう /中高年層/
ちゅうこうのそ /中興の祖/
ちゅうこうびん /昼行便/
ちゅうこうぶんこ /中公文庫/
ちゅうこうもく /中項目/
ちゅうこうれっしゃ /昼行列車/
ちゅうこかかく /中古価格/
ちゅうこき /中古機/
ちゅうこぎょうしゃ /中古業者/
ちゅうこく /忠告/
ちゅうこくふぁんど /中国ファンド/
ちゅうここうにゅう /中古購入/
ちゅうこご /中古語/
ちゅうこしじょう /中古市場/
ちゅうこしじょうかかく /中古市場価格/
ちゅうこしゃ /中古車/
ちゅうこしゃざっし /中古車雑誌/
ちゅうこしゃはんばい /中古車販売/
ちゅうこしゃはんばいてん /中古車販売店/
ちゅうこしゃや /中古車屋/
ちゅうこしゃりょう /中古車両/
ちゅうこせんもんてん /中古専門店/
ちゅうこそうば /中古相場/
ちゅうこだい /中古台/
ちゅうこてん /中古店/
ちゅうこばん /中古盤/
ちゅうこばんや /中古盤屋/
ちゅうこひん /中古品/
ちゅうこぶっけん /中古物件/
ちゅうこぶひん /中古部品/
ちゅうこぶひんや /中古部品屋/
ちゅうこぶんがく /中古文学;平安時代頃の文学/
ちゅうこや /中古屋/
ちゅうこん /中根/
ちゅうごく /中国/中國/
ちゅうごくいがい /中国以外/
ちゅうごくうんなんしょう /中国雲南省/
ちゅうごくえいが /中国映画/
ちゅうごくえんせい /中国遠征/
ちゅうごくか /中国化/
ちゅうごくかがくいん /中国科学院/
ちゅうごくかんじ /中国漢字/
ちゅうごくかんたいじ /中国簡体字/
ちゅうごくがっき /中国楽器/
ちゅうごくがわ /中国側/
ちゅうごくき /中国旗/
ちゅうごくきょうさんとう /中国共産党/
ちゅうごくぎんこう /中国銀行/
ちゅうごくぐん /中国軍/
ちゅうごくぐんみん /中国軍民/
ちゅうごくけい /中国系/
ちゅうごくけん /中国拳/
ちゅうごくこくない /中国国内/
ちゅうごくこくみん /中国国民/
ちゅうごくこくみんとう /中国国民党/
ちゅうごくこっきょう /中国国境/
ちゅうごくご /中国語/
ちゅうごくごしょしんしゃ /中国語初心者/
ちゅうごくごにゅうりょく /中国語入力/
ちゅうごくごばん /中国語版/
ちゅうごくごふう /中国語風/
ちゅうごくごよう /中国語用/
ちゅうごくさん /中国産/
ちゅうごくさんち /中国山地/
ちゅうごくざんりゅうこじ /中国残留孤児/
ちゅうごくし /中国史/
ちゅうごくしき /中国式/
ちゅうごくしじょう /中国市場/中国史上/
ちゅうごくしぶ /中国支部/
ちゅうごくしょ /中国書/
ちゅうごくしんぶん /中国新聞/
ちゅうごくしんりゃく /中国侵略/
ちゅうごくじどうしゃどう /中国自動車道/
ちゅうごくじゅうかんどう /中国縦貫道/
ちゅうごくじん /中国人/
ちゅうごくじんがくせい /中国人学生/
ちゅうごくじんがわ /中国人側/
ちゅうごくじんみん /中国人民/
ちゅうごくせい /中国製/
ちゅうごくせいいき /中国西域/
ちゅうごくせいねん /中国青年/
ちゅうごくせいふ /中国政府/
ちゅうごくせいふにんてい /中国政府認定/
ちゅうごくせいほう /中国西方/
ちゅうごくせき /中国籍/
ちゅうごくせんせいじゅつ /中国占星術/
ちゅうごくぜんど /中国全土/
ちゅうごくたいりく /中国大陸/
ちゅうごくちほう /中国地方/
ちゅうごくちゃ /中国茶;白茶,烏龍茶など/
ちゅうごくちゅうおうせいふ /中国中央政府/
ちゅうごくてき /中国的/
ちゅうごくてつがく /中国哲学/
ちゅうごくでんりょく /中国電力;[企業名]/
ちゅうごくとうき /中国陶器/
ちゅうごくどう /中国道/
ちゅうごくどくりつ /中国独立/
ちゅうごくない /中国内/
ちゅうごくないぶ /中国内部/
ちゅうごくなんぶ /中国南部/
ちゅうごくのうみん /中国農民/
ちゅうごくはっこう /中国発行/
ちゅうごくばん /中国版/
ちゅうごくびじん /中国美人/
ちゅうごくふう /中国風/
ちゅうごくぶんか /中国文化/
ちゅうごくぶんがく /中国文学/
ちゅうごくぶんめい /中国文明/
ちゅうごくへい /中国兵/
ちゅうごくへん /中国編/
ちゅうごくほうそう /中国放送/
ちゅうごくほくぶ /中国北部/
ちゅうごくほんど /中国本土/
ちゅうごくみんこう /中国民航/
ちゅうごくやさい /中国野菜/
ちゅうごくりゅう /中国流/
ちゅうごくりゅうがくせい /中国留学生/
ちゅうごくりょう /中国領/
ちゅうごくりょうり /中国料理/
ちゅうごくりょこうしゃ /中国旅行社/
ちゅうごし /中腰/
ちゅうごしっくたい /中ゴシック体/
ちゅうさ /中佐/
ちゅうさい /仲裁/中祭/
ちゅうさいきかん /仲裁機関/
ちゅうさいけいやく /仲裁契約/
ちゅうさいさいばん /仲裁裁判/
ちゅうさいさいばんしょ /仲裁裁判所/
ちゅうさいしき /中彩色/
ちゅうさいにん /仲裁人/
ちゅうさいはんだん /仲裁判断/
ちゅうさかん /中属/
ちゅうさつ /誅殺/駐箚/
ちゅうさん /中三/中産/昼餐/注参/中３/中3/
ちゅうさんかいきゅう /中産階級/
ちゅうざ /中座/
ちゅうざい /駐在/
ちゅうざいいん /駐在員/
ちゅうざいしょ /駐在所/
ちゅうざお /中棹/
ちゅうざら /中皿/
ちゅうざん /中山/
ちゅうし /中止/注視/忠士/忠死/
ちゅうしこく /中四国/
ちゅうしこくちほう /中四国地方/
ちゅうしつ /中執;[略語]中央執行委員(会)/
ちゅうしつし /中質紙/
ちゅうしてん /注視点/
ちゅうしはん /中止犯/
ちゅうしみすい /中止未遂/
ちゅうしめいれい /中止命令/
ちゅうしゃ /注射/駐車/注瀉/
ちゅうしゃいはん /駐車違反/
ちゅうしゃえき /注射液/
ちゅうしゃか /駐車可/
ちゅうしゃき /注射器/
ちゅうしゃきょかしょう /駐車許可証/
ちゅうしゃきんし /駐車禁止/
ちゅうしゃく /注釈/註釈/
ちゅうしゃくか /注釈化/
ちゅうしゃくぎょう /注釈行/註釈行/
ちゅうしゃくしょ /注釈書/
ちゅうしゃくつき /注釈付き/
ちゅうしゃくぶん /注釈文/
ちゅうしゃけん /駐車券/
ちゅうしゃしゃりょう /駐車車両/
ちゅうしゃしん /注射針;[医]=ちゅうしゃばり/
ちゅうしゃじ /駐車時/
ちゅうしゃじょう /駐車場/
ちゅうしゃじょうあんない /駐車場案内/
ちゅうしゃじょうかくほ /駐車場確保/
ちゅうしゃじょうかんきょう /駐車場環境/
ちゅうしゃじょうきょう /駐車状況/
ちゅうしゃじょうした /駐車場下/
ちゅうしゃじょうだい /駐車場代/
ちゅうしゃじょうない /駐車場内/
ちゅうしゃじょうなど /駐車場等/
ちゅうしゃじょうりょうきん /駐車場料金/
ちゅうしゃたい /駐車帯/
ちゅうしゃだい /駐車代/
ちゅうしゃだいすう /駐車台数/
ちゅうしゃちゅう /駐車中/
ちゅうしゃとう /注射筒/
ちゅうしゃばしょ /駐車場所/
ちゅうしゃばり /注射針/
ちゅうしゃひょう /駐車票/
ちゅうしゃめん /中斜面/
ちゅうしゃもんだい /駐車問題/
ちゅうしゃりょう /駐車料/
ちゅうしゃりょうきん /駐車料金/
ちゅうしゃわく /駐車枠/
ちゅうしゅう /中秋;陰暦8月(15日)。「-の名月」/仲秋;=中秋/中周/
ちゅうしゅこつ /中手骨/
ちゅうしゅつ /抽出/
ちゅうしゅつぶ /抽出部/
ちゅうしゅつぶつ /抽出物/
ちゅうしゅつほう /抽出法/
ちゅうしょ /中所/籀書/中書/
ちゅうしょう /中傷/中小/抽象/中称;[文法]⇔遠称・近称/中将;ちゅうじょう/中生/
ちゅうしょうか /抽象化/
ちゅうしょうが /抽象画/
ちゅうしょうがいねん /抽象概念/
ちゅうしょうがた /抽象型/
ちゅうしょうきかい /抽象機械/
ちゅうしょうきぎょう /中小企業/
ちゅうしょうきぎょうきほんほう /中小企業基本法/
ちゅうしょうきぎょうしんだんし /中小企業診断士/
ちゅうしょうきぎょうちょう /中小企業庁;www.chusho.meti.go.jp/
ちゅうしょうきぎょうちょうせんしえんほう /中小企業挑戦支援法/
ちゅうしょうきぎょうとうきょうどうくみあい /中小企業等協同組合/
ちゅうしょうきぎょうとうきょうどうくみあいほう /中小企業等協同組合法/
ちゅうしょうきじ /中傷記事/
ちゅうしょうぎ /中将棋/
ちゅうしょうげいじゅつ /抽象芸術/
ちゅうしょうこうぶん /抽象構文/
ちゅうしょうこうぶんぎ /抽象構文木/
ちゅうしょうこく /中小国/
ちゅうしょうしてつ /中小私鉄/
ちゅうしょうじぎょうしゃ /中小事業者/
ちゅうしょうすうがく /抽象数学/
ちゅうしょうせい /抽象性/
ちゅうしょうせかい /抽象世界/
ちゅうしょうつい /抽象対/
ちゅうしょうてき /抽象的/
ちゅうしょうてきがいねん /抽象的概念/
ちゅうしょうてきしこう /抽象的思考/
ちゅうしょうでーたがた /抽象データ型/
ちゅうしょうど /抽象度/
ちゅうしょうほうじん /中小法人/
ちゅうしょうめいし /抽象名詞/
ちゅうしょうろん /抽象論/
ちゅうしょおう /中書王/
ちゅうしょかく /中書格/
ちゅうしょく /昼食/中食/
ちゅうしょくかい /昼食会/
ちゅうしょくきゅうけい /昼食休憩/
ちゅうしょくご /昼食後/
ちゅうしょくじ /昼食時/
ちゅうしょくだい /昼食代/
ちゅうしょくどき /昼食時/
ちゅうしょくひ /昼食費/
ちゅうしょくべつ /昼食別/
ちゅうしょしょう /中書省/
ちゅうしょじま /中書島/
ちゅうしょれい /中書令/
ちゅうしようきゅう /中止要求/
ちゅうしん /中心/忠臣/衷心;まごころ。「-よりお詫びします」/注進;ご-/忠心;fidelity/中震/柱心;[建築]column centre/
ちゅうしん> /中心;(central) -人物,-施設,-星/
ちゅうしんえき /中心駅/
ちゅうしんかく /中心核;core/中心角;[数学]central angle/中心格/
ちゅうしんかだい /中心課題/
ちゅうしんがい /中心街/
ちゅうしんがた /中心型/
ちゅうしんきあつ /中心気圧/
ちゅうしんぐら /忠臣蔵/
ちゅうしんさ /中心差/
ちゅうしんさぶん /中心差分/
ちゅうしんしがいち /中心市街地/
ちゅうしんしがいちかっせいかほう /中心市街地活性化法/
ちゅうしんしど /中心示度/
ちゅうしんしや /中心視野/
ちゅうしんしゅうはすう /中心周波数/
ちゅうしんしゅだい /中心主題/
ちゅうしんしょく /中心食/
ちゅうしんじく /中心軸/
ちゅうしんじょうみゃくえいようほう /中心静脈栄養法/
ちゅうしんじんぶつ /中心人物/
ちゅうしんせい /中心性;central/中新世;[地質年代]Miocene. 2330-520万年前/
ちゅうしんせん /中心線/
ちゅうしんせんしゅ /中心選手/
ちゅうしんせんじょう /中心線上/
ちゅうしんたい /中心体/
ちゅうしんち /中心地/
ちゅうしんちゅう /中心柱/
ちゅうしんてき /中心的/
ちゅうしんてきかつどう /中心的活動/
ちゅうしんてききのう /中心的機能/
ちゅうしんてきそんざい /中心的存在/
ちゅうしんてん /中心点/
ちゅうしんでんきょく /中心電極/
ちゅうしんとし /中心都市/
ちゅうしんふきん /中心付近/
ちゅうしんふんか /中心噴火/
ちゅうしんぶ /中心部/
ちゅうしんぶいがい /中心部以外/
ちゅうしんほうこう /中心方向/
ちゅうしんりょく /中心力/
ちゅうじ /中耳/忠治/忠司/忠二/
ちゅうじえん /中耳炎/
ちゅうじく /中軸/
ちゅうじくたいざ /中軸胎座/
ちゅうじつ /忠実/
ちゅうじつど /忠実度/
ちゅうじつや /忠実屋/
ちゅうじてん /中辞典/
ちゅうじゅん /中旬/
ちゅうじゅんいこう /中旬以降/
ちゅうじゅんごろ /中旬頃/
ちゅうじゅんぶん /中旬分/
ちゅうじょ /忠恕/中所/
ちゅうじょう /中将/中条/中條/柱状/衷情/
ちゅうじょうきゅうしゃ /中上級者/
ちゅうじょうきゅうしゃよう /中上級者用/
ちゅうじょうせつり /柱状節理/
ちゅうじょうだん /中上段/
ちゅうじょうひめ /中将姫/
ちゅうじょっき /中ジョッキ/
ちゅうじん /中人/
ちゅうすい /注水/虫垂/
ちゅうすいえん /虫垂炎/
ちゅうすう /中枢/
ちゅうすうしんけい /中枢神経/
ちゅうすうしんけいけい /中枢神経系/
ちゅうすうせい /中枢性/
ちゅうすうぶ /中枢部/
ちゅうすけ /忠輔/
ちゅうず /中主/
ちゅうせい /中世;†medieval/中性;†neutral/忠誠/中正;fair/
ちゅうせいおんがく /中世音楽/
ちゅうせいご /中世語/
ちゅうせいし /中性子;neutron/中世史;medieval history/中性紙;neutral paper/
ちゅうせいしかじょうかく /中性子過剰核/
ちゅうせいしげん /中性子源/
ちゅうせいしすう /中性子数/
ちゅうせいしせい /中性子星/
ちゅうせいしせん /中性子線/
ちゅうせいしそく /中性子束/
ちゅうせいしば /中性子場/
ちゅうせいしばくだん /中性子爆弾;neutron bomb. 生物だけを殺せる核兵器/
ちゅうせいしぼう /中性脂肪/
ちゅうせいしん /忠誠心/
ちゅうせいせんざい /中性洗剤/
ちゅうせいそう /中性相/
ちゅうせいだい /中生代/
ちゅうせいだいめいし /中性代名詞/
ちゅうせいてき /中性的/中世的/
ちゅうせいど /忠誠度/
ちゅうせいどうぶつ /中生動物/
ちゅうせいびし /中性微子/
ちゅうせいふりょく /中性浮力/
ちゅうせいぶ /中西部/
ちゅうせいぶんがく /中世文学/
ちゅうせいめいし /中性名詞/
ちゅうせき /沖積/柱石/
ちゅうせきせい /沖積世/
ちゅうせきそう /沖積層/
ちゅうせきど /沖積土/
ちゅうせきへいや /沖積平野;[地学]river plain/
ちゅうせっきじだい /中石器時代/
ちゅうせつ /忠節/
ちゅうせん /抽選/抽籤;本来の表記/
ちゅうせんかい /抽選会/
ちゅうせんきょく /中選挙区/
ちゅうせんきょくせい /中選挙区制/
ちゅうせんきょくせいど /中選挙区制度/
ちゅうせんけっか /抽選結果/
ちゅうせんけん /抽選券/
ちゅうせんご /抽選後/
ちゅうせんたいしょう /抽選対象/
ちゅうせんば /抽籤馬/
ちゅうせんび /抽選日/
ちゅうせんほうほう /抽選方法/
ちゅうぜい /中背/
ちゅうぜつ /中絶/中舌/
ちゅうぜつきんし /中絶禁止/
ちゅうぜつぼいん /中舌母音;[音声学]central vowel. フランス語の「me」などの母音/
ちゅうぜんじ /中禅寺/
ちゅうぜんじこ /中禅寺湖/
ちゅうそ /注疏/柱礎;[建築]/註疏/
ちゅうそう /中層/中宗/抽送/中倉/
ちゅうそううん /中層雲/
ちゅうそうすい /中層水/
ちゅうそく /中速/
ちゅうそくいき /中速域/
ちゅうそくこつ /中足骨/
ちゅうそくしゃ /中速車/
ちゅうそっこつ /中足骨/
ちゅうそつ /中卒/
ちゅうそん /中尊/虫損/
ちゅうそんじ /中尊寺/
ちゅうぞう /鋳造/忠三/宙三/中僧/鑄像/
ちゅうぞうちゅう /鋳造中/
ちゅうた /宙太/
ちゅうたい /中退/中隊/中台;中国と台湾/紐帯/柱体/中諦;[仏教]/
ちゅうたいきん /中退金/
ちゅうたいしゃ /中退者/
ちゅうたいちょう /中隊長/
ちゅうたんぱ /中短波;intermediate wave NB:波長50-200m/
ちゅうたんぺん /中短編/
ちゅうだい /中大/中台/
ちゅうだいすぎなみ /中大杉並/
ちゅうだな /中棚/
ちゅうだん /中断/中段/中団/
ちゅうだんご /中断後/
ちゅうだんじかん /中断時間/
ちゅうだんちゅう /中断中/
ちゅうち /中置/
ちゅうちきほう /中置記法/
ちゅうちゅうごくたいし /駐中国大使/
ちゅうちゅうたいし /駐中大使/
ちゅうちょ /躊躇/
ちゅうちょう /注腸/中朝;朝廷。また、中国と(北)朝鮮。/
ちゅうちょうき /中長期/
ちゅうちょうきてき /中長期的/
ちゅうちょうきてきてんぼう /中長期的展望/
ちゅうちょうきょり /中長距離/
ちゅうちょうきょりろせん /中長距離路線/
ちゅうっぱら /中っ腹/
ちゅうづり /宙吊り/宙釣り/
ちゅうてい /中低/
ちゅうていいき /中低域/
ちゅうていおん /中低音/
ちゅうていしゃ /駐停車/
ちゅうていしゃきんし /駐停車禁止/
ちゅうていそく /中低速/
ちゅうていど /中程度/
ちゅうてつ /鋳鉄/中鉄/
ちゅうてつしょ /鋳鉄所/
ちゅうてん /中点/中天/・/沖天/宙天/沖点/冲点/
ちゅうてんれんけつていり /中点連結定理/
ちゅうでん /中電/中伝/
ちゅうでんりょく /中電力;[企業名]/
ちゅうと /中途/中図/
ちゅうとう /中東/中等/柱頭/偸盗/中唐/仲冬/中闘/柱棟/
ちゅうとうかい /偸盗戒;[仏教]五戒の一つ/
ちゅうとうがっこう /中等学校/
ちゅうとうきき /中東危機/
ちゅうとうきょういく /中等教育/
ちゅうとうじょうせい /中東情勢/
ちゅうとうせいさく /中東政策/
ちゅうとうせんそう /中東戦争/
ちゅうとうちいき /中東地域/
ちゅうとうど /中等度/
ちゅうとうふつうきょういく /中等普通教育/
ちゅうとうぶ /中等部/
ちゅうとうもんだい /中東問題/
ちゅうとうわへい /中東和平/
ちゅうとうわへいかいぎ /中東和平会議/
ちゅうとかいやく /中途解約/
ちゅうとさいよう /中途採用/
ちゅうとし /中都市/
ちゅうとしつめいしゃ /中途失明者/
ちゅうとはんぱ /中途半端/
ちゅうとろ /中トロ/
ちゅうとん /駐屯/
ちゅうとんち /駐屯地/
ちゅうど /中度/
ちゅうどう /中道/中堂/中動/
ちゅうどうじ /中堂寺/
ちゅうどうそう /中動相/
ちゅうどく /中毒/
ちゅうどくいき /中毒域/
ちゅうどくかんじゃ /中毒患者/
ちゅうどくしゃ /中毒者/
ちゅうどくしゃぞくしゅつ /中毒者続出/
ちゅうどくしょう /中毒症/
ちゅうどくしょうじょう /中毒症状/
ちゅうどくせい /中毒性/
ちゅうどくてき /中毒的/
ちゅうどしま /中年増/
ちゅうなごん /中納言/
ちゅうなん /仲南/
ちゅうなんべい /中南米/
ちゅうなんべいしょこく /中南米諸国/
ちゅうに /中二/中２/中2/
ちゅうにかい /中二階/
ちゅうにく /中肉;-中背/
ちゅうにくちゅうぜい /中肉中背/
ちゅうにち /中日/駐日/
ちゅうにちしんぶん /中日新聞/
ちゅうにちせん /中日戦/
ちゅうにちたいし /駐日大使/
ちゅうにちりょうこく /中日両国/
ちゅうにゅう /注入/
ちゅうにゅうき /注入器/
ちゅうにゅうぐち /注入口/
ちゅうにゅうほう /注入法/
ちゅうにゅうよう /注入用/
ちゅうにん /中人/
ちゅうねん /中年/
ちゅうねんいこう /中年以降/
ちゅうねんおとこ /中年男/
ちゅうねんしんし /中年紳士/
ちゅうねんだんせい /中年男性/
ちゅうのう /中脳/中濃/
ちゅうのうそーす /中濃ソース/
ちゅうのうど /中濃度/
ちゅうのり /宙乗り/
ちゅうは /中波/中破/
ちゅうはい /酎ハイ/
ちゅうはいじく /中胚軸/
ちゅうはいよう /中胚葉/
ちゅうはたい /中波帯/
ちゅうはば /中幅/
ちゅうはほうそう /中波放送/
ちゅうはん /昼飯/中半;中途半端/
ちゅうばい /虫媒/
ちゅうばいか /虫媒花/
ちゅうばこ /中箱/
ちゅうばち /中鉢/
ちゅうばつ /誅伐/誅罰/
ちゅうばん /中盤/中判/注番/
ちゅうばんいこう /中盤以降/
ちゅうばんせん /中盤戦/
ちゅうひ /中皮/中飛;[野球]センターフライ/
ちゅうび /中火/
ちゅうびん /中瓶/
ちゅうふう /中風/
ちゅうふく /中腹/
ちゅうぶ /中部/中風/
ちゅうぶう /中風/
ちゅうぶぜい /中部勢/
ちゅうぶだいがく /中部大学/
ちゅうぶちく /中部地区/
ちゅうぶちほう /中部地方/
ちゅうぶてんりゅう /中部天竜/
ちゅうぶでんりょく /中部電力;[企業名]/
ちゅうぶにっぽんほうそう /中部日本放送/
ちゅうぶにほん /中部日本/
ちゅうぶにほんほうそう /中部日本放送/
ちゅうぶらり /宙ぶらり/
ちゅうぶらりん /宙ぶらりん/
ちゅうぶる /中古/
ちゅうぶん /中文/籀文;=大篆/
ちゅうぶんるい /中分類/
ちゅうへい /駐兵/
ちゅうへいけん /駐兵権/
ちゅうへん /中編/中篇/中辺/
ちゅうへんしょうせつ /中編小説/
ちゅうべい /中米/駐米/
ちゅうべいたいし /駐米大使/
ちゅうべん /中弁;[律令制]弁官/
ちゅうほーる /中ホール/
ちゅうほしゃ /仲保者/
ちゅうほん /中本/
ちゅうぼう /厨房/中坊/
ちゅうぼうえん /中望遠/
ちゅうぼうしょ /中奉書/
ちゅうぼく /忠僕/
ちゅうぼそ /中細/
ちゅうま /中馬/
ちゅうまど /中窓/
ちゅうみつ /稠密/
ちゅうむしょう /中務省/
ちゅうめん /柱面/中免/
ちゅうもく /注目/
ちゅうもくかぶ /注目株/
ちゅうもくさく /注目作/
ちゅうもくさくひん /注目作品/
ちゅうもくせんしゅ /注目選手/
ちゅうもくてん /注目点/
ちゅうもくど /注目度/
ちゅうもくひょう /中目標/
ちゅうもん /注文/中門/註文/
ちゅうもんうけしょ /注文請書/
ちゅうもんか /注文可/
ちゅうもんかのう /注文可能/
ちゅうもんしょ /注文書/
ちゅうもんじゅうたく /注文住宅/
ちゅうもんせいさん /注文生産/
ちゅうもんせんよう /注文専用/
ちゅうもんちゅう /注文中/
ちゅうもんとり /注文取り/
ちゅうもんないよう /注文内容/
ちゅうもんぬし /注文主/
ちゅうもんばんごう /注文番号/
ちゅうもんひょう /注文票;order slip/注文表;order list/
ちゅうもんひん /注文品/
ちゅうもんふぉーむ /注文フォーム/
ちゅうもんぶん /注文分/
ちゅうもんほうほう /注文方法/
ちゅうや /昼夜/中也;人名,中原-/中夜/
ちゅうやぎゃくてん /昼夜逆転/
ちゅうやけんこう /昼夜兼行/
ちゅうやさい /中夜祭/
ちゅうゆ /注油/
ちゅうゆう /忠勇/
ちゅうよう /中庸/中葉/
ちゅうようとっき /虫様突起/
ちゅうりき /中力/
ちゅうりきこ /中力粉/
ちゅうりつ /中立/
ちゅうりつがわ /中立側/
ちゅうりつこく /中立国/
ちゅうりつしゅぎ /中立主義;neutralism/
ちゅうりつせい /中立性/
ちゅうりつせつ /中立説;[生物]neutral theory (木村資生)/
ちゅうりつせんげん /中立宣言/
ちゅうりつちたい /中立地帯/
ちゅうりつてき /中立的/
ちゅうりゃく /中略/
ちゅうりゅう /中流/駐留/
ちゅうりゅうかいきゅう /中流階級/
ちゅうりゅうぐん /駐留軍/
ちゅうりゅうど /中粒度/
ちゅうりょ /仲呂/
ちゅうりょうきゅう /中量級/
ちゅうりょく /注力/中力/
ちゅうりん /駐輪/
ちゅうりんじょ /駐輪所/
ちゅうりんじょう /駐輪場/
ちゅうる /中流/
ちゅうるい /忠類/
ちゅうれい /昼礼/
ちゅうれつ /中裂/
ちゅうろ /中露/
ちゅうろう /中老/柱廊/中臈/
ちゅうろうい /中労委/
ちゅうろく /中肋/
ちゅうろくたいざ /中肋胎座/
ちゅうろん /中論/
ちゅうわ /中和/
ちゅうわざい /中和剤/
ちゅうわてきてい /中和滴定/
ちゅうわねつ /中和熱;[化学]heat of neutralisation/
ちゅうわはんのう /中和反応/
ちゅちぇしそう /チュチェ思想;(北朝鮮の)主体思想/
ちゅつ /黜/
ちゅん /中;zhong/
ちゅんもう /屯蒙/
ちゅんりー /春麗/
ちゆ /治癒/
ちゆう /知友/知勇/
ちゆき /千幸/
ちゆこうか /治癒効果/
ちゆりつ /治癒率/
ちょ /著/貯/樗;(おうち)樗材/緒;情緒/猪;猪口/箸;はし/儲;もうけ/楮;こうぞ/瀦/潴;「瀦」の異体字/豬;いのしし/躇;躊躇/墸;(幽霊文字?)/苧;からむし/紵/佇;(たたず・む)佇立/竚;≒佇/杼;崔-/
ちょいやく /チョイ役/ちょい役/
ちょう /長/超/蝶/腸/兆;10^12/町/丁/庁/挺/調/鳥/帳;帳面/帖/寵;寵愛/趙;中国の国名/朝;朝食/潮;潮汐/嘲;嘲笑/張;(は・る) 張力/脹;は・れる/悵;うらむ/漲;みなぎ・る/萇;(いらくさ)/挑;挑戦/眺;眺望/跳;跳躍/銚;銚子/佻;軽佻/晁;あさ/窕;窈窕/誂;あつら・える/諜;諜報/牒;符牒/喋;しゃべ・る/楪;ゆずりは/澄;明澄/懲;懲役/徴;特徴/澂;「澄」の異体字/彫;彫刻/凋;凋落/稠;稠密(ちゅうみつ)/鯛;たい/雕;≒彫/聴;聴聞/聽;「聴」の旧字(人名用漢字)/疔;(できもの)面疔/廳;「庁」の旧字(人名用漢字)/廰;「庁」の旧字2/甼;「町」の異体字/暢;流暢/膓;「腸」の異体字/蔦;つた/樢/鵈;とび/貂;てん/迢;はるか/齠/肇;(はじめ)/鬯/昶;ながい/糶;せり/髫;うない/鼎;(呉音) かなえ/弔;弔問/重;重複/頂;頂上/釣;釣果/吊;つ・る/貼;貼付/輒;すなわち/輙;「輒」の異体字/冢;≒塚/塚;つか/微;び ※「徴」との混同?/魚蝨/金魚蝨/
ちょう> /超/長;長時間,長プラ,長音階/
ちょうあい /寵愛/丁合/帳合/丁合い/帳合い/
ちょうあく /懲悪/
ちょうあし /蝶足/
ちょうあつ /調圧/
ちょうあなうま /超穴馬/
ちょうあにき /超兄貴/
ちょうあまくち /超甘口/
ちょうあん /長安/
ちょうあんか /超安価/
ちょうい /潮位/弔慰;弔い慰める。「-金」/弔意;弔う気持ち。「-を表す」/
ちょういき /町域/
ちょういきん /弔慰金/
ちょういち /長一/
ちょういちりゅう /超一流/
ちょういちりゅうば /超一流馬/
ちょういちりゅうひん /超一流品/
ちょういちりゅうほてる /超一流ホテル/
ちょういちろう /長一郎/
ちょういっきゅう /超一級/
ちょういん /調印/
ちょういんしき /調印式/
ちょううすがた /超薄型/
ちょううちゅう /超宇宙/
ちょううらんげんそ /超ウラン元素;uranide/
ちょううんぼう /朝雲暮雨/
ちょうえい /町営/
ちょうえいきどう /町営軌道/
ちょうえいちゅうしゃじょう /町営駐車場/
ちょうえき /懲役/腸液/
ちょうえきけい /懲役刑/
ちょうえつ /超越/
ちょうえつかんすう /超越関数;[数学]transcendental function/
ちょうえつしゃ /超越者/
ちょうえつしゅぎ /超越主義;transcendentalism/
ちょうえつすう /超越数/
ちょうえつせい /超越性/
ちょうえつそんざい /超越存在/
ちょうえつてき /超越的/
ちょうえつろん /超越論;[哲学]Transzendentalismus(独)/
ちょうえつろんてき /超越論的/
ちょうえん /腸炎/兆円/長円/
ちょうえんけい /長円形/
ちょうおおがた /超大型/
ちょうおおぐち /超大口/
ちょうおおて /超大手/
ちょうおおもの /超大物/
ちょうおん /長音/潮音/聴音;hearing/調音;articulate/ー;長音符/
ちょうおんか /長音化/
ちょうおんかい /長音階/
ちょうおんき /聴音機/
ちょうおんきごう /長音記号/
ちょうおんけつごう /調音結合/
ちょうおんそく /超音速/
ちょうおんてん /調音点/
ちょうおんぱ /超音波/
ちょうおんぱしき /超音波式/
ちょうおんぱせんじょう /超音波洗浄/
ちょうおんぶ /聴音部/調音部/
ちょうおんぷ /長音符;ー/
ちょうおんようしき /調音様式/
ちょうか /超過/釣果/長靴/長歌/町家/長夏/弔歌/
ちょうかい /町会/懲戒/朝会/聴解;auding.「-テスト」/潮解;deliquesce/鳥海;人名・地名/嘲詼/
ちょうかいぎいん /町会議員/
ちょうかいけん /懲戒権/
ちょうかいけんしゃ /懲戒権者/
ちょうかいさん /鳥海山/
ちょうかいしょぶん /懲戒処分/
ちょうかいせい /潮解性/
ちょうかいそく /超快速/
ちょうかいたいしょう /懲戒対象/
ちょうかいふく /超回復;[生物]super compensation/
ちょうかいぼへん /朝改暮変/
ちょうかいめんしょく /懲戒免職/
ちょうかいりょく /聴解力/
ちょうかがく /超科学/
ちょうかがくてき /超科学的/
ちょうかきんむ /超過勤務;いわゆる超勤/
ちょうかきんむてあて /超過勤務手当/
ちょうかく /聴覚/長角/頂角/張角;黄巾の乱/弔客/
ちょうかくかん /聴覚感/
ちょうかくき /聴覚器/
ちょうかくきかん /聴覚器官/
ちょうかくきこう /聴覚機構/
ちょうかくきのう /聴覚機能/
ちょうかくけい /聴覚系/
ちょうかくけん /聴覚研/
ちょうかくしょうがい /聴覚障害/
ちょうかくしょうがいしゃ /聴覚障害者/聴覚障碍者/
ちょうかくしょり /聴覚処理/
ちょうかくしんけい /聴覚神経/
ちょうかくしんりがく /聴覚心理学/
ちょうかくじゅんのう /聴覚順応/
ちょうかくじょう /聴覚上/
ちょうかくじょうほうしょり /聴覚情報処理/
ちょうかくてき /聴覚的/
ちょうかくとくせい /聴覚特性/
ちょうかくひろう /聴覚疲労/
ちょうかくまっしょうけい /聴覚末梢系/
ちょうかくや /聴覚野/
ちょうかくやす /超格安/
ちょうかげき /超過激/
ちょうかじゅよう /超過需要/
ちょうかそく /超加速/
ちょうかそくど /超過速度/
ちょうかたる /腸カタル;[医]intestinal catarrh/
ちょうかねもち /超金持ち/
ちょうかぶん /超過分/
ちょうかほけん /超過保険/
ちょうからくち /超辛口/
ちょうかりじゅん /超過利潤/
ちょうかりょうきん /超過料金/
ちょうかん /朝刊/長官/腸管/鳥瞰/聴感/長巻/長寛;年号(1163-1165)/
ちょうかんかく /聴感覚/
ちょうかんかんぼう /長官官房/
ちょうかんじ /超漢字;www.chokanji.com/
ちょうかんじょう /聴感上/
ちょうかんすう /超関数/超函数/
ちょうかんすうろん /超関数論/
ちょうかんず /鳥瞰図/
ちょうかんたん /超簡単/
ちょうかんてき /鳥瞰的/
ちょうかんどう /超感動/
ちょうかんまく /腸間膜/
ちょうが /頂芽/
ちょうがい /町外/鳥害/
ちょうがいふじ /超涯不次/
ちょうがく /調楽/重学/
ちょうがくりょう /張学良/
ちょうがた /蝶形/
ちょうがたべん /蝶形弁/
ちょうがゆうせい /頂芽優勢/
ちょうがん /腸癌/
ちょうき /長期/寵姫/弔旗/
ちょうき> /長期;-予測,-金融,-熟成/
ちょうきあんてい /長期安定/
ちょうきか /長期化/
ちょうきかしつけきん /長期貸付金/
ちょうきかりいれきん /長期借入金/
ちょうきかん /長期間/
ちょうきかんこうそく /長期間拘束/
ちょうきかんしよう /長期間使用/
ちょうきかんほうち /長期間放置/
ちょうきかんほぞん /長期間保存/
ちょうききおく /長期記憶/
ちょうききゅうか /長期休暇/
ちょうききゅうよう /長期休養/
ちょうききんぞく /長期勤続/
ちょうききんり /長期金利/
ちょうきけいかく /長期計画/
ちょうきけいやく /長期契約/
ちょうきけっせき /長期欠席;-届/
ちょうきけつじょう /長期欠場/
ちょうきこくさい /長期国債/
ちょうきしきん /長期資金/
ちょうきしゅっちょう /長期出張/
ちょうきしゅっちょうちゅう /長期出張中/
ちょうきしんようぎんこう /長期信用銀行/
ちょうきじゅくせい /長期熟成/
ちょうきせん /長期戦/
ちょうきたいざい /長期滞在/
ちょうきたいざいしゃ /長期滞在者/
ちょうきち /長吉/
ちょうきてき /長期的/
ちょうきてきみとおし /長期的見通し/
ちょうきにゅういん /長期入院/
ちょうきびょうけつ /長期病欠/
ちょうきふきょうか /長期不況下/
ちょうきふざい /長期不在/
ちょうきほぞん /長期保存/
ちょうきまえばらいひよう /長期前払費用/
ちょうきもくひょう /長期目標/
ちょうきゃく /弔客/
ちょうきゅう /長久;年号(1040-1044)/超球/
ちょうきゅうめい /長久命/
ちょうきょ /聴許/
ちょうきょう /調教/長享;年号(1487-1489)/
ちょうきょうし /調教師/
ちょうきょうちゅう /調教中/
ちょうきょうぶそく /調教不足/
ちょうきょうほう /調教法/
ちょうきょうりょく /超強力/
ちょうきょこう /超虚構/
ちょうきょせい /超巨星/
ちょうきょり /長距離/
ちょうきょりうんてん /長距離運転/
ちょうきょりきっぷ /長距離切符/
ちょうきょりきゃく /長距離客/
ちょうきょりきょうそう /長距離競走;[陸上]5000m~/
ちょうきょりきろく /長距離記録/
ちょうきょりけい /長距離系/
ちょうきょりけっとう /長距離血統/
ちょうきょりこくさいせん /長距離国際線/
ちょうきょりせん /長距離戦/
ちょうきょりせんもん /長距離専門/
ちょうきょりそう /長距離走/
ちょうきょりそうこう /長距離走行/
ちょうきょりそうしゃ /長距離走者/
ちょうきょりだしゃ /長距離打者/
ちょうきょりつうきん /長距離通勤/
ちょうきょりでんわ /長距離電話/
ちょうきょりば /長距離馬/
ちょうきょりばす /長距離バス/
ちょうきょりひこう /長距離飛行/
ちょうきょりびん /長距離便/
ちょうきょりほう /長距離砲/
ちょうきょりゆそう /長距離輸送/
ちょうきょりらんなー /長距離ランナー/
ちょうきょりりょうきん /長距離料金/
ちょうきょりりょこう /長距離旅行/
ちょうきょりれっしゃ /長距離列車/
ちょうきょりろせん /長距離路線/
ちょうきょりわりびき /長距離割引/
ちょうきよほう /長期予報/
ちょうきりょこう /長期旅行/
ちょうきれんきゅう /長期連休/
ちょうきれんさい /長期連載/
ちょうきれんさいさくひん /長期連載作品/
ちょうきわりびき /長期割引/
ちょうきん /彫金/超勤;[略語]超過勤務/
ちょうぎ /町議/朝議/張儀/朝儀;朝廷の儀式/嘲戯/
ちょうぎいん /町議員/
ちょうぎかい /町議会/
ちょうぎゃく /嘲謔/
ちょうぎょ /釣魚/
ちょうぎん /朝銀/
ちょうく /長駆;「-300km」/長躯;tall.「痩身-」/長句/
ちょうくうかん /超空間;hyperspace/聴空間;auditory space/
ちょうぐう /寵遇/
ちょうけい /長兄/長径/長形/長計;長期的計画/蝶形/
ちょうけいか /蝶形花/
ちょうけいこつ /蝶形骨/
ちょうけいてんのう /長慶天皇/
ちょうけいりょう /超軽量/
ちょうけいりょうか /超軽量化/
ちょうけし /帳消し/
ちょうけつ /長欠/
ちょうけん /長剣/朝見/長絹/朝憲/聴検/朝権/
ちょうげきせん /超激戦/
ちょうげん /調弦;[音楽]tuning/長元;年号(1028-1037)/超弦;[物理]-理論/超限;[数学]transfinite/
ちょうげんじつしゅぎ /超現実主義;surrealisme/
ちょうげんじつてき /超現実的/
ちょうげんじつは /超現実派/
ちょうげんぼう /長元坊;[鳥]kestrel/
ちょうげんりろん /超弦理論/
ちょうこう /兆候/長江;Chang Jiang/聴講/調光/徴候;≒兆候/釣行/潮紅;blush/長考/朝貢;国へのみつぎもの/調香/長講;long lecture/超高/釣鉤;hook/調貢;みつぎもの/嘲詬;sarcasm/
ちょうこういき /超広域/
ちょうこうかいてん /超高回転/
ちょうこうかいてんがた /超高回転型/
ちょうこうかく /超広角/
ちょうこうき /釣行記/超広軌/
ちょうこうきぼう /聴講希望/
ちょうこうきゅう /超高級/
ちょうこうきゅうりょうてい /超高級料亭/
ちょうこうこうきゅう /超高校級/
ちょうこうさ /潮候差/
ちょうこうさんか /聴講参加/
ちょうこうし /調香師;perfumier/超格子;superlattice/
ちょうこうしつ /超硬質/
ちょうこうしゅうは /超高周波/
ちょうこうじゅんど /超高純度/
ちょうこうせい /聴講生/
ちょうこうせいのう /超高性能/
ちょうこうぜつ /長広舌/
ちょうこうそう /超高層/
ちょうこうそうけんちく /超高層建築/
ちょうこうそうびる /超高層ビル/
ちょうこうそく /超高速;ultrahigh-speed/超光速;superluminal/
ちょうこうそくかいてん /超高速回転/
ちょうこうそくこうこう /超光速航行/
ちょうこうそくこうほう /超光速航法/
ちょうこうそくだいようりょう /超高速大容量/
ちょうこうそくど /超高速度;hypervelocity. 「-撮影」/
ちょうこうひんしつ /超高品質/
ちょうこうぶんし /超高分子/
ちょうこうぼうえき /朝貢貿易/
ちょうこうみつど /超高密度/
ちょうこうむりょう /聴講無料/
ちょうこうりょう /聴講料/
ちょうこうれいかしゃかい /超高齢化社会/
ちょうこがた /超小型/
ちょうこく /彫刻/超克/肇国;=建国/
ちょうこくか /彫刻家/
ちょうこくぐざ /彫刻具座;Caelum(Cae)/
ちょうこくしつざ /彫刻室座;Sculptor(Scl)/
ちょうこくてん /彫刻展/
ちょうこくとう /彫刻刀/
ちょうこだい /超古代/
ちょうこっかしゅぎ /超国家主義/
ちょうこつ /腸骨/
ちょうこん /長恨/
ちょうこんか /長恨歌/
ちょうこんざつ /超混雑/
ちょうご /長後/鳥語/釣語/
ちょうごう /調合/調号;[音楽]key-signature/
ちょうごうか /超豪華/
ちょうごうきん /超合金/
ちょうごうよう /調合用/
ちょうごえき /長後駅/
ちょうごくあく /超極悪/
ちょうごんか /長恨歌;白楽天の詩/
ちょうさ /調査/長沙/潮差/
ちょうさい /調査委;調査委員会/弔祭/兆載/
ちょうさいいんかい /調査委員会/
ちょうさいらい /調査依頼/
ちょうさいん /調査員/
ちょうさか /調査課/
ちょうさかい /調査会/
ちょうさかん /調査官/
ちょうさがいしゃ /調査会社/
ちょうさきかん /調査期間;period/調査機関;agency/
ちょうさぎょう /調査業/
ちょうさく /調査区/
ちょうさけっか /調査結果/
ちょうさけんきゅう /調査研究/
ちょうさこうもく /調査項目/
ちょうさし /調査士/
ちょうさしつ /調査室/
ちょうさしょ /調査書/
ちょうさたい /調査隊/
ちょうさたいしょう /調査対象/
ちょうさだん /調査団/
ちょうさだんちょう /調査団長/
ちょうさちゅう /調査中/
ちょうさとうけいしりょう /調査統計資料/
ちょうさひ /調査費/
ちょうさひょう /調査票;slip/調査表;table/
ちょうさひよう /調査費用/
ちょうさぶ /調査部/
ちょうさぶそく /調査不足/
ちょうさほう /調査法/
ちょうさほうこく /調査報告/
ちょうさほうこくしょ /調査報告書/
ちょうさほうほう /調査方法/
ちょうさぼしゅう /調査募集/
ちょうさやく /調査役/
ちょうさよう /調査用/
ちょうさようし /調査用紙/
ちょうさん /逃散/張三;「張氏の三男」の意/
ちょうさんど /長三度/
ちょうさんぼし /朝三暮四/
ちょうさんりし /張三李四/
ちょうさんわおん /長三和音/
ちょうざ /長座/
ちょうざい /調剤/聴罪/
ちょうざめ /蝶鮫;sturgeon/
ちょうざんこく /超残酷/
ちょうざんぞう /長残像/
ちょうし /調子/銚子;地名,千葉/長子/長姉/聴視/長詩/弔詞;弔辞/弔詩/冢祀/
ちょうしがみ /調子紙/
ちょうしぎょこう /銚子漁港/
ちょうしし /銚子市/
ちょうししゃ /聴視者/
ちょうししょうぎょう /銚子商業/
ちょうしぜん /超自然/
ちょうしそうぞく /長子相続/
ちょうしたいりょうぶし /銚子大漁節;[民謡]千葉/
ちょうしつ /調湿;humidity control. 「-設備,-機能」/彫漆/
ちょうしなうす /超品薄/
ちょうしはずれ /調子外れ/
ちょうしぶえ /調子笛/
ちょうしもの /調子者/
ちょうしゃ /庁舎/聴者/
ちょうしゃく /長尺/
ちょうしゃてい /長射程/
ちょうしゅ /聴取/町衆/頭首;[仏教]/長酒/
ちょうしゅいち /聴取位置/
ちょうしゅう /徴収;†collect.「税の-」/聴衆/長州/釣舟/徴集;†conscript.「兵士の-」/町衆/張州;尾張/長洲;ながす?/
ちょうしゅうかく /聴衆各/
ちょうしゅうがく /徴収額/
ちょうしゅうき /長周期/
ちょうしゅうきん /徴収金/
ちょうしゅうさんか /聴衆参加/
ちょうしゅうぜんいん /聴衆全員/
ちょうしゅうゆうよ /徴収猶予/
ちょうしゅしゃ /聴取者/
ちょうしゅしょ /聴取書/
ちょうしゅじ /聴取時/
ちょうしゅじっけん /聴取実験/
ちょうしゅつ /超出/
ちょうしゅほう /聴取法/
ちょうしゅりつ /聴取率;視聴率のラジオ版/
ちょうしゅりつちょうさ /聴取率調査/
ちょうしゅん /長春/
ちょうしょ /長所/調書/調所/弔書/
ちょうしょう /嘲笑/弔鐘/長承;年号(1132-1135)/長嘯/徴証/寵妾/
ちょうしょうすうは /超少数派/
ちょうしょく /朝食/調色/
ちょうしょくじ /朝食時/
ちょうしょくじかん /朝食時間/
ちょうしょくじゅんび /朝食準備/
ちょうしょくつき /朝食付/
ちょうしょくよう /朝食用/
ちょうしょしんしゃ /超初心者/
ちょうしょたんしょ /長所短所/
ちょうしん /長身/聴診/長針;時計の-/朝臣;=あそん/寵臣;minion/調進/
ちょうしんき /聴診器/
ちょうしんくう /超真空/
ちょうしんけい /聴神経/
ちょうしんせい /超新星/
ちょうしんりがく /超心理学/
ちょうしんりがくしゃ /超心理学者/
ちょうしんりがっかい /超心理学会/
ちょうしんるこつ /彫心鏤骨/
ちょうじ /弔事;†⇔慶事/寵児/弔辞;†「-を述べる」/丁子;clove/丁字;=丁子/長治;年号(1104-06)/懲治/
ちょうじあぶら /丁子油/
ちょうじいろ /丁子色/
ちょうじかん /長時間/
ちょうじかんうんてん /長時間運転/
ちょうじかんさぎょう /長時間作業/
ちょうじかんさつえい /長時間撮影/
ちょうじかんしよう /長時間使用/
ちょうじかんていしゃ /長時間停車/
ちょうじかんでんわ /長時間電話/
ちょうじかんろこう /長時間露光/
ちょうじが /超自我;[精医]Uberich/
ちょうじく /長軸/
ちょうじくうようさい /超時空要塞/
ちょうじくほうこう /長軸方向/
ちょうじちゃ /丁子茶/
ちょうじっすう /超実数/
ちょうじつ /長日/
ちょうじつしょくぶつ /長日植物;long-day plant/
ちょうじつしょり /長日処理/
ちょうじつせい /超日性/
ちょうじゃ /長者/
ちょうじゃがさき /長者ヶ崎/
ちょうじゃく /長尺/
ちょうじゃくかん /長尺管/
ちょうじゃばんづけ /長者番付;高額納税者名簿/
ちょうじゅ /長寿/
ちょうじゅう /鳥獣/聴従/
ちょうじゅうぎが /鳥獣戯画/
ちょうじゅうせんしゃ /超重戦車/
ちょうじゅうほごく /鳥獣保護区/
ちょうじゅうりょくりろん /超重力理論/
ちょうじゅうろう /長十郎/
ちょうじゅしゃかい /長寿社会/
ちょうじゅせかいいち /長寿世界一/
ちょうじゅばんぐみ /長寿番組/
ちょうじゅばんづけ /長寿番付;全国高齢者名簿/
ちょうじゅみょう /長寿命/
ちょうじゅん /超準/
ちょうじゅんかいせき /超準解析/
ちょうじゅんすう /超準数/
ちょうじゆ /丁子油/
ちょうじょ /長女/
ちょうじょう /頂上/超常/重畳/長城/長上/牒状/超乗/
ちょうじょうきゅう /超上級/
ちょうじょうきゅうしゃ /超上級者/
ちょうじょうげんしょう /超常現象/
ちょうじょうしゃ /長上者/
ちょうじょうてき /重畳的/
ちょうじょうのうりょく /超常能力/
ちょうじょうふきん /頂上付近/
ちょうじよう /弔事用/
ちょうじり /帳尻/
ちょうじろう /長次郎/
ちょうじん /超人/鳥人/釣人/超神/
ちょうじんてき /超人的/
ちょうすいろ /長水路/
ちょうすうがく /超数学/
ちょうすけ /長介/
ちょうず /手水/
ちょうずば /手水場/
ちょうずばち /手水鉢/
ちょうせい /調整;adjust.「設定の-」/調製;prepare.「薬品の-」/調性;[音楽]tonality/長生/町政;†町の行政。「-への提言」/町制;†町という制度。「-を敷く」/長征/朝政/長逝/頂生/調声/
ちょうせいおんがく /調性音楽/
ちょうせいかん /調整官/調性感/
ちょうせいがく /調整額/
ちょうせいき /調整器/
ちょうせいきかん /調整期間/調整機関/
ちょうせいきゅう /調整給/
ちょうせいきょくめん /調整局面/
ちょうせいご /調整後/
ちょうせいざい /調整剤/
ちょうせいし /調整師/
ちょうせいしき /調整式/
ちょうせいしだい /調整次第/
ちょうせいしつ /調整室/
ちょうせいしゃ /調整者/
ちょうせいしゅだん /調整手段/
ちょうせいじょう /調整上/
ちょうせいじょうきょう /調整状況/
ちょうせいすう /調整数/
ちょうせいそく /超正則/
ちょうせいち /調整池/調整値/
ちょうせいちゅう /調整中/
ちょうせいでん /長生殿;唐の宮殿/
ちょうせいのうりょく /調整能力/
ちょうせいはば /調整幅/
ちょうせいはんい /調整範囲/
ちょうせいぶ /調整部/
ちょうせいぶそく /調整不足/
ちょうせいほう /調整法/
ちょうせいほうほう /調整方法/
ちょうせいまえ /調整前/
ちょうせいめい /超生命/
ちょうせいやく /調整役/
ちょうせいよう /調整用/
ちょうせいり /超整理/
ちょうせいりほう /超整理法/
ちょうせいりょう /調整料/
ちょうせいりょく /調整力/
ちょうせき /潮汐/長石/彫石/腸石/
ちょうせきはつでん /潮汐発電/
ちょうせきひょう /潮汐表/
ちょうせきりょく /潮汐力/
ちょうせだい /超世代/
ちょうせつ /調節/
ちょうせついでんし /調節遺伝子/
ちょうせつかのう /調節可能/
ちょうせつきこう /調節機構/
ちょうせつきのう /調節機能/
ちょうせつけい /調節系/
ちょうせつほうほう /調節方法/
ちょうせん /挑戦/朝鮮/貂蝉;三国志演義に登場する美女/腸線;catgut/腸腺;[解剖]intestinal gland/庁宣/
ちょうせんあめ /朝鮮飴/
ちょうせんいよく /挑戦意欲/
ちょうせんかんこくご /朝鮮韓国語/
ちょうせんき /挑戦記/
ちょうせんきんぎょ /朝鮮金魚/
ちょうせんけい /朝鮮系/
ちょうせんけん /挑戦権/
ちょうせんご /朝鮮語/
ちょうせんし /朝鮮史/超戦士/
ちょうせんしゃ /挑戦者/
ちょうせんしゃぐみ /挑戦者組/
ちょうせんしゃけってい /挑戦者決定/
ちょうせんしゃけっていせん /挑戦者決定戦/
ちょうせんしゅっしんしゃ /朝鮮出身者/
ちょうせんしゅっぺい /朝鮮出兵;[日本史]文禄・慶長の役(1592-1597)/
ちょうせんしんりゃく /朝鮮侵略/
ちょうせんじだい /朝鮮時代/
ちょうせんじょう /挑戦状/
ちょうせんじん /朝鮮人/
ちょうせんじんがっこう /朝鮮人学校/
ちょうせんじんさべつ /朝鮮人差別/
ちょうせんせい /朝鮮製/
ちょうせんせき /朝鮮籍/
ちょうせんせんそう /朝鮮戦争/
ちょうせんそうとく /朝鮮総督/
ちょうせんそうとくふ /朝鮮総督府/
ちょうせんそうれん /朝鮮総連/
ちょうせんだいがく /朝鮮大学/
ちょうせんだいがっこう /朝鮮大学校/
ちょうせんちゅう /挑戦中/
ちょうせんつうしんし /朝鮮通信使;[日本史]/
ちょうせんてき /挑戦的/
ちょうせんにっぽう /朝鮮日報/
ちょうせんにんじん /朝鮮人参/
ちょうせんはんとう /朝鮮半島/
ちょうせんはんとうなんぶ /朝鮮半島南部/
ちょうせんはんとうぶんだん /朝鮮半島分断/
ちょうせんへいごう /朝鮮併合/
ちょうせんぼん /朝鮮本/
ちょうせんみんしゅしゅぎじんみんきょうわこく /朝鮮民主主義人民共和国;地名,Democratic People's Republic of Korea. 北朝鮮(.kp)/
ちょうせんもじ /朝鮮文字/
ちょうせんりょうり /朝鮮料理/
ちょうぜい /徴税/町税/
ちょうぜつ /超絶/
ちょうぜつぎこう /超絶技巧/
ちょうぜつしゅぎ /超絶主義;transcendentalism/
ちょうぜつてき /超絶的/
ちょうぜつりんじん /超絶倫人/
ちょうぜん /超然/長髯/
ちょうぜんしゅぎ /超然主義/
ちょうそ /彫塑/重祚/徴租/
ちょうそう /鳥葬/
ちょうそかべ /長宗我部/
ちょうそがべ /長宗我部/
ちょうそく /長足/
ちょうそくき /調速機;governer/
ちょうそん /町村/長孫/
ちょうそんせい /町村制/
ちょうそんそうかい /町村総会/
ちょうそんちょう /町村長/
ちょうそんぶ /町村部/
ちょうそんめい /町村名/
ちょうそんやくば /町村役場/
ちょうぞう /彫像/長蔵/
ちょうぞうかん /超増感/
ちょうぞく /超俗/
ちょうたい /長体;⇔平体/調帯/
ちょうたいこく /超大国/
ちょうたいさく /超大作/
ちょうたいしょうせい /超対称性/
ちょうたいそく /長大息/
ちょうたいまん /超怠慢/
ちょうたく /彫琢/
ちょうただん /超多段/
ちょうたつ /調達/暢達/
ちょうたつこすと /調達コスト/
ちょうたつご /調達後/
ちょうたつさき /調達先/
ちょうたつひよう /調達費用/
ちょうたつぶ /調達部/
ちょうたぼう /超多忙/
ちょうたろう /長太郎/
ちょうたん /長短/超短/頂端/
ちょうたんい /兆単位/
ちょうたんさいぼう /頂端細胞/
ちょうたんしょ /長短所/
ちょうたんそく /長嘆息/
ちょうたんだ /長短打/
ちょうたんぱ /超短波/
ちょうたんぶんれつそしき /頂端分裂組織/
ちょうだ /長打/長蛇/
ちょうだい /頂戴/長大/鳥大/朝大/
ちょうだいか /長大化/
ちょうだいがめん /超大画面/
ちょうだいたん /超大胆/
ちょうだいへんせい /長大編成/
ちょうだえん /超楕円/
ちょうだつ /超脱/
ちょうだのれつ /長蛇の列/
ちょうだりつ /長打率/
ちょうだりょく /長打力/
ちょうだん /跳弾;ricochet/
ちょうちかく /聴知覚/
ちょうちふす /腸チフス;typhoid/
ちょうちゃく /打擲/
ちょうちゅう /頂肘/
ちょうちょ /蝶々/
ちょうちょう /町長/長調;[音楽]major/蝶々;菜の葉に止まれ/喋々;†おしゃべり。「-喃々」/蝶蝶/
ちょうちょううお /蝶蝶魚/蝶々魚/
ちょうちょうきょり /超長距離/
ちょうちょうなんなん /喋喋喃喃/喋々喃々/
ちょうちょうは /超長波/
ちょうちょうはっし /丁々発止/
ちょうちょうぼぼ /朝朝暮暮/朝々暮々/
ちょうちん /提灯/
ちょうちんあんこう /提灯鮟鱇/
ちょうちんきじ /提灯記事/
ちょうちんぎょうれつ /提灯行列/
ちょうちんぴん /超珍品/
ちょうちんもち /提灯持ち/
ちょうつがい /蝶番/
ちょうづけ /丁付/丁付け/
ちょうづめ /腸詰/
ちょうづら /帳面/
ちょうてい /調停/朝廷/調定/長堤/超低/
ちょうていいいん /調停委員/
ちょうていいいんかい /調停委員会/
ちょうていおん /超低音/
ちょうていかかく /超低価格/
ちょうていきょくほ /長汀曲浦/
ちょうていきんり /超低金利/
ちょうていくう /超低空/
ちょうていくうひこう /超低空飛行/
ちょうていしゃ /調停者/
ちょうていそく /超低速/
ちょうていぶんさん /超低分散/
ちょうていやく /調停役/
ちょうてき /朝敵/
ちょうてじゅん /長手順/
ちょうてすう /超手数/
ちょうてつ /澄徹/
ちょうてぬき /超手抜き/
ちょうてん /頂点/長点/
ちょうてんかん /頂点間/
ちょうてんすう /頂点数/
ちょうてんれつ /頂点列/
ちょうでん /弔電/長電/
ちょうでんじ /超電磁/
ちょうでんどう /超伝導/超電導/
ちょうでんどうじしゃく /超電導磁石/
ちょうでんどうたい /超伝導体/
ちょうでんどうでんじしゃく /超伝導電磁石/
ちょうと /長途/
ちょうとう /長刀/
ちょうとうは /超党派/
ちょうとく /長徳;年号(995-999)/
ちょうとくだい /超特大/
ちょうとっか /超特価/
ちょうとっきゅう /超特急/
ちょうど /丁度/調度/
ちょうどう /町道/庁堂/
ちょうどういん /朝堂院;平城京・平安京の正庁/
ちょうどうけん /聴導犬/
ちょうどきゅう /超弩級/
ちょうどひん /調度品/
ちょうな /手斧/鐇/
ちょうない /町内/腸内/
ちょうないかい /町内会/
ちょうないかくしょ /町内各所/
ちょうないかんきょう /腸内環境;-を整える/
ちょうないさいきん /腸内細菌/
ちょうなめ /手斧目/
ちょうなん /長男/長南/嘲難/
ちょうなんもん /超難問/
ちょうにがて /超苦手/
ちょうにゅう /調乳/
ちょうにゅうもん /超入門/
ちょうにん /町人/
ちょうにんき /超人気/
ちょうにんきぞく /町人貴族/
ちょうにんげん /超人間/
ちょうねくたい /蝶ネクタイ/
ちょうねんげつ /長年月/
ちょうねんてん /腸捻転/
ちょうねんまく /腸粘膜;intestinal mucosa/
ちょうの /蝶野/
ちょうのうりょく /超能力/
ちょうのうりょくかいはつ /超能力開発/
ちょうのうりょくしゃ /超能力者/
ちょうのうりょくばんぐみ /超能力番組/
ちょうのつぼ /町坪/
ちょうは /長波/調波/
ちょうはい /朝拝/停廃/
ちょうはかく /超破格/
ちょうはずれ /帳外れ/
ちょうはちょう /長波長/
ちょうはつ /挑発/長髪/徴発;民衆から取り立てる。「馬を-する」/調髪/挑撥;「発」旧字/
ちょうはつこうい /挑発行為/
ちょうはつてき /挑発的/
ちょうはつど /挑発度/
ちょうはながた /蝶花形/
ちょうはん /丁半/
ちょうはんげんき /長半減期/
ちょうば /帳場/跳馬;体操の種目/嘲罵/
ちょうばいか /鳥媒花/
ちょうばく /帳幕/
ちょうばつ /懲罰/
ちょうばつてき /懲罰的/
ちょうばん /丁番/
ちょうひ /張飛;三国時代・蜀漢の武将/
ちょうひさん /超悲惨/
ちょうひっさつわざ /超必殺技/
ちょうひもりろん /超紐理論;=超弦理論/
ちょうひょう /帳票/徴表;[哲学]Merkmal/徴憑;[法]/帳表;?/
ちょうび /掉尾/
ちょうびけい /長尾鶏/
ちょうびさい /超微細/
ちょうびじん /超美人/
ちょうびふう /超微風/
ちょうびょう /長病/
ちょうびりゅうし /超微粒子/
ちょうびるい /長鼻類/
ちょうびんぼう /超貧乏/
ちょうふ /貼付/調布/長府/
ちょうふえき /調布駅/
ちょうふかん /調布間/
ちょうふがおか /調布ヶ丘/
ちょうふがわ /調布側/
ちょうふく /重複/
ちょうふくじゅんれつ /重複順列;[数学]nΠr=n^r/
ちょうふくぶん /重複分/
ちょうふこうこう /調布高校/
ちょうふさい /調布祭/
ちょうふし /調布市/
ちょうふてん /調布店/
ちょうぶ /頂部/町歩/
ちょうぶく /調伏/
ちょうぶつ /長物/
ちょうぶん /長文/弔文/
ちょうぶんさん /超分散/
ちょうぶんし /超分子/
ちょうへい /徴兵/長平/長兵/
ちょうへいき /超兵器/
ちょうへいきひ /徴兵忌避/
ちょうへいけんさ /徴兵検査/
ちょうへいせい /徴兵制/
ちょうへいせいど /徴兵制度/
ちょうへいそく /腸閉塞/
ちょうへいめん /超平面/
ちょうへいれい /徴兵令/
ちょうへいれつ /超並列/
ちょうへいれつがた /超並列型/
ちょうへいれつけいさん /超並列計算/
ちょうへいれつけいさんき /超並列計算機/
ちょうへいれつしょり /超並列処理/
ちょうへき /腸壁/
ちょうへん /長編/長篇/長辺/
ちょうへんか /長編化/
ちょうへんしょうせつ /長編小説/
ちょうへんせい /長編成/
ちょうへんせいか /長編成化/
ちょうへんばん /長編版/
ちょうほ /調歩/
ちょうほう /重宝/諜報/長保;年号(999-1004)/長方/調法/弔砲/
ちょうほういん /諜報員/
ちょうほうかつどう /諜報活動/
ちょうほうき /超法規/
ちょうほうきかん /諜報機関/
ちょうほうきてき /超法規的/
ちょうほうけい /長方形/
ちょうほうたい /長方体/
ちょうほしゅてき /超保守的/
ちょうほどうき /調歩同期/
ちょうほん /張本/
ちょうほんにん /張本人/
ちょうぼ /帳簿/徴募/
ちょうぼいん /長母音/
ちょうぼう /眺望/
ちょうぼうえん /超望遠/
ちょうぼえつらんけん /帳簿閲覧権/
ちょうぼかがく /帳簿価額/
ちょうぼじょう /帳簿上/
ちょうぼるい /帳簿類/
ちょうぼん /超凡/
ちょうまじめ /超真面目/
ちょうまじゅつ /超魔術/
ちょうまつ /長松/
ちょうまる /朝丸/
ちょうまんいん /超満員/
ちょうまんばけん /超万馬券/
ちょうみ /調味/
ちょうみえき /調味液/
ちょうみつ /稠密/
ちょうみつせい /稠密性/
ちょうみりょう /調味料/
ちょうみりょうなど /調味料等/
ちょうみりょうるい /調味料類/
ちょうみん /町民/兆民;人名,中江-/
ちょうみんぜい /町民税/
ちょうみんよう /町民用/
ちょうむ /庁務/
ちょうむじゅん /超矛盾/
ちょうむすび /蝶結び/
ちょうむち /超無知/
ちょうめ /丁目/
ちょうめい /町名/長命/長明/澄明/朝命/
ちょうめいきょく /超名曲/
ちょうめいばん /超名盤/
ちょうめいもん /超名門/
ちょうめいれいご /長命令語/
ちょうめん /帳面/帖面/
ちょうめんづら /帳面面/
ちょうもう /長毛/
ちょうもく /鳥目/
ちょうもくひじ /長目飛耳/
ちょうもじ /超文字/
ちょうもつ /寵物/
ちょうもと /帳元/
ちょうもん /聴聞/弔問/頂門;-の一針/長門/
ちょうもんかい /聴聞会/
ちょうもんのいっしん /頂門の一針/
ちょうや /長夜/聴野/
ちょうやく /跳躍/超訳/重訳/調薬/
ちょうやくじょうこく /跳躍上告/
ちょうやくにん /町役人/
ちょうやくりょく /跳躍力/
ちょうゆう /町有/
ちょうゆうめい /超有名/
ちょうゆうめいじん /超有名人/
ちょうゆうめいてん /超有名店/
ちょうよう /重用/徴用/重陽;陰暦9.9/朝陽/長幼/町陽/
ちょうようのじょ /長幼の序/
ちょうらい /朝来/頂礼/
ちょうらく /凋落/長楽/
ちょうらくしょう /超楽勝/
ちょうらくじ /長楽寺/
ちょうり /調理/蝶理/嘲詈/
ちょうりいん /調理員/
ちょうりき /調理器/
ちょうりきぐ /調理器具/
ちょうりぎじゅつ /調理技術/
ちょうりし /調理師/
ちょうりしつ /調理室/
ちょうりじかん /調理時間/
ちょうりずみ /調理済み/
ちょうりだい /調理台/
ちょうりちゅう /調理中/
ちょうりつ /町立/調律/
ちょうりつし /調律師/
ちょうりつしきょうかい /調律師協会/
ちょうりつほう /調律法/
ちょうりつようちえん /町立幼稚園/
ちょうりなべ /調理鍋/
ちょうりにん /調理人/
ちょうりば /調理場/
ちょうりひん /調理品/
ちょうりほう /調理法/
ちょうりほうほう /調理方法/
ちょうりゃく /調略/長暦;年号(1037-1040)/
ちょうりゅう /潮流/
ちょうりゅうしゅ /長粒種;long-grained. タイ米など ⇔短粒種/
ちょうりゅうつう /超流通/
ちょうりゅうどう /超流動/
ちょうりゅうまい /長粒米/
ちょうりょう /跳梁/潮陵;地名,小樽など/
ちょうりょうばっこ /跳梁跋扈/
ちょうりょく /聴力/張力/潮力/
ちょうりょくけんさ /聴力検査/
ちょうりょくはつでん /潮力発電/
ちょうりよう /調理用/
ちょうりろん /超理論/
ちょうりんかい /超臨界/
ちょうりんかいすい /超臨界水;supercritical water./
ちょうりんかいりゅうたい /超臨界流体/
ちょうるい /鳥類/
ちょうれい /朝礼/町礼/凋零/長齢/
ちょうれいか /張麗華/
ちょうれいだい /朝礼台/
ちょうれいぼかい /朝令暮改/
ちょうれん /調練/長連/
ちょうろ /朝露/
ちょうろう /長老/嘲弄/
ちょうろぎ /草石蚕;=ちょろぎ/
ちょうろく /長禄;年号(1457-1460)/
ちょうわ /調和/長和;年号(1012-1017)/
ちょうわおん /長和音/
ちょうわしんどうし /調和振動子/
ちょうわすうれつ /調和数列/
ちょうわてき /調和的/
ちょうわへいきん /調和平均/
ちょき /猪牙/
ちょきぶね /猪牙舟/
ちょきん /貯金/
ちょきんがく /貯金額/
ちょきんきょく /貯金局/
ちょきんじむ /貯金事務/
ちょきんつうちょう /貯金通帳/
ちょきんばこ /貯金箱/
ちょきんりょう /貯金量/
ちょく /直/勅/猪口/捗/飭/敕;「勅」の異体字/稙;早蒔きの稲 (「植」とは別)/躅;躑躅(てきちょく,つつじ)/陟;進陟(≒進捗)/
ちょく> /直;直証,直日,直アド/
ちょくえい /直営/直衛/
ちょくえいてん /直営店/
ちょくえん /直掩/
ちょくえんすい /直円錐/
ちょくおう /直往/
ちょくおうまいしん /直往邁進/
ちょくおん /直音/
ちょくか /直下/
ちょくがん /勅願/
ちょくがんじ /勅願寺/
ちょくげき /直撃/
ちょくげきだん /直撃弾/
ちょくげん /直言/
ちょくご /直後/勅語/
ちょくさ /直鎖/
ちょくさい /直截;=ちょくせつ/直裁/勅裁/
ちょくさいてき /直截的/
ちょくし /直視/勅使;勅旨の伝令/勅旨/
ちょくしゃ /直射/直写;直接書き写す/
ちょくしゃにっこう /直射日光/
ちょくしゃほう /直射砲/
ちょくしゅつ /直出/
ちょくしょ /勅書/
ちょくしょう /勅詔/
ちょくしょうてん /直焦点/
ちょくしん /直進/
ちょくしんあんていせい /直進安定性/
ちょくしんうんどう /直進運動/
ちょくしんしゃ /直進車/
ちょくしんじ /直進時/
ちょくしんせい /直進性/
ちょくしんちゅう /直進中/
ちょくしんほうこう /直進方向/
ちょくじ /直示/植字/
ちょくじつ /直実/
ちょくじゅ /勅授/
ちょくじょ /直叙/
ちょくじょう /直上/直情/勅定;天子の決定/勅諚;天子の命令/
ちょくじょうけいこう /直情径行/
ちょくじょうてき /直情的/
ちょくせい /直生/
ちょくせいはいしゅ /直生胚珠/
ちょくせき /直積/
ちょくせつ /直接/直截;回りくどくない/直説;[文法]indicatif/
ちょくせつ> /直接;-照明,-疑問/
ちょくせつあいて /直接相手/
ちょくせつえいきょう /直接影響/
ちょくせつおん /直接音/
ちょくせつかいじょう /直接会場/
ちょくせつかいせん /直接回線/
ちょくせつかいとう /直接回答/
ちょくせつかいにゅう /直接介入/
ちょくせつかくにん /直接確認/
ちょくせつかんせつ /直接間接/
ちょくせつきじゅつ /直接記述/
ちょくせつきどう /直接起動/
ちょくせつきょうせい /直接強制/
ちょくせつきんゆう /直接金融/
ちょくせつけいやく /直接契約/
ちょくせつげんいん /直接原因/
ちょくせつこう /直接光/
ちょくせつこうげき /直接攻撃/
ちょくせつこうしょう /直接交渉/
ちょくせつこうどう /直接行動/
ちょくせつこうにゅう /直接購入/
ちょくせつさぎょう /直接作業/
ちょくせつしょうこ /直接証拠/
ちょくせつしょうめい /直接照明/
ちょくせつせいきゅう /直接請求/
ちょくせつせいきゅうけん /直接請求権/
ちょくせつせいぎょ /直接制御/
ちょくせつせっしゅ /直接摂取/
ちょくせつせつぞく /直接接続/
ちょくせつせん /直接線/直接戦/
ちょくせつせんきょ /直接選挙/
ちょくせつせんきょせい /直接選挙制/
ちょくせつせんとう /直接戦闘/
ちょくせつぜい /直接税/
ちょくせつそうさ /直接操作/
ちょくせつそくてい /直接測定/
ちょくせつたいおう /直接対応/
ちょくせつたいけつ /直接対決/
ちょくせつちゅうもん /直接注文/
ちょくせつつうしん /直接通信/
ちょくせつていしゅつ /直接提出/
ちょくせつてき /直接的/直截的/
ちょくせつてきえいきょう /直接的影響/
ちょくせつてんそう /直接転送/
ちょくせつとうし /直接投資/
ちょくせつにゅうしゃ /直接入射/
ちょくせつにゅうしゅ /直接入手/
ちょくせつにゅうりょく /直接入力/
ちょくせつは /直接波/
ちょくせつはっちゅう /直接発注/
ちょくせつはんばい /直接販売/
ちょくせつばち /直接鉢/
ちょくせつひ /直接費/
ちょくせつひかく /直接比較/
ちょくせつほう /直接法/直説法;[文法]indicatif/
ちょくせつみんしゅしゅぎ /直接民主主義/
ちょくせつみんしゅせい /直接民主制/
ちょくせつもくてきご /直接目的語/
ちょくせつゆにゅう /直接輸入/
ちょくせつりえき /直接利益/
ちょくせつりよう /直接利用/
ちょくせつれんらく /直接連絡/
ちょくせつわほう /直接話法;[文法]direct speech/
ちょくせん /直線/勅撰/
ちょくせんいっき /直線一気/
ちょくせんうんどう /直線運動/
ちょくせんかいき /直線回帰/
ちょくせんかそく /直線加速/
ちょくせんかそくき /直線加速器/
ちょくせんがい /直線外/
ちょくせんがわ /直線側/
ちょくせんきょり /直線距離/
ちょくせんくかん /直線区間/
ちょくせんぐん /直線群/
ちょくせんしき /直線式/
ちょくせんしゅう /勅撰集/
ちょくせんしょうぶ /直線勝負/
ちょくせんじょう /直線上/直線状/
ちょくせんせい /直線性/
ちょくせんせんろ /直線線路/
ちょくせんてき /直線的/
ちょくせんどうろ /直線道路/
ちょくせんび /直線美/
ちょくせんふり /直線不利/
ちょくせんぶぶん /直線部分/
ちょくせんへんこう /直線偏光/
ちょくせんほかん /直線補間/直線補完/
ちょくせんまえ /直線前/
ちょくせんわかしゅう /勅撰和歌集/
ちょくぜい /直税/
ちょくぜん /直前/
ちょくぜんゆそう /直前輸送/
ちょくそう /直送/
ちょくぞく /直属/
ちょくたつ /直達/
ちょくたつは /直達波/
ちょくだい /勅題/
ちょくちょう /直腸/
ちょくちょうえん /直腸炎;[医]proctitis/
ちょくちょうがん /直腸癌/直腸がん/直腸ガン/
ちょくつう /直通/
ちょくつううんてん /直通運転/
ちょくつううんよう /直通運用/
ちょくつうきゅうこう /直通急行/
ちょくつうじゅんきゅう /直通準急/
ちょくつうせん /直通線/
ちょくつうでんしゃ /直通電車/
ちょくつうでんわ /直通電話/
ちょくつうとっきゅう /直通特急/
ちょくつうびん /直通便/
ちょくつうれっしゃ /直通列車/
ちょくつうろせん /直通路線/
ちょくで /直出/
ちょくとう /直刀/勅答/直答/
ちょくどう /直道/直動/
ちょくどく /直読/
ちょくにゅう /直入/
ちょくにん /勅任/
ちょくにんかん /勅任官/
ちょくはい /直配/
ちょくはん /直販/直播;[農業]じかまき./勅版/
ちょくはんてん /直販店/
ちょくばい /直売/
ちょくばいてん /直売店/
ちょくひつ /直筆/
ちょくふ /直付/
ちょくほう /直方/
ちょくほうたい /直方体/
ちょくめい /勅命/
ちょくめん /直面/
ちょくもう /直毛;straight hair/
ちょくやく /直訳/
ちょくやくてき /直訳的/
ちょくゆ /直喩;[修辞]simile/勅諭/
ちょくゆしゅつ /直輸出/
ちょくゆにゅう /直輸入/
ちょくゆにゅうばん /直輸入版/
ちょくゆほう /直喩法/
ちょくりつ /直立/
ちょくりつけい /直立茎/
ちょくりつさいぼう /直立細胞/
ちょくりつし /直立枝/
ちょくりつしせい /直立姿勢/
ちょくりつじょうたい /直立状態/
ちょくりつせい /直立性/
ちょくりつふどう /直立不動/
ちょくりつほこう /直立歩行/
ちょくりゅう /直流/
ちょくりゅうか /直流化/
ちょくりゅうき /直流機/
ちょくりゅうきかんしゃ /直流機関車/
ちょくりゅうくかん /直流区間/
ちょくりゅうしんごう /直流信号/
ちょくりゅうせいぶん /直流成分/
ちょくりゅうそうでん /直流送電/
ちょくりゅうていこう /直流抵抗/
ちょくりゅうでんか /直流電化/
ちょくりゅうでんかくかん /直流電化区間/
ちょくりゅうでんしゃ /直流電車/
ちょくりゅうでんりゅう /直流電流/
ちょくりゅうはつでんき /直流発電機/
ちょくりゅうぶ /直流部/
ちょくりゅうほうしき /直流方式/
ちょくりゅうよう /直流用/
ちょくれい /勅令/直隷/
ちょくれつ /直列/
ちょくれつがた /直列型/
ちょくれつけい /直列系/
ちょくれつしき /直列式/
ちょくれつしよう /直列使用/
ちょくれつせつぞく /直列接続/
ちょくろ /直路/
ちょくわ /直和/
ちょげん /緒言/
ちょこ /猪口/
ちょこあじ /チョコ味/
ちょこう /著効/
ちょこざい /猪口才/
ちょこれーと /貯古齢糖/
ちょこれーといろ /チョコレート色;chocolate brown/
ちょさく /著作/
ちょさくか /著作家/
ちょさくぐん /著作群/
ちょさくけん /著作権/
ちょさくけんいはん /著作権違反/
ちょさくけんかんけい /著作権関係/
ちょさくけんきょうかい /著作権協会/
ちょさくけんしゃ /著作権者/
ちょさくけんしょゆうしゃ /著作権所有者/
ちょさくけんしようりょう /著作権使用料/
ちょさくけんしんがい /著作権侵害/
ちょさくけんじゃ /著作権者/
ちょさくけんじょう /著作権上/
ちょさくけんじょうもんだい /著作権上問題/
ちょさくけんせいど /著作権制度/
ちょさくけんだんたい /著作権団体/
ちょさくけんてき /著作権的/
ちょさくけんなど /著作権等/
ちょさくけんひょうじ /著作権表示/
ちょさくけんぶつ /著作権物/
ちょさくけんほう /著作権法/
ちょさくけんほうき /著作権放棄/
ちょさくけんほご /著作権保護/
ちょさくけんぽうじょう /著作権法上/
ちょさくけんもんだい /著作権問題/
ちょさくけんりょう /著作権料/
ちょさくしゃ /著作者/
ちょさくしゃざいさんけん /著作者財産権/
ちょさくしゃじんかくけん /著作者人格権/
ちょさくしゃめい /著作者名/
ちょさくちゅう /著作中/
ちょさくぶつ /著作物/
ちょさくぶつりゅうつう /著作物流通/
ちょさくりんせつけん /著作隣接権/
ちょさくりんせつけんしゃ /著作隣接権者/
ちょし /楮紙/
ちょしゃ /著者/
ちょしゃあて /著者宛/
ちょしゃきごう /著者記号/
ちょしゃしょうかい /著者紹介/
ちょしゃじしん /著者自身/
ちょしゃたち /著者達/
ちょしゃめい /著者名/
ちょしゃめいじゅん /著者名順/
ちょしゃりゃくれき /著者略歴/
ちょしょ /著書/
ちょしょめい /著書名/
ちょじゅつ /著述/
ちょじゅつか /著述家/
ちょじゅつぎょう /著述業/
ちょすい /貯水/
ちょすいそう /貯水槽/
ちょすいそしき /貯水組織/
ちょすいち /貯水池/
ちょすいよう /貯水用/
ちょすいりょう /貯水量/
ちょすかべ /長宗我部/
ちょせん /緒戦/
ちょぞう /貯蔵/著増/
ちょぞうこ /貯蔵庫/
ちょぞうこん /貯蔵根/
ちょぞうしつ /貯蔵室/
ちょぞうしゅ /貯蔵酒/
ちょぞうそう /貯蔵槽/
ちょぞうそしき /貯蔵組織/
ちょぞうひん /貯蔵品/
ちょたん /貯炭/
ちょだい /著大/
ちょちく /貯蓄/
ちょちくがく /貯蓄額/
ちょちくぎんこう /貯蓄銀行;savings bank/
ちょちくさいけん /貯蓄債券/
ちょちくせいこう /貯蓄性向/
ちょちくほけん /貯蓄保険/
ちょちくよきん /貯蓄預金;saving deposit/
ちょっか /直下/
ちょっかい /直快/
ちょっかがた /直下型/
ちょっかがたじしん /直下型地震/
ちょっかく /直角;⊥/直覚/⊥/
ちょっかくさんかくけい /直角三角形/
ちょっかくさんかっけい /直角三角形/
ちょっかくざひょう /直角座標/
ちょっかくそうきょくせん /直角双曲線/
ちょっかくてき /直覚的/
ちょっかくほうこう /直角方向/
ちょっかっこう /直滑降/
ちょっかつ /直轄/
ちょっかつち /直轄地/
ちょっかつりょう /直轄領/
ちょっかん /直感/直観;[哲学]intuition/直管/直諫/
ちょっかんしゅぎ /直観主義;intuitionism/直感主義;?/
ちょっかんしゅぎしゃ /直観主義者/
ちょっかんしゅぎろんり /直観主義論理/
ちょっかんてき /直感的/直観的/
ちょっかんひりつ /直間比率/
ちょっき /直帰/
ちょっきゅう /直球/
ちょっきゅうしょうぶ /直球勝負/
ちょっきょ /勅許/
ちょっきん /直近/
ちょっけい /直径/直系/
ちょっけい> /直径;-2センチ/
ちょっけいいんぞく /直系姻族/
ちょっけいけつぞく /直系血族/
ちょっけいしそん /直系子孫/
ちょっけいそんぞく /直系尊属/
ちょっけいひぞく /直系卑属/
ちょっけいやく /直径約/
ちょっけつ /直結/
ちょっけつしき /直結式/
ちょっこう /直行;direct/直交;90°/直航/⊥/
ちょっこうかんすう /直交関数/
ちょっこうかんすうけい /直交関数系/
ちょっこうがた /直交型/
ちょっこうきてい /直交基底/
ちょっこうぎょうれつ /直交行列/
ちょっこうぐみ /直行組/
ちょっこうけい /直交系/
ちょっこうざひょう /直交座標/
ちょっこうざひょうけい /直交座標系/
ちょっこうじく /直交軸/
ちょっこうせい /直交性/
ちょっこうちょっき /直行直帰/
ちょっこうびん /直行便/
ちょっこうぶんかい /直交分解/
ちょっこうわ /直交和/
ちょっこん /直根;[植物]taproot/
ちょっと /一寸/
ちょっとみ /一寸見/
ちょとつ /猪突/
ちょとつもうしん /猪突猛進/
ちょはっかい /猪八戒/
ちょびひげ /ちょび髭/
ちょぶん /著聞/
ちょへん /著変/
ちょぼ /点/樗蒲/
ちょぼいち /樗蒲一/
ちょぼがたり /点語り/
ちょぼく /樗木/貯木/
ちょぼくじょう /貯木場/
ちょま /苧麻/
ちょめい /著名/著明/
ちょめいさっか /著名作家/
ちょめいじん /著名人/
ちょめちょめ /××/
ちょりつ /佇立/
ちょりゅう /貯留/
ちょろぎ /草石蚕/甘露子;=草石蚕/
ちょろく /著録/
ちょろん /緒論/
ちょんがー /総角;[朝鮮語]ch'onggak/
ちょんぼ /錯和/
ちょんまげ /丁髷/
ちょんりま /千里馬/
ちよ /千代/千夜/
ちよかわ /千代川/
ちよがみ /千代紙/
ちよくら /千代倉/
ちよこ /千代子/
ちよだ /千代田/
ちよだかこうけんせつ /千代田化工建設;[企業名]/
ちよだく /千代田区/
ちよだじょがくえん /千代田女学園/
ちよだせん /千代田線/
ちよだせんあかさか /千代田線赤坂/
ちよちょう /千代町/
ちよの /千代乃/
ちよまる /千代丸/
ちよろず /千万/
ちらく /地絡/地落/
ちらし /散らし/
ちらしがき /散らし書き/
ちらしずし /ちらし寿司/散らし寿司/散らし鮨/
ちらん /知覧;地名/治乱/
ちり /地理/塵/知里/智利;Chile/
ちりあくた /塵芥/
ちりいん /地理院/
ちりがく /地理学/
ちりがみ /塵紙/ちり紙/チリ紙/
ちりがみこうかん /塵紙交換/
ちりきょういく /地理教育/
ちりぎわ /散り際/
ちりけ /身柱/
ちりけもと /身柱元/
ちりぢり /散り散り/
ちりてき /地理的/
ちりてきはいけい /地理的背景/
ちりてきぶんぷ /地理的分布/
ちりとり /塵取/
ちりなべ /ちり鍋/
ちりはま /千里浜/
ちりひじ /塵泥/
ちりほこり /塵埃;=じんあい/
ちりましほ /知里真志保/
ちりめん /縮緬/
ちりめんえ /縮緬絵/
ちりめんざこ /縮緬雑魚/
ちりめんじゃこ /縮緬雑魚/
ちりゃく /知略/智略/治略/
ちりゅう /知立/
ちりゅうし /知立市/
ちりゆきえ /知里幸恵/
ちりょ /知慮/智慮/
ちりょう /治療/
ちりょうき /治療器/
ちりょうけいか /治療経過/
ちりょうこうい /治療行為/
ちりょうこうか /治療効果/
ちりょうご /治療後/
ちりょうざい /治療剤/
ちりょうし /治療師/
ちりょうしつ /治療室/
ちりょうしゃ /治療者/
ちりょうじ /治療時/
ちりょうだい /治療代/
ちりょうちゅう /治療中/
ちりょうはんい /治療範囲/
ちりょうひ /治療費/
ちりょうほう /治療法/
ちりょうほうほう /治療方法/
ちりょうやく /治療薬/
ちりょうよう /治療用/
ちりょうれい /治療例/
ちりょうれき /治療歴/
ちりょく /知力;intellect/地力;fertility/
ちれい /地霊/
ちれき /地歴/
ちろう /遅漏/
ちろうい /地労委/
ちわ /痴話/
ちわく /地惑/
ちわげんか /痴話喧嘩/
ちわり /地割/地割り/
ちわんぞく /チワン族;Zhuang/
ちん /珍/賃/朕/狆/沈;沈没/枕;まくら/鴆;毒鳥/亭;あずまや/陳;陳謝/鎮;鎮火/椿/砧;きぬた/碪;=砧/闖;闖入/抻;(のばす)/趁;(おう)/珎;「珍」の異体字。「和同開珎」/鎭;「鎮」の旧字(人名用漢字)/
ちん> /珍/
ちんあげ /賃上げ/
ちんあつ /鎮圧/
ちんあん /珍案/
ちんいーそー /清一色/
ちんうつ /沈鬱/
ちんか /沈下/鎮火/
ちんかきょう /沈下橋/
ちんかさい /鎮花祭/鎮火祭/
ちんがいざい /鎮咳剤/
ちんがし /賃貸し/
ちんがり /賃借り/
ちんき /珍奇/丁幾/
ちんきゃく /珍客/
ちんきゅう /陳宮/
ちんきろく /珍記録/
ちんきん /沈金/賃金/
ちんぎょ /珍魚/
ちんぎょらくがん /沈魚落雁/
ちんぎん /賃金/賃銀/沈吟/
ちんぎんかくさ /賃金格差/
ちんぎんしすう /賃金指数;[経済]/
ちんぎんじょうしょう /賃金上昇/
ちんぎんすいじゅん /賃金水準/
ちんぎんたいけい /賃金体系/
ちんぎんとうそう /賃金闘争;pay dispute/
ちんぐるま /稚児車;[植物]バラ科の高山植物/
ちんけいやく /鎮痙薬/
ちんげい /珍芸/
ちんげんさい /青梗菜/
ちんこう /沈降/鎮江/沈香/
ちんこうせい /沈降性/
ちんこん /鎮魂/
ちんこんか /鎮魂歌/
ちんこんきしん /鎮魂帰神/
ちんこんきょく /鎮魂曲/
ちんご /鎮護/陳呉/珍語/
ちんごこっか /鎮護国家;仏法による国家の保護/
ちんさ /沈渣/
ちんさげ /賃下げ/
ちんざ /鎮座/
ちんざんそう /椿山荘/
ちんし /沈思/
ちんしごと /賃仕事/
ちんしもっこう /沈思黙考/
ちんしゃ /陳謝/
ちんしゃく /賃借/
ちんしゃくけん /賃借権/
ちんしゃくにん /賃借人/
ちんしゃくりょう /賃借料/
ちんしゃじょう /陳謝状/
ちんしゃち /沈砂池/
ちんしゅ /珍種/珍手/
ちんしょ /珍書/陳書;二十一史/砧杵/
ちんしょう /沈床;堤防の基礎。沈設する/沈鐘/
ちんしょうごこう /陳勝呉広/
ちんじ /珍事/椿事/
ちんじゃおろーす /青椒肉絲/
ちんじゃおろーすー /青椒肉絲/
ちんじゅ /鎮守/珍寿/
ちんじゅう /珍重;ちんちょう/珍獣/
ちんじゅつ /陳述/
ちんじゅつしょ /陳述書/
ちんじゅふ /鎮守府/
ちんじょう /陳情;petition/枕上/陳状;反駁の書状/
ちんじょうしょ /陳情書/
ちんすい /沈水/
ちんすいしょくぶつ /沈水植物/
ちんせい /鎮静;†落ち着かせる。「-剤」/沈静;†落ち着く。「-化」/鎮星;土星/
ちんせいか /沈静化/鎮静化/
ちんせいざい /鎮静剤/
ちんせき /沈積/珍石/珍籍/枕席/
ちんせつ /珍説/沈設;沈めて設置する/
ちんせん /沈船/沈潜/賃銭/
ちんぜい /鎮西/
ちんそ /賃租/
ちんそうだん /珍走団/
ちんぞう /珍蔵/
ちんたい /賃貸/沈滞/
ちんたいあぱーと /賃貸アパート/
ちんたいぎょう /賃貸業/
ちんたいけいやくしゃ /賃貸契約者/
ちんたいしゃく /賃貸借/
ちんたいじゅうたく /賃貸住宅/
ちんたいにん /賃貸人/
ちんたいぶっけん /賃貸物件/
ちんたいまんしょん /賃貸マンション/
ちんたいりょう /賃貸料/
ちんたお /青島;Qingdao/
ちんだい /鎮台/
ちんだるげんしょう /チンダル現象/
ちんだん /珍談/沈檀/
ちんだんきだん /珍談奇談/
ちんちゃく /沈着/
ちんちゃくれいせい /沈着冷静/
ちんちょう /珍重/珍鳥/
ちんちょうげ /沈丁花/
ちんちん /沈々/
ちんつう /鎮痛;(pain relief) -剤/沈痛;(painful) -な面持ち/
ちんつうさよう /鎮痛作用/
ちんつうざい /鎮痛剤/
ちんつうやく /鎮痛薬/
ちんてい /鎮定/
ちんでき /沈溺/
ちんでん /沈殿/沈澱/
ちんでんぶつ /沈殿物/
ちんとう /枕頭/珍答/
ちんとうご /陳套語/
ちんとうびょう /沈頭鋲/
ちんどうしき /沈胴式/
ちんどうちゅう /珍道中/
ちんどく /鴆毒/
ちんどんや /チンドン屋/ちんどん屋/
ちんにゅう /闖入/
ちんねん /珍念/
ちんば /跛/
ちんばめん /珍場面/
ちんばん /珍盤/
ちんぱん /青幇/
ちんぴ /陳皮/
ちんぴん /珍品/
ちんぶ /鎮撫/
ちんぶつ /珍物/
ちんぶん /珍聞/
ちんぷ /陳腐/
ちんぷか /陳腐化/
ちんぷれー /珍プレー/
ちんぷんかん /珍紛漢/珍糞漢/
ちんぷんかんぷん /珍紛漢紛/
ちんべん /陳弁/
ちんぺい /陳平/
ちんぺん /枕辺/
ちんぼつ /沈没/
ちんぼつかん /沈没艦/
ちんぼつご /沈没後/
ちんぼつせん /沈没船/
ちんぽう /珍宝/
ちんぽこ /似指/
ちんぽん /珍本/
ちんみ /珍味/
ちんみょう /珍妙/
ちんむるい /珍無類/
ちんめい /珍名/
ちんめん /沈湎/
ちんもく /沈黙/
ちんもん /珍問/
ちんようざい /鎮痒剤;痒み止め/
ちんらおとう /清老頭/
ちんりつ /賃率/
ちんりょう /賃料/
ちんりろん /珍理論/
ちんりん /沈淪/
ちんれつ /陳列/
ちんれつだな /陳列棚/
ちんれつまど /陳列窓;show window/
ちんろうどう /賃労働/
ぢ /痔/地/
ぢあけ /地上げ/
ぢえ /知恵/
ぢか /直/近/
ぢから /力/
ぢくぢ /忸怩/
ぢぐち /地口;旧仮名。「じぐち」/
ぢげ /地下/
ぢごく /地獄/
ぢさん /持参/
ぢざけ /地酒/
ぢしん /地震/
ぢぞく /持続/
ぢだい /地代/
ぢとり /地鶏/
ぢどり /地鶏/
ぢば /地場/
ぢばく /地縛/
ぢひびき /地響き/
ぢふぶき /地吹雪/
ぢみ /地味/
ぢみち /地道/
ぢめん /地面/
ぢもと /地元/
ぢゃわん /茶碗/
ぢゅう /中/
ぢょうし /調子/
っこ /っ子;鍵-,魔女-,博多-/
つ /津/都;都合/通/付/積/つ/ツ/
つーいーそー /字一色/
つーばいふぉー /２×４/
つーぱい /字牌/
つーもー /自摸/
つぁいちぇん /再見;[中国語]zai jian (See you)/
つい /対/追/終;「-に」「-の住処」/鎚;かなづち/槌;きづち/縋;すが・る/椎;脊椎/堆;(呉音)/墜;墜落/遂;-に/對;「対」の旧字/築;?/
ついう /堆烏/
ついえ /毅/
ついおく /追憶/
ついか /追加/
ついかあんない /追加案内/
ついかい /追懐/
ついかがくしゅう /追加学習/
ついかきのう /追加機能/
ついかこうえん /追加公演/
ついかこうかい /追加公開/
ついかこうにゅう /追加購入/
ついかこうもく /追加項目/
ついかさくじょ /追加削除/
ついかさくひん /追加作品/
ついかしつもん /追加質問/
ついかしゅちょう /追加主張/
ついかしょり /追加処理/
ついかじっそう /追加実装/
ついかじょうほう /追加情報/
ついかそうび /追加装備/
ついかちゅうもん /追加注文/
ついかてき /追加的/
ついかてん /追加点/
ついかとうし /追加投資/
ついかとうろくりょう /追加登録料/
ついかはいとう /追加配当/
ついかはいぶん /追加配分/
ついかはっちゅう /追加発注/
ついかはっぴょう /追加発表/
ついかはつばい /追加発売/
ついかばん /追加版/
ついかひょう /追加表/
ついかひよう /追加費用/
ついかぶそう /追加武装/
ついかぶぶん /追加部分/
ついかぶん /追加分/
ついかぶんけん /追加文献/
ついかほうこく /追加報告/
ついかよさん /追加予算/
ついかりょうきん /追加料金/
ついかれい /追加例/
ついかん /追完/
ついかんばん /椎間板/
ついかんばんへるにあ /椎間板ヘルニア/
ついがいねん /対概念/
ついき /追記/築城/鎚起/立木/
ついきしき /追記式/
ついきじこう /追記事項/
ついきそ /追起訴/
ついきゅう /追求;†追い求める。「理想-」/追及;†執拗に問い質す。「責任-」/追究;†追い求め明らかにする。「真理-」/椎弓/追給/
ついきゅうしせい /追求姿勢/
ついきん /追金/
ついぎご /対義語/
ついく /対句/
ついげき /追撃/
ついげんそう /対幻想/
ついこう /追行/追考/
ついこうちゅう /遂行中/
ついこく /堆黒/
ついこつ /椎骨/
ついご /対語/
ついごう /追号/
ついし /追試/墜死/追思;追想/追諡;おくりなの追贈/
ついしけん /追試験/
ついしゅ /追修/堆朱/
ついしゅつ /追出/
ついしょう /追従/
ついしょうめつ /対消滅/
ついしん /追伸/P.S./
ついじ /築地/築墻/
ついじっけん /追実験/
ついじべい /築地塀;屋根のある土塀/
ついじゅう /追従/
ついじゅうせい /追従性/
ついじゅく /追熟/
ついじん /追尋/
ついすう /対数/
ついずい /追随/
ついずいせい /追随性/
ついせいせい /対生成/
ついせき /追跡/追惜;mourn/
ついせきがた /追跡型/
ついせきしゅざい /追跡取材/
ついせきちょうさ /追跡調査/
ついせきほうどう /追跡報道/
ついせきほうほう /追跡方法/
ついせん /対線/
ついぜん /追善/
ついぜんくよう /追善供養/
ついそ /追訴/
ついそう /追走/追想/追送/
ついそうけん /追送検/
ついぞ /終ぞ/
ついぞう /追贈/
ついたい /椎体/
ついたいけん /追体験/
ついたち /一日/朔日/１日/1日/
ついたて /衝立/
ついだつ /追奪/
ついちょう /追徴/
ついちょうかぜい /追徴課税/
ついちょうがく /追徴額/
ついちょうきん /追徴金/
ついて /就いて/就て/
ついで /序で;by the way/次いで;next/尋いで/序/
ついでに /序でに/
ついとう /追悼/追討/
ついとうしき /追悼式/
ついとうじょうえい /追悼上映/
ついとうばんぐみ /追悼番組/
ついとうぶん /追悼文/
ついとつ /追突/
ついとつじこ /追突事故/
ついとつぼうし /追突防止/
ついな /追儺;節分の豆まき/都維那;[仏教]/
ついに /遂に/終に/
ついにん /追認/
ついのう /追納/
ついのすみか /終の栖/終の住み処/
ついひ /追肥/
ついび /追尾/
ついびせいど /追尾精度/
ついびそうち /追尾装置/
ついふく /追捕/追復/
ついふくきょく /追復曲;canon/
ついぶ /追捕/
ついほ /追補;supplement/追捕;=ついぶ/
ついほう /追放/
ついほううんどう /追放運動/
ついほうかいじょ /追放解除/
ついほばん /追補版/
ついぼ /追慕/
ついらく /墜落/
ついらくし /墜落死/
ついらくじこ /墜落事故/
ついろく /追録/
つう /通/痛;pain/
つういいそう /字一色/
つういん /通院/痛飲/
つういんこうつうひ /通院交通費/
つういんしゃ /通院者/
つううん /通運/
つうえん /通園/
つうか /通過;passage/通貨;currency/
つうかい /痛快/通解/通快;[略語]通勤快速/痛悔/
つうかいき /通過域/
つうかうんてん /通過運転/
つうかえき /通過駅/
つうかかのう /通過可能/
つうかがた /通過型/
つうかきき /通貨危機/
つうかきごう /通貨記号/
つうかきゃく /通過客/
つうかぎれい /通過儀礼/
つうかく /痛覚/通客/
つうかけいろ /通過経路/
つうかこく /通過国/
つうかご /通過後/
つうかしゃ /通過者/
つうかしゅぎ /通貨主義;monetarismの訳語/
つうかじ /通過時/
つうかじかん /通過時間/
つうかじこく /通過時刻/
つうかじゅんい /通過順位/
つうかせいげん /通過制限/
つうかせいさく /通貨政策/
つうかせん /通過線/
つうかそくど /通過速度/
つうかたいいき /通過帯域/
つうかたんい /通貨単位/
つうかちゅう /通過中/
つうかてん /通過点/
つうかでんしゃ /通過電車/
つうかれっしゃ /通過列車/
つうかん /痛感/通関/通巻;「-204号」/通観;survey/
つうかんご /通関後/
つうかんし /通関士;国家資格/
つうかんじ /通関時/
つうがく /通学/
つうがくけいろ /通学経路/
つうがくさき /通学先/
つうがくしょうめいしょ /通学証明書/
つうがくじ /通学時/
つうがくじかん /通学時間/
つうがくじかんたい /通学時間帯/
つうがくせい /通学生/
つうがくちゅう /通学中/
つうがくゆそう /通学輸送/
つうがくよう /通学用/
つうがくろ /通学路/
つうがくろせん /通学路線/
つうき /通期/通気/
つうきこう /通気口/通気孔/
つうきこうぞう /通気構造/
つうきせい /通気性/
つうきそしき /通気組織/
つうきゅう /通級;「-指導学級」「-するためには」/
つうきん /通勤/
つうきんかいそく /通勤快速/
つうきんきゃく /通勤客/
つうきんけいろ /通勤経路/
つうきんけいろじょう /通勤経路上/
つうきんけん /通勤圏/
つうきんしゃ /通勤者;†commuter/通勤車;†commuter cars/
つうきんしゃりょう /通勤車両/
つうきんじ /通勤時/
つうきんじかん /通勤時間/
つうきんじかんたい /通勤時間帯/
つうきんじごく /通勤地獄/
つうきんじじょう /通勤事情/
つうきんじゅよう /通勤需要/
つうきんちゅう /通勤中/
つうきんつうがく /通勤通学/
つうきんてあて /通勤手当/
つうきんていき /通勤定期/
つうきんていきだい /通勤定期代/
つうきんてつどう /通勤鉄道/
つうきんでんしゃ /通勤電車/
つうきんとちゅう /通勤途中/
つうきんとっかい /通勤特快/
つうきんとっきゅう /通勤特急/
つうきんひ /通勤費/
つうきんひほじょ /通勤費補助/
つうきんゆそう /通勤輸送/
つうきんよう /通勤用/
つうきんらっしゅ /通勤ラッシュ/
つうきんりゅうどう /通勤流動/
つうきんれっしゃ /通勤列車/
つうきんろ /通勤路/
つうきんろせん /通勤路線/
つうぎょう /通暁/
つうく /痛苦/
つうけい /通計/
つうけん /通研/電気通信研究所;※abbrev/東北大学電気通信研究所;※abbrev/
つうげき /痛撃/
つうげん /痛言/
つうこう /通行/通航;「運河を-する」/通好;「-条約」/通交;≒通好/通工;[略語]通信工業/通功;[キリスト教]communion/
つうこうか /通行可/
つうこうかのう /通行可能/
つうこうきょか /通行許可/
つうこうきんし /通行禁止/
つうこうきんしいはん /通行禁止違反/
つうこうくぶん /通行区分/
つうこうけん /通行券;†ticket.「-をお取りください」/通行権;†right-of-way.「袋地-」/
つうこうしゃ /通行車/
つうこうしょう /通行証/
つうこうぜい /通行税/
つうこうちゅう /通行中/
つうこうどめ /通行止め/通行止/
つうこうにん /通行人/
つうこうふか /通行不可/
つうこうふのう /通行不能/
つうこうぼん /通行本/
つうこうりょう /通行料/通行量/
つうこうりょうきん /通行料金/
つうこく /通告/痛哭/
つうこくしょ /通告書/
つうこくしょぶん /通告処分/
つうこん /痛恨/
つうこんじ /痛恨事/
つうご /通語/
つうごう /通号/
つうごのみ /通好み/
つうさん /通算/通産/
つうさん> /通算;-成績,-200勝,-データ/
つうさんきょく /通産局/
つうさんげつ /通算月/
つうさんしょう /通産省;NB:2001年1月の中央省庁再編で経済産業省に再編された/通産相;†大臣/通商産業省;※abbrev/
つうさんしょうこうぎいん /通産省工技院/
つうさんせいせき /通算成績/
つうさんだりつ /通算打率/
つうさんとくてん /通算得点/
つうさんねん /通算年/
つうし /通史/
つうしき /通式/
つうしゃく /通釈/
つうしょ /通所;-介護/通書/
つうしょう /通称/通商/
つうしょうかいぎ /通商会議/
つうしょうこうかいじょうやく /通商航海条約/
つうしょうさんぎょうしょう /通商産業省;NB:2001年1月の中央省庁再編で経済産業省に再編された/
つうしょうじょうやく /通商条約/
つうしょうだいひょうぶ /通商代表部;USTR/
つうしん /通信/痛心/
つうしんあいて /通信相手/
つうしんいん /通信員/
つうしんえいせい /通信衛星/
つうしんか /通信科/通信課/
つうしんかいせん /通信回線/
つうしんかくしゃ /通信各社/
つうしんかのう /通信可能/
つうしんかぶしきがいしゃ /通信株式会社/
つうしんかんきょう /通信環境/
つうしんかんけい /通信関係/
つうしんがいしゃ /通信会社/
つうしんがく /通信学/
つうしんがくぶ /通信学部/
つうしんがたじゅしんき /通信型受信機/
つうしんがっかい /通信学会/
つうしんき /通信機/
つうしんきかく /通信規格/
つうしんきかん /通信機関/
つうしんきき /通信機器/
つうしんきこう /通信機構/
つうしんきのう /通信機能/
つうしんきばん /通信基盤/
つうしんきょういく /通信教育/
つうしんきょういくきょうざい /通信教育教材/
つうしんきょり /通信距離/
つうしんぎじゅつ /通信技術/
つうしんぎじゅつぶ /通信技術部/
つうしんぎょう /通信業/
つうしんけーぶる /通信ケーブル/
つうしんけいろ /通信経路/
つうしんけんきゅうしょ /通信研究所/
つうしんけんきゅうぶ /通信研究部/
つうしんこうかん /通信交換/
つうしんこうがく /通信工学/
つうしんこうがっか /通信工学科/
つうしんこうざ /通信講座/
つうしんし /通信士;operator/通信使;朝鮮-/
つうしんしせつ /通信施設/
つうしんしゃ /通信社/
つうしんしゅだん /通信手段/
つうしんしょう /通信省/通信相;†大臣/
つうしんしょうがい /通信障害/
つうしんしょり /通信処理/
つうしんしんごう /通信信号/
つうしんじ /通信時/
つうしんじかん /通信時間/
つうしんじぎょうしゃ /通信事業者/
つうしんじじょう /通信事情/
つうしんじっぴ /通信実費/
つうしんじょう /通信上/
つうしんじょうけん /通信条件/
つうしんじょうほう /通信情報/
つうしんせいのう /通信性能/
つうしんせつび /通信設備/
つうしんせん /通信線/
つうしんせんよう /通信専用/
つうしんそうけん /通信総研/
つうしんそうごうけん /通信総合研/
つうしんそうち /通信装置/
つうしんそくど /通信速度/
つうしんたいしょう /通信対象/
つうしんたんまつ /通信端末/
つうしんだい /通信代/
つうしんちゅう /通信中/
つうしんてじゅん /通信手順/
つうしんとぜつ /通信途絶/
つうしんないよう /通信内容/
つうしんのうりょく /通信能力/
つうしんはくしょ /通信白書/
つうしんはんばい /通信販売/
つうしんはんばいいがい /通信販売以外/
つうしんはんばいがいしゃ /通信販売会社/
つうしんはんばいてん /通信販売店/
つうしんばいたい /通信媒体/
つうしんひ /通信費/
つうしんひよう /通信費用/
つうしんぶん /通信文/
つうしんぶんや /通信分野/
つうしんへい /通信兵/
つうしんほう /通信法/
つうしんほうしき /通信方式/
つうしんほうほう /通信方法/
つうしんぼ /通信簿/
つうしんぼうじゅほう /通信傍受法/
つうしんもう /通信網/
つうしんもくてき /通信目的/
つうしんよう /通信用/
つうしんようりょう /通信容量/
つうしんらん /通信欄/
つうしんりょう /通信料;communication fee/通信量;traffic/
つうしんりょうきん /通信料金/
つうしんりろん /通信理論/
つうしんろ /通信路/
つうしんろん /通信論/
つうじ /通時;diachronie.⇔共時/通事/通詞/通辞;=通詞/通じ/
つうじかい /通字解/
つうじたい /通時態;[言語]diachronie. ⇔共時態/
つうじてき /通時的/
つうじゅく /通塾/
つうじょう /通常/
つうじょううんちん /通常運賃/
つうじょううんてん /通常運転/
つうじょうえいぎょう /通常営業/
つうじょうかかく /通常価格/
つうじょうがた /通常型/
つうじょうがめん /通常画面/
つうじょうぎょうむ /通常業務/
つうじょうくうかん /通常空間/
つうじょうげんご /通常言語/
つうじょうこうげき /通常攻撃/
つうじょうこっかい /通常国会/
つうじょうこん /通常婚/
つうじょうさいせい /通常再生/
つうじょうさつえい /通常撮影/
つうじょうしよう /通常使用/
つうじょうじん /通常人/
つうじょうそうかい /通常総会/
つうじょうそうこう /通常走行/
つうじょうたいほ /通常逮捕/
つうじょうだん /通常弾/
つうじょうだんとう /通常弾頭/
つうじょうはがき /通常葉書/
つうじょうばん /通常版/通常盤/
つうじょうひょうじ /通常表示/
つうじょうぶん /通常文/
つうじょうへいき /通常兵器/
つうじょうほうしき /通常方式/
つうじょうほこう /通常歩行/
つうじょうよさん /通常予算/
つうじん /通人/
つうすい /通水/
つうせい /通性/
つうせき /痛惜/
つうせつ /通説/痛切/
つうせつどおり /通説通り/
つうそう /通奏/
つうそうけん /通総研/
つうそうていおん /通奏低音/
つうそく /通則/
つうぞく /通俗/
つうぞくてき /通俗的/
つうたつ /通達/
つうたん /痛嘆/痛歎/
つうだ /痛打/
つうち /通知/
つうちぎむ /通知義務/
つうちしょ /通知書/
つうちじょう /通知状/
つうちひょう /通知表/
つうちぼ /通知簿/
つうちょう /通帳/通牒/
つうちょうていき /通帳定期/
つうちよきん /通知預金;call deposit. 引出数日前に通知する必要がある/
つうてい /通底/
つうてん /痛点/
つうてんかく /通天閣/
つうでん /通電/
つうどう /通洞/通導/
つうどうそしき /通導組織/
つうどく /通読/
つうねん /通年/通念/
つうはん /通販/
つうはんぎょうしゃ /通販業者/
つうはんてん /通販店/
つうはんや /通販屋/
つうば /痛罵/
つうばん /通番/
つうぱい /字牌/
つうひ /通費/通臂/
つうふう /痛風;[医]gout/通風;ventilation/
つうふうき /通風機/
つうふうこう /通風口/
つうふん /痛憤/
つうぶん /通分/
つうへい /通弊/
つうほう /通報/通宝;寛永-/
つうほうぎむ /通報義務/
つうほうしゃ /通報者/
つうぼう /通謀/痛棒/
つうめ /通目/
つうめい /通名/
つうや /通夜/
つうやく /通訳;interpret(er)/通約;=約分/
つうやくかん /通訳官/
つうやくし /通訳氏/
つうやくしゃ /通訳者/
つうゆう /通有/
つうゆうせい /通有性/
つうよう /通用/痛痒/
つうようきかん /通用期間/
つうようぐち /通用口/
つうようじたい /通用字体/
つうようど /通用度/
つうようもん /通用門/
つうらい /通来/
つうらん /通覧/
つうりき /通力/
つうれい /通例/
つうれつ /痛烈/
つうろ /通路/
つうろがわ /通路側/
つうろはば /通路幅/
つうろん /通論;introduction/痛論;hot discussion/
つうわ /通話/
つうわじかん /通話時間/
つうわじょうたい /通話状態/
つうわせい /通話制/
つうわだい /通話代/
つうわないよう /通話内容/
つうわひょう /通話表/
つうわりょう /通話料/
つうわりょうきん /通話料金/
つえ /杖/拐/丈/
つえはしら /杖柱/
つか /柄;hilt/塚;mound/束/冢;=塚/
つかあな /塚穴/
つかい /使い/遣い/
つかいかた /使い方/
つかいかって /使い勝手/
つかいがって /使い勝手/
つかいごこち /使い心地/
つかいし /束石/
つかいすて /使い捨て/使い棄て/
つかいだて /使い立て/
つかいっぱしり /使いっ走り;パシリ/
つかいて /使い手;perlの-/
つかいで /使い出/使いで/
つかいはしり /使い走り/
つかいばしり /使い走り/
つかいばん /使い番/
つかいふるし /使い古し/
つかいほうだい /使い放題/
つかいま /使い魔/
つかいまわし /使い回し/
つかいみち /使い道/使い途/
つかいもの /使い物/使いもの/遣い物;gift/
つかいよう /使い様/
つかいわけ /使い分け/
つかえ /仕え/
つかがしら /柄頭/
つかくち /塚口/
つかぐち /塚口/
つかこし /塚越/
つかごし /塚越/
つかさ /司/元/長;首長/首;首長/官;役人/丘;丘陵/曹/阜;丘陵/寮/
つかさびと /官人/
つかさめし /司召/
つかしま /塚島/
つかずはなれず /付かず離れず/
つかたに /塚谷/
つかだ /塚田/束田/
つかぬこと /付かぬ事;-をお聞きしますが/
つかの /塚野/
つかのあいだ /束の間;つかのま/
つかのま /束の間/
つかのめ /塚目/
つかはら /塚原/束原/
つかみ /掴み/
つかみどころ /掴み所/
つかみどり /掴み取り/
つかみなげ /掴み投げ/
つかみほん /束見本/
つかむ /搏/攫/
つかもと /塚本/
つかもとしょうじ /塚本商事;[企業名]/
つかれ /疲れ/
つかれめ /疲れ目/
つかわれかた /使われ方/
つが /栂/都賀/
つがい /番/番い/津飼/
つがいけ /栂池/
つがいけこうげん /栂池高原/
つがいまい /番舞/
つがる /津軽/
つがるかいきょう /津軽海峡/
つがるかいきょうせん /津軽海峡線/
つがるじゃみせん /津軽三味線/
つがるせん /津軽線/
つがるぬり /津軽塗;弘前/
つがるはんとう /津軽半島/
つがるふじ /津軽富士;岩木山/
つがるべん /津軽弁/
つがるわん /津軽湾/
つがわ /津川/対川/
つがん /通鑑/
つき /月/坏;素焼きの器/槻;けやき/付/付き/突き/尽き/築/欟;=槻/憑き/
つき> /月;月イチ,月３度/
つきあい /付き合い/付合い/付合/
つきあかり /月明かり/月明り/
つきあげ /突き上げ/
つきあげぐん /築上郡/
つきあし /月足/
つきあたま /月頭/
つきあたり /突き当たり/突き当り/突当り/
つきあわせ /突合せ/突き合わせ/突き合せ/
つきいち /月一/月イチ/
つきうま /付き馬/
つきおか /月岡/
つきおとし /突き落とし/
つきおろしね /月卸値/
つきかいひ /月会費/
つきかげ /月影/
つきかず /月数/
つきがけ /月掛け/
つきがさ /月暈/
つきがせ /月ヶ瀬/
つきがた /月形/
つきがわり /月替わり/月代わり/月代り/
つききず /突き傷/
つききち /月基地/
つきぎめ /月極め/
つきぎめちゅうしゃじょう /月極駐車場/
つきぎょうじ /月行事/
つきぎり /月切り/月限/
つきぐみ /月組;[芸能]宝塚/
つきげ /月毛/鴾毛/
つきこ /月子/
つきこうはん /月後半/
つきごし /月越し/
つきごと /月毎/
つきごめ /搗き米/
つきごろ /月頃/
つきさっぷ /月寒/
つきさむ /月寒/
つきしま /月島/
つきしょじゅん /月初旬/
つきしろ /月白/
つきじ /築地/
つきじぐち /築地口/
つきじろ /月白/
つきすう /月数/
つきずえ /月末/
つきせかい /月世界/
つきせかいりょこう /月世界旅行/
つきそい /付き添い/付添/付添い/
つきそいかんごひ /付添看護費/
つきそいにん /付添人/
つきたおし /突き倒し/
つきたて /月舘/
つきたらず /月足らず/
つきたんい /月単位/
つきだし /突き出し/突出し/
つきだて /築館;地名,宮城/月舘;地名,福島/
つきだてちょう /築館町/
つきっきり /付きっ切り;-で看病する/
つきづき /月々/
つきていど /月程度/
つきなかば /月半ば/
つきなみ /月並/月次/槻並/
つきなんにち /月何日/
つきの /月野/
つきのいり /月の入り/
つきのき /槻木/
つきのさわり /月の障り/
つきので /月の出/
つきのはら /月野原/
つきのみ /突き鑿/
つきのもの /月の物/
つきのわ /月の輪/
つきのわぐま /月輪熊/
つきはじめ /月初め/
つきばらい /月払い/
つきばん /月番/
つきひ /月日/
つきひめ /月姫/
つきびと /付き人/付人/
つきへいきん /月平均/
つきへん /月偏/
つきべつ /月別/
つきぼし /月星/
つきまいり /月参り/
つきまち /月待ち/
つきみ /月見/
つきみざけ /月見酒/
つきみそう /月見草/
つきみだんご /月見団子/
つきみばし /月見橋/
つきめ /尽き目/
つきめくり /月捲り/
つきもの /付き物;「失敗は-だ」/憑き物;ghost.「-が落ちる」/付物/つき物/
つきもり /月森;姓/
つきやく /月役/
つきやま /築山/
つきゆきはな /月雪花/
つきゆび /突き指/
つきよ /月夜/
つきよだ /月夜田/
つきよの /月夜野/
つきわり /月割/月割り/
つぎ /次/
つぎお /次男/次雄/次夫/
つぎがみ /継紙/
つぎき /接木/継ぎ木/継木/
つぎきれ /継切/
つぎくち /注ぎ口/
つぎぐち /注ぎ口/
つぎしきし /継色紙/
つぎつぎ /次々/
つぎて /継手/継ぎ手/接手/
つぎのすけ /継之助/
つぎのま /次の間/
つぎはぎ /継ぎ接ぎ/
つぎぶし /次節;小唄/
つぎほ /接ぎ穂/
つぎめ /継ぎ目/継目/
つぎもの /継ぎ物/
つく /筑/津久/
つくい /津久井/
つくいこ /津久井湖/
つくいはま /津久井浜/
つくえ /机/
つくえがた /机型/
つくし /筑紫/土筆/
つくしかん /筑紫館/
つくしごと /筑紫箏/
つくしじろう /筑紫二郎/
つくだ /佃/附田/
つくだじま /佃島/
つくだに /佃煮/
つくだにふう /佃煮風/
つくつくぼうし /つくつく法師/
つくづく /熟/熟々/
つくで /作手/
つくと /津久戸/
つくね /築根;姓/
つくば /筑波/
つくばい /蹲踞/
つくばえき /筑波駅/
つくばかがくはく /筑波科学博/
つくばぎじゅつたんだい /筑波技術短大/
つくばけん /筑波研/
つくばけんきゅう /筑波研究/
つくばけんきゅうしょ /筑波研究所/
つくばこうじょう /筑波工場/
つくばさん /筑波山/
つくばし /つくば市/筑波市;※「つくば市」が正しい/
つくばじょうほう /筑波情報/
つくばだい /筑波大/
つくばだいかがく /筑波大化学;[企業名]/
つくばだいがく /筑波大学/
つくばだいがくいん /筑波大学院/
つくばだいがくせいぶつ /筑波大学生物/
つくばだいがくだい /筑波大学第/
つくばだいがくちゅうおう /筑波大学中央/
つくばだいがくでんし /筑波大学電子/
つくばだいびょういん /筑波大病院/
つくばね /筑波嶺/
つくばはく /筑波博/
つくばばんぱく /筑波万博/
つくぼう /突棒/
つくみ /津久見/
つくも /九十九/
つくもがみ /付喪神/九十九髪/
つくもでんき /九十九電機;[企業名]/
つくよ /月夜/
つくよみ /月読み/月讀み/
つくり /作り/傍;部首/旁;部首/造り/
つくりうた /作り歌/作り唄/
つくりおき /作り置き;-のキンピラ/
つくりかえ /作り替え/
つくりかた /作り方/
つくりこみ /作り込み/
つくりごえ /作り声/
つくりごと /作り事/
つくりざかや /造り酒屋;brewery/造酒屋/
つくりつけ /作り付け/
つくりて /作り手/
つくりばなし /作り話/
つくりもの /作り物/
つくりわらい /作り笑い/
つくろい /繕い/繕/
つくろいもの /繕い物;最近廃れつつあるかな？/
つぐ /津具;地名/継/嗣/
つぐお /嗣雄/
つぐとし /次利/
つぐとも /嗣智/嗣朋/
つぐない /償い/
つぐのぶ /嗣信/
つぐみ /鶫/
つぐも /津雲/
つけ /付/漬け/漬/附け/付け/
つけあい /付合/
つけあわせ /付け合わせ;relish/付け合せ/
つけいた /付け板/ツケ板/
つけうま /付け馬/
つけおち /付け落ち/
つけかえ /付替/付け替え/
つけかた /付け方/
つけく /付句/
つけぐすり /付け薬/
つけげ /付け毛/
つけこみちょう /付込帳/
つけさげ /付下げ;和服の模様の付け方の名/
つけじる /漬け汁/付け汁/付汁/
つけたし /付け足し/
つけたり /付けたり;appendix/
つけだけ /付竹/
つけだし /付け出し/
つけち /付知/
つけづめ /付け爪/
つけとどけ /付け届け/
つけどころ /付け所;目の-/
つけな /漬菜/
つけね /付け根/付け値/
つけば /付け場/
つけばしら /付柱;[建築]/付け柱;[建築]pilastre/
つけひげ /付け髭/
つけび /付け火/
つけびと /付け人/
つけぶみ /付け文/
つけまつげ /付け睫毛/
つけめ /付け目/
つけもの /漬物/漬け物/
つけものいし /漬物石/
つけものてん /漬物店/
つけやき /付け焼き/
つけやきば /付け焼刃/付け焼き刃/付焼刃/付焼き刃/
つげ /柘植/柘/告げ/都祁/
つげぐち /告げ口/
つごう /都合/
つごうしゅぎ /都合主義/
つごうじょう /都合上/
つごもり /晦/晦日/
つさか /津坂/
つざき /津崎/
つし /津市/都志/
つしま /対馬/津島/對馬/津嶋/
つしまかいきょう /対馬海峡/
つしまかいりゅう /対馬海流/
つしまかなめ /津島要/
つしまく /津島区/
つしまなか /津島中/
つしまふくい /津島福居/
つじ /辻/旋毛;=つむじ/
つじい /辻井/
つじうら /辻占/
つじうらない /辻占い/
つじおか /辻岡/
つじかわ /辻川/
つじがどう /辻ヶ堂/
つじぎみ /辻君/
つじぎり /辻斬り/
つじぐるま /辻車/
つじげいにん /辻芸人/
つじさわ /辻沢/
つじした /辻下/
つじせっぽう /辻説法/
つじた /辻田/
つじつじ /辻々/
つじつま /辻褄/
つじつまあわせ /辻褄合わせ/
つじどう /辻堂/
つじの /辻野/
つじばしゃ /辻馬車/
つじむら /辻村/
つじもと /辻本/辻元/
つずき /都築;※仮名遣い「つづき」/
つた /蔦/樢/
つたえ /伝え/
つたかずら /蔦葛/
つたき /津滝/
つたない /拙い/
つたや /蔦屋/
つだ /津田/
つだじゅく /津田塾/
つだじゅくだい /津田塾大/
つだじゅくだいがく /津田塾大学/
つだぬま /津田沼/
つだぬまえき /津田沼駅/
つち /土/槌;きづち/鎚/椎/壌/
つちい /土井/土居/
つちいじり /土弄り/
つちいっき /土一揆/
つちいばんすい /土井晩翠;NB:通称「どい」/
つちいろ /土色/
つちうら /土浦/
つちうらし /土浦市/
つちうらにこう /土浦二高/
つちうらにちだい /土浦日大/
つちおと /槌音/
つちかべ /土壁/
つちかわ /土川/
つちがた /土型/
つちくれ /土塊/土くれ/
つちぐも /土蜘蛛/蝪/
つちぐら /土倉/
つちぐり /土栗/
つちけいろ /土気色/
つちけむり /土煙/
つちこ /土子/
つちこつ /槌骨;[解剖](中耳の)malleus/
つちざき /土崎/
つちた /土田/
つちだ /土田/槌田/
つちつかず /土付かず/
つちづくり /土作り/
つちとい /土樋/
つちとりもちもく /ツチトリモチ目/Balanophorales/
つちどめ /土留め;[土木]土砂崩れを防ぐ工作物/
つちにんぎょう /土人形/
つちのえ /戊;[十干]5/
つちのえいぬ /戊戌/
つちのえうま /戊午/
つちのえさる /戊申/
つちのえたつ /戊辰/
つちのえとら /戊寅/
つちのえね /戊子/
つちのこ /槌の子/
つちのと /己;[十干]6/
つちのとい /己亥/
つちのとう /己卯/
つちのとうし /己丑/
つちのととり /己酉/
つちのとひつじ /己未/
つちのとみ /己巳/
つちはし /土橋/
つちばし /土橋/
つちふまず /土踏まず/
つちぶえ /土笛/
つちへん /土偏;「埃」の偏/
つちぼこり /土埃/
つちぼとけ /土仏/
つちみかど /土御門/
つちみかどてんのう /土御門天皇/
つちむろ /土室/
つちもち /土持/
つちもと /土本/
つちや /土屋/土家/土谷/
つちやぶんめい /土屋文明/
つちやま /土山/
つちゆ /土湯/
つちよせ /土寄せ/
つちろう /土牢/
つっかいぼう /突っ支い棒/つっかい棒/
つっかけ /突っ掛け/
つっけんどん /突っ慳貪/突慳貪/
つっこみ /突っ込み/突込み/
つっぱり /突っ張り/
つつ /筒/砲/
つつい /筒井/
つついづつ /筒井筒;-井筒にかけしまろがたけ過ぎにけらしな妹みざるまに(伊勢)/
つついやすたか /筒井康隆;SF作家/
つつうらうら /津々浦々/津津浦浦/
つつおと /筒音/
つつが /恙/筒賀/
つつがき /筒描き/
つつがむし /恙虫/
つつぎり /筒切り/
つつぐち /筒口/
つつさき /筒先/
つつしんで /謹んで/
つつじ /躑躅/榴/
つつじいろ /躑躅色/
つつじがおか /つつじヶ丘/榴ヶ岡/榴岡/
つつじもく /ツツジ目/Ericales/
つつじょう /筒状/
つつそで /筒袖/
つつぢゃわん /筒茶碗/
つつなか /筒中/
つつぬけ /筒抜け/
つつみ /堤/包み/包/恙/筒見/愼;「慎」の旧字(人名用漢字)/
つつみあげ /包み揚げ/
つつみがまえ /包構え;[部首]/
つつみがみ /包み紙/
つつみちゅうなごんものがたり /堤中納言物語/
つつみびょうし /包表紙/
つつみまち /堤町/
つつみむし /包み蒸し/
つつみやき /包み焼き/
つつもたせ /美人局/
つづ /通津/
つづうらうら /津々浦々/
つづき /続き/都築/綴喜/
つづきがら /続柄/続き柄/
つづきもの /続き物/
つづく /続く/
つづけ /続け/
つづけざま /続け様/
つづけじ /続け字/
つづみ /鼓/皷;「鼓」の異体字/
つづみうた /鼓唄/
つづら /葛/葛籠/
つづらおり /九十九折/九十九折り/葛折/葛折り/
つづらこ /葛籠/
つづらふじか /ツヅラフジ科/Menispermaceae/
つづり /綴/綴り/
つづりかた /綴り方;theme/綴方/
つづりかたきょうしつ /綴方教室/
つづりじ /綴り字/
つづれ /綴れ/
つづれおり /綴れ織り/綴れ織/
つて /伝/伝手/
つと /衝と/
つとに /夙に/
つとむ /力/勉/努/務/勤/
つとめ /勤め/
つとめぐち /勤め口/
つとめさき /勤め先/
つとめて /努めて/
つとめにん /勤め人/
つとめびと /勤め人/
つど /都度/津戸/
つどい /集い/集/
つどけってい /都度決定/
つな /綱/津名/
つなうち /綱打ち;[相撲]/
つなお /綱男/
つなかん /ツナ缶/
つながり /繋がり/
つなぎ /繋/津奈木/繋ぎ/
つなぎめ /繋ぎ目/
つなぐ /綱具/
つなしま /綱島/綱嶋/
つなそ /綱麻/
つなとり /綱取り;[相撲]横綱挑戦/
つなひき /綱引き/
つなみ /津波/
つなみけいほう /津波警報/
つなみじょうほう /津波情報/
つなみちゅういほう /津波注意報/
つなみよほう /津波予報/
つなわたり /綱渡り/綱渡/
つなん /津南/
つね /常/恒/経/典/恆;「恒」の旧字(人名用漢字)/桓;?/
つねあき /常明/
つねお /恒夫/恒雄/恒男/常雄/常夫/常男/
つねかわ /恒川/
つねきち /常吉/
つねきよ /経清/
つねこ /恒子/
つねじ /常次/
つねずみ /常澄/
つねたけ /恒毅/典武/
つねづね /常々/
つねとう /恒藤/恒任/
つねとし /恒敏/種敏/
つねとよ /常豊/
つねなが /常長/
つねなみ /常並/
つねに /常に/
つねのり /恒憲/
つねはる /常晴/
つねひこ /恒彦/
つねひごろ /常日頃/
つねひら /恒平/
つねひろ /恒宏/常広/恒博/常廣/
つねまさ /恒正/
つねもり /常森/
つねやす /常安/経康/
つねゆき /常幸/恒行/
つねよ /常与/
つねよし /恒吉/常吉/恒美/
つの /角/津野/都農/都濃/
つのお /角尾/
つのおか /角岡/
つのかくし /角隠し/
つのがい /角皆/
つのがえる /角蛙/
つのがき /角書/角書き/
つのがみ /角髪/
つのがら /角柄/
つのぎ /角木/
つのごけるい /角苔類/
つのごろう /角五郎/
つのざめ /角鮫/
つのだ /角田/
つのはず /角筈/
つのぶえ /角笛/
つのへん /角偏/
つのまた /角叉/
つのもじ /角文字/
つはもの /兵/
つはら /津原/
つはん /ツ反;ツベルクリン反応/
つば /唾/鍔/鐔/
つばい /椿井/
つばき /椿/唾/
つばきあぶら /椿油/
つばきい /椿井/
つばきか /ツバキ科/Theaceae/
つばきさんじゅうろう /椿三十郎/
つばきしゅぞう /椿酒造/
つばきはら /椿原/
つばきひめ /椿姫/
つばきもとちえいん /椿本チエイン/
つばきやま /椿山/
つばくらめ /燕/
つばくろ /燕/
つばくろうお /燕魚/
つばさ /翼/翅/
つばぜりあい /鍔迫り合い/
つばた /津幡/
つばな /茅花/
つばめ /燕/
つばめうお /燕魚/
つばめがえし /燕返し/
つばめざわ /燕沢/
つばもと /鍔元/
つひに /遂に/終に/
つぶ /粒/螺;巻貝/
つぶあん /粒餡/粒あん/
つぶえ /粒餌/
つぶぎん /粒銀/
つぶこしょう /粒胡椒/粒コショウ/
つぶさき /粒崎/
つぶさに /具に/備に/悉に/
つぶし /潰し/
つぶじょう /粒状/
つぶす /潰/
つぶぞろい /粒揃い/
つぶつぶ /粒々/粒粒/
つぶて /礫/
つぶますたーど /粒マスタード/
つぶやき /呟き/
つぶより /粒選り/
つぶら /円ら/円/
つぶらや /円谷/
つぶれ /潰れ/
つべつ /津別/
つべるくりんはんのう /ツベルクリン反応;[医]tuberculin reaction. 結核の検査法/
つぼ /坪/壺/壷;「壺」の異体字/
つぼあたり /坪当たり/坪当り/
つぼい /坪井/壷井/壺井/壺居/
つぼいさかえ /壺井栄/
つぼうち /坪内/
つぼうちしょうよう /坪内逍遥/
つぼかわ /坪川/
つぼくら /坪倉/
つぼさき /坪崎/
つぼすう /坪数/
つぼせんざい /壺前栽/
つぼた /坪田/
つぼたんか /坪単価/
つぼだけ /坪岳/
つぼづけ /つぼ漬/
つぼにわ /坪庭/
つぼね /局/
つぼはち /つぼ八/
つぼほり /壺掘り;[建築]柱に合わせて穴を掘る/
つぼみ /蕾/莟/
つぼや /壺屋/壷屋;「壺」異体字/
つぼやき /壺焼き/壺焼/
つぼやきいも /壺焼き芋/壺焼芋/
つぼややき /壺屋焼/
つま /妻/褄;和服の-/嬬;か弱い女性/都万;地名,島根県/
つまい /妻井/
つまお /妻夫/
つまおと /爪音/
つまかべ /妻壁;[建築]軒に垂直な方向(妻)の壁/
つまぎ /爪木/
つまご /妻籠/
つまごい /嬬恋/つま恋/妻恋/
つまさき /爪先/つま先/
つまずき /躓き;-の石/
つまづき /躓き/
つまど /妻戸/
つまどいこん /妻問婚/
つまどり /褄取り/
つまはじき /爪弾き/
つまびき /爪弾き/
つまびらか /詳らか/審らか/
つまべに /爪紅/
つまみぐい /つまみ食い/摘み食い/摘まみ食い/撮み食い/
つまみな /摘まみ菜/
つまようじ /爪楊枝/
つまるところ /詰まる所/
つみ /罪/詰み/辟/
つみあげ /積み上げ/
つみいし /積石/積み石/
つみいしき /罪意識/
つみいれ /摘入れ/
つみおろし /積み卸し/
つみかえ /積み替え/積替え/積替/
つみかさね /積み重ね/
つみき /積み木/積木/
つみきん /積金/積み金/
つみくさ /摘み草/
つみこみ /積み込み/
つみごえ /積肥/
つみたて /積立/積み立て/積立て/
つみたてきん /積立金/
つみたてほうしき /積立方式/
つみたてよきん /積立預金/
つみち /積地/
つみつくり /罪作り/
つみとが /罪科/
つみとばつ /罪と罰;Prestuplenie i nakazanie(1866), Dostoevskii/
つみに /積荷/積み荷/
つみにほけん /積荷保険/
つみのこし /積み残し/
つみびと /罪人/
つみほろぼし /罪滅ぼし/
つみまし /積み増し/
つみれ /摘入/
つむ /錘/紡錘/舶;大船/頭/
つむがた /紡錘形/
つむがり /都牟刈/
つむぎ /紬/紡/紡木/
つむぎいと /紬糸/
つむぎうた /紡ぎ唄;グレートヒェンの-/
つむぎおり /紬織/紬織り/
つむじ /旋毛/辻/旋風/
つむじかぜ /旋風/つむじ風/
つむじまがり /旋毛曲り/旋毛曲がり;ひねくれ者/
つむら /津村/津邑/
つむり /頭/
つめ /爪/詰め/詰/
つめあと /爪痕/
つめあわせ /詰め合わせ/詰合せ/詰め合せ/詰合わせ/
つめいん /爪印/
つめえり /詰襟/詰め襟/
つめかえ /詰め替え/
つめかえよう /詰め替え用/詰替用/
つめきり /爪切り/
つめくさ /詰草/
つめご /詰碁/詰め碁/
つめさき /爪先/
つめしょ /詰所/詰め所;警察官-/
つめしょうぎ /詰将棋/詰め将棋/
つめすじ /詰筋/
つめた /冷た/
つめて /詰手;[将棋]王を詰ませる手/
つめどころ /詰所/詰め所/
つめのあか /爪の垢;-を煎じて飲む/
つめばら /詰め腹;-を切らされる/詰腹/
つめほうだい /詰め放題/
つめもの /詰め物/詰物/
つめろ /詰めろ;[将棋]次に王手となる手。「-をかける」/
つも /自摸;[麻雀]/模;?/
つもほう /自模和/
つもり /津守/積もり/積り/心算/
つや /艶/通夜/艷;旧字/
つやけ /艶気/
つやけし /艶消し/つや消し/艶消/
つやごと /艶事/
つやざき /津屋崎/
つやだし /艶出し/つや出し/ツヤ出し/艶出/
つやつや /艶々/艶艶/
つやぶみ /艶文/
つやま /津山/
つやません /津山線/
つやもの /艶物/
つやものがたり /艶物語/
つゆ /梅雨/露/汁;麺類などの/液/黴雨/
つゆあけ /梅雨明け;最近は発表されない/梅雨明/
つゆいこう /梅雨以降/
つゆいり /梅雨入り/梅雨入/入梅/
つゆき /露木/
つゆくさ /露草/
つゆくさいろ /露草色/
つゆくさもく /ツユクサ目/Commelinales/
つゆこ /露子/
つゆごろ /梅雨頃/
つゆざむ /梅雨寒/
つゆしぐれ /露時雨/
つゆじも /露霜/
つゆぞら /梅雨空/
つゆどき /梅雨時/
つゆはし /露橋/
つゆはらい /露払い/
つゆほど /露程/
つよき /強気/
つよきすじ /強気筋/
つよごし /強腰/
つよさ /強さ/
つよし /剛/強/毅/幹/剛士/津義/毅師/
つよび /強火/
つよみ /強み/強味/
つら /面/
つらあて /面当て/
つらがまえ /面構え/
つらだし /面出し/
つらだましい /面魂/
つらつら /熟々/倩々;=熟々/
つらなり /連なり/
つらのかわ /面の皮;-が厚い,-を剥ぐ,いい-/
つらゆき /貫之/
つらよごし /面汚し/
つらら /氷柱/
つり /釣り/釣/吊り/吊/系/
つりーがた /ツリー型/
つりーこうぞう /ツリー構造/
つりあい /釣り合い/釣合/釣合い/
つりあげ /吊り上げ/釣り上げ/釣上げ/
つりいと /釣り糸/釣糸/
つりうむ /Tm/Thulium/
つりおとし /吊り落とし/
つりかた /釣り方/
つりかわ /吊革/吊り革/吊り皮/釣り革/
つりがき /釣書/
つりがね /釣鐘/釣り鐘/
つりがねがた /釣鐘形/
つりがねそう /釣鐘草/
つりがねむし /釣鐘虫/
つりきゃく /釣り客/
つりぐ /釣具/釣り具/吊り具/
つりぐてん /釣具店/
つりぐや /釣具屋/
つりこうこく /吊り広告/
つりこみごし /釣り込み腰/
つりごし /釣り輿/
つりさげしき /吊り下げ式/
つりざお /釣竿/釣り竿/
つりし /釣り師/釣師/
つりしょ /釣書/
つりせん /釣り銭/釣銭/
つりたに /釣谷/
つりだいこ /釣太鼓/
つりだし /吊り出し/
つりて /釣手/
つりてんじょう /釣天井/釣り天井/
つりとだな /吊り戸棚/
つりどうぐ /釣り道具/釣道具/
つりどの /釣殿/
つりば /釣り場/
つりばし /吊り橋/吊橋/
つりばり /釣り針/釣針/
つりひも /吊り紐/
つりびと /釣り人/釣人/
つりぶね /釣り船/釣船/釣り舟/釣舟/
つりほう /釣法/
つりぼり /釣り堀/釣堀/
つりまと /釣的/
つりめ /吊り目/
つりもと /釣元/
つりやど /釣宿/釣り宿/
つりやね /吊り屋根/
つりわ /吊り輪/
つる /鶴/蔓/弦;弓の-/絃;≒弦/鉉;鍋の-/都留/寉;「鶴」の異体字/敦;人名読み/
つるあまちゃ /蔓甘茶/
つるい /鶴居/釣井/
つるいち /鶴一/
つるえ /鶴枝/鶴江/
つるおか /鶴岡/
つるおかし /鶴岡市/
つるおと /弦音/
つるかめ /鶴亀/
つるかめざん /鶴亀算/
つるかめつるかめ /鶴亀鶴亀;縁起直しのおまじない/
つるかわ /鶴川/
つるが /敦賀/鶴賀/鶴我/
つるがおか /鶴岡/
つるがおかはちまんぐう /鶴岡八幡宮/
つるがかん /敦賀間/
つるがこう /敦賀港/
つるがしま /鶴ヶ島/
つるがみね /鶴ヶ峰/
つるがや /鶴ヶ谷/
つるきえき /鶴来駅/
つるぎ /剣/鶴来;地名,石川/剱;「剣」の異体字1/劔;「剣」の異体字2/劍;「剣」の旧字(人名用漢字)/劒;「剣」の異体字3/釼;≒剣/
つるぎざき /剣崎/
つるぎのまい /剣の舞/
つるくさ /蔓草/
つるくび /鶴首/
つるこう /鶴光/
つるさき /鶴崎/
つるざ /鶴座;Grus(Gru)/
つるし /吊るし;-の背広(=既製服)/
つるしあげ /吊るし上げ/吊し上げ/
つるしま /鶴島/
つるしょくぶつ /蔓植物/
つるじろう /鶴次郎/
つるせい /蔓性/
つるぞう /鶴蔵/
つるた /鶴田/
つるたろう /鶴太郎/
つるだ /鶴田/
つるっぱげ /つるっ禿/
つるな /蔓菜/
つるにちにちそう /蔓日々草/蔓日日草/
つるにょうぼう /鶴女房/
つるのこ /鶴の子/
つるのまる /鶴の丸/
つるはぎ /鶴脛/
つるはし /鶴嘴;pickaxe/鶴橋;地名,大阪/
つるばみ /橡/
つるばら /蔓薔薇/
つるふじ /鶴藤/
つるべ /釣瓶/鶴瓶;人名。笑福亭鶴瓶/
つるべおとし /釣瓶落とし;秋の日は-/釣瓶落し/
つるま /鶴間/
つるまい /鶴舞/
つるまいえき /鶴舞駅/
つるまいこうえん /鶴舞公園/
つるまいせん /鶴舞線/
つるまき /弦巻/鶴巻/
つるまきおんせん /鶴巻温泉/
つるみ /鶴見/
つるみく /鶴見区/
つるみず /鶴水/
つるみせん /鶴見線/
つるみだいがく /鶴見大学;www.tsurumi-u.ac.jp/
つるみだけ /鶴見岳;地名,大分/
つるむらさき /蔓紫/
つるや /鶴屋/鶴谷/
つるやなんぼく /鶴屋南北/
つるやま /鶴山/
つるれいし /蔓茘枝/
つれ /連れ/
つれあい /連れ合い/連合い/
つれこ /連れ子/
つれこみ /連れ込み/連込み/
つれこみやど /連れ込み宿;ラブホ/
つれご /連れ子/
つれだか /連れ高/
つれづれ /徒然/
つれづれぐさ /徒然草/
つれまい /連舞/
つれやす /連れ安/
つわの /津和野/
つわぶき /石蕗/
つわもの /兵/強者/
つわり /悪阻/
つんどく /積読/積ん読/積讀;「読」旧字/
つんぼ /聾/
つんぼさじき /聾桟敷/
づ /図/津/
づか /塚/冢/
づかい /使い/
づかれ /疲れ/
づき /付/月/
づくえ /机/
づくし /尽くし/尽し;フグ-,花-,心-/
づくり /作り/造り;(連濁) 神明-,数奇屋-,活け-/
づけ /付/付け/漬;醤油漬,野沢菜漬,西京漬/漬け/
づつ /筒/
づつう /頭痛/
づな /綱/
づのう /頭腦/
づま /妻/
づみ /詰み/
づめ /詰め/詰/
づり /釣り/吊り/
づる /鶴/
づれ /連れ/
て /手/弖;助詞の「て」/〒;郵便番号/
てーぶるさんざ /テーブル山座;Mensa(Men)/
てーぶるせき /テーブル席/
てーぷおこし /テープ起こし/
てあい /手合い/手合/
てあか /手垢/
てあし /手足/
てあしくちびょう /手足口病/
てあそび /手遊び/
てあたり /手当たり/手当り/
てあたりしだい /手当たり次第/手当り次第/
てあて /手当/手当て/
てあな /手穴/
てあぶり /手焙り/
てあみ /手編み/手編/
てあら /手荒/
てあらい /手洗い/手洗/
てあらいばち /手洗鉢/
てあわせ /手合わせ/手合せ/
てぃーさいぼう /Ｔ細胞;[医]T cell/
てぃーしゃつ /Ｔシャツ/Tシャツ/
てぃーじ /Ｔ字/T字/
てぃーじろ /Ｔ字路;「丁字路」ともいう/T字路;「丁字路」ともいう/
てぃーばっく /Ｔバック/Tバック/
てぃじろ /Ｔ字路;「丁字路」ともいう/T字路;「丁字路」ともいう/
てい /低;low/底;bottom/邸;邸宅/帝/亭/体;ほうほうの-/態;ほうほうの-/定/庭;庭園/廷;法廷/挺;挺身/艇;(boat) 飛行艇/停;停止/渟/丁;丁字路/訂;改訂/汀;みぎわ/釘;くぎ/叮;叮嚀(=丁寧)/酊;酩酊/提;提案/堤;堤防/碇;碇泊/掟;おきて/嚔;くさめ/嚏;「嚔」の異体字/呈;提示/程;程度/逞;不定/酲;(二日酔い)/偵;偵察/貞;貞操/禎/幀;装幀/碵/遉;さすが/締;(し・める)締結/諦;(あきら・める)諦念/蹄;(ひづめ)蹄鉄/啼;(なく)啼泣/楴;かんざし/鵜;う/剃;剃髪/弟;末弟/悌;孝悌/梯;(はしご)雲梯/涕;流涕/睇;(流し目)/第;(漢音)/抵;抵当/柢;根柢(=根底)/牴;牴触(=抵触)/觝;觝触(=抵触)/羝;おひつじ/詆;そしる/滞;(漢音) とどこお・る/綴;つづり/逓;逓信/遞;「逓」の旧字/鄭;鄭重(=丁重)/鼎;鼎談/薙;な・ぐ/棣/眤/騁/躰;「体」の異体字/軆;「体」の旧字1/體;「体」の旧字2/袋;布袋?/
てい> /低/
ていあつ /低圧;low/定圧;constant/
ていあつよう /低圧用/
ていあん /提案/
ていあんいけん /提案意見/
ていあんいらいしょ /提案依頼書/
ていあんがた /提案型/
ていあんがたえいぎょう /提案型営業/
ていあんがわ /提案側/
ていあんきじ /提案記事/
ていあんけん /提案権/
ていあんご /提案後/
ていあんしゃ /提案者/
ていあんしょ /提案書/
ていあんないよう /提案内容/
ていあんほうほう /提案方法/
ていあんりゆうせつめい /提案理由説明/
ていい /定位/低位;low/帝位/
ていいかぶ /低位株/
ていいかん /定位感/
ていいき /低域/
ていいきつうか /低域通過/
ていいきのう /定位機能/
ていいきぶ /低域部/
ていいち /定位置/貞一/禎一/
ていいど /低緯度/
ていいのうりょく /定位能力/
ていいん /定員/
ていいんいっぱい /定員一杯/
ていいんがい /定員外/
ていいんじょうしゃ /定員乗車/
ていいんわれ /定員割れ/定員割/
ていうん /低運/
ていうんてんだいしゃ /低運転台車/
ていえき /定役/
ていえん /庭園/定演/
ていえんびじゅつかん /庭園美術館/
ていおう /帝王/
ていおうがく /帝王学/
ていおうしょう /帝王賞/
ていおうせっかい /帝王切開/
ていおん /低温;†cold/低音;†bass/定温;†homothermal/
ていおんいき /低音域/
ていおんか /低温下/
ていおんかん /低音感/
ていおんがわ /低温側/低音側/
ていおんき /低温期/
ていおんけん /低温研/
ていおんこうがくかい /低温工学会/
ていおんさっきん /低温殺菌;牛乳/
ていおんじ /低温時/
ていおんど /低温度/
ていおんどうぶつ /定温動物/
ていおんぶ /低音部/
ていおんやけど /低温火傷/
ていおんよう /低温用/
ていか /定価/低下/定家/低価;low price/定價;「価」旧字/
ていかい /停会/低徊/
ていかいか /定価以下/
ていかいじょう /定価以上/
ていかいぞうど /低解像度/
ていかいてん /低回転/
ていかいてんいき /低回転域/
ていかいてんがた /低回転型/
ていかいはつこく /低開発国/
ていかかく /低価格/
ていかかくか /低価格化/
ていかかくきょうそう /低価格競争/
ていかかくしゃ /低価格車/
ていかかくせいひん /低価格製品/
ていかかくひん /低価格品/
ていかかくろせん /低価格路線/
ていかく /定格/底角/
ていかくかいてんすう /定格回転数/
ていかくしゅつりょく /定格出力/
ていかくそくど /定格速度/
ていかくでんあつ /定格電圧/
ていかくでんりゅう /定格電流/
ていかくりつ /低確率/
ていかごうけい /定価合計/
ていかっしゃ /定滑車;⇔動滑車/
ていかはんばい /定価販売/
ていかひょう /定価表/
ていかほう /低価法;[会計]/
ていかろりー /低カロリー/
ていかん /定款/諦観/帝冠/定感/停刊/
ていかんかく /定間隔/
ていかんし /定冠詞/
ていかんど /低感度/
ていが /定芽/
ていがく /定額;fixed amount/低額;small amount/停学/
ていがくこがわせ /定額小為替/
ていがくせい /定額制/
ていがくねん /低学年/
ていがくほう /定額法/
ていがくほけん /定額保険/
ていき /定期/提起/帝紀/定気/
ていき> /定期;(periodic) -検査,-演奏会/
ていきあつ /低気圧/
ていきいち /定期市/
ていきいれ /定期入れ;pass case/定期入/
ていきえんそうかい /定期演奏会/
ていきかいいん /定期会員/
ていきかいさい /定期開催/
ていきかんこう /定期観光/
ていきかんこうぶつ /定期刊行物/
ていききゃく /定期客/
ていききんさいけん /定期金債権/
ていきけい /定期刑/
ていきけん /定期券/
ていきけんうりば /定期券売場/
ていきけんくかん /定期券区間/
ていきけんしん /定期検診/
ていきこうどく /定期購読/
ていきこうにゅう /定期購入/
ていきこうろ /定期航路/
ていきざっし /定期雑誌/
ていきしけん /定期試験/
ていきしゃくちけん /定期借地権/
ていきしょうきゅう /定期昇給/
ていきじょうしゃけん /定期乗車券/
ていきせん /定期船/定期戦/
ていきだい /定期代/
ていきちんたいしゃく /定期賃貸借/
ていきつみきん /定期積金/
ていきてき /定期的/
ていきてんけん /定期点検/
ていきとうこう /定期投稿/
ていきとっきゅう /定期特急/
ていきとりひき /定期取引/
ていきど /低輝度/
ていきどう /低軌道/
ていきのう /低機能/
ていきびん /定期便/
ていきほうこく /定期報告/
ていきほけん /定期保険/
ていきほしゅ /定期保守/
ていきゅう /定休/庭球;tennis/低級/涕泣;涙を流して泣く/啼泣;声を上げて泣く/
ていきゅう> /低級/
ていきゅうげんご /低級言語/
ていきゅうび /定休日/
ていきゅうぶ /庭球部/
ていきょう /提供/帝京/
ていきょうかのう /提供可能/
ていきょうきょく /提供曲/
ていきょうぎじゅつかがくだいがく /帝京技術科学大学/
ていきょうこうこう /帝京高校/
ていきょうさき /提供先/
ていきょうしゃ /提供者/
ていきょうしゃがわ /提供者側/
ていきょうじょうほう /提供情報/
ていきょうだい /帝京大/
ていきょうだいがく /帝京大学/
ていきょうちゅう /提供中/
ていきょうないよう /提供内容/
ていきょうはちおうじ /帝京八王子/
ていきょうばんぐみ /提供番組/
ていきょうほうほう /提供方法/
ていきょうもと /提供元/
ていきよきん /定期預金/
ていきりよう /定期利用/
ていきれっしゃ /定期列車/
ていきん /提琴/
ていきんり /低金利/
ていきんりじだい /低金利時代/
ていきんりせいさく /低金利政策/
ていぎ /定義/提議/
ていぎいき /定義域/
ていぎかのう /定義可能/
ていぎぐん /定義群/
ていぎしき /定義式/
ていぎじたい /定義自体/
ていぎじょう /定義上/
ていぎせつ /定義節/
ていぎたい /定義体/
ていぎちゅう /定義中/
ていぎちょう /定義長/
ていぎづけ /定義付け/
ていぎないよう /定義内容/
ていぎぶ /定義部/
ていぎぶぶん /定義部分/
ていぎぶん /定義文/
ていぎほう /定義法/
ていぎほうほう /定義方法/
ていぎもじ /定義文字/
ていぎもんだい /定義問題/
ていぎょう /帝業/
ていぎん /帝銀/
ていくう /低空/
ていくうひこう /低空飛行/
ていけい /提携/定型/定形/梯形/
ていけいかいしょう /提携解消/
ていけいがい /定型外/
ていけいく /定型句/
ていけいさき /提携先/
ていけいし /定型詩/
ていけいしょり /定型処理/
ていけいてき /定型的/
ていけいふうとう /定型封筒/
ていけいぶん /定型文/
ていけっとう /低血糖/
ていけっとうしょう /低血糖症/
ていけつ /締結/貞潔/挺傑/
ていけつあつ /低血圧/
ていけつあつしょう /低血圧症;[医]/
ていけのうお /手池の魚/
ていけん /定見/定検;[略語]定期検査,定期検診/
ていげき /帝劇;[略語]帝国劇場/
ていげん /提言/低減;reduce/逓減;step down/低弦;[音楽]viola,cello,contrabass/定言;[論理]/定限;limit/低限;?/
ていげんか /低減化/
ていげんてき /定言的;[論理]kategorisch/
ていげんめいほう /定言命法/
ていこ /艇庫/貞子/挺庫/
ていこう /抵抗/低高/定項/
ていこううんどう /抵抗運動/
ていこうかねつ /抵抗加熱/
ていこうかん /抵抗感/
ていこうがい /低公害/
ていこうがいしゃ /低公害車/
ていこうき /抵抗器/
ていこうけん /抵抗権;[法]right of resistance/
ていこうせい /抵抗性/
ていこうせいぎょ /抵抗制御/
ていこうせいぎょしゃ /抵抗制御車/
ていこうせいぶん /抵抗成分/
ていこうせいりょく /抵抗勢力/
ていこうち /抵抗値/
ていこうふか /抵抗負荷/
ていこうようせつ /抵抗溶接;resistance welding/
ていこうりつ /抵抗率/
ていこうりょく /抵抗力/
ていこうるい /抵抗類/
ていこく /帝国/定刻/帝國;旧字/
ていこくかいぐん /帝国海軍/帝國海軍;旧字/
ていこくぎかい /帝国議会/
ていこくぐん /帝国軍/
ていこくけんぽう /帝国憲法;(大日本帝国憲法)/
ていこくげきじょう /帝国劇場/
ていこくさんぎょう /帝国産業;[企業名]/
ていこくしゅぎ /帝国主義/
ていこくしゅぎしゃ /帝国主義者/
ていこくしゅぎだんかい /帝国主義段階/
ていこくしゅと /帝国首都/
ていこくせきゆ /帝国石油;[企業名]/
ていこくせんい /帝国繊維;[企業名]/
ていこくばん /帝国版/
ていこくほてる /帝国ホテル;[企業名]/
ていこくりくぐん /帝国陸軍/帝國陸軍;旧字/
ていこすと /低コスト/
ていご /低語/
ていさい /体裁/
ていさく /定朔/
ていさつ /偵察/
ていさついん /偵察員/
ていさつえいせい /偵察衛星/
ていさつき /偵察機/
ていさつよういん /偵察要員/
ていさん /帝産/
ていさんそ /低酸素/
ていさんそしょう /低酸素症;[医]hypoxia/
ていさんだい /帝産台/
ていざ /帝座/
ていざいは /定在波/
ていざいはひ /定在波比/
ていざいはほう /定在波法/
ていざん /低山/定残/
ていざんぎょう /定残業/
ていざんけい /定山溪/
ていし /停止/手石/定詞/底止/諦視/
ていしいち /停止位置/
ていしえき /停止液/
ていしき /定式/程式/
ていしきか /定式化/
ていしきかん /停止期間/
ていしきょり /停止距離/
ていしげき /低刺激/
ていしげきせい /低刺激性/
ていしげんしょう /停止現象/
ていししょぶん /停止処分/
ていししんごう /停止信号/
ていしじ /停止時/
ていしじかん /停止時間/
ていしじょうけん /停止条件/
ていしじょうたい /停止状態/
ていしすんぜん /停止寸前/
ていしせい /低姿勢/停止性/
ていしせん /停止線/
ていしちゅう /停止中/
ていしちょくぜん /停止直前/
ていしつ /底質;sediment/低質;low quality/低湿;⇔高燥/帝室/廷叱/
ていしつごしょうてん /帝室御賞典/
ていしつど /低湿度/
ていしのうりょく /停止能力/
ていしほうほう /停止方法/
ていしぼう /低脂肪/
ていしぼうにゅう /低脂肪乳;別名・水溶き脱脂粉乳/
ていしめいれい /停止命令/
ていしもんだい /停止問題/
ていしゃ /停車/
ていしゃいち /停車位置/
ていしゃえき /停車駅/
ていしゃえきあんない /停車駅案内/
ていしゃかのう /停車可能/
ていしゃご /停車後/
ていしゃしゃりょう /停車車両/
ていしゃじ /停車時/
ていしゃじかん /停車時間/
ていしゃじょう /停車場/
ていしゃじょうたい /停車状態/
ていしゃちゅう /停車中/
ていしゃちょくぜん /停車直前/
ていしゃば /停車場/
ていしゃまえ /停車前/
ていしゃれっしゃ /停車列車/
ていしゅ /亭主/艇首/
ていしゅう /鄭州/定収/挺秀/
ていしゅうにゅう /低収入/定収入/
ていしゅうは /低周波/
ていしゅうはおん /低周波音/
ていしゅうはおんしょうこうぐん /低周波音症候群/
ていしゅうはしゅつりょく /低周波出力/
ていしゅうはしんどう /低周波振動/
ていしゅうはすう /低周波数/
ていしゅうはすういき /低周波数域/
ていしゅかんぱく /亭主関白/
ていしゅく /貞淑/
ていしゅっし /低出資/
ていしゅつ /提出/挺出;excel/
ていしゅつきげん /提出期限/
ていしゅつご /提出後/
ていしゅつさき /提出先/
ていしゅつしめきり /提出締切/
ていしゅつしゃ /提出者/
ていしゅつしょるい /提出書類/
ていしゅつじょ /提出所/
ていしゅつび /提出日/
ていしゅつぶつ /提出物/
ていしゅつぶんしょ /提出文書/
ていしゅつほうほう /提出方法/
ていしゅつまえ /提出前/
ていしゅつよう /提出用/低出葉/
ていしゅつようし /提出用紙/
ていしゅつりつ /提出率/
ていしゅもち /亭主持ち/
ていしょ /低所/
ていしょう /提唱/定昇/低唱;浅酌-/
ていしょうしゃ /提唱者/
ていしょうちゅう /提唱中/
ていしょうど /低照度/
ていしょうひ /低消費/
ていしょうひでんりょく /低消費電力/
ていしょく /定食/抵触/定植;「稲の-」/停職;「-処分」/定職;「-に就く」/呈色/牴触;=抵触/
ていしょくはんのう /呈色反応/
ていしょくや /定食屋/
ていしょとく /低所得/
ていしょとくしゃ /低所得者/
ていしょとくしゃそう /低所得者層/
ていしょとくそう /低所得層/
ていしろう /偵四郎/
ていしん /逓信/挺身;†身を挺する/廷臣/艇身;†boat's length. cf.馬身/挺進;†抜きん出て進む/定進/遞信;「逓」旧字/
ていしんこう /貞信公;小倉山 峰のもみぢば 心あらば いまひとたびの みゆき待たなむ/
ていしんしゅうてき /低侵襲的/
ていしんしょう /逓信省/
ていしんだいじん /逓信大臣/
ていしんらい /低信頼/
ていじ /提示;†「対案を-する」/定時/呈示;†(≒提示,特に具体的な物について)「身分証を-する」/丁字/低次/貞治;年号(1362-68)/貞二/悌二/貞次/禎二/禎治/綴字/
ていじうんこう /定時運行/
ていじおん /提示音/
ていじかかく /提示価格/
ていじけい /丁字形/
ていじげん /低次元/
ていじご /定時後/
ていじごと /定時毎/
ていじじかん /提示時間/
ていじじこく /提示時刻/呈示時刻/
ていじじゅんじょ /提示順序/
ていじじょうけん /提示条件/
ていじすう /提示数/
ていじせい /定時制/
ていじそうかい /定時総会/
ていじそうち /呈示装置/
ていじつ /定日/
ていじぶ /提示部/
ていじほう /提示法/定時法/綴字法;orthography/
ていじゅう /定住/
ていじゅうしん /低重心/
ていじゅうしんか /低重心化/
ていじゅんど /低純度/
ていじょ /貞女/
ていじょう /定常/呈上/堤上/
ていじょううちゅうろん /定常宇宙論/
ていじょうおん /定常音/
ていじょうかくりつ /定常確率/
ていじょうぎょうむ /定常業務/
ていじょうこう /定常光/
ていじょうじけいれつ /定常時系列/
ていじょうじょうたい /定常状態/
ていじょうせい /定常性/
ていじょうたい /定常態/
ていじょうてき /定常的/
ていじょうでんりゅう /定常電流;stationary current/
ていじょうは /定常波/
ていじょうぶ /定常部/
ていじょうぶんぷ /定常分布/
ていじれんらく /定時連絡/
ていじろ /丁字路/
ていじん /帝人/
ていすいじゅん /低水準/
ていすう /定数/艇数/
ていすうかくさ /定数格差/
ていすうきごう /定数記号/
ていすうけいさん /定数計算/
ていすうけいすう /定数係数/
ていすうこう /定数項/
ていすうしき /定数式/
ていすうぜせい /定数是正/
ていすうち /定数値/
ていすうばい /定数倍/
ていすうぶん /定数文/
ていずいえきあつしょうこうぐん /低髄液圧症候群/
ていせい /訂正/定性/帝政/低声/帝制/貞静/提撕/
ていせいいん /訂正印/
ていせいかしょ /訂正箇所/
ていせいかのう /訂正可能/
ていせいがくえん /貞静学園/
ていせいきじ /訂正記事/
ていせいきのう /訂正機能/
ていせいご /訂正後/
ていせいしてき /訂正指摘/
ていせいすいろん /定性推論/
ていせいせいぶつ /底生生物;benthos/
ていせいちょう /低成長/
ていせいてき /定性的/
ていせいてん /訂正点/
ていせいとうこう /訂正投稿/
ていせいのう /低性能/
ていせいのうりょく /訂正能力/
ていせいばん /訂正版/
ていせいふごう /訂正符号/
ていせいぶんせき /定性分析/
ていせいほうほう /訂正方法/
ていせいよう /訂正用/
ていせいりつ /訂正率/
ていせき /定積;isochoric.「-変化」/艇積/定石;動かない石 NB:囲碁用語は「じょうせき」/
ていせきぶん /定積分/
ていせつ /定説/貞節/挺節/
ていせん /停戦;cease-fire/停船;船の停止/
ていせんかんし /停戦監視/
ていせんきょうぎ /停戦協議/
ていせんきょうていいはん /停戦協定違反/
ていせんりょう /低線量/
ていぜん /庭前/挺然/
ていそ /提訴/定礎/
ていそう /低層;low layer/貞操/底層;bottom layer/逓送/
ていそうおん /低騒音/
ていそうかんねん /貞操観念/
ていそうすい /底層水/
ていそうたい /貞操帯/
ていそうりゅう /底層流/
ていそく /低速/定則/
ていそくいき /低速域/
ていそくか /低速化/
ていそくかいせん /低速回線/
ていそくかいてん /低速回転/定速回転/
ていそくがわ /低速側/
ていそくしゃ /低速車/
ていそくじ /低速時/定速時/
ていそくすう /定足数/
ていそくそうこう /定速走行/
ていそくど /低速度/定速度/
ていそしき /定礎式/
ていそんしつ /低損失/
ていぞう /逓増;次第に増えること/貞蔵/
ていぞく /低俗/
ていぞくせい /低俗性/
ていたい /停滞/堤体/定退/手痛い/
ていたいいき /低帯域/
ていたいおん /低体温/
ていたいおんしょう /低体温症/
ていたいかん /停滞感/
ていたいき /停滞期/
ていたいぐみ /停滞組/
ていたいぜんせん /停滞前線/
ていたいちゅう /停滞中/
ていたいび /停滞日/定退日/
ていたく /邸宅/
ていたらく /体たらく/為体/低鱈苦;当て字/
ていだい /帝大/提題/
ていだいけい /帝大系/
ていだん /鼎談/梯団/低段/
ていだんしゃ /低段者/
ていち /低地/定置;fixed/定値;constant value/
ていちあみ /定置網/
ていちしき /定置式/
ていちそうこうねんぴ /定地走行燃費/
ていちゃく /定着/
ていちゃくえき /定着液/
ていちゃくか /定着化/
ていちゃくじかん /定着時間/
ていちゃくせい /定着性/
ていちゃくど /定着度/
ていちゃくぶつ /定着物/
ていちゃくりつ /定着率/
ていちゅうそく /低中速/
ていちょう /低調/丁重/低張/艇長/鄭重;=丁重/低潮/
ていちょく /挺直/
ていちんぎん /低賃金/
ていっぱい /手一杯/
ていてい /廷丁/亭々/
ていてつ /蹄鉄/
ていてん /定点/
ていてんかんそく /定点観測/
ていてんしき /定点式/
ていでん /停電/遞傳/
ていでんあつ /低電圧;low voltage/定電圧;constant voltage/
ていでんあつか /低電圧化/
ていでんあつげん /定電圧源/
ていでんじ /停電時/
ていでんじこ /停電事故/
ていでんりゅう /定電流/
ていでんりゅうげん /定電流源/
ていでんりゅうじゅうでん /定電流充電/
ていと /帝都/
ていとう /抵当/低糖/低頭/提灯/
ていとうがし /抵当貸/
ていとうけん /抵当権/
ていとうけんせっていしゃ /抵当権設定者/
ていとうしょうけん /抵当証券/
ていとく /提督/帝徳/
ていとくてん /低得点/
ていとでんてつ /帝都電鉄/
ていとものがたり /帝都物語/
ていとん /停頓/
ていど /程度/
ていどくせい /低毒性/
ていどさ /程度差/
ていどひつよう /程度必要/
ていどもんだい /程度問題/
ていどよそく /程度予測/
ていどりかい /程度理解/
ていない /庭内/邸内/廷内/
ていね /手稲/
ていねい /丁寧/
ていねいご /丁寧語/
ていねん /定年/諦念/停年;=定年/丁年;20歳/
ていねんご /定年後/停年後/
ていねんごろ /定年頃/
ていねんせい /定年制/停年制/
ていねんたいかん /定年退官/
ていねんたいしょく /定年退職/停年退職/
ていねんぴ /低燃費/
ていねんれい /低年齢/
ていねんれいか /低年齢化/
ていねんれいそう /低年齢層/
ていのう /低能/
ていのうしゅく /低濃縮/
ていのうど /低濃度/
ていは /停波/
ていはい /停廃/
ていはく /停泊/碇泊;=停泊/
ていはくち /停泊地/
ていはつ /剃髪/
ていはつしき /剃髪式/
ていはんぱつ /低反発/
ていばい /逓倍/
ていばいき /逓倍器/
ていばいりつ /低倍率/
ていばつ /挺抜/
ていばん /定番/定盤;定番のレコード?/定版;?/
ていばんしょうひん /定番商品/
ていひじゅう /低比重/
ていひょう /定評/
ていひんしつ /低品質/
ていひんど /低頻度/
ていびょう /帝廟/
ていふ /貞婦/
ていふか /低負荷/
ていふく /定幅/
ていぶ /底部/
ていぶんかいのう /低分解能/
ていぶんさん /低分散/
ていへん /底辺/
ていほん /底本;†sourcebook.「校訂の-」/定本;†standard text.「-○○全集」/
ていぼう /堤防/
ていぼく /低木/
ていまい /弟妹/
ていみつど /低密度/
ていめい /低迷/締盟/
ていめいぎみ /低迷気味/
ていめいじだい /低迷時代/
ていめん /底面/
ていめんせき /底面積/
ていもう /剃毛/
ていや /悌也/
ていやく /締約/定訳/
ていゆ /提喩;[修辞]synecdoche/
ていゆうせん /艇優先/
ていゆほう /提喩法/
ていよう /提要/定容/定窯;宋代の名窯/
ていようりょう /低用量/
ていようりょうぴる /低用量ピル/
ていよく /低翼/体良く/
ていよくき /低翼機/
ていよさん /低予算/
ていらく /低落/
ていり /定理/低利/廷吏/
ていりき /禎力/
ていりしょうめい /定理証明/
ていりしょうめいけい /定理証明系/
ていりつ /定率;†fixed rate/低率;†low rate/定立;[哲学]These/鼎立/定律;fixed laws/挺立/
ていりつげんぜい /定率減税/
ていりつぜい /定率税/
ていりつほう /定率法/
ていりゅう /底流/停留/
ていりゅうしょ /停留所/
ていりゅうじかん /停留時間/
ていりゅうじょ /停留所/
ていりゅうじょいがい /停留所以外/
ていりゅうじょう /停留場/
ていりゅうじょかん /停留所間/
ていりゅうじょめい /停留所名/
ていりょう /定量/
ていりょうか /定量化/
ていりょうきん /低料金/
ていりょうせい /定量性/
ていりょうせん /定量戦/
ていりょうてき /定量的/
ていりょうてきしひょう /定量的指標/
ていりょうぶんせき /定量分析/
ているい /涕涙/
ていれ /手入れ/
ていれい /定例/
ていれいかい /定例会/
ていれいきょうじゅかい /定例教授会/
ていれつ /低劣/貞烈/
ていれべる /低レベル/
ていれん /低廉/
ていろん /定論/
てうえ /手植え/
てうす /手薄/
てうち /手打/手打ち/
てうちめん /手打ち麺/手打麺/
ておい /手負い/
ておくれ /手遅れ/手後れ/
ておけ /手桶/
ておし /手押し/
ておち /手落ち/
ておの /手斧/
ており /手織/手織り/
てかがみ /手鏡/手鑑/
てかげん /手加減/
てかず /手数/
てかせ /手枷/
てが /手賀/
てがい /手飼/
てがかり /手掛かり/手がかり/手掛り/手懸り/手懸かり/
てがき /手書き/手書/
てがきすうじ /手書き数字/
てがきすうじにんしき /手書き数字認識/
てがきもじ /手書き文字/
てがきもじにんしき /手書き文字認識/
てがた /手形/
てがたかしつけ /手形貸付;loan of bill. 銀行あての約手を出させる融資/
てがたこうい /手形行為/
てがたこうかんじょ /手形交換所/
てがたさいけん /手形債権/
てがたな /手刀/
てがたひきうけ /手形引受/
てがたほう /手形法/
てがたわりびき /手形割引/
てがぬま /手賀沼/
てがみ /手紙/
てがら /手柄/
てがらばなし /手柄話/
てがる /手軽/
てがわ /手側/
てき /的/敵;enemy/適;適切/滴;水滴/摘;指摘/鏑;かぶら/嫡;嫡子/笛;汽笛/迪;迪化(ウルムチ)/廸;「迪」の異体字/荻;おぎ/狄;夷狄/逖;(にげる)/擲;投擲/躑;躑躅/擢;抜擢/糴;かいよね/剔;摘出/覿;覿面/俶/彳;(ぎょうにんべん)/
てき> /敵;敵艦隊,敵陣営,敵戦車/
てきあいて /敵相手/
てきい /敵意;hostility/適意;pleasure/
てきえい /敵影/
てきおう /適応/
てきおうか /適応化/
てきおうかのう /適応可能/
てきおうがくしゅう /適応学習/
てきおうがた /適応型/
てきおうけい /適応系/
てきおうしょう /適応症/
てきおうしょうがい /適応障害;[医]/
てきおうしょうこうぐん /適応症候群/
てきおうしんごうしょり /適応信号処理/
てきおうせい /適応性/
てきおうせいぎょ /適応制御/
てきおうせんりゃく /適応戦略/
てきおうてき /適応的/
てきおうど /適応度/
てきおうはんい /適応範囲/
てきおうぶんかつ /適応分割/
てきおうほう /適応法/
てきおうほうさん /適応放散/
てきおうりょく /適応力/
てきおん /適温/
てきか /滴下;drip/摘果;fruit picking/適価;moderate price/摘花;flower picking/迪化;地名,現ウルムチ/
てきかく /的確;†accurate.「-な判断」/適格;†eligible.「-者」/適確;†=的確(の当て字)/
てきかくしゃ /適格者/
てきかくせい /適格性/
てきかくたいしょくねんきん /適格退職年金/
てきかくねんきん /適格年金/
てきかた /敵方/
てきかん /敵艦/
てきかんたい /敵艦隊/
てきが /摘芽/
てきがいしん /敵愾心/
てきがた /敵方/
てきがわ /敵側/
てきき /適期/敵機/手利き/摘記;=てっき/
てききしゅうらい /敵機襲来/
てききょてん /敵拠点/
てきぎ /適宜/
てきぎついか /適宜追加/
てきぎはんだん /適宜判断/
てきぎへんこう /適宜変更/
てきぎょう /適業/
てきぐん /敵軍/
てきげん /適言/
てきこく /敵国/
てきこくじょうこう /敵国条項/
てきごう /適合/
てきごうか /適合化/
てきごうしゃ /適合車/
てきごうせい /適合性/
てきごうど /適合度/
てきごうにんてい /適合認定/
てきごうりつ /適合率/
てきさい /適才/
てきさく /適作/
てきざい /適材/滴剤;[医]drop/
てきざいてきしょ /適材適所/
てきし /敵視/摘示/
てきしつ /敵失;-に乗じる/
てきしゃ /適者/敵車/
てきしゃせいぞん /適者生存/
てきしゅ /敵手/
てきしゅう /敵襲/
てきしゅつ /摘出/剔出/
てきしゅつしゅじゅつ /摘出手術/
てきしゅつじゅつ /摘出術/
てきしょ /適所/
てきしょう /敵将/
てきしょく /適職/
てきしょてきざい /適所適材/
てきしん /摘心/摘芯;頂芽を摘みとること/
てきじ /適時/
てきじだ /適時打/
てきじにるいだ /適時二塁打/
てきじょ /摘除/滌除/
てきじょう /敵情/
てきじょうしさつ /敵状視察/
てきじん /敵陣/敵人/
てきじんがわ /敵陣側/
てきじんない /敵陣内/
てきず /手傷/手疵/手創/
てきせい /適正;†adequate.「-価格」/適性;†aptitude.「-検査」/敵性;†hostile.「-音楽」/
てきせいか /適正化/
てきせいかかく /適正価格/
てきせいけんさ /適性検査/
てきせいこうりょう /適正光量/
てきせいしけん /適性試験/
てきせいしょり /適正処理/
てきせいしんだん /適性診断/
てきせいすう /適正数/
てきせいち /適正値/
てきせいてつづき /適正手続/
てきせいりょく /適正力/
てきせいろこう /適正露光/
てきせいろしゅつ /適正露出/
てきせつ /適切/
てきせつふてきせつ /適切不適切/
てきせんしゃ /敵戦車/
てきせんとうき /敵戦闘機/
てきぜん /敵前/
てきぜんとうぼう /敵前逃亡/
てきそん /劇村/
てきたい /敵対/
てきたいいしき /敵対意識/
てきたいかんけい /敵対関係/
てきたいこうい /敵対行為/
てきたいこうどう /敵対行動/
てきたいし /敵対視/
てきたいしゃ /敵対者/
てきたいしん /敵対心/
てきたいせいりょく /敵対勢力/
てきたいてき /敵対的/
てきたいてきばいしゅう /敵対的買収/
てきだん /敵弾/擲弾/擲彈;旧字/
てきだんとう /擲弾筒/
てきち /適地/敵地/
てきちゅう /的中/敵中/適中;≒的中/
てきちゅうりつ /的中率/
てきちょく /躑躅/
てきてい /滴定/
てきとう /適当/
てきとうせい /適当性/
てきど /適度/
てきどうし /敵同士/
てきにん /適任/敵人/
てきにんしゃ /適任者/
てきはい /敵背/
てきはつ /摘発/
てきはつじけん /摘発事件/
てきばくげきき /敵爆撃機/
てきひ /適否/
てきひょう /適評/
てきふてき /適不適/
てきへい /敵兵/
てきほう /適法/
てきほうこうい /適法行為/
てきほうせい /適法性/
てきほんきょち /敵本拠地/
てきほんしゅぎ /敵本主義/
てきみかた /敵味方/
てきめん /覿面/
てきや /的屋/テキ屋/
てきやく /適役/敵役;かたきやく/適訳/適薬/
てきよう /適用/摘要/
てきようかのう /適用可能/
てきようがい /適用外/
てきようきそく /適用規則/
てきようぎょうむ /適用業務/
てきようけっか /適用結果/
てきようげんかい /適用限界/
てきようこうか /適用効果/
てきようご /適用後/
てきようじ /適用時/
てきようじゅんじょ /適用順序/
てきようじょうけん /適用条件/
てきようじょがい /適用除外/
てきようじれい /適用事例/
てきようずみ /適用済/
てきようせい /適用性/
てきようたいしょう /適用対象/
てきようたいしょうがい /適用対象外/
てきようはんい /適用範囲/
てきようはんいがい /適用範囲外/
てきようふかのう /適用不可能/
てきようぶ /適用部/
てきようへんこう /適用変更/
てきようほう /適用法/
てきようまえ /適用前/
てきようれい /適用例/
てきらい /摘蕾;[園芸]ツボミを間引くこと/
てきりょう /適量/
てきるい /敵塁/
てきれい /適齢/適例/
てきれいき /適齢期/
てきろく /摘録/
てぎね /手杵/
てぎれ /手切れ/
てぎれきん /手切れ金/
てぎわ /手際/
てくせ /手癖/手くせ/
てくだ /手管/
てくねちうむ /Tc/Technetium/
てくばり /手配り/
てくび /手首/
てくびこっせつ /手首骨折/
てくらがり /手暗がり/
てぐ /手具/
てぐさり /手鎖/
てぐす /天蚕糸/
てぐすね /手ぐすね/手薬煉/手具脛/
てぐち /手口/
てぐるま /輦/手車/
てけいさん /手計算/
てこ /梃子/梃/手子/挺子;?/
てこいれ /梃入れ/テコ入れ/てこ入れ/
てこう /手甲/
てこぎ /手漕ぎ/
てご /手児/
てごころ /手心/
てごたえ /手応え/手答え/
てごと /手事;箏曲の間奏/
てごま /手駒/
てごめ /手籠/手籠め/手篭め;「籠」異体字/
てごろ /手頃/手ごろ/
てさき /手先/
てさぎょう /手作業/
てさぐり /手探り/
てさげ /手提げ/手提/
てさげかばん /手提げ鞄/
てさげきんこ /手提げ金庫;portable safe/
てさげぶくろ /手提げ袋/
てさし /手差し/
てさばき /手捌き/
てざいく /手細工/
てざき /手崎/
てざし /手差し/
てざわり /手触り/
てしお /手塩/天塩/
てしおがわ /天塩川;北海道/
てしおざら /手塩皿/
てしおなかがわ /天塩中川/
てしかが /弟子屈/
てしがわら /勅使河原/
てしくつちょう /弟子屈町/
てしごと /手仕事/
てした /手下/
てしば /手柴/
てしま /手島/手嶋/
てしゅうせい /手修正/
てしょく /手燭/手職/
てしろぎ /手代木/
てしんごう /手信号/
てじか /手近/
てじな /手品/
てじなし /手品師/
てじま /手島/手嶋/
てじまい /手仕舞い/
てじめ /手締め/
てじゃく /手酌/
てじゅん /手順/
てじゅんしょ /手順書/
てじょう /手錠/
てすう /手数/
てすうりょう /手数料/
てすうりょうていど /手数料程度/
てすうりょうむりょう /手数料無料/
てすき /手漉き;「-の和紙」/手隙;「お-の時にでも」/手透き;=手隙/
てすさび /手遊び/
てすじ /手筋/
てすじしゅう /手筋集/
てすとかんきょう /テスト環境/
てすときかん /テスト期間/
てすとしようしょ /テスト仕様書/
てすとばん /テスト版/
てすとまえ /テスト前/
てすり /手摺り/手すり/
てずか /手塚;※仮名遣い「てづか」/
てずから /手ずから/
てずり /手刷/
てずれ /手擦れ/
てせい /手製/
てぜい /手勢/
てぜま /手狭/
てぜんたい /手全体/
てそう /手相/
てそうがく /手相学/
てそうみ /手相見/
てぞん /手損/
てたれ /手タレ/
てだい /手代/
てだし /手出し/
てだすかり /手助かり/
てだすけ /手助け/
てだて /手立て/手だて/
てだま /手玉/
てだれ /手練/手練れ/手足れ/
てちがい /手違い/
てちょう /手帳/手帖;=手帳/
てちょうがた /手帳型/
てぢか /手近/
てっ /徹/
てっか /鉄火/
てっかい /撤回/鉄拐;†隋の仙人/鉄枴;†鉄の杖/
てっかいようきゅう /撤回要求/
てっかく /適格/的確/
てっかどん /鉄火丼/
てっかどんぶり /鉄火丼/
てっかば /鉄火場/
てっかまき /鉄火巻/鉄火巻き/
てっかめん /鉄仮面/
てっかん /鉄管/鉄幹;梅の幹/鉄環/
てっき /敵機/鉄器/適期/鉄騎/摘記/
てっきじだい /鉄器時代/
てっきゅう /鉄球/
てっきょ /撤去/剔去/
てっきょう /鉄橋/
てっきょうした /鉄橋下/
てっきょかのう /撤去可能/
てっきょご /撤去後/
てっきん /鉄筋/鉄琴/
てっきんこう /鉄筋工/
てっきんこんくりーと /鉄筋コンクリート;RC/
てっけつ /鉄血/剔抉/
てっけん /鉄拳/鉄剣/鉄建/鉄研/
てっけんせいさい /鉄拳制裁/
てっこう /鉄鋼;steel/鉄工;ironsmith/手甲/鉄鉱;iron ore/鉄甲;iron armour/鐵工;「鉄」旧字/鐵鋼;「鉄」旧字/鐵鉱;「鉄」旧字/剔紅/
てっこうぎょう /鉄鋼業/
てっこうしょ /鉄工所/鐵工所;「鉄」旧字/鉄鋼所/鉄鉱所/鐵鉱所;「鉄」旧字/鐵綱所;「鉄」旧字/
てっこうじょ /鉄工所/鐵工所;「鉄」旧字/
てっこうじょう /鉄工場/
てっこうせき /鉄鉱石/
てっこうせん /鉄甲船/
てっこうだん /徹甲弾/
てっこつ /鉄骨/
てっこついんりょう /鉄骨飲料/
てっこつこうぞう /鉄骨構造;Ｓ造/
てっこつぞう /鉄骨造/
てっこつてっきんこんくりーと /鉄骨鉄筋コンクリート/
てっさ /鉄鎖/
てっさい /鉄斎;富岡鉄斎/
てっさく /鉄柵/鉄索/
てっしゃ /鉄砂/
てっしゅう /撤収/撤收;旧字/
てっしゅうじゅんび /撤収準備/
てっしょう /鉄漿/徹宵/哲章;人名/
てっしょきものがたり /徹書記物語/
てっしん /鉄心/
てっしんせきちょう /鉄心石腸/
てっせい /鉄製/哲西/
てっせき /鉄石/
てっせん /鉄線/鉄泉/鉄扇/
てっそく /鉄則/
てったい /撤退/
てったいきげん /撤退期限/
てったいじょうけん /撤退条件/
てったいちゅう /撤退中/
てっちゅう /鉄柱/
てっちゅうこうげき /鉄柱攻撃/
てっつい /鉄槌/鉄鎚/
てってい /徹底/
てってい> /徹底;-分析,-解析,-追及/
てっていか /徹底化/
てっていかいせき /徹底解析/
てっていかいぞう /徹底改造/
てっていかいめい /徹底解明/
てっていこうかい /徹底公開/
てっていこうせん /徹底抗戦/
てっていせい /徹底性/
てっていついせき /徹底追跡/
てっていてき /徹底的/
てっていひかく /徹底比較/
てっていぶんせき /徹底分析/
てっとう /鉄塔/
てっとうてつび /徹頭徹尾/
てっぱい /撤廃/
てっぱつ /鉄鉢/
てっぱん /鉄板/鉄鈑/
てっぱんやき /鉄板焼/
てっぴ /鉄扉/
てっぴつ /鉄筆/
てっぴつばん /鉄筆版/
てっぷ /轍鮒/
てっぷん /鉄粉/
てっぺい /撤兵/鉄平/
てっぺいせき /鉄平石/
てっぺき /鉄壁/
てっぺん /天辺/鉄片/
てっぽう /鉄砲/
てっぽううお /鉄砲魚/
てっぽうかじ /鉄砲鍛冶/
てっぽうじる /鉄砲汁;河豚汁/
てっぽうすう /鉄砲数/
てっぽうだま /鉄砲玉/
てっぽうづか /鉄炮塚;姓/
てっぽうみず /鉄砲水/
てっぽうゆり /鉄砲百合;trumpet lily/
てつ /鉄/轍;わだち。「-を踏む」/徹;徹夜/撤;撤退/姪;めい/咥;くわ・える/垤;ありづか/迭;更迭/跌;蹉跌/哲;哲学/耋;(高齢者)/餮;(むさぼる)/屮/綴;(テイの慣用音)点綴/輟;(やめる)/鐡;「鉄」の旧字1/鐵;「鉄」の旧字2/銕;「鉄」の異体字/Fe/Iron/
てつあき /哲明/
てつあれい /鉄アレイ/鉄亜鈴/
てついち /鉄一/
てついろ /鉄色/
てつえ /鉄絵/
てつお /哲夫/哲男/哲雄/哲郎/哲生/鉄夫/鉄男/鉄雄/徹男/哲臣/
てつか /手塚/
てつかいしょく /鉄灰色/
てつかず /手付かず/手着かず/
てつかぶと /鉄兜/
てつがく /哲学/
てつがくか /哲学科/
てつがくかい /哲学会/
てつがくきょういく /哲学教育/
てつがくきょうじゅ /哲学教授/
てつがくし /哲学史/
てつがくしゃ /哲学者/
てつがくしゃたち /哲学者達/
てつがくしゅっぱん /哲学出版;[出版社名]/
てつがくしょ /哲学書/
てつがくじょう /哲学上/
てつがくだんぎ /哲学談義/
てつがくてき /哲学的/
てつがくてきがいねん /哲学的概念/
てつがくばたけ /哲学畑/
てつがくろん /哲学論/
てつがくろんぎ /哲学論議/
てつがくろんそう /哲学論争/
てつき /手付き/手付/哲樹/手突き;†矢を手で投げること/
てつきどう /鉄軌道/
てつぎょ /鉄魚/轍魚/
てつくず /鉄屑/
てつぐし /鉄串/
てつけ /手付/手付け/
てつけいたい /鉄警隊/
てつけきん /手付金/手付け金/
てつけん /鉄研/
てつげんばん /鉄眼版/
てつこ /徹子/哲子/
てつごうし /鉄格子/
てつさび /鉄錆/
てつざい /鉄剤/鉄材/
てつざん /鉄山/
てつし /哲史/哲士/哲資/
てつしゃりん /鉄車輪/
てつしん /鉄芯/
てつじ /哲司/哲二/哲志/哲士/哲史/轍次/哲嗣/哲至/綴字/
てつじょう /鉄条/
てつじょうぎ /鉄定規/
てつじょうもう /鉄条網/
てつじろう /哲治郎/
てつじん /鉄人/哲人/
てつせい /鉄製/
てつせいひん /鉄製品/
てつた /哲多/
てつたろう /鉄太郎/哲太郎/
てつだい /手伝い/
てつづき /手続/手続き/
てつづきかん /手続き間/
てつづきがた /手続き型/手続型/
てつづきがたげんご /手続き型言語/手続型言語/
てつづきじょう /手続き上/
てつづきてき /手続的/手続き的/
てつづきない /手続き内/
てつづきほう /手続法/
てつどう /鉄道/鐵道;「鉄」旧字/
てつどうあいこうか /鉄道愛好家/
てつどういがい /鉄道以外/
てつどういっぱん /鉄道一般/
てつどういん /鉄道員/
てつどうえいぎょうほう /鉄道営業法/
てつどうえき /鉄道駅/
てつどうえんちょう /鉄道延長/
てつどうおう /鉄道王/
てつどうかい /鉄道界/
てつどうかもつ /鉄道貨物/
てつどうかんけい /鉄道関係/
てつどうかんけいしゃ /鉄道関係者/
てつどうかんれん /鉄道関連/
てつどうがいしゃ /鉄道会社/
てつどうがわ /鉄道側/
てつどうきねんかん /鉄道記念館/
てつどうきねんび /鉄道記念日/
てつどうきょく /鉄道局/
てつどうぎじゅつ /鉄道技術/
てつどうぎょう /鉄道業/
てつどうけい /鉄道系/
てつどうけいえい /鉄道経営/
てつどうけいさつたい /鉄道警察隊/
てつどうけん /鉄道研/
てつどうけんきゅうかい /鉄道研究会/
てつどうけんせつこうだん /鉄道建設公団/
てつどうこうあん /鉄道公安/
てつどうこうあんかん /鉄道公安官/
てつどうこうあんしょくいん /鉄道公安職員/
てつどうこうがく /鉄道工学/
てつどうこうそくか /鉄道高速化/
てつどうこくゆうか /鉄道国有化/
てつどうざっし /鉄道雑誌/
てつどうしがっかい /鉄道史学会/
てつどうしゃしん /鉄道写真/
てつどうしゃりょう /鉄道車両/
てつどうしゅみ /鉄道趣味/
てつどうしょう /鉄道省/
てつどうしょうか /鉄道唱歌/
てつどうしょくいん /鉄道職員/
てつどうじぎょう /鉄道事業/
てつどうじぎょうしゃ /鉄道事業者/
てつどうじぎょうほう /鉄道事業法/
てつどうじぎょうめんきょ /鉄道事業免許/
てつどうじこ /鉄道事故/
てつどうじこくひょう /鉄道時刻表/
てつどうじじょう /鉄道事情/
てつどうじょうほう /鉄道情報/
てつどうせいび /鉄道整備/
てつどうせいびききん /鉄道整備基金/
てつどうせん /鉄道線/
てつどうせんろ /鉄道線路/
てつどうそうけん /鉄道総研/
てつどうでんか /鉄道電化/
てつどうとう /鉄道等/
てつどうない /鉄道内/
てつどうはくぶつかん /鉄道博物館/
てつどうぶ /鉄道部/
てつどうぶもん /鉄道部門/
てつどうめい /鉄道名/
てつどうもう /鉄道網/
てつどうもけい /鉄道模型/
てつどうもけいしゅみ /鉄道模型趣味/
てつどうもけいよう /鉄道模型用/
てつどうゆうびん /鉄道郵便/
てつどうゆそう /鉄道輸送/
てつどうようご /鉄道用語/
てつどうようらん /鉄道要覧/
てつどうりょうきん /鉄道料金/
てつどうりょこう /鉄道旅行/
てつどうりょこうじゅつ /鉄道旅行術/
てつなべ /鉄鍋/
てつのり /哲憲/
てつぱいぷ /鉄パイプ/
てつひと /鉄人/鉄一/
てつひろ /哲弘/哲宏/
てつびょう /鉄鋲/
てつびん /鉄瓶/
てつぶろ /鉄風炉/
てつぶん /鉄分/
てつぶんか /鉄文化/
てつぶんほきゅう /鉄分補給/
てつぼう /鉄棒/鉄帽;iron helm/
てつまど /鉄窓/
てつまん /徹マン/
てつみ /哲美/
てつめん /鉄面/
てつめんぴ /鉄面皮/
てつもん /鉄門/
てつや /哲也/哲哉/徹夜/徹也/鉄也/哲弥/鉄弥/
てつやぐみ /徹夜組/
てつゆき /徹之/徹行/
てつようそう /綴葉装/
てつり /哲理/
てつりつ /迭立;両統-/
てつりん /鉄輪/
てつろ /鉄路/
てつろう /哲郎/哲朗/徹郎/鉄郎/
てつわん /鉄腕;-アトム/鉄椀;iron bowl/
てつわんあとむ /鉄腕アトム;[漫画]手塚治虫/
てづか /手塚/
てづかおさむ /手塚治虫/
てづかさとみ /手塚理美/
てづかみ /手掴み/
てづくり /手作り/
てづつ /手筒;昔の小銃/
てづつはなび /手筒花火/
てづまり /手詰まり/手詰り/
てづめ /手詰め/手詰/
てづり /手釣/
てづる /手蔓/
てて /父/
ててき /父君/
ててぎみ /父君/
ててご /父御/
ててなしご /父無し子/
てとり /手取り/
てとりあしとり /手取り足取り/
てどうさ /手動作/
てどり /手取り/手取/
てどりがわ /手取川/
てないしょく /手内職/
てなえ /攣/
てなおし /手直し/
てなが /手長/
てなぐさみ /手慰み/
てなげ /手投げ/
てなげだん /手投げ弾;手榴弾/
てなべ /手鍋/
てなみ /手並み/手並/
てならい /手習い/手習/
てなれ /手馴れ/
てなわ /手縄/
てにすぶ /テニス部/
てにもつ /手荷物/
てにもつけんさ /手荷物検査/
てにもつけんさじょう /手荷物検査場/
てにもつよう /手荷物用/
てにゅうりょく /手入力/
てにをは /天爾遠波/弖爾乎波/
てぬい /手縫い/
てぬかり /手抜かり/
てぬき /手抜き/
てぬきこうじ /手抜き工事/
てぬぐい /手拭い/手拭/手ぬぐい/
てのうち /手の内/
てのうら /手の裏/
てのこう /手の甲/
てのなか /手の中/
てのひら /掌/手の平/手のひら/
てのび /手延び/
てのべ /手延べ;-素麺/
てのべめん /手延べ麺/
てのもの /手の物/
てはい /手配/手牌;[麻雀]/
てはいし /手配師/
てはいしょ /手配書/
てはいちゅう /手配中/
てはいりょこう /手配旅行/
てはじめ /手始め/
てはず /手筈/手はず/
てはっちょう /手八丁;口八丁-/
てはら /手原/
てば /手羽/
てばこ /手箱/
てばさき /手羽先/
てばた /手旗/手機/
てばたしんごう /手旗信号;semaphore/
てばなし /手放し/
てばなれ /手離れ/
てばにく /手羽肉/
てばもと /手羽元/
てばや /手早/
てばん /手番/
てびかえ /手控え/
てびき /手引き/手引/
てびきあん /手引案/
てびきしょ /手引書/手引き書/
てびきだい /手引第/
てびねり /手捻り/
てびょうし /手拍子/
てびろ /手広/
てふうきん /手風琴/
てふき /手拭き/
てふだ /手札/
てふろんかこう /テフロン加工/
てぶくろ /手袋/
てぶそく /手不足/
てぶら /手ぶら/
てぶり /手振り/手振/
てぶれ /手ぶれ;[写真]/
てへん /天辺/手偏/頂辺/
てべんとう /手弁当/
てほどき /手解き/手ほどき/
てほん /手本/
てほんびき /手本引き/
てぼり /手掘り;-トンネル/手彫り;-の印鑑/
てま /手間/
てまえ /手前/点前/
てまえがって /手前勝手/
てまえがわ /手前側/
てまえだたみ /点前畳;[茶道]/
てまえども /手前共;our shop/
てまえみそ /手前味噌/
てまき /手巻き;-時計,-寿司/手巻/
てまきずし /手巻き寿司/手巻寿司/
てまくら /手枕/
てましごと /手間仕事/
てまだい /手間代/
てまちん /手間賃/
てまつぶし /手間潰し/
てまね /手真似/
てまねき /手招き/
てまひま /手間暇/
てまり /手毬/手鞠/
てまりうた /手毬唄/手鞠唄/手鞠歌/
てまわし /手回し/
てまわり /手回り/
てみじか /手短/
てみず /手水/
てみやげ /手土産/
てむかい /手向かい/
てめえ /手前/
てめえら /手前ら/
てもち /手持ち/手持/
てもちひん /手持ち品/手持品/
てもちぶさた /手持ち無沙汰/
てもと /手元/手許/
てもときん /手許金/
てもとりゅうどうせい /手元流動性/
てもり /手盛り/
てやき /手焼き/手焼/
てやく /手役/
てゆび /手指/
てら /寺/tera;[SI接頭語]T,10^12/地球/
てらい /寺井/衒い/
てらうち /寺内/
てらお /寺尾/
てらおか /寺岡/
てらおかせいこう /寺岡精工/
てらおとこ /寺男/
てらかた /寺方/
てらかど /寺門/
てらかわ /寺川/
てらがいと /寺垣内/
てらがわ /寺側/
てらくら /寺倉/
てらこ /寺子/
てらこしょう /寺小姓/
てらこや /寺子屋/
てらごや /寺小屋/
てらさか /寺坂/
てらさき /寺崎/
てらさわ /寺沢/寺澤/
てらした /寺下/
てらしま /寺島/寺嶋/
てらしょう /寺庄/
てらじま /寺島/
てらせん /寺銭/
てらそま /寺杣/
てらだ /寺田/
てらだとらひこ /寺田寅彦;(1878-1935)物理学者・随筆家/
てらち /寺地;-寄進/
てらどまり /寺泊/
てらにし /寺西/
てらの /寺野/
てらまえ /寺前/
てらまち /寺町/
てらまちじいんぐん /寺町寺院群/
てらまちどおり /寺町通/
てらむら /寺村/
てらもと /寺本/寺元/
てらやま /寺山/
てらやましゅうじ /寺山修司/
てり /輝/
てりかえし /照り返し/
てりは /照り葉/照葉/
てりやき /照り焼き/照焼/照焼き/
てりやす /輝泰/
てりゅうだん /手榴弾/
てりょうり /手料理/
てる /輝/照/晃/瑛/
てるあき /輝明/
てるい /照井/
てるお /輝夫/輝雄/輝男/照夫/照雄/照男/光男/晃夫/晃央/
てるき /輝樹/
てるこ /てる子/照子/輝子/
てるたか /照貴/
てるてるぼうず /てるてる坊主/照る照る坊主/
てると /照人/
てるのぶ /照信/輝暢/晧史/
てるのり /照則/
てるは /照葉/
てるひこ /輝彦/照彦/照比古/
てるひさ /照久/
てるひろ /照洋/
てるびうむ /Tb/Terbium/
てるみ /照美/輝美/
てるもと /輝元/
てるやす /輝泰/
てるゆき /輝幸/輝之/
てるる /Te/Tellurium/
てれ /照れ/
てれあさ /テレ朝/
てれかくし /照れ隠し/
てれとう /テレ東;テレビ東京/
てれび /電視/
てれびあさひ /テレビ朝日/
てれびがめん /テレビ画面/
てれびきょく /テレビ局/
てれびしーえむ /テレビＣＭ/
てれびしゅつえん /テレビ出演/
てれびだい /テレビ台/
てれびちゅうけい /テレビ中継/
てれびでんわ /テレビ電話/
てれびとう /テレビ塔/
てれびとうきょう /テレビ東京/
てれびばんぐみ /テレビ番組/
てれびほうそう /テレビ放送/
てれびよう /テレビ用/
てれびらん /テレビ欄/
てれびんゆ /テレビン油;terebinthina/
てれや /照れ屋/
てれわらい /照れ笑い/
てれん /手練/
てれんてくだ /手練手管/
てろこうげき /テロ攻撃/
てろじけん /テロ事件/
てろそしき /テロ組織/
てろたいさく /テロ対策/
てわけ /手分け/
てわざ /手技/手業/
てわたし /手渡し/
てん /点/店/天/転/展/貂/典/忝;かたじけな・い/添;添付/廛;やしき/壥;「廛」の異体字/纏;半纏/纒;「纏」の異体字/躔/填;充填/槙;まき/鷆/鷏;「鷆」の異体字/顛;顛末/巓;(山の)いただき/癲;癲癇(てんかん)/沾/霑/點;「点」の旧字/貼;(慣用音)/覘;うかが・う/靦/碾;ひ・く/輾;輾転反側/轉;「転」の旧字(人名用漢字)/囀;さえず・る/甜;甜菜/恬;恬然/腆/殄/丶;チュ,てん/奠;香奠/篆;篆刻/諂;へつら・う/辿;たど・る/殿;御殿/・;→dot/．/、/，/…/・・・/梃;?/
てんあつ /転圧/
てんあん /天安;年号(857-859)/
てんあんもん /天安門/
てんあんもんじけん /天安門事件/
てんあんもんひろば /天安門広場/
てんい /転移;†transfer.「癌の-」/転位;†displace.「原子の-」/天衣;-無縫/天意/典医/典韋;三国時代・曹操配下の巨漢/
てんいおんど /転移温度/
てんいがい /点以外/
てんいこうそ /転移酵素;[生化学]transferase/
てんいそう /転移巣;[医]metastatic focus/
てんいち /天一/
てんいむほう /天衣無縫/
てんいり /点入/
てんいん /店員/転院/
てんいんきょういく /店員教育/
てんうん /天運/
てんえ /天衣/
てんえい /天栄/天永;年号(1110-1113)/
てんえん /展延/天延;年号(973-976)/
てんえんせい /展延性/
てんおう /天王/天応;年号(781-782)/
てんおうせい /天王星;=てんのうせい/
てんおん /転音/天恩/
てんおんげん /点音源/
てんか /天下/添加/点火/転嫁;†「責任-」/転化;†conversion.「意味の-」/天花;雪/転科/天火/転訛;†[言語]corruption/天華/
てんかい /展開/天界/天海/転回/
てんかいかんすう /展開関数/
てんかいきぼう /展開希望/
てんかいけい /展開形/
てんかいけいすう /展開係数/
てんかいこうげき /展開攻撃/
てんかいご /展開後/
てんかいしき /展開式/
てんかいしゅほう /展開手法/
てんかいじ /展開時/
てんかいじたい /展開自体/
てんかいじょうたい /展開状態/
てんかいず /展開図/
てんかいずほう /展開図法/
てんかいそくど /展開速度/
てんかいち /天下市/天下一/
てんかいちぶどうかい /天下一武道会;[漫画]ドラゴンボール/
てんかいちゅう /展開中/
てんかいっぴん /天下一品/
てんかいてき /展開的/
てんかいてん /転回点/
てんかいばん /展開版/
てんかいぶ /展開部/
てんかいぶぶん /展開部分/
てんかいまえ /展開前/
てんかいゆうり /展開有利/
てんかく /点画;漢字の-/
てんかけい /点火系/
てんかこ /点過去/
てんかご /添加後/
てんかごめん /天下御免/
てんかざい /添加剤/
てんかしん /点加振/
てんかじき /点火時期/
てんかす /天滓/天かす/
てんかたいへい /天下泰平/天下太平/
てんかつきゅう /天蝎宮;[十二宮]さそり座(10.23-11.21)/
てんかてい /点過程/
てんかとう /転化糖;[化学]invert sugar/
てんかとういつ /天下統一/
てんかとり /天下取り/
てんかにち /天火日/
てんかびと /天下人/
てんかふぶ /天下布武;[日本史]信長の印文/
てんかふん /天花粉/天瓜粉;=天花粉/
てんかぶつ /添加物/
てんかぶつなど /添加物等/
てんかぷらぐ /点火プラグ/
てんかまえ /点火前/
てんかむそう /天下無双/
てんかむてき /天下無敵/
てんかれいじ /添加励磁/
てんかわ /添川/
てんかわけめ /天下分け目/
てんかん /転換/展観/癲癇/点間/天漢;天の川/天官/転官/
てんかんかかく /転換価格/
てんかんかぶしき /転換株式/
てんかんき /転換期/転換器/
てんかんしゃさい /転換社債/
てんかんじ /転換時/
てんかんてん /転換点/
てんかんろ /転換炉/
てんが /典雅/天河/天下;=てんか/殿下;=でんか/
てんがい /天外/天蓋/天涯/
てんがいこどく /天涯孤独/
てんがいまきょう /天外魔境/
てんがく /転学/
てんがくぶ /転学部/
てんがぢゃや /天下茶屋/
てんがん /点眼/天眼/
てんがんえき /点眼液/
てんがんざい /点眼剤/
てんがんすい /点眼水/
てんがんやく /点眼薬/
てんき /天気/転機/転記/転帰/天機/天氣/
てんきあめ /天気雨/
てんきがいきょう /天気概況/
てんきず /天気図/
てんきそうだんしょ /天気相談所/
てんきそうだんじょ /天気相談所/
てんきばんぐみ /天気番組/
てんきぼ /点鬼簿;鬼籍/
てんきや /天気屋/
てんきゅう /天球;[天文]celestrial shpere/天宮;天上の宮殿/
てんきゅうぎ /天球儀/
てんきょ /転居/典拠/
てんきょう /癲狂/
てんきょういん /癲狂院/
てんきょさき /転居先/
てんきょつうち /転居通知/
てんきよほう /天気予報/
てんきよほうし /天気予報士/
てんきん /転勤/
てんきんさき /転勤先/
てんきんぞく /転勤族/
てんきんひ /転勤費/
てんぎ /天喜;年号(1053-1058)/転義/典儀/
てんぎく /天菊/
てんぎょう /転業/天慶;年号(938-947)/
てんく /転句/
てんくう /天空/
てんくうかいかつ /天空海闊/
てんくうじょう /天空城/
てんくぎ /天釘;[パチンコ]/
てんぐ /天狗/
てんぐう /天宮/
てんぐさ /天草/
てんぐざる /天狗猿/
てんぐたけ /天狗茸/
てんぐだいら /天狗平/
てんぐとう /天狗党;[日本史]/
てんぐばし /天狗橋/
てんぐまい /天狗舞/
てんぐやま /天狗山/
てんけい /典型/天啓;revelation/天恵;gift/点景/添景;≒点景/天刑;天罰/
てんけいち /典型値/
てんけいてき /典型的/
てんけいれい /典型例/
てんけつ /転結/点穴/
てんけつごう /点結合/
てんけん /点検/天険;要害/天譴;天罰/
てんけんこうもく /点検項目/
てんけんしゅうり /点検修理/
てんけんじこう /点検事項/
てんけんせいび /点検整備/
てんげ /天下/天花;天国の花/天華/
てんげん /天元;年号(978-983)/点源/
てんげんだい /天元台/
てんこ /点呼/典故/
てんこう /天候/転向/転校/天功/天光/典孝/天皇/
てんこうぐみ /転向組/
てんこうげん /点光源/
てんこうこくしょく /天香国色/
てんこうさき /転校先/
てんこうしだい /天候次第/
てんこうしょにち /転校初日/
てんこうせい /転校生/
てんこうふじゅん /天候不順/
てんこうぶんがく /転向文学/
てんこうりつ /点効率/
てんこうりょく /転向力/
てんこおん /転呼音;[言語]「ハ行-」/
てんこく /篆刻/転告/
てんこもり /てんこ盛り/天こ盛り/テンコ盛り/
てんご /点５/転語/
てんごく /天国/典獄/
てんごくきぶん /天国気分/
てんごくへん /天国篇/
てんごくゆき /天国行き/天国行/
てんさ /点差/
てんさい /転載/天才/天災/甜菜/天際/
てんさいいらい /転載依頼/
てんさいか /転載可/
てんさいかいし /転載開始/
てんさいかがくしゃ /天才科学者/
てんさいかのう /転載可能/
てんさいきさい /天才奇才/
てんさいきじ /転載記事/
てんさいきょか /転載許可/
てんさいきんし /転載禁止/
てんさいけん /転載権/
てんさいご /転載後/
てんさいしゃ /転載者/
てんさいしょうじょ /天才少女/
てんさいしょうねん /天才少年/
てんさいじ /天才児/転載時/
てんさいじゆう /転載自由/
てんさいじょう /点差以上/
てんさいじょうけん /転載条件/
てんさいせい /天才性/
てんさいせいとう /甜菜製糖/
てんさいちへん /天災地変/
てんさいてき /天才的/
てんさいとう /甜菜糖/
てんさいはだ /天才肌/
てんさいふう /天才風/
てんさいふか /転載不可/
てんさいもと /転載元/
てんさいろん /天才論/
てんさく /添削/転作/
てんさくしどう /添削指導/
てんさん /天蚕/
てんさんぶつ /天産物/
てんざ /典座/
てんざい /点在/
てんざん /天山/
てんし /天使;angel/天子;emperor/展翅/天資/覘視/
てんしき /点式/
てんしげ /天繁/
てんしじ /点支持/
てんしじかん /天使時間/
てんしたち /天使達/
てんしち /転質/
てんしちょう /天使長/
てんしつ /天質/
てんしゃ /転写/転社/
てんしゃく /転借/
てんしゃだい /転車台/
てんしやく /天使役/
てんしゅ /店主/天守;-閣/天主;(<Deus)「-教」/
てんしゅうごう /点集合/
てんしゅかく /天守閣/
てんしゅきょう /天主教/
てんしゅく /転宿/
てんしゅつ /転出/点出/
てんしゅつこう /転出校/
てんしゅつしょうめい /転出証明/
てんしゅつとどけ /転出届/
てんしゅどう /天主堂/
てんしゅん /転瞬/
てんしょ /篆書/添書/転所/典書/
てんしょう /天正;年号(1573-92)/転生/天昇/天象/天承;年号(1131-1132)/
てんしょうどう /天賞堂/
てんしょく /転職/天職;vocation/天色/
てんしょくご /転職後/
てんしょくさき /転職先/
てんしょくまえ /転職前/
てんしん /天津/転身;†「作家への-」/転進;†退却/点心/天真;-爛漫/天心;岡倉-/
てんしんあまぐり /天津甘栗/
てんしんこう /天津港/
てんしんしはんだいがく /天津師範大学/
てんしんはん /天津飯/
てんしんらんまん /天真爛漫/
てんじ /展示/点字/添字;そえじ/典侍/天治;年号(1124-1126)/篆字/
てんじいん /展示員/
てんじいんさつ /点字印刷/
てんじかい /展示会/
てんじかいしゅさいしゃ /展示会主催者/
てんじかいじょう /展示会場/
てんじかん /展示館/
てんじかんけい /点字関係/
てんじきき /展示機器/
てんじく /天竺/
てんじくあおい /天竺葵/
てんじくがく /天竺楽/
てんじくねずみ /天竺鼠/
てんじくもめん /天竺木綿/
てんじくよう /天竺様;[建築]/
てんじしつ /展示室/
てんじしゃ /展示車/
てんじじょう /展示場/
てんじせつめいかい /展示説明会/
てんじそくばい /展示即売/
てんじそくばいかい /展示即売会/
てんじたんとうしゃ /展示担当者/
てんじつ /天日/
てんじつえん /天日塩/
てんじてんのう /天智天皇/
てんじとしょかん /点字図書館/
てんじひこう /展示飛行/
てんじひん /展示品/
てんじぶつ /展示物/
てんじぶろっく /点字ブロック/
てんじほう /展示法/
てんじゃ /点者/
てんじゅ /天寿/天授;年号(1375-1381)/
てんじゅう /転住/
てんじゅこく /天寿国/
てんじゅこくまんだら /天寿国曼荼羅/
てんじょ /天助/
てんじょう /天井;ceiling/天上;heaven/添乗/点状/殿上/天壌;天地/纏繞/天壤;旧字/
てんじょういた /天井板/
てんじょういん /添乗員/
てんじょううら /天井裏/
てんじょうかい /天上界/
てんじょうが /天井画/天上画;?/
てんじょうがわ /天井川/
てんじょうけい /纏繞茎/
てんじょうさじき /天井桟敷/
てんじょうせっちがた /天井設置型/
てんじょうだか /天井高/
てんじょうつり /天井吊/
てんじょうてんか /天上天下/
てんじょうてんげ /天上天下/
てんじょうびと /殿上人/
てんじょうむきゅう /天壌無窮/天壤無窮;「壌」旧字/
てんじょうめん /天井面/
てんじよう /点字用/
てんじん /天神/天人/
てんじんいわたや /天神岩田屋/
てんじんさま /天神様;-の細道じゃ/
てんじんだいら /天神平/
てんじんちぎ /天神地祇/
てんじんばし /天神橋/
てんじんまつり /天神祭/
てんじんや /天神屋/
てんすい /天水/
てんすう /点数/
てんすうか /点数化/
てんすうけいさん /点数計算/
てんすうせい /点数制/
てんすうせいど /点数制度/
てんすうちょうせい /点数調整/
てんすうはいぶん /点数配分/
てんずみ /点炭;[茶道]/
てんせい /転生;輪廻-/天性;nature/天成;heaven-sent/展性;malleable/転成;transform/天生/点睛;画龍-/
てんせいご /転生後/転成語/
てんせいじんご /天声人語/
てんせいまえ /転生前/
てんせいりんね /転生輪廻/
てんせいろ /天せいろ/
てんせき /転籍;transfer/典籍;book/転石/
てんせきとどけ /転籍届/
てんせっしょく /点接触/
てんせつ /点綴;てんてい/
てんせん /点線;……/転戦/転線;電車の-/
てんせんげん /点線源/
てんぜん /典膳/恬然/
てんそう /転送/
てんそうかのう /転送可能/
てんそうがわ /転送側/
てんそうき /転送機/
てんそうきかん /転送期間/
てんそうきこう /転送機構/
てんそうきのう /転送機能/
てんそうこうりつ /転送効率/
てんそうさき /転送先/
てんそうしつ /転送室/
てんそうしゃ /転送者/
てんそうしゅうりょう /転送終了/
てんそうしょり /転送処理/
てんそうじ /転送時/
てんそうじかん /転送時間/
てんそうじっけん /転送実験/
てんそうせいのう /転送性能/
てんそうそうち /転送装置/
てんそうそくど /転送速度/
てんそうちゅう /転送中/
てんそうとちゅう /転送途中/
てんそうのうりょく /転送能力/
てんそうはば /転送幅/
てんそうほうほう /転送方法/
てんそうもと /転送元/
てんそうよう /転送用/
てんそうようきゅう /転送要求/
てんそうようりょう /転送容量/
てんそうりょう /転送量/転送料/
てんそうろ /転送路/
てんそく /纏足/天測/天足;⇔纏足/典則/店則/纒足;異体字/
てんそば /天蕎麦/
てんそん /天孫/
てんそんこうりん /天孫降臨/
てんぞ /典座/
てんぞう /点像/
てんぞく /転属/
てんたい /天体/転貸/
てんたいかんそく /天体観測/
てんたいがぞう /天体画像/
てんたいしゃく /転貸借/
てんたいしゃしん /天体写真/
てんたいしゃしんか /天体写真家/
てんたいしょう /点対称/
てんたいぶつりがく /天体物理学/
てんたいぼうえんきょう /天体望遠鏡/
てんたいや /天体屋/
てんたいよう /天体用/
てんたかく /天高く/
てんたく /転宅/
てんたん /恬淡/
てんだい /天台/椽大/
てんだいさん /天台山;地名/
てんだいしかん /天台止観/
てんだいしゅう /天台宗/
てんだいだいし /天台大師;<538-597> 智ギ(豈＋頁)/
てんち /天地/転地;「-療養」/転置;inverse.「-行列」/
てんちかいびゃく /天地開闢/
てんちがえし /天地返し;[園芸]/
てんちぎゃくてん /天地逆転/
てんちぎょうれつ /転置行列/
てんちしんめい /天地神明/
てんちじん /天地人/
てんちそうぞう /天地創造/
てんちむよう /天地無用/
てんちゃ /甜茶;中国の甘いお茶/点茶/
てんちゃく /展着/
てんちゃくざい /展着剤;[園芸]spreading agent/
てんちゅう /天誅/天柱/転注/
てんちゅうぐみ /天誅組/天忠組/
てんちゅうさつ /天中殺/
てんちゅうし /典鋳司/
てんちゅうせつ /天中節/
てんちょう /店長/転調/天頂;zenith/天長;年号(824-834)/天聴;天皇が聴く/天寵;grace/
てんちょうさき /転調先/
てんちょうせつ /天長節;現在の天皇誕生日に相当/
てんちょうちきゅう /天長地久/
てんちりょうよう /転地療養/
てんつい /点対/
てんつゆ /天汁/天つゆ/
てんてい /天帝/点綴/
てんていとう /転抵当/
てんてき /点滴/天敵/
てんてきちゅう /点的中/
てんてこまい /てんてこ舞い;merry-go-round/
てんてつ /転轍/点綴;てんてい/
てんてつき /転轍機/
てんてん /転々/点々/輾転;-反側/展転;=輾転/…/・・・;中黒x3/‥/．．．/：/……/
てんてんてん /・・・;中黒x3/
てんてんはんそく /輾転反側/
てんでんか /点電荷/
てんと /奠都/
てんとう /店頭/転倒/点灯/天道/点燈/顛倒;≒転倒/点頭;nod/纏頭;祝儀/
てんとうかかく /店頭価格/
てんとうかぶ /店頭株/
てんとうかん /点灯管/
てんとうこうかい /店頭公開/
てんとうざいこ /店頭在庫/
てんとうしじょう /店頭市場/
てんとうしょぶんひん /店頭処分品/
てんとうじ /点灯時/転倒時/
てんとうちゅう /点灯中/
てんとうはんばい /店頭販売/
てんとうひん /店頭品/
てんとうむし /てんとう虫/天道虫/紅娘/瓢虫/
てんとく /天徳;年号(957-961)/転得/
てんとくじ /天徳寺/
てんとせん /点と線;-の支配/
てんとり /点取り/
てんどう /天童/天道/天堂/天動/顛動/
てんどうこうげん /天童高原/
てんどうし /天童市/
てんどうせつ /天動説/
てんどく /転読/点読/顛読/
てんどん /天丼/
てんな /天和;年号(1681-1684)/
てんない /店内/
てんないほうそう /店内放送/
てんなんしょう /天南星;[植物]dragon/
てんに /点２/
てんにゅう /転入/
てんにゅうせい /転入生/
てんにゅうてんしゅつ /転入転出/
てんにゅうとどけ /転入届/
てんにょ /天女/
てんにん /転任/天人/天仁;年号(1108-1110)/
てんにんか /天人花/
てんにんぎく /天人菊;[植物]gaillardia/
てんにんさき /転任先/
てんにんそう /天人草;[植物]/
てんにんちょう /天人鳥/
てんね /天衣/
てんねん /天然/
てんねんうらん /天然ウラン/
てんねんかじつ /天然果実/
てんねんかじゅう /天然果汁/
てんねんがき /天然牡蠣/
てんねんがす /天然ガス/
てんねんきねんぶつ /天然記念物/
てんねんごむ /天然ゴム;⇔合成ゴム/
てんねんしげん /天然資源/
てんねんしぜん /天然自然/
てんねんしば /天然芝/
てんねんしょく /天然色/
てんねんすい /天然水/
てんねんせっけん /天然石鹸/
てんねんせんりょう /天然染料/
てんねんとう /天然痘/
てんねんぱーま /天然パーマ/
てんねんひりょう /天然肥料/
てんねんぼく /天然木/
てんねんぼけ /天然ボケ/
てんねんもの /天然物/
てんねんゆき /天然雪/
てんねんりん /天然林/
てんのう /天皇/天王/
てんのうき /天皇記;620,厩戸皇子。現存せず/
てんのうきかんせつ /天皇機関説/
てんのうけ /天皇家/
てんのうこうごう /天皇皇后/
てんのうざん /天王山/
てんのうしゅけん /天皇主権/
てんのうしょう /天皇賞/
てんのうしょうあき /天皇賞秋/
てんのうしょうぐみ /天皇賞組/
てんのうしょうはる /天皇賞春/
てんのうしょうば /天皇賞馬/
てんのうじ /天王寺/
てんのうじえき /天王寺駅/
てんのうじこうえん /天王寺公園;大阪/
てんのうじしん /天皇自身/
てんのうじどうぶつえん /天王寺動物園/
てんのうじや /天王寺屋/
てんのうず /天王洲/
てんのうせい /天皇制/天王星;uranus/
てんのうせいど /天皇制度/
てんのうせいひはん /天皇制批判/
てんのうせいろん /天皇制論/
てんのうそくいご /天皇即位後/
てんのうたんじょうび /天皇誕生日;12.23/
てんのうだい /天王台/
てんのうちょう /天王町/
てんのうはい /天皇杯/
てんのうはいけっしょう /天皇杯決勝/
てんのうはいじゅんけっしょう /天皇杯準決勝/
てんのうはいよせん /天皇杯予選/
てんのうひはん /天皇批判/
てんのうへいか /天皇陛下/
てんのうほうぎょ /天皇崩御/
てんのうほうちゅう /天皇訪中/
てんのうほうどう /天皇報道/
てんはいれつ /点配列/
てんはく /天白/
てんはくく /天白区/
てんば /天馬/天端/
てんばい /転売/店売/
てんばいかいもどし /転売買戻し/
てんばいや /転売屋/
てんばつ /天罰/
てんばつてきめん /天罰覿面/
てんばん /天板/
てんばんごう /店番号/
てんぱい /聴牌;[麻雀]/天盃/顛沛/
てんぱく /天白/天伯/
てんぱん /天板/典範/
てんびき /天引き/
てんびざい /点鼻剤/
てんびやく /点鼻薬/
てんびょう /点描/
てんびょうほう /点描法/
てんびん /天秤/
てんびんきゅう /天秤宮;[十二宮]てんびん座(9.23-10.22)/
てんびんざ /天秤座;Libra(Lib),(9.23-10.22)/
てんびんぼう /天秤棒/
てんぴ /天日/天火;oven/
てんぴじお /天日塩/
てんぴぼし /天日干し/
てんぴょう /天平;年号(729-749)/
てんぴょうかんぽう /天平感宝;年号(749)/
てんぴょうしょうほう /天平勝宝;年号(749-757)/
てんぴょうじだい /天平時代;710-794/
てんぴょうじんご /天平神護;年号(765-767)/
てんぴょうぶんか /天平文化/
てんぴょうほうじ /天平宝字;年号(757-765)/
てんぴん /天稟/
てんぶ /転部/
てんぶくろ /天袋/
てんぶつ /天物/典物/
てんぶん /天分/天文;年号(1532-55)/篆文/
てんぷ /添付/天賦/貼付;ちょうふ/
てんぷかのう /添付可能/
てんぷく /転覆/天福/天吹/顛覆;=転覆/
てんぷしょるい /添付書類/
てんぷしりょう /添付資料/
てんぷじんけん /天賦人権/
てんぷちずさんしょう /添付地図参照/
てんぷふぁいる /添付ファイル/
てんぷら /天麩羅/天ぷら/
てんぷらあぶら /天ぷら油/
てんぷらこ /天ぷら粉/
てんぷらなべ /天ぷら鍋/
てんぷらや /天麩羅屋/天ぷら屋/
てんべつ /点別/
てんぺい /天兵/
てんぺん /天変/天辺/転変/
てんぺんちい /天変地異/
てんほー /天和/
てんほう /天和/
てんほくせん /天北線/
てんぼう /展望/点棒/
てんぼうしゃ /展望車/
てんぼうせき /展望席/
てんぼうだい /展望台/
てんぼうとう /展望塔/
てんぼうりん /転法輪/
てんぽ /店舗/填補/転補/
てんぽう /天保;年号(1830-1844)/天方/
てんぽうさん /天保山/
てんぽうざん /天保山/
てんぽうせん /天保銭/
てんぽうのかいかく /天保の改革;[日本史]天保12-14(1841-43),水野忠邦/
てんぽうんえい /店舗運営/
てんぽがた /店舗型/
てんぽない /店舗内/
てんぽはんばい /店舗販売/
てんぽめんせき /店舗面積/
てんぽもう /店舗網/
てんぽよう /店舗用/
てんぽん /点本/
てんま /天馬/伝馬/天魔/天満/
てんまがわ /天満川/
てんまく /天幕/
てんません /伝馬船/
てんまちょう /伝馬町/
てんまつ /顛末/天松/
てんまつき /顛末記/
てんまど /天窓/
てんまばし /天満橋/
てんまばやし /天間林/
てんまや /天満屋/
てんまん /天満/
てんまんぐう /天満宮/
てんまんてん /点満点/
てんむす /天むす/
てんむてんのう /天武天皇/
てんめ /点目/
てんめい /店名/天命/天明;年号(1781-1789)/
てんめいのたいか /天明の大火;[日本史]天明8(1788)/
てんめいふめい /店名不明/
てんめつ /点滅/
てんめつおん /点滅音/
てんめつき /点滅器/
てんめつじょうたい /点滅状態/
てんめん /纏綿/
てんめんじゃん /甜麺醤/
てんもう /天網/
てんもうかいかい /天網恢恢/
てんもく /天目/
てんもくぢゃわん /天目茶碗/
てんもん /天文/
てんもんえいせい /天文衛星;astronomical satellite/
てんもんか /天文家/
てんもんかん /天文館/
てんもんかんけい /天文関係/
てんもんがく /天文学/
てんもんがくしゃ /天文学者/
てんもんがくてき /天文学的/
てんもんがっか /天文学科/
てんもんがっかい /天文学会/
てんもんけい /天文系/
てんもんけいさん /天文計算/
てんもんげっぽう /天文月報/
てんもんげんしょう /天文現象/
てんもんざっし /天文雑誌/
てんもんしゃしん /天文写真/
てんもんしょうねん /天文少年/
てんもんたんい /天文単位/
てんもんだい /天文台/
てんもんどうこうかい /天文同好会/
てんもんねんかん /天文年鑑/
てんもんぶ /天文部/
てんもんや /天文屋/
てんや /店屋/
てんやく /点訳;点字訳/典薬;[律令制]医薬担当/点役;[日本史]臨時課税/転役;role change/天役;=点役/点薬;目薬(をさす)/典鑰;[律令制]倉庫の鍵(鑰)の管理役/
てんやくりょう /典薬寮/
てんやもの /店屋物/
てんゆう /天佑/天祐/
てんゆうしんじょ /天佑神助/
てんよ /天与/
てんよう /転用/天養;年号(1144-1145)/
てんようさき /転用先/
てんようせつ /点溶接;spot welding/
てんらい /天来/天雷/
てんらく /転落/顛落;=転落/
てんらくし /転落死/
てんらくじこ /転落事故/
てんらん /展覧/天覧/
てんらんかい /展覧会/
てんらんかいじょう /展覧会場/
てんらんじあい /天覧試合/
てんり /天理/
てんりきょう /天理教/
てんりこうこう /天理高校/
てんりし /天理市/
てんりじんよく /天理人欲;宇宙の摂理と人間の欲望/
てんりせん /天理線/
てんりだい /天理大/
てんりひがし /天理東/
てんりゃく /天暦;年号(947-957)/
てんりゅう /天竜/天龍/点流/
てんりゅうがわ /天竜川/
てんりゅうがわかこう /天竜川河口/
てんりゅうきょう /天龍峡/
てんりゅうはちぶしゅう /天竜八部衆;[仏教]/
てんりょう /天領/填料/転寮/
てんりん /転輪/
てんりんおう /転輪王/轉輪王/
てんれい /典礼/篆隷;篆書と隷書/典例;先例/典麗/
てんれつ /点列/
てんれんけつ /点連結/
てんろ /転炉;LD-/
てんろうせい /天狼星/
てんろく /天六/天禄;年号(970-973)/
てんわ /天和/
で /出/弟/
でーたあっしゅく /データ圧縮/
でーたかいせき /データ解析/
でーたかんり /データ管理/
でーたがた /データ型/
でーたぐん /データ群/
でーたこうぞう /データ構造;[情報]data structure/
でーたしゅうしゅう /データ収集/
でーたしょり /データ処理/
でーたすう /データ数/
でーたつうしん /データ通信/
でーたてんそう /データ転送/
でーたにゅうりょく /データ入力/
でーたべーすか /データベース化/
でーたりょう /データ量/
でーとしょうほう /デート商法/
であい /出会い/出逢い/出合い/
であいがしら /出会い頭/出合い頭/
であいけい /出会い系/
であし /出足/
であしばらい /出足払い/
でぃーぜるしゃ /ディーゼル車/
でぃおにゅそすてき /ディオニュソス的;[美学]Dionysian/
でぃみぬえんど /dim;次第に弱く/diminuendo/
でい /泥/禰;(人名用漢字)/
でいがん /泥岩;[地質]mudstone/
でいじょう /泥状/
でいすい /泥酔/泥水/
でいたん /泥炭/
でいたんち /泥炭地/
でいちゅう /泥中/
でいど /泥土/
でいねい /泥濘/
でいばだった /提婆達多/
でいばんがん /泥板岩/
でいり /出入り/泥裏/泥裡/
でいりきんし /出入り禁止/
でいりぐち /出入口/出入り口/
でいりゅう /泥流/
でいろ /泥路/
でおきしりぼかくさん /デオキシリボ核酸/
でおくれ /出遅れ/
でおくれかん /出遅れ感/
でおんな /出女;入鉄砲-/
でか /刑事/deca;[SI接頭語]da,10^1/
でかぐらむ /瓧/
でかせぎ /出稼ぎ/
でかた /出方/出かた/
でかたしだい /出方次第/
でかめーとる /籵/
でかりっとる /竍/
でがたり /出語り/
でがら /出殻/
でがらし /出涸らし;お茶の-/
でがわ /出川/
でき /出来/溺/
できあい /溺愛/出来合い/出来合/
できあがり /出来上がり/
できうお /出来魚/
できぐあい /出来具合/
できごころ /出来心/
できごと /出来事/
できし /溺死/
できしだい /出来次第/
できじたい /出来自体/
できすぎ /出来過ぎ/出木杉;姓,漫画「ドラえもん」の登場人物/
できそこない /出来損ない/
できたて /出来立て/
できだか /出来高/
できだかばらい /出来高払い;年俸２億プラス-/
できちゃったけっこん /できちゃった結婚;[新語]妊娠が判明してから結婚すること/
できちゃったこん /できちゃった婚;[新語]/
できね /出来値/
できばえ /出来栄え/出来映え/
できふでき /出来不出来/
できぼし /出来星/
できぼつ /溺没/
できもの /出来物/
できれーす /出来レース/
できわく /溺惑/
できん /出禁;[略語]出入り禁止/
でぎわ /出際/
でく /木偶/
でくにんぎょう /木偶人形/
でくのぼう /木偶の坊/
でくれっしぇんど /decres;次第に弱く/decrescendo/
でぐあい /出具合/
でぐち /出口/
でぐちおにさぶろう /出口王仁三郎/
でぐちちょうさ /出口調査/
でぐちちょくぜん /出口直前/
でぐちふきん /出口付近/
でげいこ /出稽古/
でげねりあか /デゲネリア科/Degeneriaceae/
でこ /凸/
でこすけ /デコ助/
でこでん /デコ電/
でこぼこ /凸凹/
でこぼこみち /凸凹道/
でさかり /出盛り/
でさき /出先/
でさききかん /出先機関/
でさく /出作/
でざいんか /デザイン科/
でざいんせい /デザイン性/
でざいんてき /デザイン的/
でざき /出崎/
でざわ /出沢/
でし /弟子/deci;[SI接頭語]d,10^-1/
でしいり /弟子入り/
でしお /出汐/出潮/
でしぐらむ /瓰/
でしごと /出仕事/
でしたち /弟子達/
でしな /出しな/
でしょく /出職/
でしりっとる /竕/
でじたるか /デジタル化/
でじたるかいせん /デジタル回線/
でじたるかでん /デジタル家電/
でじたるしょめい /デジタル署名/
でじたるしょり /デジタル処理/
でじたるしんごう /デジタル信号/
でじたるどけい /デジタル時計/
でじたるほうそう /デジタル放送/
でじたるろくおん /デジタル録音;digital recording/
でじま /出島/
でじる /出汁;?/
でじろ /出城/
ですぎ /出過ぎ/
ですくとっぷがた /デスクトップ型/
ですたい /です体;[国語学]です・ますを用いる文体です/
ですみ /出隅/出角;=出隅/
でずいらず /出ず入らず/
でずっぱり /出突っ張り/
でせん /出銭/
でぞめ /出初め/
でぞめしき /出初式/出初め式/
でたて /出立て/
でたとこしょうぶ /出た所勝負/
でたに /出谷/
でたらめ /出鱈目/
でだし /出だし/出出し/
でだま /出玉/
でだまじょうきょう /出玉状況/
でだますう /出玉数/
でだまりつ /出玉率/
でっち /丁稚/
でっちぼうこう /丁稚奉公/
でっちょうそう /粘葉装/
でっちり /出っ尻/
でっぱ /出っ歯/
でっぱり /出っ張り/
でつ /捏/
でつぞう /捏造/
でづくり /出作り;小作/
でづっぱり /出突っ張り/
でづら /出面/
でどころ /出所/出処/出どころ/
でなおし /出直し/
ではい /デ杯;[tennis][略語]Davis Cup/
ではいり /出入り/
ではじめ /出始め/
ではずれ /出外れ/
ではな /出端/
でば /出刃;-包丁/出歯;=でっぱ/出場;=出場所/
でばかめ /出歯亀/
でばがめ /出歯亀;=でばかめ/
でばしょ /出場所/
でばな /出鼻;-を挫く/出端;≒出鼻/出花;番茶も-/
でばぼうちょう /出刃包丁/出刃庖丁;=出刃包丁 NB:「包」は代用字/
でばやし /出囃子;落語の/
でばん /出番/
でぱちか /デパ地下;[新語]デパートの地下(食料品)売場/
でびゅーさく /デビュー作/
でびゅーせん /デビュー戦/
でふぉるとち /デフォルト値/
でふね /出船/
でぶしょう /出不精/
でぶせん /デブ専/
でぶち /出淵/
でべそ /出臍;お前の母ちゃん-/
でほ /出穂/
でほうだい /出放題/
でぼんき /デボン紀;[地質年代]Devonian. 4085-3630万年前/
でま /手間/
でまえ /出前/
でまえもち /出前持ち/出前持/
でまかせ /出任せ/
でまち /出待ち/出町;地名/
でまちやなぎ /出町柳;地名,京都/
でまちやなぎえき /出町柳駅/
でまど /出窓/
でまる /出丸/
でみず /出水/
でみせ /出店/
でむかえ /出迎え/
でむら /出村/
でめ /出目/
でめきん /出目金/
でめとく /出目徳;人名/
でもがめん /デモ画面/
でもこうしん /デモ行進/
でもたい /デモ隊/
でもと /出本/
でもどり /出戻り/
でもの /出物/
でもばん /デモ版/
でもん /出門/
でやしき /出屋敷/
でゆ /出湯/
でよう /出様/
でら /寺/
でるた /δ;delta/Δ;Delta/
でるふぁいほう /デルファイ法;(delphi method) 専門家へのアンケートによる未来予測法/
でるまく /出る幕/
でわ /出羽/出葉;人名 姓/
でわさんざん /出羽三山;地名,月山・羽黒山・湯殿山/
でわざくら /出羽桜/
でわにしき /出羽錦/
でわのうみ /出羽海/
でわのうみべや /出羽海部屋/
でん /電/殿/伝/田/佃;つくだ/甸;緬甸/畋/沺/鈿;螺鈿/棯/澱;沈殿/淀;よど/傳;「伝」の旧字(人名用漢字)/臀;臀部/黏;「粘」の異体字/
でん> /伝;(said to be) 伝雪舟作,伝定家筆/
でんあつ /電圧/
でんあつけい /電圧計/
でんあつげん /電圧源/
でんあつこうか /電圧降下/
でんあつていか /電圧低下/
でんあつへんどう /電圧変動/
でんい /電位/
でんいけい /電位計;electrometer/
でんいさ /電位差/
でんえもん /伝衛門/
でんえん /田園/
でんえんこうきょうがく /田園交響楽;la Symphonie Pastorale(1919), Gide/
でんえんこうきょうきょく /田園交響曲/
でんえんし /田園詩/
でんえんちょうふ /田園調布/
でんえんちょうふえき /田園調布駅/
でんえんちょうふふたば /田園調布雙葉/
でんえんとし /田園都市/
でんえんとしせん /田園都市線/
でんえんふうけい /田園風景/
でんおん /伝音/
でんおんけい /伝音系/
でんか /電化/殿下/電荷;(e) electrical charge/田家/伝家;-の宝刀/
でんかい /電解;†electrolysis.「-液」/電界;†electric field/
でんかいかいせき /電界解析/
でんかいきょうど /電界強度/
でんかいしつ /電解質/
でんかいそう /電解槽;electrolyser/
でんかいない /電界内/
でんかかいぎょう /電化開業/
でんかかんせい /電化完成/
でんかくかん /電化区間/
でんかけいかく /電化計画/
でんかご /電化後/
でんかせいひん /電化製品/
でんかのほうとう /伝家の宝刀/
でんかぶんぷ /電荷分布/
でんかほうしき /電化方式/
でんかまえ /電化前/
でんかみつど /電荷密度/
でんかりょう /電荷量/
でんかん /電管/田漢;田舎者/電環/
でんがく /田楽/電楽/
でんがくどうふ /田楽豆腐/
でんがくほうし /田楽法師/
でんき /電気;†electricity/電機;†電気機械/電器;†電気器具/伝記;biography/伝奇;romance/傳綺/
でんき> /電気;-自動車,-工事,-ショック/
でんきいす /電気椅子;electric chair/
でんきうお /電気魚/
でんきうなぎ /電気鰻/
でんきえいが /伝記映画/
でんきえいどう /電気泳動/
でんきおんきょう /電気音響/
でんきおんすいき /電気温水器/
でんきか /電気科/電気化/
でんきかいり /電気解離/
でんきかいろ /電気回路/
でんきかがく /電気化学/
でんきかぶしきがいしゃ /電気株式会社/
でんきかんけい /電気関係/
でんきかんりし /電気管理士/
でんきがい /電気街/電器街;?/
でんきがっか /電気学科/
でんきがっかい /電気学会/
でんきがっき /電気楽器/
でんきがま /電気釜/
でんきき /電機器/
でんききかい /電気機械/
でんききかんしゃ /電気機関車/
でんききき /電気機器/
でんきききこうがく /電気機器工学/
でんききぐ /電気器具/
でんきくどう /電気駆動/
でんきけい /電気系/
でんきけいがっか /電気系学科/
でんきけいじ /電気計時/
でんきけいとう /電気系統/
でんきけんそくしゃ /電気検測車/
でんきこうがく /電気工学/
でんきこうがくか /電気工学科/
でんきこうがくけい /電気工学系/
でんきこうがくしゃ /電気工学者/
でんきこうがくじっけん /電気工学実験/
でんきこうがくせんこう /電気工学専攻/
でんきこうがくだいに /電気工学第二/
でんきこうがっか /電気工学科/
でんきこうぎょう /電気工業/
でんきこうさくぶつ /電気工作物/
でんきこうじ /電気工事/
でんきこうじし /電気工事士/
でんきさんぎょう /電器産業/
でんきしき /電気式/
でんきしげき /電気刺激/
でんきしゃ /電気車/
でんきしゅうじんき /電気集塵器/
でんきしゅにんぎじゅつしゃ /電気主任技術者/
でんきしょうせつ /伝奇小説/
でんきしようりょう /電気使用量/
でんきしんごう /電気信号/
でんきじかけ /電気仕掛/
でんきじきがく /電気磁気学/
でんきじぎょう /電気事業/
でんきじぎょうほう /電気事業法/
でんきじどうしゃ /電気自動車/
でんきじょうほう /電気情報/
でんきじょうほうけい /電気情報系/
でんきじょうほうこうがく /電気情報工学/
でんきじょうほうこうがっか /電気情報工学科/
でんきすいはんき /電気炊飯器/
でんきすたんど /電気スタンド/
でんきすとーぶ /電気ストーブ/
でんきせい /電機製/電器製/
でんきせいぎょ /電気制御/
でんきせいひん /電気製品/電器製品/
でんきせいりがく /電気生理学;electrophysiology/
でんきせき /電気石;tourmaline/
でんきせつび /電気設備/
でんきせんたくき /電気洗濯機/
でんきそうきょくし /電気双極子;[化学]electric duplex/
でんきそうじき /電気掃除機/
でんきそうち /電気装置/
でんきそりょう /電気素量;1.60217653*10^-19C/
でんきたんさ /電気探査/
でんきだい /電気代/電機大/
でんきだいがく /電機大学/
でんきだいなど /電気代等/
でんきちゅうぞう /電気鋳造/
でんきつうしん /電気通信/
でんきつうしんがくぶ /電気通信学部/
でんきつうしんけんきゅうしょ /電気通信研究所/
でんきつうしんけんきゅうじょ /電気通信研究所/
でんきつうしんじぎょう /電気通信事業/
でんきつうしんじぎょうしゃ /電気通信事業者/
でんきつうしんじぎょうほう /電気通信事業法/
でんきつうしんだい /電気通信大/
でんきつうしんだいがく /電気通信大学/
でんきていこう /電気抵抗/
でんきてき /電気的/伝記的;†biographic/伝奇的;†romantic/
でんきてきかつどう /電気的活動/
でんきてきとくせい /電気的特性/
でんきてつどう /電気鉄道/
でんきてん /電器店/
でんきでんし /電気電子/
でんきでんしぶんや /電気電子分野/
でんきでんどうど /電気伝導度/
でんきとう /電気棟/
でんきどうりょく /電気動力/
でんきどりる /電気ドリル/
でんきなべ /電気鍋/
でんきばん /電気版/
でんきひつじ /電気羊/
でんきぶ /電気部/
でんきぶらん /電気ブラン/
でんきぶろ /電気風呂/
でんきぶんかい /電気分解/
でんきほうしき /電気方式/
でんきぽっと /電気ポット/
でんきもうふ /電気毛布/
でんきもの /伝奇物/電気物/
でんきや /電気屋/電器屋/電機屋/
でんきゅう /電球/
でんきょうしゃ /電響社/
でんきょく /電極/
でんきょくでんい /電極電位;[化学]electrode potential/
でんきょくはんのう /電極反応/
でんきょくひん /電極品/
でんきようせつ /電気溶接;electric welding/
でんきようりょう /電気容量/
でんきりきがく /電気力学/
でんきりきせん /電気力線;[物理]/
でんきりょう /電気量/
でんきりょうきん /電気料金/
でんきりょうほう /電気療法/
でんきりょく /電気力/
でんきりろん /電気理論/
でんきれいぞうこ /電気冷蔵庫/
でんきれんけつき /電気連結器/
でんきろ /電気炉/
でんきろうれん /電気労連/
でんきろくおん /電気録音/
でんぎ /電技/
でんぎょう /電業/伝教/
でんぎょうだいし /伝教大師/
でんぐねつ /デング熱;[医]dengue/
でんぐりがえし /でんぐり返し/
でんけい /電計/
でんけん /電顕/電鍵/電検/
でんけんさんしゅ /電験三種/
でんげき /電撃/
でんげきおう /電撃王/
でんげきけっこん /電撃結婚/
でんげきてき /電撃的/
でんげん /電源/
でんげんいがい /電源以外/
でんげんいり /電源入/
でんげんかいはつ /電源開発/
でんげんかいろ /電源回路/
でんげんかんけい /電源関係/
でんげんがわ /電源側/
でんげんきょうきゅう /電源供給/
でんげんこーど /電源コード/
でんげんこうじ /電源工事/
でんげんしゃ /電源車/
でんげんしゅうはすう /電源周波数/
でんげんしゅつりょく /電源出力/
でんげんせつび /電源設備/
でんげんせん /電源線/
でんげんたんし /電源端子/
でんげんつき /電源付/
でんげんでんあつ /電源電圧/
でんげんとうにゅう /電源投入/
でんげんとうにゅうご /電源投入後/
でんげんとうにゅうじ /電源投入時/
でんげんとうにゅうちょくご /電源投入直後/
でんげんないぞう /電源内蔵/
でんげんばん /電源板/
でんげんふよう /電源不要/
でんげんぶ /電源部/
でんげんよう /電源用/
でんげんようりょう /電源容量/
でんこう /電工;†電気工事/電光;†「-掲示板」/電興/
でんこうかぶしきがいしゃ /電工株式会社/
でんこうけいじ /電光掲示/
でんこうけいじばん /電光掲示板/
でんこうしき /電光式/
でんこうせっか /電光石火/
でんこうばん /電光板/
でんこうひょうじ /電光表示/
でんこうひょうじばん /電光表示板/
でんごん /伝言/
でんごんばん /伝言板/
でんさん /電算/電産;電器産業/
でんさんか /電算化/電算課/
でんさんき /電算機/
でんさんきしつ /電算機室/
でんさんしつ /電算室/
でんさんしゃしょく /電算写植/
でんさんしょり /電算処理/
でんさんぶ /電算部/
でんざい /電材/
でんし /電子/殿試;科挙の三次試験/
でんし> /電子;-ピアノ,-部品,-決済/
でんしおるがん /電子オルガン/
でんしおん /電子音/
でんしおんがく /電子音楽/
でんしおんきょう /電子音響/
でんしか /電子化/電子科/
でんしかいぎ /電子会議/
でんしかいぎしつ /電子会議室/
でんしかいろ /電子回路/
でんしかいろがく /電子回路学/
でんしかく /電子殻/
でんしかるて /電子カルテ/
でんしかんけい /電子関係/
でんしがく /電子学/
でんしがっき /電子楽器/
でんしきかい /電子機械/
でんしきき /電子機器/
でんしききじぎょうぶ /電子機器事業部/
でんしききぶ /電子機器部/
でんしききるい /電子機器類/
でんしきどう /電子軌道/
でんしきょう /電子協/電子工業振興協会;※abbrev/
でんしぎじゅつ /電子技術/
でんしぎじゅつしゃ /電子技術者/
でんしぎじゅつそうごうけんきゅうしょ /電子技術総合研究所/
でんしぎじゅつぶんや /電子技術分野/
でんしけい /電子系/
でんしけいさん /電子計算/
でんしけいさんき /電子計算機/
でんしけいさんきしつ /電子計算機室/
でんしけいじばん /電子掲示板/
でんしけっさい /電子決済/
でんしけん /電子研/
でんしけんきゅうしょ /電子研究所/
でんしけんびきょう /電子顕微鏡/
でんしこう /電子工/
でんしこうがく /電子工学/
でんしこうがくか /電子工学科/
でんしこうがくせんこう /電子工学専攻/
でんしこうがっか /電子工学科/
でんしこうぎょう /電子工業/
でんしこうさく /電子工作/
でんしこうさくよう /電子工作用/
でんしざいりょう /電子材料/
でんししき /電子式/
でんししゅっぱん /電子出版/
でんししょうとりひき /電子商取引/
でんししょうめいしょ /電子証明書/
でんししょせき /電子書籍/
でんししょめい /電子署名/
でんしじしょ /電子辞書/
でんしじてん /電子辞典/
でんしじゅう /電子銃/
でんしじょうたい /電子状態/
でんしじょうほう /電子情報/
でんしじょうほうがっか /電子情報学科/
でんしじょうほうけい /電子情報系/
でんしじょうほうこうがく /電子情報工学/
でんしじょうほうこうがくせんこう /電子情報工学専攻/
でんしじょうほうつう /電子情報通/
でんしじょうほうつうしんがっかい /電子情報通信学会;www.ieice.org/
でんしすぴんきょうめい /電子スピン共鳴;ESR/
でんしずのう /電子頭脳/
でんしせいき /電子精機/
でんしせいぎょ /電子制御/
でんしせいぎょか /電子制御化/
でんしせいぎょきかい /電子制御機械/
でんしせいふ /電子政府/
でんしせってん /電子接点/
でんしせん /電子線;†electron beam/電子戦;†e-war/
でんしせんい /電子遷移/
でんしそし /電子素子/
でんしだい /電視台/
でんしちゃっか /電子着火/
でんしつい /電子対/
でんしつうしん /電子通信/
でんしつうしんがく /電子通信学/
でんしつうしんがっか /電子通信学科/
でんしつうしんがっかい /電子通信学会/
でんしてがた /電子手形/
でんしてき /電子的/
でんしてきすと /電子テキスト/
でんしてちょう /電子手帳/
でんしとうひょう /電子投票/
でんしとうろん /電子討論/
でんしとしょかん /電子図書館/
でんしとりひき /電子取引/
でんしどけい /電子時計/
でんしは /電子波/
でんしはいち /電子配置/
でんしばいたい /電子媒体/
でんしばいたいじょう /電子媒体上/
でんしばん /電子版/
でんしびーむ /電子ビーム;electron beam/
でんしぴあの /電子ピアノ/
でんしぶっく /電子ブック/
でんしぶっせい /電子物性/
でんしぶつり /電子物理/
でんしぶひん /電子部品/
でんしぶんぐ /電子文具/
でんしぶんぷ /電子分布/
でんしまねー /電子マネー/
でんしめーる /電子メール/
でんしめいる /電子メイル/
でんしもじ /電子文字/
でんしゃ /電車/殿舎/田舎/伝写/伝者/
でんしゃいがい /電車以外/
でんしゃうんちん /電車運賃/
でんしゃえき /電車駅/
でんしゃか /電車化/
でんしゃかん /田舎漢;イナカモノ/
でんしゃきゅうこう /電車急行/
でんしゃく /電車区/
でんしゃせん /電車線/
でんしゃせんよう /電車専用/
でんしゃだい /電車代/
でんしゃちん /電車賃/
でんしゃつうがく /電車通学/
でんしゃつうきん /電車通勤/
でんしゃつうきんしゃ /電車通勤者/
でんしゃとくていくかん /電車特定区間/
でんしゃとっきゅう /電車特急/
でんしゃない /電車内/
でんしゃへんせい /電車編成/
でんしゃみち /電車道/
でんしゃよう /電車用/
でんしゃりよう /電車利用/
でんしゅう /伝習/
でんしゆうびん /電子郵便/
でんしゆそう /電子輸送/
でんしょ /伝書/
でんしょう /伝承/電照/伝誦;口誦して伝承する/伝唱;≒伝誦/
でんしょうきょく /伝承曲/
でんしょうぎく /電照菊/
でんしょうさいばい /電照栽培/
でんしょうしゃ /伝承者/
でんしょうぶんがく /伝承文学/
でんしょく /電飾/
でんしょくこう /電色光/
でんしょばと /伝書鳩/
でんしりょうし /電子量子/
でんしれいき /電子励起/
でんしれいきじょうたい /電子励起状態/
でんしれいきゃく /電子冷却/
でんしれんじ /電子レンジ/
でんしん /電信/伝信/田紳/
でんしんあつかい /電信扱い/
でんしんき /電信機/
でんしんきゅう /電信級/
でんしんそうきん /電信送金/
でんしんでんわ /電信電話/
でんしんでんわがいしゃ /電信電話会社/
でんしんはちごう /電信八号;denshin8.esprix.net/
でんしんばしら /電信柱/
でんじ /電磁/
でんじかい /電磁界/
でんじかんきょう /電磁環境/
でんじかんのう /電磁感応/
でんじき /電磁気/
でんじきがく /電磁気学/
でんじげんしょう /電磁現象/
でんじしき /電磁式/
でんじしゃく /電磁石/
でんじしょうがい /電磁障害/
でんじそうごさよう /電磁相互作用/
でんじちょうり /電磁調理/
でんじちょうりき /電磁調理器/電磁調理機;<rare>/
でんじてき /電磁的/
でんじてききろく /電磁的記録/
でんじは /電磁波/
でんじはこうがく /電磁波工学/
でんじば /電磁場/
でんじほうていしき /電磁方程式/
でんじゅ /伝授/
でんじゆうどう /電磁誘導/
でんじょう /電情/
でんじょうつう /電情通/
でんじりきがく /電磁力学/
でんじりゅうたい /電磁流体/
でんじりょく /電磁力/
でんじん /電人/
でんすけ /伝助/電助/
でんせい /電請/
でんせいかん /伝声管/
でんせつ /伝説/電設/
でんせつしゅう /伝説集/
でんせつじょう /伝説上/
でんせつてき /伝説的/
でんせつぶつ /伝説物/
でんせん /電線/伝染;†「-病」/伝線;†ストッキングの破れ/伝宣/電閃/電専/
でんせんおんど /電線音頭/
でんせんせい /伝染性/
でんせんせいこうはん /伝染性紅斑/
でんせんちちゅうか /電線地中化/
でんせんひき /電線引/
でんせんびょう /伝染病/
でんせんびょういん /伝染病院/
でんせんびょうよぼうほう /伝染病予防法/
でんそう /伝送/電装/電送/
でんそうかんけい /電装関係/
でんそうけい /電装系/伝送系/
でんそうけいろ /伝送経路/
でんそうけん /電総研/伝送研/電子技術総合研究所;※abbrev/
でんそうしき /電送式/
でんそうしゅだん /伝送手段/
でんそうせいぎょ /伝送制御/
でんそうせん /伝送線/
でんそうそくど /伝送速度/
でんそうたいいき /伝送帯域/
でんそうだい /電総大/
でんそうちゅう /伝送中/
でんそうとくせい /伝送特性/
でんそうないよう /伝送内容/
でんそうばいたい /伝送媒体/
でんそうひん /電装品/
でんそうぶ /電送部/
でんそうりょう /伝送量/
でんそうろ /伝送路/
でんそく /電束/
でんそくみつど /電束密度;[物理]electric flux density/
でんそん /伝存/
でんたいばん /電胎版/
でんたく /電卓/
でんたくかたて /電卓片手/
でんたくがた /電卓型/
でんたくきのう /電卓機能/
でんたつ /伝達/
でんたつかんすう /伝達関数/
でんたつけい /伝達系/
でんたつけいしき /伝達形式/
でんたつけいろ /伝達経路/
でんたつけん /伝達権/
でんたつこうりつ /伝達効率/
でんたつしゃ /伝達者/
でんたつしゅだん /伝達手段/
でんたつそしき /伝達組織/
でんたつとくせい /伝達特性/
でんたつぶっしつ /伝達物質/
でんたつほうしき /伝達方式/
でんたつりつ /伝達率/
でんたつろ /伝達路/
でんたん /電探/
でんだ /伝田/
でんだい /田代/電大/
でんち /電池/
でんちぎれ /電池切れ/
でんちく /電蓄/
でんちくどう /電池駆動/
でんちこうかん /電池交換/
でんちしき /電池式/
でんちせいぞう /電池製造/
でんちだい /電池代/
でんちないぞう /電池内蔵/
でんちぱっく /電池パック/
でんちふよう /電池不要/
でんちぶぶん /電池部分/
でんちゅう /電柱/殿中/
でんちゅうけん /電中研/
でんちゅうばおり /殿中羽織/
でんちゅうばん /電鋳版/
でんちようりょう /電池容量/
でんつう /電通;[企業名]/
でんつうけん /電通研/
でんつうこくさいじょうほう /電通国際情報/
でんつうだい /電通大/電気通信大学;※abbrev/
でんてい /電停/
でんてつ /電鉄/
でんてついずもし /電鉄出雲市/
でんてつがいしゃ /電鉄会社/
でんでん /電電/電々/
でんでんこうしゃ /電電公社/
でんでんだいこ /でんでん太鼓/
でんでんむし /蝸牛/
でんとう /伝統/電灯/電燈;「灯」旧字/
でんとうげいのう /伝統芸能/
でんとうこう /伝統校/
でんとうこうげい /伝統工芸/
でんとうしゅうかん /伝統習慣/
でんとうしゅぎ /伝統主義/
でんとうせん /電灯線/
でんとうてき /伝統的/
でんとうてきしゅうかん /伝統的習慣/
でんとうてきろんりがく /伝統的論理学/
でんとうび /伝統美/
でんとうりょうり /伝統料理/
でんどう /電動;†electric.「-ハブラシ」/殿堂/伝導;†conduction.「イオン-」 NB:熱・電荷・信号/伝道;†[宗教]mission.「-師」/伝動;†power transmission.「-ベルト」 NB:動力/電導;†electrical conduction.「光-」 NB:電荷/
でんどう> /電動/
でんどうあわたてき /電動泡立て器/
でんどういり /殿堂入り/
でんどうき /電動機/
でんどうけい /伝導系/
でんどうし /伝道師/
でんどうしき /電動式/
でんどうしゃ /電動車/
でんどうじてんしゃ /電動自転車;電動アシスト自転車/
でんどうせい /伝導性/電導性/
でんどうたい /伝導体/
でんどうのしょ /伝道の書;[聖書]Ecclesiastes(Ecc,Eccle)/
でんどうば /殿堂馬/
でんどうりつ /伝導率/
でんねつ /電熱/伝熱/
でんねつき /電熱器/
でんねつせん /電熱線/
でんのう /電脳/
でんのうか /電脳化/
でんのうがい /電脳街/
でんのうがろう /電脳画廊/
でんのうくうかん /電脳空間/
でんのうくらぶ /電脳倶楽部/
でんのうしゃかい /電脳社会/
でんのうせんし /電脳戦士/
でんのうづくえ /電脳机/
でんのうとし /電脳都市/
でんのうぶ /電脳部/
でんのうゆうえんち /電脳遊園地/
でんば /電場/
でんばた /田畑/
でんばほうれいしゅう /電波法令集/
でんぱ /電波/伝播/
でんぱかんりきょく /電波管理局/
でんぱきゅうしゅうざい /電波吸収材/
でんぱきゅうしゅうたい /電波吸収体/
でんぱぎょうせい /電波行政/
でんぱけい /電波系/
でんぱけいしき /電波形式/
でんぱけん /電波研/
でんぱこうせん /電波高専/
でんぱし /電波子/
でんぱしょうがい /電波障害/
でんぱしょうねん /電波少年/
でんぱしようりょう /電波使用料/
でんぱしんぶん /電波新聞/
でんぱしんぶんしゃ /電波新聞社;[企業名]/
でんぱじょうきょう /電波状況/
でんぱぜい /電波税/
でんぱた /田畑/
でんぱち /伝八/
でんぱつ /電髪/
でんぱつうしんがっか /電波通信学科/
でんぱてんたい /電波天体/
でんぱてんもんがく /電波天文学/
でんぱでんそう /電波伝送/電波電送/
でんぱでんぱん /電波伝搬/
でんぱとう /電波塔/
でんぱどけい /電波時計/
でんぱばいたい /電波媒体/
でんぱほう /電波法/
でんぱほうき /電波法規/
でんぱほうれいしょうろく /電波法令抄録/
でんぱぼうえんきょう /電波望遠鏡/
でんぱぼうがい /電波妨害/
でんぱむきょうしつ /電波無響室/
でんぱりよう /電波利用/
でんぱりようりょう /電波利用料/
でんぱん /伝搬/殿版/伝播;※「でんぱ」の誤り/
でんぱんきこう /伝播機構/
でんぱんけい /伝搬系/
でんぱんけいろ /伝搬経路/
でんぱんこう /伝搬項/
でんぱんじかん /伝搬時間/
でんぱんそくど /伝搬速度/
でんぱんは /伝搬波/
でんぱんろ /伝搬路/
でんぴょう /伝票/
でんぴょうしょり /伝票処理/
でんぶ /臀部/田麩/
でんぶん /伝聞/電文/伝文/
でんぶんけいしき /伝聞形式/
でんぶんしゃ /伝聞者/
でんぶんしょうこ /伝聞証拠/
でんぶんじょうほう /伝聞情報/
でんぶんちょう /伝聞調/
でんぶんてき /伝聞的/
でんぷ /田夫/
でんぷやじん /田夫野人/
でんぷん /澱粉/でん粉/
でんぷんしつ /澱粉質/
でんぼう /伝法/
でんぽ /田圃/
でんぽう /電報/伝法/
でんぽうきょく /電報局/
でんぽうぶん /電報文/
でんぽん /伝本/
でんまーく /丁抹;Denmark/
でんまーくご /デンマーク語;デンマークの公用語/
でんまちょう /伝馬町/
でんめい /電命/
でんや /田野/
でんらい /伝来/
でんらいご /伝来語/
でんらん /電纜/
でんり /電離/
でんりく /電リク;[略語]電話リクエスト/
でんりけん /電離圏/
でんりしょうとつ /電離衝突/
でんりせい /電離性/
でんりそう /電離層/
でんりそんしつ /電離損失/
でんりど /電離度/
でんりばこ /電離箱/
でんりゃく /電略/
でんりゅう /電流/
でんりゅういってい /電流一定/
でんりゅうけい /電流計/
でんりゅうげん /電流源/
でんりゅうせん /電留線/
でんりゅうち /電流値/
でんりゅうつうか /電流通過/
でんりゅうばくは /電流爆破/
でんりゅうへんか /電流変化/
でんりゅうみつど /電流密度/
でんりゅうようりょう /電流容量/
でんりゅうりょう /電流量/
でんりょく /電力/
でんりょくかんけい /電力関係/
でんりょくがいしゃ /電力会社/
でんりょくきょうきゅう /電力供給/
でんりょくきょうきゅうりょく /電力供給力/
でんりょくぎょうかい /電力業界/
でんりょくけい /電力計/
でんりょくけいとう /電力系統/
でんりょくけいとうこうがく /電力系統工学/
でんりょくしせつ /電力施設/
でんりょくしょうひ /電力消費/
でんりょくしょうひりょう /電力消費量/
でんりょくじゅよう /電力需要/
でんりょくせん /電力線/
でんりょくでんし /電力電子/
でんりょくはいせん /電力配線/
でんりょくぶそく /電力不足/
でんりょくへんかんき /電力変換器/
でんりょくもう /電力網/
でんりょくりょう /電力量/
でんりょくりょうけい /電力量計/
でんれい /伝令/電鈴/
でんれいし /伝令使/
でんろ /電路/
でんわ /電話/
でんわあんない /電話案内/
でんわいっぽん /電話一本/
でんわかいせん /電話回線/
でんわかいだん /電話会談/
でんわかにゅうけん /電話加入権/
でんわかんゆう /電話勧誘/
でんわかんれん /電話関連/
でんわがいしゃ /電話会社/
でんわき /電話機/電話器;?/
でんわきのう /電話機能/
でんわきほんたい /電話機本体/
でんわきゅう /電話級/
でんわきょく /電話局/
でんわぎょう /電話業/
でんわぐち /電話口/
でんわけんり /電話権利/
でんわこうかん /電話交換/
でんわこうかんきょく /電話交換局/
でんわこうかんしゅ /電話交換手;telephone operator/
でんわしつ /電話室/
でんわじじょう /電話事情/
でんわせん /電話線/
でんわそうだん /電話相談/
でんわたんまつ /電話端末/
でんわだい /電話代/電話台/
でんわだいせつやく /電話代節約/
でんわちゅう /電話中/
でんわちょう /電話帳/
でんわちょうさ /電話調査/
でんわとうひょう /電話投票/
でんわばん /電話番/
でんわばんごう /電話番号/
でんわばんごうあんない /電話番号案内/
でんわばんごうかくにん /電話番号確認/
でんわばんごうひょう /電話番号表/
でんわぼっくす /電話ボックス/
でんわもう /電話網/
でんわや /電話屋/
でんわよう /電話用/
でんわよやく /電話予約/
でんわよやくうけつけ /電話予約受付/
でんわよやくかいし /電話予約開始/
でんわりょう /電話料/
でんわりょうきん /電話料金/
でんわりようしゃ /電話利用者/
でんわれんらく /電話連絡/
でんわれんらくもう /電話連絡網/
と /戸/都/徒/途/斗;10升/堵;安堵/屠;屠殺/賭;賭博/睹/覩;「睹」の異体字/渡;渡来/鍍;鍍金/度;屹度/兎;うさぎ/兔;「兎」の異体字/菟/莵;「菟」の異体字/吐;嘔吐/杜;杜甫/土;土地/汢;ぬた/肚;はら/塗;塗装/荼/蠹/蠧;「蠹」の異体字/妬;嫉妬/砥;砥石/礪;礪波/砺;「礪」の異体字/蚪;蝌蚪(かと,おたまじゃくし)/跿/登;登山/十;十色/人;隼人/外;外様/頭/図;図書/圖;「図」の旧字/富/冨;「富」の旧字(人名用漢字)/闘;?/砿;?/
と> /都;都議会,都条例/渡/
とーなめんとせん /トーナメント戦/
とーみょう /豆苗/
とーれ /東レ;[企業名]/
とあさ /遠浅/
とあみ /投網/
とい /樋/問/問い/土肥/戸井/
といあわせ /問い合わせ/問い合せ/問合せ/問合わせ/問合/
といあわせさき /問い合わせ先/
というつせんきょ /統一選挙/
といかけ /問い掛け/問掛け/
といき /吐息/
といし /砥石/礪/
といた /戸板/
といたじょし /戸板女子/
といたとうげ /戸板峠/
といだけ /樋竹/
といち /十一;高利貸/
といつ /対子/
といとい /対々/
といといほー /対対和/
といみさき /都井岬/
といめん /対面/
といや /問屋/
といやまち /問屋町/
といれきゅうけい /トイレ休憩/
といれそうじ /トイレ掃除/
といれよう /トイレ用/
といろ /十色;十人-/
とう /党/塔/糖/等/唐/答/当/東/棟/島/籐;-椅子/陶;陶器/刀/灯/燈;「灯」の旧字(人名用漢字)/頭/豆;豆腐/逗;逗留/痘;天然痘/登;登校/鐙;あぶみ/嶝;(さか)/橙;だいだい/磴;(いしざか)/濤;波濤/涛;「濤」の異体字/擣;(うつ)/檮/梼;「檮」の異体字/祷;祈祷/陦/盗;盗賊/盜;「盗」の旧字(人名用漢字)/湯;銭湯/蕩;放蕩/蘯;「蕩」の異体字/盪;脳震盪/档/當;「当」の旧字/礑;(はたと)/蟷;蟷螂の斧/螳;螳螂(=蟷螂)/沓;くつ/踏;踏破/滔;滔々と/蹈;≒踏/鞜;青鞜/韜;韜晦/桃;桃源郷/逃;逃避/迯;「逃」の異体字/嶋;「島」の旧字(人名用漢字)/嶌;「島」の異体字2/搗;つ・く/闘;戦闘/鬥;(とうがまえ)/鬪;「闘」の旧字/冬;冬季/疼;疼痛/橈;橈骨/撓;(しな・る)撓曲/筒;円筒/桐;きり/悼;追悼/掉;(慣用音)掉尾/棹;さお/罩/搭;搭載/荅/鞳/剳;(さす)/幢;はた/橦/潼/撞;つ・く/藤;ふじ/謄;謄写/騰;高騰/滕/籘;「籐」の異体字/縢/到;到着/倒;転倒/淘;淘汰/萄;葡萄/掏;す・る/綯;な・う/桶;湯桶/樋;とい/投;投手/骰;骰子(さいころ)/酘;(そえ)/叨;(むさぼる)/釖;≒刀/凍;凍死/套;常套/統;統一/董;骨董/討;討伐/透;透明/吋;inch/兜;かぶと/櫂;かい/宕/偸;ぬすむ/稲;水稲/稻;「稲」の旧字(人名用漢字)/儻/黨;「党」の旧字/榻;(長椅子)/搨;(する)/塘;(つつみ)/溏;(どろ)/亠;(なべぶた)/夲/帑;かねぐら/抖/朸;おうご/棠;やまなし/淌;(大波)/竇;あな/纛;(旗の一種)/鬧;(さわぐ)/閙;「鬧」の異体字/饕;(むさぼる)/鼕;(太鼓の音)/読;読点/讀;「読」の旧字/道;神道/納;(慣用音)出納/任;(人名用)/通;(漢音の一つ)とお・る/訪;と・う?/訊;と・う?/父;父さん?/十;とお?/諮;し?/篤;?/
とう> /当/東;東亜,東漢,東三省/等;等長,等高線,等雨量(線)/
とうあ /東亜/東亞/
とうあがくえん /東亜学園/
とうあけんせつ /東亜建設;[企業名]/
とうあつ /等圧/
とうあつせん /等圧線/
とうあつへんか /等圧変化;[熱力学]isobaric change/
とうあつめん /等圧面/
とうあぺいんと /東亜ペイント/
とうあぼうしょく /東亜紡織/
とうあれんめい /東亜連盟/
とうあん /答案/偸安/
とうあんようし /答案用紙/
とうい /糖衣/当意;-即妙/当為;[哲学]Sollen/等位;coordinate.「-接続詞」/東夷/登位/陶猗;お金持ち/
とういいんかい /当委員会/
とういく /陶育/
とういじょう /糖衣錠/
とういす /籐椅子/
とういそくみょう /当意即妙/
とういち /東一/
とういつ /統一/
とういつおうじゃ /統一王者/
とういつか /統一化/
とういつかん /統一感/
とういつきかく /統一規格/
とういつきょうかい /統一教会/統一協会/
とういつけんかい /統一見解/
とういつげんご /統一言語/
とういつこうどう /統一行動/
とういつこうほ /統一候補/
とういつこっか /統一国家/
とういつしき /統一指揮/
とういつせい /統一性/
とういつせん /統一戦/
とういつせんきょ /統一選挙/
とういつせんせん /統一戦線/
とういつたい /統一体/
とういつてき /統一的/
とういつば /統一場/
とういつばりろん /統一場理論/
とういつひょうき /統一表記/
とういつほうしき /統一方式/
とういつほせん /統一補選/
とういつりろん /統一理論/
とういてき /等位的/
とういも /唐芋;サツマイモ/
とういん /党員/当院/桐蔭/東員/登院/頭韻/
とういんがくえん /桐蔭学園/
とううつ /陶鬱/
とううん /東雲/
とうえい /投影/東映;[企業名]www.toei.co.jp/東栄;地名,愛知/灯影/東永/倒影/冬営/
とうえいえいが /東映映画/
とうえいき /投影機/
とうえいぎじゅつ /投影技術/
とうえいず /投影図/
とうえいぞう /投影像/
とうえいどうが /東映動画/
とうえいないよう /投影内容/
とうえいばん /東映版/
とうえいほう /投影法/
とうえいほうこう /投影方向/
とうえいめん /投影面/
とうえん /桃園/登園/遠縁;とおえん/
とうえんめい /陶淵明/
とうおう /東欧/湯王;殷の始祖/藤黄;[植物]cambogia/陶泓/
とうおうしょこく /東欧諸国/
とうおく /塔屋;=とうや/
とうおん /等温/唐音/
とうおんせん /等温線/
とうおんたいき /等温大気/
とうおんへんか /等温変化;[熱力学]isothermal change/
とうか /透過/投下/等価/灯火;†「-親しむべし」/桃花/当課/糖化;saccharify/燈火;「灯」旧字/頭花;[植物]/等化;equalise/灯下;†/燈下;「灯」旧字/豆果;legume/陶家/陶化;≒感化/灯花;-の報/登科;科挙に合格すること/刀下;-の鳥/橙果/十日;とおか/１０日/10日/
とうかい /東海/当会/倒壊/韜晦/倒潰/
とうかいいん /当会員/
とうかいおき /東海沖/
とうかいかーぼん /東海カーボン;[企業名]/
とうかいかんこう /東海観光/
とうかいがくせい /東海学生/
とうかいきせん /東海汽船/
とうかいぎんこう /東海銀行/
とうかいこうえい /東海公営/
とうかいこうぎょう /東海興業/東海鋼業;[企業名]/
とうかいし /東海市/
とうかいしぜんほどう /東海自然歩道/
とうかいしぶ /東海支部/
とうかいじしん /東海地震/
とうかいじどうしゃどう /東海自動車道/
とうかいじょしだいがく /東海女子大学/
とうかいだい /東海大/
とうかいだいかいはつこう /東海大開発工/
とうかいだいがく /東海大学/
とうかいだいがくまえ /東海大学前/
とうかいだいこうふ /東海大甲府/
とうかいだいさがみ /東海大相模/
とうかいだいひょう /東海代表/
とうかいだいよん /東海大四/
とうかいちいき /東海地域/
とうかいちく /東海地区/
とうかいちば /十日市場;※仮名遣い「とおかいちば」/
とうかいちほう /東海地方/
とうかいどう /東海道/
とうかいどういち /東海道一/
とうかいどうかもつせん /東海道貨物線/
とうかいどうくかん /東海道区間/
とうかいどうごじゅうさんつぎ /東海道五十三次/
とうかいどうしんかんせん /東海道新幹線/
とうかいどうせん /東海道線/
とうかいどうせんえんせん /東海道線沿線/
とうかいどうせんとつか /東海道線戸塚/
とうかいどうせんのぼり /東海道線上り/
とうかいどうちゅうひざくりげ /東海道中膝栗毛;十返舎一九/
とうかいどうほんせん /東海道本線/
とうかいぱるぷ /東海パルプ/
とうかいほうめん /東海方面/
とうかいむら /東海村/
とうかいりん /東海林/
とうかおん /透過音/
とうかかいろ /等価回路/
とうかかく /等価格/当価格/
とうかかん /十日間/
とうかかんけい /等価関係/
とうかがた /透過型/
とうかき /等化器/
とうかく /当確/頭角/倒閣/等角/等覚/
とうかくしゃぞう /等角写像/
とうかくりつ /等確率/
とうかげん /桃花源/
とうかげんり /等価原理/
とうかこう /透過光/
とうかこうかん /等価交換/
とうかしほんかいしゅう /投下資本回収/
とうかしょく /透過色/
とうかせい /透過性/等価性/
とうかせる /等価セル/
とうかそうおん /等価騒音/
とうかそうおんれべる /等価騒音レベル/
とうかそくどうんどう /等加速度運動/
とうかそんしつ /透過損失/
とうかつ /統括;integrate/統轄;reign/
とうかつしてん /統括支店/
とうかつじぎょうぶ /統括事業部/統轄事業部/
とうかつじごく /等活地獄/
とうかつはん /統括班/
とうかつぶ /統括部/統轄部/
とうかつぶちょう /統括部長/
とうかつほんぶ /統括本部/
とうかてき /透過的/等価的/
とうかてん /等価点/
とうかへんかん /等価変換/
とうかまち /十日町/
とうかむり /唐冠/
とうかむりがい /唐冠貝/
とうかめん /透過面/
とうかりつ /透過率/
とうかりょく /透過力/
とうかん /投函/当館/東関/統監/等閑;なおざり/東漢;=後漢/盗汗;ねあせ/陶棺/唐冠/冬官/凍寒/灯竿/
とうかんかく /等間隔/
とうかんし /等閑視/
とうかんふ /統監府/
とうかんぶ /党幹部/
とうかんむり /唐冠/
とうが /冬瓜/冬芽/陶画/唐画/灯蛾/陶瓦/
とうがい /当該/頭蓋/凍害/等外/頭外/
とうがい> /当該;-処分,-物件,-事案/
とうがいあいてかた /当該相手方/
とうがいえいが /当該映画/
とうがいえん /等外延/
とうがいかくごう /当該各号/
とうがいかしょ /当該箇所/
とうがいきじ /当該記事/
とうがいきゅうだん /当該球団/
とうがいきょだく /当該許諾/
とうがいくかん /当該区間/
とうがいけんきゅうかい /当該研究会/
とうがいこうい /当該行為/
とうがいこういしゃ /当該行為者/
とうがいこく /当該国/
とうがいこつ /頭蓋骨/
とうがいしちょうそん /当該市町村/
とうがいしょうぎょうよう /当該商業用/
とうがいしょうひん /当該商品/
とうがいじつえん /当該実演/
とうがいじどう /当該児童/
とうがいだんたい /当該団体/
とうがいちいき /当該地域/
とうがいちょさくけん /当該著作権/
とうがいちょさくぶつ /当該著作物/
とうがいふくせいぶつ /当該複製物/
とうがく /唐楽;唐の音楽。また雅楽の様式/陶額/
とうがし /唐菓子/
とうがっか /当学科/
とうがった /遠刈田/
とうがね /東金/
とうがまえ /闘構え;[部首]鬥/
とうがらし /唐辛子/
とうがん /東岸/冬瓜/
とうき /冬季;†季節としての冬。「-五輪」/登記/陶器/当期/冬期;†時期としての冬。「-休暇」/投棄;dump.「ゴミの-」/投機;speculate.「-的売買」/騰貴/当帰;漢方薬/当機/当季;this season/党紀;党の紀律。「-の乱れ」/党規;党の規則。「-違反」/党旗/闘鬼/頭記/
とうきかく /当企画/
とうきかん /登記官/
とうきがわら /陶器瓦/
とうききゅうか /冬期休暇/
とうきぎむしゃ /登記義務者/
とうきげんてい /冬季限定/
とうきごりん /冬季五輪/
とうきしょ /登記所/登記書/
とうきしんせい /登記申請/
とうきじ /当記事/
とうきじゅんりえき /当期純利益/
とうきすじ /投機筋/
とうきせい /陶器製/投機性/
とうきせん /登記船/
とうきち /藤吉/
とうきちろう /藤吉郎/
とうきてき /投機的/
とうきとりひき /投機取引/
とうきはくぶつかん /陶器博物館/
とうきび /唐黍/
とうきぶつ /投棄物/
とうきへいさ /冬季閉鎖/冬期閉鎖/
とうきほう /登記法;不動産-,商業-/
とうきぼ /登記簿/
とうきぼとうほん /登記簿謄本/
とうきゃく /等脚/
とうきゃくるい /橈脚類/
とうきゅう /東急/等級/投球/討究/冬宮/
とうきゅういけがみせん /東急池上線/
とうきゅうおおいまちえき /東急大井町駅/
とうきゅうおおいまちせん /東急大井町線/
とうきゅうかいすう /投球回数/
とうきゅうかんこう /東急観光/
とうきゅうがわ /東急側/
とうきゅうけんせつ /東急建設;[企業名]/
とうきゅうしゃりょう /東急車両/
とうきゅうしんたまがわせん /東急新玉川線/
とうきゅうじ /投球時/
とうきゅうせん /東急線/
とうきゅうせんえんせん /東急線沿線/
とうきゅうでんてつ /東急電鉄/
とうきゅうとうよこ /東急東横/
とうきゅうとうよこせん /東急東横線/
とうきゅうとうよこてん /東急東横店/
とうきゅうどうさ /投球動作/
とうきゅうないよう /投球内容/
とうきゅうはんず /東急ハンズ/
とうきゅうひゃっかてん /東急百貨店/
とうきゅうひゃっかてんまえ /東急百貨店前/
とうきゅうふどうさん /東急不動産/
とうきゅうぶんかむら /東急文化村/
とうきゅうほてる /東急ホテル/
とうきゅうほんてん /東急本店/
とうきゅうまえ /東急前/投球前/
とうきゅうめかません /東急目蒲線/
とうきょう /東京/東教/
とうきょうあきはばら /東京秋葉原/
とうきょういかしかだいがく /東京医科歯科大学/
とうきょういかだいがく /東京医科大学/
とうきょういがい /東京以外/
とうきょういけぶくろ /東京池袋/
とうきょういち /東京一/
とうきょううえの /東京上野/
とうきょうえき /東京駅/
とうきょうえきだいまる /東京駅大丸/
とうきょうえきちか /東京駅地下/
とうきょうえきちゃく /東京駅着/
とうきょうえきみなみぐち /東京駅南口/
とうきょうえん /東京円/
とうきょうおうふく /東京往復/
とうきょうおおさかかん /東京大阪間/
とうきょうおおつか /東京大塚/
とうきょうおんがくだいがく /東京音楽大学/
とうきょうおんだい /東京音大/
とうきょうおんど /東京音頭/
とうきょうかい /当協会/
とうきょうかいかん /東京会舘;異体字/
とうきょうかいさい /東京開催/
とうきょうかいじょう /東京海上;[企業名]/東京会場/
とうきょうかいはつ /東京開発/
とうきょうかいわい /東京界隈/
とうきょうかがくどうじん /東京化学同人/
とうきょうかせい /東京化成/
とうきょうかせいだい /東京家政大/
とうきょうかせいだいがく /東京家政大学/
とうきょうかながわ /東京神奈川/
とうきょうかんない /東京管内/
とうきょうが /東京画/
とうきょうがくげいだい /東京学芸大/
とうきょうがくげいだいがく /東京学芸大学/
とうきょうがす /東京ガス/東京瓦斯;[企業名]/
とうきょうがわ /東京側/
とうきょうきかんく /東京機関区/
とうきょうきそけん /東京基礎研/
とうきょうきゅうこう /東京急行/
とうきょうきゅうこうでんてつ /東京急行電鉄/
とうきょうきゅうじょう /東京球場/
とうきょうきんこう /東京近郊/
とうきょうきんむ /東京勤務/
とうきょうぎんこう /東京銀行/
とうきょうくらぶ /東京倶楽部/
とうきょうぐち /東京口/
とうきょうけい /東京系/
とうきょうけいき /東京計器/
とうきょうけいばじょう /東京競馬場/
とうきょうけいれつ /東京系列/
とうきょうけん /東京圏/
とうきょうげいじゅつげきじょう /東京芸術劇場/
とうきょうげいじゅつだいがく /東京芸術大学/
とうきょうこう /東京港/東京校/
とうきょうこうえん /東京公演/
とうきょうこうか /東京工科/
とうきょうこうかだい /東京工科大/
とうきょうこうかだいがく /東京工科大学/
とうきょうこうきょうがくだん /東京交響楽団/
とうきょうこうぎょうだい /東京工業大/
とうきょうこうぎょうだいがく /東京工業大学/
とうきょうこうげいだいがく /東京工芸大学/
とうきょうこうこう /東京高校/
とうきょうこうじょう /東京工場/
とうきょうこうせいねんきん /東京厚生年金/
とうきょうこうせん /東京高専/
とうきょうこうだい /東京工大/
とうきょうこくさい /東京国際/
とうきょうこくさいくうこう /東京国際空港/
とうきょうこくさいだいがく /東京国際大学/
とうきょうこくぜいきょく /東京国税局/
とうきょうご /東京語/
とうきょうさいばん /東京裁判/
とうきょうしき /東京式/
とうきょうししゃ /東京支社/
とうきょうしじょう /東京市場/
とうきょうしたまち /東京下町/
とうきょうしば /東京芝/
とうきょうしぶ /東京支部/
とうきょうしゅっちょう /東京出張/
とうきょうしょうがいとくべつ /東京障害特別/
とうきょうしょうけんとりひきじょ /東京証券取引所;東証/
とうきょうしょうせんだいがく /東京商船大学/
とうきょうしょせき /東京書籍/
とうきょうしょせきいんさつ /東京書籍印刷;[企業名]/
とうきょうしんがくだいがく /東京神学大学/
とうきょうしんじゅく /東京新宿/
とうきょうしんぶん /東京新聞/
とうきょうしんぶんはい /東京新聞杯/
とうきょうじぎょうしょ /東京事業所/
とうきょうじむしょ /東京事務所/
とうきょうじょうほう /東京情報/
とうきょうじょがっかん /東京女学館/
とうきょうじょし /東京女子/
とうきょうじょしがくいん /東京女子学院/
とうきょうじょしだいがく /東京女子大学/
とうきょうじん /東京人/
とうきょうすいさんだい /東京水産大/
とうきょうすいさんだいがく /東京水産大学/
とうきょうすたいる /東京スタイル/
とうきょうせいかつ /東京生活/
とうきょうせいこう /東京製鋼/
とうきょうせいてつ /東京製鐵;[企業名]/
とうきょうせたがや /東京世田谷/
とうきょうせん /東京戦/
とうきょうぜいかん /東京税関/
とうきょうぜんたい /東京全体/
とうきょうそうげんしゃ /東京創元社/
とうきょうたいいくかん /東京体育館/
とうきょうたいかい /東京大会/
とうきょうたわー /東京タワー/
とうきょうたんけん /東京探検/
とうきょうたんていだん /東京探偵団/
とうきょうだい /東京大/東教大/
とうきょうだいがく /東京大学/
とうきょうだいがくしゅうし /東京大学修士/
とうきょうだいがくしゅっぱんかい /東京大学出版会;[出版社名]/
とうきょうだいがくせい /東京大学生/
とうきょうだいがくせいきょう /東京大学生協/
とうきょうだいがくせいさん /東京大学生産/
とうきょうだいがくほんごう /東京大学本郷/
とうきょうだいがくものがたり /東京大学物語/
とうきょうだいがくりか /東京大学理科/
とうきょうだいくうしゅう /東京大空襲/
とうきょうちかえき /東京地下駅/
とうきょうちく /東京地区/
とうきょうちほう /東京地方/
とうきょうちゅうしん /東京中心/
とうきょうちゅうしんぶ /東京中心部/
とうきょうちゅうにち /東京中日/
とうきょうちょっこうびん /東京直行便/
とうきょうてあとる /東京テアトル/
とうきょうてっこう /東京鐵鋼/
とうきょうてん /東京店/
とうきょうてんもんだい /東京天文台/
とうきょうでんき /東京電気/
とうきょうでんきだい /東京電機大/
とうきょうでんきだいがく /東京電機大学/
とうきょうでんしせっけい /東京電子設計/
とうきょうでんりょく /東京電力;[企業名]/
とうきょうと /東京都/
とうきょうとくない /東京都区内/
とうきょうとくぶ /東京都区部/
とうきょうとこうつうきょく /東京都交通局/
とうきょうとしょ /東京図書/
とうきょうとしょくいん /東京都職員/
とうきょうとすいどうきょく /東京都水道局/
とうきょうとちょう /東京都庁/
とうきょうとない /東京都内/
とうきょうとみん /東京都民/
とうきょうとりつ /東京都立/
とうきょうとりつだい /東京都立大;NB:首都大学東京への再編が予定されている/
とうきょうとりつだいがく /東京都立大学;NB:首都大学東京への再編が予定されている/
とうきょうどう /東京堂/
とうきょうどうしゅっぱん /東京堂出版;[出版社名]/
とうきょうなんせいぶ /東京南西部/
とうきょうにちにちしんぶん /東京日日新聞/
とうきょうにっさん /東京日産/
とうきょうのうぎょうだいがく /東京農業大学/
とうきょうのうこうだい /東京農工大/
とうきょうのうこうだいがく /東京農工大学/
とうきょうはちおうじ /東京八王子/
とうきょうはつ /東京発/
とうきょうはるみ /東京晴海/
とうきょうばん /東京版/
とうきょうびん /東京便/
とうきょうぶんか /東京文化/
とうきょうぶんかかいかん /東京文化会館/
とうきょうへん /東京篇/
とうきょうべいえぬけーほーる /東京ベイＮＫホール/
とうきょうべん /東京弁/
とうきょうほうげん /東京方言/
とうきょうほうしき /東京方式/
とうきょうほうそう /東京放送/
とうきょうほうめん /東京方面/
とうきょうほか /東京他/
とうきょうほんしゃ /東京本社/
とうきょうみつびし /東京三菱/
とうきょうみやげ /東京土産/
とうきょうめいか /東京銘菓/
とうきょうやまのてせんない /東京山手線内/
とうきょうゆうしゅん /東京優駿/
とうきょうよみうりきょじんぐん /東京読売巨人軍/
とうきょうりかだい /東京理科大/
とうきょうりかだいがく /東京理科大学/
とうきょうりっしょう /東京立正/
とうきょうりゅう /東京流/
とうきょうりゅうつう /東京流通/
とうきょうわん /東京湾/
とうきょうわんいっしゅう /東京湾一周/
とうきょうわんがん /東京湾岸/
とうきょうわんぐち /東京湾口/
とうきょうわんない /東京湾内/
とうきょく /当局/登極;天皇の即位/
とうきょくしゃ /当局者/
とうきょり /等距離/
とうきりえき /当期利益/
とうきりょう /登記料/
とうきん /陶鈞;ろくろ/
とうきんせん /東金線/
とうぎ /討議/東儀/闘技/党議/東魏;[中国史](534-550)/
とうぎこうそく /党議拘束/
とうぎじこう /討議事項/
とうぎじょう /闘技場/
とうぎゅう /闘牛/
とうぎゅうし /闘牛士/
とうぎょ /統御/闘魚/
とうぎょう /陶業/
とうぎり /当限/
とうぎん /当今/
とうくつ /盗掘/
とうくろう /藤九郎/
とうぐう /東宮/
とうぐうごしょ /東宮御所/
とうぐうしょく /東宮職;宮内庁-。 皇太子夫妻担当/
とうぐうぼう /春宮坊/
とうぐん /東軍/
とうけ /当家/
とうけい /統計/東経;east longitude.「-135度」/闘鶏/倒景/
とうけいえんざん /統計演算/
とうけいかいせき /統計解析/
とうけいかいせきよう /統計解析用/
とうけいがく /統計学/
とうけいがくてき /統計学的/
とうけいきょく /統計局/
とうけいけいさん /統計計算/
とうけいけっか /統計結果/
とうけいごさ /統計誤差/
とうけいしゅほう /統計手法/
とうけいしょり /統計処理/
とうけいしょりよう /統計処理用/
とうけいしりょう /統計資料/
とうけいじ /東慶寺;著名な縁切寺/
とうけいじょう /統計上/
とうけいじょうほう /統計情報/
とうけいすうがく /統計数学/
とうけいすうじ /統計数字/
とうけいずひょう /統計図表/
とうけいせいど /統計精度/
とうけいち /統計値/
とうけいちょうさ /統計調査/
とうけいてき /統計的/
とうけいてきしゅほう /統計的手法/
とうけいてきしりょう /統計的資料/
とうけいてきすうち /統計的数値/
とうけいてきせいしつ /統計的性質/
とうけいてきほうそく /統計的法則/
とうけいてきゆういせい /統計的有意性/
とうけいねつりきがく /統計熱力学/
とうけいひょう /統計表/
とうけいぶ /頭頸部/
とうけいぶつり /統計物理/
とうけいぶんせき /統計分析/
とうけいぶんぷ /統計分布/
とうけいよう /統計用/
とうけいりきがく /統計力学/
とうけいりょう /統計量/
とうけつ /凍結/盗血/
とうけつじゅせいらん /凍結受精卵/
とうけつじょうきょう /凍結状況/
とうけつどうろ /凍結道路/
とうけつぼうし /凍結防止/
とうけつぼうしざい /凍結防止剤/
とうけつぼうしよう /凍結防止用/
とうけつまえ /凍結前/
とうけつろ /凍結路/
とうけん /刀剣/倒懸/闘犬/東建/当権/陶甄/
とうけんがけい /陶犬瓦鶏/
とうけんきゅうかい /当研究会/
とうけんきゅうしつ /当研究室/
とうけんきゅうしょ /当研究所/
とうけんるい /刀剣類/
とうげ /峠/
とうげい /陶芸/
とうげいか /陶芸家/
とうげえき /峠駅/
とうげこう /登下校/
とうげこうじ /登下校時/
とうげこうちゅう /登下校中/
とうげごえ /峠越え/峠越/
とうげぞく /峠族/
とうげつ /当月/冬月/
とうげつざん /当月残/
とうげつぶん /当月分/
とうげみち /峠道/
とうげん /桃源/套言/
とうげんきょう /桃源郷/
とうこ /東子;人名/島弧/東胡/党錮/投壺/董狐/唐鼓/桃壺/
とうこう /投稿/登校/東工/当行/東光/投降/陶工/東行/等高/投光/登高/刀工/登降/東郊/灯光/頭光/東耕/冬耕/凍港/党綱/
とうこういらい /投稿依頼/
とうこうかいすう /投稿回数/
とうこうかのう /投稿可能/
とうこうがわ /投稿側/
とうこうき /投光器/
とうこうきじ /投稿記事/
とうこうきじすう /投稿記事数/
とうこうきてい /投稿規定/
とうこうきょひ /登校拒否/
とうこうきんし /投稿禁止/
とうこうぎゃくし /倒行逆施/
とうこうけいけん /投稿経験/
とうこうげんこう /投稿原稿/
とうこうこうい /投稿行為/
とうこうご /投稿後/
とうこうさき /投稿先/
とうこうさくひん /投稿作品/
とうこうしかく /投稿資格/
とうこうしつもん /投稿質問/
とうこうしめきり /投稿締切/
とうこうしゃ /投稿者/
とうこうしゃしん /投稿写真/
とうこうしゃじしん /投稿者自身/
とうこうしゃすう /投稿者数/
とうこうしゃぜんいん /投稿者全員/
とうこうしゃどうし /投稿者同士/
とうこうしゃべつ /投稿者別/
とうこうしゃほんにん /投稿者本人/
とうこうしゃめい /投稿者名/
とうこうしょく /橙黄色/
とうこうじ /投稿時/登校時/
とうこうじかん /投稿時間/
とうこうじてん /投稿時点/
とうこうじゅんび /投稿準備/
とうこうすう /投稿数/
とうこうずみ /投稿済/
とうこうせいげん /投稿制限/
とうこうせいていがた /東高西低型/
とうこうせん /等高線/
とうこうせんず /等高線図/
とうこうそうすう /投稿総数/
とうこうだい /東工大/東京工業大学;※abbrev/
とうこうちゅう /投稿中/登校中/
とうこうてじゅん /投稿手順/
とうこうないよう /投稿内容/
とうこうなみ /投稿並/
とうこうにん /党公認/
とうこうばしょ /投稿場所/
とうこうひんど /投稿頻度/
とうこうび /投稿日/登校日/
とうこうぶん /投稿文/
とうこうへい /投降兵/
とうこうほうしき /投稿方式/
とうこうほうほう /投稿方法/
とうこうまえ /投稿前/
とうこうよう /投稿用/
とうこうらん /投稿欄/
とうこうりょう /投稿量/
とうこうれき /投稿歴/
とうこうろんぶん /投稿論文/
とうこく /透谷/
とうこつ /頭骨;skull/橈骨;[解剖](前腕部の)radius/
とうこん /闘魂/当今/刀痕/
とうこんさんじゅうし /闘魂三銃士/
とうご /統語;syntax/頭語;手紙の書き出し。eg.拝啓/倒語;[言語]reversed word. eg.「種」→「ネタ」/東児;地名/套語/
とうごう /統合/東郷;人名/投合/等号/＝/
とうごうあん /統合案/
とうごうか /統合化/
とうごうかいはつかんきょう /統合開発環境/
とうごうかしゅほう /統合化手法/
とうごうかのうせい /統合可能性/
とうごうかんきょう /統合環境/
とうごうがた /統合型/
とうごうき /統合器/
とうごうきょういく /統合教育/
とうごうぎじゅつ /統合技術/
とうごうご /統合後/
とうごうしっちょうしょう /統合失調症/
とうごうしゃ /統合者/
とうごうしょり /統合処理/
とうごうせい /統合性/
とうごうせいじ /東郷青児;(1897-1978) 画家/
とうごうていあん /統合提案/
とうごうてき /統合的/
とうごうてきけんきゅう /統合的研究/
とうごうばくりょうかいぎ /統合幕僚会議/
とうごうばん /統合版/
とうごうへいはちろう /東郷平八郎/
とうごうほう /統合法/
とうごうりつ /統合率/
とうごかいせき /統語解析/
とうごく /投獄/東国/当国/
とうごくほうげん /東国方言/
とうごけい /頭語系/
とうごこうぞう /統語構造/
とうごじょう /統語上/
とうごてき /統語的/
とうごはんちゅう /統語範疇/
とうごま /唐胡麻/
とうごろん /統語論/
とうさ /踏査/等差/
とうさい /搭載;物に載せる。「HDD-」/登載;文章に載せる。「戸籍への-」/当歳/統裁/
とうさいいち /搭載位置/
とうさいうお /当歳魚/
とうさいかのう /搭載可能/
とうさいかん /搭載艦/
とうさいき /搭載機/
とうさいきすう /搭載機数/
とうさいぎょ /当歳魚/
とうさいしゃ /搭載車/
とうさいと /当サイト/
とうさいば /当歳馬/
とうさいりょう /搭載量/
とうさきゅうすう /等差級数/
とうさく /盗作/倒錯/東作/
とうさくしゃ /倒錯者/
とうさすうれつ /等差数列/
とうさつ /盗撮/透察/
とうさま /父様/
とうさん /倒産/父さん/東讃/逃散/
とうさんご /倒産後/
とうさんさい /唐三彩/
とうさんどう /東山道;地名/
とうさんやく /党三役/
とうざ /当座/
とうざい /東西/
とうざいかくさ /東西格差/
とうざいじゆうつうろ /東西自由通路/
とうざいせん /東西線/
とうざいせんかいそく /東西線快速/
とうざいせんちょくつう /東西線直通/
とうざいせんない /東西線内/
とうざいたいけつ /東西対決/
とうざいとういつ /東西統一/
とうざいなんぼく /東西南北/
とうざいぶんめい /東西文明/
とうざいほうこう /東西方向/
とうざいりょうよこづな /東西両横綱/
とうざかしこし /当座貸越;overdraft. (銀行側から見た)預金残高以上の振出/
とうざかりこし /当座借越/
とうざしさん /当座資産;流動資産の一種。預金、受取手形、売掛金、有価証券の4つからなる/
とうざしのぎ /当座凌ぎ/
とうざのがれ /当座逃れ/
とうざよきん /当座預金/
とうざん /当山/頭山/唐山/唐桟/
とうし /投資/闘士/闘志/透視/凍死/唐詩/骰子/唐紙/祷祀/祷祠/
とうしか /投資家/
とうしがいしゃ /投資会社/
とうしがく /投資額/
とうしがほう /透視画法/
とうしき /等式/
とうしぎんこう /投資銀行;investment bank/
とうしけいかく /投資計画/
とうしこうか /投資効果/
とうしこもん /投資顧問/
とうしこもんぎょう /投資顧問業/
とうししじょう /投資市場/
とうししゃ /投資者/
とうししんたく /投資信託/
とうししんたくがいしゃ /投資信託会社/
とうしじぎょうくみあい /投資事業組合/
とうしじぎょうゆうげんせきにんくみあいほう /投資事業有限責任組合法/
とうしじゅつ /透視術/
とうしじょうほう /投資情報/
とうしず /透視図;perspective/
とうしずほう /透視図法/
とうしせん /唐詩選/
とうしたんい /投資単位/
とうしっこうぶ /党執行部/
とうしつ /糖質/等質/
とうしつせい /透湿性/等質性/
とうしつりょう /等質量/
とうしとう /投資等/
とうしど /透視度/
とうしはいぶん /投資配分/
とうしば /東芝;[企業名]/
とうしばえいぞう /東芝映像/
とうしばきかい /東芝機械/
とうしばぐち /東芝口/
とうしばけい /東芝系/
とうしばけんきゅうかいはつ /東芝研究開発/
とうしばじゅんせい /東芝純正/
とうしばじょうほう /東芝情報/
とうしばせい /東芝製/
とうしばちゅうぶ /東芝中部/
とうしばちょう /東芝町/
とうしばなす /東芝那須/
とうしばばん /東芝版/
とうしばふちゅう /東芝府中/
とうしへんかん /透視変換/
とうしゃ /当社/投射/謄写/投写/透写/謄寫;「写」旧字/
とうしゃいんさつ /謄写印刷/
とうしゃきてい /当社規定/
とうしゃせいひん /当社製品/
とうしゃばん /謄写版/
とうしゃひ /当社比/
とうしゃほう /投射法/
とうしゅ /投手/党首/当主/頭首/陶朱;=范蠡/
とうしゅう /踏襲/東州/東周/等終/
とうしゅうさいしゃらく /東洲斎写楽/
とうしゅきよう /投手起用/
とうしゅく /投宿/
とうしゅじん /投手陣/
とうしゅせいめい /投手生命/
とうしゅせん /投手戦/党首選/
とうしゅぶもん /投手部門/
とうしゅめい /投手名/
とうしゅりょく /投手力/
とうしゆうかしょうけん /投資有価証券/
とうしょ /当初;†at first/投書/当所;†here/島嶼/当処;†=当所/頭書/答書/
とうしょう /東証/闘将/凍傷/刀匠/刀傷/闘翔/
とうしょういちぶ /東証一部/東証１部/
とうしょうかぶかしすう /東証株価指数/
とうしょうぐう /東照宮/
とうしょうだいごんげん /東照大権現/
とうしょうだいじ /唐招提寺/
とうしょうにぶ /東証二部/東証２部/
とうしょうめん /刀削麺/
とうしょきたい /当初期待/
とうしょく /橙色;orange/等色;isochromatic/当職/東食;[企業名]www.toshoku.co.jp/
とうしょけいかく /当初計画/
とうしょばこ /投書箱/
とうしょよさん /当初予算;initial budget/
とうしょよそう /当初予想/
とうしょよてい /当初予定/
とうしょらん /投書欄/
とうしりょく /透視力/
とうしろう /藤四郎;加藤四郎左衛門景正/
とうしん /投信/答申/東進/頭身/刀身/闘神/等身/投身/東晋;[中国王朝]/東伸/灯心/等親/
とうしんぐさ /灯心草;[植物]rush/
とうしんじさつ /投身自殺/
とうしんせん /等深線/
とうしんそう /灯心草;[植物]rush/
とうしんだい /等身大/
とうしんてつどう /東清鉄道/
とうじ /当時/杜氏/湯治/冬至;[二十四節気]12.22頃/東寺/当事;-者/当寺;this temple/答辞/統辞;syntax/等時;-性/蕩児/悼辞/統治;=とうち/刀自;=とじ/田路;人名/田牛;地名,静岡/藤治/
とうじいん /等持院/
とうじき /陶磁器/
とうじきせい /陶磁器製/
とうじくしょうけい /等軸晶系;[化学]isometric system/
とうじこうこうせい /当時高校生/
とうじこく /当事国/
とうじご /頭字語/
とうじさい /冬至祭/
とうじしゃ /当事者/
とうじしゃいしき /当事者意識/
とうじしゃかん /当事者間/
とうじしゃしゅぎ /当事者主義/
とうじしゃてきかく /当事者適格/
とうじしゃのうりょく /当事者能力/
とうじしょうがくせい /当時小学生/
とうじせい /等時性/
とうじちゅうがくせい /当時中学生/
とうじつ /当日/冬日/
とうじつあさ /当日朝/
とうじつうけつけ /当日受付/
とうじつかいじょう /当日会場/
とうじつかいじょうまえ /当日会場前/
とうじつけしいんゆうこう /当日消印有効/
とうじつけん /当日券/
とうじつさんか /当日参加/
とうじつしてい /当日指定/
とうじつじさん /当日持参/
とうじつじゅんび /当日準備/
とうじつちゅう /当日中/
とうじつとうちゃくぶん /当日到着分/
とうじつはっこう /当日発行/
とうじつはっぴょう /当日発表/
とうじつぶん /当日分/
とうじつりょうきん /当日料金/
とうじば /湯治場/
とうじばん /東寺版/
とうじゅ /藤樹/東樹/
とうじゅうろう /藤十郎/
とうじゅく /登熟;(穀物・豆類の)種子が稔っていくこと/
とうじゆうめい /当時有名/
とうじょ /倒叙/唐書/東序/
とうじょう /登場/搭乗/東上/東条/東城/筒状/東條/登城/棟上/凍上/頭状/闘諍/刀杖/
とうじょういぜん /登場以前/
とうじょういらい /登場以来/
とうじょういん /搭乗員/
とうじょううん /塔状雲/
とうじょうか /頭状花/
とうじょうかいかん /東條會舘;異体字/
とうじょうかじょ /頭状花序/
とうじょうきゃく /搭乗客/
とうじょうきょり /搭乗距離/
とうじょうぐち /搭乗口/
とうじょうけん /搭乗券/
とうじょうご /登場後/
とうじょうしゃ /搭乗者/
とうじょうしゃほけん /搭乗者保険/
とうじょうじ /登場時/搭乗時/
とうじょうじっせき /搭乗実績/
とうじょうじんぶつ /登場人物/
とうじょうじんぶつたち /登場人物達/
とうじょうじんぶつめい /登場人物名/
とうじょうせん /東上線/
とうじょうちょくぜん /搭乗直前/
とうじょうてつどう /東上鉄道/
とうじょうとうじ /登場当時/
とうじょうばめん /登場場面/
とうじょうばんぐみ /登場番組/
とうじょうひでき /東条英機/
とうじょうび /搭乗日/
とうじょうびん /搭乗便/
とうじょうまえ /登場前/搭乗前/
とうじょうよてい /登場予定/
とうじょうよていび /搭乗予定日/
とうじょうりつ /搭乗率/
とうじょたいだい /東女体大/
とうじりつ /透磁率/
とうじろう /藤治郎/
とうじん /唐人/蕩尽/党人/陶人/刀刃/
とうじんおきち /唐人お吉/
とうじんぼう /東尋坊/
とうじんまち /唐人町/
とうす /刀子/東司/
とうすい /陶酔/透水/統帥/
とうすいきょう /陶酔境/
とうすいけん /統帥権/
とうすいせい /透水性/
とうすいだい /東水大/
とうすう /頭数/
とうすうけん /統数研/統計数理研究所;※abbrev/
とうすけ /東介/藤輔/
とうすぽ /東スポ/
とうせい /統制/当世/陶製/東征/党勢/籐製/騰勢/冬青;[植物]/搗精/踏青;春のピクニック/濤声;波のうねる音/倒生/
とうせいがくえん /東星学園/
とうせいけいざい /統制経済/
とうせいは /統制派/
とうせいふう /当世風/
とうせいりょく /統制力/
とうせき /透析/投石/陶石/等積/党籍/凍石;steatite/
とうせきかいし /透析開始/
とうせきかいろ /透析回路/
とうせきかんじゃ /透析患者/
とうせきき /透析機/
とうせきしつ /透析室/
とうせきじ /透析時/
とうせきそうち /透析装置/
とうせきちゅう /透析中/
とうせきどうにゅう /透析導入/
とうせきへんか /等積変化;[熱力学]isochoric change/
とうせきりょうほう /透析療法/
とうせつ /当節/
とうせん /当選/東線/唐船/東遷/頭線/当籤/盗泉;-の水を飲まず/陶潜;=陶淵明/陶染/
とうせんかいすう /当選回数/
とうせんかくじつ /当選確実/
とうせんかくりつ /当選確率/
とうせんかろ /冬扇夏炉/
とうせんきん /当選金/当籤金/
とうせんけってい /当選決定/
とうせんご /当選後/
とうせんしゃ /当選者/
とうせんしょうしょ /当選証書/
とうせんばんごう /当選番号/
とうぜ /党是/
とうぜん /当然/陶然/当前/東漸/當然;「当」旧字/
とうぜんそんざい /当然存在/
とうそう /闘争/逃走/痘瘡/刀槍/党争/鬪爭/
とうそうおん /唐宋音/
とうそうけいろ /逃走経路/
とうそうしん /闘争心/
とうそうせん /東早戦/
とうそうちゅう /逃走中/
とうそうほうほう /闘争方法/逃走方法/
とうそく /等速/頭側/党則/
とうそくうんどう /等速運動/
とうそくえんうんどう /等速円運動/
とうそくちょくせんうんどう /等速直線運動/
とうそくど /等速度/
とうそくどうんどう /等速度運動/
とうそくるい /頭足類/
とうそしき /当組織/
とうそつ /統率/
とうそつしゃ /統率者/
とうそつせい /統率性/
とうそつりょく /統率力/
とうそん /藤村/
とうぞく /盗賊/
とうぞくかぎょう /盗賊家業;?/
とうぞくけい /盗賊系/
とうぞくだん /盗賊団/
とうぞくなど /盗賊等/
とうた /淘汰/
とうたいかい /党大会/
とうたく /董卓;後漢末期の群雄/
とうたつ /到達/
とうたつかのう /到達可能/
とうたつかのうせい /到達可能性/
とうたつきょり /到達距離/
とうたつしゅぎ /到達主義/
とうたつじかん /到達時間/
とうたつじかんさ /到達時間差/
とうたつせい /到達性/
とうたつてん /到達点/
とうたつど /到達度/
とうたつは /到達波/
とうたつはんい /到達範囲/
とうたつふかのう /到達不可能/
とうたつもくひょう /到達目標/
とうたん /東端/
とうたんぱくしつ /糖蛋白質/
とうだ /投打/任田;姓/頭打/
とうだい /灯台/東大/当代/等大/燈台;「灯」異体字/登第/東台/東京大学;※abbrev/
とうだいいかけん /東大医科研/
とうだいいがくぶ /東大医学部/
とうだいいん /東大院/
とうだいうら /東大裏/
とうだいかいようけん /東大海洋研/
とうだいかがく /東大化学;[企業名]/
とうだいがく /当大学/
とうだいがわ /東大側/
とうだいきこう /東大気候/
とうだいきょういく /東大教育/
とうだいきょうじゅ /東大教授/
とうだいきょうよう /東大教養/
とうだいぐさもく /トウダイグサ目/Euphorbiales/
とうだいぐさもくぐん /トウダイグサ目群/
とうだいけいざい /東大経済/
とうだいけいざいがくぶ /東大経済学部/
とうだいげんしりょく /東大原子力/
とうだいこう /東大工/
とうだいこうがくぶ /東大工学部/
とうだいこまば /東大駒場/
とうだいごうかくしゃ /東大合格者/
とうだいごうかくしゃすう /東大合格者数/
とうだいしゅっしんしゃ /東大出身者/
とうだいしゅっぱんかい /東大出版会;[出版社名]/
とうだいじ /東大寺/
とうだいじしんけん /東大地震研/
とうだいすうがく /東大数学/
とうだいすうりかがく /東大数理科学/
とうだいせい /東大生/
とうだいせいけん /東大生研/
とうだいせいさん /東大生産/
とうだいせいさんけん /東大生産研/
とうだいせんたんけん /東大先端研/
とうだいだいけい /東大大型/
とうだいのう /東大農/
とうだいのうがくぶ /東大農学部/
とうだいびょういん /東大病院/
とうだいぶっせいけん /東大物性研/
とうだいぶつり /東大物理/
とうだいぶんがくぶ /東大文学部/
とうだいほう /東大法/
とうだいほうがくぶ /東大法学部/
とうだいほんごう /東大本郷/
とうだいまえ /東大前/
とうだいめいよきょうじゅ /東大名誉教授/
とうだいもとくらし /灯台下暗し/
とうだいもり /灯台守/
とうだいやく /東大薬/
とうだいり /東大理/
とうだいりがくぶ /東大理学部/
とうだん /登壇/当団/投弾/
とうだんしゃ /登壇者/
とうだんたい /当団体/
とうち /当地/統治/等値/倒置/島地/投地/
とうちか /統治下/
とうちきこう /統治機構/
とうちく /東筑/唐竹/
とうちけん /統治権/
とうちこうい /統治行為/
とうちしき /倒置式/
とうちしゃ /統治者/
とうちせん /等値線/
とうちほう /倒置法/
とうちゃ /闘茶/
とうちゃく /到着/
とうちゃくかんかく /到着間隔/
とうちゃくき /到着機/
とうちゃくきゃく /到着客/
とうちゃくご /到着後/
とうちゃくごすうにち /到着後数日/
とうちゃくしだい /到着次第/
とうちゃくじ /到着時/
とうちゃくじかん /到着時間/
とうちゃくじこく /到着時刻/
とうちゃくじゅん /到着順/
とうちゃくじゅんじょ /到着順序/
とうちゃくち /到着地/
とうちゃくとし /到着都市/
とうちゃくび /到着日/
とうちゃくぶん /到着分/
とうちゃくりつ /到着率/
とうちゃん /父ちゃん/
とうちゅう /頭注;headnote/頭註/陶鋳/
とうちゅうかそう /冬虫夏草/
とうちょう /盗聴/登頂/頭頂/登庁/等長;isometric/等張;isotonic/頭長/唐朝/
とうちょうえき /等張液/
とうちょうき /盗聴器/
とうちょうじけん /盗聴事件/
とうちょうないよう /盗聴内容/
とうちょうぶ /頭頂部/
とうちょうほう /盗聴法/
とうちょうぼうし /盗聴防止/
とうちょうぼうしきのう /盗聴防止機能/
とうちょうよう /頭頂葉/
とうちょく /当直/
とうちん /東浄/陶枕/
とうつう /頭痛;=ずつう/疼痛;うずく痛み/東通/
とうつうさんぎょう /東通産業;[企業名]/
とうつき /当月/
とうてい /到底/
とうていふかのう /到底不可能/
とうていむり /到底無理/
とうてき /投擲/
とうてつ /透徹/饕餮/
とうてつこうぎょう /東鉄工業;[企業名]/
とうてつもん /饕餮文/
とうてん /当店/読点;「、」/東天/
とうてんこう /東天紅/
とうで /遠出/
とうでん /東電/盗電/
とうでんがわ /東電側/
とうでんてん /等電点/
とうと /東都/
とうとう /等々/等等/東陶;[企業名]TOTO/滔々;-と流れる/東塔/偸盗/陶陶/登登/到頭;-完成した/滔滔/丁丁/蕩蕩/鼕鼕/疾う疾う/幢々/
とうとうきき /東陶機器;[企業名]/
とうとうみ /遠江/
とうとく /統督;governer/
とうとすいさん /東都水産/
とうとつ /唐突/頭突/
とうど /糖度/陶土/凍土/
とうどう /藤堂/東道/東堂/当道/
とうどうばつい /党同伐異/
とうどく /東独/
とうどり /頭取/
とうな /唐菜/
とうない /党内/島内/東内/頭内/
とうないていい /頭内定位/
とうなす /唐茄子/
とうなん /東南/盗難/
とうなんあじあ /東南アジア/
とうなんかいじしん /東南海地震/
とうなんげき /盗難劇/
とうなんこうい /盗難行為/
とうなんしゃ /盗難車/
とうなんしょうめい /盗難証明/
とうなんたいさく /盗難対策/
とうなんたはつ /盗難多発/
とうなんとう /東南東/
とうなんとどけ /盗難届/
とうなんぶ /東南部/
とうなんほけん /盗難保険/
とうなんほしょう /盗難補償/
とうなんぼうし /盗難防止/
とうなんぼうしよう /盗難防止用/
とうにち /東日/
とうにゅう /投入/豆乳/刀入/
とうにゅうきんがく /投入金額/
とうにゅうぐち /投入口/
とうにゅうご /投入後/
とうにゅうじ /投入時/
とうにゅうひりつ /投入比率/
とうにゅうりょう /投入量/
とうにょう /糖尿/
とうにょうびょう /糖尿病/
とうにん /当人/
とうにんいがい /当人以外/
とうにんたち /当人達/
とうにんどうし /当人同士/
とうねん /当年/
とうの /東野/冬野;姓/統乃/当の/遠野;※仮名遣い「とおの」/
とうのうだい /東農大/
とうのしょう /東庄/
とうのちゅうじょう /頭の中将/
とうのみね /多武峰;地名,/
とうのみねしょうしょうものがたり /多武峰少将物語/
とうのむかし /疾うの昔/
とうは /党派/踏破/
とうはいごう /統廃合/
とうはく /東伯/等伯/
とうはしん /党派心;partisanship/
とうはせい /党派性/
とうはつ /頭髪/
とうはと /東ハト;[企業名]キャラメルコーン/東鳩;※現在は「東ハト」/
とうはば /等幅/
とうはん /登坂;†-車線/登攀;†冬山-/盗犯/東阪/東版/東販;[企業名][略語]東京出版販売株式会社。www.tohan.jp NB:現在は「トーハン株式会社」/
とうはんしゃせん /登坂車線/
とうはんじ /登坂時/
とうば /塔婆/
とうばい /等倍/当倍/
とうばく /倒幕/討幕/
とうばつ /討伐/盗伐;伐採して盗む/倒伐/党閥/
とうばつたい /討伐隊/
とうばん /当番/登板/
とうばんい /当番医/
とうばんかた /登板過多/
とうばんぐみ /当番組/
とうばんこう /当番校/
とうばんじゃん /豆板醤/豆瓣醤/
とうばんせい /当番制/
とうばんちょう /当番町/
とうひ /逃避/頭皮/当否/等比/唐檜/討匪/
とうひきゅうすう /等比級数/
とうひこう /逃避行/討匪行/
とうひこうどう /逃避行動/
とうひすうれつ /等比数列/
とうひちゅう /逃避中/
とうひょう /投票/
とうひょうかいし /投票開始/
とうひょうかんり /投票管理/
とうひょうかんりきかん /投票管理機関/
とうひょうかんりしゃ /投票管理者/
とうひょうがく /投票額/
とうひょうきかん /投票期間/
とうひょうきかんちゅう /投票期間中/
とうひょうきょひ /投票拒否/
とうひょうきんがく /投票金額/
とうひょうけいしき /投票形式/
とうひょうけっか /投票結果/
とうひょうけん /投票権;†right of vote.「国民の-」/投票券;†voting card.「-を忘れても投票できます」/
とうひょうこうどう /投票行動/
とうひょうご /投票後/
とうひょうさ /投票差/
とうひょうさき /投票先/
とうひょうさぎょう /投票作業/
とうひょうさんかしゃ /投票参加者/
とうひょうしかく /投票資格/
とうひょうしゃ /投票者/
とうひょうしゃすう /投票者数/
とうひょうしゃぜんいん /投票者全員/
とうひょうしゃめい /投票者名/
とうひょうしゅうけい /投票集計/
とうひょうしゅうりょう /投票終了/
とうひょうしゅうりょうご /投票終了後/
とうひょうしょない /投票所内/
とうひょうじっし /投票実施/
とうひょうじゅんい /投票順位/
とうひょうじょ /投票所/
とうひょうじょう /投票場/
とうひょうじょうい /投票上位/
とうひょうじょうけん /投票条件/
とうひょうじょない /投票所内/
とうひょうすう /投票数/
とうひょうせい /投票制/
とうひょうせいど /投票制度/
とうひょうせいりつ /投票成立/
とうひょうせんしゅつ /投票選出/
とうひょうぜんたい /投票全体/
とうひょうそうすう /投票総数/
とうひょうたいしょう /投票対象/
とうひょうたちあいにん /投票立会人/
とうひょうちゅう /投票中/
とうひょうないよう /投票内容/
とうひょうにんずう /投票人数/
とうひょうはっぴょう /投票発表/
とうひょうはんたい /投票反対/
とうひょうばこ /投票箱/
とうひょうび /投票日/
とうひょうびとうじつ /投票日当日/
とうひょうぶん /投票分/
とうひょうほうしき /投票方式/
とうひょうほうほう /投票方法/
とうひょうむこう /投票無効/
とうひょうよう /投票用/
とうひょうようし /投票用紙/
とうひょうらん /投票欄/
とうひょうりつ /投票率/
とうひょうりゆう /投票理由/
とうひょうれい /投票例/
とうひん /盗品/
とうび /掉尾;(慣用読み) =ちょうび/
とうびょう /闘病/投錨/
とうびょうせいかつ /闘病生活/
とうびょうせいかつちゅう /闘病生活中/
とうふ /豆腐/豆富/■/
とうふう /東風/唐風/党風/
とうふく /等幅;-フォント/倒伏;(稲などが)倒れる/東福/
とうふくじ /東福寺/
とうふくじえき /東福寺駅/
とうふじる /豆腐汁/
とうふなべ /豆腐鍋/
とうふや /豆腐屋/
とうふよう /豆腐よう/
とうぶ /東部/東武/頭部/当部/
とうぶあさくさ /東武浅草/
とうぶいせざきせん /東武伊勢崎線/
とうぶえんせん /東武沿線/
とうぶかいてん /頭部回転/
とうぶきょうだ /頭部強打/
とうぶきょく /当部局/
とうぶせんせん /東部戦線/
とうぶせんない /東武線内/
とうぶそうちゃく /頭部装着/
とうぶつ /唐物/
とうぶてつどう /東武鉄道/
とうぶでんしゃ /東武電車/
とうぶでんたつかんすう /頭部伝達関数/
とうぶとうじょうせん /東武東上線/
とうぶとっきゅう /東武特急/
とうぶどうぶつこうえん /東武動物公園/
とうぶなつじかん /東部夏時間/
とうぶにっこう /東武日光/
とうぶにっこうえき /東武日光駅/
とうぶにっこうせん /東武日光線/
とうぶのだ /東武野田/
とうぶはくぶつかん /東武博物館/
とうぶん /当分/糖分/等分/
とうぶんあんたい /当分安泰/
とうぶんかつ /等分割/
とうぶんさき /当分先/
とうぶんしょ /当文書/
とうぶんせん /等分線/
とうぶんぷ /等分布/
とうへい /東平/
とうへき /盗癖/東壁/
とうへん /等辺/陶片/
とうへんついほう /陶片追放/
とうへんぼく /唐変木/
とうべつ /当別/
とうべん /答弁/
とうべんしょ /答弁書/
とうほう /当方/東方/東宝;[企業名]/東邦/投法/桐朋/等方/答訪/答砲/
とうほうあん /当法案/
とうほうおき /東方沖/
とうほうおんだい /東邦音大/桐朋音大/
とうほうがくえん /桐朋学園/
とうほうがくえんだいがく /桐朋学園大学/
とうほうがす /東邦瓦斯/
とうほうきょうかい /東方教会/
とうほうぎんこう /東邦銀行/
とうほうけい /東宝系/
とうほうけいげきじょう /東宝系劇場/
とうほうけんぶんろく /東方見聞録;Il Milione,1271-95,Marco Polo/
とうほうこう /等方向/
とうほうさんらん /等方散乱/
とうほうしてい /当方指定/
とうほうじたく /当方自宅/
とうほうじょし /桐朋女子/
とうほうじょしこうこう /桐朋女子高校/
とうほうせい /等方性;isotropy/
とうほうせいきょうかい /東方正教会/
とうほうせいめい /東邦生命/
とうほうたい /等方体/
とうほうだいがく /東邦大学/
とうほうてき /等方的/
とうほうとくさつえいが /東宝特撮映画/
とうほうふたん /当方負担/
とうほうれーよん /東邦レーヨン/
とうほく /東北/
とうほくかんない /東北管内/
とうほくがくいん /東北学院/
とうほくがくいんだい /東北学院大/
とうほくがくいんだいがく /東北学院大学/
とうほくこうぎょうだい /東北工業大/
とうほくこうぎょうだいがく /東北工業大学/
とうほくさわ /東北沢/
とうほくししゃ /東北支社/
とうほくしてん /東北支店/
とうほくしぶ /東北支部/
とうほくしぶちょう /東北支部長/
とうほくしょく /東北色/
とうほくしんかんせん /東北新幹線/
とうほくしんしゃ /東北新社/
とうほくじどうしゃどう /東北自動車道/
とうほくじん /東北人/
とうほくせん /東北線/東北戦/
とうほくたいかい /東北大会/
とうほくだい /東北大/東北大学;※abbrev/
とうほくだいがく /東北大学/東北大學;「学」旧字/
とうほくだいがくこうがくぶ /東北大学工学部/
とうほくだいがくせいきょう /東北大学生協/
とうほくだいがくでんきつうしんけんきゅうじょ /東北大学電気通信研究所/
とうほくだいがくびょういん /東北大学病院/
とうほくだいがくぶんがくぶ /東北大学文学部/
とうほくだいこう /東北大工/
とうほくだいせい /東北大生/
とうほくちいき /東北地域/
とうほくちく /東北地区/
とうほくちほう /東北地方/
とうほくでんりょく /東北電力;[企業名]/
とうほくとう /東北東/
とうほくとっきゅう /東北特急/
とうほくどう /東北道/
とうほくにほん /東北日本/
とうほくふくしだい /東北福祉大/
とうほくぶ /東北部/
とうほくべん /東北弁/
とうほくほうげん /東北方言/
とうほくほうそう /東北放送/
とうほくほうめん /東北方面/
とうほくほんせん /東北本線/
とうほくやっかだい /東北薬科大/
とうほくよう /東北用/
とうほくりょこう /東北旅行/
とうほん /謄本/唐本/
とうほんせいそう /東奔西走/
とうほんにん /当本人/
とうほんぶ /党本部/
とうぼ /掏摸/
とうぼう /逃亡/陶房/
とうぼうしゃ /逃亡者/
とうぼうせいかつ /逃亡生活/
とうぼうはん /逃亡犯/
とうぼく /倒木/冬木/唐木/透木/
とうま /当麻/藤間/當麻;「当」旧字/冬馬/当間/討魔/東馬/
とうまちくい /稲麻竹葦/
とうみ /唐箕;昔の農具/
とうみつ /糖蜜/東密/
とうみつど /等密度/
とうみょう /灯明/豆苗/燈明/
とうみょうだい /灯明台/
とうみん /冬眠/島民/
とうみんじょうたい /冬眠状態/
とうみんまえ /冬眠前/
とうむ /党務/
とうむら /東村/
とうめい /透明/東名/党名/
とうめいかわさき /東名川崎/
とうめいかん /透明感/東名間/
とうめいこうそく /東名高速/
とうめいこうそくせん /東名高速線/
とうめいこうそくどうろ /東名高速道路/
とうめいごてんば /東名御殿場/
とうめいし /透明視/
とうめいしずおか /東名静岡/
とうめいしょく /透明色/
とうめいじどうしゃどう /東名自動車道/
とうめいせい /透明性/
とうめいせっけん /透明石鹸/
とうめいたい /透明体/
とうめいど /透明度/
とうめいにんげん /透明人間/
とうめいはままつにし /東名浜松西/
とうめいはん /東名阪/
とうめいばす /東名バス/
とうめいばん /透明盤/
とうめいぶぶん /透明部分/
とうめいよこはま /東名横浜/
とうめん /当面/東面/等面/
とうめんよう /等面葉/
とうもう /投網/
とうもく /頭目/
とうもつ /唐物/
とうもろこし /玉蜀黍/
とうや /塔屋;ビルの上に突出している構造物/当夜/陶冶/洞爺;地名/塔矢;姓/
とうやく /投薬/当薬;[漢方]センブリ/湯薬/
とうやこ /洞爺湖/
とうやま /當山;「当」旧字/当山/遠山;※仮名遣い「とおやま」/
とうやまはい /遠山灰/
とうやまる /洞爺丸/
とうゆ /灯油/
とうゆうし /投融資/
とうゆかん /灯油缶/
とうよ /投与/東予/
とうよう /東洋/登用;recruit/盗用;pirate/当用;-漢字/東陽;地名/陶窯/頭葉;[解剖]lobe.「前-」/陶俑;副葬品の土人形/投用/蕩揺;rock/陶遥/
とうよう> /東洋;-文明,-医学/
とうよういがく /東洋医学/
とうようえいわ /東洋英和/
とうようおんがく /東洋音楽/
とうようかがく /東洋化学;[企業名]/
とうようかん /東洋館/
とうようかんじ /当用漢字/
とうようかんじひょう /当用漢字表/
とうようが /東洋画/
とうようがく /東洋学/
とうようけい /東洋系/
とうようけいざい /東洋経済/
とうようこうぎょう /東洋工業;[企業名]/
とうようこうそく /東葉高速/
とうようこうそくてつどう /東葉高速鉄道/
とうようこうはん /東洋鋼板/
とうようさんぎょう /東洋産業;[企業名]/
とうようさんそ /東洋酸素/
とうようし /東洋史/
とうようしそう /東洋思想/
とうようじょうぞう /東洋醸造/
とうようじょうほう /東洋情報/
とうようじょし /東洋女子/
とうようじん /東洋人/
とうようすいさん /東洋水産/
とうようせいかん /東洋製罐/
とうようせいとう /東洋精糖/
とうようだいがく /東洋大学/
とうようだいひめじ /東洋大姫路/
とうようちょう /東陽町/
とうようてき /東洋的/
とうようてつがく /東洋哲学/
とうようでんき /東洋電機;[企業名]/東洋電器;[企業名]?/
とうようでんきせいぞう /東洋電機製造/
とうようふう /東洋風/
とうようふとう /東洋埠頭/
とうようぶんか /東洋文化/
とうようぶんこ /東洋文庫/
とうようぼうせき /東洋紡績/
とうよく /東翼/
とうよこ /東横/
とうよこがくえん /東横学園/
とうよこせん /東横線/
とうよこせんしぶや /東横線渋谷/
とうよこせんしぶやえき /東横線渋谷駅/
とうよこてん /東横店/
とうよりょう /投与量/
とうらい /到来/当来/
とうらいおん /到来音/
とうらいほうこう /到来方向/
とうらいもの /到来物/
とうらうどねす /等ラウドネス/
とうらく /騰落/当落/
とうらくせんじょう /当落線上/
とうらんけい /倒卵形;obovoid/
とうり /桃李/党利/統理/通;とおり/
とうりだい /東理大/
とうりつ /倒立/頭立/
とうりつしんし /倒立振子/
とうりつぞう /倒立像/
とうりつりょく /統率力/
とうりとうりゃく /党利党略;党の利益と党の戦略(のために動くこと)/
とうりとく /等利得/
とうりふげん /桃李不言/
とうりゃく /党略/
とうりゅう /逗留/刀流/当流/闘竜/
とうりゅうもん /登竜門/
とうりょう /棟梁/当量;†equivalent.「モル-」/等量;†equal amount/頭領/投了/統領/
とうりょうず /投了図/
とうりん /登臨/
とうる /透;とおる/徹/
とうるい /盗塁/糖類/
とうるいおう /盗塁王/
とうるいし /盗塁死/
とうるいしっぱい /盗塁失敗/
とうるいすう /盗塁数/
とうれ /東レ/
とうれい /答礼/
とうろ /当路/
とうろう /灯籠/蟷螂;-の斧/燈籠;異体字/燈篭;異体字/螳螂/登楼/灯篭;「籠」異体字/
とうろうながし /灯籠流し/
とうろうのおの /蟷螂の斧/
とうろく /登録/東麓/
とうろくいしょう /登録意匠/
とうろくいらい /登録依頼/
とうろくうけつけ /登録受付/
とうろくうけつけぎょうむ /登録受付業務/
とうろくかいじょ /登録解除/
とうろくかくにん /登録確認/
とうろくかんりょう /登録完了/
とうろくきせい /登録規制/
とうろくきのう /登録機能/
とうろくきぼうしゃ /登録希望者/
とうろくぎむしゃ /登録義務者/
とうろくくぶん /登録区分/
とうろくけんすう /登録件数/
とうろくご /登録語/
とうろくごすう /登録語数/
とうろくさき /登録先/
とうろくさぎょう /登録作業/
とうろくしち /登録質/
とうろくしゃ /登録者/
とうろくしゃすう /登録者数/
とうろくしゃめい /登録者名/
とうろくしょ /登録書/
とうろくしょう /登録証/
とうろくしょうしょ /登録証書/
とうろくしょうひょう /登録商標/
とうろくしょひよう /登録諸費用/
とうろくしんせい /登録申請/
とうろくじ /登録時/
とうろくじどうしゃ /登録自動車/
とうろくじゅり /登録受理/
とうろくじゅん /登録順/
とうろくじょう /登録上/
とうろくじょうほう /登録情報/
とうろくすう /登録数/
とうろくずみ /登録済/
とうろくせい /登録制/
とうろくせいど /登録制度/
とうろくせんしゅ /登録選手/
とうろくそうさ /登録操作/
とうろくたんごすう /登録単語数/
とうろくちゅう /登録中/
とうろくてつづき /登録手続/
とうろくないよう /登録内容/
とうろくはがき /登録葉書/
とうろくば /登録馬/
とうろくばん /登録版/
とうろくばんごう /登録番号/
とうろくひ /登録費/
とうろくひょう /登録票/登録表/
とうろくび /登録日/
とうろくへんこう /登録変更/
とうろくほうほう /登録方法/
とうろくぼ /登録簿/
とうろくまえ /登録前/
とうろくまっしょう /登録抹消/
とうろくむりょう /登録無料/
とうろくめい /登録名/
とうろくめいぼ /登録名簿/
とうろくめんきょぜい /登録免許税/
とうろくもうしこみようし /登録申込用紙/
とうろくよう /登録用/
とうろくようきゅう /登録要求/
とうろくりつ /登録率/
とうろくりょう /登録料/
とうろん /討論/闘論/
とうろんかい /討論会/
とうろんけいしき /討論形式/
とうろんしゃ /討論者/
とうろんないよう /討論内容/
とうろんばんぐみ /討論番組/
とうわ /東和/十和/東倭/藤和/
とうわく /当惑/
とえ /十重/
とえい /都営/渡英/
とえいあさくさせん /都営浅草線/
とえいこうつう /都営交通/
とえいしゃ /都営車/
とえいしんじゅくせん /都営新宿線/
とえいせん /都営線/
とえいせんない /都営線内/
とえいちかてつ /都営地下鉄/
とえいばす /都営バス/
とえいみたせん /都営三田線/
とえはたえ /十重二十重/
とお /十/遠/通/
とおあさ /遠浅/
とおあるき /遠歩き/
とおい /遠井/
とおう /渡欧/
とおえん /遠縁/
とおか /十日/10日/
とおかいち /十日市/
とおかいちば /十日市場;横浜の地名/
とおかえびす /十日戎/
とおかった /遠刈田/
とおかまち /十日町/
とおかや /十日夜;=とおかんや/
とおからず /遠からず/
とおかんや /十日夜;10.10の神事/
とおがった /遠刈田/
とおく /遠く/
とおさぶらい /遠侍/
とおし /通し/
とおしきょうげん /通し狂言/
とおしけん /通し券/
とおしばしら /通し柱/
とおしばんごう /通し番号/
とおしもの /通し物/
とおしや /通し矢/
とおせんぼ /通せんぼ/
とおせんぼう /通せん坊/
とおぜめ /遠攻め/
とおだ /遠田/
とおちか /遠近/
とおで /遠出/
とおとうみ /遠江/
とおなり /遠鳴り/
とおね /遠音/
とおの /遠野/
とおのものがたり /遠野物語/
とおのり /遠乗り/
とおひと /遠人/
とおび /遠火/
とおぼえ /遠吠え/遠吠/
とおま /遠間/
とおまき /遠巻き/
とおまわし /遠回し/
とおまわり /遠回り/
とおみ /遠見/
とおみづか /遠見塚/
とおめ /遠目/
とおめがね /遠眼鏡/
とおや /遠矢/
とおやま /遠山/
とおやまざくら /遠山桜/
とおり /通り/通/
とおりあめ /通り雨/
とおりいっぺん /通り一遍/
とおりがかり /通り掛かり/
とおりすがり /通りすがり/
とおりそうば /通り相場/
とおりちょう /通町/
とおりな /通り名/
とおりぬけ /通り抜け/
とおりね /通り値/
とおりま /通り魔/
とおりみち /通り道/
とおる /達/徹/理/透/亨/融/享/逹;「達」の異体字/
とおわ /十和/
とおんきごう /ト音記号/
とか /都下/渡河/徒過;むだに時をすごす/
とかい /都会/渡海/
とかいか /都会化/
とかいじん /都会人/
とかいそだち /都会育ち/
とかいっこ /都会っ子/
とかいてき /都会的/
とかいは /都会派/
とかげ /蜥蜴/石竜子/
とかげざ /蜥蜴座;Lacerta(Lac)/
とかしき /渡嘉敷/
とかち /十勝/
とかちがわ /十勝川/
とかちだけ /十勝岳;地名,北海道/
とかちへいや /十勝平野/
とが /咎/科;=咎/図画;猥褻-/利賀;地名,富山/都雅;みやびやか/栂;=つが/
とがい /都外/
とがうち /戸河内/
とがき /ト書/ト書き/
とがくし /戸隠/
とがし /富樫/冨樫;「富」異体字/
とがにん /咎人/
とがのお /栂尾/
とがま /利鎌/
とがみ /戸上/
とがめ /咎め/
とがめだて /咎め立て/
とがり /戸狩/戸苅/
とがりごえ /尖り声/
とがわ /戸川/外川/
とき /時/朱鷺/鴇;=朱鷺/鴾;=鴇/土岐;地名,兵庫県南部/鬨;-の声/斎;寺の食事/刻/晨;鶏が晨を作る/辰/時間;当て字/秋;(大切な時期)/穐;「秋」の異体字/常;人名用/
ときいらい /時以来/
ときいろ /鴇色/
ときえだ /時枝/
ときお /時男/時雄/時夫/時生/登紀夫/時郎/
ときおか /時岡/
ときおり /時折/時おり/
ときかた /解き方/
ときがし /時貸し/
ときがらし /溶き芥子/
ときがり /時借り/
ときがわ /都幾川/
ときぐし /解き櫛/
ときこ /時子/登紀子/時空子/
ときさだ /時貞/
ときざわ /鴇沢;姓/
ときじろう /時次郎/
ときそば /時蕎麦/
ときた /時田/
ときたま /時偶/
ときたまご /溶き卵/溶卵/
ときだ /時田/
ときだいこ /時太鼓;時間を知らせる太鼓/
ときち /十吉/
ときつ /時津/
ときつかぜ /時津風/
ときとう /時任/
ときどき /時々/時時/
ときなし /時無し/
ときならぬ /時ならぬ/
ときに /時に/
ときね /十樹根/
ときのうじがみ /時の氏神;仲裁者/
ときのうん /時の運;勝負は-/
ときのこえ /鬨の声/
ときのひと /時の人;一時的に脚光を浴びている人。focal figure/
ときひろ /時広/時弘;姓/
ときび /斎日;僧侶にごちそう(トキ)する日/
ときぶんかつ /時分割/
ときまさ /常正/
ときもの /解き物/
ときょう /都響;[略語]東京都交響楽団/
ときょうそう /徒競走/
ときよ /時世/
ときよじせつ /時世時節/
ときりょう /斎料/
ときわ /常盤/常磐/常葉/
ときわかえで /常磐楓/
ときわぎ /常磐木/
ときわこうえん /常磐公園/
ときわざ /常盤座/
ときわじゅ /常盤樹/
ときわじんじゃ /常磐神社/
ときわず /常磐津/
ときわずぶし /常磐津節;[浄瑠璃]/
ときわだい /常盤台/
ときわまつ /トキワ松/
ときわまつがくえん /トキワ松学園/
ときん /鍍金/と金/頭巾/兜巾/頭襟/
ときんそう /吐金草/
とぎ /都議/伽/富来;地名/研ぎ/砥/
とぎかい /都議会/
とぎし /研ぎ師;grinder/砥師/
とぎじる /磨ぎ汁/
とぎせん /都議選/
とぎつ /時津/
とぎばなし /伽話/伽噺/
とぎまち /富来町/
とぎもの /研ぎ物/
とぎゃく /吐逆/
とぎょ /渡御/蠹魚/
とぎれ /途切れ/跡切れ/
とぎれとぎれ /途切れ途切れ;choppy. 「-のメロディ」/
とぎん /都銀/
とく /得;merit/徳;virture/特/匿;匿名/慝;(隠し立て)/督;監督/禿;禿頭/篤;危篤/悳;「徳」の異体字/涜;冒涜/犢;こうし/黷;(けがす)/牘;(手紙)/読;読本/讀;「読」の旧字/疾く/
とくい /得意;「-科目」/特異;peculiar.「-点」/
とくいがお /得意顔/
とくいきゃく /得意客/
とくいく /徳育/
とくいげ /得意気/
とくいげんしょう /特異現象/
とくいさき /得意先/
とくいせい /特異性/
とくいせきぶん /特異積分/
とくいぜん /得意然/
とくいたいしつ /特異体質/
とくいち /徳一/特異値/
とくいちぶんかい /特異値分解/
とくいてき /特異的/
とくいてん /特異点/
とくいび /特異日/
とくいふとくい /得意不得意/
とくいぶんや /得意分野/
とくいまんめん /得意満面/
とくいわざ /得意技/
とくいんがい /特飲街;[略語]特殊飲食店街/
とくえ /徳衛/
とくえい /徳衛/
とくお /徳雄/徳男/十九夫/
とくおか /徳岡/
とくか /特化/
とくがき /徳垣/
とくがく /篤学;studious/督学;-官/
とくがわ /徳川/
とくがわいえさだ /徳川家定;13th(1853-58)/
とくがわいえしげ /徳川家重;9th(1745-60)/
とくがわいえつぐ /徳川家継;7th(1713-16)/
とくがわいえつな /徳川家綱;4th(1651-80)/
とくがわいえなり /徳川家斉;11th(1787-1837)/
とくがわいえのぶ /徳川家宣;6th(1709-12)/
とくがわいえはる /徳川家治;10th(1760-86)/
とくがわいえみつ /徳川家光;3rd(1623-51)/
とくがわいえもち /徳川家茂;14th(1858-66)/
とくがわいえやす /徳川家康;1st(1603-05)/
とくがわいえよし /徳川家慶;12th(1837-53)/
とくがわき /徳川期/
とくがわけ /徳川家/
とくがわけいき /徳川慶喜;=よしのぶ/
とくがわしょうぐんけ /徳川将軍家/
とくがわじだい /徳川時代;江戸時代/
とくがわつなよし /徳川綱吉;5th(1680-1709),犬公方/
とくがわばくふ /徳川幕府/
とくがわひでただ /徳川秀忠;2nd(1605-23)/
とくがわみつくに /徳川光圀;ええい控えおろう/
とくがわむせい /徳川夢声/
とくがわよしのぶ /徳川慶喜;15th(1866-67)/
とくがわよしむね /徳川吉宗;8th(1716-45),米将軍/
とくき /特記/
とくきじこう /特記事項/
とくぎ /特技/徳義/
とくぎしん /徳義心/
とくぎょう /得業/徳業/
とくぎょうし /得業士/
とくぐん /督軍/
とくこ /徳子/
とくこう /徳行/特高/
とくごうとうげ /徳本峠;地名,/
とくさ /木賊/
とくさいろ /木賊色/
とくさく /得策/
とくさつ /特撮/
とくさつえいが /特撮映画/
とくさつぎじゅつ /特撮技術/
とくさつしつ /特撮室/
とくさつもの /特撮物/
とくさつよう /特撮用/
とくさぶろう /徳三郎/
とくさわ /徳沢/
とくさん /特産/
とくさんひん /特産品/
とくさんぶつ /特産物/
とくし /篤志/特使/得之/特旨;特別の思し召し/
とくしか /篤志家/
とくしってん /得失点/
とくしってんさ /得失点差/
とくしつ /特質/得失/
とくしつてんさ /得失点差/
とくしま /徳島/
とくしまかん /徳島間/
とくしまくうこう /徳島空港/
とくしまけん /徳島県/
とくしまけんきょう /徳島県境/
とくしまし /徳島市/
とくしません /徳島線/
とくしまだい /徳島大/
とくしまだいがく /徳島大学/
とくしゃ /特赦;[法]特定の〈人物〉の刑罰を赦免/特車/特写/
とくしゃたい /特車隊/
とくしゅ /特殊/特種;†特殊な種類/
とくしゅ> /特殊/
とくしゅいんしょくてん /特殊飲食店/
とくしゅう /特集/
とくしゅうきじ /特集記事/
とくしゅうごう /特集号/
とくしゅうちゅう /特集中/
とくしゅうばんぐみ /特集番組/
とくしゅうらがき /特殊裏書/
とくしゅか /特殊化/
とくしゅかい /特殊解/
とくしゅかんすう /特殊関数/
とくしゅがいしゃ /特殊会社/
とくしゅがっきゅう /特殊学級/
とくしゅがっこう /特殊学校/
とくしゅきごう /特殊記号/
とくしゅきのう /特殊機能/
とくしゅきょういく /特殊教育/
とくしゅぎのう /特殊技能/
とくしゅぎんこう /特殊銀行;special bank/
とくしゅくうかん /特殊空間/
とくしゅけい /特殊形/
とくしゅけいしき /特殊形式/
とくしゅけいじょう /特殊形状/
とくしゅこう /特殊鋼/
とくしゅこうか /特殊効果/
とくしゅこうぎ /特殊講義/
とくしゅこうぐ /特殊工具/
とくしゅこうげき /特殊攻撃/
とくしゅさいせい /特殊再生/
とくしゅさいのう /特殊才能/
とくしゅさつえい /特殊撮影/
とくしゅしゃ /特殊車/
とくしゅしゃりょう /特殊車両/
とくしゅじじょう /特殊事情/
とくしゅじどうしゃ /特殊自動車/特種自動車;?/
とくしゅせい /特殊性/
とくしゅそうたいろん /特殊相対論/
とくしゅつ /特出/
とくしゅのうりょく /特殊能力/
とくしゅはいれつ /特殊配列/
とくしゅぶき /特殊武器/
とくしゅぶたい /特殊部隊/
とくしゅぶつ /特殊物/
とくしゅぶらく /特殊部落/
とくしゅへいき /特殊兵器/
とくしゅへんすう /特殊変数/
とくしゅほうじん /特殊法人/
とくしゅほそう /特殊舗装/
とくしゅむせんぎし /特殊無線技師/
とくしゅもくてき /特殊目的/
とくしゅもじ /特殊文字/
とくしゅようと /特殊用途/特種用途;?/
とくしゅよくじょう /特殊浴場/
とくしゅれい /特殊例/
とくしょ /特書/
とくしょう /特賞/特称;⇔全称/∃/
とくしょく /特色/涜職/
とくしん /特進/得心/篤信/涜神/得真/
とくじ /徳治;年号(1306-1308)/徳次/徳地/
とくじつ /篤実/
とくじゅ /特需/
とくじゅけいき /特需景気/
とくじょう /特上/
とくじろう /徳次郎/
とくじん /徳人/
とくずき /特漉き/
とくせい /特性;attribute.「光学-」/特製;specially made.「-ケーキ」/徳性;virtue/徳政;-令/徳星;(木星)/涜聖/
とくせいきょくせん /特性曲線/
とくせいさ /特性差/
とくせいすうち /特性数値/
とくせいち /特性値/
とくせいてき /特性的/
とくせいひょう /特性表/
とくせいひん /特製品/
とくせいびょう /特性病/
とくせいれい /徳政令/
とくせいれっか /特性劣化/
とくせつ /特設/
とくせつかいじょう /特設会場/
とくせん /特選/特撰/特薦/督戦/特専/
とくせんがい /特選街/
とくせんたい /特戦隊/
とくせんひん /特選品/
とくそう /特捜;特別捜査/得喪/特装/徳宗/得宗/徳操/禿瘡/
とくそうけいじ /特捜刑事/
とくそうたい /特捜隊/
とくそうぶ /特捜部/
とくそく /督促/
とくそくじょう /督促状/
とくそくてつづき /督促手続/
とくそほう /特措法;[略語]特別措置法/
とくそん /特損;[略語]特別損失/
とくぞう /徳蔵/
とくたい /特待/
とくたいせい /特待生/
とくたろう /徳太郎/
とくだ /徳田/得田/
とくだい /特大/
とくだいごう /特大号/
とくだいじ /徳大寺/
とくだしゅうせい /徳田秋声/
とくだつ /得脱/
とくだね /特ダネ/特種/
とくだわら /徳俵;[相撲]/
とくだん /特段/
とくち /渡久地;姓/
とくちしゅぎ /徳治主義/
とくちゅう /特注/
とくちゅうひん /特注品/
とくちょう /特徴;characteristics/特長;advantage/
とくちょういちらん /特徴一覧/
とくちょうか /特徴化/
とくちょうがくしゅう /特徴学習/
とくちょうくうかん /特徴空間/
とくちょうしゅうはすう /特徴周波数/
とくちょうちゅうしゅつ /特徴抽出/
とくちょうづけ /特徴付け/
とくちょうてき /特徴的/
とくちょうてききのう /特徴的機能/
とくちょうてん /特徴点/
とくちょうぶつ /特徴物/
とくちょうめん /特徴面/
とくちょうりょう /特徴量/
とくてい /特定/
とくていいぞう /特定遺贈/
とくていうんちん /特定運賃/
とくていか /特定化/
とくていきのうびょういん /特定機能病院/
とくていきゅうだん /特定球団/
とくていきょく /特定局;特定郵便局/
とくていきんせんしんたく /特定金銭信託/
とくていくかん /特定区間/
とくていけんせつぎょう /特定建設業/
とくていこうざ /特定口座/
とくていこじん /特定個人/
とくていざいげん /特定財源/
とくていざいさん /特定財産/
とくていしせつ /特定施設;[法]汚染源等として政令で定められた施設. cf.大気汚染17,水質汚濁2/
とくていしっそうしゃ /特定失踪者/
とくていしゃりょう /特定車両/
とくていしょうけい /特定承継/
とくていしょうすう /特定少数/
とくていしょうでんりょく /特定小電力/
とくていじんぶつ /特定人物/
とくていせつび /特定設備/
とくていせんしゅ /特定選手/
とくていたすう /特定多数/
とくていち /特定値/
とくていちいき /特定地域/
とくていちいきがい /特定地域外/
とくていちょうていほう /特定調停法;[法][略語]特定債務等の調整の促進のための特定調停に関する法律/
とくていひえいりかつどうそくしんほう /特定非営利活動促進法/
とくていひえいりかつどうほうじん /特定非営利活動法人;specified NPO. (特)/
とくていふのう /特定不能/
とくていぶつ /特定物/
とくていぶぶん /特定部分/
とくていぶんや /特定分野/
とくていほけんようしょくひん /特定保健用食品/
とくていもくてき /特定目的/
とくていもくてきがいしゃ /特定目的会社/
とくていゆうびんきょく /特定郵便局/
とくていようと /特定用途/
とくていわしゃ /特定話者/
とくてん /特典/得点/特点;singularity/
とくてんおう /得点王/
とくてんき /得点機/
とくてんけいか /得点経過/
とくてんけいさん /得点計算/
とくてんけん /得点圏;[野球]二塁または三塁/
とくてんけんだりつ /得点圏打率/
とくてんげん /得点源/
とくてんこうくうけん /特典航空券/
とくてんさ /得点差/
とくてんしゃ /得点者/
とくてんすう /得点数/
とくてんちゅう /得点中/
とくてんつき /得点付/
とくてんはいぶん /得点配分/
とくてんはんい /得点範囲/
とくてんばめん /得点場面/
とくてんひょう /得点表/
とくてんぶんぷ /得点分布/
とくてんほうほう /得点方法/
とくてんりつ /得点率/
とくてんりょく /得点力/
とくてんりょこう /特典旅行/
とくでん /特電/
とくとう /特等/禿頭/
とくとうせき /特等席/
とくとく /得々/得得/
とくとみ /徳富/徳冨;「富」異体字/
とくとみろか /徳冨蘆花;(1868-1927) 作家。『不如帰』/
とくど /得度/
とくどう /得道/
とくない /都区内/
とくなが /徳永/
とくに /特に/
とくにん /特任;特別に任命/特認;特別に承認/
とくのう /特濃/篤農/
とくのうか /篤農家/
とくのしま /徳之島/
とくは /特派/
とくはい /特配/
とくはいん /特派員/
とくはいんほうこく /特派員報告/
とくはし /徳橋/
とくはつ /特発/禿髪/
とくはつせい /特発性/
とくはら /徳原/
とくばい /特売/
とくばいび /特売日/
とくばん /特番/
とくひさ /徳久/
とくひつ /特筆/
とくひつたいしょ /特筆大書/
とくひょう /得票/
とくひょうさ /得票差/
とくひょうじゅんい /得票順位/
とくひょうすう /得票数/
とくひょうりつ /得票率/
とくひら /徳平/
とくひろ /徳弘/
とくぶん /得分/
とくへい /徳平/
とくべつ /特別/
とくべつ> /特別/
とくべつあつかい /特別扱い/
とくべつい /特別委;特別委員会/
とくべついいんかい /特別委員会/
とくべついにん /特別委任/
とくべつうんちん /特別運賃/
とくべつえんそうかい /特別演奏会/
とくべつか /特別化/
とくべつかいいん /特別会員/
とくべつかいけい /特別会計/
とくべつかいじょう /特別会場/
とくべつかいそく /特別快速/
とくべつかいひ /特別会費/
とくべつかかく /特別価格/
とくべつかんらんせき /特別観覧席/
とくべつき /特別機/
とくべつきかく /特別企画/
とくべつきてい /特別規定/
とくべつきゅうか /特別休暇/
とくべつきゅうこう /特別急行/
とくべつきゅうこうれっしゃ /特別急行列車/
とくべつきょうしつ /特別教室;理科室・音楽室など/
とくべつきょうしょ /特別教書/
とくべつきょうそう /特別競走/特別競争/
とくべつきょうてい /特別協定/
とくべつく /特別区/
とくべつくいき /特別区域/
とくべつくかん /特別区間/
とくべつけつぎ /特別決議/
とくべつけんきゅう /特別研究/
とくべつけんきゅういん /特別研究員/
とくべつけんきゅうがくせい /特別研究学生/
とくべつけんきゅうしつ /特別研究室/
とくべつこうあつ /特別高圧;[電設]7000V超/
とくべつこうえん /特別講演/
とくべつこうえんかい /特別講演会/
とくべつこうぎ /特別講義/
とくべつこうげきたい /特別攻撃隊/
とくべつこうこく /特別抗告/
とくべつこうてきかんり /特別公的管理/
とくべつこうとうけいさつ /特別高等警察/
とくべつこうろうしょう /特別功労賞/
とくべつこっかい /特別国会/
とくべつこんなん /特別困難/
とくべつごう /特別号/
とくべつさいばんしょ /特別裁判所/
とくべつさんか /特別参加/
とくべつし /特別視/
とくべつしつ /特別室/
とくべつしてい /特別指定/
とくべつしていせき /特別指定席/
とくべつしゃりょう /特別車両/
とくべつしゅつえん /特別出演/
とくべつしょう /特別賞/
とくべつしょうきゃく /特別償却;special depreciation/
とくべつしょく /特別職/特別食/特別色/
とくべつしょち /特別処置/
とくべつしようしゃ /特別仕様車/
とくべつじあい /特別試合/
とくべつじょうこく /特別上告/
とくべつすいしんけんきゅう /特別推進研究/
とくべつせい /特別製/
とくべつせき /特別席/
とくべつせつびひ /特別設備費/
とくべつせん /特別戦/
とくべつせんしつ /特別船室/
とくべつせんばつ /特別選抜/
とくべつそち /特別措置/
とくべつそちほう /特別措置法/
とくべつそんしつ /特別損失/
とくべつたいぐう /特別待遇/
とくべつたんぽ /特別担保/
とくべつちゅうもん /特別注文/
とくべつてあて /特別手当/
とくべつてん /特別展/
とくべつてんねんきねんぶつ /特別天然記念物/
とくべつとそう /特別塗装/
とくべつはいとう /特別配当/
とくべつはいにん /特別背任/
とくべつはいにんざい /特別背任罪/
とくべつはんぷ /特別頒布/
とくべつばん /特別版/特別盤/
とくべつばんぐみ /特別番組/
とくべつふろく /特別付録/
とくべつへん /特別編/
とくべつへんしゅう /特別編集/
とくべつべんごにん /特別弁護人/
とくべつほう /特別法/
とくべつほうこく /特別報告/
とくべつもくてきがいしゃ /特別目的会社/
とくべつようごろうじんほーむ /特別養護老人ホーム/
とくべつようしえんぐみ /特別養子縁組/
とくべつようとしょくひん /特別用途食品/
とくべつよさん /特別予算/
とくべつりえき /特別利益/
とくべつりょうきん /特別料金/
とくべつりょうきんふよう /特別料金不要/
とくべつりょうり /特別料理/
とくべつれいかい /特別例会/
とくべつわく /特別枠/
とくべつわりびき /特別割引/
とくほう /特報/
とくほん /読本/
とくぼう /徳望/
とくま /徳間/
とくましょてん /徳間書店/
とくまぶんこ /徳間文庫/
とくまる /徳丸/得丸/
とくみ /徳美/徳見/
とくみち /篤道/
とくみつ /徳光/
とくむ /特務/
とくむかん /特務艦/
とくむきかん /特務機関/
とくむしかん /特務士官/
とくむそうちょう /特務曹長/
とくめい /匿名/特命/
とくめいか /匿名化/
とくめいきぼう /匿名希望/
とくめいくみあい /匿名組合/
とくめいせい /匿名性/
とくめいとうこう /匿名投稿/
とくめいとうしょ /匿名投書/
とくめいほうしき /匿名方式/
とくもく /徳目/
とくもと /徳本/徳元/
とくもり /特盛/
とくやく /特約/
とくやくてん /特約店/
とくやす /徳康/
とくやま /徳山/
とくやまこうせん /徳山高専/
とくやまし /徳山市/
とくやまそーだ /徳山曹達/
とくゆう /特有/特融;特別融資/
とくゆうざいさん /特有財産/
とくゆき /徳行/得之/
とくよう /徳用/特養;[略語]特別養護(老人ホーム)/特用;special use/
とくようひん /徳用品/
とくようぶくろ /徳用袋/
とくら /戸倉/十倉/都倉/
とくり /徳利/
とくりつ /特立/
とくれい /特例/督励/
とくれいくかん /特例区間/
とくれいし /特例市;NB:人口20万人以上 (<地方自治法)/
とくれいそち /特例措置/
とくれいてき /特例的/
とくれいほう /特例法/
とくろん /特論/
とくわり /特割/
とぐち /戸口/
とぐら /戸倉/
とぐろ /蜷局/塒;-を巻く/
とけ /土気/
とけい /時計/徒刑/土圭;=時計 NB:「時計」は当て字/都計;[略語]都市計画/
とけいかん /時計館/
とけいきのう /時計機能/
とけいざ /時計座;Horologium(Hor)/
とけいざら /時計皿;実験用具/
とけいしょうぶ /時計勝負/
とけいじかけ /時計仕掛/
とけいぜんたい /時計全体/
とけいそう /時計草/
とけいだい /時計台/
とけいつき /時計付/
とけいてん /時計店/
とけいとう /時計塔/
とけいないぞう /時計内蔵/
とけいほうこう /時計方向/
とけいまわり /時計回り/
とけいや /時計屋/
とけつ /吐血/
とけん /都県/覩見/
とけんどう /都県道/
とげ /棘/刺/朿/
とげうお /棘魚/
とげっぽう /吐月峰/
とげつきょう /渡月橋;京都嵐山/
とげぬき /刺抜き/
とげぬきじぞう /刺抜き地蔵;巣鴨/
とこ /床/常/
とこ> /常;常夏,常若,常花/
とこあげ /床上げ/
とこい /常井/
とこいた /床板/
とこいり /床入り;bed-in/
とこう /渡航/都甲/
とこうさき /渡航先/
とこうし /塗工紙/
とこうしゃ /渡航者/
とこうじょうほう /渡航情報/
とこうひ /渡航費/
とこがまち /床框/
とこし /戸越/
とこしえ /永久;forever/常しえ;forever/
とこしえき /戸越駅/
とこしき /床敷/
とこしぎんざ /戸越銀座/
とこしこうえん /戸越公園/
とこじょうず /床上手/
とこずれ /床擦れ/
とこだたみ /床畳/
とこつち /床土/
とこなつ /常夏/
とこなめ /常滑/
とこなめせん /常滑線/
とこなめやき /常滑焼/
とこのま /床の間/床ノ間/
とこは /常葉/
とこはる /常春/
とこばしら /床柱/
とこばなれ /床離れ/
とこばらい /床払い/
とこぶし /常節/
とこみせ /床見世/床店/
とこや /床屋/
とこやだんぎ /床屋談義/
とこやま /床山/
とこやみ /常闇/
とこよ /常世/常夜/
ところ /所/処/處/野老/
ところが /処が/
ところがき /所書/
ところがら /所柄/
ところことば /所言葉/
ところざわ /所沢/
ところざわし /所沢市/
ところてん /心太/瓊脂/
ところてんぐさ /心太草/
ところてんしき /心太式/
ところどころ /所々/
ところばらい /所払い/
ところばんち /所番地;地名・番地/
とこわか /常若/
とこん /吐根;[植物]ipecac/
とごう /渡豪/戸郷/
とさ /土佐/
とさいぬ /土佐犬/
とさえ /土佐絵/
とさか /鶏冠/戸坂/
とさかのり /鶏冠海苔/
とさけん /土佐犬/
とさしみず /土佐清水/
とさず /土佐酢/
とさっこ /土佐っ子/
とさつ /屠殺/塗擦/
とさつじょう /屠殺場/
とさづくり /土佐造り;[料理]鰹のタタキ/土佐作り/
とさでんてつ /土佐電鉄/
とさに /土佐煮/
とさにっき /土佐日記;紀貫之/土左日記;=土佐日記/
とさぶし /土佐節;[浄瑠璃]/
とさべん /土佐弁/
とさやま /土佐山/
とさやまだ /土佐山田/
とさんせん /土讃線/
とざい /塗材/吐剤/
とざき /戸崎/
とざと /外里/
とざま /外様/
とざまだいみょう /外様大名/
とざわ /戸沢/
とざん /登山/
とざんあんない /登山案内/
とざんかいし /登山開始/
とざんき /登山記/
とざんきち /登山基地/
とざんきゃく /登山客/
とざんきょうそう /登山競争/
とざんぐち /登山口/
とざんぐつ /登山靴/
とざんしゃ /登山者/
とざんそうび /登山装備/
とざんてつどう /登山鉄道/
とざんでんしゃ /登山電車/
とざんどう /登山道/
とし /年/歳/都市/徒死/利/俊/寿/捷/稔/暁/世/繁/壽/祀/夙/駿/肇/敏/
としあき /俊明/利明/敏明/俊昭/利昭/敏昭/寿明/俊彰/俊章/聡明/俊朗/敏朗/敏彰/年昭/繁明/
としあけ /年明け/
としうえ /年上/
としうら /年占/
としえ /敏江/季衣/とし恵/俊恵/敏枝/利絵/
としお /敏夫/俊夫/俊雄/敏雄/利夫/敏男/利雄/俊男/利男/敏郎/登志夫/寿夫/寿雄/寿男/利生/淑夫/俊朗/利朗/稔雄/
としおとこ /年男/
としおんな /年女/
としか /都市化/
としかいはつ /都市開発/
としかさ /年嵩/
としかず /俊一/利一/俊和/敏和/寿一/敏一/利和/寿和/
としかっこう /年格好/年恰好/
としかつ /利勝/敏克/
としかん /都市間/
としかんいどう /都市間移動/
としかんきょう /都市環境/
としかんてつどう /都市間鉄道/
としかんゆそう /都市間輸送/
としかんれんらく /都市間連絡/
としがい /年甲斐/都市外/
としがす /都市ガス/
としがた /都市型/
としき /俊樹/敏樹/敏生/年樹/稔貴/年紀/歳樹/戸敷/
としきのう /都市機能/
としきばん /都市基盤/
としきんこう /都市近郊/
としぎんこう /都市銀行/
としくうかん /都市空間/
としくに /年邦/
としくれ /年暮れ/
としけいかく /都市計画/
としけいかくぜい /都市計画税/
としけいかくどうろ /都市計画道路/
としけいかくほう /都市計画法/
としけん /都市圏/
としこ /敏子/俊子/淑子/利子/寿子/とし子/登志子/トシ子/年子/
としこうがく /都市工学/
としこうそく /都市高速/
としこうぞう /都市構造/
としこうつう /都市交通/
としこうつうねんぽう /都市交通年報/
としこし /年越し/
としこっか /都市国家/
としご /年子/
としごいのまつり /祈年祭/
としごと /年毎/
としごもり /年籠り/
としごろ /年頃/
としさいかいはつほう /都市再開発法/
とししげ /利重/
とししせつ /都市施設;<都市計画法11/
としした /年下/
とししゃかいがく /都市社会学;urban sociology/
とししゅうゆう /都市周遊/
としじ /俊治/
としせいび /都市整備/
としそうおう /年相応/
としぞう /俊三/
としたいこう /都市対抗/
としたいこうやきゅう /都市対抗野球/
としたか /敏隆/俊孝/利孝/
としただ /利忠/俊匡/
としたに /利谷/
としだか /年高/
としだま /年玉;お年玉/
としちず /都市地図/
としつき /年月/
としつぐ /敏嗣/俊嗣/壽二/
としづよ /年強/
としてつどう /都市鉄道/
としてる /敏輝/
としでんせつ /都市伝説/
としとりざかな /年取り魚/
としない /都市内/
としなお /俊直/利直/
としなか /年中/年半/
としなみ /年波/
としなり /利成/
としのうち /年の内/
としのこう /年の功/
としのころ /年の頃/
としのせ /年の瀬/歳の瀬/
としのは /年の端/
としのぶ /利信/利伸/敏伸/
としのよ /年の夜/
としのり /俊則/敏則/利則/敏憲/俊範/利典/聡徳/寿則/年紀/敏規/
としは /年端;「―も行かぬ少年」/
としはる /利治/俊治/敏治/寿晴/季栄/
としひこ /俊彦/敏彦/利彦/寿彦/稔彦/壽彦/年彦/捷彦/
としひさ /俊久/利久/敏寿/
としひで /俊英/俊秀/
としひと /敏仁/
としひろ /敏弘/俊博/俊弘/俊宏/敏宏/利博/利弘/俊裕/利広/利宏/敏裕/俊浩/利浩/敏啓/歳弘/
としふさ /俊房/
としふみ /敏文/俊文/俊史/年史/
としぶ /都市部/
としぶんか /都市文化/
としほど /年程/
としま /豊島/年増/利島/十島/戸島/戸嶋/
としまえん /豊島園/
としまおか /豊島岡/
としまおかじょしがくえん /豊島岡女子学園/
としまく /豊島区/
としまさ /敏正/
としまわり /年回り/
としみ /利美/寿実/年美/敏巳/都志見/
としみち /利通/俊道/利道/季道/
としみつ /利光/俊光/敏光/
としめい /都市名/
としゃ /吐瀉/
としゃぶつ /吐瀉物/
としや /俊哉/俊也/敏也/敏哉/俊弥/利也/
としやす /利泰/敏康/敏靖/
としゅ /徒手/斗酒/
としゅくうけん /徒手空拳/
としゅつ /吐出/
としゅつりょう /吐出量/
としゆき /俊之/敏之/敏行/利幸/俊幸/敏幸/俊行/利之/利行/歳之/
としょ /図書/屠所/
としょう /渡渉/杜松/
としょうじつ /杜松実/
としょかーど /図書カード/
としょかかり /図書掛/
としょかん /図書館/
としょかんいん /図書館員/
としょかんがく /図書館学/
としょかんしりょう /図書館資料/
としょかんじょうほうがく /図書館情報学/
としょかんじょうほうだい /図書館情報大/
としょかんじょうほうだいがく /図書館情報大学/
としょかんだい /図書館大/
としょかんほう /図書館法;(学校-,国立国会-)/
としょかんまえ /図書館前/
としょかんれんじょうほう /図書関連情報/
としょがく /図書学/
としょきょく /図書局/
としょく /塗色/徒食/
としょけん /図書券/
としょけんさく /図書検索/
としょしつ /図書室/
としょしゅっぱん /図書出版/
としょしりょうしつ /図書資料室/
としょしんぶん /図書新聞/
としょひ /図書費/
としょぶもん /図書部門/
としょぶんかん /図書分館/
としょもくろく /図書目録/
としょりょう /図書寮;[律令制]/
としよ /敏代/
としより /年寄/年寄り/
としよりかぶ /年寄株/
としよわ /年弱/
としろう /敏郎/俊郎/俊朗/利郎/
としわか /年若/
としわすれ /年忘れ/
としわり /年割/年割り/
としん /都心/妬心/兎唇;みつくち/
としんかん /都心間/
としんがわ /都心側/
としんち /都心地/
としんちく /都心地区/
としんない /都心内/
としんぶ /都心部/
としんほうこう /都心方向/
とじ /綴/綴じ/賭事/杜氏/途次/刀自/徒事/徒爾/
とじいと /綴じ糸/
とじかっこ /閉括弧/
とじき /戸敷/
とじこみ /綴じ込み/
とじしろ /綴じ代/
とじぶた /綴じ蓋;破れ鍋に-/
とじほん /綴本/
とじま /戸島/
とじまり /戸締り/
とじめ /綴じ目/
とじょう /途上/都城/登城/外城/屠場/図情;[略語][固有名詞]図書館情報(大学)/
とじょうこく /途上国/
とじょうだい /図情大/
とじょうれい /都条例/
とじん /都人/都塵/
とす /鳥栖/
とすし /鳥栖市/
とせ /歳/
とせい /渡世/都政/
とせいにん /渡世人/
とせん /渡船/
とせんば /渡船場/
とぜい /都税/
とぜつ /途絶/杜絶/
とぜん /徒然/
とぜんいき /都全域/
とそ /屠蘇/
とそう /塗装/
とそうかんりょうご /塗装完了後/
とそうき /塗装機/
とそうぎょう /塗装業/
とそうこう /塗装工/
とそうご /塗装後/
とそうしじ /塗装指示/
とそうずみ /塗装済/
とそうはば /塗装幅/
とそうぶ /塗装部/
とそうへんこう /塗装変更/
とそうまえ /塗装前/
とそうめん /塗装面/
とそうめんせき /塗装面積/
とそきげん /屠蘇機嫌/
とそさん /屠蘇散/
とそしゅ /屠蘇酒/
とそつ /兜率/
とそつてん /兜率天/
とそぶくろ /屠蘇袋/
とたん /途端/塗炭/
とたんちょう /ト短調/
とたんのくるしみ /塗炭の苦しみ/
とたんぶき /トタン葺き;tin-roofed/
とたんやね /トタン屋根/
とだ /戸田/
とだい /都大/東京都立大学;※abbrev/
とだか /戸高/
とだし /戸田市/
とだせいじ /戸田誠司/
とだな /戸棚/
とち /土地/橡;buckeye/栃;「橡」の国字/杤;=栃/柮;(呉音)切り株/
とちお /栃尾/
とちかいりょうく /土地改良区/
とちかいりょうほう /土地改良法/
とちかおく /土地家屋/
とちかおくちょうさし /土地家屋調査士/
とちかがみもく /トチカガミ目/Hydrocharitales/
とちかわ /橡川/
とちかん /土地勘/土地鑑;=土地勘/
とちかんかつ /土地管轄/
とちがら /土地柄/
とちぎ /栃木/朽木/
とちぎけん /栃木県/
とちぎけんじん /栃木県人/
とちぎけんない /栃木県内/
とちぎし /栃木市/
とちぎべん /栃木弁/
とちぎょうせい /土地行政/
とちく /屠畜/
とちくかくせいりほう /土地区画整理法/
とちくじょう /屠畜場/
とちことば /土地言葉/
とちざわ /栃沢;姓/
とちしゅうよう /土地収用/
とちしゅうようほう /土地収用法/
とちしょゆうけん /土地所有権/
とちしようけん /土地使用権/
とちじ /都知事/
とちじせん /都知事選/
とちたいさく /土地対策/
とちだい /土地代/
とちだいちょう /土地台帳/
とちっこ /土地っ子/
とちない /栃内/
とちのき /橡/栃/
とちのわか /栃乃和歌/
とちばいしゅう /土地買収/
とちほゆうぜい /土地保有税/
とちほんいせい /土地本位制/
とちぼっしゅう /土地没収/
とちめん /栃麺/
とちめんぼう /栃麺棒/
とちもと /栃本/
とちもんだい /土地問題/
とちゅう /途中/杜仲;-茶/
とちゅうえき /途中駅/
とちゅうきけん /途中棄権/
とちゅうきゅうけい /途中休憩/
とちゅうけいか /途中経過/
とちゅうけいろ /途中経路/
とちゅうげしゃ /途中下車/
とちゅうげしゃいん /途中下車印/
とちゅうこうき /途中降機/
とちゅうこうたい /途中交代/
とちゅうさんか /途中参加/
とちゅうしゅつじょう /途中出場/
とちゅうしょうりゃく /途中省略/
とちゅうず /途中図/
とちゅうたいじょう /途中退場/
とちゅうだんかい /途中段階/
とちゅうちゃ /杜仲茶/
とちゅうていしゃ /途中停車/
とちゅうりゃく /途中略/
とちょう /都庁/登頂/徒長;[園芸](根や枝など)無駄に長く伸びる/
とちょういてん /都庁移転/
とちょうし /徒長枝;[園芸]無駄に長く伸びた枝/
とちょうちょう /ト長調/
とちりよう /土地利用/
とちりようけいかく /土地利用計画/
とちりれき /土地履歴/
とちわかじだい /栃若時代/
とっか /特価;bargain/特化;specialise/特科;artillery,砲兵/徳化;civilise/
とっかい /特快;†[略語]特別快速/特会;†[略語]特別会計/特解;[数学]particular solution/
とっかえひっかえ /取っ替え引っ替え/
とっかかり /取っ掛かり/取っ掛り/
とっかがた /特化型/
とっかく /突角/凸角/
とっかてき /特化的/
とっかひん /特価品/
とっかん /突貫/吶喊/
とっかんこうじ /突貫工事/
とっき /特記/突起/特機/特器/
とっきじこう /特記事項/
とっきたい /突起体/
とっきぶつ /突起物/
とっきゅう /特急/特級/
とっきゅういがい /特急以外/
とっきゅうか /特急化/
とっきゅうがた /特急型/
とっきゅうがたしゃりょう /特急型車両/
とっきゅうがたでんしゃ /特急型電車/
とっきゅうけん /特急券/
とっきゅうしゃ /特急車/
とっきゅうしゃりょう /特急車両/
とっきゅうしゅ /特級酒/
とっきゅうしょく /特急色/
とっきゅうつうかまち /特急通過待ち/
とっきゅうでんしゃ /特急電車/
とっきゅうはくちょう /特急白鳥/
とっきゅうほうしき /特急方式/
とっきゅうよう /特急用/
とっきゅうようしゃりょう /特急用車両/
とっきゅうりょうきん /特急料金/
とっきゅうれっしゃ /特急列車/
とっきょ /特許/
とっきょう /徳教/
とっきょか /特許化/特許課/
とっきょかんけい /特許関係/
とっきょきょく /特許局/
とっきょけん /特許権/
とっきょげんぼ /特許原簿/
とっきょこうほう /特許公報/
とっきょしゅつがん /特許出願/
とっきょしゅつがんちゅう /特許出願中/
とっきょしょう /特許証/
とっきょしりょう /特許資料/
とっきょしんがい /特許侵害/
とっきょしんせい /特許申請/
とっきょじむしょ /特許事務所/
とっきょせいど /特許制度/
とっきょせんりゃく /特許戦略/
とっきょちょう /特許庁/
とっきょちょうさ /特許調査/
とっきょとうろく /特許登録/
とっきょないよう /特許内容/
とっきょひん /特許品/
とっきょほう /特許法/
とっきょもんだい /特許問題/
とっきょりょう /特許料/
とっきん /特金;[略語]特定金銭信託/
とっく /特区;[略語]特別区/疾っく/疾く/
とっくみあい /取っ組み合い/
とっくり /徳利/
とっくん /特訓/
とっくんちゅう /特訓中/
とっけい /特恵/
とっけつ /突厥/
とっけつもじ /突厥文字/
とっけん /特権/特研/
とっけんかいきゅう /特権階級/
とっけんてき /特権的/
とっこ /独鈷/
とっこう /特攻;[略語]特別攻撃。「-隊」/特効;「-薬」/特講;[略語]特別講義/徳行;morality/特高;[略語]特別高等警察/篤行;humane act/
とっこうき /特攻機/
とっこうたい /特攻隊/
とっこうだいさくせん /特攻大作戦/
とっこうやく /特効薬/
とっこうやろう /特攻野郎/
とっこつ /突兀/
とっさ /咄嗟/
とっしゅつ /突出/
とっしん /突進/
とっしんりょく /突進力/
とっしんわざ /突進技/
とったん /突端/
とって /取っ手/把手/取手/把っ手/
とってい /突堤/
とっておき /取って置き/
とっとり /鳥取/
とっとりかん /鳥取間/
とっとりけん /鳥取県/
とっとりさきゅう /鳥取砂丘/
とっとりし /鳥取市/
とっとりだい /鳥取大/
とっとりだいがく /鳥取大学/
とっぱ /突破/鳥羽/
とっぱこう /突破口/
とっぱつ /突発/
とっぱつげんしょう /突発現象/
とっぱつしん /突発疹/
とっぱつせい /突発性/
とっぱつせいなんちょう /突発性難聴;[医]sudden deafness/
とっぱつせいはっしん /突発性発疹/
とっぱつてき /突発的/
とっぱほうほう /突破方法/
とっぱりょく /突破力/
とっぱん /凸版/
とっぱんいんさつ /凸版印刷/
とっぴ /突飛/
とっぴょうし /突拍子/
とっぷ# /トップ#0/
とっぷう /突風/
とっぷかいだん /トップ会談;summit meeting/
とっぷきじ /トップ記事/
とっぷきゅう /トップ級/
とっぷした /トップ下/
とっぷしょう /トップ賞/
とっぷつ /突沸/
とっぷてん /トップ10/
とつ /突/凸/咄;咄嗟/柮;(切り株)/吶;吶々(=訥々)/訥;朴訥/
とつおう /凸凹/
とつか /戸塚/
とつかえき /戸塚駅/
とつかく /戸塚区/凸角/
とつかくみん /戸塚区民/
とつかわ /十津川/
とつかんすう /凸関数/
とつがた /凸型/
とつがたでんき /凸型電機;[企業名]/
とつがわ /十津川/
とつきとうか /十月十日/
とつきとおか /十月十日/
とつぎさき /嫁ぎ先/
とつくに /外つ国/
とつけつごう /凸結合/
とつげき /突撃/突激/
とつげきたい /突撃隊/
とつごう /突合/
とつじょ /突如/
とつじょしゅつげん /突如出現/
とつぜん /突然/
とつぜんいんたい /突然引退/
とつぜんし /突然死/
とつぜんへんい /突然変異/
とつでん /凸電/
とつとつ /訥々;口籠る様子/咄々;舌打ちの音/吶々;≒訥々/訥訥/
とつとつかいじ /咄咄怪事/咄々怪事/
とつにゅう /突入/
とつにゅうぐち /突入口/
とつへいほう /凸閉包/
とつべん /訥弁/
とつほう /凸包/
とつめん /凸面/
とつめんきょう /凸面鏡/
とつれんず /凸レンズ;convex lens/
とづか /戸塚/
とてい /徒弟/
とていせい /徒弟制/
とてつ /途轍;―も無い/
とても /迚も/迚/
とでん /都電/
ととう /渡島/徒党/渡唐/渡頭/
ととき /十時/
ととく /都督/
ととくふ /都督府/
ととさま /父様/
ととや /魚屋;高麗茶碗の一種/
ととやのちゃわん /魚屋茶碗/
ととりべ /鳥取部;鳥をつかまえる昔の職業/
とど /椴/
とどう /都道/
とどうふけん /都道府県/
とどうふけんぎかい /都道府県議会/
とどうふけんごと /都道府県毎/
とどうふけんざかい /都道府県境/
とどうふけんじちたい /都道府県自治体/
とどうふけんじょうれい /都道府県条例/
とどうふけんちじ /都道府県知事/
とどうふけんひ /都道府県費/
とどうふけんべつ /都道府県別/
とどうふけんめい /都道府県名/
とどく /渡独;ドイツ行き/
とどけ /届/届け/屆;旧字/
とどけがき /届書/
とどけさき /届け先/届先/
とどけしょ /届書/
とどけで /届出/届け出/
とどけでぎむ /届出義務/
とどけでじこう /届出事項/
とどけでずみしょう /届出済証/
とどけでせい /届出制/
とどけでにん /届出人/
とどけもの /届け物/
とどこおり /滞り/
とどほっけむら /椴法華村/
とどまつ /椴松/椴/
とどむ /閼/
とどめ /止め/
とどめる /閼/
とどろ /轟/
とどろき /轟き/等々力/轟/軣;異体字/
とどろきおん /轟音/
とどん /吐呑/
とない /都内/
とないきんこう /都内近郊/
とないぼうしょ /都内某所/
となかい /馴鹿/
となき /渡名喜/
となみ /砺波/礪波/外波/渡並/
となり /隣/隣り/鄰;「隣」の異体字/
となりあわせ /隣り合わせ/隣合わせ/
となりきんじょ /隣近所/
となりぐみ /隣組/
となりどうし /隣同士/
となりまち /隣町/
となりむら /隣村/
となん /都南/
とにかく /兎に角;当て字/
とにく /屠肉/
とにち /渡日/
とにもかくにも /兎にも角にも/
とにゅう /吐乳/
とね /利根;地名/刀根/刀禰/
とねがわ /利根川/
とねぐん /利根郡/
とねやま /刀根山/
とねり /舎人/
とねりしんのう /舎人親王;日本書紀/
との /殿/
とのい /宿直/
とのいびと /宿直人/
とのうち /登内/
とのおか /外岡/
とのがた /殿方/
とのこ /砥の粉/砥粉/
とのご /殿御/
とのさき /外崎;姓/
とのさま /殿様/
とのさまがえる /殿様蛙/
とのさましごと /殿様仕事/
とのさましょうばい /殿様商売/
とのさまばった /殿様蝗虫/
とのしょう /土庄/
とのづくり /殿作り/
とのと /殿戸/
とのま /殿馬;姓/
とのみ /富海/
とのも /主殿;-寮,-司/
とのもり /主殿;-寮,-司/
とのもりりょう /主殿寮;[律令制]/
とのやまちょう /殿山町/
とはい /徒輩/
とはいえ /とは言え/
とはん /登攀/登坂/
とはんしゃせん /登坂車線/
とば /鳥羽/賭場/
とばえ /鳥羽絵/
とばえき /鳥羽駅/
とばく /賭博/
とばくざい /賭博罪/
とばくじょう /賭博場/
とばくせい /賭博性/
とばくち /とば口/
とばす /都バス/
とばせん /鳥羽線/
とばた /戸畑/
とばてんのう /鳥羽天皇/
とばどの /鳥羽殿;-へ五六騎いそぐ野分哉(蕪村)/
とばふしみのたたかい /鳥羽伏見の戦い;[日本史](1868)/
とばやま /鳥羽山/
とばり /帳/帷;=帳/戸張;姓/幄;=帳/幃;=帳/戸張り;戸板で張物をする/
とひ /都鄙;都会と田舎/都費;(東京)都の費用/徒費;waste/
とび /鳶/鴟;=鳶/鵄;=鳶/飛び/
とび> /飛び;(複合して)飛び歩く,飛び掛かる/
とびいし /飛び石/飛石/
とびいしれんきゅう /飛び石連休/飛石連休/
とびいり /飛び入り/飛入り/
とびいりさんか /飛び入り参加/
とびいろ /鳶色/
とびうお /飛魚/
とびうおざ /飛魚座;Volans(Vol)/
とびおか /飛岡/
とびおり /飛び降り/飛び下り/飛降り/飛下り/
とびおりじさつ /飛び降り自殺/飛降り自殺/
とびきゅう /飛び級/
とびきり /飛切り/
とびぐち /鳶口/
とびげり /飛び蹴り/
とびこ /飛子/
とびこみ /飛び込み/
とびこみえいぎょう /飛び込み営業/
とびこみじさつ /飛び込み自殺/飛込み自殺/
とびさき /飛び先/飛先/
とびしま /飛島/
とびしょく /鳶職/
とびた /飛田/
とびだし /飛び出し;-ナイフ/飛出し;-注意/
とびち /飛び地/飛地/
とびとび /飛び飛び/
とびどうぐ /飛び道具/飛道具/
とびのうお /飛びの魚/
とびばこ /飛び箱/
とびひ /飛び火/飛火/
とびら /扉/
とびらいち /扉位置/
とびらえ /扉絵/
とびらせん /扉線/
とびわし /飛鷲/
とふ /塗布/都府/妬婦;やきもちやきのおっかさん/
とふぎじゅつ /塗布技術/
とふぎょ /杜父魚/
とふけん /都府県/
とふご /塗付後/
とふつ /渡仏/
とぶくろ /戸袋/
とぶくろまど /戸袋窓/
とぶすま /戸襖/
とぶつ /吐物/
とぶとり /飛ぶ鳥/
とぶらい /弔い;=とむらい/
とべ /戸部/砥部/
とべい /渡米/
とべやき /砥部焼/
とほ /徒歩/杜甫/
とほう /途方/
とほすうふん /徒歩数分/
とほそくはつ /吐哺捉髪;握髪吐哺,政治に心を砕き寸時も安居しない/
とほつうがく /徒歩通学/
とほれんらく /徒歩連絡/
とぼく /杜牧;唐の詩人(803-853)/
とぼそ /枢/
とま /苫/篷/笘/
とまく /塗膜/
とまこまい /苫小牧/
とましの /苫篠/
とます /斗/
とまた /苫田/攴;[部首]攴繞(ぼくにょう)に同じ/
とまつ /塗抹/戸松/塗沫/
とまとかん /トマト缶/
とまとに /トマト煮/
とまどい /戸惑い/
とまぶね /苫舟/
とまべち /苫米地/
とままえ /苫前/
とまや /苫屋/
とまり /泊まり/泊り/泊;地名/渡真利/
とまりがけ /泊まり掛け/泊り掛け;-の出張/
とまりきゃく /泊まり客/泊り客/
とまりぎ /止まり木;perch. 「鸚鵡の-」/止り木/
とまりこみ /泊り込み/泊まり込み/
とみ /富/頓;-に(≒急に)/冨;「富」の旧字(人名用漢字)/登美/當;「当」の旧字,?/
とみあい /富合/
とみい /富井/
とみうら /富浦/冨浦/
とみえ /富江/
とみお /富雄/富夫/富男/富美男/
とみおか /富岡/冨岡/
とみおかこうこう /富岡高校/
とみおかてっさい /富岡鉄斎;(1836-1924) 南画家/
とみおかにし /富岡西/
とみおかはちまんぐう /富岡八幡宮/
とみか /富加/
とみかわ /富川/
とみくじ /富籤/
とみぐすく /豊見城/
とみこ /富子/登美子/富美子/
とみこうみ /左見右見/
とみさと /富里/
とみさとちょう /富里町/
とみさとまち /富里町/
とみさわ /富沢/冨沢/
とみざわ /富沢/富澤/
とみしま /富島/
とみしろ /都城/
とみしろこうこう /豊見城高校/
とみじ /富治/
とみじゅうろう /富十郎/
とみた /富田/冨田;「富」異体字/
とみたやすこ /富田靖子/
とみたろう /富太郎/
とみつかちょう /富塚町/
とみて /冨手;「富」異体字/
とみとく /富徳/
とみなが /富永/冨永;「富」異体字/
とみなり /冨成;「富」異体字/
とみに /頓に/
とみの /富野/
とみはま /富浜/
とみはり /富張/
とみひこ /富彦/
とみひさ /富久/
とみひさちょう /富久町/
とみまつ /富松/
とみもと /富本/
とみもとぶし /富本節;[浄瑠璃]/
とみや /富谷/
とみやす /富安/
とみやちょう /富谷町/
とみやま /富山/鳥見山;地名,奈良/
とみよ /富魚/
とみよし /富吉/
とみん /都民/
とみんぜい /都民税/
とみんばん /都民版/
とむ /吐夢/
とむら /戸村/外村/
とむらい /弔い/
とむらいがっせん /弔い合戦/
とめ /留/登米/留め/止め/
とめおき /留置/
とめがね /止め金/留金/
とめきち /留吉/
とめぐん /登米郡/
とめこ /留子/
とめしょ /留所/
とめじ /留治/
とめそで /留袖/
とめど /止め処;-もない,-もなく涙が溢れる/止処/留処/
とめば /留場/
とめべん /止め弁/
とめやま /留山/
とめん /塗面/
とも /友/共/供;従者/朋;≒友/鞆;弓具/艫;⇔舳/伴/侶/朝;(人名用)/知;(人名用)/智;(人名用)/具;(人名用)/恭;(人名用)/靹;「鞆」の異体字/舮;「艫」の異体字/
とも> /共;共喰い,共倒れ,共涙/
ともあき /智明/智朗/倫明/智彰/公明/公暁;名/恭章/
ともい /友井/
ともいし /友石/
ともいち /友一/
ともいろ /共色/
ともうら /共裏/
ともえ /巴/知重/友衛/
ともえがたどうき /巴形銅器/
ともえがわ /巴川/
ともえがわせいししょ /巴川製紙所/
ともえがわら /巴瓦;=軒丸瓦/
ともえぐみ /巴組/
ともえだ /友枝/
ともえなげ /巴投げ/
ともえふじ /巴富士/
ともえり /共襟/
ともお /智雄/智夫/友雄/知夫/智央/朋夫/友朗/
ともおか /友岡/
ともか /友香/
ともかがみ /共鏡/
ともかく /兎も角/
ともかくも /兎も角も/
ともかず /智和/智一/友和/共和/
ともかせぎ /共稼ぎ/
ともがおか /友ヶ丘/
ともがき /友垣/
ともがら /輩/讐/讎/
ともき /智樹/知樹/友紀/友喜/朋喜/
ともきち /友吉/
ともきよ /友清/
ともくに /友國;姓/
ともぐい /共食い/
ともこ /智子/知子/朋子/友子/倫子/とも子/朝子/
ともざ /艫座;Puppis(Pup)/船尾座;Puppis(Pup)/
ともざる /友猿/
ともし /知士/
ともしび /灯/灯火/燈;「灯」の旧字(人名用漢字)/燭;(字義:動かずに照らすあかり)/灯し火/
ともじ /友治/知司/十文字/
ともぞう /友蔵/
ともたか /智孝/友隆/
ともたけ /智武/
ともたろう /智太郎/
ともだ /友田/
ともだおれ /共倒れ/
ともだち /友達/友だち/
ともだちかん /友達間/
ともだちがい /友達甲斐/
ともだちづくり /友達作り/
ともだちていど /友達程度/
ともだちどうし /友達同士/
ともだちわりびき /友達割引/
ともち /砥用/
ともちか /友近/知親/朋哉/
ともづな /纜/
ともづり /友釣/
ともづる /友鶴/
ともとし /智年/
ともども /共々/
ともなか /邑中/
ともなが /友永/朝長/朝永/
ともながしんいちろう /朝永振一郎/
ともなり /友成/共鳴り/
ともに /共に/倶に/
ともぬの /共布/
ともね /鞆音/共寝/
ともの /友野/伴野/
とものうら /鞆の浦/
とものかい /友の会/
とものり /友則/智徳/友紀/智則/智紀/智規/知典/知徳/知紀/
ともはな /友花/
ともはる /智春/知治/
ともばたらき /共働き/
ともひこ /智彦/友彦/知彦/朋彦/
ともひさ /智久/知久/友久/朋久/
ともひで /智秀/友秀/知英/
ともひと /智仁/智斉/
ともひろ /智弘/智広/智博/知宏/智浩/智洋/朋宏/友広/知浩/友洋/朋博/恭祐/共洋/
ともびき /友引;[六輝]勝負無し/
ともふさ /智英;名/
ともへ /艫舳/
ともべ /友部/
ともべや /供部屋/
ともまさ /智真/
ともまつ /友松/
ともみ /朋美/知美/智美/とも美/具視/友視/智巳/智己/知実/友海/具実/具美/朋三/知視/
ともみち /友道/智道/伴通/
ともみつ /伴光/
ともみはら /倶美原/
とももり /知盛/
ともや /智也/知也/
ともやす /友康/朋康/
ともゆき /智之/知之/知行/智行/智幸/朋之/友幸/朋幸/共之/
ともよ /知世/知代/智世/
ともよし /知義/智義/友良/智由/知節/
ともらい /弔い;=とむらい/
とや /鳥屋/戸谷/外谷/
とやかく /兎や角/
とやま /富山/外山/戸山/
とやまえき /富山駅/
とやまがわ /富山側/
とやまくうこう /富山空港/
とやまけん /富山県/
とやまけんけい /富山県警/
とやまけんだい /富山県大/
とやまけんりつだい /富山県立大/
とやまけんりつだいがく /富山県立大学/
とやまさん /富山産/
とやまし /富山市/
とやましがい /富山市街/
とやましない /富山市内/
とやましんこう /富山新港/
とやまだい /富山大/
とやまだいがく /富山大学/
とやまちてつ /富山地鉄/
とやまちほうてつどう /富山地方鉄道/
とやまちょう /戸山町/
とやまはつ /富山発/
とやまびん /富山便/
とやまべん /富山弁/
とやまわん /富山湾/
とゆ /樋/
とゆう /都有/都邑/
とゆうち /都有地/
とよ /豊/樋/豐;「豊」の旧字/
とよあき /豊明/
とよあきつしま /豊秋津洲/
とよあけ /豊明/
とよあしはら /豊葦原/
とよう /渡洋/
とようち /豊内/
とようら /豊浦/
とよおか /豊岡/豊丘/
とよおかく /豊岡区/
とよおかこうじょう /豊岡工場/
とよかず /豊和/
とよかわ /豊川/
とよかわいなり /豊川稲荷/
とよがおか /豊ヶ丘/
とよき /豊樹/
とよきち /豊吉/
とよぎだい /豊技大/
とよくに /豊国/
とよくら /豊倉/
とよこ /豊子/
とよこう /豊高/
とよころ /豊頃/
とよさか /豊栄/
とよさき /豊崎;姓/
とよさく /豊作/
とよさと /豊里/豊郷/
とよさわ /豊沢/
とよしき /豊四季/
とよしな /豊科/
とよしなかん /豊科間/
とよしま /豊島/豊嶋/
とよじ /豊治/
とよす /豊洲/
とよすえき /豊洲駅/
とよすしじょう /豊洲市場/
とよすふとう /豊洲埠頭/
とよた /豊田/
とよたけ /豊竹;義太夫の名跡/
とよたけざ /豊竹座/
とよたこうせん /豊田高専/
とよたし /豊田市/
とよたしゃたい /トヨタ車体;[企業名]/
とよたじどうしゃ /トヨタ自動車;[企業名]/
とよたちゅうけん /豊田中研/
とよたま /豊玉/
とよたろう /豊太郎;名/
とよだ /豊田/
とよだこうき /豊田工機/
とよだこうぎょうだいがく /豊田工業大学/
とよださきち /豊田佐吉/
とよだせん /豊田線/
とよだつうしょう /豊田通商;[企業名]/
とよつ /豊津/
とよてつ /豊鉄/
とよとし /豊年/
とよとみ /豊臣/豊富/
とよとみがた /豊臣方/
とよとみひでよし /豊臣秀吉/
とよとみひでより /豊臣秀頼/
とよなか /豊中/
とよなかし /豊中市/
とよなかしてん /豊中支店/
とよなかしない /豊中市内/
とよね /豊根/
とよの /豊能/豊野/
とよのぶ /豊信/豊伸/
とよのぼり /豊登/
とよはし /豊橋/
とよはしえき /豊橋駅/
とよはしかん /豊橋間/
とよはしきた /豊橋北/
とよはしぎかだい /豊橋技科大/
とよはしぎじゅつかがくだいがく /豊橋技術科学大学/
とよはしぎだい /豊橋技大/
とよはしし /豊橋市/
とよはしほうめん /豊橋方面/
とよはま /豊浜/
とよはら /豊原/
とよひこ /豊彦/
とよひさ /豊久/
とよひせん /豊肥線/
とよひと /十余一/
とよひほんせん /豊肥本線/
とよひら /豊平/
とよひらがわ /豊平川/
とよひらく /豊平区/
とよひろ /豊弘/豊広/
とよふく /豊福/
とよふみ /豊文/東洋史/
とよま /登米/
とよまえかわさき /豊前川崎/
とよまつ /豊松/
とよまる /豊丸/
とよやま /豊山/
とら /虎/寅;[十二支]3/乕/
とらい /渡来/戸来/
とらいけい /渡来系/
とらいじん /渡来人/
とらいち /寅市/
とらえかた /捉え方/
とらえどころ /捉え所/
とらお /虎雄/虎男/寅雄/寅男/
とらかんむり /虎冠;「虎」のかんむり/
とらがしら /虎頭;「虔」のかしら/
とらがり /虎刈り/虎狩り;インドの-/
とらきち /寅吉/虎吉/
とらぎ /トラ技/
とらくす /寅楠/
とらさん /寅さん/
とらぞう /虎造/虎三/
とらとう /虎党/
とらどし /寅年/
とらねこ /虎猫/
とらのこ /虎の子/
とらのまき /虎の巻/
とらのもん /虎ノ門/虎の門/
とらひこ /寅彦/
とらひめ /虎姫/
とらふぐ /虎河豚/
とらわれ /囚われ/
とり /鳥/鶏;にわとり/酉;[十二支]10/禽;獲る鳥/図利;賭博開帳-/鷄;「鶏」の旧字(人名用漢字)/取/取り/
とりあい /取り合い/取合い/
とりあえず /取り敢えず/取りあえず/
とりあげ /取り上げ/
とりあたま /鳥頭/
とりあつかい /取扱/取り扱い/取扱い/
とりあつかいかた /取り扱い方/
とりあつかいぎょう /取扱業/
とりあつかいぎょうしゃ /取扱業者/
とりあつかいしゃ /取扱者/取扱車/
とりあつかいしょうひん /取扱商品/
とりあつかいじょ /取扱所/
とりあつかいせつめいしょ /取扱説明書/
とりあつかいちゅうい /取扱注意/
とりあつかいてん /取扱店/
とりあつかいもと /取扱元/
とりあわせ /取り合わせ/取合せ/取り合せ/
とりい /鳥居/鳥井/
とりいそぎ /取り急ぎ/
とりいれ /取り入れ/取入れ/
とりいれぐち /取り入れ口/取入れ口/
とりいんふるえんざ /鳥インフルエンザ/
とりう /鳥生/
とりうち /鳥打ち/
とりうちぼう /鳥撃帽/
とりうみ /鳥海/
とりうむ /Th/Thorium/
とりうむけいれつ /トリウム系列;4n系列/
とりうら /鳥占/
とりえ /取り柄/取り得/取柄/取得;(要ルビ)/
とりお /鳥尾/
とりおい /鳥追/鳥追い/
とりおき /取り置き/
とりおどし /鳥威し/
とりかい /鳥飼/
とりかえ /取り替え/取替え/取替/
とりかえし /取り返し/
とりかげ /鳥影/
とりかご /鳥籠/
とりかじ /取り舵/取舵/
とりかた /取り方/
とりかぶと /鳥兜/
とりかぶとぞく /Aconitum/トリカブト属/
とりがい /鳥飼/鳥貝/
とりがしら /鳥頭/
とりがた /鳥潟/
とりがら /鶏ガラ/鳥ガラ;?/
とりき /取り木/取木/
とりきめ /取り決め/取決め/取極/取り極め/
とりくち /取口/
とりくみ /取り組み/取組/取組み/
とりくみひょう /取組表/
とりくんだ /取り組んだ/
とりけし /取消/取り消し/取消し/
とりけしけん /取消権/
とりけししょぶん /取消処分/
とりけしでんぴょう /取消伝票/
とりげ /鳥毛/
とりこ /虜/擒;=虜/俘;=虜/取り粉/取り子;[民俗学]「お前は本当は橋の下で拾われた子なんだよ」/虜擒/
とりこし /取り越し/
とりこしぐろう /取り越し苦労/取越し苦労/
とりこぼし /取り零し/
とりこみ /取り込み/取込/
とりこみさぎ /取り込み詐欺;代金踏み倒し/取込み詐欺;代金踏み倒し/
とりこわし /取り壊し;-工事/取壊し/
とりごえ /鳥越/
とりごや /鳥小屋/
とりさか /鳥坂/
とりさげ /取り下げ/取下げ/取下/
とりさわ /鳥沢/鳥澤/
とりざた /取り沙汰/取りざた/取沙汰/
とりざら /取り皿/取皿;大皿から料理を取るための皿/
とりしま /鳥島/
とりしまり /取締/取り締まり/取締り/取り締り/
とりしまりほう /取締法/
とりしまりやく /取締役/
とりしまりやくかい /取締役会/
とりしまりやくしゃちょう /取締役社長/
とりしまりやくほんぶちょう /取締役本部長/
とりしらべ /取り調べ/取調べ/取調/
とりしらべかん /取調官/
とりしらべしつ /取調室/
とりす /鳥巣/
とりせつ /取説/
とりたち /鳥達/
とりたて /取り立て;借金の-/取立て/取立/
とりたていにんうらがき /取立委任裏書/
とりたてきん /取立金/
とりたに /鳥谷/
とりだい /鳥大/
とりだか /取高/取り高/
とりだし /取り出し/取出/
とりだんご /鶏団子/
とりつ /都立/
とりつかせい /都立家政/
とりつき /取り付き/
とりつきょういくけんきゅうじょ /都立教育研究所/
とりつぎ /取次/取次ぎ/取り次ぎ/
とりつぎがいしゃ /取次会社/
とりつぎてん /取次店/
とりつけ /取り付け/取付/取付け/
とりつけかくど /取付角度/
とりつけかなぐ /取付金具/
とりつけこうじ /取付工事/
とりつけさわぎ /取り付け騒ぎ/
とりつけせつめいしょ /取付説明書/
とりつけぶ /取付部/
とりつけぶぶん /取付部分/
とりつけほうほう /取付方法/
とりつけりょう /取付料/
とりつこう /都立高/
とりつこうこう /都立高校/
とりつだい /都立大/東京都立大学;※abbrev/
とりつだいがく /都立大学/
とりつびじゅつかん /都立美術館/
とりつぶし /取り潰し/
とりづか /取り束/
とりて /取り手/
とりてき /取的/
とりてん /鳥天/
とりで /砦/取手;地名,茨城/塞/
とりでにこう /取手二高/
とりとめ /取り留め/
とりとりべ /鳥取部;鳥をつかまえる昔の職業/
とりどし /酉年/
とりどり /取り取り/
とりなおし /取り直し;相撲の-/取直し/
とりにく /鶏肉/鳥肉/
とりにんげん /鳥人間/
とりのいち /酉の市/
とりのこ /鳥の子/
とりのこいろ /鳥の子色/
とりのこがみ /鳥の子紙/
とりのす /鳥の巣;春の季語/
とりはからい /取り計らい/取計らい/
とりはずし /取り外し;detach/取外し/
とりはだ /鳥肌/
とりばし /取り箸/
とりひき /取引/取り引き/取引き/
とりひきかかく /取引価格/
とりひきさき /取引先/取り引き先/
とりひきざいりょう /取引材料/
とりひきしょうひょうしょ /取引証憑書/
とりひきじょ /取引所/
とりひきだかぜい /取引高税/
とりひきていし /取引停止/
とりひきないよう /取引内容/
とりひきほうほう /取引方法/
とりぶえ /鳥笛;鳥の声のする笛/
とりぶん /取り分/取分;分け前/
とりぷるやす /トリプル安/
とりべの /鳥辺野/
とりほうだい /取り放題/
とりまえ /取り前/
とりまき /取り巻き/取巻き/取巻/
とりまとめ /取り纏め/
とりまわし /取り回し;配線の-/取回し/
とりみ /鳥見/
とりめ /鳥目/
とりめにあか /トリメニア科/Trimeniaceae/
とりもち /取り持ち/鳥黐/
とりもどしけん /取戻権/
とりもなおさず /取りも直さず/
とりもの /捕物/捕り物/
とりものちょう /捕物帳/捕物帖/
とりや /鳥屋/鳥谷/
とりやま /鳥山/
とりやめ /取り止め/
とりょう /塗料/斗量/
とりよせ /取り寄せ/取寄せ/鳥寄せ;†birdcall/
とりりょうり /鳥料理/
とりろう /鶏郎/
とりわき /鳥脇/
とりわけ /取り分け/取分け/
とるこ /土耳古;Turco/土耳其/
とるこいし /トルコ石;一二月の誕生石/
とるこじん /トルコ人/
とるこだま /トルコ玉;turquoise/
とるこぶろ /トルコ風呂/
とるこぼう /トルコ帽;fez/
とるこりょうり /トルコ料理/
とれたて /獲れたて;-の魚/穫れたて;-野菜/取れ立て/
とれだか /取れ高/
とれつ /堵列/
とれん /都連/
とろ /吐露/瀞;深く静かな流れ/
とろーるぎょぎょう /トロール漁業;底引き網を使った漁業/
とろーるせん /トロール船;トロール漁業をする船/
とろいあせんそう /トロイア戦争/
とろいせき /登呂遺跡/
とろう /徒労/
とろうかん /徒労感/
とろばこ /トロ箱;魚を入れる(主に発泡スチロール製の)箱。語源不詳/
とろび /とろ火/
とろろ /薯蕷/黄蜀葵/
とろろあおい /黄蜀葵/
とろろいも /薯蕷芋;やまいも/とろろ芋/
とろろこんぶ /とろろ昆布/
とろろじる /薯蕷汁/とろろ汁/
とろん /徒論/
とわ /永遠/永久/常/登和/
とわずがたり /問わず語り/
とわたり /門渡り;=会陰/
とわだ /十和田/
とわだこ /十和田湖/
とわだし /十和田市/
とん /豚/噸;ton(1000kg)/瓲;=噸/頓;整頓/屯;駐屯/沌;混沌/飩;饂飩/惇/敦;敦煌/暾/燉/遁;隠遁/遯;≒遁/問;問屋/団;布団/團;「団」の旧字(人名用漢字)/東;(dong)中国音/丼;?/
とんあい /貪愛/
とんいっきょく /東一局/
とんえい /屯営/
とんかつ /豚カツ/
とんかつや /とんかつ屋/
とんがらし /唐辛子/
とんがりぼうし /尖り帽子/
とんきょう /頓狂/頓興;すっ―/
とんきんわん /トンキン湾;ベトナム/
とんぐう /頓宮/
とんこう /敦煌/遁甲/燉煌/
とんこつ /豚骨/
とんこつあじ /豚骨味/
とんご /頓悟/
とんさんきょく /東三局/
とんざ /頓挫/
とんざい /屯在/
とんし /頓死/豚脂;lard/
とんしゃ /豚舎/頓写/
とんしゅ /頓首/
とんしょ /屯所/
とんしょうぼだい /頓証菩提/
とんじ /遁辞/豚児;boo!/
とんじゃく /頓着/貪着/
とんじょ /東女/
とんじる /豚汁/
とんじるふう /豚汁風/
とんじんち /貪瞋痴/
とんすう /トン数/
とんず /筒子/
とんせい /遁世/遯世/
とんせいしゃ /遁世者/
とんそう /遁走/
とんそうきょく /遁走曲/
とんそく /豚足/
とんぞく /遁俗/
とんだばやし /富田林/
とんち /頓知/頓智/
とんちき /頓痴気;とんま/
とんちゃく /頓着/
とんちんかん /頓珍漢/
とんでん /屯田/
とんでんへい /屯田兵/
とんとろ /豚トロ/
とんとんびょうし /とんとん拍子/
とんどん /豚丼/
とんない /貪愛/
とんなんしゃぺい /東南西北/
とんにきょく /東二局/
とんにく /豚肉/
とんねるこうか /トンネル効果/
とんば /東場/
とんばら /頓原/
とんび /鳶/
とんぷうそう /東風荘/
とんぷく /頓服/
とんぷくやく /頓服薬/
とんぼ /蜻蛉/
とんぼがえり /蜻蛉返り/とんぼ返り/
とんま /頓馬/
とんや /問屋/
とんやがい /問屋街/
とんやくみあい /問屋組合/
とんやせいかないこうぎょう /問屋制家内工業;後に工場制手工業に発展した/
とんよく /貪欲/
ど /度/土/奴/怒;怒り/努;努力/弩;石弓/°;degree/℃;celsius/戸/駑;にぶい/呶;呶鳴る/孥;妻子/堵;安堵/
ど> /度/
ど、にち /土、日/
どーなつばん /ドーナツ盤;EP/
どーばーかいきょう /ドーバー海峡/
どーむきゅうじょう /ドーム球場/
どあい /度合い/度合/
どあごし /ドア越し/
どあつ /土圧/
どあつけい /土圧計/
どあほ /ど阿呆/
どい /土井/土肥/土居/
どいがき /土井垣/
どいっき /土一揆/
どいつ /独逸/何奴/独乙/獨逸/獨乙/独/
どいつかんねんろん /ドイツ観念論;der deutsche Idealismus/
どいつぐん /ドイツ軍/
どいつご /ドイツ語/
どいつさん /ドイツ産/
どいつじん /ドイツ人/
どいつせい /ドイツ製/
どいつぶんか /ドイツ文化/
どいつぶんがく /ドイツ文学/
どいなか /ド田舎/ど田舎/
どいばんすい /土井晩翠;(1871-1952) 詩人 NB:本名「つちい」/
どう /同/銅/胴/道/堂/動/洞/如何/導;導線/恫;恫喝/桐;(慣用音) きり/働;労働/慟;慟哭/童;童謡/憧;憧憬/撞;(つ・く) 撞着/瞳;瞳孔/僮/艟/獰;獰猛/瞠;瞠目/耨;(くさぎる)/鬧;(さわぐ)/閙;「鬧」の異体字/嫐;なぶ・る/萄;葡萄/儂;わし/陶;(呉音)/藤;安藤/撓;たわ・む/橈/鐃;(どら)/〃;→くりかえし/ゞ/々/Cu/Copper/
どう> /同/動;動睡眠,動力学/道;(北海道) 道北部,道委員/如何/
どうあい /同愛/
どうあいきねんびょういん /同愛記念病院/
どうあく /道悪/獰悪/
どうあげ /胴上げ/
どうあん /同案/
どうあんたすう /同案多数/同案他数;?/
どうい /同意/同位/胴衣/
どういいんかい /同委員会/
どういかく /同位角/
どういぎ /同意義/
どういけん /同意見/
どういけんたすう /同意見多数/
どういげんそ /同位元素/
どういご /同意語/
どういしゃ /同意者/
どういしょ /同意書/
どういそう /同位相/
どういたい /同位体/
どういたいこうか /同位体効果/
どういたいひ /同位体比/
どういっしゅ /同一種/
どういつ /同一/
どういつえき /同一駅/
どういつか /同一化/
どういつがいねん /同一概念/
どういつきしゅ /同一機種/同一騎手/
どういつきょくめん /同一局面/
どういつぎょう /同一行/
どういつけいえい /同一経営/
どういつけいしき /同一形式/
どういつげんご /同一言語/
どういつし /同一視/
どういつしほん /同一資本/
どういつしゃしゅ /同一車種/
どういつしゅうかい /同一周回/
どういつしゅうはすう /同一周波数/
どういつしょぞく /同一所属/
どういつじこく /同一時刻/
どういつじょうけん /同一条件/
どういつじんぶつ /同一人物/
どういつせい /同一性/
どういつせいひん /同一製品/
どういつせいほじけん /同一性保持権/
どういつせかい /同一世界/
どういつせん /同一線/
どういつせんじょう /同一線上/
どういつそしき /同一組織/
どういつぞく /同一属/
どういつちんぎん /同一賃金/
どういつてん /同一点/
どういつないよう /同一内容/
どういつにん /同一人/
どういつねん /同一年/
どういつはん /同一犯/
どういつひんしつ /同一品質/
どういつびん /同一便/
どういつふごう /同一符号/
どういつへいめん /同一平面/
どういつほうこう /同一方向/
どういつめい /同一名/
どういつもじ /同一文字/
どういつりつ /同一律/
どういつりょういき /同一領域/
どういつりょうきん /同一料金/
どういつろうどう /同一労働/
どういつろせん /同一路線/
どういつわ /同一話/
どういつわく /同一枠/
どういん /動員/動因/導引/
どういんすう /動員数/
どういんりつ /動員率/
どういんりょく /動員力/
どうう /堂宇/
どううら /胴裏/
どうえい /道営/
どうえき /同駅/
どうえん /導演/
どうおう /道央/
どうおん /同音/
どうおんいぎご /同音異義語/
どうおんご /同音語/
どうか /同化/同価/銅貨/道家/同課/道歌/銅戈/導火/
どうかいぎ /同会議/
どうかいぎいん /道会議員/
どうかいじょう /同会場/
どうかかく /同価格/
どうかく /同格/同角/動確/
どうかごうぶつ /銅化合物/
どうかせいさく /同化政策/
どうかせん /導火線/
どうかそしき /同化組織/
どうかっしゃ /動滑車;⇔定滑車/
どうかつ /恫喝/
どうかひか /同花被花/
どうかん /同感/導管/道管/道灌/道観/
どうかんすう /導関数/
どうかんとく /同監督/
どうが /動画/童画;子供の絵/
どうがあっしゅくきかく /動画圧縮規格/
どうがい /道外/
どうがく /同額/同学/動学;dynamics/道学/
どうがくねん /同学年/
どうがしま /堂ヶ島/
どうがぞう /動画像/
どうがた /同型/
どうがたかん /同型艦/
どうがたき /同型機/
どうがたしゃ /同型車/
どうがまいすう /動画枚数/
どうがん /童顔/動眼/
どうがんしんけい /動眼神経/
どうき /同期/動機;†motive/動悸;†ドキドキ/同機/銅器/同気/動気/
どうきかい /同期会/
どうきかいろ /同期回路/
どうきかく /同規格/
どうきかさん /同期加算/
どうきがた /同期型/
どうきき /同期機/
どうききこう /同期機構/
どうきしき /同期式/
どうきしゅ /同機種/
どうきしゅうはすう /同期周波数/
どうきしょり /同期処理/
どうきしんごう /同期信号/
どうきじ /同記事/
どうきじょう /動機上/
どうきせい /同期生/同期性/
どうきせつぞく /同期接続/
どうきつうしん /同期通信/
どうきづけ /動機付け/
どうきてき /同期的/
どうきてん /同期点/
どうきてんそう /同期転送/
どうきにゅうしゃ /同期入社/
どうきほうしき /同期方式/
どうきゅう /同級/撞球/慟泣/
どうきゅうしゃ /同厩舎/
どうきゅうせい /同級生/
どうきゅうせいどうし /同級生同士/
どうきょ /同居/
どうきょう /同郷/道教/銅鏡/道鏡/同香/
どうきょうい /道教委;道教育委員会/
どうきょうけい /道教系/
どうきょうじん /同郷人/
どうきょく /同局/同曲/
どうきょしゃ /同居者/
どうきょにん /同居人/
どうきょり /同距離/
どうきん /同衾/同金;[将棋]/同斤/
どうぎ /同義/道義;†moral.「-に反する」/動議;†motion.「-を提出する」/道着;†「柔剣道の-」/胴着;†vest/道議;北海道議会(議員)/
どうぎかい /道議会/
どうぎご /同義語/
どうぎごじしょ /同義語辞書/
どうぎしん /道義心/
どうぎじょう /道義上/
どうぎていしゅつ /動議提出/
どうぎてき /道義的/
どうぎてきせきにん /道義的責任/
どうぎはんぷく /同義反復/
どうぎょう /同業/同行/童形/
どうぎょうくみあい /同業組合;guild/
どうぎょうしゃ /同業者/
どうぎょうしゅ /同業種/
どうぎょうたしゃ /同業他社/
どうぎょく /同玉/
どうぎん /同銀/
どうく /同区/
どうくかん /同区間/
どうくつ /洞窟/
どうくつない /洞窟内/
どうくん /同訓/同君/
どうくんいじ /同訓異字/
どうぐ /道具/
どうぐいっしき /道具一式/
どうぐかた /道具方/
どうぐだたみ /道具畳;[茶道]/
どうぐだて /道具立て/
どうぐち /洞口/
どうぐばこ /道具箱/
どうぐや /道具屋/
どうけ /道化/同家/道家;どうか/
どうけい /憧憬/同系;†same kind.「-色」/同型;†same type.「-写像」/同形;†same form.「-異義語」/同慶/動径/道警;北海道警察/同桂;(将棋?)/
どうけいき /同形機/
どうけいしゃぞう /同型写像/同形写像/
どうけいしょく /同系色/
どうけいせい /同型性/同形性/
どうけいたい /同形態/
どうけいとう /同系統/
どうけいどうだい /同形同大/
どうけいれつ /同系列/
どうけし /道化師/
どうけつ /洞穴/同穴;夫婦円満.「偕老-」/
どうけん /同県/同権/銅剣/洞見/
どうけんきゅうしつ /同研究室/
どうげつ /同月/
どうげん /同源/道元/道玄/
どうげんざか /道玄坂/
どうげんたい /動原体;[生物]centromere/
どうこ /銅壺/堂鼓/
どうこう /動向/同行;「ツアーに-する」/瞳孔/同好;「-の士」/同項;「-第3号」/同校/同工;-異曲/銅鉱/道光/道幸/同興/同甲/同功/銅坑/同庚/
どうこういきょく /同工異曲/
どうこうかい /同好会/
どうこうこう /同高校/
どうこうしゃ /同行者/
どうこうちょうさ /動向調査/
どうこうなど /動向等/
どうこうのし /同好の士/
どうこうはんしゃ /瞳孔反射;[医]pupillary reflex/
どうこうほう /道交法/
どうこうほういはん /道交法違反/
どうこうほうじょう /道交法上/
どうこく /同国/慟哭/同刻/
どうこくじん /同国人/
どうこん /同梱;include.「-の説明書」/同根;of the same root.「-の問題」/
どうこんしき /銅婚式;7周年/
どうご /道後/同語/
どうごう /同号/道号/
どうごうきん /銅合金/
どうごおんせん /道後温泉/
どうごげん /同語源/
どうごはんぷく /同語反復/
どうさ /動作/同左/
どうさい /道斎/
どうさおん /動作音/
どうさか /動作可/
どうさかくにん /動作確認/
どうさかくにんご /動作確認後/
どうさかくにんじょうほう /動作確認情報/
どうさかくにんよう /動作確認用/
どうさかのう /動作可能/
どうさかんきょう /動作環境/
どうさかんきょうせってい /動作環境設定/
どうさきしゅ /動作機種/
どうさぎれ /動作切/
どうさくしゃ /同作者/
どうさげんり /動作原理/
どうさしゅ /動作主/
どうさしゅつりょく /動作出力/
どうさじ /動作時/
どうさじっけん /動作実験/
どうさじっせき /動作実績/
どうさじょうきょう /動作状況/
どうさじょうけん /動作条件/
どうさじょうたい /動作状態/
どうさせい /動作性/
どうさそう /動作相/
どうさそくど /動作速度/
どうさちゅう /動作中/
どうさつ /洞察/
どうさつりょく /洞察力/
どうさていし /動作停止/
どうさてん /動作点/
どうさでんあつ /動作電圧/
どうさとくせい /動作特性/
どうさふのう /動作不能/
どうさふりょう /動作不良/
どうさぶ /動作部/
どうさほうこく /動作報告/
どうさほしょう /動作保証/
どうさみかくにん /動作未確認/
どうさよう /動作用/
どうさりょういき /動作領域/
どうさん /動産;movables/道産;北海道産/道三;人名/
どうさんほけん /動産保険;movable insurance/
どうざ /銅座;copper mint/同座/動座/
どうざい /同罪/
どうざっし /同雑誌/
どうざん /銅山/
どうし /同士;†「仲間-」/同志;†comrade.「党の-」/動詞/同市/同氏/同誌;magazine/同紙;paper/導師/道士/同視/道志/同旨/
どうしうち /同士打ち/同士撃ち/
どうしか /動詞化/
どうしかい /同士会/
どうしかいどう /道志街道/
どうしかく /動詞格/
どうしかつよう /動詞活用/
どうしけい /動詞形/
どうししゃ /同志社/
どうししゃだい /同志社大/
どうししゃだいがく /同志社大学/
どうした /堂下/
どうしつ /同室/同質/
どうしつせい /同質性/
どうして /如何して/
どうしてき /動詞的/
どうしても /如何しても/
どうしゃ /同社/動車/同車/
どうしゃせい /同社製/
どうしゃはっこう /同社発行/
どうしゅ /同種/同趣/同株/
どうしゅう /同州/同舟;呉越-/堂衆/同衆/銅臭/同臭/
どうしゅうき /同周期/
どうしゅうせい /道州制/
どうしゅく /同宿/
どうしゅし /同趣旨/
どうしゅぞく /同種族/
どうしゅつ /導出/
どうしゅつかてい /導出過程/
どうしゅつかのう /導出可能/
どうしゅつがた /導出型/
どうしゅつぎ /導出木/
どうしゅつけい /導出系/
どうしゅつさき /導出先/
どうしゅつほう /導出法/
どうしゅりゅうし /同種粒子/
どうしゅんてん /道春点/
どうしょ /同書/同所/道書/
どうしょう /銅賞/同省/同床/道床/
どうしょういむ /同床異夢/
どうしょうてん /同焦点/
どうしょく /同色/同職/銅色;copper/
どうしょくくみあい /同職組合;Zunft/
どうしょくけい /同色系/
どうしょくぶつ /動植物/
どうしょくぶつめい /動植物名/
どうしりょう /同資料/
どうしん /同心/童心/童神/道心/道新;[略語]北海道新聞/
どうしんえん /同心円/
どうしんえんじょう /同心円状/同心円上/
どうじ /同時/童子/同次/動時/同字;-異訓/
どうじ> /同時;-発売,-攻撃,-移植/
どうじえんそう /同時演奏/
どうじか /同時化/
どうじかいさい /同時開催/
どうじかん /同時間/
どうじき /同時期/
どうじく /同軸/
どうじくかいてん /同軸回転/
どうじくけーぶる /同軸ケーブル;coaxial (cable)/
どうじくじょう /同軸上/
どうじけいすう /同時計数/
どうじけん /同事件/
どうじこうしん /同時更新/
どうじこく /同時刻/
どうじしゅうろく /同時収録/
どうじしゅつりょくかのう /同時出力可能/
どうじしんこう /同時進行/
どうじしんこうけい /同時進行形/
どうじしんこうてき /同時進行的/
どうじじっこう /同時実行/
どうじじょうえい /同時上映/
どうじせい /同時性/
どうじせつぞく /同時接続/
どうじせんきょ /同時選挙/
どうじそうさ /同時操作/
どうじたはつ /同時多発/
どうじたはつてき /同時多発的/
どうじだい /同時代/
どうじだいじん /同時代人/
どうじだいせい /同時代性/
どうじちょうり /同時調理/
どうじつ /同日/
どうじつうやく /同時通訳/
どうじつせんきょ /同日選挙;衆参-/
どうじてんとう /同時点灯/
どうじとうこう /同時投稿/
どうじにゅうりょく /同時入力/
どうじはつおん /同時発音/
どうじはつおんすう /同時発音数/
どうじはつばい /同時発売/
どうじひょうじ /同時表示/
どうじほうそう /同時放送/
どうじぼしゅう /同時募集/
どうじま /堂島/
どうじめ /胴締め/
どうじゃく /瞠若/
どうじゅつ /道術/
どうじゅん /同順/
どうじゅんい /同順位/
どうじゅんかい /同潤会/
どうじょ /童女/
どうじょう /道場/同情/同上/同乗/同条;-第3項/道上/堂上/仝/〃;文単位/
どうじょうけん /同条件/
どうじょうしゃ /同乗者/
どうじょうしん /同情心/
どうじょうじ /道成寺/
どうじょうだいにこう /同条第二項/
どうじょうてき /同情的/
どうじょうない /道場内/
どうじょうぬし /道場主/
どうじょうひょう /同情票/
どうじょうみゃく /動静脈/
どうじょうやぶり /道場破り/
どうじろくおん /同時録音/
どうじん /同人/同仁/道仁/
どうじんざっし /同人雑誌;同人誌/
どうじんし /同人誌/
どうじんしかつどう /同人誌活動/
どうじんしさっか /同人誌作家/
どうじんしそくばいかい /同人誌即売会/
どうじんしゃ /同人社/
どうじんしよう /同人誌用/
どうすい /導水/
どうすいじゅん /同水準/
どうすう /同数/
どうず /同図/
どうせい /同棲;cohabitation/同性;†same sex/同姓;†-同名/銅製/動静/同声/道政/
どうせいあい /同性愛/
どうせいあいしゃ /同性愛者/
どうせいけっこん /同性結婚/
どうせいじだい /同棲時代/
どうせいちゅう /同棲中/
どうせいどうめい /同姓同名/
どうせいのう /同性能/
どうせいふ /同政府/
どうせき /同席/道関/
どうせだい /同世代/
どうせん /動線;flow line/銅線;†copper line/導線;†lead/銅銭;copper coin/同船/
どうせんこう /同専攻/
どうぜい /道税/同勢/
どうぜん /同然/同前/
どうそ /同祖;†homoeology.「-遺伝子」/同素;†allotropy.「-体」/
どうそう /同窓/同相/
どうそうかい /同窓会/
どうそうかいし /同窓会誌/
どうそうかいほう /同窓会報/
どうそうかいめいぼ /同窓会名簿/
どうそうせい /同窓生/
どうそく /同側/
どうそじん /道祖神/
どうそたい /同素体/
どうそん /同村/道村/
どうぞう /銅像/
どうぞく /同族/同属/道俗/
どうぞくがいしゃ /同族会社/
どうぞくけいえい /同族経営/
どうぞくだん /同族団/
どうぞくれつ /同族列/
どうたい /動態;動き。「人口-」/胴体;body/導体;conductor/同体;「一心-」/動体;動いているもの。「-視力」/道諦;[仏教]/
どうたいけい /同体型/胴体径/
どうたいしりょく /動体視力/動態視力;?/
どうたいちゃくりく /胴体着陸;belly-landing/
どうたいとうけい /動態統計/
どうたいほぞん /動態保存/動体保存;?/
どうたく /銅鐸/
どうだい /同大/同題/
どうだいがく /同大学/
どうだいがくいん /同大学院/
どうだいら /堂平/
どうだん /道断/同断/満天星;[植物]/同段/道斷/
どうだんつつじ /満天星;[植物]/
どうち /同地/同値/同治/≡;ごうどう/⇔;<=>/
どうちいき /同地域/
どうちかんけい /同値関係/
どうちく /同地区/
どうちじ /道知事/
どうちじせん /道知事選/
どうちせい /同値性/
どうちてき /同値的/
どうちゃく /同着/撞着/
どうちゃくごほう /撞着語法/
どうちゅう /道中/
どうちゅうき /道中記/
どうちゅうぎ /道中着;travel wear/
どうちょう /同調/道庁/同庁/
どうちょうかいろ /同調回路/
どうちょうきょくせん /同調曲線/
どうちょうしゃ /同調者/
どうちょうそうち /同調装置/
どうちょうてん /同調点/
どうちょうとせつ /道聴塗説/
どうちるい /同値類/
どうつう /導通/
どうてい /同定/道程/童貞/同底/
どうていあん /同提案/
どうていこ /洞庭湖/
どうていど /同程度/
どうていりつ /同定率/
どうてき /動的/
どうてきかいせき /動的解析/
どうてきけいかくほう /動的計画法/
どうてきせいぎょ /動的制御/
どうてきそくばく /動的束縛/
どうてきはいぶん /動的配分/
どうてきふかぶんさん /動的負荷分散/
どうてん /同点/動転/同店/動点/動顛/鬧天/
どうてんけっしょう /同点決勝/
どうてんだん /同点弾/
どうでん /導電/道傳/道伝/
どうでんい /同電位/
どうでんせい /導電性/
どうでんたい /導電体/
どうでんりつ /導電率/
どうでんりょく /動電力/
どうと /道都;札幌の異名/
どうとう /同等/道東/同党/堂塔/道統/
どうとういじょう /同等以上/
どうとうがらん /堂塔伽藍/
どうとうきのう /同等機能/
どうとうせい /同等性/
どうとうひん /同等品/
どうとうほうめん /道東方面/
どうとく /道徳/
どうとくか /道徳家/
どうとくかん /道徳観/道徳感/
どうとくきはん /道徳規範/
どうとくきょういく /道徳教育/
どうとくけいじじょうがく /道徳形而上学/
どうとくしん /道徳心/
どうとくじょう /道徳上/
どうとくせい /道徳性;morality/動特性;kinetics/
どうとくてき /道徳的/
どうとくてきけんち /道徳的見地/
どうとくてつがく /道徳哲学/
どうとくてん /同得点/
どうとくほうそく /道徳法則/
どうとんぼり /道頓堀/
どうどう /堂々/同道/道々/道道;北海道が管理する道/
どうどうめぐり /堂々巡り/
どうない /道内/
どうないじこくひょう /道内時刻表/
どうないよう /同内容/
どうなが /胴長/
どうなべ /銅鍋/
どうなん /道南/
どうにゅう /導入/
どうにゅういぜん /導入以前/
どうにゅうかいし /導入開始/
どうにゅうかのう /導入可能/
どうにゅうき /導入期/
どうにゅうきょういく /導入教育/
どうにゅうぐち /導入口/
どうにゅうご /導入後/
どうにゅうざい /導入剤/
どうにゅうしえん /導入支援/
どうにゅうしょき /導入初期/
どうにゅうじ /導入時/
どうにゅうじょう /導入上/
どうにゅうちょくぜん /導入直前/
どうにゅうてき /導入的/
どうにゅうとうしょ /導入当初/
どうにゅうぶ /導入部/
どうにゅうぶぶん /導入部分/
どうにゅうほう /導入法/
どうにゅうほうほう /導入方法/
どうにゅうまえ /導入前/
どうにょう /導尿/
どうにょうかん /導尿管/
どうにん /同人/
どうねん /同年/動燃/道念/
どうねんだい /同年代/
どうねんど /動粘度/
どうねんぱい /同年輩/
どうねんれい /同年齢/
どうのじ /々/
どうのじてん /同の字点;々/々/
どうは /導波/道破/
どうはい /同輩/
どうはかん /導波管/
どうはく /銅箔/
どうはち /銅鉢/
どうはろ /導波路/
どうはん /同伴/
どうはんきょうぎしゃ /同伴競技者/
どうはんしゃ /同伴者/
どうば /同馬/
どうばち /銅鉢/
どうばり /胴張/胴張り/
どうばん /銅板/銅版/銅盤/
どうばんが /銅版画/
どうばんがてん /銅版画展/
どうばんぐみ /同番組/
どうひ /同飛/同妃/胴皮/
どうひつ /同筆/
どうひょう /道標/同表/
どうびょう /同病/
どうびょういん /同病院/
どうびょうし /銅拍子/
どうふ /豆腐/同歩/
どうふう /同封/同風/
どうふく /同腹/道服/
どうふけん /道府県/
どうふけんぜい /道府県税/
どうふけんみんぜい /道府県民税/
どうふごう /同符号/
どうぶ /胴部/童舞/
どうぶく /道服/胴服/
どうぶち /胴縁/
どうぶつ /動物/
どうぶつあいご /動物愛護/
どうぶつあいごきょうかい /動物愛護協会/
どうぶつあいごだんたい /動物愛護団体/
どうぶつあいごほう /動物愛護法/
どうぶつえん /動物園/
どうぶつえんせん /動物園線/
どうぶつえんまえ /動物園前/
どうぶつかい /動物界/
どうぶつがく /動物学/
どうぶつがくしゃ /動物学者/
どうぶつぎゃくたい /動物虐待/
どうぶつぐん /動物群/
どうぶつこうどうがく /動物行動学/
どうぶつしつ /動物質/
どうぶつしゃかいがく /動物社会学;animal sociology/
どうぶつしゃしん /動物写真/
どうぶつしんりがく /動物心理学;zoopsychology/
どうぶつじっけん /動物実験/
どうぶつせい /動物性/
どうぶつせいたんぱくしつ /動物性蛋白質/
どうぶつそう /動物相;[生物]fauna/
どうぶつたち /動物達/
どうぶつちゅうしん /動物中心/
どうぶつちりがく /動物地理学;zoogeography/
どうぶつてき /動物的/
どうぶつびょういん /動物病院/
どうぶつめい /動物名/
どうぶつゆ /動物油/
どうぶるい /胴震い/
どうぶん /同文/
どうぶんしょ /同文書/
どうぶんや /同分野/
どうべや /同部屋/
どうべんきこう /動弁機構/
どうほう /同胞;†conpatriot.「-意識」/同法/同報/同朋;†仲間/同袍;(原義:上衣を共用する)親しい仲間/
どうほうあん /同法案/
どうほうこう /同方向/
どうほうこく /同報告/
どうほうつうしん /同報通信/
どうほく /道北/
どうほこ /銅矛/銅鉾/
どうぼ /同母/
どうぼいん /同母音/
どうぼう /同朋/同房/
どうま /胴間/
どうまき /胴巻/
どうまごえ /胴間声/
どうまさつ /動摩擦/
どうまさつけいすう /動摩擦係数/
どうまさつりょく /動摩擦力/
どうまる /胴丸/
どうまわり /胴回り/
どうまん /道満;姓/
どうみゃく /動脈/
どうみゃくけっちゅう /動脈血中/
どうみゃくけつ /動脈血/
どうみゃくこうか /動脈硬化/
どうみゃくさいけつ /動脈採血/
どうみゃくさんぎょう /動脈産業/
どうみゃくじょう /動脈上/
どうみゃくちゅう /動脈中/
どうみゃくない /動脈内/
どうみゃくりゅう /動脈瘤/
どうみょう /同苗/
どうみょうじ /道明寺/
どうみょうじこ /道明寺粉/
どうみょうじほしい /道明寺糒/
どうみん /道民/
どうみんぜい /道民税/
どうめい /同盟/同名/
どうめいいじん /同名異人/
どうめいえいが /同名映画/
どうめいかんけい /同盟関係/
どうめいきゅうこう /同盟休校/
どうめいきょく /同名曲/
どうめいぐん /同盟軍/
どうめいこく /同盟国/
どうめいし /動名詞/同名市/
どうめいしゃ /同盟者/
どうめいひぎょう /同盟罷業/
どうめいひこう /同盟罷工;同盟罷業に同じ/
どうめだりすと /銅メダリスト/
どうめだる /銅メダル/
どうめん /道面/道免/
どうもう /獰猛/童蒙;子供/艟艨;軍艦/
どうもく /瞠目/
どうもと /胴元;博奕の-/堂本;人名/
どうもり /堂守/
どうもん /同門;fellow/洞門/
どうや /同夜/銅谷/
どうやく /同役/
どうゆう /同友/道有/同憂/
どうゆうかい /同友会/
どうゆうち /道有地/
どうよう /同様/動揺/童謡/童幼/
どうよく /胴欲/
どうら /銅鑼/
どうらく /道楽/
どうらくはんぶん /道楽半分/
どうらくむすこ /道楽息子/
どうらくむすめ /道楽娘/
どうらくもの /道楽者/
どうらん /動乱/胴乱/銅藍/
どうり /道理/
どうりきがく /動力学/
どうりきがくてき /動力学的/
どうりつ /同率/道立/
どうりつしゅい /同率首位/
どうりつゆうしょう /同率優勝/
どうりゅう /同流/
どうりょう /同僚/同量/
どうりょうきん /同料金/
どうりょうじょうし /同僚上司/
どうりょうやく /同僚役/
どうりょく /動力/
どうりょくいん /動力因;アリストテレス/
どうりょくかっくうき /動力滑空機/
どうりょくげん /動力源/
どうりょくしげん /動力資源/
どうりょくしゃ /動力車/
どうりょくしゅうちゅう /動力集中/
どうりょくせいのう /動力性能/
どうりょくせん /動力船/
どうりょくそうち /動力装置/
どうりょくだいしゃ /動力台車/
どうりょくでんたつけい /動力伝達系/
どうりょくでんたつそうち /動力伝達装置/
どうりょくひ /動力費/
どうりょくぶ /動力部/
どうりょくろ /動力炉/
どうりん /動輪/
どうりんけい /動輪径/
どうるい /同類/
どうるいこう /同類項/
どうれつ /同列/
どうれつし /同列視/
どうれべる /同レベル/
どうれん /道連/
どうろ /道路/
どうろうんそうしゃりょう /道路運送車両/
どうろうんそうしゃりょうほう /道路運送車両法/
どうろかくちょう /道路拡張/
どうろかんけい /道路関係/
どうろかんりしゃ /道路管理者/
どうろがわ /道路側/
どうろぎょうせい /道路行政/
どうろくじん /道陸神/
どうろけいかく /道路計画/
どうろけんせつ /道路建設/
どうろこうじ /道路工事/
どうろこうだん /道路公団/
どうろこうつう /道路交通/
どうろこうつうほう /道路交通法/
どうろこんざつ /道路混雑/
どうろじじょう /道路事情/
どうろじじょうなど /道路事情等/
どうろじゅうたい /道路渋滞/
どうろじょう /道路上/
どうろじょうきょう /道路状況/
どうろじょうほう /道路情報/
どうろせいび /道路整備/
どうろせん /同路線/
どうろぜい /道路税/
どうろぞい /道路沿い/道路沿/
どうろぞく /道路族/
どうろだい /道路代/
どうろちず /道路地図/
どうろちゅうおう /道路中央/
どうろちょう /道路長/
どうろちょうさ /道路調査/
どうろとうけい /道路統計/
どうろはば /道路幅/
どうろばんごう /道路番号/
どうろひょうしき /道路標識/
どうろひょうじ /道路標示/道路表示/
どうろふくいん /道路幅員/
どうろほう /道路法/
どうろみぎがわ /道路右側/
どうろもう /道路網/
どうろゆそう /道路輸送/
どうろようりょう /道路容量/
どうろよこ /道路横/
どうろわき /道路脇/
どうわ /童話/同和/道話/
どうわかん /童話館/
どうわがくしゅう /同和学習/
どうわきょういく /同和教育/
どうわく /同枠/
どうわくば /同枠馬/
どうわげき /童話劇/
どうわこうぎょう /同和鉱業/
どうわさっか /童話作家/
どうわさべつ /同和差別/
どうわしゅう /童話集/
どうわたいさくじぎょう /同和対策事業/
どうわちく /同和地区/
どうわちくじゅうみん /同和地区住民/
どうわぶらく /同和部落/
どうわもんだい /同和問題/
どおし /同士/
どおり /通り/通/
どかい /土塊/
どかた /土方/
どかべん /どか弁/
どかゆき /ドカ雪/どか雪/
どかん /土管/
どがい /度外/
どがいし /度外視/
どがま /土釜/
どき /土器/怒気/時/度器/
どきがわ /土器川/
どきゅう /土休/弩級;dreadnought/弩弓;crossbow/
どきょう /度胸/読経/
どきょういっぱつ /度胸一発/
どきょうだめし /度胸試し/
どきん /土禁/
どぎも /度肝/
どく /毒/独/読/得/徳/獨;「独」の旧字/髑;髑髏/讀;旧字/
どく> /独;[略語]ドイツ.-首脳,-検/毒;毒饅頭,毒ガス,毒カレー/
どくあたり /毒中り/
どくいり /毒入り/毒入/
どくえい /独英/独泳/
どくえき /毒液/
どくえさ /毒餌/
どくえん /独演/
どくおう /独往/
どくかい /読解/
どくかいりょく /読解力/
どくが /毒牙/毒蛾/
どくがい /毒害/
どくがく /独学/
どくがくしゃ /独学者/
どくがし /毒菓子/
どくがす /毒ガス/
どくがろん /独我論/
どくがん /独眼/
どくがんりゅう /独眼竜/
どくがんりゅうまさむね /独眼竜政宗/
どくきのこ /毒茸/毒キノコ/
どくきんほう /独禁法/
どくぎょ /毒魚/
どくぎん /独吟/
どくぐも /毒蜘蛛/
どくぐん /独軍/
どくけ /毒気/
どくけし /毒消し/
どくげん /独言/
どくご /読後/独語/
どくごかん /読後感/
どくごかんそう /読後感想/
どくごかんそうぶん /読後感想文/
どくさい /独裁/
どくさいこっか /独裁国家/
どくさいしゃ /独裁者/
どくさいせい /独裁制/
どくさいせいけん /独裁政権/
どくさいせいじ /独裁政治/
どくさいたいせい /独裁体制/
どくさいてき /独裁的/
どくさつ /毒殺/
どくざ /独座/
どくざいろん /独在論;solipsism/
どくし /毒死/
どくしゃ /読者/
どくしゃがわ /読者側/
どくしゃさんか /読者参加/
どくしゃしょうたい /読者招待/
どくしゃじしん /読者自身/
どくしゃすう /読者数/
どくしゃぜんいん /読者全員/
どくしゃそう /読者層/
どくしゃたいしょう /読者対象/
どくしゃとうこう /読者投稿/
どくしゃとうひょう /読者投票/
どくしゃらん /読者欄/
どくしゅ /毒手/毒酒/
どくしゅう /独習/独修/
どくしゅうしょ /独習書/
どくしょ /読書/
どくしょう /独唱/読誦;声に出してよむこと/
どくしょうしゃ /独唱者/
どくしょか /読書家/
どくしょかい /読書会/
どくしょかんそうぶん /読書感想文/
どくしょけいこう /読書傾向/
どくしょさんとう /読書三到/
どくしょさんよ /読書三余/
どくしょしゅうかん /読書週間/
どくしょしょうがい /読書障害/
どくしょしょうゆう /読書尚友/
どくしょじん /読書人/
どくしょとう /読書灯/
どくしょひゃっぺん /読書百遍/
どくしょりょく /読書力/
どくしょれき /読書歴/
どくしん /独身/読唇/
どくしんおとこ /独身男/
どくしんきぞく /独身貴族/
どくしんしゃ /独身者/
どくしんじだい /独身時代/
どくしんじゅつ /読唇術/読心術/
どくしんじょせい /独身女性/
どくしんせいかつ /独身生活/
どくしんだんせい /独身男性/
どくしんどうし /独身同士/
どくしんもの /独身者/
どくしんりょう /独身寮/
どくじ /独自/
どくじかいはつ /独自開発/
どくじかいろ /独自回路/
どくじきかく /独自規格/
どくじぎじゅつ /独自技術/
どくじしよう /独自仕様/
どくじせい /独自性/
どくじちょうさ /独自調査/
どくじほうしき /独自方式/
どくじもじ /独自文字/
どくじゃ /毒蛇/
どくじゅ /読誦/
どくじろせん /独自路線/
どくじん /毒刃/
どくすい /毒水/
どくず /読図/
どくせい /毒性/
どくせいじっけん /毒性実験/
どくせいひょうか /毒性評価/
どくせいぶん /毒成分/
どくせき /毒螫/
どくせん /独占/毒腺/独擅/
どくせんか /独占化/
どくせんかかく /独占価格/
どくせんきぎょう /独占企業/
どくせんきんしほう /独占禁止法/
どくせんけいやく /独占契約/
どくせんけん /独占権/
どくせんしほん /独占資本;monopolist capital/
どくせんしほんしゅぎ /独占資本主義/
どくせんしよう /独占使用/
どくせんじょう /独擅場/
どくせんじょうたい /独占状態/
どくせんてき /独占的/
どくせんはんばい /独占販売/
どくせんゆにゅう /独占輸入/
どくせんよく /独占欲/
どくぜつ /毒舌/
どくぜつか /毒舌家/
どくぜつせん /毒舌戦/
どくぜん /独善/
どくぜんけいこう /独善傾向/
どくぜんしゃ /独善者/
どくぜんしゅぎ /独善主義/
どくぜんせい /独善性/
どくぜんてき /独善的/
どくそ /毒素/
どくそう /独走/独奏/独創/毒草/
どくそうかい /独奏会/
どくそうきょく /独奏曲/
どくそうきょくぜんしゅう /独奏曲全集/
どくそうしゃ /独奏者/独創者/
どくそうじょうたい /独走状態/
どくそうせい /独創性/
どくそうてき /独創的/
どくそうよう /独奏用/
どくそうりょく /独創力/
どくそん /独尊/独存/獨尊/
どくたけ /毒茸/
どくだけ /毒茸/
どくだみか /ドクダミ科/Saururaceae/
どくだん /独断/
どくだんじょう /独壇場/
どくだんせんこう /独断専行/
どくだんてき /独断的/
どくだんろん /独断論/
どくち /毒血/
どくとく /独特/独得/
どくにんじん /毒人参/
どくぬき /毒抜き/
どくは /読破/
どくはい /毒杯/
どくはく /独白/
どくはくたい /独白体;monologue/
どくばり /毒針/
どくひつ /毒筆/
どくふ /読譜/毒婦/
どくふつ /独仏/
どくぶつ /毒物/
どくぶつがく /毒物学;toxicology/
どくぶん /独文/
どくぶんか /独文科/
どくへび /毒蛇/
どくほん /読本/
どくぼう /独房/
どくみ /毒見/
どくみょう /独明/
どくむぎ /毒麦/
どくむし /毒虫/
どくや /毒矢/
どくやく /毒薬/独訳;ドイツ語訳/
どくらく /独楽/
どくりつ /独立/
どくりつあん /独立案/
どくりつうんどう /独立運動/
どくりつえいようせいぶつ /独立栄養生物/
どくりつかいぎょう /独立開業/
どくりつがた /独立型/
どくりつきかん /独立機関/
どくりつきねんかん /独立記念館/
どくりつきねんび /独立記念日/
どくりつぎゆうぐん /独立義勇軍/
どくりつぎょうせいほうじん /独立行政法人/
どくりつぐれんたい /独立愚連隊/
どくりつけい /独立系/
どくりつこく /独立国/
どくりつこっか /独立国家/
どくりつこっかきょうどうたい /独立国家共同体;CIS/
どくりつご /独立語/独立後/
どくりつさいさん /独立採算/
どくりつさいさんせい /独立採算制/
どくりつしん /独立心/
どくりつじぎょうしゃ /独立事業者/
どくりつじしょう /独立事象/
どくりつじそん /独立自尊/
どくりつじゅ /独立樹/
どくりつせい /独立性/
どくりつせいりょく /独立勢力/
どくりつせんげん /独立宣言/
どくりつせんそう /独立戦争/
どくりつだいがくいん /独立大学院/
どくりつだんたい /独立団体/
どくりつてき /独立的/
どくりつてん /独立点/
どくりつとう /独立党/
どくりつどっぽ /独立独歩/
どくりつふき /独立不羈/
どくりつへんすう /独立変数/
どくりつみんぞく /独立民族/
どくりょう /読了/
どくりょうご /読了後/
どくりょく /独力/
どくろ /髑髏/
どくわ /独和;独和辞典/読話;読唇術/独話/
どぐう /土偶/
どけい /時計/
どけん /土建/
どけんぎょう /土建業/
どけんぎょうしゃ /土建業者/
どけんや /土建屋/
どげざ /土下座/
どこ /何処/床/何所/
どこう /土工/土光/土侯/
どこか /何処か/
どこそこ /何処其処/
どこでも /何処でも/
どことなく /何処と無く/
どこふくかぜ /何処吹く風/どこ吹く風/
どこまで /何処迄/
どこまでも /何処迄も/
どこら /何処ら/
どこらへん /どこら辺/
どころ /所/処/
どこんじょう /ど根性/
どご /土語/
どごう /怒号/土豪/
どごうれっしん /土豪劣紳/
どさくさまぎれ /どさくさ紛れ/
どさけん /ドサ健/
どさまわり /ドサ回り/どさ回り/
どさん /土讃/
どさんこ /道産子/
どざえもん /土左衛門/
どし /年/
どしー /℃/
どしつ /土質/怒叱/
どしゃ /土砂/
どしゃくずれ /土砂崩れ/
どしゃさいがい /土砂災害/
どしゃぶり /土砂降り/どしゃ降り/
どしゅう /土州;土佐/
どしょう /土性;姓/
どしょうぼね /土性骨/
どしょうまち /道修町/
どしろうと /ド素人/ど素人/
どじょう /土壌/泥鰌/鰌/鰍/鯲/土壤;旧字/
どじょうおせん /土壌汚染/
どじょうおせんたいさくほう /土壌汚染対策法/
どじょうおせんぼうしほう /土壌汚染防止法;[法][略語]農用地の土壌の汚染防止等に関する法律/
どじょうがく /土壌学;pedology/
どじょうがた /土壌型/
どじょうすくい /泥鰌掬い;宴会芸/
どじょうない /土壌内/
どじょうなべ /泥鰌鍋/
どじょうめん /土壌面/
どじん /土人/
どすう /度数/
どすうぶんぷ /度数分布/
どすごえ /どす声/
どすてば /土捨場/
どせい /土星/怒声/土製/
どせいけい /土星系/
どせき /土石/
どせきりゅう /土石流/
どせきりゅうはっせい /土石流発生/
どそう /土葬/土倉/
どそく /土足/
どぞう /土蔵/
どぞうづくり /土蔵造り;[建築]木造部分を完全に塗り込める/
どぞく /土俗/
どぞくてき /土俗的/
どたぐつ /どた靴;clodhopper/
どたばたきげき /どたばた喜劇/
どたばたげき /ドタバタ劇/
どたんば /土壇場/
どだい /土台/土代;文書の草案/
どだん /土壇/
どち /何方/
どちゃく /土着/
どちゃくみんぞく /土着民族/
どちゅう /土中/
どちょう /怒張/度牒/
どちら /何方/
どっか /読過/
どっかい /読解/読会/
どっかいのうりょく /読解能力/
どっかいりょく /読解力/
どっかいりょくぶそく /読解力不足/
どっかく /独覚/
どっき /毒気/
どっきょ /独居/
どっきょう /読経/
どっきょうだいがく /独協大学/
どっきょぼう /独居房/
どっきょろうじん /独居老人/
どっきんほう /独禁法/
どっけ /毒気/
どっけつしょう /毒血症;[医]blood poisoning/
どっこ /独鈷/
どっこう /独行/
どっこうせん /独航船/
どっち /何方/
どっちみち /何方道/
どっと /ドッと/
どっとたんい /ドット単位/
どっぷらーこうか /ドップラー効果/
どっぽ /独歩/
どつ /肭/
どて /土手/塢/土堤/
どてぐち /土手口/
どてっぱら /土手っ腹/
どてなべ /土手鍋/
どてみち /土手道/
どてら /褞袍/
どとう /怒涛;異体字/怒濤/
どどいつ /都々逸/
どどめ /土留め/
どどめいろ /どどめ色/
どなた /何方/
どなべ /土鍋/
どなり /隣/鄰;「隣」の異体字/
どなりごえ /怒鳴り声/
どにち /土日/
どにちいがい /土日以外/
どにちきゅうじつ /土日休日/
どにちげつ /土日月/
どにちしゅくじつ /土日祝日/
どにちしゅくじついがい /土日祝日以外/
どにちちゅう /土日中/
どの /殿/何の/
どの> /何の/
どのう /土嚢/
どのかた /何の方;(要ルビ)/どの方/
どのへん /どの辺/
どのみち /何の道/
どのよう /何の様/
どはずれ /度外れ/
どはつ /怒髪/
どはで /ド派手/
どば /土場/駑馬/
どばし /土橋/
どばと /土鳩/
どひ /土肥/土樋/奴婢/
どひょう /土俵/
どひょういり /土俵入り/土俵入/
どひょうぎわ /土俵際/
どひょうちゅうおう /土俵中央/
どひょうば /土俵場/
どびゃくしょう /土百姓/
どびょうし /銅拍子/
どびん /土瓶/
どびんむし /土瓶蒸し/土瓶蒸/
どふん /土墳/
どぶ /溝/
どぶいた /溝板/ドブ板/
どぶがい /蚌/
どぶがわ /溝川/ドブ川/
どぶさらい /溝浚い/
どぶにうむ /Db/Dubnium/
どぶねずみ /溝鼠/
どぶろ /土風炉/
どぶろく /濁酒/濁醪/
どへき /土壁/
どへた /ド下手/ど下手/
どべい /土塀/
どほうがかい /土崩瓦解/
どぼく /土木/奴僕/
どぼくがく /土木学/
どぼくぎょう /土木業/
どぼくぎょうしゃ /土木業者/
どぼくけい /土木系/
どぼくけんせつ /土木建設/
どぼくこうがく /土木工学;civil engineering(CE)/
どぼくこうじ /土木工事/
どぼくさぎょうよう /土木作業用/
どぼくひ /土木費/
どま /土間/
どまり /止まり/
どまんじゅう /土饅頭;墓/
どまんなか /ど真ん中/ド真中/
どみのたおし /ドミノ倒し/
どみのりろん /ドミノ理論/
どみん /土民/
どめ /度目/
どめいんめい /ドメイン名/
ども /共/吃/
どもえ /巴/
どもり /土盛り/吃り/度盛り;scale/
どもん /土門/
どやがい /どや街/
どよう /土曜/土用;-の丑/
どようしんや /土曜深夜/
どようにちよう /土曜日曜/
どようばん /土曜晩/
どようび /土曜日/
どようびしゅっぱつ /土曜日出発/
どら /銅鑼/鐃/鑼/錚/
どらいぶかん /ドライブ感/
どらえもん /ドラえもん/
どらごえ /どら声/
どらねこ /どら猫;魚を銜えます/ドラ猫/
どらびだごぞく /ドラビダ語族;[言語]Dravidian/
どらふとかいぎ /ドラフト会議/
どらまか /ドラマ化/
どらむかん /ドラム缶/
どらむしき /ドラム式/
どらむすこ /ドラ息子/どら息子/
どらやき /銅鑼焼/銅鑼焼き/
どらわん /銅羅湾/
どり /取り/鳥/鶏/
どりすしき /ドリス式;[建築]Doric order. ギリシア建築の様式/
どりすじん /ドリス人;Doric/
どりょう /度量/
どりょうこう /度量衡/
どりょく /努力/
どりょくか /努力家/
どりょくかてい /努力過程/
どりょくぎむ /努力義務/
どりょくしょう /努力賞/
どりょくちゅう /努力中/
どりょくもくひょう /努力目標/
どりんくざい /ドリンク剤;徹夜のお共/
どる /＄;dollar/
どるい /土塁;mound/土類;アルカリ-/
どるいきんぞく /土類金属/
どるいどきょう /ドルイド教/
どるうり /ドル売り/
どるえん /ドル円/
どるがい /ドル買い;有事の-/
どるさつ /ドル札/
どるそうば /ドル相場/
どるだか /ドル高/
どるだて /ドル建て/
どるばこ /ドル箱/
どるやす /ドル安/
どれ /何れ/
どれい /奴隷/土鈴/
どれいかいほう /奴隷解放/
どれいしゅ /奴隷主/
どれいしょうにん /奴隷商人/
どれいせい /奴隷制/
どれいせいしゃかい /奴隷制社会/
どれいせいど /奴隷制度/
どれいせん /奴隷船/
どれいたち /奴隷達/
どれいてき /奴隷的/
どれいどうとく /奴隷道徳;キリスト教道徳。/
どれいぼうえき /奴隷貿易/
どれか /何れか/
どれすすがた /ドレス姿/
どろ /泥/土呂/
どろあし /泥足/
どろうみ /泥海/
どろえ /泥絵/
どろえのぐ /泥絵の具/
どろぐつ /泥靴;muddy boots/
どろじあい /泥仕合/泥試合;※「泥仕合」の誤りとされる/
どろじょう /泥状/
どろた /泥田/
どろつち /泥土/
どろてき /泥的/
どろどろ /泥々/
どろなわ /泥縄/
どろぬま /泥沼/
どろぬまか /泥沼化/
どろぬまりゅう /泥沼流/
どろはね /泥跳ね;雨の日に/
どろぱっく /泥パック/
どろぶね /泥舟/泥船/
どろぼう /泥棒/
どろぼうたいさく /泥棒対策/
どろぼうねこ /泥棒猫/
どろまみれ /泥塗れ/
どろみず /泥水/
どろみち /泥道/泥路/
どろよけ /泥除け/
どろんこ /泥んこ/
どわすれ /度忘れ/ど忘れ/
どん /丼/鈍/曇;曇天/呑;併呑/貪;貪欲/嫩;(わかい)/緞;緞子/
どんか /鈍化/
どんかく /鈍角/
どんかくさんかくけい /鈍角三角形/
どんかくさんかっけい /鈍角三角形/
どんかん /鈍感/
どんき /鈍器/
どんぐり /団栗/團栗;「団」旧字/
どんぐりまなこ /団栗眼/
どんこう /鈍行/
どんこん /鈍根/
どんさい /鈍才/
どんしゅう /呑舟;-の魚/
どんしょく /貪食/曇色/
どんしょくさいぼう /貪食細胞;[生物]phagocyte (=食細胞)/
どんじゅう /鈍重/
どんじり /どん尻/
どんす /緞子/
どんそく /鈍足/
どんぞこ /どん底/
どんちゃんさわぎ /どんちゃん騒ぎ/
どんちょう /緞帳/
どんつう /鈍痛/
どんづまり /どん詰まり/どん詰り/
どんてん /曇天/
どんでんがえし /どんでん返し/
どんと /呑吐/
どんとう /鈍刀/
どんとほうしき /ドント方式;D'Hondt method/
どんびゃくしょう /どん百姓/
どんぶつ /鈍物/
どんぶり /丼/
どんぶりかんじょう /丼勘定/
どんぶりばち /丼鉢;-ゃ浮いた浮いた/
どんぶりめし /丼飯/
どんぶりもの /丼物/
どんま /鈍麻;†感覚が鈍くなる/鈍磨;†磨り減って鈍くなる/
どんもの /丼物/
どんよく /貪欲/
どんよくさ /貪欲さ/
どんらん /貪婪/曇鸞/
どんりょく /嫩緑/
どんるい /丼類/
な /名/菜/奈;奈良/那;那覇/娜;(呉音) 婀娜(あだ)/儺;追儺(ついな)/茄;茄子/拿;(呉音) 拿捕(だほ)/無;南無/南;(慣用音)/納;納屋/魚/
なーすふく /ナース服/
なあて /名宛/
なあてにん /名宛人/
ない /内/無/乃/地震/
ない> /内/
ないあつ /内圧/
ないい /内意/
ないいん /内因/内院/内印;天皇のハンコ/
ないいんせい /内因性/
ないうちゅう /内宇宙/
ないえ /奈井江/
ないえつ /内閲/内謁/
ないえん /内縁/内炎;[化学]⇔外炎/内苑;皇居-/内宴/
ないおう /内奥;deep inside/内応;裏切り/
ないか /内科/内化/内火/
ないかい /内科医/内界/内回/内海/
ないかいこうろ /内海航路/
ないかく /内閣/内角;inside/内郭;「城の-」/内格;[文法]inessive/
ないかくかいぞう /内閣改造/
ないかくかんぼう /内閣官房/
ないかくかんぼうちょうかん /内閣官房長官/
ないかくきゅう /内角球/
ないかくくんれい /内閣訓令/
ないかくこくじ /内閣告示/
ないかくしじりつ /内閣支持率/
ないかくせい /内閣制/
ないかくそうじしょく /内閣総辞職/
ないかくそうりだいじん /内閣総理大臣/
ないかくふ /内閣府;総理府、経済企画庁、沖縄開発庁が2001年1月の中央省庁再編で再編されたもの/
ないかくふしんにん /内閣不信任/
ないかくふしんにんあん /内閣不信任案/
ないかくぶんこ /内閣文庫/
ないかくほう /内閣法/
ないかてき /内科的/
ないかひ /内果皮/
ないかん /内観/内患/内官/
ないかんりょうほう /内観療法;[精医]naikan therapy/
ないがい /内外/
ないがいかかくさ /内外価格差/
ないがいそう /内外装/
ないがしろ /蔑ろ/
ないがめん /内画面/
ないがん /内含/
ないき /内規/内記/
ないきじゅんかん /内気循環/
ないきょう /内教;仏教/
ないきょうぼう /内教坊/
ないきょく /内局/
ないきん /内勤/
ないぎ /内儀/
ないくう /内腔/内宮/
ないくん /内訓/
ないぐう /内宮/
ないぐぶ /内供奉/
ないけい /内径/
ないけん /内見/
ないげんご /内言語/
ないこう /内向;-的/内攻;retrocede/内訌/内項;inner term/
ないこうしょう /内交渉/
ないこうせい /内向性/
ないこうてき /内向的/
ないこく /内国/
ないこくかいしゃ /内国会社/
ないこくかわせ /内国為替;domestic exchange. ⇔外国為替/
ないこくさい /内国債/
ないこくさん /内国産/
ないこくさんしゅぼば /内国産種牡馬/
ないこくさんば /内国産馬/
ないこくじん /内国人/
ないこくみん /内国民/
ないこくみんたいぐう /内国民待遇/
ないこっかく /内骨格/
ないこん /内婚/
ないご /内語/
ないごう /内合/
ないごうがいじゅう /内剛外柔/
ないさい /内妻/内済/
ないさいぼうかい /内細胞塊/
ないざい /内在/
ないざいか /内在化/
ないざいせい /内在性/
ないざいてき /内在的/
ないざいぶつ /内在物/
ないし /乃至/内侍/〜/
ないしき /内式/
ないしきょう /内視鏡/
ないしきょうけんさ /内視鏡検査/
ないしつ /内室/
ないしどころ /内侍所/
ないしのかみ /尚侍/
ないしのつかさ /内侍司;[律令制]/
ないしゃく /内借/内戚/
ないしゃこう /内斜行/
ないしゅう /内周/
ないしゅうげん /内祝言/
ないしゅうちょう /内周長/
ないしゅっけつ /内出血/
ないしょ /内緒/内書/
ないしょう /内相;内務大臣/内証/内障/内鞘;[植物]pericycle/内省;宮中の役所/
ないしょうしき /内照式/
ないしょく /内職/
ないしょばなし /内緒話/
ないしん /内心/内診/内申/
ないしんおう /内親王/
ないしんしょ /内申書/
ないしんてん /内申点/
ないしんのう /内親王/
ないしんふくざつ /内心複雑/
ないじ /内示/内耳/内事/
ないじえん /内耳炎/
ないじしんけい /内耳神経/
ないじつ /内実/
ないじゅ /内需/
ないじゅうがいごう /内柔外剛/
ないじゅかくだい /内需拡大/
ないじゅどころ /内豎所/
ないじょ /内助/
ないじょう /内情/
ないじょのこう /内助の功/
ないじん /内陣/
ないすん /内寸/
ないせい /内政/内省/内製/内生/内声/
ないせいかんしょう /内政干渉/
ないせいき /内性器/
ないせいじょう /内清浄/
ないせいてき /内省的/
ないせいふかんしょう /内政不干渉/
ないせいほうこく /内省報告/
ないせいもんだい /内政問題/
ないせいり /内整理/
ないせき /内積/内戚/
ないせつ /内接/
ないせつえん /内接円/
ないせん /内線;extension.「-番号」/内戦;civil war/
ないせんじょう /内線上/
ないせんじょうたい /内戦状態/
ないせんでんわ /内線電話/
ないせんでんわもう /内線電話網/
ないせんばんごう /内線番号/
ないせんひょう /内線表/
ないせんもう /内線網/
ないぜん /内膳/
ないそう /内装/内挿;[数学]interpolation/内層/内奏;非公式に奏上する/内争;内輪揉め/
ないそうこうじ /内装工事/
ないそうほう /内挿法/
ないそく /内側;⇔がいそく/内足/内則;≒内規/
ないぞう /内蔵;†built-in.「-HDD」/内臓;†organs.「-疾患」/
ないぞう> /内蔵;-HDD/
ないぞうおんげん /内蔵音源/
ないぞうかのう /内蔵可能/
ないぞうかんかく /内臓感覚;[生理]体内の諸感覚/
ないぞうがた /内蔵型/
ないぞうき /内蔵機/
ないぞうけい /内臓系/
ないぞうこてい /内蔵固定/
ないぞうしっかん /内臓疾患/
ないぞうしぼうしょうこうぐん /内臓脂肪症候群/
ないぞうでんち /内蔵電池/
ないぞうとけい /内蔵時計/
ないぞうどけい /内蔵時計/
ないぞうはれつ /内臓破裂/
ないぞうほうしき /内蔵方式/
ないぞうよう /内蔵用/
ないぞうろしゅつけい /内蔵露出計/
ないぞく /内属/
ないたい /内帯/内体/
ないたいせつ /内体説/
ないたつ /内達/
ないだい /内題/
ないだいじん /内大臣/
ないだく /内諾/
ないだん /内談/
ないち /内地/内治/
ないつう /内通/
ないつうしゃ /内通者/
ないてい /内定/内偵/内庭/
ないていしき /内定式/
ないていしゃ /内定者/
ないていしょ /内定書/
ないていひ /内廷費/
ないてき /内的/
ないてん /内転/内点/内典/
ないてんきん /内転筋;太ももの内側の筋肉。野球のピッチャーが痛めたりする。/
ないてんほう /内点法/
ないとう /内藤/
ないど /内帑/
ないどう /内道;内法,⇔外道,外法/
ないどきん /内帑金/
ないない /内々/無い無い/
ないないづくし /無い無い尽くし/
ないないてい /内々定/
ないにゅう /内乳/
ないねん /内燃/内捻/
ないねんき /内燃機/
ないねんきかん /内燃機関/
ないはいよう /内胚葉/
ないはおん /内破音;[音声学]implosive/
ないはつ /内発/
ないはつてき /内発的/
ないひ /内皮/内秘/
ないふ /内府/
ないふく /内服/内福/
ないふくえき /内服液/
ないふくやく /内服薬/
ないふん /内紛/
ないぶ /内部/
ないぶかいろ /内部回路/
ないぶかんさ /内部監査/
ないぶかんすう /内部関数/
ないぶきこう /内部機構/
ないぶきてい /内部規定/
ないぶきりつ /内部規律/
ないぶけいざい /内部経済;internal economies/
ないぶけいしき /内部形式/
ないぶけつごう /内部結合/
ないぶこーど /内部コード/
ないぶこうせい /内部構成/
ないぶこうぞう /内部構造/
ないぶこくはつ /内部告発/
ないぶしょうがい /内部障害/
ないぶしょり /内部処理/
ないぶしよう /内部仕様/
ないぶしりょう /内部資料/
ないぶじかん /内部時間/
ないぶじじょう /内部事情/
ないぶじゅうりょくは /内部重力波/
ないぶじゆうど /内部自由度/
ないぶじょうたい /内部状態/
ないぶじょうほう /内部情報/
ないぶせい /内部生/
ないぶせってい /内部設定/
ないぶせん /内部線/
ないぶそうさ /内部操作/
ないぶそうしょく /内部装飾/
ないぶそしき /内部組織/
ないぶぞうせつ /内部増設/
ないぶだんせん /内部断線/
ないぶちょうさ /内部調査/
ないぶていこう /内部抵抗/
ないぶてき /内部的/
ないぶどうさ /内部動作/
ないぶは /内部波/
ないぶひずみ /内部歪/
ないぶひょう /内部表/
ないぶひょうか /内部評価/
ないぶひょうげん /内部表現/
ないぶぶきょく /内部部局/
ないぶぶんれつ /内部分裂/
ないぶへんすう /内部変数/
ないぶほうかい /内部崩壊/
ないぶむじゅん /内部矛盾/
ないぶもーど /内部モード/
ないぶもでる /内部モデル/
ないぶもんだい /内部問題/
ないぶりゅうほ /内部留保/
ないぶりょういき /内部領域/
ないぶん /内分/内文/内聞/
ないぶんぴ /内分泌/
ないぶんぴつ /内分泌/
ないぶんぴつけい /内分泌系/
ないへいせい /内閉性/
ないへき /内壁/
ないへん /内編/内篇/
ないほう /内包/内法;内道,⇔外法,外道/内方/内報/
ないほうてき /内包的/
ないほうろんり /内包論理/
ないまく /内幕;inside/内膜;[解剖]endosporium/
ないまぜ /綯い交ぜ/
ないみつ /内密/
ないむ /内務/
ないむしょう /内務省/
ないむだいじん /内務大臣/
ないめい /内命/
ないめん /内面/
ないめんか /内面化/
ないめんせい /内面性/
ないめんせいかつ /内面生活/
ないめんてき /内面的/
ないめんびょうしゃ /内面描写/
ないもう /内毛/
ないもうこ /内蒙古/
ないもの /無い物;-ねだり/
ないものねだり /無い物ねだり/
ないや /内野/
ないやあんだ /内野安打/
ないやく /内約/
ないやしゅ /内野手/
ないやじゆうせき /内野自由席/
ないやじん /内野陣/
ないやせき /内野席/
ないゆう /内憂/
ないゆうがいかん /内憂外患/
ないよう /内容/内用/内洋;⇔外洋/
ないよういぜん /内容以前/
ないよういちらん /内容一覧/
ないようかくにん /内容確認/
ないようぎんみ /内容吟味/
ないようこうかい /内容公開/
ないようこうがい /内容梗概/
ないようご /内容語;[言語]content word.⇔構造語/
ないようしだい /内容次第/
ないようしょうめい /内容証明/
ないようしょうめいゆうびん /内容証明郵便/
ないようじたい /内容自体/
ないようせき /内容積/
ないようせつめい /内容説明/
ないようちゅう /内容中/
ないようてき /内容的/
ないようどおり /内容通り/
ないようなど /内容等/
ないようは /内容派/
ないようふめい /内容不明/
ないようぶ /内容部/
ないようぶつ /内容物/
ないようぶんせき /内容分析/
ないようぶんるい /内容分類/
ないようへんこう /内容変更/
ないようべつ /内容別/
ないようほうふ /内容豊富/
ないようりょう /内容量/
ないらん /内覧/内乱/
ないらんかい /内覧会/
ないらんざい /内乱罪/
ないりく /内陸/
ないりくこく /内陸国/
ないりくせい /内陸性/
ないりくぶ /内陸部/
ないりょく /内力/
ないりん /内輪/
ないりんいがい /内輪以外/
ないりんさ /内輪差/
ないりんざん /内輪山/
ないれ /名入れ/
ないろんげん /ナイロン弦/
ないわくせい /内惑星/
ないわん /内湾/
なうて /名うて/
なうまんぞう /ナウマン象;Naumann's elephant/
なえ /苗/奈江/地震/
なえいろ /苗色/
なえうり /苗売り/
なえぎ /苗木/
なえこ /苗子/
なえしろ /苗代/
なえどこ /苗床/
なえなえ /萎え萎え;[口](副詞)気力の抜けるさま/
なえば /苗場/
なえばたけ /苗畑/
なえばやま /苗場山/
なえぼ /苗穂/
なえま /苗間/
なえむら /苗村/
なお /猶;more/尚;≒猶/直;straight/奈央;人名/奈緒/菜穂/
なお> /尚;-一層/猶/
なおあき /直明/尚明/
なおい /直井/
なおいち /直一/
なおいり /直入/
なおえ /直江/尚江/
なおえつ /直江津/
なおえつかん /直江津間/
なおかず /直一/直和/
なおかつ /猶且/直勝/
なおかわ /直川/
なおがき /尚書き/
なおき /直樹/直紀/直木/直毅/尚紀/直喜/
なおきしょう /直木賞/
なおきち /直吉/
なおこ /直子/尚子/奈緒子/奈保子/奈央子/菜桜子/菜生子/
なおさら /尚更/
なおざり /等閑/
なおし /直し/直/直志/尚史/直史/尚士/
なおしかた /直し方/
なおしま /直島/
なおじ /直治/
なおずみ /直純/尚純/
なおた /直田/
なおたか /直孝/
なおたけ /尚武/
なおと /直人/尚人/
なおとし /直敏/直利/尚稔/
なおなおがき /尚々書/尚尚書/
なおのぶ /直宣/
なおのり /直徳/尚憲/尚紀/
なおはら /猶原/
なおはる /直治/
なおひこ /直彦/尚彦/
なおひさ /直久/尚久/
なおひで /直秀/
なおひと /直人/直仁/
なおひろ /直宏/直弘/尚宏/尚弘/直大;名/直広/直廣/
なおふみ /直史/尚文/
なおまさ /直昌/
なおみ /直美/奈緒美/なお美/尚美/直実/奈穂美/奈保美/名保美/
なおみち /直道/
なおや /直也/尚也/尚哉/直弥/名親/
なおゆき /直之/直行/尚之/直幸/尚幸/
なおよし /直義/直良/尚良し/
なおれ /名折れ/
なか /中/那珂/仲/
なか#か /中#1日/
なか> /中;中棚,中落ち,(地名)中落合/
なかあし /中足/
なかあだち /中阿達/
なかい /中居/仲井/仲居/中井/
なかいえき /中井駅/
なかいけ /仲池/
なかいず /中伊豆/
なかいた /中板;[茶道]/
なかいち /中市/
なかいひでお /中井英夫/
なかいま /仲井真/
なかいみほ /中井美穂/
なかいり /中入/中入り;-後の勝敗/
なかいわ /中岩/
なかう /なか卯;[企業名]ファーストフード。www.nakau.co.jp/
なかうち /中内/
なかうま /中馬/
なかうみ /中海/
なかえ /中江/
なかえちょうみん /中江兆民;1847-1901/
なかお /中尾/
なかおか /中岡/
なかおかちまち /仲御徒町/
なかおく /中奥/
なかおし /中押し/
なかおち /中落ち/
なかおもて /中表/
なかおり /中折り/
なかおれ /中折れ/
なかおれぼうし /中折れ帽子/中折帽子/
なかかるいざわ /中軽井沢/
なかかわね /中川根/
なかかんすけ /中勘助;(1885-1965) 作家。『銀の匙』/
なかがい /仲買/
なかがいうち /中谷内/
なかがいにん /仲買人/
なかがき /中垣/
なかがた /中潟/
なかがみ /中上/
なかがみけんじ /中上健次/
なかがわ /中川/那珂川;†栃木県／福岡県/那賀川;†徳島県/仲川/
なかがわら /中河原/
なかき /中木/
なかきた /中北/中来田/
なかぎし /中岸/
なかぎょう /中京/
なかぎり /中桐/中限/
なかく /中区/
なかくぎ /中釘/
なかくら /中倉/仲倉/
なかくろ /・/
なかぐすく /中城/
なかぐち /中口/
なかぐろ /中黒/・/
なかけちょう /名掛丁/
なかこ /仲子/
なかこうじ /中小路;姓/仲小路/
なかこま /中巨摩/
なかご /中子/中心/
なかごう /中郷/
なかごし /中越/
なかごみ /中込/
なかごめ /中込/
なかごろ /中頃/中ごろ/
なかさき /中崎/
なかさく /中作/
なかさつない /中札内/
なかさと /中里/
なかさんげ /中山下/
なかざ /中座/
なかざいけ /中在家/
なかざき /中崎;姓/仲崎;姓/
なかざと /中里;姓/仲里;姓/
なかざわ /中澤;姓/中沢;姓/仲沢;姓/
なかし /仲仕/
なかした /中下/
なかしべつ /中標津/
なかしほろ /中士幌/
なかしま /中島;姓/中嶋;姓/
なかしょう /中庄/
なかしょく /中食/
なかじき /中敷/中敷き/
なかじきり /中仕切り/
なかじた /中舌/
なかじたぼいん /中舌母音;[音声学]central vowel/
なかじま /中島;姓/中嶋;姓/仲島;姓/中陦;姓/
なかじまあつし /中島敦;作家。『李陵』『山月記』/
なかじまつねゆき /中島常幸/
なかじまひこうきがいしゃ /中島飛行機会社/
なかじまふとう /中島埠頭/
なかじめ /中締め/
なかじゅく /中宿/
なかじょう /中条/中條/
なかす /中州/中洲;=中州/中須/
なかすぎ /中杉/
なかすじ /中筋/
なかすみ /中済/
なかず /中頭/中洲/
なかずとばず /鳴かず飛ばず/
なかずみ /中澄/
なかせ /中瀬/
なかせん /中仙/
なかせんどう /中山道/中仙道/
なかそ /中曽/
なかそね /仲宗根/中曽根/
なかそねやすひろ /中曽根康弘/
なかぞこ /中底;(靴の)insole/
なかぞの /中園/中薗/
なかぞら /中空/
なかた /中田/仲田/
なかたがい /仲違い/仲たがい/
なかたじま /中田島/
なかたじまさきゅう /中田島砂丘/
なかたど /仲多度/
なかたに /中谷/仲谷/
なかたね /中種子/
なかだ /中田/仲田/
なかだいら /中平/
なかだか /中高/
なかだし /中出し/
なかだち /媒/仲立/仲立ち/中立/
なかだちえいぎょう /仲立営業/
なかだちにん /仲立人/
なかだちょう /中田町/
なかだて /中舘;異体字/
なかだな /中棚/
なかだるみ /中弛み/中だるみ/
なかち /中地/仲地/
なかちく /中地区/
なかちょう /仲町/中長/
なかぢ /中地/
なかつ /中津/
なかつえ /中津江/中枝/
なかつか /中塚/
なかつかさ /中務/
なかつかさしょう /中務省/
なかつがる /中津軽/
なかつがわ /中津川/
なかつがわりんどう /中津川林道/
なかつぎ /中継ぎ/
なかつくに /中つ国/
なかつやま /中津山/
なかづり /中吊り/
なかづりこうこく /中吊り広告/
なかて /中手/中稲/
なかてん /中点/・/
なかで /中出/中手;[囲碁]「五目-は死」/
なかでも /中でも/
なかとう /中藤/
なかとがわ /中戸川/
なかとき /中時/
なかとさ /中土佐/
なかとじ /中綴じ/
なかとびら /中扉/
なかとみ /中富/
なかとんべつ /中頓別/
なかど /中戸/
なかなお /仲直/
なかなおり /仲直り/
なかなか /中々/中中/仲々/難々/
なかにいかわ /中新川/
なかにいだ /中新田/
なかにし /中西/
なかにほん /中日本/
なかにも /中にも/
なかにわ /中庭/
なかぬき /中抜き/中貫き/
なかぬり /中塗り/
なかね /中根/仲値/中値/
なかの /中野/仲野/
なかのえき /中野駅/
なかのおおえのおうじ /中大兄皇子/
なかのきみ /中の君;[文語]二番目の姫君/
なかのく /中野区/
なかのくち /中之口/
なかのさんぷらざ /中野サンプラザ/
なかのし /中野市/
なかのしげはる /中野重治;(1902-79)作家。『歌のわかれ』/
なかのしま /中之島/中野島/
なかのしまこうえん /中之島公園;大阪/
なかのしょう /中ノ庄/中之庄/
なかのしょてん /中野書店/
なかのじょう /中之条/
なかのだい /中野台/
なかのちょう /仲之町/
なかのぶがくえん /中延学園/
なかのべ /中延/
なかのほうめん /中野方面/
なかのまつりごとのつかさ /中務省/
なかのむさしの /中野武蔵野/
なかはし /中橋/
なかはた /中畑;姓/
なかはま /中浜/
なかはら /中原;姓/
なかはらえき /中原駅/
なかはらかいかん /中原会館/
なかはらかいどう /中原街道/
なかはらく /中原区/
なかはらちゅうや /中原中也/
なかば /半ば/
なかばこ /中箱/
なかばすぎ /半ば過ぎ/
なかばやし /中林/
なかばる /中原/
なかばん /中番/
なかひがし /中東;姓/
なかひら /中平/
なかび /中日/
なかびしゃ /中飛車/
なかびょうし /中表紙/
なかぶくろ /中袋/
なかぶた /中蓋/
なかぶと /中太/
なかへじ /中辺路/
なかほど /中程/中ほど/
なかほり /中堀/
なかぼね /中骨/
なかま /仲間/中間/仲魔/
なかまいしき /仲間意識/
なかまいり /仲間入り/仲間入/
なかまうち /仲間内/
なかまき /中牧/
なかまく /中幕/
なかまたち /仲間達/
なかまち /中町/仲町/
なかまつ /中松/
なかまどうし /仲間同士/
なかまはずれ /仲間外れ/
なかまる /・/中束/
なかまわれ /仲間割れ/
なかみ /中身/中味;=中身/
なかみかど /中御門/
なかみかどてんのう /中御門天皇/
なかみかわ /中見川/
なかみせ /仲見世/
なかみぞ /中溝/
なかみち /中道/仲道/
なかみなと /那珂湊/
なかむら /中村/仲村/
なかむらく /中村区/
なかむらこうこう /中村高校/
なかむらざ /中村座;[歌舞伎]江戸三座の一/
なかむらし /中村市/
なかむらたかし /中村尚司/
なかむらや /中村屋/
なかめぐろ /中目黒/
なかもず /中百舌鳥/
なかもと /中本/仲本/中元;姓/
なかもり /中森/
なかもりあきな /中森明菜/
なかもん /中門/
なかや /中谷/中屋/中矢/仲谷/
なかやしき /中屋敷/
なかやすみ /中休み/
なかやま /中山/仲山/
なかやまきねん /中山記念/
なかやまけいばじょう /中山競馬場/
なかやましば /中山芝/
なかやませいこうしょ /中山製鋼所;[企業名]/
なかやまだいしょうがい /中山大障害/
なかやまとうげ /中山峠/
なかやまひんば /中山牝馬/
なかやまみほ /中山美穂/
なかやまりょう /中山陵/
なかゆび /中指/
なかよし /仲良し/仲好し;=仲良し/
なから /半ら/
なかりゃく /中略/
なかれ /勿れ/莫れ/毋れ/勿/毋/
なかわきべつえき /中湧別駅/
なかわく /中枠/
なかわた /中綿/
なかわり /中割り/
なかんずく /就中/
なが /長/永/
なが> /長;長電話,長泣き,長談議/
ながあみ /長編み/
ながあめ /長雨/
ながい /永井/長井/長居/永射/
ながいあいだ /長い間/
ながいかふう /永井荷風/
ながいき /長生き/長生/
ながいきゅうぎじょう /長居球技場/
ながいけ /長池/
ながいこうえん /長居公園/
ながいし /長石/
ながいす /長椅子/
ながいずみ /長泉/
ながいた /長板/
ながいも /長芋;とろろいも/長薯/
ながうた /長唄/長歌/
ながえ /長柄;-刀/轅;牛車の-/永江/名替/
ながえさんきょう /長江三峡/
ながお /長尾/永尾/長夫/長緒/
ながおい /長追い/
ながおか /長岡/永岡/
ながおかえき /長岡駅/
ながおかきょう /長岡京/
ながおかきょうし /長岡京市/
ながおかぎかだい /長岡技科大/
ながおかぎだい /長岡技大/
ながおかし /長岡市/
ながおかてんじん /長岡天神/
ながおし /長押し/
ながおせん /長尾線/
ながおだい /長尾台/
ながおとうげ /長尾峠/
ながき /長岐/
ながぎし /永岸/
ながぎぬ /長衣/
ながくつした /長靴下/
ながくて /長久手/
ながくぼ /長久保/
ながくら /長倉/
ながぐつ /長靴/
ながけちょう /名掛丁/
ながごと /長言/
ながさ /長さ/
ながさか /長坂/
ながさき /長崎/永崎/
ながさきえき /長崎駅/
ながさきえきまえ /長崎駅前/
ながさきかんこう /長崎観光/
ながさきくうこう /長崎空港/
ながさきけん /長崎県/
ながさきけんえい /長崎県営/
ながさきけんちょう /長崎県庁/
ながさきこう /長崎港/
ながさきし /長崎市/
ながさきしない /長崎市内/
ながさきしゅっしんしゃ /長崎出身者/
ながさきしんぶん /長崎新聞/
ながさきせん /長崎線/
ながさきぞうせんじょ /長崎造船所/
ながさきだい /長崎大/
ながさきだいがく /長崎大学/
ながさきでんき /長崎電軌/
ながさきでんききどう /長崎電気軌道/
ながさきでんてつ /長崎電鉄/
ながさきどう /長崎道/
ながさきにちだい /長崎日大/
ながさきばん /長崎版/
ながさきべん /長崎弁/
ながさきほんせん /長崎本線/
ながさきや /長崎屋/
ながさきわん /長崎湾/
ながさく /永作/
ながさわ /長沢/長澤/永沢/
ながざら /長皿/
ながし /流し/
ながしうち /流し打ち;[野球]投球に逆らわない打法. ⇔引っ張り/
ながしかく /長四角/
ながしずき /流し漉き/
ながしだい /流し台/
ながしの /長篠/
ながしば /流し場;銭湯の-/
ながしま /長島/長嶋/永島/永嶋/
ながしまおんせん /長島温泉/
ながしまかずしげ /長嶋一茂;人名/
ながしまかんとく /長嶋監督/
ながしましげお /長嶋茂雄/
ながしめ /流し目/
ながじゃく /長尺/
ながじゅばん /長襦袢/
ながす /長洲/
ながすぎ /長過ぎ/
ながすくじら /長須鯨/
ながずぼん /長ズボン/
ながせ /長瀬/永瀬/
ながせさんぎょう /長瀬産業;[企業名]/
ながそで /長袖/
ながた /永田/長田/長多/
ながたち /長太刀;+0 longsword/
ながたちょう /永田町/
ながたな /菜刀;菜切り庖丁/
ながたに /長谷/永谷/
ながたにえん /永谷園/
ながたび /長旅/
ながだんぎ /長談義/
ながちょうば /長丁場/
ながっちり /長っ尻/
ながつ /長津/永津/
ながつか /長塚/長束/
ながつかたかし /長塚節;(1879-1915) 作家。『土』/
ながつき /長月;陰暦9月/
ながつだ /長津田/
ながつだえき /長津田駅/
ながつづき /長続き/永続き/
ながつま /長妻/
ながづくえ /長机/
ながて /長手/
ながてぶくろ /長手袋/
ながてほうこう /長手方向/
ながでんわ /長電話/
ながと /長門/長戸/
ながとうりゅう /長逗留/
ながとし /長年/
ながとの /長殿/
ながとみ /長富/長冨;「富」異体字/
ながとも /長友/永友/
ながとろ /長瀞/
ながなが /長々/
ながぬま /長沼/
ながねぎ /長葱/長ネギ/
ながねん /長年/永年/
ながの /長野/永野;人名/長能/永埜/
ながのえき /長野駅/
ながのがわ /長野側/
ながのけん /長野県/
ながのけんみん /長野県民/
ながのこう /長野高/
ながのこうじょう /長野工場/
ながのこうせん /長野高専/
ながのし /長野市/
ながのしぎかい /長野市議会/
ながのしない /長野市内/
ながのしんかんせん /長野新幹線/
ながのじどうしゃどう /長野自動車道/
ながのだい /長野大/
ながのだいがく /長野大学/
ながのでんてつ /長野電鉄/
ながのどう /長野道/
ながのにほんむせん /長野日本無線/
ながのはら /長野原/
ながのはらくさつぐち /長野原草津口/
ながのほうめん /長野方面/
ながはし /長橋/
ながはた /永幡/
ながはま /長浜/長濱/
ながはまかん /長浜間/
ながはら /永原/長原/
ながはる /長治;名/
ながばかま /長袴/
ながばなし /長話/
ながばり /長針/
ながひと /長人/
ながひばち /長火鉢/
ながびつ /長櫃/
ながふさ /長房/
ながぶせ /長伏/
ながぶち /長渕/長淵/
ながぶちつよし /長渕剛/
ながぶろ /長風呂/
ながほ /長保/
ながまさ /長政/
ながまち /長町/
ながまちえき /長町駅/
ながまつ /永松/長松/
ながみ /永見/
ながみち /長道/
ながみつ /長光/永光/
ながみね /長嶺/長峯/
ながむし /長虫/
ながむね /長宗/
ながめ /眺め/長め/長目/霖;=長雨/長雨/
ながもち /長持ち/長持/長もち/
ながもちうた /長持唄/
ながものがたり /長物語/
ながもり /長森;姓/永森/
ながや /長屋/長谷/長家/
ながやおう /長屋王/
ながやす /永安/
ながやま /永山/長山/
ながやまえき /永山駅/
ながやみ /長病み/
ながやり /長槍/
ながゆ /長湯/
ながゆき /長幸/
ながよ /長与/長夜/
ながよし /永吉/長吉/
ながら /乍ら/長良/長柄/乍/
ながらがわ /長良川/
ながらがわかこうせき /長良川河口堰/
ながらがわてつどう /長良川鉄道/
ながらく /長らく/
ながれ /流れ/
ながれかいさん /流れ解散/
ながれさぎょう /流れ作業/流作業/
ながれず /流れ図/
ながれだま /流れ弾/
ながれぼし /流れ星/
ながれもの /流れ者/
ながれや /流れ矢/
ながれやま /流山/
ながわ /名川/奈川/奈河/
ながわずらい /長患い/痼/
なき /泣き/亡き/鳴/
なきおとし /泣落し/
なきおんな /泣き女/泣女/
なきがお /泣き顔/
なきがら /亡骸/亡き骸/
なきごえ /鳴き声/泣き声/鳴声/
なきごと /泣き言/
なきじょうご /泣き上戸/
なきたま /亡き魂/
なきっつら /泣きっ面/
なきつら /泣き面/
なきどころ /泣き所/
なきどり /鳴き鳥/
なきね /泣き寝/
なきねいり /泣き寝入り/
なきべそ /泣きべそ/
なきぼくろ /泣き黒子/
なきまね /鳴き真似;ホーホケキョ/泣き真似;うえ〜ん/
なきむし /泣き虫/
なきもの /亡き者;-にする/
なきり /菜切り/奈切/
なきりすげ /菜切菅/
なきりぼうちょう /菜切り包丁/菜切包丁/
なきりゅう /鳴き竜/鳴竜/
なきわかれ /泣き別れ/
なきわらい /泣き笑い/
なぎ /凪/薙/梛/奈義/南木/椥/
なぎさ /渚/
なぎそ /南木曾/
なぎなた /長刀/薙刀/
なぎなたがた /長刀形/
なぎなたほこ /長刀鉾/
なぎなたぼこ /長刀鉾/
なぎょう /ナ行/な行/
なぎょうへんかくかつよう /ナ行変格活用;[文法]ナ変。 (死ぬ)な-に-ぬ-ぬる-ぬれ-ね/
なくなく /泣く泣く/
なくら /名倉/
なぐ /薙/
なぐさ /慰/
なぐさみもの /慰み物/慰み者;-にされる/
なぐさめ /慰め/
なぐさめがお /慰め顔/
なぐも /南雲/
なぐら /名倉/殴羅/
なぐり /名栗/殴り/
なぐりあい /殴り合い;-の喧嘩/
なぐりがき /殴り書き/
なぐるける /殴る蹴る/
なげ /投げ/無げ/
なげあみ /投網/投げ網/
なげいればな /抛入花/
なげうり /投げ売り/投売り/
なげかた /投げ方/
なげき /嘆き/歎き/
なげきす /投げキス/
なげきっす /投げキッス;チュッ！/
なげきのかべ /嘆きの壁;Wailing Wall/
なげくび /投げ首/
なげこみ /投げ込み;-が足りない/投込み/
なげこみでら /投げ込み寺;死んだ遊女を「投げ込み」ました/
なげざお /投げ竿/
なげし /長押/
なげせん /投げ銭/
なげづり /投げ釣り/投げ釣/
なげなわ /投げ縄/
なげぶみ /投げ文/投文/
なげや /投げ矢;darts/投矢/
なげやり /投げ遣り/投げ槍/投槍/投げやり/
なげわざ /投げ技/
なこ /名古/
なこうじ /若王寺/
なこうど /仲人/
なこうどぐち /仲人口/
なこそ /勿来/
なご /名護/名古/名子/
なごや /名古屋;愛知/名護屋;佐賀/名越/那古屋/
なごやいがい /名古屋以外/
なごやえいぎょうしょ /名古屋営業所/
なごやえき /名古屋駅/
なごやえきちか /名古屋駅地下/
なごやえきまえ /名古屋駅前/
なごやか /和やか/
なごやきゅうじょう /名古屋球場/
なごやきんこう /名古屋近郊/
なごやきんこぐん /名古屋金鯱軍/
なごやくうこう /名古屋空港/
なごやぐち /名古屋口/
なごやけいえい /名古屋経営/
なごやけいばじょう /名古屋競馬場/
なごやこーちん /名古屋コーチン;鶏/
なごやこうえん /名古屋公演/
なごやこうぎょうだい /名古屋工業大/
なごやこうぎょうだいがく /名古屋工業大学/
なごやこうそく /名古屋高速/
なごやこうだい /名古屋工大/
なごやこくぜいきょく /名古屋国税局/
なごやし /名古屋市/
なごやししゃ /名古屋支社/
なごやしてん /名古屋支店/
なごやしない /名古屋市内/
なごやしぶ /名古屋支部/
なごやじょう /名古屋城/
なごやじん /名古屋人/
なごやじんく /名古屋甚句;[民謡]/
なごやせいさくしょ /名古屋製作所;[企業名]/
なごやせん /名古屋線/
なごやたいかい /名古屋大会/
なごやだい /名古屋大/
なごやだいいん /名古屋大院/
なごやだいがく /名古屋大学/
なごやだいしょうてん /名古屋大賞典/
なごやだいり /名古屋大理/
なごやちく /名古屋地区/
なごやてつどう /名古屋鉄道/
なごやにし /名古屋西/
なごやはつ /名古屋発/
なごやばしょ /名古屋場所/
なごやべん /名古屋弁/
なごやほうめん /名古屋方面/
なごやほんせん /名古屋本線/
なごやまつり /名古屋祭/
なごやめいぶつ /名古屋名物/
なごり /名残/名残り/
なごん /納言/
なさけ /情け/情/
なさけしらず /情け知らず/
なさけむよう /情け無用/
なさけようしゃ /情け容赦;-ない/
なさぬなか /生さぬ仲/
なざし /名指し/
なし /梨/無し/無/
なしがり /なし狩り/
なしくずし /なし崩し/済し崩し/
なしくずしてき /なし崩し的/
なしじ /梨子地/
なしだ /梨田/
なしだい /梨大/
なしのつぶて /梨の礫/
なしもとのみや /梨本宮/
なじみ /馴染/馴染み/
なじみきゃく /馴染み客/
なす /那須/茄子/茄/那州/
なすおんせん /那須温泉/
なすか /ナス科/
なすこうじょう /那須工場/
なすこん /茄子紺/
なすしおばら /那須塩原/
なすすべ /為す術/
なすだけ /那須岳;地名,栃木/
なすの /那須野/
なすのよいち /那須与一;平家物語の弓の名手/
なすび /茄子/茄/
なすもく /ナス目/Solanales/
なすもくぐん /ナス目群/
なずな /薺/
なずらえうた /準え歌/
なせ /奈瀬;姓/
なぜ /何故/名瀬/
なぜか /何故か/
なぜなら /何故なら/∵/
なぞ /謎/
なぞかけ /謎掛け/
なぞがく /謎学/
なぞことば /謎言葉/
なぞとき /謎解き/
なぞなぞ /謎々/
なぞなぞものがたり /謎々物語/謎謎物語/
なぞわざ /謎技/
なた /鉈/屶/釶/
なたしょう /名田庄/
なたに /名谷/
なたね /菜種/
なたねあぶら /菜種油/
なたまめ /鉈豆/
なだ /灘/洋/涙/
なだい /名代/名題/灘井/
なだいやくしゃ /名題役者/
なだきたどおり /灘北通/
なだく /灘区/
なだこう /灘高/灘校/
なだこうこう /灘高校/
なだこうとうがっこう /灘高等学校/
なださき /灘崎/
なだたる /名立たる/名だたる/
なだち /名立/
なだちゅう /灘中/
なだちゅうがく /灘中学/
なだれ /雪崩/
なだれげんしょう /雪崩現象/
なだれしき /雪崩式/
なち /那智/
なっ /納/
なっきり /菜っ切り/
なっしゅきんこう /ナッシュ均衡;[ゲーム理論]Nash Equilibrium/
なっしょ /納所;お寺の-/
なっせん /捺染/
なっちん /納音/
なっとう /納豆/
なっとうきん /納豆菌/
なっとうしゅう /納豆臭/
なっとうじる /納豆汁/
なっとうまき /納豆巻/納豆巻き/
なっとく /納得/
なっとくかん /納得感/
なっとくずく /納得尽く/
なっぱ /菜っ葉/菜葉/
なつ /夏/捺;捺印/奈津;人名/
なつあき /夏秋/
なついがい /夏以外/
なついろ /夏色/
なついん /捺印/
なつえ /夏江/
なつお /夏生/
なつおんな /夏女/
なつか /長束/
なつかし /懐かし/
なつかぜ /夏風邪/
なつかわ /夏川/
なつがき /夏牡蛎/
なつがすみ /夏霞/
なつがた /夏型/
なつがっこう /夏学校/
なつがっしゅく /夏合宿/
なつがれ /夏枯れ/
なつき /夏樹/夏生/夏木/奈月/無月/夏季;かき/
なつぎ /夏着/
なつぎぬ /夏衣/
なつぎり /夏霧/
なつくいな /夏水鶏/
なつくさ /夏草/
なつぐも /夏雲/
なつげ /夏毛/
なつげしき /夏景色/
なつこ /奈津子/夏子/なつ子/那津子/
なつこみ /夏コミ/
なつごう /夏号/
なつごろ /夏頃/
なつごろも /夏衣/
なつさく /夏作/
なつじかん /夏時間/
なつじゅう /夏中/
なつずいせん /夏水仙;fairy lily/
なつぜみ /夏蝉/
なつぜんご /夏前後/
なつぞら /夏空/
なつだいこん /夏大根;辛い!/
なつどり /夏鳥/
なつの /夏野/
なつのじん /夏の陣/
なつば /夏場/
なつばおり /夏羽織/
なつばしょ /夏場所/
なつばて /夏ばて/夏バテ/
なつばん /夏版/
なつひこ /夏彦/
なつび /夏日/
なつふく /夏服/
なつほんばん /夏本番/
なつぼうし /夏帽子/
なつまけ /夏負け/夏負/
なつまつり /夏祭/夏祭り/
なつみ /菜摘/奈津美/夏美/夏実/夏巳/
なつみかん /夏蜜柑/夏みかん/夏ミカン/
なつむき /夏向き/
なつむし /夏虫/
なつめ /夏目/棗/夏芽;⇔冬芽/棘/
なつめそうせき /夏目漱石/
なつめまさこ /夏目雅子/
なつめやし /棗椰子/
なつめろ /懐メロ;[口]懐かしのメロディ/
なつもの /夏物/
なつもよう /夏模様/
なつやさい /夏野菜/
なつやすみ /夏休み/夏休/
なつやせ /夏痩せ/
なつやま /夏山/
なつよ /夏代/
なつよう /夏用/
なづけ /名付け/菜漬/
なづけおや /名付け親/名付親/
なでがた /撫で肩/なで肩/
なでぎり /撫で斬り/
なでしこ /撫子/
なでしこもく /ナデシコ目/Caryophyllales/
なでしこもくぐん /ナデシコ目群/
なでなで /撫で撫で/
なではら /撫原/
なでら /斜平/
なでん /南殿/
なとり /名取/
なとりうむ /Na/Sodium/
なとりうむえん /ナトリウム塩/
なとりし /名取市/
など /等/抔;≒等/
などころ /名所/
などなど /等々/
なな /七/奈々/奈奈/７/
なな> /七/
なない /七位/
なないろ /七色/
ななえ /七重/奈々絵/奈々江/七栄/
ななお /七尾/
ななおせん /七尾線/
ななか /七華;名/
ななかい /七会/
ななかく /七角/
ななきた /七北田/
ななくさ /七草/
ななくせ /七癖/
ななくま /七隈/
ななこ /七個/奈々子/魚子/斜子/7個/七子/
ななこおり /斜子織り/斜子織/魚子織り/魚子織/
ななこまち /七小町/
ななころび /七転び/
ななころびやおき /七転び八起き/
ななさわ /奈々沢/
ななさん /七三/
ななさんいちぶたい /七三一部隊;[日本史](1933-45)/
ななし /名無し/名無/
ななしゅきょうぎ /七種競技/
ななしょく /七色/
ななじゅうにんやくせいしょ /七十人訳聖書;Septuagint/
ななじゅうねんだい /七十年代/
ななじょう /七条/
ななじょうかわらまち /七条河原町/
ななせ /七瀬/
ななそ /七十/
ななそじ /七十路/七十/
ななたび /七度/
ななたま /七玉/
ななだいせん /七大戦/
ななだる /七滝/
ななつ /七つ/七ツ/
ななつか /七塚/
ななつたき /七ッ滝/
ななつどうぐ /七つ道具;泥棒の-/
ななつぼし /七つ星/
ななつもり /七ッ森/
ななにん /七人/
ななねん /七年/
ななねんめ /七年目/
ななひかり /七光/七光り/
ななひき /七匹/
ななふし /竹節虫/
ななふしぎ /七不思議/
ななぶ /七部/
ななほしてんとう /七星瓢虫/
ななまがり /七曲り/
ななみ /七海/七生/
ななめ /斜め/
ななめうえ /斜め上/
ななめうしろ /斜め後ろ/
ななめこうほう /斜後方/
ななめした /斜め下/
ななめぜんぽう /斜前方/
ななめまえ /斜め前/
ななめよみ /斜め読み/
ななやしろ /七社/
ななやま /七山/
ななよ /七夜/
ななれんしょう /七連勝/
ななわり /七割/
なに /何/
なに> /何;何版,何先生/
なにいろ /何色/
なにうりば /何売場/
なにえき /何駅/
なにか /何か/何科/
なにかと /何彼と/
なにがし /某/何某/
なにがた /何型/
なにがなんでも /何が何でも/
なにけい /何系/
なにけん /何県/
なにげ /何気/
なにご /何語/
なにごころ /何心/
なにごと /何事/何言/
なにさま /何様/
なにしろ /何しろ/
なにじん /何人/
なにせ /何せ/
なにせん /何線/
なにせんせい /何先生/
なにとぞ /何卒/
なにとも /何とも/
なになに /何々/何何/
なにはさておき /何は扨措き/何は扨置き/
なにばしょ /何場所/
なにひとつ /何一つ/
なにびと /何人/
なにぶん /何分/
なにほど /何程/
なにも /何も/
なにもの /何者;†somebody.「あいつ-だ？」/何物;†something.「欺瞞以外の-でもない」/
なにもよう /何模様/
なにや /何屋/
なにやつ /何奴/
なにやら /何やら/
なにゆえ /何故/
なによう /何用/
なにより /何より;それは-です/
なにわ /灘/難波/浪速/浪花/
なにわぶし /浪花節/
なにわぶしてき /浪花節的/
なぬか /七日/
なぬし /名主/
なの /七/nano;[SI接頭語]n,10^-9/
なのか /七日/７日/7日/
なのかめ /七日目/
なのこ /菜子/
なのはな /菜の花/
なのはなばたけ /菜の花畑/
なのり /名乗り/名告り/
なのりゅうし /ナノ粒子/
なは /那覇/
なはえき /那覇駅/
なはくうこう /那覇空港/
なはこうつう /那覇交通/
なはさば /鯆/
なはし /那覇市/
なはしない /那覇市内/
なはり /奈半利/名張/
なばかり /名ばかり/
なばな /菜花/
なばり /名張/
なばりせん /名張線/
なぱーむだん /ナパーム弾;(napalm)焼夷弾の一種/
なふだ /名札/
なぶら /∇;nabla(ベクトル微分)/
なぶりごろし /嬲り殺し/
なぶりもの /嬲り者/
なへん /奈辺/那辺;=奈辺/ナ変;ナ行変格活用/
なべ /鍋/辺/邉;「辺」の旧字1/邊;「辺」の旧字2/
なべかい /鍋会/
なべかま /鍋釜/
なべき /鍋気/
なべしき /鍋敷き/
なべしま /鍋島/
なべぞこ /鍋底/
なべた /鍋田/
なべたに /鍋谷/
なべつかみ /鍋掴み/
なべづる /鍋鶴/鍋鉉/
なべて /並べて/
なべの /鍋野/
なべはだ /鍋肌/
なべはり /鍋貼/
なべぶぎょう /鍋奉行/
なべぶた /鍋蓋/
なべもの /鍋物/鍋もの/
なべやき /鍋焼/鍋焼き;-うどん/
なべやきうどん /鍋焼き饂飩/
なべりょうり /鍋料理/
なほ /尚/猶/菜穂/
なほこ /菜穂子/奈穂子/
なほざり /等閑/
なほし /直衣/
なほみ /奈保美/
なほもって /尚以て/
なぽれおんほうてん /ナポレオン法典;[世界史]Code Napoleon(code civil)/
なま /生/
なま> /生;-写真,-ジャケ/
なまあげ /生揚げ/
なまあし /生足/生脚/
なまあん /生餡/生あん/
なまいき /生意気/
なまいきざかり /生意気盛り/
なまうお /生魚/
なまえ /名前/
なまえいがい /名前以外/
なまえいり /名前入/
なまえかいけつ /名前解決/
なまえかんり /名前管理/
なまえくうかん /名前空間/
なまえしてい /名前指定/
なまえじたい /名前自体/
なまえつきぱいぷ /名前付きパイプ/
なまえひょう /名前表/
なまえまけ /名前負け/
なまえよう /名前用/
なまえんそう /生演奏/
なまおと /生音/
なまおぼえ /生覚え/
なまおん /生音/
なまかじり /生齧り/
なまかべ /生壁/
なまかべいろ /生壁色/
なまかわ /生皮/
なまかんせん /生観戦/
なまがき /生牡蠣/生牡蛎/生蛎/
なまがくしょう /生学生/
なまがけ /生掛け/
なまがし /生菓子/
なまがっき /生楽器/
なまがわ /生皮/
なまがわき /生乾き/
なまき /生木/
なまきず /生傷/生疵;=生傷/
なまくび /生首/
なまくら /鈍/鈍ら/
なまくりーむ /生クリーム/
なまぐさ /生臭/腥/
なまぐさぼうず /生臭坊主/
なまけぐせ /怠け癖/
なまけごころ /怠け心/
なまけもの /怠け者/
なまげんこう /生原稿/
なまこ /海鼠/
なまこかべ /海鼠壁/
なまこん /生コン;生コンクリート/
なまこんくりーと /生コンクリート/
なまごみ /生塵/生ゴミ/
なまごみしょりき /生ごみ処理機/
なまごめ /生米/
なまごろし /生殺し/
なまざかな /生魚/生肴/
なましいたけ /生椎茸/
なましゅつえん /生出演/
なましょく /生食/
なましょくよう /生食用/
なまじ /憖/
なまじっか /憖っか/
なまじゃけ /生鮭/
なまじゃしん /生写真/
なまじょうゆ /生醤油/
なます /膾/鱠;=膾/韲;≒膾/
なますじこ /生筋子/
なまず /鯰/癜;[医](皮膚病) leukoderma/鮠;はや,?/
なませっこう /生石膏/
なまそば /生蕎麦;茹でてないソバ/
なまたまご /生卵/生玉子/
なまため /生天目/生田目/
なまだら /生鱈/生ダラ/
なまち /生血/
なまちち /生乳/
なまちゃ /生茶/
なまちゅうけい /生中継/
なまつば /生唾/
なまづめ /生爪/生詰/
なまでーた /生データ/
なまなま /生生/生々/
なまにえ /生煮え/
なまにく /生肉/
なまはけい /生波形/
なまはげ /生剥/生剥げ;秋田の奇祭/
なまはだ /生肌/
なまはんか /生半可/
なまはんじゃく /生半尺/
なまばな /生花/
なまばんぐみ /生番組/
なまぱんこ /生パン粉/
なまびーる /生ビール/
なまびょうほう /生兵法/
なまぴ /生ピ/
なまふ /生麩/
なまぶし /生節;半乾きの鰹節/
なまへんじ /生返事/
なまほうそう /生放送/
なまぼし /生乾し/
なままめ /生豆/
なまみ /生身/
なまみず /生水/
なまみそ /生味噌/
なまむぎ /生麦/
なまめん /生麺/
なまもの /生物/
なまやけ /生焼け/
なまやさい /生野菜/
なまよい /生酔い/
なまり /鉛;Pb/訛/訛り;accent/Pb/Lead/
なまりいた /鉛板/
なまりいり /鉛入/
なまりいろ /鉛色/
なまりかごうぶつ /鉛化合物/
なまりだん /鉛弾/
なまりちくでんち /鉛蓄電池/
なまりばん /鉛版/
なまりぶくろ /鉛袋/
なまりぶし /生り節/生節/
なまろく /生録/
なまろくおん /生録音/
なみ /波/並/浪/奈美/奈未/名美/奈巳/竝;「並」の旧字/〜;→なみせん/
なみあい /浪合/
なみあし /並足/
なみいか /並以下/
なみいた /波板;波状の板。トタン屋根など/
なみうち /波打/
なみうちぎわ /波打ち際/波打際/
なみえ /浪江/
なみお /波雄/
なみおか /浪岡/
なみおと /波音/
なみかぜ /波風/
なみかた /波方/
なみかっこ /波括弧/
なみかわ /並河/浪川/
なみがい /浪貝/
なみがけ /並罫/
なみがしら /波頭/
なみがた /波形/
なみき /並木/行木/
なみきおおはし /並木大橋/
なみきざ /並木座/
なみきみち /並木道/
なみけい /波罫;〜/
なみこし /浪越/
なみしょう /浪商/
なみじ /波路/
なみじょう /波状/
なみせい /並製/
なみせん /波線/〜/
なみたいてい /並大抵/
なみだ /涙/泪;「涙」の異体字/涕/
なみだあめ /涙雨/
なみだがお /涙顔/
なみだがた /涙型/
なみだがわ /涙川;cry me a river/
なみだきん /涙金/
なみだごえ /涙声/
なみだながら /涙ながら/
なみだばし /涙箸/
なみだめ /涙目/
なみだもの /涙もの/涙モノ/
なみとう /並等/
なみなみ /並々/
なみの /波野/
なみのはな /波の花;(忌言葉)塩/
なみのり /波乗り/波乗/
なみはずれ /並外れ/
なみはば /並幅/
なみひととおり /並一通り/
なみへい /波平/
なみま /波間/
なみまく /波幕/
なみまくら /波枕/
なみまつ /並松/
なみもり /並盛/
なみよけ /波除け/
なむ /南無/
なむあみだぶつ /南無阿弥陀仏;(浄土宗)/
なむさん /南無三/
なむさんぼう /南無三宝/
なむみょうほうれんげきょう /南無妙法蓮華経;(日蓮宗)/
なむら /魚群/
なめ /滑/嘗/
なめいし /大理石/
なめかた /行方/
なめかわ /滑川/
なめがた /行方/
なめくじ /蛞蝓/
なめくじうお /蛞蝓魚/
なめこ /滑子/
なめし /菜飯/
なめしがわ /鞣革/
なめたけ /滑茸/
なめらか /滑らか/
なめりかわ /滑川/
なや /納屋/納谷;人名/魚屋/
なやみ /悩み/
なやみおおき /悩み多き/
なやみごと /悩み事/
なやみそうだん /悩み相談/
なやらい /追儺;=ついな/
なゆ /那由/
なゆた /那由多;10^60/那由他;=那由多/奈由太;人名/
なよせ /名寄せ/
なよせちょう /名寄帳/
なよたけ /弱竹/
なよろ /名寄/
なよろほんせん /名寄本線/
なら /奈良/楢;oak/柞;≒楢/枹;≒楢/平城;=奈良 ※連想?/
ならい /奈良井/
ならいごと /習い事/
ならいしょう /習い性/
ならえ /奈良絵/
ならえき /奈良駅/
ならえほん /奈良絵本/
ならお /奈良尾/
ならおか /奈良岡/
ならかわ /楢川/
ならかん /奈良間/
ならき /奈良木/
ならく /奈落/
ならけん /奈良県/
ならけんなんぶ /奈良県南部/
ならけんみん /奈良県民/
ならこうえん /奈良公園/
ならこうせん /奈良高専/
ならこうつう /奈良交通/
ならさき /楢崎/
ならざき /楢崎/
ならし /奈良市/馴らし;じゃじゃ馬-/慣らし;足-,口-/
ならしてん /奈良支店/
ならしない /奈良市内/
ならしの /習志野/
ならしのし /習志野市/
ならじだい /奈良時代/
ならじょしだい /奈良女子大/
ならじょしだいがく /奈良女子大学/
ならず /不成/
ならずもの /ならず者/
ならずものこっか /ならず者国家/
ならせん /奈良線/
ならせんえんせん /奈良線沿線/
ならせんたん /奈良先端/
ならせんたんかがくぎじゅつだいがくいんだいがく /奈良先端科学技術大学院大学/
ならせんたんだい /奈良先端大/
ならちく /奈良地区/
ならちょう /奈良町/
ならづけ /奈良漬/
ならでん /奈良電/
ならは /楢葉/
ならはら /奈良原/
ならば /→/⊃/⇒/
ならび /並び/
ならびかえ /並び換え/
ならびじゅん /並び順/
ならびに /並びに/
ならへいあんじだい /奈良平安時代/奈良・平安時代/
ならべ /並べ/
ならべかえ /並べ替え/
ならほうめん /奈良方面/
ならやま /平城山/
ならやまぶしこう /楢山節考/
ならわし /習わし/慣わし/
なり /鳴り/也/形/成/就/斉/哉/
なりあい /成合/
なりあいじ /成相寺/
なりあがり /成り上がり/
なりあき /成昭/
なりあきら /斉彬/
なりお /成雄/
なりかたち /形姿/
なりかつよう /ナリ活用;形容動詞の活用形態/
なりかわ /成川/
なりきん /成金/
なりきんしゅみ /成金趣味/
なりぎん /成銀/
なりこ /成子/
なりこま /成駒/
なりこまや /成駒屋;よっ、-！/
なりさと /成里/
なりさわ /成沢/成澤/
なりしげ /成茂/
なりしま /成嶋/
なりた /成田/
なりたかん /成田間/
なりたくうこう /成田空港/
なりたくうこうえき /成田空港駅/
なりたくうこうかん /成田空港間/
なりたくうこうちゃく /成田空港着/
なりたくうこうもんだい /成田空港問題/
なりたし /成田市/
なりたしんかんせん /成田新幹線/
なりたせん /成田線/
なりたち /成り立ち/成立ち/
なりたにし /成田西/
なりたはつ /成田発/
なりたびん /成田便/
なりたほうめん /成田方面/
なりたや /成田屋/
なりたりこん /成田離婚/
なりち /成知/
なりて /成り手/為り手/
なりと /成人/
なりとみ /成富/
なりとも /成知/成伴/
なりはら /成原/
なりひさご /生り瓢;ヒョウタン/
なりひと /成人/
なりひら /業平/
なりひらばし /業平橋/
なりひらばしえき /業平橋駅/
なりひろ /成洋/
なりふり /形振り/
なります /成増/
なりまつ /成松/
なりみ /也実/也美/
なりみつ /成允/
なりもと /成本/
なりもの /鳴り物/鳴物/生り物/済り物/
なりものいり /鳴り物入り/鳴物入り/
なりものし /鳴物師/
なりやす /成康/
なりゆき /成行/成行き/成り行き/
なりゆきちゅうもん /成り行き注文/成行き注文/
なりゆきまかせ /成り行き任せ/
なりよし /成良/
なりわ /成羽/
なりわい /生業/業/
なる /成/徳/鳴/奈留/
なるあき /成章/
なるお /鳴尾/成雄/
なるおきねん /鳴尾記念/
なるかみ /鳴神/
なるき /成紀/
なるきよ /成清/
なるけ /成毛/
なるげ /成毛;姓/
なるこ /鳴子/
なるご /鳴子/
なるさわ /鳴沢/成沢/成澤/鳴澤/
なるしま /成島/成嶋/
なるせ /成瀬/鳴瀬/
なるせだい /成瀬台/
なるたき /鳴滝/
なるたきじゅく /鳴滝塾;[日本史]/
なるち /成知/
なると /鳴門/鳴戸/
なるとう /成東/
なるとおおはし /鳴門大橋/
なるときょうていじょう /鳴門競艇場/
なるとだい /鳴門鯛/
なるとちゅうじょうものがたり /鳴門中将物語/
なるとまき /鳴門巻/
なるひこ /徳彦/
なるひさ /徳寿/
なるひろ /成広/
なるべく /成る可く/可成/
なるほど /成程/成る程/
なるみ /鳴海/成美/成己/
なるみつ /成光/
なるよし /成良/
なれ /慣れ/熟れ;-鮨/馴/
なれあい /馴れ合い/馴合/
なれずし /熟鮨/馴鮨/
なれそめ /馴初め/馴れ初め;結婚式用語/
なれっこ /慣れっこ;いいの、-だから/馴れっこ;<rare>/
なれのはて /成れの果て/成れの果/
なわ /縄/名和;人名/苗;(熟字訓)苗代/繩;「縄」の旧字/
なわあみ /縄編み;-のマフラー/
なわおか /縄岡/
なわおび /縄帯/
なわしろ /苗代/
なわしろだ /苗代田/
なわじり /縄尻/
なわた /縄田/
なわて /畷/縄手/
なわとび /縄跳び/縄飛び/
なわない /縄綯い/
なわのり /縄海苔/
なわのれん /縄暖簾/
なわばしご /縄梯子/
なわばり /縄張り/縄張/
なわめ /縄目/
なわもじ /縄文字/
なをれ /名折れ/
なん /何/難/南/軟/男/楠;楠公/喃;喃語/娚/納;納戸/
なん> /何/難;難題,難事業,難問題/南/
なんあ /南ア/
なんあり /難有り/
なんい /南緯/難易/何位/
なんいど /難易度/
なんいどせってい /難易度設定/
なんいどちょうせい /難易度調整/
なんいない /何位内/
なんえつ /南越;[中国史](BC207-111)/
なんえん /何円/
なんおう /南欧/
なんおうけい /南欧系/
なんおうふく /何往復/
なんおく /何億/
なんおくえん /何億円/
なんおくかい /何億回/
なんおくねん /何億年/
なんおん /軟音/
なんか /南下/軟化/南瓜;カボチャ/南柯;「-の夢」/何か/
なんかい /何回/南海/難解/何階/
なんかいきしかわせん /南海貴志川線/
なんかいじしん /南海地震/
なんかいせん /何回線/南海戦/
なんかいたかのせん /南海高野線/
なんかいてん /何回転/
なんかいでんしゃ /南海電車/
なんかいでんてつ /南海電鉄/
なんかいどう /南海道/
なんかいほうそう /南海放送/
なんかいほんせん /南海本線/
なんかいめ /何回目/
なんかいりゅう /南海龍/
なんかげつ /何ヶ月/何カ月/何か月/何箇月/
なんかこくご /何か国語/何カ国語/
なんかしょ /何箇所/何ヶ所/何カ所/何か所/何ヵ所/
なんかしょう /軟化症/
なんかじょう /何箇条/
なんかてん /軟化点/
なんかん /難関/南関/何巻/南漢;[中国史]十国の一(917-971)/
なんかんぶん /何巻分/
なんかんめ /何巻目/
なんが /軟臥/
なんがい /南外/
なんがく /南学/
なんがつ /何月/
なんがつごう /何月号/
なんがつごろ /何月頃/
なんがつなんにち /何月何日/
なんがめん /何画面/
なんがん /南岸/
なんき /南紀/何機/
なんきごう /南紀号/
なんきしらはま /南紀白浜/
なんきつ /難詰/
なんきゅう /軟球/
なんきょう /難境/
なんきょく /南極/難局/難曲/何曲/何局/
なんきょくえっとうたい /南極越冬隊/
なんきょくかい /南極海/
なんきょくかんそくたい /南極観測隊/
なんきょくけん /南極圏/
なんきょくじょうやく /南極条約/
なんきょくじょうやくかんきょうほごぎていしょ /南極条約環境保護議定書/
なんきょくせい /南極星/
なんきょくたいりく /南極大陸/
なんきょくてん /南極点/
なんきょくめ /何曲目/
なんきん /南京/軟禁/Nanjing/
なんきんかんらく /南京陥落/
なんきんぎゃくさつじけん /南京虐殺事件/
なんきんこうりゃく /南京攻略/
なんきんし /南京市/
なんきんじけん /南京事件/
なんきんじょう /南京錠/
なんきんじょうやく /南京条約;[世界史]阿片戦争/
なんきんせんし /南京戦史/
なんきんだいぎゃくさつ /南京大虐殺/
なんきんねずみ /南京鼠/
なんきんぶくろ /南京袋/
なんきんまめ /南京豆/
なんきんむし /南京虫/
なんぎ /難儀/難義;†difficult signification.「-語を含む詩篇」/
なんぎょう /難行;厳しい修行/難業;難しい事業/何行;how many lines/
なんぎょうくぎょう /難行苦行/
なんぎょうどう /難行道/
なんぎょうめ /何行目/
なんく /何区/
なんくかん /何区間/
なんくせ /難癖;-を付ける/何癖;-もある/
なんくち /何口/
なんくみ /何組/
なんくん /難訓/
なんぐあず /南瓜子/
なんぐう /南宮/
なんぐん /南軍/
なんけ /南家/
なんけた /何桁/
なんけん /何件/何軒/軟件;[中国語](ruan jian) software/難件;厄介な事件/
なんげん /何軒/南限/
なんこ /何個/
なんこう /難航/軟膏/南高/南港/南光/軟鋼;soft steel/楠公;楠木正成/南郊/軟攻/
なんこうがい /軟口蓋/
なんこうがいおん /軟口蓋音;[音声学]velar/
なんこうだい /南光台/
なんこうちゅう /難航中/
なんこうどう /南江堂;[出版社名]/
なんこうふらく /難攻不落/
なんこうまえ /楠公前/
なんこく /南国/
なんこつ /軟骨/
なんこつぎょ /軟骨魚/
なんご /喃語/難語/南後/
なんごう /南郷/何号/
なんごうかん /何号館/
なんごうしゃ /何号車/
なんごうせん /何号線/
なんごく /南国/
なんさい /何歳/何才/
なんさく /何作/
なんさくめ /何作目/
なんさつ /何冊/
なんざ /軟座/
なんざん /南山/難産/
なんざんだい /南山大/
なんざんだいがく /南山大学/
なんし /男子/南支;South China/南史;二十一史/難思/
なんしあい /何試合/
なんしあいめ /何試合目/
なんしき /軟式/
なんしきやきゅう /軟式野球/
なんしつ /軟質/
なんしつまい /軟質米/
なんしゃしゅ /何車種/
なんしゅ /何種/
なんしゅう /何周/何週/南州/南宗;禅/
なんしゅうかん /何週間/
なんしゅうかんまえ /何週間前/
なんしゅうが /南宗画/
なんしゅうねん /何周年/
なんしゅうめ /何周目/
なんしゅるい /何種類/
なんしょ /難所/
なんしょう /南昌/何勝/難症/
なんしょうなんぱい /何勝何敗/
なんしょく /難色/何色/男色/
なんしん /南進/
なんじ /汝/何時/爾/難治/難事/何次/難字/尓;「爾」の異体字/
なんじいこう /何時以降/
なんじかん /何時間/
なんじきょく /南磁極/
なんじけん /難事件/
なんじころ /何時頃/
なんじごろ /何時頃/
なんじっかい /何十回/
なんじっけん /何十件/
なんじっつう /何十通/
なんじってん /何十点/
なんじっぷん /何十分/
なんじなんぷん /何時何分/
なんじゃく /軟弱/
なんじゃくか /軟弱化/
なんじゃくじばん /軟弱地盤/
なんじゃくもの /軟弱者/
なんじゅう /難渋/何重/何十/
なんじゅうえん /何十円/
なんじゅうだい /何十台/
なんじゅうにん /何十人/
なんじゅうねん /何十年/
なんじゅうばい /何十倍/
なんじゅうまん /何十万/
なんじゅうまんにん /何十万人/
なんじゅうまんまい /何十万枚/
なんじゅうもん /何十問/
なんじゅうりょう /何十両/
なんじゅっかい /何十回/
なんじゅっけん /何十件/何十軒/
なんじゅっしゅるい /何十種類/
なんじゅっつう /何十通/
なんじゅってん /何十点/
なんじゅっぴき /何十匹/
なんじゅっぷん /何十分/
なんじゅっぽん /何十本/
なんじょう /南条/南條/南城/何条/南常/何乗/
なんじら /汝等/
なんすい /軟水/
なんせ /何せ/
なんせい /南西/南勢/軟性/何世/南征/
なんせいき /何世紀/
なんせいげかん /軟性下疳/
なんせいこうくう /南西航空/
なんせいしょ /南斉書;二十一史/
なんせいしょとう /南西諸島/
なんせいたん /南西端/
なんせいにほん /南西日本/
なんせいぶ /南西部/
なんせいほうこう /南西方向/
なんせき /何隻/
なんせだい /何世代/
なんせん /南線/難船/
なんせんほくば /南船北馬/
なんせんめ /何戦目/
なんぜん /何千/
なんぜんえん /何千円/
なんぜんじ /南禅寺/
なんぜんつう /何千通/
なんぜんにん /何千人/
なんぜんねん /何千年/
なんぜんびき /何千匹/
なんぜんまん /何千万/
なんぜんまんえん /何千万円/
なんぜんまんにん /何千万人/
なんそう /南総/南宋/南倉/南窓/何層/何走/
なんそうさとみはっけんでん /南総里見八犬伝;滝沢馬琴/
なんそく /何足/
なんそしき /軟組織/
なんぞ /何ぞ/
なんたい /軟体/男体/何体/
なんたいさん /男体山/
なんたいどうぶつ /軟体動物/
なんたる /何たる/
なんたん /南端/
なんたんい /何単位/
なんだい /難題/何台/何代/
なんだいもん /南大門/
なんだか /何だか/
なんだかんだ /何だかんだ/
なんだばつ /何打罰/
なんだん /南淡/何段/
なんだんかい /何段階/
なんち /難治/
なんちしっかん /難治疾患/
なんちゃく /何着/
なんちゃくりく /軟着陸/
なんちゅう /南中/
なんちゅうじこく /南中時刻/
なんちょう /難聴/軟調/南朝/何丁/
なんちょうしゃ /難聴者/
なんちん /Nanjing/南京/
なんつう /何通/
なんつうめ /何通目/
なんて /何て/
なんてい /南庭/軟庭/
なんてき /難敵/何滴/
なんてつ /軟鉄/
なんてん /難点/南天/何点/何店/
なんてんか /ナンテン科/Nandinaceae/
なんてんぽ /何店舗/
なんでい /軟泥/
なんでも /何でも/
なんでもかんでも /何でもかんでも/何でも彼んでも;<rare>/
なんでもや /何でも屋/
なんでん /南殿/南伝/
なんでんぶっきょう /南伝仏教/
なんと /南都/南斗/何と/
なんとう /南東/南島/何等/何頭/軟投/南唐;[中国史]十国の一(937-975)/
なんとうきゅう /何等級/
なんとうごぞく /南島語族;[言語]Austronesian/
なんとうせん /南東線/
なんとうは /軟投派/
なんとうぶ /南東部/
なんとおり /何通り/
なんとか /何とか/
なんとなく /何となく/
なんとなれば /何となれば/∵/
なんとほくれい /南都北嶺/
なんとも /何とも/
なんど /何度/難度/納戸/
なんどいろ /納戸色/
なんどう /南洞/
なんどうせん /軟銅線/
なんどき /何時/
なんどく /難読/
なんどくちめい /難読地名/
なんどちょう /納戸町/
なんどめ /何度目/
なんなく /難無く/難なく/
なんなんせい /南南西/
なんなんとう /南南東/
なんにち /何日/
なんにちかん /何日間/
なんにちぐらい /何日位/
なんにちご /何日後/
なんにちごろ /何日頃/
なんにちづけ /何日付/
なんにちぶん /何日分/
なんにちまえ /何日前/
なんにちめ /何日目/
なんにょ /男女/
なんにん /何人/
なんにんぶん /何人分/
なんにんめ /何人目/
なんねい /南寧/
なんねん /何年/難燃/
なんねんうえ /何年上/
なんねんかん /何年間/
なんねんがた /何年型/
なんねんくらいまえ /何年位前/
なんねんご /何年後/
なんねんざい /難燃材/
なんねんざいりょう /難燃材料/
なんねんせい /難燃性/何年生/
なんねんなんがつ /何年何月/
なんねんなんがつごう /何年何月号/
なんねんなんがつなんにち /何年何月何日/
なんねんなんくみ /何年何組/
なんねんばん /何年版/
なんねんぶん /何年分/
なんねんまえ /何年前/
なんねんめ /何年目/
なんの /南野/何の/
なんのう /南濃/
なんのその /何のその/
なんはく /何拍/
なんはこ /何箱/
なんば /難波/難場/
なんばい /何倍/何杯/
なんばら /南原/
なんばりき /何馬力/
なんばん /南蛮/何番/軟盤/
なんばんがし /南蛮菓子;カステラ・金平糖など/
なんばんじん /南蛮人/
なんばんせん /何番線/南蛮船/
なんばんち /何番地/
なんばんづけ /南蛮漬;小鰺の-/
なんばんめ /何番目/
なんばんやき /南蛮焼/
なんぱ /軟派/難破/
なんぱく /何泊;†宿泊回数/軟白/何拍;†何分の何拍子/
なんぱこ /何箱/
なんぱせん /難破船/
なんぱつ /何発/
なんぱつめ /何発目/
なんひき /何匹/
なんひょう /何票/
なんびき /何匹/
なんびと /何人/
なんびゃく /何百/
なんびゃくえん /何百円/
なんびゃくぎょう /何百行/
なんびゃくつう /何百通/
なんびゃくにん /何百人/
なんびゃくねん /何百年/
なんびゃくばい /何百倍/
なんびゃくまん /何百万/
なんびゃくまんえん /何百万円/
なんびゃっこ /何百個/
なんびょう /難病/何秒/
なんびょういない /何秒以内/
なんびょうかん /何秒間/
なんぴと /何人/
なんぴょう /何票/
なんぴょうよう /南氷洋/
なんぴん /何品/難平/
なんふつ /南仏/
なんふん /何分/
なんぶ /南部/南武/軟部/何部/
なんぶしせん /南武支線/
なんぶせん /南武線/
なんぶせんえんせん /南武線沿線/
なんぶつ /難物/
なんぶてつびん /南部鉄瓶/
なんぶはくじん /南部白人/
なんぶん /何分/難文/
なんぷう /南風/軟風/
なんぷくじ /南福寺/
なんぷん /何分/
なんぷんまち /何分待ち/
なんへんせい /何編成/
なんべい /南米/
なんべいけい /南米系/
なんべいさん /南米産/
なんべいせん /南米線/
なんべいたいりく /南米大陸/
なんべいびょう /南米病/
なんべいほうめん /南米方面/
なんべいりょこう /南米旅行/
なんべん /軟便/何遍/
なんぺい /南平;名/
なんぺん /何編/
なんぼいん /軟母音/
なんぼく /南北/
なんぼくかん /南北間/
なんぼくせいぶん /南北成分/
なんぼくせん /南北線/
なんぼくせんそう /南北戦争/
なんぼくちょう /南北朝/
なんぼくちょうじだい /南北朝時代;(日本:1336-92 中国:439-589)/
なんぼくちょうせん /南北朝鮮/
なんぼくもんだい /南北問題/
なんぼくりゅう /南北流/
なんぼん /何本/
なんぼんばしら /何本柱/
なんぼんめ /何本目/
なんぽ /南畝/何歩/
なんぽう /南方/
なんぽうかぜ /南方風/
なんぽうぐんしゅうだん /南方軍集団/
なんぽうけい /南方系/
なんぽく /南北/
なんぽろ /南幌/
なんぽん /何本/
なんまい /何枚/
なんまん /何万/
なんまんえん /何万円/
なんまんてん /何万点/
なんまんにん /何万人/
なんまんねん /何万年/
なんまんまい /何万枚/
なんみょうほうれんげきょう /南無妙法蓮華経/
なんみん /難民/
なんみんえんじょ /難民援助/
なんみんきゃんぷ /難民キャンプ/
なんみんく /難民区/
なんみんじょうやく /難民条約/
なんみんにんてい /難民認定/
なんみんはん /難民班/
なんめい /何名/
なんめん /南面/何面/
なんもう /軟毛/
なんもく /南牧/
なんもじ /何文字/
なんもん /難問/何問/
なんもんしゅう /難問集/
なんもんだい /難問題/
なんや /南谷/
なんやく /難役/
なんよう /南洋/難溶/南陽;地名/何曜/
なんようせい /難溶性/
なんようび /何曜日/
なんら /何等/何ら/
なんらか /何らか/
なんり /南里/
なんりゅうせき /南流石/
なんりょ /南呂/
なんりょう /何両/
なんりょうへんせい /何両編成/
なんりょうめ /何両目/
なんりん /何輪/
なんれつ /何列/
なんれんさ /何連鎖/
なんろ /難路/
なんろく /南麓/
なんわ /何話/
なんわり /何割/
に /二/荷/似/煮/弐;「二」の大字/弍;「二」の異体字/丹/仁;(呉音の一)仁王/児;小児/尼;尼僧/邇;ちか・い/迩;「邇」の異体字/岻;(呉音)/爾;(呉音)/貳;「弍」の旧字/貮;「弍」の旧字/２/2/
に> /二/煮;(ナ行上一段 未然・連用形)煮詰める,煮殺す,煮凍り,煮出す/
にあげ /荷揚げ/
にあし /荷足/
にあつかい /荷扱い/
にあぴんしょう /ニアピン賞;[ゴルフ](near pin は和製英語)/
にありーいこーる /≒/
にい /新/二位/兄/新居/
にいい /新居/
にいかっぷ /新冠/
にいかっぷちょう /新冠町/
にいかわ /新川/
にいがき /新垣/
にいがた /新潟/
にいがたえき /新潟駅/
にいがたかん /新潟間/
にいがたぐち /新潟口/
にいがたけん /新潟県/
にいがたこうつう /新潟交通/
にいがたさん /新潟産/
にいがたし /新潟市/
にいがたしない /新潟市内/
にいがただい /新潟大/
にいがただいがく /新潟大学/
にいがただいしょうてん /新潟大賞典/
にいがたちいき /新潟地域/
にいがたてっこうしょ /新潟鉄工所/
にいがたてん /新潟店/
にいがたほうそう /新潟放送/
にいがたみつこし /新潟三越/
にいがためいくん /新潟明訓/
にいがためいくんこう /新潟明訓高/
にいがためいくんこうこう /新潟明訓高校/
にいくら /新倉/
にいさと /新里/
にいさま /兄様;姉様はL辞書にある/
にいさん /兄さん/
にいざ /新座/
にいざか /新坂/
にいざかまち /新坂町/
にいざき /新居崎/
にいざと /新里/
にいじま /新島/
にいじょう /二以上/
にいだ /新田/
にいちゃん /兄ちゃん/
にいつ /新津/
にいつま /新妻/
にいつる /新鶴/
にいづま /新妻/
にいで /新出/
にいな /二名/
にいなめさい /新嘗祭/
にいぬま /新沼/
にいはま /新居浜/
にいはら /新原/
にいはり /新治/
にいはる /新治/
にいはるぐん /新治郡/
にいばる /新治/
にいべ /新部/
にいほ /仁保/新穂/
にいぼとけ /新仏/
にいぼん /新盆/
にいまくら /新枕/
にいみ /新見/新美/新実/新實/
にいむら /新村/
にいるぴと /二色人/
にいろ /丹色/
にいんくらぶ /二院クラブ/
にいんせい /二院制/
にうけ /荷受/荷受け/
にうけにん /荷受人/
にうごき /荷動き/
にうま /荷馬/
にえ /贄/錵/煮え/沸/
にえびと /贄人/
にえゆ /煮え湯/煮湯/
にお /鳰;かいつぶり/匂/仁尾/
におい /匂/匂い/臭い;特に悪臭/荷負/
においけし /臭い消し/
においぶくろ /匂袋/
におう /仁王/二王;土に-無し/
におうだち /仁王立ち/
におうふく /二往復/
におうみや /匂宮/
におくりにん /荷送人/
におし /二推し/
におぶ /Nb/Niobium/
におやか /匂やか/
におろし /荷卸し/荷下ろし/
にか /二課/二価/
にかい /二階/二回/２回/2回/２階/2階/
にかいせき /二階席/
にかいせん /二回戦/
にかいだて /二階建/二階建て/
にかいだな /二階棚/
にかいていど /二回程度/
にかいどう /二階堂/
にかいどうこうこう /二階堂高校/
にかいめ /二回目/２回目/
にかいめいこう /二回目以降/
にかかい /二科会;二科展を主催/
にかく /仁鶴/
にかげつ /二ヶ月/二カ月/二箇月/
にかげつぶん /二箇月分/二カ月分/
にかこく /二ヵ国/
にかこくご /二ヶ国語/
にかしょ /二箇所/二カ所/2箇所/
にかた /煮方/
にかどでんち /ニカド電池/
にかほ /仁賀保/
にかめいが /二化螟蛾/
にかわ /膠/仁川/
にかわしつ /膠質/
にかわせ /荷為替/
にかん /二冠/
にが /苦/
にがうり /苦瓜/
にがお /似顔/
にがおえ /似顔絵/
にがおえたいしょう /似顔絵大賞/
にがき /苦木/
にがさ /苦さ/
にがたけ /苦竹/
にがっき /二学期/
にがつ /二月/２月/2月/如月;※連想,旧暦/
にがつかくめい /二月革命;1848年フランスでの革命。これにより王政から共和制に移行した。/
にがつち /苦土/
にがて /苦手/
にがてちゅう /苦手中/
にがびゃくどう /二河白道/
にがみ /苦味/苦み/
にがむし /苦虫/
にがゆ /煮粥/
にがよもぎ /苦艾/
にがり /苦汁/
にがわ /仁川/
にがわせ /荷為替/
にがわせてがた /荷為替手形;document bill(DB)/
にがわらい /苦笑い/
にがん /二眼/
にがんれふ /二眼レフ/
にき /仁木/二木/二基/二季;春と秋／雨季と乾季,春と秋／雨季と乾季/二気;陰と陽/日記;=にっき/二期/
にきかい /二期会;(歌劇団)/
にきさく /二期作/
にきしゅ /二機種/
にきたつ /熟田津;地名,伊予/
にきび /面皰/靤/
にきめ /和布/
にきゅう /二級/
にきゅうけんちくし /二級建築士/
にきゅうしゅ /二級酒/
にきゅうひん /二級品/
にきょく /二極/二曲/
にきょくか /二極化/
にきょくぶんか /二極分化/
にきょくめ /二曲目/
にきり /煮切り;-酒/
にぎす /似鱚/
にぎてき /二義的/
にぎにぎ /握々/握握;役人の子は-を良く覚え/賑々/賑賑/
にぎやか /賑やか/
にぎょう /二行/2行/
にぎり /握り;grip/
にぎりずし /握り鮨/
にぎりばし /握り箸/
にぎりめし /握り飯/
にぎわい /賑/賑わい/
にく /肉/二区/
にくあつ /肉厚/
にくいれ /肉入れ/
にくいろ /肉色/
にくか /肉果/
にくかい /肉塊/
にくかん /肉感/
にくかんてき /肉感的/
にくが /肉芽/
にくがかり /肉係/
にくがそしき /肉芽組織;[生物]granulation tissue/
にくがん /肉眼/
にくきゅう /肉球/
にくきり /肉切り/
にくきりぼうちょう /肉切り包丁/
にくぎゅう /肉牛/
にくけい /肉桂/肉髻;[仏教]/肉刑/
にくげ /肉芽/
にくこう /肉交/
にくこっぷん /肉骨粉/
にくざんほりん /肉山脯林/
にくしつ /肉質/
にくしみ /憎しみ/
にくしゅ /肉腫/
にくしょく /肉食/肉色/
にくしょくきょうりゅう /肉食恐竜/
にくしょくぎょ /肉食魚/
にくしょくじゅう /肉食獣/
にくしょくせい /肉食性/
にくしょくどうぶつ /肉食動物/
にくしん /肉親/肉身;flesh/
にくじき /肉食/
にくじきさいたい /肉食妻帯/
にくじゃが /肉じゃが/
にくじゅう /肉汁/
にくじょう /肉情/
にくじる /肉汁/
にくすい /肉穂/肉垂/
にくすいかじょ /肉穂花序/
にくずくか /ニクズク科/Myristicaceae/
にくずれ /荷崩れ/煮崩れ/
にくせい /肉声/
にくせいひん /肉製品/
にくたい /肉体/
にくたいかんけい /肉体関係/
にくたいてき /肉体的/
にくたいてきくつう /肉体的苦痛/
にくたいてきけっかん /肉体的欠陥/
にくたいてきとくちょう /肉体的特徴/
にくたいねんれい /肉体年齢/
にくたいは /肉体派/
にくたいび /肉体美/
にくたいろうどう /肉体労働/
にくだい /肉代/
にくだま /肉玉/
にくだん /肉弾/肉彈;「弾」旧字/
にくだんご /肉団子/
にくだんせん /肉弾戦/肉彈戰;旧字/
にくっけ /肉っ気/
にくづき /肉付き/肉月;[部首]「肌」の偏/
にくづけ /肉付け/
にくづめ /肉詰め/
にくてい /憎体/
にくてき /肉的/
にくどうふ /肉豆腐/
にくはく /肉薄/肉迫;≒肉薄/
にくばなれ /肉離れ/
にくひつ /肉筆/
にくふん /肉粉/
にくぶと /肉太/
にくぶとん /肉蒲団;李漁/
にくへん /肉片/
にくぼう /肉棒/
にくぼそ /肉細/
にくまれぐち /憎まれ口/
にくまれっこ /憎まれっ子/
にくまれもの /憎まれ者/
にくまれやく /憎まれ役/
にくまん /肉饅/肉まん/
にくまんじゅう /肉饅頭/
にくみそ /肉味噌/
にくや /肉屋/
にくやさい /肉野菜/
にくよう /肉用/
にくようぎゅう /肉用牛/
にくようしゅ /肉用種/
にくよく /肉欲/
にくよくてき /肉欲的/
にくりょうり /肉料理/
にくるい /肉類/
にくろむせん /ニクロム線/
にくん /二君/
にぐら /荷鞍/
にぐるま /荷車/
にぐん /二軍/二群/
にぐんおち /二軍落ち/
にけん /二軒/二件/二間/２研/二研/
にげ /逃げ/
にげあし /逃げ足/
にげうま /逃げ馬;[競馬]/
にげかくれ /逃げ隠れ/
にげきり /逃げ切り/
にげぐち /逃げ口/
にげこうじょう /逃げ口上/
にげことば /逃げ言葉/逃言葉/
にげごし /逃げ腰/
にげじたく /逃げ支度/
にげば /逃げ場/
にげみず /逃げ水/
にげみち /逃げ道/
にげん /二元/
にげんきん /二弦琴/
にげんしゃ /二玄社;[出版社名]www.nigensha.co.jp/
にげんてき /二元的/
にげんろん /二元論/
にこ /二胡/二個/2個/
にこう /二項/二高/2項/
にこうえんざんし /二項演算子/
にこうかんけい /二項関係/2項関係/
にこうていり /二項定理/
にこうぶんぷ /二項分布/
にこく /二国/
にこくかん /二国間/
にこくかんきょうぎ /二国間協議/
にこげ /和毛/
にこごり /煮凝り;[料理]煮汁がゼラチン状になる煮物。「赤魚の-」/煮凍り;=煮凝り/煮凝/
にこちんさん /ニコチン酸/
にこにこがお /ニコニコ顔/にこにこ顔/
にこみ /煮込み/煮込/
にこみりょうり /煮込み料理/
にころがし /煮転がし/
にこん /耳根/
にご /二語/
にごう /二号/二合/
にごうかん /二号館/
にごうめ /二合目/
にごしらえ /荷拵え/
にごり /濁り/
にごりえ /濁江/
にごりざけ /濁り酒/
にごりみず /濁り水/
にごん /二言/
にさ /二叉/
にさくひん /二作品/
にさつ /二冊/
にさつぶん /二冊分/
にさん /二三/二、三/
にさんか /二酸化/
にさんかいおう /二酸化硫黄/
にさんかたんそ /二酸化炭素/
にさんかちっそ /二酸化窒素/
にさんにち /二三日/２、３日/
にざえもん /仁左衛門/
にざかな /煮魚/
にし /西/二子/二死/螺/爾志/
にし> /西/
にしあい /二試合/
にしあいづ /西会津/
にしあおやま /西青山/
にしあかし /西明石/
にしあざい /西浅井/
にしあざぶ /西麻布/
にしあじあ /西アジア;地名/
にしあち /西阿知/
にしあまね /西周/
にしあらい /西新井/
にしありえ /西有家/
にしありた /西有田/
にしあわくら /西粟倉/
にしい /西井/
にしいえ /西家/
にしいけ /西池/
にしいず /西伊豆/
にしいずほうめん /西伊豆方面/
にしいちさんるい /二死一三塁/
にしいばらき /西茨城/
にしいる /西入ル/
にしいわい /西磐井/
にしうすき /西臼杵/
にしうみ /西海/
にしうめだ /西梅田/
にしうら /西浦/西裏/
にしうわ /西宇和/
にしお /西尾/
にしおおい /西大井/
にしおおいえき /西大井駅/
にしおおさかせん /西大阪線/
にしおおじ /西大路/
にしおおじごじょう /西大路五条/
にしおおじしじょう /西大路四条/
にしおおじしちじょう /西大路七条/
にしおおたに /西大谷/
にしおおつ /西大津/
にしおおつえき /西大津駅/
にしおか /西岡/
にしおぎ /西荻/
にしおぎくぼ /西荻窪/
にしおぎくぼえき /西荻窪駅/
にしおちあい /西落合/
にしかいがん /西海岸/
にしかごしま /西鹿児島/
にしかごしまかん /西鹿児島間/
にしかさい /西葛西/
にしかしま /西鹿島/
にしかすがい /西春日井/
にしかぜ /西風/
にしかた /西方/西片/西形/
にしかつやま /西勝山/
にしかつら /西桂/
にしかど /西角/西門/
にしかなざわ /西金沢/
にしかも /西加茂/
にしかるいざわ /西軽井沢/
にしかわ /西川/
にしかわきよし /西川きよし/
にしかん /西館/
にしかんだ /西神田/
にしかんばら /西蒲原/
にしがいち /西垣内/
にしがき /西垣/
にしがや /西ヶ谷/
にしがわ /西側/
にしがわしょこく /西側諸国/
にしがわじんえい /西側陣営/
にしがわせんしんこく /西側先進国/
にしき /錦/西紀/西木/二式/
にしきえ /錦絵/
にしきがおか /錦ヶ丘/
にしきがわてつどう /錦川鉄道/
にしきぎ /錦木/
にしきぎか /ニシキギ科/Celastraceae/
にしきぎもく /ニシキギ目/Celastrales/
にしきごい /錦鯉/
にしきた /西北/
にしきちょう /錦町/
にしきで /錦手/
にしきど /錦戸/
にしきどう /錦堂/
にしきね /和稲/
にしきのみはた /錦の御旗/
にしきみ /錦見/
にしきょうごく /西京極/
にしきょうごくきゅうじょう /西京極球場/
にしきりゅう /西桐生/
にしきりゅうえき /西桐生駅/
にしぎょうく /西京区/
にしぎんざ /西銀座/
にしく /西区/
にしくじょう /西九条/
にしくにさき /西国東/
にしくびき /西頚城/
にしくわな /西桑名/
にしくわなえき /西桑名駅/
にしぐち /西口/
にしぐちちかがい /西口地下街/
にしこう /西高/
にしこうえん /西公園/
にしこうべ /西神戸/
にしこく /西国/
にしこくぶんじ /西国分寺/
にしこくら /西小倉/
にしこくらえきまえ /西小倉駅前/
にしこまごめ /西駒込/
にしこむすび /西小結/
にしこやま /西小山/
にしご /西語/二死後/
にしごう /西郷/
にしごうし /西合志/
にしごたんだ /西五反田/
にしさんそう /西三荘/
にしさんどう /西参道/
にしざおう /西蔵王/
にしざき /西崎/
にしざわ /西澤/西沢/
にしざわじゅんいち /西澤潤一/
にししおがま /西塩釜/
にしした /西下/
にししば /西柴/
にししらい /西白井/
にししらかわ /西白河/
にししん /西新/
にししんじゅく /西新宿/
にししんじゅくしてん /西新宿支店/
にしじま /西島/西嶋/
にしじん /西陣/西新/
にしじんおり /西陣織/
にしすぎ /西杉/
にしすずらんだい /西鈴蘭台/
にしせきわけ /西関脇/
にしせんだい /西仙台/
にしせんぼく /西仙北/
にしぜき /西関/
にしぞの /西園/
にしたが /西多賀/
にしたてやま /西館山/西舘山;「館」異体字/
にしたに /西谷/
にしたま /西多摩/
にしたんざわ /西丹沢/
にしだ /西田/
にしだいら /西平/
にしだきたろう /西田幾多郎;哲学者/
にしだけ /西岳/
にしださちこ /西田佐知子/
にしだて /西館/
にしだとしゆき /西田敏行/
にしちく /西地区/
にしつがる /西津軽/
にしてつ /西鉄/
にしてつおおむたせん /西鉄大牟田線/
にしてつきたきゅうしゅうせん /西鉄北九州線/
にしてつびん /西鉄便/
にしてつふくおか /西鉄福岡/
にしとう /西棟/
にしとうきょう /西東京/
にしとうきょうたいかい /西東京大会/
にしとさ /西土佐/
にしとさむら /西土佐村/
にしとなみ /西砺波/西礪波/
にしどいつ /西ドイツ/西独/
にしどうろ /西道路/
にしどみ /西富/
にしな /仁科/西名/
にしないるねつ /西ナイル熱/
にしなかじまみなみかた /西中島南方/
にしなが /西永/
にしなきねんざいだん /仁科記念財団/
にしなす /西那須/
にしなだ /西灘/
にしなり /西成/
にしにっぽり /西日暮里/
にしにっぽん /西日本/
にしにほん /西日本/
にしにほんいち /西日本一/
にしにほんいちえん /西日本一円/
にしにほんがくせい /西日本学生/
にしにほんがわ /西日本側/
にしにほんししゃ /西日本支社/
にしにほんしぶ /西日本支部/
にしにほんしんぶん /西日本新聞/
にしにほんたんだいふ /西日本短大付/
にしにほんへん /西日本編/
にしね /西根/
にしの /西野/
にしのうち /西の内/
にしのおもて /西之表/
にしのきょう /西の京/
にしのしま /西ノ島/
にしのその /西之園;姓/
にしのだいら /西の平/
にしのはら /西之原/西野原/
にしのみや /西宮/
にしのみやかん /西宮間/
にしのみやきたぐち /西宮北口/
にしのみやきゅうぎじょう /西宮球技場/
にしのみやきゅうじょう /西宮球場/
にしのみやし /西宮市/
にしのみやせん /西宮線/
にしはくしまちょう /西白島町/
にしはし /西橋/
にしはた /西畑/
にしはちおうじえき /西八王子駅/
にしはま /西浜/
にしはら /西原/
にしはる /西春/
にしはんきゅう /西半球/
にしはんぶん /西半分/
にしばん /西版/
にしひら /西平/
にしび /西日/西陽/
にしびわじま /西枇杷島/
にしふじ /西富士/
にしふじのみや /西富士宮/
にしふな /西船/
にしふなばし /西船橋/
にしふなばしえき /西船橋駅/
にしふなばしかん /西船橋間/
にしべ /西部/
にしほ /西穂/
にしほうめん /西方面/
にしほだか /西穂高/
にしほんがんじ /西本願寺/
にしほんまち /西本町/
にしまいづる /西舞鶴/
にしまき /西牧/
にしまごめ /西馬込/
にしまち /西町/
にしまつ /西松/
にしまつうら /西松浦/
にしまど /西窓/
にしみなみ /西南/
にしみや /西宮/
にしみやきたぐちえき /西宮北口駅/
にしむき /西向き/
にしむら /西村/
にしむらや /西村屋/
にしむらやま /西村山/
にしむろ /西牟婁/
にしめ /西目/煮染め/煮しめ/
にしめいはん /西名阪/
にしめや /西目屋/
にしめら /西米良/
にしもと /西本/
にしもとかんとく /西本監督/
にしもり /西森/
にしもろかた /西諸県/
にしゃ /二者/二社/
にしゃかん /二者間/
にしゃせんいつ /二者選一/
にしゃたくいつ /二者択一/
にしや /西屋/
にしやいづ /西焼津/
にしやつしろ /西八代/
にしやま /西山/
にしやまぼくじょう /西山牧場/
にしやまものがたり /西山物語/
にしゅ /二種/
にしゅうかん /二週間/2週間/
にしゅうかんご /二週間後/
にしゅうかんまえ /二週間前/
にしゅうめいこう /二周目以降/
にしゅうれんぞく /二週連続/
にしゅつ /二出/
にしゅるい /二種類/
にしょう /二章/
にしょうがくしゃ /二松学舎/
にしょうてん /二焦点/
にしょうめ /二勝目/
にしょく /二色/二食/
にしよーろっぱ /西ヨーロッパ/
にしよこづな /西横綱/
にしよこはま /西横浜/
にしよどがわ /西淀川/
にしわかまつ /西若松/
にしわき /西脇/
にしわきじゅんざぶろう /西脇順三郎;詩人。『旅人かへらず』/
にしわせだ /西早稲田/
にしわだ /西和田/
にしん /鰊/鯡;=鰊/二審/二進;0b0110/二心;-を抱く/二伸;p.s./2進/
にしんき /二進木/
にしんぎ /二進木/
にしんすう /二進数/2進数/
にしんとう /二親等/
にしんほう /二進法/２進法/
にしんわ /2進和/
にじ /虹/二次/二時/二児/尼寺/二字/霓;=虹/２次/2次/2時/
にじ> /二次;-試験,-創作/
にじいろ /虹色/
にじかい /二次会/
にじかこう /二次加工/
にじかん /二時間/2時間/
にじかんすう /二次関数/
にじかんせん /二次感染/
にじがわ /二次側/
にじき /二時期/
にじきおく /二次記憶/
にじきおくそうち /二次記憶装置/
にじきょくせん /二次曲線/
にじきょくめん /２次曲面/2次曲面/
にじく /二軸/
にじくけっしょう /二軸結晶/
にじけい /2次系/
にじげん /二次元/２次元/2次元/
にじげんてき /二次元的/
にじこ /虹子/
にじさいがい /二次災害/
にじしき /二次式/
にじしけん /二次試験/
にじしょうがい /二次障害/
にじしよう /二次使用/
にじしようりょう /二次使用料/
にじしりょう /二次資料/
にじじこ /二次事故/
にじすいしょう /虹水晶/
にじせい /二字姓/
にじせいちょう /二次生長/
にじそうさく /二次創作/
にじたいしゃ /二次代謝/
にじっさい /二十歳/
にじっせいき /二十世紀/
にじっぴき /二十匹/
にじてき /二次的/2次的/
にじてきちょさくぶつ /二次的著作物/
にじでんせつ /虹伝説/
にじでんち /二次電池/
にじの /虹野/
にじはいふ /二次配布/
にじばん /二次版/
にじへき /二次壁/
にじほうていしき /二次方程式/
にじます /虹鱒/
にじみゃく /二次脈/
にじもくぶ /二次木部/
にじゅう /二重/廿/二十/2重/
にじゅうあご /二重顎/
にじゅういちだいしゅう /二十一代集/
にじゅういっし /二十一史/
にじゅういっせいき /二十一世紀/
にじゅういんようふ /二重引用符/
にじゅううつし /二重写し/二重映し/
にじゅうおり /二重織/
にじゅうおんせい /二重音声/
にじゅうか /二重化/
にじゅうかかく /二重価格/
にじゅうかぎかっこ /二重鉤括弧/『/』/
にじゅうかくさん /二重拡散/
にじゅうかぜい /二重課税/
にじゅうかべ /二重壁/
にじゅうかん /二重管/
にじゅうかんせつ /二重間接/
にじゅうきじゅん /二重基準/
にじゅうく /二重苦/
にじゅうけつごう /二重結合/
にじゅうこうぞう /二重構造/
にじゅうこくせき /二重国籍/
にじゅうごし /二十五史;二十四史＋新元史/
にじゅうさっし /二重サッシ/
にじゅうさんく /二十三区/
にじゅうさんじゅう /二重三重/
にじゅうさんや /二十三夜;Make a wish!/
にじゅうしし /二十四史;二十一史＋旧唐書＋旧五代史＋明史/
にじゅうしせっき /二十四節気/
にじゅうしょう /二重唱/
にじゅうじんかく /二重人格/
にじゅうせい /二重性;dualism/二重星;[天文]double star/
にじゅうせいかつ /二重生活/
にじゅうせいきゅう /二重請求/
にじゅうせきぶん /二重積分/∬/
にじゅうせん /二重線/2重線/
にじゅうそう /二重奏/
にじゅうぞこ /二重底/
にじゅうだい /二十代/
にじゅうていぎ /二重定義/
にじゅうとうこう /二重投稿/
にじゅうとうひょう /二重投票/
にじゅうとうろく /二重登録/
にじゅうにし /二十二史;二十一史＋旧唐書or明史/
にじゅうねん /二十年/
にじゅうはちぶしゅう /二十八部衆;[仏教]千手観音の眷属/
にじゅうはっしゅく /二十八宿/
にじゅうはんてん /二重反転/
にじゅうばし /二重橋/
にじゅうばしまえ /二重橋前/
にじゅうばしまええき /二重橋前駅/
にじゅうひてい /二重否定/2重否定/
にじゅうぶんせつ /二重分節;[言語]double articulation/
にじゅうぼいん /二重母音/
にじゅうまど /二重窓/
にじゅうまる /二重丸/◎/
にじゅうめんそう /二十面相/
にじゅうもうけんほう /二重盲検法;double blind test(DBT)/
にじゅうやまかっこ /二重山括弧/《/》/
にじゅうやまがっこ /二重山括弧/《/》/
にじゅうよじかんせい /二十四時間制/
にじゅうよんきん /二十四金/
にじゅうらせん /二重螺旋;[生物]double helix/
にじゅうろくや /二十六夜/
にじゅうろこう /二重露光/
にじゅうわく /二重枠/
にじゅっさい /二十歳/
にじゅっせいき /二十世紀/
にじゅっぴき /二十匹/
にじょ /二女/
にじょう /二条/二乗/二丈/2乗/
にじょういんのさぬき /二条院讃岐;わが袖は 潮ひにみえぬ 沖の石の 人こそしらね かわくまもなし/
にじょうき /二畳紀;[地質年代]=ペルム紀/
にじょうこん /二乗根;[数学]sqrt/
にじょうごさ /二乗誤差/
にじょうじょう /二条城/
にじょうてんのう /二条天皇/
にじょうほう /二乗法/
にじょうわ /二乗和/２乗和/
にじよせん /二次予選/
にじりぐち /躙り口;[茶道]/
にじりゅうし /二次粒子/2次粒子/
にじりん /二次林;[林学]second growth/
にじる /煮汁/
にじるし /荷印/
にじんえい /二陣営/
にすい /二水;[部首](冫)/
にすがた /荷姿;packing/似姿;icon/
にせ /偽/贋/偐;≒贋/僞;「偽」の旧字(人名用漢字)/二世/
にせ> /偽;偽一万円札,偽ブランド/
にせい /二世/二星;Altair and Vega/２声/
にせえ /似絵/
にせがね /贋金/
にせき /二関/
にせけいかん /偽警官/
にせさつ /偽札/贋札/
にせたい /二世帯/
にせたいじゅうたく /二世帯住宅/
にせたんてい /偽探偵/
にせもの /偽物;fake/偽者;なりすまし/贋物;=偽物/贋者/
にせものがたり /仁勢物語/
にせん /二千/二線/二錢;「銭」旧字/
にせんえん /二千円/
にせんえんさつ /二千円札/
にせんきゅう /二線級/
にせんしき /二線式/
にせんめ /二煎目/
にそう /尼僧/二層/二相/二曹/
にそうしき /二槽式/
にそうしきせんたくき /二槽式洗濯機/
にそうりゅう /二相流/
にそく /二足/
にそくさんもん /二束三文/
にそくほこう /二足歩行/
にぞめ /煮染め/
にた /仁多/
にたい /二体/
にたいもんだい /二体問題/
にたき /煮炊き/
にたく /二択/
にただ /仁多田/
にたどり /似鳥/
にたに /二谷/
にたにゆりえ /二谷友里恵/
にたまご /煮卵/
にたみ /仁多見/
にたもの /似た者/
にたやま /仁田山/
にたりよったり /似たり寄ったり/
にたろう /二太郎/
にたんちょう /ニ短調/
にだ /荷駄/
にだい /荷台/二台/二大/2大/
にだいかいちょう /二代会長/
にだいしょうぐん /二代将軍/
にだいせいとう /二大政党/
にだいせいとうせい /二大政党制/
にだいめ /二代目/二台目/
にだし /煮出し/荷出し/
にだしじる /煮出し汁/
にだな /荷棚/
にだん /二段/
にだんかい /二段階/2段階/
にだんかつよう /二段活用/
にだんがさね /二段重ね/
にだんがまえ /二段構え;with a fallback/
にだんぐみ /二段組/
にだんこうげき /二段攻撃/
にだんめ /二段目/
にち /日/二値/2値/
にち> /日;日米,日農,嫌日感情/
にちい /日伊/
にちいき /日域/
にちいだい /日医大/
にちいん /日陰/
にちうん /日暈/
にちえい /日英/日影/日栄/
にちおう /日欧/
にちおん /日音/
にちか /二値化/2値化/二千翔/
にちかくさ /日較差/
にちかん /日間/
にちが /日我/
にちがく /日額/
にちがぞう /二値画像/
にちぎん /日銀/
にちぎんそうさい /日銀総裁/
にちぎんたんかん /日銀短観/
にちぎんほう /日銀法/
にちげつ /日月/
にちげつか /日月火/
にちげつかすい /日月火水/
にちげつかすいもく /日月火水木/
にちげん /日限/
にちご /日後/日語/
にちじ /日時/日次/
にちじび /日耳鼻/
にちじゅう /日中/
にちじょう /日常/日乗;diary/
にちじょう> /日常/
にちじょういっぱん /日常一般/
にちじょうかいわ /日常会話/
にちじょうぎょうむ /日常業務/
にちじょうげんご /日常言語/
にちじょうご /日常語/
にちじょうさはん /日常茶飯/
にちじょうさはんじ /日常茶飯事/
にちじょうしゃかい /日常社会/
にちじょうしゅ /日常酒/
にちじょうしゅうかん /日常習慣/
にちじょうせい /日常性/
にちじょうせいかつ /日常生活/
にちじょうせいかつじょう /日常生活上/
にちじょうせいかつぜんぱん /日常生活全般/
にちじょうてき /日常的/
にちじょうふうけい /日常風景/
にちじょうりよう /日常利用/
にちじょたいだい /日女体大/
にちじん /日神/
にちずい /日瑞/
にちだい /日大/日本大学;※abbrev/
にちだいこうどう /日大講堂/
にちだいさくらがおか /日大桜ヶ丘/
にちだいせいさんこう /日大生産工/
にちだいだいがくいん /日大大学院/
にちだいつるがおか /日大鶴ヶ丘/
にちだいにこう /日大二高/
にちだいぶざん /日大豊山/
にちだいやまがた /日大山形/
にちだいりこう /日大理工/
にちづけ /日付/
にちでん /日電/
にちでんきょう /日電協/
にちでんせい /日電製/
にちでんばん /日電版/
にちどう /日動/
にちどうかさい /日動火災/
にちどく /日独/
にちどくい /日独伊/
にちどくいさんごくどうめい /日独伊三国同盟/
にちなん /日南/
にちなんかいがん /日南海岸/
にちなんがくえん /日南学園/
にちなんし /日南市/
にちにち /日々/
にちにちこれこうじつ /日々是好日/
にちにちそう /日日草/
にちのうけん /日能研;[略語]日本能率研究会/
にちはむ /日ハム/日本ハム;※abbrev/
にちはら /日原/
にちはん /日半/日販;[企業名][略語]日本出版販売株式会社。www.nippan.co.jp/
にちふつ /日仏/
にちふつじしょ /日仏辞書/
にちぶ /日舞/
にちぶん /日分;(助数詞)/日文;[略語]日本文学/
にちべい /日米/
にちべいおう /日米欧/
にちべいかいぎ /日米会議/
にちべいかいせん /日米開戦/
にちべいかがくきょうりょくじぎょう /日米科学協力事業/
にちべいかん /日米間/
にちべいきょうどう /日米共同/
にちべいきょうどうけんきゅう /日米共同研究/
にちべいぎょうせいきょうてい /日米行政協定/
にちべいこうくうきょうてい /日米航空協定/
にちべいこうしょう /日米交渉/
にちべいこうぞうきょうぎ /日米構造協議/
にちべいしんぜん /日米親善/
にちべいせんそう /日米戦争/
にちべいたいこう /日米対抗/
にちべいちいきょうてい /日米地位協定/
にちべいひかく /日米比較/
にちべいぼうえきまさつ /日米貿易摩擦/
にちべいやきゅう /日米野球/
にちべんれん /日弁連/
にちぼうしん /日貿信/
にちぼつ /日没/
にちぼつご /日没後/
にちぼつじこく /日没時刻/
にちぼつまえ /日没前/
にちまえ /日前/
にちまんぎていしょ /日満議定書/
にちめ /日目/
にちめんじつぎょう /日綿実業/
にちもつ /日没/
にちや /日夜/
にちやどりょく /日夜努力/
にちゅう /二中/
にちょう /二鳥/
にちょうけんじゅう /二挺拳銃/
にちょうちょう /ニ長調/
にちょうなげ /二丁投げ/
にちょうめ /二丁目/
にちょく /二直;[野球]セカンドライナー/
にちよう /日曜/日用/
にちようあさ /日曜朝/
にちよううんきゅう /日曜運休/
にちようがっこう /日曜学校;教会の-/
にちようげきじょう /日曜劇場/
にちようごご /日曜午後/
にちようさいじつ /日曜祭日/
にちようざっか /日用雑貨/
にちようしゅくじつ /日曜祝日/
にちようしゅっきん /日曜出勤/
にちようしんや /日曜深夜/
にちようだいく /日曜大工/
にちようはつ /日曜発/
にちようばん /日曜版/
にちようひん /日用品/
にちようび /日曜日/
にちようびあさ /日曜日朝/
にちようびじゅつかん /日曜美術館/
にちようびゆうがた /日曜日夕方/
にちようぶん /日曜分/
にちようようがげきじょう /日曜洋画劇場/
にちようよる /日曜夜/
にちりょう /日糧/
にちりん /日輪/日林/
にちりんし /日林誌/
にちりんろん /日林論/
にちれき /日瀝/
にちれん /日蓮/
にちれんしゅう /日蓮宗/
にちろ /日露/
にちろぎょぎょう /日魯漁業/
にちろく /日録/
にちろせんえき /日露戦役/
にちろせんそう /日露戦争/
にちわ /日和/
にっか /日課/日華/日貨/
にっかぎれん /日科技連/
にっかじへん /日華事変/
にっかつ /日活/
にっかつこうぎょう /日活興業;[企業名]/
にっかどでんち /ニッカド電池/
にっかひょう /日課表/
にっかわ /新川/
にっかん /日刊/日韓/肉感/
にっかん> /日刊/
にっかんきょうてい /日韓協定/
にっかんぎていしょ /日韓議定書/
にっかんけいば /日刊競馬/
にっかんこう /日刊工/
にっかんこうぎょう /日刊工業;[企業名]/
にっかんこうぎょうしんぶん /日刊工業新聞/
にっかんこうぎょうしんぶんしゃ /日刊工業新聞社;[企業名]/
にっかんこうしょう /日韓交渉/
にっかんこうそくせん /日韓高速船/
にっかんし /日刊紙/
にっかんじょうやく /日韓条約/
にっかんてき /肉感的;sensual/
にっき /日記/日揮;[企業名]www.jgc.co.jp/肉桂;cinnamon/
にっきしゅう /日記集/
にっきそう /日機装/
にっきちょう /日記帳/
にっきふう /日記風/
にっきぶんがく /日記文学/
にっきゅう /日給/
にっきょう /日共/
にっきょうさい /日教済;財団法人日本教育公務員弘済会/
にっきょうそ /日教組;日本教職員組合/
にっきん /日勤/
にっくう /日空/
にっくに /新国/
にっけい /日経;[略語]日本経済新聞(社)/日系;Japanese.「-三世」/日計;daily total/肉桂;cinnamon/
にっけいいろ /肉桂色;cinnamon (黄褐色)/
にっけいきぎょう /日系企業/
にっけいこうくうがいしゃ /日系航空会社/
にっけいさんぎょうしんぶん /日経産業新聞/
にっけいしょう /日経賞/
にっけいしんしゅんはい /日経新春杯/
にっけいしんぶん /日経新聞/
にっけいしんぶんゆうかん /日経新聞夕刊/
にっけいじん /日系人/
にっけいにせい /日系二世/
にっけいひょう /日計表/
にっけいへいきん /日経平均/
にっけいへいきんかぶか /日経平均株価/
にっけいれん /日経連/
にっける /Ni/Nickel/
にっけんかがく /日研化学;[企業名]/
にっこう /日光/日興/日航/日工/
にっこういがい /日光以外/
にっこうえき /日光駅/
にっこうかいどう /日光街道/
にっこうがわ /日光側/
にっこうき /日航機/
にっこうきどう /日光軌道/
にっこうきょうせき /日鉱共石/
にっこうしょうけん /日興證券;[企業名]NB:現・日興コーディアル証券/日興証券;※「日興證券」が正式だった/
にっこうせん /日光線/
にっこうよく /日光浴/
にっこり /莞爾;かんじ (当て字)/
にっころがし /煮っ転がし/
にっさん /日産/日参/
にっさんしゃ /日産車/
にっさんしゃたい /日産車体;[企業名]/
にっさんじどうしゃ /日産自動車;[企業名]/
にっさんよこはま /日産横浜/
にっし /日誌/
にっしゃ /日射/
にっしゃびょう /日射病/
にっしゃりょう /日射量/
にっしゅう /日周/日収/入集/日州;日向/
にっしゅつ /日出/
にっしょう /日照/日商/日章/入声/
にっしょういわい /日商岩井/
にっしょうき /日章旗/
にっしょうけん /日照権/
にっしょうけんもんだい /日照権問題/
にっしょうじかん /日照時間/
にっしょうどう /日章堂/
にっしょうぶそく /日照不足/
にっしょうりょう /日照量/
にっしょく /日食/日蝕/
にっしん /日清;†日本と清国。「-戦争」/日新;†日々に新た/日進;†「-月歩」/日神/日心/
にっしんげっぽ /日進月歩/
にっしんしょくひん /日清食品;[企業名]/
にっしんせいこう /日新製鋼;[企業名]/
にっしんせいふん /日清製粉;[企業名]/
にっしんせいゆ /日清製油;[企業名]/
にっしんせんそう /日清戦争;1894-95/
にっしんちょう /日進町/
にっしんぼうせき /日清紡績;[企業名]/
にっすう /日数/
にっせい /日生/日精/
にっせいげきじょう /日生劇場/
にっせいさんぎょう /日製産業;[企業名]/
にっせき /日赤;[略語]日本赤十字社/日夕;昼夜,夕方/日石;[略語]日本石油/
にっそ /日ソ/
にっそう /入宋/
にっそうかん /日想観/
にっそきょうどうせんげん /日ソ共同宣言;1956/
にった /新田/仁田/
にったいだい /日体大/
にったく /日拓/
にったん /日鍛/
にっちしじょう /ニッチ市場/
にっちせんりゃく /ニッチ戦略;[新語]niche strategies/
にっちつ /日窒/
にっちも /二進も/
にっちもさっちも /二進も三進も/
にっちゅう /日中/
にっちゅうかん /日中間/日中韓/
にっちゅうかんけい /日中関係/
にっちゅうきょうどうせいめい /日中共同声明/
にっちゅうしよう /日中使用/
にっちゅうせんそう /日中戦争/
にっちゅうそうほう /日中双方/
にっちゅうへいわゆうこうじょうやく /日中平和友好条約/
にっちゅうゆうこう /日中友好/
にっちゅうりょこうしゃ /日中旅行社/
にっちょう /日朝/
にっちょうかんけい /日朝関係/
にっちょく /日直/
にっつう /日通/
にっつうこうくう /日通航空/
にってい /日程/日帝/
にっていえんき /日程延期/
にっていちょうせい /日程調整/
にっていてき /日程的/
にっていひょう /日程表/
にっていへんこう /日程変更/
にってつ /日鉄/
にってれ /日テレ/
にってん /日展/
にってんし /日天子/
にっとう /日当/日東/入唐/日塔/
にっとうしょいん /日東書院;[出版社名]/
にっとうせいもう /日東製網/
にっとうぼう /日東紡/
にっとうぼうせき /日東紡績/
にっぱい /日配/
にっぱいひん /日配品/
にっぱち /二八;商売の落ち込む二月と八月/
にっぴょう /日評/
にっぽう /日報/日豊/
にっぽうせん /日豊線/
にっぽうほんせん /日豊本線/
にっぽじしょ /日葡辞書/
にっぽり /日暮里/
にっぽん /日本/
にっぽんいち /日本一/
にっぽんえいたいぐら /日本永代蔵;西鶴/
にっぽんかーぼん /日本カーボン/
にっぽんかい /日本海/
にっぽんかせい /日本化成/
にっぽんかん /日本間/
にっぽんがいし /日本ガイシ/日本碍子/
にっぽんきんぞく /日本金属/
にっぽんぎんこう /日本銀行/
にっぽんぐんじん /日本軍人/
にっぽんぐんぶたい /日本軍部隊/
にっぽんぐんへいし /日本軍兵士/
にっぽんけいざい /日本経済/
にっぽんけおり /日本毛織/
にっぽんけみこん /日本ケミコン/
にっぽんけみふぁ /日本ケミファ/
にっぽんこう /日本校/
にっぽんこうかいじ /日本公開時/
にっぽんこうかん /日本鋼管/
にっぽんこうくう /日本航空/
にっぽんこく /日本国/
にっぽんこくけんぽう /日本国憲法/
にっぽんころむびあ /日本コロムビア/
にっぽんご /日本語/
にっぽんしき /日本式/
にっぽんしん /日本新/
にっぽんしんぱん /日本信販/
にっぽんしんやく /日本新薬/
にっぽんじゅう /日本中/
にっぽんじん /日本人/
にっぽんじんかんこうきゃく /日本人観光客/
にっぽんじんしんぱん /日本人審判/
にっぽんじんせんしゅ /日本人選手/
にっぽんすいさん /日本水産/
にっぽんせいこう /日本精工/
にっぽんせいふん /日本製粉/
にっぽんぜおん /日本ゼオン/
にっぽんたいかい /日本大会/
にっぽんだいひょう /日本代表/
にっぽんだんじ /日本男児/
にっぽんつううん /日本通運;[企業名]/
にっぽんでんき /日本電気/
にっぽんでんこう /日本電工;[企業名]/
にっぽんでんそう /日本電装/
にっぽんでんつう /日本電通/
にっぽんとむそん /日本トムソン/
にっぽんどうろ /日本道路/
にっぽんはつじょう /日本発条/
にっぽんはむ /日本ハム/
にっぽんばし /日本橋/
にっぽんひゅーむかん /日本ヒューム管/
にっぽんびくたー /日本ビクター/
にっぽんぶどうかん /日本武道館/
にっぽんぺいんと /日本ペイント/
にっぽんほうそう /ニッポン放送;www.jolf.co.jp/日本放送;?/
にっぽんほんど /日本本土/
にっぽんゆうせん /日本郵船;[企業名]/
にっぽんゆそうき /日本輸送機/
にっぽんゆにばっく /日本ユニバック/
にっぽんれーす /日本レース/
にっぽんれっとう /日本列島/
につう /二通/2通/
につうめ /2通目/
につけ /煮付け/煮つけ/
にづくり /荷造り/荷作り/
にづくりひ /荷造費/
にづみ /荷積み/
にて /二手/
にていぜんしょ /二程全書/
にてん /二点/2点/
にてんさんてん /二転三転/
にてんとうし /二点透視/
にと /二兎/二途/
にとう /二等/二頭/仁藤/二盗;[野球]stealing second/二党/
にとうきん /二頭筋/
にとうしゃ /二等車/
にとうしん /二頭身/
にとうだて /二頭立て/
にとうぶん /二等分/2等分/
にとうぶんせん /二等分線/
にとうへい /二等兵/
にとうへいそう /二等兵曹/
にとうへんさんかくけい /二等辺三角形/
にとうへんさんかっけい /二等辺三角形/
にとうめ /二頭目/
にとうりゅう /二刀流/
にとべ /新渡戸/二藤部/
にとべいなぞう /新渡戸稲造/
にとものがたり /二都物語/
にど /二度/
にどいも /二度芋/
にどうち /二度打ち/
にどさんど /二度三度/
にどざき /二度咲き/
にどでま /二度手間/
にどと /二度と/
にどぬり /二度塗り/二度塗/
にどね /二度寝/
にどめ /二度目/
にな /螺/蜷/
にないて /担い手/
にながわ /蜷川/
ににぎのみこと /邇邇芸命/
ににん /二人/
ににんさんきゃく /二人三脚/
ににんしょう /二人称/
ににんしょうたんすう /二人称単数/
ににんまえ /二人前/
ににんわんきゅう /二人椀久/
にぬき /煮抜き/荷抜き/
にぬきたまご /煮抜き玉子/
にぬけ /二抜け/２抜け/
にぬし /荷主/
にねん /二年/２年/2年/
にねんかん /二年間/
にねんご /二年後/
にねんせい /二年生/2年生/
にねんせいそうほん /二年生草本/
にねんそう /二年草;園芸/
にねんまえ /二年前/
にねんめ /二年目/
にのあし /二の足;-を踏む/
にのうで /二の腕/
にのおり /二の折;[俳諧]/
にのかまえ /二構/二構え/
にのく /二の句/
にのじてん /二の字点;1-2-22/
にのつぎ /二の次/
にのへ /二戸/
にのまい /二の舞/二の舞い/
にのまる /二の丸/
にのみや /二宮/二の宮/
にのみやそんとく /二宮尊徳/
にのや /二の矢/
には /二波/二派/
にはい /二杯/二敗/
にはいず /二杯酢/
にはか /俄/
にはく /二泊/二拍/2泊/
にはくみっか /二泊三日/
にはくめ /二拍目/
にはつ /二発/
にはつめ /二発目/
にはん /二版/二犯/
にばい /二倍/
にばいす /二杯酢/
にばいたい /二倍体;[生物]diploid. これが普通/
にばこ /荷箱/
にばしゃ /荷馬車/
にばん /二番/
にばんかん /二番館/
にばんせき /二番席/
にばんせんじ /二番煎じ/
にばんだしゃ /二番打者/
にばんちょう /二番町/
にばんて /二番手/
にばんめ /二番目/2番目/
にひ /二飛;[野球]セカンドフライ/
にひき /二匹/
にひきめ /二匹目/
にひゃく /二百/
にひゃくすうじゅうねん /二百数十年/
にひゃくとおか /二百十日/
にひゃくはつか /二百二十日/
にびいろ /鈍色/
にびたし /煮浸し/煮びたし/
にびょうし /二拍子;[音楽]/
にふ /二夫;-にまみえず/二歩;[将棋]/２符/
にふくつい /二幅対/
にふだ /荷札/
にふん /二分/2分/
にぶ /二部/二分/2部/II部/
にぶおんぷ /二分音符/２分音符/
にぶさく /二部作/
にぶじょうじょう /二部上場/
にぶせい /二部制/
にぶつ /二物/
にぶね /荷船/
にぶん /二分/2分/
にぶんか /二分化/
にぶんき /二分木/
にぶんぎ /二分木/2分木/
にぶんほう /二分法/2分法/
にへい /二瓶/仁平/
にへん /二辺/
にへんすう /2変数/
にべ /仁部/鰾膠;-もない/
にほ /二歩/
にほう /二方/
にほうせい /二峰性/
にほてまえ /二歩手前/
にほん /日本/二本/
にほん> /日本/
にほんあし /二本足/
にほんいかだいがく /日本医科大学/
にほんいがい /日本以外/
にほんいくえいかい /日本育英会/
にほんいしかい /日本医師会;www.med.or.jp/
にほんいじょう /日本以上/
にほんいたがらす /日本板硝子/
にほんいだい /日本医大/
にほんいち /日本一/
にほんいっしゅう /日本一周/
にほんえいが /日本映画/
にほんえいがしじょう /日本映画史上/
にほんえいせいほうそう /日本衛星放送/
にほんえいたいぐら /日本永代蔵;西鶴/
にほんえん /日本円/
にほんえんかきょうかい /日本煙火協会/
にほんえんがん /日本沿岸/
にほんえんげきし /日本演劇史/
にほんおうふく /日本往復/
にほんおおかみ /日本狼;Canis hodophilax/
にほんおんがく /日本音楽/
にほんおんがくちょさくけんきょうかい /日本音楽著作権協会;JASRAC (Japanese Society for Rights of Authors, Composers and Publishers)/
にほんおんきょうがっかい /日本音響学会/
にほんおんきょうがっかいし /日本音響学会誌/
にほんか /二本化/
にほんかい /日本海/
にほんかいえんがん /日本海沿岸/
にほんかいかいせん /日本海海戦/
にほんかいがたきこう /日本海型気候/
にほんかいがわ /日本海側/
にほんかいぐん /日本海軍/
にほんかいこう /日本海溝/
にほんかいじゅうかん /日本海縦貫/
にほんかいはつぎんこう /日本開発銀行;Japan Development Bank(JDB) (現・日本政策投資銀行)/
にほんかいようがっかい /日本海洋学会/
にほんかいりゅう /日本海流/
にほんかがっかい /日本化学会/
にほんかくち /日本各地/
にほんかぶ /日本株/
にほんかぼちゃ /日本南瓜/
にほんかやく /日本化薬/
にほんかん /日本館/日本間/
にほんが /日本画/
にほんがいし /日本ガイシ;[企業名]/日本碍子;[企業名]※「日本ガイシ」が正式名/
にほんがく /日本学/
にほんがくしいん /日本学士院/
にほんがくじゅつかいぎ /日本学術会議/
にほんがくじゅつしんこうかい /日本学術振興会;www.jsps.go.jp/
にほんがた /日本型/
にほんがみ /日本髪/
にほんがわ /日本側/
にほんがわふたん /日本側負担/
にほんがわら /日本瓦/
にほんきいん /日本棋院/
にほんきか /日本帰化/
にほんきかいがっかい /日本機械学会/
にほんきかくきょうかい /日本規格協会/
にほんきぎょう /日本企業/
にほんきしょうきょうかい /日本気象協会/
にほんきどうぶたい /日本機動部隊/
にほんきょうさんとう /日本共産党/
にほんきょじゅうしゃ /日本居住者/
にほんきりすときょうだん /日本基督教団/
にほんきりゃく /日本紀略;神代-1036の歴史書/
にほんきろく /日本記録/
にほんきんかい /日本近海/
にほんぎ /日本紀;六国史、または日本書紀のこと/
にほんぎんこう /日本銀行/
にほんぎんこうけん /日本銀行券/
にほんくっし /日本屈指/
にほんぐん /日本軍/
にほんぐんこくしゅぎ /日本軍国主義/
にほんぐんじん /日本軍人/
にほんけいえいきょうかい /日本経営協会/
にほんけいざい /日本経済/
にほんけいざいしんぶん /日本経済新聞/
にほんけいざいしんぶんしゃ /日本経済新聞社;[企業名]www.nikkei.co.jp/
にほんけん /日本犬/
にほんけんちくがっかい /日本建築学会/
にほんげいじゅついん /日本芸術院;文科省所管。www.geijutuin.go.jp/
にほんげいじゅつぶんかしんこうかい /日本芸術文化振興会;www.ntj.jac.go.jp/
にほんげんごがっかい /日本言語学会/
にほんこう /日本校/
にほんこうえん /日本公演/日本講演/
にほんこうかい /日本公開/
にほんこうかいばん /日本公開版/
にほんこうかん /日本鋼管/
にほんこうき /日本後紀;792-833の歴史書。大半が散逸。840年成立/
にほんこうぎょう /日本鉱業/
にほんこうぎょうきかく /日本工業規格/
にほんこうぎょうぎんこう /日本興業銀行/
にほんこうぎょうだい /日本工業大/
にほんこうぎょうだいがく /日本工業大学/
にほんこうくう /日本航空/
にほんこうそくつうしん /日本高速通信/
にほんこうだい /日本工大/
にほんこうつうこうしゃ /日本交通公社/
にほんこうでん /日本光電/
にほんこうぶつがっかい /日本鉱物学会/
にほんこく /日本国/日本國/
にほんこくがい /日本国外/
にほんこくけんぽう /日本国憲法/
にほんこくけんぽうか /日本国憲法下/
にほんこくさい /日本国債/
にほんこくせいふ /日本国政府/
にほんこくせき /日本国籍/
にほんこくせきりだつ /日本国籍離脱/
にほんこくどかいはつ /日本国土開発/
にほんこくない /日本国内/
にほんこくないはっこう /日本国内発行/
にほんこくないりょこう /日本国内旅行/
にほんこくみん /日本国民/
にほんこくみんぜんいん /日本国民全員/
にほんこだいし /日本古代史/
にほんこゆう /日本固有/
にほんご /日本語/
にほんごいがい /日本語以外/
にほんごいじょう /日本語以上/
にほんごうせいごむ /日本合成ゴム/
にほんごおん /日本語音/
にほんごおんいん /日本語音韻/
にほんごか /日本語化/日本語可/
にほんごかいせき /日本語解析/
にほんごかくちょう /日本語拡張/
にほんごかさぎょう /日本語化作業/
にほんごかんきょう /日本語環境/
にほんごかんけい /日本語関係/
にほんごかんじ /日本語漢字/
にほんごかんれん /日本語関連/
にほんごがく /日本語学/
にほんごきげん /日本語起源/
にほんごきのう /日本語機能/
にほんごきょうしつ /日本語教室/
にほんごくどうし /日本極道史/
にほんござっし /日本語雑誌/
にほんごしょり /日本語処理/
にほんごじしょ /日本語辞書/
にほんごじまく /日本語字幕/
にほんごじまくばん /日本語字幕版/
にほんごせんよう /日本語専用/
にほんごたいおう /日本語対応/
にほんごたいおうばん /日本語対応版/
にほんごたんまつ /日本語端末/
にほんごちゅう /日本語中/
にほんごつう /日本語通/
にほんごどくとく /日本語独特/
にほんごにゅうしゅつりょく /日本語入出力/
にほんごにゅうりょく /日本語入力/
にほんごにゅうりょくかんきょう /日本語入力環境/
にほんごにゅうりょくちゅう /日本語入力中/
にほんごにゅうりょくほうほう /日本語入力方法/
にほんごのうりょく /日本語能力/
にほんごばん /日本語版/
にほんごばんよう /日本語版用/
にほんごひょうき /日本語表記/
にほんごひょうげん /日本語表現/
にほんごひょうじ /日本語表示/
にほんごふう /日本語風/
にほんごぶぶん /日本語部分/
にほんごぶん /日本語文/
にほんごぶんけん /日本語文献/
にほんごぶんしょ /日本語文書/
にほんごぶんしょう /日本語文章/
にほんごぶんぽう /日本語文法/
にほんごへんかん /日本語変換/
にほんごへんかんよう /日本語変換用/
にほんごへんしゅう /日本語編集/
にほんごほうそう /日本語放送/
にほんごほんやく /日本語翻訳/
にほんごほんらい /日本語本来/
にほんごめい /日本語名/
にほんごもじ /日本語文字/
にほんごもじれつ /日本語文字列/
にほんごやく /日本語訳/
にほんごよう /日本語用/
にほんごりょく /日本語力/
にほんごろん /日本語論/
にほんさ /二本鎖/
にほんさいけんしんようぎんこう /日本債券信用銀行;現・あおぞら銀行/
にほんさいこ /日本最古/
にほんさいこう /日本最高/
にほんさいご /日本最後/
にほんさいしょ /日本最初/
にほんさいじょうりく /日本再上陸/
にほんさいだい /日本最大/
にほんさいだいきぼ /日本最大規模/
にほんさくひん /日本作品/
にほんさん /日本産/日本サン/
にほんさんぎょうしんぶん /日本産業新聞/
にほんさんけい /日本三景/
にほんさんそ /日本酸素/
にほんさんだいじつろく /日本三代実録;858-887の歴史書。901年成立/
にほんさんだいとうげ /日本三大峠/
にほんさんば /日本産馬/
にほんざし /二本差し/
にほんざる /日本猿/
にほんし /日本史/
にほんしかんけい /日本史関係/
にほんしき /日本式/
にほんしぎょう /日本紙業/
にほんししゃ /日本支社/
にほんしじょう /日本市場/日本史上/
にほんしたんほう /日本史探訪/
にほんしぶ /日本支部/
にほんしほん /日本資本/
にほんしゃ /日本車/
にほんしゃかい /日本社会/
にほんしゃかいぜんたい /日本社会全体/
にほんしゃかいとう /日本社会党/
にほんしゃりょう /日本車両/
にほんしゅ /日本酒/
にほんしゅっぱつ /日本出発/
にほんしゅっぱん /日本出版/
にほんしゅっぱんしゃ /日本出版社;[出版社名]/
にほんしゅど /日本酒度/
にほんしょう /日本賞/
にほんしょうぎれんめい /日本将棋連盟/
にほんしょえん /日本初演/
にほんしょき /日本書紀/
にほんしょく /日本食/
にほんしょくてん /日本食店/
にほんしょくひん /日本食品/
にほんしよう /日本仕様/
にほんしりーず /日本シリーズ;[野球]日本一決定戦/
にほんしん /日本新/
にほんしんきろく /日本新記録/
にほんしんとう /日本新党/
にほんしんどう /日本神道/
にほんしんぱん /日本信販/
にほんしんぶんきょうかい /日本新聞協会/
にほんしんりがっかい /日本心理学会/
にほんしんわ /日本神話/
にほんじかん /日本時間/
にほんじっしんぶんるいほう /日本十進分類法;Nippon Decimal Classification(NDC)/
にほんじゅう /日本中/
にほんじゅうだん /日本縦断/
にほんじょうくう /日本上空/
にほんじょし /日本女子/
にほんじょしだいひょう /日本女子代表/
にほんじょせい /日本女性/
にほんじん /日本人/
にほんじんいがい /日本人以外/
にほんじんいっぱん /日本人一般/
にほんじんいみん /日本人移民/
にほんじんかい /日本人会/
にほんじんかん /日本人観/
にほんじんかんこうきゃく /日本人観光客/
にほんじんかんとく /日本人監督/
にほんじんがくせい /日本人学生/
にほんじんがっこう /日本人学校/
にほんじんきしゃ /日本人記者/
にほんじんきょりゅうみん /日本人居留民/
にほんじんけんきゅうしゃ /日本人研究者/
にほんじんさっか /日本人作家/
にほんじんしよう /日本人仕様/
にほんじんじょうきゃく /日本人乗客/
にほんじんせんしゅ /日本人選手/
にほんじんてき /日本人的/
にほんじんどうし /日本人同士/
にほんじんはつ /日本人初/
にほんじんふうふ /日本人夫婦/
にほんじんみん /日本人民/
にほんじんりゅうがくせい /日本人留学生/
にほんじんりょこうしゃ /日本人旅行者/
にほんじんろん /日本人論/
にほんすいろきょうかい /日本水路協会/
にほんすうがっかい /日本数学会/
にほんすもうきょうかい /日本相撲協会/
にほんせい /日本製/
にほんせいこうしょ /日本製鋼所;[企業名]/
にほんせいさくとうしぎんこう /日本政策投資銀行;www.dbj.go.jp/
にほんせいさん /日本生産/
にほんせいねんかん /日本青年館/
にほんせいひん /日本製品/
にほんせいふ /日本政府/
にほんせいふく /日本征服/
にほんせいめい /日本生命/
にほんせき /日本籍/
にほんせきぐん /日本赤軍/
にほんせきじゅうじ /日本赤十字/
にほんせきじゅうじしゃ /日本赤十字社/
にほんせきゆ /日本石油;[企業名] NB:現・日石三菱株式会社/
にほんせめんと /日本セメント;[企業名]/
にほんせん /‖/
にほんせんしゅ /日本選手/
にほんせんしゅけん /日本選手権/
にほんぜい /日本勢/
にほんぜんこく /日本全国/
にほんぜんたい /日本全体/
にほんぜんど /日本全土/
にほんそーだ /日本曹達/
にほんたいいくきょうかい /日本体育協会;www.japan-sports.or.jp/
にほんたいいくだいがく /日本体育大学/
にほんたいおう /日本対応/
にほんたいかい /日本大会/
にほんたいざい /日本滞在/
にほんたいし /日本大使/
にほんたいしかん /日本大使館/
にほんたたき /日本叩き/
にほんたばこさんぎょうかぶしきがいしゃ /日本たばこ産業株式会社/
にほんたんぺんぶもん /日本短編部門/
にほんだーびー /日本ダービー;[競馬]/
にほんだい /日本大/
にほんだいがく /日本大学/
にほんだいじしょ /日本大辞書/
にほんだいひょう /日本代表/
にほんだいら /日本平/
にほんだいりてん /日本代理店/
にほんだて /二本建/二本立て/
にほんだんし /日本男子/
にほんちーむ /日本チーム/
にほんちく /日本地区/
にほんちず /日本地図/
にほんちゃ /日本茶/
にほんちゅうおうけいばかい /日本中央競馬会;JRA (Japan Racing Association)/
にほんちょうきしんようぎんこう /日本長期信用銀行;現・新生銀行/
にほんちんぼつ /日本沈没/
にほんつう /日本通/
にほんつううん /日本通運;[企業名]/
にほんづつみ /日本堤/
にほんていえん /日本庭園/
にほんていこくぐん /日本帝国軍/
にほんてき /日本的/
にほんてつどう /日本鉄道/
にほんてれび /日本テレビ;[企業名]www.ntv.co.jp/
にほんでんき /日本電気;[企業名]www.nec.co.jp/
にほんでんきせい /日本電気製/
にほんでんさんき /日本電算機/
にほんでんし /日本電子/
にほんでんしけいさん /日本電子計算/
にほんでんしんでんわ /日本電信電話/
にほんでんしんでんわかぶしきがいしゃ /日本電信電話株式会社;[企業名]NTT. www.ntt.co.jp/
にほんでんそう /日本電装/
にほんでんとう /日本伝統/
にほんでんねつがっかい /日本伝熱学会/
にほんでんぱこうぎょう /日本電波工業;[企業名]/
にほんとう /日本刀/
にほんとくゆう /日本特有/
にほんどうぶつがっかい /日本動物学会/
にほんどうろこうだん /日本道路公団/
にほんどくじ /日本独自/
にほんどくとく /日本独特/
にほんない /日本内/
にほんなみ /日本並/
にほんにんちかがくかい /日本認知科学会/
にほんねこ /日本猫/
にほんのうえん /日本脳炎/
にほんのうりつきょうかい /日本能率協会/
にほんのうりんきかく /日本農林規格/
にほんはっちゃく /日本発着/
にほんはつ /日本初/日本発/
にほんはつとうじょう /日本初登場/
にほんはつばい /日本発売/
にほんはむ /日本ハム/
にほんば /日本馬/
にほんばし /日本橋/
にほんばしじょがっかん /日本橋女学館/
にほんばしほんてん /日本橋本店/
にほんばしまるぜん /日本橋丸善/
にほんばしみつこし /日本橋三越/
にほんばれ /日本晴れ/
にほんばん /日本版/日本盤/
にほんばんじまく /日本版字幕/
にほんばんだい /日本版第/
にほんひかりがっかい /日本光学会/
にほんひょうじゅんじ /日本標準時/
にほんひょうろんしゃ /日本評論社/
にほんびじゅついん /日本美術院/
にほんふう /日本風/
にほんふたん /日本負担/
にほんぶっきょう /日本仏教/
にほんぶっさん /日本物産;[企業名]/
にほんぶつりがっかい /日本物理学会/
にほんぶどう /日本武道/
にほんぶどうかん /日本武道館/
にほんぶもん /日本部門/
にほんぶよう /日本舞踊/
にほんぶん /日本文/
にほんぶんか /日本文化/
にほんぶんかしゃ /日本文華社/
にほんぶんかてき /日本文化的/
にほんぶんがく /日本文学/
にほんぶんげいしゃ /日本文芸社/
にほんぶんこう /日本分校/日本分光/
にほんへん /日本編/
にほんへんしゅうばん /日本編集盤/
にほんべんごしれんごうかい /日本弁護士連合会/
にほんほうじんせつりつ /日本法人設立/
にほんほうそうきょうかい /日本放送協会/
にほんほうもん /日本訪問/
にほんぼうえきしんこうかい /日本貿易振興会;JETRO (Japan External Trade Organisation)/
にほんま /日本間/
にほんまい /日本米/
にほんまち /日本町/
にほんまつ /二本松/
にほんまる /日本丸/
にほんみこうかい /日本未公開/
にほんみこうかいさく /日本未公開作/
にほんみはっぴょうきょく /日本未発表曲/
にほんみはつばい /日本未発売/
にほんみんよう /日本民謡/
にほんむかし /日本昔/
にほんむかしばなし /日本昔話/
にほんむけ /日本向/日本向け/
にほんむせん /日本無線/
にほんめ /二本目/
にほんめい /日本名/
にほんもの /日本物/
にほんもんとくてんのうじつろく /日本文徳天皇実録;850-858の歴史書。879年成立/
にほんやきゅう /日本野球/
にほんやく /日本訳/
にほんやちょう /日本野鳥/
にほんやっきょくほう /日本薬局方/
にほんゆうすう /日本有数/
にほんゆうせいこうしゃ /日本郵政公社;www.post.japanpost.jp/
にほんゆうせんたいしょう /日本有線大賞/
にほんゆしゅつにゅうぎんこう /日本輸出入銀行;Export-Import Bank of Japan(EIB) (現・国際協力銀行)/
にほんゆび /二本指/
にほんよう /日本用/
にほんりくぐん /日本陸軍/
にほんりゅう /日本流/
にほんりょう /日本領/
にほんりょういき /日本霊異記/
にほんりょうじかん /日本領事館/
にほんりょうり /日本料理/
にほんりょうりかい /日本料理界/
にほんりょうりや /日本料理屋/
にほんりょこう /日本旅行/
にほんれっとう /日本列島/
にほんろぼっとがっかい /日本ロボット学会/
にぼし /煮干し/煮干/
にまい /二枚/２枚/
にまいおろし /二枚下ろし;[料理]/
にまいかんばん /二枚看板/
にまいがい /二枚貝/
にまいがさね /二枚重ね/
にまいぐみ /二枚組/
にまいげり /二枚蹴り/
にまいごし /二枚腰/
にまいじた /二枚舌/
にまいど /二枚戸/
にまいば /二枚刃/
にまいめ /二枚目/
にまいめやく /二枚目役/
にまめ /煮豆/
にみや /二宮/
にみょう /二名/
にむら /二村/
にめい /二名/
にめん /二面/
にめんせい /二面性/
にもうさく /二毛作/
にもじ /二文字/2文字/
にもじめ /二文字目/
にもつ /荷物/
にもつうんぱんよう /荷物運搬用/
にもつおきば /荷物置場/
にもつけんさ /荷物検査/
にもつごと /荷物毎/
にもつしつ /荷物室/
にもつせいり /荷物整理/
にもつとびら /荷物扉/
にもつはんにゅう /荷物搬入/
にもつよう /荷物用/
にもの /煮物/
にもん /2問/
にゃく /若/蒻/
にゃくどう /若道/
にやく /荷役/二役/
にやっかい /荷厄介/
にゅー /ν;nu/Ν;Nu/
にゅーかっするびょう /ニューカッスル病;(鶏の)Newcastle disease/
にゅーじーらんど /新西蘭;New Zealand/
にゅーすそくほう /ニュース速報/
にゅーすばんぐみ /ニュース番組/
にゅーとんほう /ニュートン法/
にゅーとんりきがく /ニュートン力学;Newtonian mechanics. いわゆる力学/
にゅーよーく /紐育;New York/
にゅーよーくしじょう /ニューヨーク市場/
にゅう /入/乳/柔/廿/ν;nu/
にゅういき /入域/
にゅういん /入院/
にゅういんかんじゃ /入院患者/
にゅういんきかん /入院期間/
にゅういんさき /入院先/
にゅういんせいかつ /入院生活/
にゅういんちゅう /入院中/
にゅういんちりょう /入院治療/
にゅういんひ /入院費/
にゅういんりょう /乳飲料/
にゅううん /乳暈/
にゅうえい /入営/
にゅうえき /乳液/
にゅうえん /入園/
にゅうえんけん /入園券/
にゅうえんしき /入園式/
にゅうえんむりょう /入園無料/
にゅうえんりょう /入園料/
にゅうか /入荷/乳化/入科/
にゅうかい /入会/
にゅうかいあんない /入会案内/
にゅうかいかのう /入会可能/
にゅうかいかんゆう /入会勧誘/
にゅうかいきぼう /入会希望/
にゅうかいきぼうしゃ /入会希望者/
にゅうかいきん /入会金/
にゅうかいきんめんじょ /入会金免除/
にゅうかいご /入会後/
にゅうかいごきぼう /入会御希望/
にゅうかいしかく /入会資格/
にゅうかいしゃ /入会者/
にゅうかいじ /入会時/
にゅうかいじき /入会時期/
にゅうかいたいかい /入会退会/
にゅうかいてつづき /入会手続き/
にゅうかいとくてん /入会特典/
にゅうかいひ /入会費/
にゅうかいひむりょう /入会費無料/
にゅうかいほうほう /入会方法/
にゅうかいまえ /入会前/
にゅうかいもうしこみしょ /入会申込書/
にゅうかく /入閣/
にゅうかざい /乳化剤/
にゅうかすう /入荷数/
にゅうかだいすう /入荷台数/
にゅうかまち /入荷待ち/
にゅうかりょう /入荷量/
にゅうかわ /丹生川/
にゅうかん /入館/入管/入感/乳管/入棺/
にゅうかんきょく /入感局/
にゅうかんけん /入館券/
にゅうかんほう /入管法;[法][略語]入出国管理および難民認定法/
にゅうかんりょう /入館料/
にゅうがく /入学/
にゅうがくいわい /入学祝/入学祝い/
にゅうがくきぼうしゃ /入学希望者/
にゅうがくきん /入学金/
にゅうがくご /入学後/
にゅうがくしき /入学式/
にゅうがくしけん /入学試験/
にゅうがくしけんもんだい /入学試験問題/
にゅうがくしゃ /入学者/
にゅうがくしゃぼしゅう /入学者募集/
にゅうがくじ /入学時/
にゅうがくせい /入学生/
にゅうがくていいん /入学定員/
にゅうがくとうじ /入学当時/
にゅうがくねんがっぴ /入学年月日/
にゅうがくねんど /入学年度/
にゅうがくりょう /入学料/
にゅうがん /乳癌/乳がん/乳ガン/
にゅうきゅう /入厩/
にゅうきょ /入居/入渠/
にゅうきょう /入京/入鋏/
にゅうきょしかく /入居資格/
にゅうきょしゃ /入居者/
にゅうきょまえ /入居前/
にゅうきん /入金/
にゅうきんかくにんご /入金確認後/
にゅうきんがく /入金額/
にゅうきんでんぴょう /入金伝票/
にゅうきんひょう /入金票/
にゅうぎゅう /乳牛/
にゅうぎょ /入漁/入御/
にゅうぎょう /乳業/
にゅうぎょく /入玉/
にゅうぎょけん /入漁権/
にゅうぎょりょう /入漁料/
にゅうこ /入庫/入呼/
にゅうこう /入稿/入港/入校/乳香/入構/入坑/入貢/
にゅうこうりょう /入港料/
にゅうこく /入国/
にゅうこくかんりきょく /入国管理局/
にゅうこくかんりほう /入国管理法/
にゅうこくきょひ /入国拒否/
にゅうこくご /入国後/
にゅうこくさしょう /入国査証/
にゅうこくしんさ /入国審査/
にゅうこくしんさかん /入国審査官/
にゅうこくしんさりょう /入国審査料/
にゅうこくじ /入国時/
にゅうこくぜい /入国税/
にゅうこくちてん /入国地点/
にゅうこくび /入国日/
にゅうこくまえ /入国前/
にゅうこじ /入庫時/
にゅうこすう /入庫数/
にゅうこん /入魂/
にゅうこんしき /入魂式/
にゅうごく /入獄/
にゅうさつ /入札/
にゅうさつかかく /入札価格/
にゅうさつきんがく /入札金額/
にゅうさつしき /入札式/
にゅうさつしゃ /入札者/
にゅうさつほうしき /入札方式/
にゅうさん /乳酸/
にゅうさんいんりょう /乳酸飲料/
にゅうさんきん /乳酸菌/
にゅうさんきんいんりょう /乳酸菌飲料/
にゅうさんち /乳酸値/
にゅうさんはっこう /乳酸発酵/
にゅうざい /乳剤/
にゅうざいそう /乳剤層/
にゅうざいめん /乳剤面/
にゅうざん /入山/
にゅうし /入試/乳歯;baby tooth/乳脂;milk fat/入市/
にゅうしか /入試課/
にゅうしかもく /入試科目/
にゅうしせいど /入試制度/
にゅうしち /入質/
にゅうしつ /入室/
にゅうしぼう /乳脂肪/
にゅうしもんだい /入試問題/
にゅうしゃ /入社/入射/入舎/
にゅうしゃあんない /入社案内/
にゅうしゃいらい /入社以来/
にゅうしゃおん /入射音/
にゅうしゃかく /入射角/
にゅうしゃこう /入射光/
にゅうしゃご /入社後/
にゅうしゃしき /入社式/
にゅうしゃしけん /入社試験/
にゅうしゃじ /入社時/
にゅうしゃそく /入射束/
にゅうしゃねんど /入社年度/
にゅうしゃは /入射波/
にゅうしゃび /入社日/
にゅうしゃまえ /入社前/
にゅうしゃめん /入射面/
にゅうしゃりゅうし /入射粒子/
にゅうしゅ /入手/乳酒/入朱;アカを入れる/乳首;=ちくび/
にゅうしゅう /乳臭/
にゅうしゅか /入手可/
にゅうしゅかのう /入手可能/
にゅうしゅかのうせい /入手可能性/
にゅうしゅけいろ /入手経路/
にゅうしゅこんなん /入手困難/
にゅうしゅご /入手後/
にゅうしゅさき /入手先/
にゅうしゅしゅだん /入手手段/
にゅうしゅじゅん /入手順/
にゅうしゅずみ /入手済/
にゅうしゅちゅう /入手中/
にゅうしゅっこ /入出庫/
にゅうしゅっこくじ /入出国時/
にゅうしゅつ /入出/
にゅうしゅつこく /入出国/
にゅうしゅつこくじ /入出国時/
にゅうしゅつりょく /入出力/
にゅうしゅつりょくかんけい /入出力関係/
にゅうしゅつりょくけい /入出力系/
にゅうしゅつりょくそうち /入出力装置/
にゅうしゅつりょくたんし /入出力端子/
にゅうしゅつりょくち /入出力値/
にゅうしゅつりょくとくせい /入出力特性/
にゅうしゅつりょくぶぶん /入出力部分/
にゅうしゅつりょくよう /入出力用/
にゅうしゅなん /入手難/
にゅうしゅばしょ /入手場所/
にゅうしゅふかのう /入手不可能/
にゅうしゅふのう /入手不能/
にゅうしゅほう /入手法/
にゅうしゅほうほう /入手方法/
にゅうしゅもと /入手元/
にゅうしょ /入所/
にゅうしょう /入賞/入省/
にゅうしょうさくひん /入賞作品/
にゅうしょうしゃ /入賞者/
にゅうしょうじ /乳小児/
にゅうしょうりつ /入賞率/
にゅうしょきじゅん /入所基準/
にゅうしょく /入植/入職/
にゅうしょくしゃ /入植者/
にゅうしょくち /入植地/
にゅうしょくりつ /入職率/
にゅうしょしき /入所式/
にゅうしょしゃ /入所者/
にゅうしょせいかつ /入所生活/
にゅうしん /入信/入神/入心/
にゅうしんがく /入進学/
にゅうじ /乳児/入寺/
にゅうじき /乳児期/
にゅうじほいく /乳児保育/
にゅうじゃく /入寂;[仏教] 死ぬこと/柔弱/
にゅうじゅう /乳汁/
にゅうじゅく /入塾/
にゅうじょう /入場/入城/入定/乳状/
にゅうじょうきょく /入場曲/
にゅうじょうきんし /入場禁止/
にゅうじょうぐち /入場口/
にゅうじょうけん /入場券/
にゅうじょうご /入場後/
にゅうじょうしき /入場式/
にゅうじょうしゃ /入場者/
にゅうじょうしゃすう /入場者数/
にゅうじょうじ /入場時/
にゅうじょうじんいん /入場人員/
にゅうじょうせいげん /入場制限/
にゅうじょうせいりけん /入場整理券/
にゅうじょうぜい /入場税/
にゅうじょうまえ /入場前/
にゅうじょうむりょう /入場無料/
にゅうじょうりつ /入場率/
にゅうじょうりょう /入場料/
にゅうじょうりょうしゅうにゅう /入場料収入/
にゅうすい /入水/
にゅうせい /乳清;whey/入声/
にゅうせいひん /乳製品/
にゅうせき /入籍/
にゅうせきとどけ /入籍届/
にゅうせん /入選/乳腺/入線/入船/
にゅうせんえん /乳腺炎;[医]/
にゅうせんけん /入船券/
にゅうせんはっぴょう /入選発表/
にゅうぜん /入善/
にゅうそう /入槽/
にゅうそん /入村/
にゅうそんりょう /入村料/
にゅうたい /入隊/入退/入体/
にゅうたいいん /入退院/
にゅうたいかい /入退会/
にゅうたいしつ /入退室/
にゅうたいしゅつ /入退出/
にゅうたいじょう /入退場/
にゅうたいじょうじ /入退場時/
にゅうだく /乳濁/
にゅうだくえき /乳濁液/
にゅうだん /入団/
にゅうだんきぼう /入団希望/
にゅうだんきょひ /入団拒否/
にゅうだんご /入団後/
にゅうだんしき /入団式/
にゅうだんじ /入団時/
にゅうだんてすと /入団テスト/
にゅうちゃく /入着/
にゅうちょう /入庁/入超/入朝/
にゅうてい /入廷/
にゅうてん /入店/
にゅうでん /入電/
にゅうとう /乳頭/乳糖/入湯/入党/入刀/入唐/
にゅうとうおんせん /乳頭温泉/
にゅうとうきん /乳頭筋/
にゅうとうぜい /入湯税/
にゅうとうとっき /乳頭突起/
にゅうどう /入道/
にゅうどうぐも /入道雲/
にゅうどうざき /入道崎/
にゅうどうしんのう /入道親王;[日本史]/
にゅうない /入内/
にゅうねん /入念/
にゅうの /入野/
にゅうはくしょく /乳白色/
にゅうばい /入梅/
にゅうばち /乳鉢/
にゅうひ /入費/
にゅうび /乳糜/
にゅうふ /入夫/
にゅうふこんいん /入夫婚姻/
にゅうぶ /入部/
にゅうぶとどけ /入部届/
にゅうほうほう /入方法/
にゅうぼう /乳房/乳棒/
にゅうまく /入幕/
にゅうみん /入眠/
にゅうめつ /入滅/
にゅうめん /煮麺/入麺/
にゅうもん /入門/
にゅうもんかいせつ /入門解説/
にゅうもんかいていばん /入門改訂版/
にゅうもんき /入門機/入門期/
にゅうもんきょういく /入門教育/
にゅうもんこうざ /入門講座/
にゅうもんしゃ /入門者/
にゅうもんしゃよう /入門者用/
にゅうもんしょ /入門書/
にゅうもんてい /入門艇/
にゅうもんてき /入門的/
にゅうもんばん /入門版/
にゅうもんへん /入門編/
にゅうもんぼん /入門本/
にゅうもんよう /入門用/
にゅうよう /入用/乳用/
にゅうようぎゅう /乳用牛/
にゅうようしゅ /乳用種/
にゅうようじ /乳幼児/
にゅうようじとつぜんししょうこうぐん /乳幼児突然死症候群;SIDS (Sudden Infant Death Syndrome)/
にゅうよく /入浴/入欲;?/
にゅうよくきんし /入浴禁止/
にゅうよくけん /入浴券/
にゅうよくざい /入浴剤/
にゅうよくちゅう /入浴中/
にゅうよくりょう /入浴料/
にゅうよくりょうきん /入浴料金/
にゅうらい /入来/
にゅうらく /入洛/乳酪/
にゅうりょう /入寮/
にゅうりょうひ /入寮費/
にゅうりょうび /入寮日/
にゅうりょく /入力/
にゅうりょくいき /入力域/
にゅうりょくいち /入力位置/
にゅうりょくおん /入力音/
にゅうりょくおんあつ /入力音圧/
にゅうりょくかのう /入力可能/
にゅうりょくかんきょう /入力環境/
にゅうりょくかんじ /入力漢字/
にゅうりょくかんすう /入力関数/
にゅうりょくがわ /入力側/
にゅうりょくきのう /入力機能/
にゅうりょくきりかえ /入力切替/入力切換/
にゅうりょくきろく /入力記録/
にゅうりょくぎょう /入力行/
にゅうりょくくうかん /入力空間/
にゅうりょくけいしき /入力形式/
にゅうりょくこうりつ /入力効率/
にゅうりょくご /入力後/
にゅうりょくしき /入力式/
にゅうりょくしゃ /入力者/
にゅうりょくしゅうはすう /入力周波数/
にゅうりょくしょり /入力処理/
にゅうりょくしんごう /入力信号/
にゅうりょくじ /入力時/
にゅうりょくじょうたい /入力状態/
にゅうりょくじょうほう /入力情報/
にゅうりょくせん /入力線/
にゅうりょくせんたく /入力選択/
にゅうりょくそう /入力層/入力相/
にゅうりょくそうち /入力装置/
にゅうりょくそくど /入力速度/
にゅうりょくたんし /入力端子/
にゅうりょくたんまつ /入力端末/
にゅうりょくだん /入力段/
にゅうりょくち /入力値/
にゅうりょくちゅう /入力中/
にゅうりょくてき /入力的/
にゅうりょくでーた /入力データ/
にゅうりょくでんあつ /入力電圧/
にゅうりょくでんりゅう /入力電流/
にゅうりょくとちゅう /入力途中/
にゅうりょくはいれつ /入力配列/
にゅうりょくはけい /入力波形/
にゅうりょくぱらめーた /入力パラメータ/
にゅうりょくふぁいる /入力ファイル/
にゅうりょくふかのう /入力不可能/
にゅうりょくぶ /入力部/
にゅうりょくぶん /入力文/
にゅうりょくへんかん /入力変換/
にゅうりょくほう /入力法/
にゅうりょくほうしき /入力方式/
にゅうりょくほうほう /入力方法/
にゅうりょくみす /入力ミス/
にゅうりょくめん /入力面/
にゅうりょくもーど /入力モード/
にゅうりょくもじ /入力文字/
にゅうりょくもじすう /入力文字数/
にゅうりょくよう /入力用/
にゅうりょくようそ /入力要素/
にゅうりょくようりょう /入力容量/
にゅうりょくりきりつ /入力力率/
にゅうりょくりょういき /入力領域/
にゅうりょくれい /入力例/
にゅうりょくれつ /入力列/
にゅうりょくわく /入力枠/
にゅうりん /乳輪/
にゅうろう /入牢/
にゅうわ /柔和/
にょ /女/如/汝;(呉音)/
にょい /如意/女医;[律令制]/
にょいち /如一/
にょいほうじゅ /如意宝珠/
にょいぼう /如意棒/
にょいん /女院/
にょう /尿/繞;部首のニョウ。「之繞」「廴繞」/女;(慣用音)女房/獰;(呉音) 獰猛(どうもう)/
にょうい /尿意/
にょういん /女院/
にょうかん /尿管/
にょうき /尿器/
にょうけっせき /尿結石/
にょうけんさ /尿検査/
にょうご /女御/
にょうさいかん /尿細管/
にょうさん /尿酸/
にょうしっきん /尿失禁/
にょうじゅ /女嬬/女孺/
にょうせき /尿石/
にょうそ /尿素/
にょうどう /尿道/
にょうどうえん /尿道炎/
にょうどうけっせき /尿道結石/
にょうどうこう /尿道口/
にょうどくしょう /尿毒症/
にょうはち /鐃鉢;仏具/
にょうへい /尿閉/
にょうほうしょう /尿崩症;[医]/
にょうぼ /女房/
にょうぼう /女房/
にょうぼうことば /女房詞;杓子→杓文字など/
にょうぼうほうしょ /女房奉書/
にょうぼうやく /女房役/
にょうぼこども /女房子供/
にょうまく /尿膜/
にょうもれ /尿漏れ/
にょうろ /尿路/
にょうろけっせき /尿路結石/
にょおう /女王/
にょかん /女官/
にょご /女御/
にょし /女子/
にょしき /女色/
にょしょう /女性/女将/
にょしょく /女色/
にょじつ /如実/
にょじつちけん /如実知見/
にょじゅ /女嬬/女孺/
にょぜ /如是/
にょぜがもん /如是我聞/
にょたい /女体/
にょたいもり /女体盛り;[卑]/
にょにん /女人/
にょにんきんせい /女人禁制/
にょにんきんぜい /女人禁制/
にょほう /如法/
にょほうあんや /如法暗夜/
にょぼさつ /如菩薩/
にょぼん /女犯/
にょやしゃ /如夜叉/
にょらい /如来/
にょらいぞう /如来蔵/
にょろ /〜/
によう /二葉/二様/
によど /仁淀/
にら /韮/薤;(らっきょう)/韭;「韮」の異体字/
にらさき /韮崎/
にらさわ /韮沢/
にらたま /ニラ玉/
にらづか /韮塚/
にらみ /睨み/
にらみあい /睨み合い/
にらめっこ /睨めっこ/
にらやま /韮山/
にらやまがさ /韮山笠/
にらやまずきん /韮山頭巾/
にらやまちょう /韮山町/
にらればいため /ニラレバ炒め/
にらんせい /二卵性/
にらんせいそうせいじ /二卵性双生児/
にり /二理/
にりつ /二律/
にりつはいはん /二律背反/
にりゅう /二流/
にりゅうか /二硫化/
にりん /二輪/２輪/
にりんか /二輪花/
にりんくどう /二輪駆動/
にりんしゃ /二輪車/
にりんじどうしゃ /二輪自動車/
にりんつうこうきんし /二輪通行禁止/
にりんめんきょ /二輪免許/
にりんよう /二輪用/
にるい /二塁/二類/
にるいけい /二類型/
にるいしゅ /二塁手/
にるいそうきゅう /二塁送球/
にるいそうしゃ /二塁走者/
にるいだ /二塁打/
にるいるいしん /二塁塁審/
にれ /楡/
にれい /楡井/
にれつ /二列/
にれつめ /二列目/
にれんぱつ /二連発/
にろう /二浪/
にろくじちゅう /二六時中/
にわ /庭/丹羽/二羽/二話/
にわいし /庭石/
にわいじり /庭いじり/庭弄り;gardening/
にわか /俄/俄か/仁輪加/
にわかあめ /俄雨/にわか雨/瀑/
にわかじこみ /俄仕込み/
にわかじたて /俄仕立て/
にわかゆき /俄雪/
にわき /庭木/
にわきょういく /庭教育/
にわさか /庭坂/
にわさき /庭先/
にわし /庭師/
にわしごと /庭仕事;yard work/
にわせ /庭瀬/
にわた /庭田/
にわたし /荷渡/
にわたずみ /潦/
にわづくり /庭作り/
にわとり /鶏/鷄;「鶏」の旧字(人名用漢字)/
にわとりごや /鶏小屋/
にわの /庭野/
にわばん /庭番/
にわも /庭面/
にわり /二割/
にん /任/人/認/忍/妊/刃/仁/儿;にんにょう/刄;「刃」の異体字/姙;「妊」の異体字/
にんあい /人愛/
にんあん /仁安;年号(1166-1169)/
にんい /任意/∀/
にんいいんたい /任意引退/
にんいいんたいせんしゅ /任意引退選手/
にんいかい /任意回/
にんいかくど /任意角度/
にんいかんすう /任意関数/
にんいきてい /任意規定/
にんいこ /任意個/
にんいこすう /任意個数/
にんいしゅっとう /任意出頭/
にんいじゅんびきん /任意準備金/
にんいせい /任意性/
にんいせいさん /任意清算/
にんいせいり /任意整理/
にんいそうさ /任意捜査/
にんいだいり /任意代理/
にんいだんたい /任意団体/
にんいちょう /任意長/
にんいつみたてきん /任意積立金;利益剰余金の内、企業が独自に積立てた部分/
にんいどうこう /任意同行/
にんいほう /任意法/
にんいほうき /任意法規/
にんいほけん /任意保険/
にんか /認可/
にんかせい /認可制/
にんかほうじん /認可法人/
にんかん /任官/
にんがい /人外;ひとでなし/人界;[仏教]人間界/
にんき /人気/任期/
にんきうま /人気馬/
にんきかん /人気館/
にんききしゅ /人気機種/
にんききゅうじょうしょう /人気急上昇/
にんききゅうだん /人気球団/
にんきぎれ /任期切れ/
にんきさくひん /人気作品/
にんきさっか /人気作家/
にんきしゃ /人気車/
にんきしゃしゅ /人気車種/
にんきしょうひん /人気商品/
にんきじゅん /人気順/
にんきじょうい /人気上位/
にんきじょうしょう /人気上昇/
にんきせんこう /人気先行/
にんきせんしゅ /人気選手/
にんきぜっちょう /人気絶頂/
にんきちゅう /任期中/
にんきていか /人気低下/
にんきてん /人気店/
にんきとうひょう /人気投票/
にんきとり /人気取り/
にんきばくはつ /人気爆発/
にんきばん /人気盤/
にんきばんぐみ /人気番組/
にんきまんりょう /任期満了/
にんきもの /人気者/
にんきょ /認許/
にんきょう /任侠/仁侠/
にんぎょ /人魚/
にんぎょう /人形/
にんぎょうあい /人形愛/
にんぎょうあそび /人形遊び/
にんぎょうか /人形化/
にんぎょうかいぞう /人形改造/
にんぎょうかん /人形館/
にんぎょうげき /人形劇/
にんぎょうげきだん /人形劇団/
にんぎょうさっか /人形作家/
にんぎょうし /人形師/
にんぎょうじょうるり /人形浄瑠璃/
にんぎょうちょう /人形町/
にんぎょうちょうえき /人形町駅/
にんぎょうつかい /人形遣い/
にんぎょうてき /人形的/
にんぎょうとうげ /人形峠;ウラン鉱/
にんぎょうはくぶつかん /人形博物館/
にんぎょうまわし /人形回し/
にんぎょうよう /人形用/
にんぎょでん /人魚伝/
にんぎょひめ /人魚姫/
にんく /人工/忍苦/
にんぐみ /人組/
にんけんてんのう /仁賢天皇/
にんげつ /人月/
にんげん /人間/
にんげんあい /人間愛/
にんげんあいて /人間相手/
にんげんいがい /人間以外/
にんげんかい /人間界/
にんげんかいはつほうこくしょ /人間開発報告書/
にんげんかがく /人間科学;human science/
にんげんかん /人間観/
にんげんかんきょう /人間環境/
にんげんかんけい /人間関係/
にんげんがく /人間学/
にんげんがくるい /人間学類/
にんげんがた /人間型/
にんげんがわ /人間側/
にんげんきげき /人間喜劇;[文学]la Comedie humaine (Balzac)/
にんげんぎらい /人間嫌い/
にんげんけいたい /人間形態/
にんげんげきじょう /人間劇場/
にんげんげんり /人間原理/
にんげんこうがく /人間工学/
にんげんこうがくかい /人間工学会/
にんげんこうがくてき /人間工学的/
にんげんこくほう /人間国宝/
にんげんさま /人間様/
にんげんしこう /人間志向/
にんげんしっかく /人間失格/
にんげんしゃかい /人間社会/
にんげんじしん /人間自身/
にんげんじたい /人間自体/
にんげんじょうほう /人間情報/
にんげんせい /人間性/
にんげんそうさ /人間操作/
にんげんそんざい /人間存在/
にんげんぞう /人間像/
にんげんたち /人間達/
にんげんだいがく /人間大学/
にんげんてき /人間的/
にんげんてきみりょく /人間的魅力/
にんげんてきよういん /人間的要因/
にんげんとくゆう /人間特有/
にんげんどう /人間道/
にんげんどうし /人間同士/
にんげんどっく /人間ドック/
にんげんどらま /人間ドラマ/
にんげんなみ /人間並/
にんげんばくだん /人間爆弾/
にんげんばなれ /人間離れ/
にんげんばんじさいおう /人間万事塞翁/
にんげんひとり /人間一人/
にんげんひとりひとり /人間一人一人/
にんげんふうしゃ /人間風車/
にんげんふしん /人間不信/
にんげんみ /人間味/
にんげんもよう /人間模様/
にんげんよう /人間用/
にんげんりかい /人間理解/
にんげんわざ /人間業/人間技/
にんこうてんのう /仁孝天皇/
にんさんばけしち /人三化七/
にんさんぷ /妊産婦/
にんしき /認識/
にんしきかがく /認識科学/
にんしきかてい /認識過程/
にんしきがく /認識学/
にんしききこう /認識機構/
にんしきけい /認識系/
にんしきけっか /認識結果/
にんしきこうぞう /認識構造/
にんしきしゅたい /認識主体/
にんしきしょく /認識色/
にんしきしょり /認識処理/
にんしきじかん /認識時間/
にんしきじしょ /認識辞書/
にんしきじっけん /認識実験/
にんしきせいど /認識精度/
にんしきせいのう /認識性能/
にんしきそうち /認識装置/
にんしきたいしょう /認識対象/
にんしきど /認識度/
にんしきのうりょく /認識能力/
にんしきはんい /認識範囲/
にんしきひょう /認識票/
にんしきぶ /認識部/
にんしきぶそく /認識不足/
にんしきほうほう /認識方法/
にんしきよう /認識用/
にんしきりつ /認識率/
にんしきりょく /認識力/
にんしきりろん /認識理論/
にんしきろん /認識論/
にんしゅう /人衆/
にんしょう /認証/人称/人証/認照/
にんしょうかん /認証官/
にんしょうきこう /認証機構/
にんしょうきょく /認証局/
にんしょうしき /認証式/
にんしょうだいめいし /人称代名詞/
にんしょうちゅう /認証中/
にんしょうほいくしょ /認証保育所/
にんしょうほうしき /認証方式/
にんしん /妊娠/
にんしんおそ /妊娠悪阻;[医]hyperemesis/
にんしんけんさやく /妊娠検査薬;[医]pregnancy test/
にんしんしゅっさん /妊娠出産/
にんしんしょき /妊娠初期/
にんしんじ /妊娠時/
にんしんせん /妊娠線/
にんしんちゅう /妊娠中/
にんしんちゅうぜつ /妊娠中絶/
にんしんちゅうどくしょう /妊娠中毒症;[医]gestosis/
にんしんてきれいき /妊娠適齢期/
にんじ /仁治;年号(1240-1243)/
にんじゃ /忍者/
にんじゃでら /忍者寺/
にんじゃぶげいちょう /忍者武芸帳/
にんじゃぶたい /忍者部隊/
にんじゃもの /忍者物/
にんじゃやく /忍者役/
にんじゃやしき /忍者屋敷/
にんじゅ /仁寿;年号(851-854)/
にんじゅう /忍従/
にんじゅつ /忍術/
にんじょう /人情/刃傷/人定/
にんじょうきげき /人情喜劇/
にんじょうざた /刃傷沙汰/
にんじょうてき /人情的/
にんじょうばなし /人情話/人情噺/
にんじょうぼん /人情本/
にんじょうみ /人情味/
にんじん /人参/人身/人蔘/忍人/
にんずう /人数/
にんずうこうせい /人数構成/
にんずうせいげん /人数制限/
にんずうてき /人数的/
にんずうはあく /人数把握/
にんずうひ /人数比/
にんずうぶん /人数分/
にんせん /人選/
にんそう /人相/
にんそうがき /人相書き/人相書/
にんそうがく /人相学/
にんそうみ /人相見/
にんそく /人足/
にんそくよせば /人足寄場/
にんたい /忍耐/
にんたいりょく /忍耐力/
にんだく /認諾/
にんだくちょうしょ /認諾調書/
にんち /認知/任地/
にんちいみろん /認知意味論/
にんちかがく /認知科学/
にんちかがくかい /認知科学会/
にんちかがくしゃ /認知科学者/
にんちかがくせんしょ /認知科学選書/
にんちかがくてき /認知科学的/
にんちかがっかい /認知科学会/
にんちかてい /認知過程/
にんちきこう /認知機構/
にんちきのう /認知機能/
にんちげんごがく /認知言語学/
にんちしょう /認知症/
にんちしょり /認知処理/
にんちしんり /認知心理/
にんちしんりがく /認知心理学/
にんちしんりがくしゃ /認知心理学者/
にんちしんりがくてき /認知心理学的/
にんちじっけん /認知実験/
にんちてき /認知的/
にんちとどけ /認知届/
にんちど /認知度/
にんちのうりょく /認知能力/
にんちばいたい /認知媒体/
にんちもでる /認知モデル/
にんちゅう /人中/
にんちゅうはく /人中白/
にんちりょうほう /認知療法;[精医]cognitive therapy/
にんちりろん /認知理論/
にんてい /認定/人体/
にんていい /認定医/
にんていか /認定課/
にんていきき /認定機器/
にんていきじゅん /認定基準/
にんていこう /認定校/
にんていこうじょう /認定工場/
にんていしぼう /認定死亡/
にんていしゃ /認定者/
にんていしょう /認定証/
にんていせいど /認定制度/
にんていばんごう /認定番号/
にんていひん /認定品/
にんていほうほう /認定方法/
にんていようけん /認定要件/
にんてん /人天/
にんてんどう /任天堂/
にんてんどうせい /任天堂製/
にんでん /人天/
にんとうぜい /人頭税/
にんとく /仁徳/
にんとくてんのう /仁徳天皇/
にんどう /忍冬/忍道/人道/
にんどうからくさもん /忍冬唐草文/
にんどうしゅ /忍冬酒/
にんどうもん /忍冬文/
にんな /仁和;年号(885-889)/
にんなじ /仁和寺/
にんにく /大蒜;garlic/忍辱;[仏教]/蒜;ひる(強い臭いのある野菜一般)/葫;=大蒜/
にんにち /人日/
にんにょう /人繞/
にんねん /人年/
にんのう /人皇/
にんぴ /認否/
にんぴにん /人非人/
にんぴょう /任憑/
にんぴん /人品/
にんぶん /人分/
にんぷ /妊婦/人夫/
にんべつ /人別/
にんべつちょう /人別帳/
にんべん /人偏/
にんぼう /人法;[仏教]/
にんぽう /忍法/
にんぽうちょう /忍法帳/忍法帖/
にんまえ /人前/
にんみょうてんのう /仁明天皇/
にんむ /任務/
にんむしっぱい /任務失敗/
にんめ /人目/
にんめい /任命/任名/
にんめいけん /任命権/
にんめん /任免/
にんよう /任用/認容/
にんようご /任用後/
ぬ /怒/奴/濡;?/
ぬーどしゃしん /ヌード写真/
ぬいいと /縫糸/縫い糸/
ぬいぐるみ /縫い包み/
ぬいしろ /縫い代/縫代/
ぬいだ /縫田;姓/
ぬいとり /縫い取り/縫取り/
ぬいはく /縫箔/
ぬいばり /縫い針/縫針/
ぬいめ /縫い目/縫目/
ぬいもの /縫い物/縫物/
ぬいもん /縫紋/
ぬえ /鵺/
ぬか /糠/額/
ぬかあめ /糠雨/
ぬかか /糠蚊/
ぬかご /糠子/零余子/
ぬかずき /酸漿/
ぬかた /額田/
ぬかたのおおきみ /額田王/
ぬかづけ /糠漬/
ぬかどこ /糠床/
ぬかばえ /糠蠅/
ぬかばたらき /糠働き/
ぬかびら /糠平/
ぬかびらこ /糠平湖/
ぬかぶくろ /糠袋/
ぬかみそ /糠味噌/
ぬかみそづけ /糠味噌漬/
ぬかよろこび /糠喜び/ぬか喜び/
ぬかり /抜かり/泥濘/
ぬかるみ /泥濘/
ぬき /貫/抜き/緯/
ぬきあしさしあし /抜き足差し足/
ぬきい /貫井/
ぬきいた /貫板/
ぬきいと /緯糸/
ぬきうち /抜き打ち/抜打ち/
ぬきうつし /抜写し/
ぬきがき /抜き書き/抜書き/抜書/
ぬきさし /抜き差し/
ぬきずり /抜刷/
ぬきだし /抜き出し/
ぬきて /貫手;(空手技)/抜手;(泳ぎ方)/
ぬきとりけんさ /抜取り検査/抜き取り検査/
ぬきに /抜荷/抜き荷/
ぬきほん /抜本/
ぬきみ /抜き身/抜身/
ぬきやま /抜山/
ぬきよみ /抜き読み/抜読み/
ぬぎき /脱ぎ着/脱着/
ぬぎすて /脱ぎ捨て/
ぬく /温/
ぬくい /貫井/
ぬくしな /温品/
ぬくぬく /温々;-と/
ぬくみ /温み/
ぬくもり /温もり;warmth/
ぬけ /抜け/脱/抜/
ぬけあな /抜け穴/抜穴/
ぬけがけ /抜け駆け/抜駆/
ぬけがら /抜け殻/蛻/脱け殻/抜殻/脱殻/
ぬけぐち /抜け口/
ぬけげ /抜け毛/脱け毛;<rare>/
ぬけさく /抜け作/
ぬけに /抜け荷/抜荷/
ぬけにん /抜け忍/抜忍/
ぬけみち /抜け道/抜道/
ぬけめ /抜け目/抜目/
ぬさ /幣/帛/
ぬし /主/塗師;漆細工職人/
ぬしや /塗師屋/
ぬすっと /盗人/
ぬすびと /盗人/
ぬすびとじょうご /盗人上戸/
ぬすみ /盗み/窃/
ぬすみぎき /盗み聞き/
ぬすみぐい /盗み食い/
ぬすみどり /盗み撮り/
ぬすみみ /盗み見/
ぬすみよみ /盗み読み/
ぬすむ /窃/
ぬた /垈/饅;[料理]酢味噌和え/
ぬなわ /沼縄/
ぬの /布/
ぬのいち /布市/
ぬのいちまち /布市町/
ぬのかわ /布川/
ぬのきそ /布基礎;[建築]構造壁沿いに設ける基礎/
ぬのきれ /布切れ/
ぬのぎれ /布切れ/
ぬのぐつ /布靴/
ぬのじ /布地/
ぬのせい /布製/
ぬのてーぷ /布テープ/
ぬのはし /布橋/
ぬのはらえき /布原駅/
ぬのびき /布引/
ぬのぶくろ /布袋/
ぬのぼり /布掘り;[建築]壁に合わせて穴を掘る。cf.布基礎/
ぬのまき /布巻/
ぬのむら /布村/
ぬのめ /布目/
ぬのめがわら /布目瓦;布目のある、古代の瓦。/
ぬのや /布屋/
ぬひ /奴婢/
ぬぼく /奴僕/
ぬま /沼/
ぬまうえ /沼上/
ぬまお /沼尾/
ぬまおか /沼岡/
ぬまかぜ /沼風/
ぬまかみ /沼上/
ぬまかわ /沼川/
ぬまがみ /沼上/
ぬまくない /沼宮内/
ぬまくま /沼隈/
ぬまくら /沼倉/
ぬまぐち /沼口/
ぬまざき /沼崎/
ぬまじり /沼尻;姓/
ぬまず /沼津/
ぬまずこう /沼津港/
ぬまずこうじょう /沼津工場/
ぬまずし /沼津市/
ぬまずひがし /沼津東/
ぬまた /沼田/
ぬまたちょう /沼田町/
ぬまち /沼地/
ぬまづ /沼津/
ぬまづこう /沼津港/
ぬまづし /沼津市/
ぬまべ /沼部/
ぬまべえき /沼部駅/
ぬまやま /沼山/
ぬめ /絖/
ぬめぬめ /滑々;NB:「すべすべ」と同形/滑滑/
ぬめり /滑り;slime NB:「すべり」と同形/
ぬもじ /盗文字/
ぬり /塗/塗り/
ぬりえ /塗り絵/
ぬりかえ /塗り替え/塗替/塗替え/
ぬりかべ /塗り壁/塗壁/
ぬりぐすり /塗り薬/塗薬/
ぬりし /塗師/塗り師/
ぬりつけ /塗付/
ぬりばし /塗り箸/塗箸/
ぬりもの /塗物/
ぬるま /微温/
ぬるまゆ /微温湯/ぬるま湯/
ぬるみ /温み/
ぬるゆ /微温湯/
ぬれ /濡れ/
ぬれいろ /濡れ色/
ぬれえん /濡れ縁;雨戸の外の縁側/濡縁/
ぬれがみ /濡れ髪;-を猫が舐めるので閉口/
ぬれぎぬ /濡れ衣/濡衣/
ぬれごと /濡れ事/濡事/
ぬれぞうきん /濡れ雑巾/
ぬれたおる /濡れタオル/
ぬれて /濡れ手;-で粟/
ぬれぬれ /濡れ濡れ/
ぬれねずみ /濡れ鼠/
ぬれば /濡れ場/濡場/
ぬればいろ /濡れ羽色/濡羽色/
ぬれぶきん /濡れ布巾/
ね /値/根/寝/音/嶺/子;[十二支](1)ねずみ/禰;禰宜 (人名用漢字)/祢;「禰」の異体字1 (人名用漢字)/袮;「禰」の異体字2 (人名不可)/涅;涅槃/寢;「寝」の旧字(人名用漢字)/
ね> /寝;(ナ行下一・下二 未然・連用形)寝過ごす,寝違え,寝驚く/
ねーちゃん /ネーちゃん/
ねあか /根明/
ねあがり /値上がり/根上/根上り/
ねあがりまつ /根上り松/
ねあげ /値上げ/値上/
ねあせ /寝汗/盗汗;=寝汗/
ねあらい /値洗い/
ねい /寧;丁寧/嚀;≒寧/檸;檸檬(ねいもう,レモン)/濘;泥濘/聹/佞;佞臣/侫;「佞」の異体字/禰;禰宜(ねぎ) (人名用漢字)/祢;「禰」の異体字/
ねいか /寧夏/
ねいかん /佞奸/
ねいき /寝息/
ねいし /根石/
ねいしん /佞臣/
ねいじつ /寧日/
ねいじん /佞人/
ねいす /寝椅子/
ねいは /寧波/
ねいひつ /寧謐/
ねいも /根芋/
ねいり /寝入り/
ねいりばな /寝入り端/
ねいれ /値入れ;markup,margin/
ねいろ /音色/
ねうお /根魚/
ねうごき /値動き/
ねうち /値打ち/値打/
ねえ /姉/
ねえさま /姉様/
ねえさん /姉さん/姐さん/
ねえちゃん /姉ちゃん/
ねえや /姉や/
ねえよ /寧代;江川達也『まじかる☆タルるートくん』の登場人物/
ねお /根尾/根緒/
ねおき /寝起き/寝起/
ねおしろい /寝白粉/
ねおじうむ /Nd/
ねおじむ /Nd/Neodymium/
ねおん /Ne/Neon/
ねおんかん /ネオン管;neon tube/
ねおんがい /ネオン街/
ねかた /寝方/根方/
ねかぶ /根株/
ねが /願/
ねがい /願/願い/
ねがいごと /願い事/
ねがいさげ /願い下げ/
ねがいで /願い出/
ねがいぶみ /願い文/
ねがえり /寝返り/
ねがお /寝顔/
ねがさ /値嵩/値がさ/
ねがさかぶ /値嵩株/
ねがため /根固め/
ねがったりかなったり /願ったり叶ったり/
ねがみ /根上/
ねがわくは /願わくは/
ねがわくば /願わくば/
ねきり /根切り;[園芸]根っこを切ること/
ねきりむし /根切虫/
ねぎ /葱/禰宜;神社の-/
ねぎあか /ネギ亜科/
ねぎか /葱科/
ねぎし /根岸/
ねぎしけいばじょう /根岸競馬場/
ねぎししんりんこうえん /根岸森林公園/
ねぎしせん /根岸線/
ねぎしちょう /根岸町/
ねぎとろどん /ねぎとろ丼/
ねぎぼうず /葱坊主/
ねぎま /葱鮪;-鍋/
ねぎやき /ネギ焼/ネギ焼き/ねぎ焼/ねぎ焼き/
ねぎり /値切/値切り/根切り;[建築]基礎などの形に沿って穴を掘ること/
ねぎわ /根際/寝際/
ねくずれ /値崩れ/
ねくび /寝首/
ねくら /根暗/
ねぐされ /根腐れ;[園芸]root rot/
ねぐせ /寝癖/
ねぐら /塒/
ねこ /猫/
ねこあし /猫足/猫脚/
ねこいた /猫板/
ねこいらず /猫いらず/
ねこか /猫科/
ねこかぶり /猫被り/猫かぶり/
ねこかわいがり /猫可愛がり/猫かわいがり/
ねこかん /猫缶/
ねこかんけい /猫関係/
ねこがた /猫型/
ねこぐるま /猫車/
ねこざめ /猫鮫/
ねこじた /猫舌/
ねこじまん /猫自慢/
ねこぜ /猫背/
ねこそぎ /根刮ぎ/根こそぎ/
ねこた /猫田/
ねこだまし /猫騙し;[相撲]/
ねこっけ /猫っ毛/
ねこて /猫手/
ねこなでごえ /猫撫で声/猫なで声/
ねこのこ /猫の子/
ねこのて /猫の手/
ねこのひたい /猫の額/
ねこのめ /猫の目/
ねこは /猫派/
ねこばば /猫糞/
ねこびたい /猫額/
ねこべ /猫部/
ねこま /猫魔;地名,「裏磐梯-」/猫間/
ねこまた /猫又/
ねこまたぎ /猫跨ぎ/
ねこみ /寝込み/
ねこみみ /猫耳/
ねこむすめ /猫娘/
ねこめ /猫目/
ねこめいし /猫目石/
ねこやなぎ /猫柳/
ねこよう /猫用/
ねごこち /寝心地/
ねごと /寝言/
ねごや /根小屋/
ねごろ /値頃/根来;地名/
ねごろかん /値頃感/
ねごろばん /根来版/
ねさがり /値下がり/
ねさげ /値下げ/値下/
ねざかな /根魚/
ねざき /根崎/
ねざけ /寝酒/
ねざさ /根笹/
ねざし /根差し/根挿し;[園芸]/
ねざま /寝様/
ねざめ /寝覚め/寝醒め/
ねざや /値鞘/
ねしち /根質;「ねじち」とも。根担保の一種(質権)/
ねしな /寝しな/
ねしゃか /寝釈迦/
ねしょうが /根生姜/
ねしょうがつ /寝正月/
ねしょうべん /寝小便/
ねしょんべん /寝小便/
ねじ /螺子/捻子/捩子/螺/捻/
ねじあな /ネジ穴/螺子穴/
ねじきり /ネジ切り/螺子切り/ねじ切り/
ねじくぎ /ネジ釘/螺子釘/ねじ釘/
ねじけ /拗け/
ねじこみ /捩じ込み/
ねじしき /ねじ式;つげ義春/
ねじたく /寝支度/
ねじどめ /ネジ止め/
ねじまわし /螺子回し;screwdriver/ネジ回し/ねじ回し/
ねじめ /根占/根締め/音締め;三味線の調律/
ねじやま /ネジ山/螺子山/ねじ山/
ねじりはちまき /捩り鉢巻き/
ねじろ /根城/根白/
ねすがた /寝姿/
ねすこ /ネス湖/
ねず /鼠/杜松;[植物]juniper/根津;※ねづ/禰津;※ねづ/
ねずみ /鼠/鼡;「鼠」の異体字/子;[十二支]1/
ねずみいろ /鼠色/
ねずみおとこ /鼠男/ネズミ男/
ねずみがえし /鼠返し/
ねずみこう /鼠講/ねずみ講/ネズミ講/
ねずみこぞう /鼠小僧/
ねずみざん /鼠算/
ねずみざんしき /鼠算式/ねずみ算式/ネズミ算式/
ねずみしの /鼠志野/
ねずみたち /鼠達/
ねずみとり /鼠捕り/ネズミ捕り/ネズミ取り/
ねずみどし /子年/
ねずみはなび /鼠花火;地面をシュルシュルと回り、パンとはぜて終わる小さな花火。「-のような人生」/ネズミ花火/
ねぞう /寝相/
ねた /妬/
ねたきり /寝た切り/
ねたきりろうじん /寝たきり老人/寝た切り老人/
ねたぎれ /ネタ切れ/
ねただし /ネタ出し/
ねたばこ /寝たばこ/寝タバコ/寝煙草/
ねたふり /ネタ振り/
ねたみ /妬み/嫉み/
ねたみそねみ /妬み嫉み/
ねたんぽ /根担保/
ねだ /根太/
ねだい /寝台/
ねだめ /寝溜め/
ねだやし /根絶やし/
ねだん /値段/
ねだんいがい /値段以外/
ねだんいじょう /値段以上/
ねだんこうしょう /値段交渉/
ねだんさ /値段差/
ねだんそうおう /値段相応/
ねだんそうとう /値段相当/
ねだんてき /値段的/
ねだんとう /値段等/
ねだんひょう /値段表/
ねだんふめい /値段不明/
ねだんぶん /値段分/
ねだんへんどう /値段変動/
ねちがえ /寝違え/
ねっか /熱河/熱火/
ねっから /根っから/
ねっかんあつえん /熱間圧延/
ねっき /熱気/
ねっききゅう /熱気球/
ねっきゅう /熱球/
ねっきょう /熱狂/
ねっきょうてき /熱狂的/
ねっきよく /熱気浴/
ねっけい /熱型;体温の変化の型/
ねっけつ /熱血/
ねっけつかん /熱血漢/
ねっけつしゅじんこう /熱血主人公/
ねっけん /熱圏/
ねっこ /根っこ/根っ子/
ねっさ /熱砂/
ねっさん /熱讃/
ねっしせん /熱視線/
ねっしゃ /熱写/熱砂;=ねっさ/
ねっしゃびょう /熱射病/
ねっしゅ /熱酒/
ねっしょ /熱暑/
ねっしょう /熱唱/熱傷;やけど/
ねっしん /熱心/
ねっすい /熱水/
ねっせい /熱性/熱誠/
ねっせん /熱戦;exciting game/熱線;heat ray|wire/熱泉;hot springs/
ねったい /熱帯/
ねったいうりん /熱帯雨林/
ねったいぎょ /熱帯魚/
ねったいぎょかんけい /熱帯魚関係/
ねったいぎょしいく /熱帯魚飼育/
ねったいぎょや /熱帯魚屋/
ねったいぎょよう /熱帯魚用/
ねったいさん /熱帯産/
ねったいしょくぶつ /熱帯植物/
ねったいせい /熱帯性/
ねったいちいき /熱帯地域/
ねったいちほう /熱帯地方/
ねったいていきあつ /熱帯低気圧/
ねったいびょう /熱帯病;tropical disease/
ねったいや /熱帯夜;NB:最低気温が25℃以上/
ねったいりん /熱帯林/
ねっちゅう /熱中/
ねっちゅうしょう /熱中症/
ねってい /熱低/
ねっとう /熱湯/熱闘;fierce fight/熱鬧;「闘」旧字/
ねっとうら /ネット裏/
ねっとかでん /ネット家電/
ねっときょく /ネット局/
ねっとじょう /ネット上/
ねっとせつぞく /ネット接続/
ねっとはんばい /ネット販売/
ねっとわーくか /ネットワーク化/
ねっぱ /熱波/
ねっぱつ /熱発/
ねっぷう /熱風/
ねっぷうろ /熱風炉/
ねつ /熱/捏;捏造/
ねつ> /熱;熱工学,熱流体,熱対策/
ねつあい /熱愛/
ねつあいちゅう /熱愛中/
ねつい /熱意/
ねつうんどう /熱運動/
ねつえねるぎー /熱エネルギー;[物理]thermal energy/
ねつえん /熱演/
ねつえんじゅんかん /熱塩循環/
ねつおうりょく /熱応力;[物理][建築]熱によって内部に生ずる応力/
ねつか /熱価/
ねつかがくほうていしき /熱化学方程式/
ねつかく /熱核/
ねつかくはんのう /熱核反応/
ねつかくゆうごう /熱核融合/
ねつかん /熱感/
ねつかんわ /熱緩和/
ねつがん /熱願/
ねつき /寝付き/値付き;値段が付いて取引が成立すること/
ねつきうお /根付き魚/根付魚/
ねつきかん /熱機関/
ねつききゅう /熱気球/
ねつきぐ /熱器具/
ねつきでんりょく /熱起電力/
ねつきょうきゅう /熱供給/
ねつぎ /根継ぎ/
ねつぐん /熱群/
ねつけ /根付/根付け/熱気/
ねつけいれん /熱痙攣/
ねつけん /熱圏;thermosphere/熱研/
ねつげん /熱源/
ねつこうかん /熱交換/
ねつこうかんがた /熱交換型/
ねつこうかんき /熱交換器/
ねつこうかんぶ /熱交換部/
ねつこうがく /熱工学/
ねつこうりつ /熱効率/
ねつさまし /熱冷まし/
ねつしょり /熱処理/
ねつじょう /熱情/
ねつじょうてき /熱情的;情熱的/
ねつせっしょく /熱接触/
ねつそくど /熱速度/
ねつそんしつ /熱損失/
ねつそんしつけいすう /熱損失係数/
ねつぞう /捏造/
ねつたいさく /熱対策/
ねつちゅうせいし /熱中性子/
ねつちゅうせいしそく /熱中性子束/
ねつていこう /熱抵抗/
ねつてき /熱的/
ねつてきし /熱的死/
ねつてんしゃ /熱転写/
ねつてんしゃしき /熱転写式/
ねつてんしゃほうしき /熱転写方式/
ねつでんこうか /熱電効果/
ねつでんし /熱電子/
ねつでんそし /熱電素子/
ねつでんたつ /熱伝達/
ねつでんたつりつ /熱伝達率/
ねつでんつい /熱電対/
ねつでんどう /熱伝導/
ねつでんどうせい /熱伝導性/
ねつでんどうりつ /熱伝導率/
ねつでんりゅう /熱電流/
ねつど /熱度/
ねつはっさん /熱発散/
ねつはっせい /熱発生/
ねつびょう /熱病/
ねつふか /熱負荷/
ねつふくしゃ /熱輻射/
ねつぶつりがく /熱物理学/
ねつぶんかい /熱分解;pyrolysis/
ねつへいこう /熱平衡/
ねつへんか /熱変化/
ねつへんせい /熱変性/
ねつべん /熱弁/
ねつほうしゃ /熱放射/
ねつぼう /熱望/
ねつぼうそう /熱暴走/
ねつぼうちょう /熱膨張/
ねつゆそう /熱輸送/
ねつようりょう /熱容量/
ねつよく /熱浴/
ねつらい /熱雷/
ねつりき /熱力/
ねつりきがく /熱力学/
ねつりきがくけい /熱力学系/
ねつりきがくてき /熱力学的/
ねつりゅう /熱流/
ねつりゅうそく /熱流束/
ねつりょう /熱量/
ねつりょうけい /熱量計/
ねつるい /熱涙/
ねつれつ /熱烈/
ねつれつかんげい /熱烈歓迎/
ねつろん /熱論/
ねづ /根津/禰津/
ねづえき /根津駅/
ねづか /根塚/
ねづけ /値付け/
ねづじんぱち /根津甚八/
ねづまり /根詰まり;[園芸]/
ねていとう /根抵当/
ねていとうけん /根抵当権/
ねとまり /寝泊まり/寝泊り/
ねとり /音取;雅楽の-/
ねどこ /寝床/寝所;=寝床/
ねどし /子年/
ねなし /根無し/
ねなしぐさ /根無し草/根無草/
ねなりがき /根成柿/
ねのひ /子の日/
ねはば /値幅/
ねはばせいげん /値幅制限/
ねはん /涅槃;煩悩を無くした静寂の状態/
ねはんえ /涅槃会/
ねはんぎょう /涅槃経;大般涅槃経/
ねはんげんそく /涅槃原則;[精医]Nirvanaprinzip/
ねはんず /涅槃図/
ねば /粘/根羽/
ねばち /根鉢/
ねばつち /粘土/
ねばねば /粘々/粘粘/
ねばり /粘り/
ねばりがち /粘り勝ち/
ねばりけ /粘り気/
ねばりごし /粘り腰/
ねびえ /寝冷え/
ねびき /値引き/値引/
ねびきか /値引可/
ねびきすう /値引数/
ねびきりつ /値引率/値引き率/
ねびらき /値開き/
ねふだ /値札/
ねぶ /合歓/
ねぶか /根深/
ねぶかじる /根深汁/
ねぶかねぎ /根深葱/
ねぶかわ /根府川/
ねぶくろ /寝袋/
ねぶくろじさん /寝袋持参/
ねぶそく /寝不足/
ねぶと /根太/
ねぶみ /値踏み/
ねぷつにうむ /Np/Neptunium/
ねぷつにうむけいれつ /ネプツニウム系列;4n+1系列/
ねべや /寝部屋/
ねほしょう /根保証/
ねほりはほり /根掘り葉掘り/
ねほん /根本/
ねぼう /寝坊/
ねぼけ /寝惚け/
ねぼけまなこ /寝惚け眼/
ねぼすけ /寝坊助/
ねま /寝間/
ねまき /寝間着/寝巻;=寝間着/寝衣;=寝間着/根巻き;[園芸]root wrapping/根巻/
ねまちづき /寝待月/
ねまわし /根回し/
ねまわり /根回り/
ねみだれ /寝乱れ/
ねみつば /根三つ葉/
ねみみ /寝耳/
ねみみにみず /寝耳に水/
ねむ /合歓/
ねむけ /眠気/
ねむけざまし /眠気覚まし/
ねむのき /合歓木/棔/
ねむり /眠り/
ねむりきょうしろう /眠狂四郎/
ねむりぐすり /眠り薬/
ねむりひめ /眠り姫/
ねむりびょう /眠り病/
ねむろ /根室/
ねむろえき /根室駅/
ねもと /根本/根元/
ねものがたり /寝物語/
ねや /閨/寝屋/
ねやがわ /寝屋川/
ねやがわし /寝屋川市/
ねやがわしゃこ /寝屋川車庫/
ねゆき /根雪/
ねらい /狙い/
ねらいうち /狙い撃ち/狙い打ち/
ねらいめ /狙い目/
ねり /練り/練/
ねりいと /練糸/
ねりいろ /練色/
ねりえ /練り餌;インコの-/煉餌/煉り餌/
ねりがし /練り菓子/練菓子/
ねりきり /煉切/煉り切り/
ねりこ /練り粉/練粉/煉り粉/
ねりこう /練り香/練香/煉香/煉り香/
ねりこうじ /練り麹/煉り麹/
ねりこうすい /練り香水/
ねりせいひん /練り製品/練製品/煉り製品/
ねりぬき /練貫/
ねりひばり /練り雲雀/
ねりべい /練塀/
ねりま /練馬/
ねりまえき /練馬駅/
ねりまかん /練馬間/
ねりまく /練馬区/
ねりまくみん /練馬区民/
ねりまだいこん /練馬大根/
ねりもの /練り物/練物/煉り物/
ねりようかん /練り羊羹/練羊羹/煉り羊羹/
ねるちんすく /尼布楚/
ねわけ /根分け/
ねわざ /寝技/
ねわざし /寝業師/
ねわら /寝藁/
ねん /年/念/粘/燃;燃焼/然;天然/撚;撚糸/捻;捻挫/稔;みの・る/拈;≒捻/棯;なつめ/
ねん> /年;年2回,年休/
ねんあき /年明き/
ねんあけ /年明け/年明/
ねんあし /年足;[相場]/
ねんいじょう /年以上/
ねんいちど /年一度/
ねんいちねん /年一年;year by year/
ねんいっかい /年一回/
ねんいり /念入り/念入/
ねんえき /粘液/
ねんえきさいぼう /粘液細胞/
ねんえきしつ /粘液質/
ねんえきすいしゅ /粘液水腫/
ねんおし /念押し/
ねんかい /年会/年回/
ねんかいひ /年会費/
ねんかいひむりょう /年会費無料/
ねんかくさ /年較差/
ねんかん /年間/年鑑/年刊/
ねんかんかっそうにっすう /年間滑走日数/
ねんかんけいやく /年間契約/
ねんかんこうどく /年間購読/
ねんかんこうどくりょう /年間購読料/
ねんかんさいた /年間最多/
ねんかんししゅつ /年間支出/
ねんかんしていせき /年間指定席/
ねんかんしぼうすう /年間死亡数/
ねんかんしょうきん /年間賞金/
ねんかんしょうひでんりょく /年間消費電力/
ねんかんとうろく /年間登録/
ねんかんへいきん /年間平均/
ねんかんほうそう /年間放送/
ねんかんよさん /年間予算/
ねんかんよやく /年間予約/
ねんかんよやくせき /年間予約席/
ねんが /年賀/年画/
ねんがく /年額/
ねんがじょう /年賀状/
ねんがじょうはいたつ /年賀状配達/
ねんがじょうよう /年賀状用/
ねんがっぴ /年月日/
ねんがはがき /年賀葉書/
ねんがらねんじゅう /年がら年中/
ねんがん /念願/
ねんき /年季;-奉公,-が入る/年期;2004-/年忌;n周忌/年紀;([日本史]=年序)/年記;=年紀/
ねんきぼうこう /年季奉公/年期奉公;?/
ねんきゅう /年休/年給/
ねんきゅうぼ /年休簿/
ねんきり /年切り/
ねんきん /年金/粘菌/
ねんきんうんよう /年金運用/
ねんきんかいかく /年金改革/
ねんきんがく /年金額/
ねんきんききん /年金基金/
ねんきんせいかつ /年金生活/
ねんきんせいかつしゃ /年金生活者/
ねんきんせいど /年金制度/
ねんきんぶんかつ /年金分割/
ねんきんほう /年金法/
ねんきんほうあん /年金法案/
ねんきんほけん /年金保険/
ねんぎょ /年魚/
ねんぎょうじ /年行事/
ねんくれ /年暮/
ねんぐ /年貢/
ねんぐまい /年貢米/
ねんけいかく /年計画/
ねんげつ /年月/
ねんげみしょう /拈華微笑/
ねんげん /年限/
ねんこう /年功/
ねんこうじょれつ /年功序列/
ねんこうちんぎん /年功賃金/
ねんこん /念根/
ねんご /年後/
ねんごう /年号/
ねんごと /年毎/
ねんごろ /年頃/懇ろ/
ねんさ /年差/
ねんさい /年祭/年歳/
ねんさん /年産/
ねんざ /捻挫/
ねんし /年始/撚糸/念死;[仏教]memento mori/
ねんしき /年式/
ねんしきそうおう /年式相応/
ねんしきていど /年式程度/
ねんしきふめい /年式不明/
ねんしきゅうぎょう /年始休業/
ねんした /年下/
ねんしまわり /年始回り/
ねんしゃ /念写/念者/
ねんしゅう /年収/年周/
ねんしゅうしさ /年周視差/
ねんしゅうにゅう /年収入/
ねんしゅつ /捻出/
ねんしょ /年初/念書/
ねんしょう /燃焼/年少/年商/
ねんしょうおんど /燃焼温度/
ねんしょうき /燃焼器;burner/
ねんしょうぐみ /年少組/
ねんしょうけいさん /燃焼計算/
ねんしょうこうりつ /燃焼効率/
ねんしょうしけん /燃焼試験/
ねんしょうしつ /燃焼室/
ねんしょうじかん /燃焼時間/
ねんしょうじょうたい /燃焼状態/
ねんしょうそう /年少層/
ねんしょうそくど /燃焼速度/
ねんしょうとう /燃焼筒/
ねんしょうど /燃焼度/
ねんしょうねつ /燃焼熱;[化学]heat of combustion/
ねんしょらい /年初来/
ねんじ /年次/年時/念持/
ねんじけいかく /年次計画/
ねんじすいい /年次推移/
ねんじそうかい /年次総会/
ねんじぶつ /念持仏/
ねんじほうこく /年次報告/
ねんじほうこくしょ /年次報告書/
ねんじゃ /念者/
ねんじゅ /念珠;数珠/念誦;念じ唱える/
ねんじゅう /年中/
ねんじゅうぎょうじ /年中行事;=ねんちゅうぎょうじ/
ねんじゅうむきゅう /年中無休/
ねんすう /年数/
ねんず /念珠/
ねんせい /粘性/年生/年制/
ねんせいりつ /粘性率/
ねんせいりょく /粘性力/
ねんそつ /年卒/
ねんたんい /年単位/
ねんだい /年代/
ねんだいき /年代記/
ねんだいこうはん /年代後半/
ねんだいじゅん /年代順/
ねんだいぜんはん /年代前半/
ねんだいとくてい /年代特定/
ねんだいひょう /年代表/
ねんだいべつ /年代別/
ねんだいもの /年代物/
ねんだんせい /粘弾性/
ねんちゃく /粘着/
ねんちゃくけいすう /粘着係数/
ねんちゃくご /粘着語/
ねんちゃくざい /粘着剤/粘着材/
ねんちゃくしき /粘着式/
ねんちゃくしつ /粘着質/
ねんちゃくせい /粘着性/
ねんちゃくてーぷ /粘着テープ/
ねんちゃくぶぶん /粘着部分/
ねんちゃくりょく /粘着力/
ねんちゅう /年中/粘稠/
ねんちゅうぎょうじ /年中行事/
ねんちょう /年長/粘稠/
ねんちょうしゃ /年長者/
ねんてん /捻転/
ねんとう /念頭/年頭/
ねんとうきょうしょ /年頭教書/
ねんとうぶつ /燃灯仏;[仏教]Dipamkara/
ねんど /年度/粘土;†clay.「紙-」/粘度;†viscosity.「液体の-」/
ねんどう /念動/
ねんどがわら /粘土瓦/
ねんどがん /粘土岩;[地質]claystone/
ねんどけい /粘度計/
ねんどしつ /粘土質/
ねんどだいひょうば /年度代表馬/
ねんどない /年度内/
ねんどまつ /年度末/
ねんない /年内/
ねんないちゅう /年内中/
ねんないはつばい /年内発売/
ねんにん /念人/
ねんねん /年々/年年/
ねんねんさいさい /年年歳歳/年々歳々/
ねんのため /念の為/念のため/為念/
ねんはん /年半/
ねんばつ /年伐/
ねんばらい /年払い/
ねんばん /年版/
ねんばんがん /粘板岩/
ねんぱ /念波/
ねんぱい /年配/年輩;≒年配/
ねんぱいしゃ /年配者/
ねんびゃくねんじゅう /年百年中/
ねんぴ /燃費/
ねんぴいちらん /燃費一覧/
ねんぴけい /燃費計/
ねんぴこうじょう /燃費向上/
ねんぴじゅうし /燃費重視/
ねんぴせつやく /燃費節約/
ねんぴょう /年表/
ねんぴりつ /燃費率/
ねんぶつ /念仏/
ねんぶつおどり /念仏踊り/念仏踊/
ねんぶつざんまい /念仏三昧/
ねんぶつじ /念仏寺/
ねんぶん /年分/
ねんぷ /年譜/年賦/
ねんべつ /年別/
ねんぽう /年報;annual/年俸;annual salary/念法/
ねんぽうせい /年俸制/
ねんまえ /年前/
ねんまく /粘膜/
ねんまくめん /粘膜面/
ねんまつ /年末/
ねんまつさいしゅう /年末最終/
ねんまつしょうせん /年末商戦/
ねんまつしんこう /年末進行/
ねんまつちょうせい /年末調整/
ねんまつねんし /年末年始/
ねんまつねんしきゅうか /年末年始休暇/
ねんまつばんぐみ /年末番組/
ねんめ /年目/
ねんゆ /燃油/
ねんゆう /念友/
ねんよ /年余/
ねんらい /年来/
ねんり /年利/
ねんりかんざん /年利換算/
ねんりき /念力/
ねんりつ /年率/
ねんりまわり /年利回り/
ねんりょ /念慮/
ねんりょう /燃料/燃量;?/
ねんりょうぎれ /燃料切れ/
ねんりょうけい /燃料計;fuel gauge/燃料系;fuel system/
ねんりょうさいくる /燃料サイクル/
ねんりょうしゅうごうたい /燃料集合体/
ねんりょうしょうひりつ /燃料消費率/
ねんりょうしょうひりょう /燃料消費量/
ねんりょうそうち /燃料装置/
ねんりょうたんく /燃料タンク/
ねんりょうだい /燃料代/
ねんりょうてん /燃料店/
ねんりょうでんち /燃料電池/
ねんりょうでんちしゃ /燃料電池車/
ねんりょうひ /燃料費/
ねんりょうふんしゃ /燃料噴射/
ねんりょうぶそく /燃料不足/
ねんりょうほきゅう /燃料補給/
ねんりょうぼう /燃料棒/
ねんりょうゆそう /燃料輸送/
ねんりん /年輪/
ねんれい /年齢/年令;NB:「年齢」の略式表記/
ねんれいげんてい /年齢限定/
ねんれいこうせい /年齢構成/
ねんれいさ /年齢差/年令差/
ねんれいせいげん /年齢制限/年令制限/
ねんれいせいべつ /年齢性別/
ねんれいせってい /年齢設定/
ねんれいそう /年齢層/
ねんれいそうおう /年齢相応/
ねんれいてき /年齢的/
ねんれいふしょう /年齢不詳/
ねんれいべつ /年齢別/年令別/
ねんわり /年割り/年割/
の /野/埜;「野」の旧字(人名用漢字)/之/乃;NB:「之」と違い、日本のみの用法/廼;すなわち/濃;美濃/−;minus/
の> /野;野羽織,野育ち,野ネズミ/
のーちらすごう /ノーチラス号;Nautilus. <『海底二万里』/
のーと /帳面/
のーとがた /ノート型/
のーどかん /ノード間/
のーべりうむ /No/Nobelium/
のーべるしょう /ノーベル賞/
のあそび /野遊び/
のいけ /野池/
のいち /野市/
のいちご /野苺/
のう /脳;brain/能;ability/農;agri./濃;thick/膿;pus/能生;地名,新潟/納;納付/衲;衲衣/嚢;背嚢/曩;さき(に)/悩;悩殺/惱;「悩」の旧字/瑙;瑪瑙/碯;「瑙」の異体字/腦;「脳」の旧字/王;親王/皇;天皇/獰;(漢音) 獰猛(どうもう)/
のう> /濃/
のうあい /能間/
のうあつ /脳圧;[医]brain pressure/
のういがい /脳以外/
のういっけつ /脳溢血/
のういん /能因;(988-?) 歌人/
のうえん /農園/脳炎/濃艶/
のうおん /濃音/
のうおんか /濃音化/
のうか /農家/農科;-大学/濃化/
のうかい /納会/脳回;[解剖]gyrus/
のうかいだい /能開大/
のうかがく /脳科学/
のうかく /能格/
のうかしん /膿痂疹/
のうかすいたい /脳下垂体/
のうかん /納竿/脳幹/納棺/能管/農間;耕作の合間。「-稼ぎ」/農閑;耕作の仕事があまりない。「-期」/
のうかんき /農閑期/
のうかんけい /脳関係/
のうかんしょうがい /脳幹障害/
のうがき /能書き/能書/
のうがく /農学/能楽/
のうがくけんきゅうか /農学研究科/
のうがくし /能楽師/
のうがくどう /能楽堂/
のうがくぶ /農学部/
のうがっこう /農学校/
のうがや /能ヶ谷/
のうき /納期/農機/能記;[言語]signifiant/農期/納城/
のうきぐ /農機具/
のうきげん /納期限/
のうきのう /脳機能/
のうきょう /農協/納経/膿胸/脳橋/
のうきょうげん /能狂言/
のうきょけつ /脳虚血/
のうきん /納金/
のうぎょう /農業/
のうぎょういいんかい /農業委員会/
のうぎょうか /農業科/
のうぎょうかいはつ /農業開発/
のうぎょうがっこう /農業学校/
のうぎょうきほんほう /農業基本法/
のうぎょうきょうどうくみあい /農業協同組合/
のうぎょうけいざいがく /農業経済学;agronomics/
のうぎょうこく /農業国/
のうぎょうさいがいほしょうほう /農業災害補償法/
のうぎょうしゃだいがっこう /農業者大学校;農水省。www.farmers.ac.jp/
のうぎょうしょとく /農業所得/
のうぎょうじゅうじしゃ /農業従事者/
のうぎょうせいさく /農業政策/
のうぎょうせいさんほうじん /農業生産法人/
のうぎょうぜんしょ /農業全書/
のうぎょうほうじん /農業法人/
のうぎょうよう /農業用/
のうぎょうようすい /農業用水/
のうぎょうようち /農業用地/
のうぐ /農具/
のうけ /能化/
のうけっせん /脳血栓/
のうけつ /膿血/
のうけつりゅう /脳血流/
のうけつりゅうりょう /脳血流量/
のうけん /脳研/
のうげ /能化/
のうげい /農芸/能芸/
のうげいかがく /農芸化学/
のうげか /脳外科/
のうこう /濃厚/農耕/農工/農高;[略語]農業高校/
のうこうしゃかい /農耕社会/
のうこうしりょう /濃厚飼料/
のうこうそく /脳梗塞/
のうこうだい /農工大/
のうこうだいがく /農工大学/
のうこうぶんか /農耕文化/
のうこうみん /農耕民/
のうこうよう /農耕用/
のうこつ /納骨/
のうこつどう /納骨堂/
のうこん /濃紺/
のうさい /納采/濃彩/能才;物事を成功させられる才能/
のうさいぼう /脳細胞/
のうさぎ /野兎/
のうさぎょう /農作業/
のうさく /農作/
のうさくしょ /能作書/
のうさくぶつ /農作物/
のうさくもつ /農作物/
のうさつ /悩殺/納札/
のうさつじょ /納札所/
のうさん /農産/
のうさんそん /農山村/
のうさんち /農産地/
のうさんひん /農産品/
のうさんぶつ /農産物/
のうざい /能材/
のうざしょう /脳挫傷/
のうし /脳死/濃紫/直衣/野牛/
のうししょく /濃紫色/
のうしじょうたい /脳死状態/
のうしつ /脳室/
のうしゃ /納車/
のうしゃかい /納射会/
のうしゃきねん /納車記念/
のうしゃご /納車後/
のうしゃじ /納車時/
のうしゃとうじ /納車当時/
のうしゃび /納車日/
のうしゃまえ /納車前/
のうしゅ /嚢腫/
のうしゅう /能州;能登/濃州;美濃(岐阜)/
のうしゅく /濃縮/
のうしゅくうらん /濃縮ウラン/
のうしゅくえき /濃縮液/
のうしゅくかじゅう /濃縮果汁/
のうしゅくかんげん /濃縮還元/
のうしゅくど /濃縮度/
のうしゅくよう /濃縮用/
のうしゅっけつ /脳出血/
のうしゅよう /脳腫瘍/
のうしょ /能書/農書/
のうしょう /脳症/農相/農商/脳漿/
のうしょうがい /脳障害/
のうしょく /濃色/
のうしょくけい /濃色系/
のうしんけい /脳神経/
のうしんけいげか /脳神経外科;neurosurgery/
のうしんとう /脳震盪/
のうじ /農事/能地/能事/
のうじず /脳磁図/
のうじゅ /納受/
のうじゅう /膿汁/
のうじゅん /濃醇/
のうじょう /農場/嚢状/
のうじょうさん /農場産/
のうじれき /農事歴/
のうすい /農水;農林水産/
のうすいしゅ /脳水腫;[医]hydrocephalia/
のうすいしょう /農水省/農水相;†農林水産大臣/
のうずい /脳髄/
のうせい /農政/能性/脳性/
のうせいがく /農政学/
のうせいぜんしょ /農政全書/
のうせいまひ /脳性麻痺;cerebral paralysis/
のうせきずいしんけい /脳脊髄神経/
のうせん /農専/能詮/
のうせんかた /納銭方/
のうぜい /納税/
のうぜいかんけい /納税関係/
のうぜいかんりにん /納税管理人/
のうぜいきげん /納税期限/
のうぜいぎむしゃ /納税義務者/
のうぜいしゃ /納税者/
のうぜいしゃばんごうせいど /納税者番号制度/
のうぜいしょ /納税書/
のうぜいしょうめい /納税証明/
のうぜいしょうめいしょ /納税証明書/
のうぜいしんこく /納税申告/
のうぜいじゅんびよきん /納税準備預金/
のうぜいつうちしょ /納税通知書/
のうぜんかずら /凌霄花/
のうそう /農宗/能相;[文法]active voice.⇔所相/
のうそくせん /脳塞栓/
のうそっちゅう /脳卒中/
のうそん /農村/
のうそんしゃかいがく /農村社会学;rural sociology/
のうそんしょう /脳損傷/
のうそんふうけい /農村風景/
のうそんぶ /農村部/
のうたりん /脳足りん/
のうたん /濃淡/
のうたんがぞう /濃淡画像/
のうたんち /濃淡値/
のうだ /納田/
のうだい /農大/
のうだいいちこう /農大一高/
のうち /農地/野内/納地/
のうちほう /農地法/
のうちゅう /脳中/嚢中;-の錐/嚢虫;条虫の幼虫/
のうてい /脳底/
のうてん /脳天/
のうてんき /能天気/脳天気;=能天気/腦天氣;「脳」「気」旧字/
のうてんし /能天使;powers/
のうど /濃度/農奴/
のうどう /農道/能動/
のうどうきつえん /能動喫煙/
のうどうせい /能動性/
のうどうせいぎょ /能動制御/
のうどうそう /能動相/
のうどうたい /能動態/
のうどうてき /能動的/
のうどかいほう /農奴解放/
のうどち /濃度値/
のうどてき /濃度的/
のうない /脳内/
のうないしゅっけつ /脳内出血/
のうないしんけい /脳内神経/
のうないぶっしつ /脳内物質/
のうないまやく /脳内麻薬/
のうないまやくぶっしつ /脳内麻薬物質/
のうなし /能無し/
のうなんかしょう /脳軟化症/
のうにゅう /納入/
のうにゅうか /納入価/
のうにゅうきかん /納入期間/
のうにゅうきげん /納入期限/
のうにゅうぎょうしゃ /納入業者/
のうにゅうこくちしょ /納入告知書/
のうにゅうさき /納入先/
のうにゅうしょ /納入書/
のうにゅうじ /納入時/
のうにゅうじっせき /納入実績/
のうにん /納人/
のうは /脳波/
のうはん /農繁/
のうはんき /農繁期/
のうひつ /能筆/
のうひょう /脳表/
のうひん /納品/
のうひんけつ /脳貧血/
のうひんさき /納品先/
のうひんしょ /納品書/
のうひんじ /納品時/
のうひんまち /納品待ち/
のうび /濃尾/
のうびょう /脳病/
のうびょういん /脳病院/
のうふ /納付/農夫/農婦/
のうふきげん /納付期限/
のうふしゃ /納付者/
のうふしょ /納付書/
のうぶたい /能舞台/
のうぶん /能文/
のうへい /農兵/
のうへいぶし /農兵節;[民謡]静岡/
のうべん /能弁/
のうほ /農圃;田畑のこと/
のうほう /農法/嚢胞;[医]cyst. 液体がたまる/膿疱;[医]pustule. ウミがたまる/
のうほん /納本/能本;お能の台本/
のうほんしゅぎ /農本主義/
のうまく /脳膜/
のうまくえん /脳膜炎/
のうみ /能美/能見/
のうみそ /脳味噌/脳ミソ/脳みそ/
のうみつ /濃密/
のうみん /農民/
のうみんいっき /農民一揆/
のうみんが /農民画/
のうみんせんそう /農民戦争/
のうみんで /農民出/
のうみんふう /農民風/
のうみんぶんがく /農民文学/
のうむ /濃霧/
のうむしょう /農務省/
のうむちゅういほう /濃霧注意報/
のうめん /能面/
のうやく /農薬/
のうやくしゃ /能役者/
のうやくせいぶん /農薬成分/
のうやま /納山/
のうよう /膿瘍/嚢瘍/
のうらん /悩乱/
のうり /脳裏/脳裡/能吏/
のうりき /能力;寺男/
のうりつ /能率/
のうりつか /能率化/
のうりつかいぜん /能率改善/
のうりつきゅう /能率給/
のうりつてき /能率的/
のうりゅうさん /濃硫酸/
のうりょう /納涼/脳梁/
のうりょうさい /納涼祭/
のうりょく /能力/濃緑/
のうりょくいっぱい /能力一杯/
のうりょくきゅう /能力給/
のうりょくけんていしけん /能力検定試験/
のうりょくこうじょう /能力向上/
のうりょくさ /能力差/
のうりょくしだい /能力次第/
のうりょくしゃ /能力者/
のうりょくしゅぎ /能力主義/
のうりょくしょく /濃緑色/
のうりょくじたい /能力自体/
のうりょくじょう /能力上/
のうりょくじょうしょう /能力上昇/
のうりょくち /能力値/
のうりょくてき /能力的/
のうりょくひょうか /能力評価/
のうりょくぶそく /能力不足/
のうりん /農林/
のうりんぎょぎょう /農林漁業/
のうりんしょう /農林省/
のうりんすいさん /農林水産/
のうりんすいさんぎょう /農林水産業/
のうりんすいさんぎょうひ /農林水産業費/
のうりんすいさんしょう /農林水産省/
のうりんすいさんだいじん /農林水産大臣;農水相/
のうりんだいじん /農林大臣/
のうりんちゅうおうきんこ /農林中央金庫;www.nochubank.or.jp/
のえ /野家/
のえる /Ｎｏёｌ/
のおがた /直方/
のおがたえき /直方駅/
のおがたし /直方市/
のかぜ /野風/
のかた /野方/
のかみ /野上/
のがき /野垣/
のがた /野方/
のがみ /野上/埜上/
のがみでんてつ /野上電鉄/
のがわ /野川/野河/
のき /軒/簷;=軒/檐;=軒/
のきうら /軒裏/
のきがわら /軒瓦/
のきげた /軒桁/
のきさき /軒先/
のきした /軒下/
のきじゃばら /軒蛇腹/
のきたけ /軒丈/
のきだか /軒高/
のきどい /軒樋;雨樋の、軒で雨水を受ける部分/
のきなみ /軒並/
のきならび /軒並び/
のきば /軒端/
のきひらがわら /軒平瓦/
のきまるがわら /軒丸瓦/
のきわり /軒割/
のぎ /芒/禾/乃木/野木/野義/
のぎく /野菊/
のぎさか /乃木坂/
のぎざか /乃木坂/
のぎし /野岸/
のぎつね /野狐/
のぎまれすけ /乃木希典/
のぎめ /禾目/
のぎわ /野際/
のぎわようこ /野際陽子/
のくび /野首;姓/
のぐそ /野糞/
のぐち /野口/
のぐちひでよ /野口英世/
のぐら /野倉/
のけもの /除け者/
のげ /野毛/
のこ /鋸/
のこぎり /鋸/
のこぎりがま /鋸鎌/
のこぎりば /鋸歯/
のこくず /鋸屑/
のこのしま /能古島/
のこば /鋸歯/
のこらず /残らず/
のこり /残り/
のこりかす /残り滓/
のこりが /残り香/
のこりび /残り火/
のこりもの /残り物/
のこりゆ /残り湯/
のさか /野坂/野栄/
のさっぷ /納沙布/
のさっぷみさき /納沙布岬/
のざき /野崎/野咲/
のざききた /野崎北/
のざきさんぎょう /野崎産業;[企業名]/
のざと /野里/
のざらし /野晒し/
のざる /野猿/
のざわ /野沢/野澤/
のざわおんせん /野沢温泉/
のざわな /野沢菜/
のし /熨斗/熨/
のしがみ /熨斗紙/
のしがわら /熨斗瓦/
のした /野下/
のしぶくろ /熨斗袋/
のしめ /熨斗目/
のしろ /能代/野城/能城/
のしろえき /能代駅/
のしろこう /能代工/
のじ /野地/野路/
のじいた /野地板/
のじし /野猪/
のじま /野島/野嶋/
のじゅく /野宿/
のじり /野尻/
のじりこ /野尻湖/
のじりほうえい /野尻抱影/
のじん /野人/
のずえ /野末/
のせ /能勢/野瀬/能瀬/
のせがわ /野迫川/
のせぐち /能勢口/
のせでんしゃ /能勢電車/
のそだち /野育ち/
のぞえ /野添/野副/
のぞき /覗き/覗/
のぞきあな /覗き穴/
のぞきしゅみ /覗き趣味/
のぞきま /覗き魔/
のぞきまど /覗き窓/
のぞきみ /覗き見/
のぞみ /望/希/稀/望み/
のぞみうす /望み薄/
のぞみどおり /望み通り/
のぞむ /望/
のぞりこ /野反湖/
のたれ /湾/
のたれじに /野垂れ死に/
のだ /野田/
のだいこ /野太鼓;野良の幇間/
のだがわ /野田川/
のだけ /野竹;[植物]セリ科/
のだし /野田市/
のだせん /野田線/
のだて /野点/野立て/
のだはま /野田浜/
のだはんしん /野田阪神/
のち /後/
のちかわ /後川/
のちざん /後産;=あとざん/
のちぞい /後添い/
のちぞえ /後添え/
のちのち /後々/後後/
のちほど /後程/後ほど/
のちょう /野帳/
のっと /祝詞/¬;not/
のっとり /乗っ取り/
のっぴき /退っ引き/
のっぽろ /野幌/
のつ /野津/
のつはる /野津原/
のつぼ /野壺/
のづき /野月/
のづち /野槌/
のづみ /野積み/
のづら /野面/
のてう /盧泰愚/
のてん /野天/
のてんぶろ /野天風呂/
ので /野出/
のでら /野寺/
のと /能登/能都/
のとかわ /能登川/
のとがわ /能登川/
のとじま /能登島/
のとせん /能登線/
のとちほう /能登地方/
のとはんとう /能登半島/
のとろ /能取/
のど /喉/咽/吭;のどぶえ/
のどあめ /のど飴/喉飴/
のどか /長閑/
のどくび /喉頸/
のどごし /喉越し/喉ごし/
のどじまん /喉自慢/のど自慢/
のどちんこ /喉ちんこ/
のどびこ /喉彦/
のどぶえ /喉笛/
のどぼとけ /喉仏/
のどもと /喉元/
のどわ /喉輪/
のなか /野中/野仲/
のなみ /野並/
のねこ /野猫/
のねずみ /野鼠/野ネズミ/
のの /野々/
ののいち /野々市/
ののか /野々香/
ののぐち /野々口/
ののはら /野々原/
ののむら /野々村/
ののやま /野々山/
のはら /野原/
のば /野場/
のばし /伸ばし/
のばと /野鳩/
のばな /野花/
のばなし /野放し/
のばら /野薔薇/
のひら /野平/
のび /野火/伸/伸び/
のびざかり /伸び盛り/
のびた /のび太/
のびたき /野鶲/
のびちぢみ /伸び縮み/
のびと /野人/
のびのび /伸び伸び/
のびりつ /伸び率/伸率/
のびる /野蒜/
のふせ /野伏/
のぶ /順/信/展/修/延/伸/宣/亘/允/暢/惟/
のぶあき /信明/伸明/信昭/宣明/伸晃/延晃/悦旦/
のぶえ /伸枝/信恵/延枝/
のぶお /信夫/信雄/伸夫/信男/宣夫/伸生/信生/暢夫/信朗/陳雄/
のぶおか /信岡;姓/
のぶおき /暢興/
のぶかず /信和/
のぶかつ /信雄/信勝/信克/
のぶき /伸樹/信樹/信木/
のぶくに /信邦/
のぶこ /信子/伸子/敦子/暢子/延子/展子/
のぶし /野伏;山伏(やまぶし)。山野で修行する僧/野武士/野臥;=野伏/
のぶじ /伸治/伸自/
のぶすけ /宣介/
のぶせり /野伏せり/野臥せり/
のぶた /信太/
のぶたか /信孝/信隆/信高/伸啓/
のぶただ /信忠/
のぶち /野縁/
のぶどう /野葡萄/
のぶなが /信長/
のぶはら /信原/
のぶはる /伸治/
のぶひこ /信彦/伸彦/宣彦/暢彦/延彦/
のぶひさ /信久/暢久/延久/順久/
のぶひで /宣秀/
のぶひと /宣仁/
のぶひろ /信博/信弘/信宏/伸浩/信洋/伸弘/宣弘/展弘/伸広/宣博/信寛/伸裕/伸啓/伸廣/
のぶふさ /信房/
のぶまさ /宣政/伸昌/
のぶみつ /信光/
のぶや /信也/暢也/誠也/
のぶやす /信康/延康/宣保/
のぶゆき /信行/信之/信幸/伸之/伸行/伸幸/宣之/暢之/展之/伸介/
のぶよし /信義/伸好/
のぶろう /伸郎/信郎/宣郎/
のぶん /攵/
のへじ /野辺地/
のへん /野辺/
のべ /野辺/延/延べ/野邊/
のべ> /延べ;延べ坪数,延べ人数,延べ４万人/延/
のべいた /延板/
のべおか /延岡/
のべおかかん /延岡間/
のべおくり /野辺送り/
のべがね /延金/
のべがみ /延紙/
のべじんいん /延べ人員/
のべすう /延べ数/延数/
のべだか /延高/
のべつぼ /延坪/
のべつまくなし /のべつ幕無し/
のべな /野辺名/
のべにっすう /延べ日数/延日数/
のべにんずう /延人数/
のべばらい /延べ払い/
のべぼう /延べ棒/
のべめんせき /延べ面積;[建築]床面積の総和/延面積/
のべやま /野辺山/
のべやまてんもんだい /野辺山天文台/
のべゆかめんせき /延べ床面積/
のほう /野方/野放/
のほうず /野放図/
のほり /野堀/
のぼたん /野牡丹;[植物]melastome/
のぼとけ /野仏/
のぼり /幟;banner/上り/登り/昇り/登/
のぼりおり /上り下り/昇り降り;エレベーターの-/登り降り;坂道の-/
のぼりがま /登り窯/
のぼりくだり /上り下り;-の旅人が/
のぼりくち /登り口/上り口/
のぼりぐち /登り口/上り口/
のぼりざか /上り坂/登り坂/
のぼりせん /上り線/
のぼりちょうし /上り調子/
のぼりと /登戸/
のぼりとえき /登戸駅/
のぼりばた /幟旗/
のぼりべつ /登別/
のぼりぼう /登り棒/
のぼりりゅう /昇り竜/登り竜/
のぼる /登/昇/
のま /野間/々/
のまおい /野馬追/
のまずくわず /飲まず食わず/
のまち /野町/
のまひろし /野間宏;作家(1915-91) 『暗い絵』/
のみ /蚤;flea/鑿;chisel/能美/乃美/
のみかい /飲み会/呑み会/
のみかた /飲み方/
のみくい /飲み食い/飲み喰い/呑み喰い/
のみくち /飲み口/飲口/
のみぐすり /飲み薬/飲薬/
のみぐち /呑口/
のみぐん /能美郡/
のみこうい /呑み行為/呑行為/
のみこみ /飲み込み/
のみごこち /飲み心地/
のみごたえ /飲み応え/
のみごろ /飲み頃/
のみしろ /飲み代/呑み代/
のみすぎ /飲み過ぎ/
のみすけ /呑み助;drunk/飲み助/呑助/飲助/
のみず /野水/
のみだい /飲み代/
のみち /野道/
のみっぷり /飲みっ振り/
のみて /飲み手/
のみで /飲み出;何、土産は焼酎一升？こりゃ相当-があるな/
のみともだち /飲み友達/
のみなかま /飲み仲間/
のみにげ /飲み逃げ/
のみのいち /蚤の市;flea market/
のみほうだい /飲み放題/
のみみず /飲み水/
のみもの /飲み物/飲物/
のみや /飲み屋/呑み屋/野宮;人名/呑屋/飮み屋;「飲」旧字/
のみやま /野見山/
のみりょう /飲み料/
のむぎ /野麦/
のむぎとうげ /野麦峠/
のむら /野村/乃村/
のむらしょうけん /野村證券;[企業名]/野村証券;※「野村證券」が正式/
のむらそうけん /野村総研/
のも /野茂/
のもざき /野母崎/
のもと /野本/
のもり /野守/
のやき /野焼き/野焼/
のやま /野山/
のら /野良/
のらいぬ /野良犬/
のらぎ /野良着/
のらくらもの /のらくら者/
のらしごと /野良仕事/
のらねこ /野良猫/ノラ猫/のら猫/
のり /海苔/糊/法/乗り/典/則/範/矩/教/規/紀/徳/憲/雅/哲/就/昇/伯/宜/規範/弼/悳;「徳」の異体字/朔/孔/
のりあい /乗合/乗り合い/
のりあき /憲明/紀明/典明/典昭/則明/紀昭/範明/憲章/法明/倫明/功晶;名/規昭/徳晶/
のりいれ /乗り入れ/乗入れ/乗入/
のりいれがみ /糊入紙/
のりえ /法枝/礼江/
のりお /紀夫/則夫/典夫/憲夫/紀男/範夫/憲生/憲雄/典生/典男/徳雄/展男/則郎/昇男/
のりおり /乗り降り/
のりかえ /乗り換え/乗換え/乗り替え/乗換/乗替え/
のりかえあんない /乗換案内/
のりかええき /乗換駅/
のりかえきゃく /乗換客/
のりかえぐち /乗換口/
のりかえじかん /乗換時間/
のりかず /紀和/則和/
のりかた /乗り方/
のりき /乗り気/
のりくち /乗り口/
のりくみいん /乗組員/
のりくら /乗鞍/
のりくらおんせん /乗鞍温泉/
のりくらこうげん /乗鞍高原/
のりくらだけ /乗鞍岳/
のりこ /典子/紀子/法子/のり子/範子/倫子/則子/乃梨子/規子/徳子/教子/賀子/訓子/能理子/祈子/
のりこし /乗越/乗り越し/
のりこしえき /乗越駅/
のりごこち /乗り心地/乗心地/
のりざね /徳実/
のりしげ /則茂/
のりしろ /糊代/
のりたか /典孝/範高/則貴/
のりたけ /憲武/則竹/
のりちか /乃親/
のりつぎ /乗り継ぎ/乗継/
のりつぎえき /乗継駅/
のりつぎわりびき /乗継割引/
のりづき /法月/
のりづけ /糊付け/糊付/
のりづら /法面;=のりめん/
のりて /乗り手/
のりと /祝詞/
のりにげ /乗逃げ/
のりのつかさ /式部省;[律令制]三省/
のりのみや /紀宮/
のりのみやさま /紀宮様/
のりば /乗り場/乗場/
のりひこ /紀彦/憲彦/規彦/
のりひさ /典久/範久/則久/哲久/典尚/
のりひと /徳仁/
のりひろ /憲広/典大/紀大/則浩/
のりふみ /憲文/
のりべんとう /海苔弁当/
のりほ /範穂/
のりまき /海苔巻/則巻/
のりまさ /典正/紀政/
のりまつ /乗松/
のりむね /倫宗/
のりめん /法面;人工的な傾斜/
のりもと /紀元/
のりもの /乗り物/乗物/
のりものけん /乗物券/
のりものよい /乗り物酔い/乗物酔い/
のりや /法也/紀哉/
のりやす /典康/
のりゆき /紀之/憲之/則之/敬之/徳行/則行/範行/紀幸/徳幸/規之/哲之/憲行/規行/典行/範幸/矩之/宜之/則征/
のりゆみ /賭弓/
のりゆみのかえりあるじ /賭弓の還り饗/
のりゆみのかえりだち /賭弓の還り立ち/
のりゆみのせち /賭弓の節/
のりよ /記代/
のりよし /徳芳/徳吉/紀吉/法良/
のりろう /憲郎/
のりわく /法枠/
のるうぇー /諾威;Norway/
のるうぇーご /ノルウェー語;ノルウェーの公用語/
のるかそるか /伸るか反るか/
のるまんじん /ノルマン人;Normans/
のれん /暖簾/
のれんわけ /暖簾分け/
のろ /野呂;人名/麕;(鹿の一種)/祝女/
のろい /呪い/詛い/
のろけ /惚気/
のろけばなし /惚気話/
のろし /狼煙/烽火/燧/烽/狼烟/
のろのろ /鈍々/
のろま /鈍間/野呂松;=鈍間/野呂間;=鈍間/
のわき /野分/
のんき /呑気;当て字/暖気/のん気/暢気;当て字/
のんだくれ /飲んだくれ/
のんべえ /飲兵衛/呑兵衛/
のんれむすいみん /ノンレム睡眠;non-REM sleep/
は /葉/歯/刃/覇/派/波/破/端/羽/巴;ともえ/把;把握/杷;枇杷/琶;琵琶/芭;芭蕉/爬;爬虫類/笆;ませ/葩;はな/頗;すこぶる/簸/坡/陂;「坡」の異体字/玻;玻璃/碆/菠;菠薐草/跛;跛行/叭;喇叭/垪/怕/播;播種/刄;「刃」の異体字/齒;「歯」の異体字/霸;「覇」の異体字/張;動詞語幹?/
はーぐ /海牙/
はーとがた /ハート形/
はーどめん /ハード面/
はーばーどだいがく /ハーバード大学;Harvard University. www.harverd.edu/
はあく /把握/
はあん /破闇/
はい /肺/灰/牌/杯/盃;「杯」の旧字(人名用漢字)/胚;[生物]embryo/輩/敗/廃/癈;≒廃/廢;「廃」の旧字/配/背/拝;崇拝/拜;「拝」の旧字(人名用漢字)/湃;澎湃/俳;俳句/排;排出/徘;徘徊/琲;珈琲 (字義は「玉飾り」)/裴/佩;佩剣/旆/珮/沛;顛沛/霈/孛/悖;悖徳/睥;(呉音) 睥睨/稗;ひえ/坏;つき/憊;疲労困憊/擺/碚/吠;ほ・える/這;?/埴;?/
はい> /灰;灰[緑紫褐](色),灰猫/
はいあん /廃案/
はいい /配位/配意/廃位/
はいいけつごう /配位結合/
はいいし /配位子;[化学]ligand/
はいいしょく /胚移植/
はいいろ /灰色/
はいいろいっしょく /灰色一色/
はいいろぐま /灰色熊/
はいいん /敗因/配員/排印/
はいいんぼん /排印本/
はいえい /背泳/
はいえき /廃液;†wastewater.「蒸留-」/排液;†drainage/廃駅/
はいえきしょり /廃液処理/
はいえつ /拝謁/
はいえん /肺炎/排煙/廃園/
はいえんか /排煙家/
はいおく /廃屋/
はいか /配架/配下/廃家/排架/拝火/廃貨/輩下;=配下/
はいかい /徘徊;-老人/俳諧/誹諧;=俳諧/
はいかいし /俳諧師/
はいかいしちぶしゅう /俳諧七部集;蕪村七部集/
はいかきょう /拝火教/
はいかぐら /灰神楽/
はいかっしょく /灰褐色/
はいかつりょう /肺活量/
はいかでん /廃家電/
はいかん /配管/廃刊/拝観/廃館/廃艦/肺肝/肺患/廃官/
はいかんきゃく /拝観客/
はいかんこう /配管工/
はいかんこうじ /配管工事/
はいかんごう /廃刊号/
はいかんじ /廃刊時/
はいかんていし /拝観停止/
はいかんめい /配管名/
はいかんりょう /拝観料/
はいが /胚芽/俳画/拝賀/
はいがい /排外/拝外;†外国崇拝/
はいがいうんどう /排外運動/
はいがいしゅぎ /排外主義/
はいがく /廃学/
はいがす /排ガス/
はいがすきせい /排ガス規制/
はいがすしょり /排ガス処理/
はいがた /灰型/
はいがまい /胚芽米/
はいがゆ /胚芽油/
はいがん /肺癌/拝顔/肺ガン/肺がん/
はいがんけんしん /肺癌検診/
はいき /排気/廃棄/拝跪/
はいきあつ /排気圧/
はいきおん /排気音/
はいきおんどけいこく /排気温度警告/
はいきかん /排気管/
はいきがす /排気ガス/
はいきがわ /排気側/
はいききせい /排気規制/
はいきけい /排気系/
はいきこう /排気口/
はいきしき /排気式/
はいきしゅ /肺気腫/
はいきしょぶん /廃棄処分/
はいきたいさく /排気対策/
はいきていこう /排気抵抗/
はいきねつ /排気熱/
はいきのう /肺機能/
はいきひよう /廃棄費用/
はいきぶつ /廃棄物/
はいきぶつしょり /廃棄物処理/
はいきぶつしょりほう /廃棄物処理法;[法][略語]廃棄物の処理および清掃に関する法律/
はいきぶつはつでん /廃棄物発電/
はいきべん /排気弁/
はいきみゃくどう /排気脈動/
はいきゃく /廃却/
はいきゅう /配給/配球/排球/廃休/
はいきゅうがいしゃ /配給会社/
はいきゅうけん /配給権/
はいきゅうちゅう /肺吸虫/
はいきゅうまい /配給米/
はいきゅうもう /配給網/
はいきゅうりょく /配給力/
はいきょ /廃墟/廃虚/
はいきょう /背教/俳協/
はいきょく /廃局/廃曲/
はいきりょう /排気量/
はいきりょうへんこう /排気量変更/
はいきん /背筋/配筋;[建築]「RCの-」/拝金/
はいきんしゅぎ /拝金主義/
はいきんりょく /背筋力/
はいぎょ /肺魚/
はいぎょう /廃業/
はいく /俳句/
はいくつ /背屈/
はいぐ /拝具/
はいぐう /配偶/
はいぐうし /配偶子/
はいぐうしゃ /配偶者/
はいぐうしゃこうじょ /配偶者控除/
はいぐうしゃせんたく /配偶者選択/
はいぐうしゃてあて /配偶者手当/
はいぐうしゃとくべつこうじょ /配偶者特別控除/
はいぐうしゃわりびき /配偶者割引/
はいぐうたい /配偶体/
はいぐすり /灰釉/
はいぐん /敗軍/
はいけい /背景/拝啓/拝敬/
はいけいおん /背景音/
はいけいが /背景画/
はいけいがぞう /背景画像/
はいけいこう /背景光/
はいけいざつおん /背景雑音/
はいけいしょく /背景色/
はいけいせい /胚形成/
はいけいせかい /背景世界/
はいけいせってい /背景設定/
はいけいちしき /背景知識/
はいけいちょうさ /背景調査/
はいけいふくしゃ /背景輻射/
はいけいほうしゃ /背景放射/
はいけっかく /肺結核/
はいけつしょう /敗血症/
はいけん /拝見/佩剣/
はいげき /排撃/
はいこう /廃校/配向/配光/廃坑/廃鉱/背向/
はいこうじょう /廃工場/
はいこうせい /配光性/
はいこうとくせい /配光特性/
はいこきゅう /肺呼吸/
はいご /背後/廃語/
はいごう /配合/廃合/俳号/
はいごうひりょう /配合肥料;[農業]compound manure/
はいごかんけい /背後関係/
はいごれい /背後霊/
はいさ /排砂/
はいさつ /拝察/廃札/
はいざい /廃材/配剤/
はいざら /灰皿/
はいざん /敗残/廃山/廃残/
はいざんへい /敗残兵/
はいし /廃止/敗死/廃市/胚子/稗史;稗史小説/廃址/
はいしあん /廃止案/
はいしえき /廃止駅/
はいしけってい /廃止決定/
はいしご /廃止後/
はいししんせい /廃止申請/
はいしせん /廃止線/
はいしちょくぜん /廃止直前/
はいしつ /肺疾/廃疾/癈疾;=廃疾/
はいしび /廃止日/
はいしもんだい /廃止問題/
はいしゃ /歯医者/敗者/廃車/配車/背斜;[地質]anticline/拝謝/
はいしゃく /拝借/
はいしゃしゃりょう /廃車車両/
はいしゃしょう /廃車証/
はいしゃしょうめいしょ /廃車証明書/
はいしゃたい /廃車体/
はいしゃちょくぜん /廃車直前/
はいしゃび /廃車日/
はいしゃふっかつ /敗者復活/
はいしゅ /胚珠/
はいしゅつ /排出;discharge/輩出;優れた人材が連続して出現する/
はいしゅつきじゅん /排出基準/
はいしゅつけん /排出権;CO2-/
はいしゅつりょう /排出量/
はいしょ /配所/俳書/肺書/
はいしょう /廃娼/拝承/敗将/
はいしょうき /排障器/
はいしょく /配色;colouring/配食/敗色;-濃厚/憊色;疲れた様子/
はいしょくのうこう /敗色濃厚/
はいしん /配信/背信;†betray/背進;†前を向いたまま後ずさる/
はいしんこうい /背信行為/
はいしんさき /配信先/
はいしんじゅん /肺浸潤/
はいしんていし /配信停止/
はいしんもと /配信元/
はいじ /廃寺/拝辞/
はいじく /胚軸/
はいじつせい /背日性/
はいじま /拝島/
はいじまえき /拝島駅/
はいじまかん /拝島間/
はいじません /拝島線/
はいじゅ /拝受/
はいじゅくれい /廃塾令/
はいじゅんかん /肺循環/
はいじょ /排除;remove/廃除;abolish/
はいじょう /廃城/
はいじょうみゃく /肺静脈/
はいじょかんこく /排除勧告/
はいじょのうりょく /排除能力/
はいじょめいれい /排除命令/
はいじょろん /排除論/
はいじん /廃人/俳人/配陣/癈人;別字/拝塵/
はいじんどうよう /廃人同様/
はいすい /排水;†drainwater.「家庭-」/廃水;†wastewater.「放射性-」/配水;†water distribution.「-設備」/背水;-の陣/
はいすいかん /配水管/排水管/
はいすいき /排水機/
はいすいこう /排水溝;道路脇の-/排水口;洗面台の-/
はいすいこうか /排水効果/
はいすいこうよう /排水口用/
はいすいしせつ /排水施設/
はいすいしゅ /肺水腫/
はいすいしょり /排水処理/
はいすいせい /排水性/
はいすいせいのう /排水性能/
はいすいせつび /排水設備/
はいすいそう /排水槽/
はいすいのうりょく /排水能力/
はいすいのじん /背水の陣/背水乃陣/
はいすいよう /排水用/
はいすいりょう /排水量/
はいすいろ /排水路/
はいせい /俳聖/敗勢/廃星/
はいせいかんさいぼう /胚性幹細胞;[生物]embryo-stem cell (ES cell)/
はいせいしん /肺性心/
はいせき /排斥/廃石/俳席/
はいせつ /排泄/排雪;雪を取り除ける/
はいせつき /排泄器;[生物]excretory organ/
はいせつぶつ /排泄物/
はいせん /配線/敗戦/廃線/廃船/配船/肺尖/敗線;[囲碁]/
はいせんあと /廃線跡/
はいせんいしょう /肺線維症/
はいせんぎょうしゃ /配線業者/
はいせんこうじ /配線工事/
はいせんこく /敗戦国/
はいせんご /敗戦後/
はいせんざいりょう /配線材料/
はいせんしき /廃線敷/
はいせんしょり /敗戦処理/
はいせんしようりょう /配線使用料/
はいせんじ /敗戦時/
はいせんすう /敗戦数/
はいせんず /配線図/
はいせんずしゅう /配線図集/
はいせんせつだん /配線切断/
はいせんちょう /配線長/
はいせんとうしゅ /敗戦投手;⇔勝利投手/
はいせんまえ /敗戦前/
はいぜつ /廃絶/
はいぜん /配膳/沛然/
はいぜんしつ /配膳室/
はいそ /敗訴/
はいそう /配送/敗走/背走/
はいそうきのう /配送機能/
はいそうけい /配送系/
はいそうけいろ /配送経路/
はいそうさき /配送先/
はいそうしょり /配送処理/
はいそうてすうりょう /配送手数料/
はいそうひ /配送費/
はいそうほう /廃掃法;[法][略語]廃棄物の処理および清掃に関する法律/
はいそうほうほう /配送方法/
はいそうよう /配送用/
はいそうりょう /配送料/配送量/
はいそく /背側/背足/
はいそくせん /肺塞栓/
はいそん /廃村/
はいぞう /肺臓/
はいぞく /配属/
はいた /排他/歯痛/
はいたい /敗退/胚胎/廃退/廃頽/佩帯/
はいたいし /廃太子/
はいたか /鷂/
はいたしゅぎ /排他主義/
はいたせいぎょ /排他制御/
はいたつ /配達/
はいたついん /配達員/
はいたつきろく /配達記録/
はいたつしゃ /配達者/
はいたつしょうめい /配達証明/
はいたつじ /配達時/
はいたつじかん /配達時間/
はいたつじこ /配達事故/
はいたつにん /配達人/
はいたつび /配達日/
はいたつほうほう /配達方法/
はいたつまえ /配達前/
はいたてき /排他的/
はいたてきけいざいすいいき /排他的経済水域/
はいたてきろんりわ /排他的論理和/
はいだ /灰田/
はいだん /俳壇/
はいち /配置/廃置/背馳/
はいちがえ /配置替え/配置換/
はいちご /配置後/
はいちじょう /配置上/
はいちじょうきょう /配置状況/
はいちず /配置図/
はいちせい /背地性/
はいちてんかん /配置転換/
はいちもんだい /配置問題/
はいちゃく /廃嫡/敗着/
はいちやく /配置薬/
はいちゅうりつ /排中律/
はいちょう /拝聴/
はいちょうきん /腓腸筋/
はいつう /背痛/
はいてい /廃帝/拝呈/
はいていらおゆえ /海底撈月/
はいてくかぶ /ハイテク株/
はいてん /配点/配転/
はいてんねがい /配転願/配転願い/
はいでん /配電/拝殿/
はいでんせん /配電線/
はいでんばこ /配電箱/
はいでんばん /配電盤/
はいと /廃都/
はいとう /配当/佩刀/
はいとうかぜい /配当課税/
はいとうきん /配当金/
はいとうこうじょ /配当控除/
はいとうしょとく /配当所得/
はいとうせいこう /配当性向/
はいとうそしき /配当組織/
はいとうたい /配糖体;[化学]glycoside/
はいとうぶん /配当分/
はいとうみつ /廃糖蜜/
はいとうりつ /配当率/
はいとうれい /廃刀令/
はいとく /背徳/悖徳/
はいとくしゃ /背徳者;immoraliste/
はいとくてき /背徳的/
はいどう /廃道/
はいどうみゃく /肺動脈/
はいどく /拝読/
はいにち /排日/
はいにゅう /胚乳/
はいにょう /排尿/
はいにょうこんなん /排尿困難/
はいにょうしょうがい /排尿障害/
はいにん /背任/
はいにんざい /背任罪/
はいねこ /灰猫/
はいねつ /排熱/廃熱/
はいのう /排膿/背嚢/胚嚢/
はいのうよう /肺膿瘍/
はいはい /這い這い;もう-するようになった/
はいはん /背反/廃藩/排反/背叛/悖反/
はいはんざい /背叛罪/
はいはんちけん /廃藩置県/
はいばら /榛原/生原/
はいばん /廃盤;-CD/廃番;-商品/廃版;-文書/胚盤;[生物]blastodisk/杯盤/
はいばんほう /胚盤胞/
はいばんろうぜき /杯盤狼藉/
はいぱい /配牌/
はいひん /廃品/廢品;「廃」旧字/
はいひんかいしゅう /廃品回収/
はいび /配備/拝眉/
はいびょう /肺病/
はいびん /配便/
はいふ /配布;†広く配付する。「アプリケーションの-」/配付;†「資料の-」/配賦;割り当てる/肺腑/
はいふう /俳風/誹風/
はいふうやなぎだる /誹風柳多留/
はいふかのう /配布可能/
はいふき /灰吹/灰吹き/
はいふきてい /配布規定/
はいふきや /灰吹屋/
はいふきんし /配布禁止/
はいふく /拝復;†返信用の挨拶語/拝伏;†ひれ伏し拝む。「阿弥陀像に-する」/
はいふけいたい /配布形態/
はいふさき /配布先/
はいふしゃ /配布者/
はいふしゅだん /配布手段/
はいふしりょう /配布資料/
はいふじ /配布時/
はいふじき /配布時期/
はいふじゆう /配布自由/
はいふじょうけん /配布条件/配付条件/
はいふせいげん /配布制限/
はいふちゅうし /配布中止/配付中止/
はいふてすうりょう /配布手数料/
はいふはんい /配布範囲/
はいふばしょ /配布場所/
はいふばん /配付版/
はいふひん /配布品/
はいふぶつ /配布物/
はいふぶん /配布分/
はいふほうほう /配布方法/
はいふもと /配布元/
はいふよう /配布用/
はいふよていび /配布予定日/
はいふん /‐;hyphen/―;dash/
はいぶ /背部/廃部;部員が辞めていって遂に-になってしまった。/拝舞/
はいぶつ /廃物/廃仏/
はいぶつきしゃく /廃仏毀釈;明治時代の仏教排斥運動/排仏棄釈;明治時代の仏教排斥運動/廃仏棄釈/排仏毀釈/
はいぶつきょう /拝物教/
はいぶつりよう /廃物利用/
はいぶりっどしゃ /ハイブリッド車/
はいぶん /配分/俳文/拝聞/
はいぶんがく /配分額/
はいぶんしゃ /配分者/
はいぶんひょう /配分表/
はいぶんほうほう /配分方法/
はいへい /敗兵/
はいべん /排便/
はいぺすと /肺ペスト/
はいほう /肺胞/敗報/
はいほん /配本/
はいぼう /敗亡/
はいぼく /敗北/
はいぼくしゃ /敗北者/
はいぼくしゅぎ /敗北主義/
はいぼくせんげん /敗北宣言/
はいまつ /這松/
はいみ /俳味/
はいみょう /俳名/
はいめ /敗目/
はいめい /拝命/俳名/
はいめつ /廃滅/
はいめん /背面/
はいめんひこう /背面飛行/
はいもん /肺門/
はいや /肺野/灰屋/
はいやく /配役/背約/
はいやぶし /はいや節;[民謡]牛深-/
はいゆ /廃油/
はいゆう /俳優/俳友/
はいゆうざ /俳優座/
はいゆうたち /俳優達/
はいよう /廃用;out of use.「-牛」/肺葉;[解剖]lung lobe/胚葉;[生物]germ layer/佩用;wear.「勲章を-する」/
はいようぎゅう /廃用牛/
はいようしょうこうぐん /廃用症候群/
はいらる /海拉爾/
はいらん /排卵/
はいらんび /排卵日/
はいらんゆうはつ /排卵誘発;[医](不妊治療)/
はいらんゆうはつざい /排卵誘発剤/
はいり /背理/背離/
はいりくち /入り口/
はいりぐち /入り口/
はいりつ /廃立/
はいりほう /背理法/
はいりゅう /配流/
はいりょ /配慮/
はいりょう /拝領/
はいる /配流/
はいれい /拝礼/
はいれつ /配列/排列;≒配列/
はいれつけい /配列型/
はいれつけいさん /配列計算/
はいれつすう /配列数/
はいれつぜんたい /配列全体/
はいれつない /配列内/
はいれつひょうじ /配列表示/
はいれつへんすう /配列変数/
はいれつめい /配列名/
はいれつりょういき /配列領域/
はいろ /葉色/廃炉/羽色/
はいろう /肺癆/肺労;結核/
はいろん /俳論/
はいわ /俳話/
はうすさいばい /ハウス栽培/
はうた /端唄/端歌/
はうたもの /端歌物/
はうちわ /羽団扇/
はうら /葉裏/
はえ /蠅/蝿;異体字/南風/生え/
はえぎわ /生え際/
はえざ /蝿座;Musca(Mus)/蠅座;Musca(Mus)/
はえたたき /蠅叩き/ハエ叩き/
はえとり /蝿取り/
はえなわ /延縄/
はえぬき /生え抜き/
はえばる /南風原/
はおう /覇王/
はおうじゅ /覇王樹/
はおうでん /覇王伝/
はおく /破屋/
はおと /羽音/
はおり /羽織/
はおんきごう /ハ音記号/
はか /墓/破瓜/量/計/捗/果/
はかあな /墓穴/
はかい /破壊/破戒;戒律を破る/破潰;破壊・潰滅/
はかいかつどう /破壊活動/
はかいかつどうぼうしほう /破壊活動防止法;破防法/
はかいけんさ /破壊検査/
はかいこうい /破壊行為/
はかいこうさく /破壊工作/
はかいこうどう /破壊行動/
はかいご /破壊後/
はかいし /墓石/破壊子/
はかいしゃ /破壊者/
はかいしん /破壊神/
はかいそう /破戒僧/
はかいてき /破壊的/
はかいど /破壊度/
はかいむざん /破戒無慙/
はかいもくひょう /破壊目標/
はかいりつ /破壊率/
はかいりょく /破壊力/
はかき /破瓜期/
はかく /破格/
はかくね /破格値/
はかげ /葉陰/葉影/
はかしょ /墓所/
はかじるし /墓標/
はかず /葉数/
はかせ /博士/
はかせかてい /博士課程/
はかせかていこうき /博士課程後期/
はかせかていぜんき /博士課程前期/
はかせがくいろんぶん /博士学位論文/
はかせけ /博士家/
はかせけてん /博士家点/
はかせこうきかてい /博士後期課程/
はかせごう /博士号/
はかせぜんきかてい /博士前期課程/
はかせろんぶん /博士論文/
はかぜ /葉風/羽風/
はかた /博多/伯方/
はかたいがい /博多以外/
はかたえき /博多駅/
はかたえきこうつう /博多駅交通/
はかたおり /博多織/
はかたかん /博多間/
はかたく /博多区/
はかたっこ /博多っ子/
はかたにんぎょう /博多人形/
はかたのつ /博多津;地名/
はかたはく /博多泊/
はかたはつ /博多発/
はかたびん /博多便/
はかたふう /博多風/
はかたぶし /博多節;[民謡]/
はかたべん /博多弁/
はかたほうめん /博多方面/
はかたみなみ /博多南/
はかたみなみえき /博多南駅/
はかたわん /博多湾/
はかば /墓場/
はかびょう /破瓜病;hebephrenia/
はかぶ /端株/
はかほり /墓掘り/
はかま /袴/
はかまいり /墓参り/
はかますがた /袴姿/
はかまだ /袴田/
はかむら /墓村/
はかもり /墓守/
はからい /計らい/
はからずも /図らずも/
はかり /秤/量り/計り/
はかりうり /量り売り/
はかりきり /量り切り/
はかりごと /謀/
はかりざら /秤皿/
はかりめ /秤目/
はが /芳賀/羽賀/波賀/
はがい /羽交い/
はがいじめ /羽交い締め/羽交い絞め/羽交締め/
はがえ /羽替え/
はがき /葉書/葉書き/端書/
はがくれ /葉隠/葉隠れ/
はがぐん /芳賀郡/
はがしょてん /芳賀書店/
はがた /歯型/歯形/
はがため /歯固め/
はがね /鋼/刃金/
はがねいもの /鋼鋳物;steel casting(SC)/
はがま /羽釜/歯釜/
はがみ /歯噛み/
はがわ /羽川/
はがん /破顔/
はがんいっしょう /破顔一笑/
はき /破棄/覇気/破毀/杷木;地名/
はきいそう /破棄移送/
はきくだし /吐き下し/
はきけ /吐き気/嘔気/吐気/
はきさしもどし /破棄差戻し/破棄差し戻し/
はきじはん /破棄自判/
はきそうじ /掃き掃除/
はきだし /掃き出し/掃出し/
はきだしまど /掃出し窓/掃き出し窓/
はきだめ /掃き溜め/
はきもの /履物/
はきゃく /破却;壊すこと/
はきゅう /波及/
はきゅうこうか /波及効果/
はきょう /破鏡;離婚/
はきょく /破局/
はきょくすんぜん /破局寸前/
はぎ /萩/脛/矧/
はぎお /萩尾/
はぎしり /歯軋り/
はぎた /萩田/
はぎたに /萩谷/
はぎの /萩野/
はぎのつき /萩の月/
はぎのまち /萩野町/
はぎはら /萩原/
はぎひら /萩平/
はぎまつり /萩まつり/
はぎもと /萩本/
はぎもときんいち /萩本欽一/
はぎもり /萩森/
はぎや /萩谷/
はぎやき /萩焼/
はぎょう /ハ行/は行/覇業/
はぎょうてんこおん /ハ行転呼音;[国語学]eg.かは→kawa/
はぎり /歯切り/
はぎれ /歯切れ/端切れ/歯切/
はぎわら /萩原/
はぎわらさくたろう /萩原朔太郎;(1886-1942)詩人。『青猫』『月に吠える』/
はく /箔;金箔/拍;脈拍/白/泊;宿泊/伯;画伯/薄;薄情/博;博覧会/剥;剥奪/迫;迫力/舶;船舶/粕;酒粕/柏;かしわ/珀;琥珀/狛;狛犬/佰/岶/陌/魄;落魄/帛;布帛/亳/愽;「博」の旧字/搏;脈搏/擘/蘗/璞;あらたま/膊;上膊/栢;「柏」の異体字/
はくあ /白亜/白堊;=白亜/
はくあい /博愛/
はくあいしゅぎ /博愛主義/
はくあき /白亜紀;[地質年代]Cretaceous. 14000-6500万年前/白堊紀/
はくい /白衣/羽咋;地名/伯夷;商周革命のころの孤竹国の公子/伯井/
はくいすがた /白衣姿/
はくいのてんし /白衣の天使/
はくいん /博引/
はくいんぼうしょう /博引旁証/
はくう /白雨/
はくうん /白雲/
はくうんも /白雲母/
はくえい /搏景/
はくえいぐん /白衛軍/
はくえん /白煙/
はくえんこう /白鉛鉱/
はくおう /白鴎/白鴬/
はくおし /箔押し/
はくかい /擘開/
はくが /博雅/
はくがい /迫害/
はくがいしゃ /迫害者/
はくがく /博学/
はくがくたさい /博学多才/
はくがん /白眼/
はくがんし /白眼視/
はくきょい /白居易;=白楽天/
はくぎ /博儀/
はくぎょ /白魚/
はくぎん /白銀/
はくぐう /薄遇/
はくぐん /白軍/
はくげい /白鯨/
はくげき /迫撃/搏撃/
はくげきほう /迫撃砲/
はくげんがく /博言学;philology/
はくごうしゅぎ /白豪主義/
はくさ /白砂/
はくさい /白菜/舶載/
はくさん /白山/
はくさんした /白山下/
はくし /博士/白紙/薄志/搏摯;手で捕える/
はくしいにん /白紙委任/
はくしいにんじょう /白紙委任状/
はくしかてい /博士課程/
はくしがくいろんぶん /博士学位論文/
はくしき /博識/
はくしごう /博士号/
はくしじゃっこう /薄志弱行/
はくしつ /白質/
はくしてっかい /白紙撤回/
はくしとうあん /白紙答案/
はくしま /白島/
はくしゃ /拍車/薄謝/白砂/
はくしゃく /伯爵/
はくしゃくふじん /伯爵夫人/
はくしゃせいしょう /白砂青松/
はくしゅ /拍手/
はくしゅう /白秋/伯州;伯耆/
はくしゅかっさい /拍手喝采/
はくしょ /白書/帛書/薄暑/
はくしょく /白色/
はくしょくか /白色化/
はくしょくこう /白色光/
はくしょくざつおん /白色雑音/
はくしょくじんしゅ /白色人種/
はくしょくてろ /白色テロ/
はくしょくわいせい /白色矮星/
はくしろんぶん /博士論文/
はくしん /迫真/白新/
はくしんせい /迫真性/
はくじ /白磁/白字/
はくじつ /白日/
はくじつむ /白日夢/
はくじゃ /白蛇/
はくじゃく /薄弱/
はくじゃくじ /薄弱児/
はくじゅ /白寿;99歳/
はくじょう /白状/薄情/白杖;視覚障害者の杖/
はくじょうもの /薄情者/
はくじん /白人/白刃/
はくじんおんがく /白人音楽/
はくじんけい /白人系/
はくじんしはい /白人支配/
はくじんしゅ /白人種/
はくじんせんよう /白人専用/
はくすい /白水/
はくすいしゃ /白水社;[出版社名]フランス関連。www.hakusuisha.co.jp/
はくすう /泊数;nights/拍数;beats/搏数;旧字/
はくすきのえ /白村江/
はくず /白図/
はくせい /剥製/
はくせき /白石/白皙;色白/
はくせつ /白雪/拍節/
はくせん /白線/白癬;[医]tinea/白扇/白戦;素手での戦闘/白銑;white iron/搏戦;格闘/
はくせんきん /白癬菌/
はくせんしゃ /白泉社;[出版社名]雑誌『花とゆめ』。www.hakusensha.co.jp/薄銭社;?/
はくぜん /白髯/
はくそ /歯屎/
はくそう /博捜/薄葬/
はくそんこう /白村江;地名,朝鮮半島の川. 「-の戦い」/
はくた /伯太/
はくたん /白炭/
はくだい /博大/
はくだく /白濁/
はくだくえき /白濁液/
はくだつ /剥奪/はく奪/剥脱;剥げ落ちる・剥ぎ落とす/
はくだん /白檀/
はくち /白地/白痴/泊地;harbour/白雉;年号(650-654)/
はくちず /白地図/
はくちび /白痴美/
はくちゅう /白昼/伯仲;実力-/
はくちゅうこう /白昼光/
はくちゅうどうどう /白昼堂々/
はくちゅうむ /白昼夢/
はくちゅうむてき /白昼夢的/
はくちょう /白鳥/白丁/
はくちょうこ /白鳥湖/
はくちょうごう /白鳥号/
はくちょうざ /白鳥座;Cygnus(Cyg)/
はくちょうだい /白鳥台/
はくちょうのうた /白鳥の歌/
はくちょうのみずうみ /白鳥の湖;Tchaikovsky/
はくつる /白鶴/
はくつるびじゅつかん /白鶴美術館/
はくてい /白丁/
はくてん /白点/
はくでい /白泥/
はくとう /白桃/白湯/白頭/白糖/搏闘/
はくとうゆ /白灯油/
はくど /白土;[園芸]white clay/
はくどう /拍動/白銅;nickel/白道;月の軌道/搏動;=拍動/
はくどうか /白銅貨/
はくないしょう /白内障/
はくねつ /白熱/
はくねつこう /白熱光/
はくねつとう /白熱灯/
はくはく /白々;明々―/
はくはつ /白髪/
はくはつちゅん /白發中/
はくはん /白飯/白斑/
はくば /白馬/
はくばい /白梅/
はくばえき /白馬駅/
はくばえきまえ /白馬駅前/
はくばのりくら /白馬乗鞍/
はくばほうめん /白馬方面/
はくばん /薄板/白板/
はくひょう /薄氷;-を履(ふ)む/白票/
はくひんかんげきじょう /博品館劇場/
はくび /白眉;蜀漢の馬良の通称。転じて優れたもの/
はくびしん /白鼻心/
はくびせん /伯備線/
はくびょう /白描/
はくふ /白布/伯父/帛布;絹と布/
はくふん /白粉/
はくぶつ /博物/
はくぶついん /博物院/
はくぶつかん /博物館/
はくぶつかんかいかん /博物館開館/
はくぶつかんどうぶつえん /博物館動物園/
はくぶつかんほう /博物館法/
はくぶつがく /博物学/
はくぶつし /博物誌/博物史/
はくぶん /博文/白文/博聞/
はくぶんやくれい /博文約礼/
はくへい /白兵/
はくへいせん /白兵戦/
はくへき /白壁/薄壁/
はくへん /薄片/剥片/
はくへんせっき /剥片石器/
はくほう /白鳳/
はくほうじだい /白鳳時代/
はくほうどう /博報堂/
はくほうぶんか /白鳳文化/
はくぼ /薄暮/
はくぼく /白墨/
はくま /白魔/
はくまい /白米/
はくまく /薄膜/白膜/
はくめ /拍目/
はくめい /薄命;美人-/薄明;twilight/
はくめん /白面/
はくめんか /薄面化/
はくや /白夜/箔屋/
はくゆん /学胤/
はくよう /白楊/伯洋/
はくようきゅう /白羊宮;[十二宮]おひつじ座(3.21-4.19)/
はくようけん /伯養軒/
はくようしゃ /白揚社;[出版社名]www.hakuyo-sha.co.jp/白洋舎;[企業名]クリーニング。www.hakuyosha.co.jp/
はくらい /舶来/
はくらいひん /舶来品/
はくらく /剥落/伯楽/白楽;地名/
はくらくてん /白楽天;唐の詩人/
はくらん /博覧/白藍/
はくらんかい /博覧会/
はくらんきょうき /博覧強記/
はくり /剥離/薄利/白痢/
はくりき /薄力/
はくりきこ /薄力粉/
はくりきこむぎこ /薄力小麦粉/
はくりこっせつ /剥離骨折/
はくりざい /剥離剤/
はくりたばい /薄利多売/
はくりゅう /白龍/白竜/
はくりょく /迫力/
はくりょくじゅうぶん /迫力充分/
はくりょくまんてん /迫力満点/
はくれんが /白煉瓦/
はくろ /白露;([二十四節気]9.8頃)/白鷺/
はくろう /白蝋/伯労;モズ/
はくろうびょう /白蝋病/
はくろく /白鹿/
はくろしあ /白ロシア;Belorussiya(ベラルーシ)/
はくろん /博論/
はくわ /白話/
はくわしょうせつ /白話小説/
はくわぶんがく /白話文学/
はぐ /爬具/
はぐき /歯茎/歯ぐき/齦/
はぐきおん /歯茎音;[音声学]alveolar/
はぐち /刃口/
はぐま /白熊;ヤクの尻尾の毛/
はぐるま /歯車/
はぐるましき /歯車式/
はぐるまひ /歯車比/
はぐれぐも /浮浪雲/
はぐろ /羽黒/歯黒/
はぐろさん /羽黒山;地名,山形/
はぐんせい /破軍星;Alkaid/
はけ /刷毛/捌け/
はけい /波形/
はけいかいせき /波形解析/
はけいぶんせき /波形分析/
はけいれい /波形例/
はけぐち /捌け口/はけ口/
はけめ /刷毛目/
はけん /派遣/覇権/
はけんあらそい /覇権争い/
はけんがいしゃ /派遣会社/
はけんぎょう /派遣業/
はけんさき /派遣先/
はけんしゃいん /派遣社員/
はけんしゅぎ /覇権主義/
はげ /禿/剥げ/破夏;[仏教]/
はげあたま /禿頭/ハゲ頭/
はげいとう /葉鶏頭;[植物]tampala/
はげたか /禿鷹/
はげまし /励まし/
はげみ /励み/
はげやま /禿山/
はげわし /禿鷲/
はげん /波源/
はこ /箱/函;(字義:物を包み込むハコ)「本の-」/匣;(字義:ぴったりと蓋のできるハコ)「パンドラの-」/筐;(字義:竹製の四角い籠)/筥;(字義:竹製の丸い籠)/箪;(字義:薄い竹で編んだ容器)/凾;「函」の異体字/葉子/□;記号の四角 →box/運;動詞語幹/
はこいり /箱入り/箱入/
はこいりむすめ /箱入り娘/
はこう /波高/跛行/破口/爬行/
はこうぶんぷ /波高分布/
はこえ /箱絵/
はこえふう /箱絵風/
はこかなもの /箱金物/
はこがい /箱買い/
はこがき /箱書き;美術品などの箱に書かれた題名や作者名など/箱書/
はこがた /箱型/
はこがまえ /匚構え;[部首]/
はこさきぐう /筥崎宮/
はこざき /箱崎/筥崎/
はこざきちょう /箱崎町/
はこした /箱下/
はこじゃく /箱尺/
はこだい /箱代/
はこだて /函館/
はこだてえき /函館駅/
はこだてきねん /函館記念/
はこだてけいばじょう /函館競馬場/
はこだてしがい /函館市街/
はこだてせん /函館線/
はこだてせんそう /箱館戦争;1868/
はこだてどっく /函館ドック/
はこだてほんせん /函館本線/
はこだてやま /函館山/
はこづけ /箱付/
はこづめ /箱詰め/箱詰/
はこにわ /箱庭/
はこにわりょうほう /箱庭療法/
はこね /箱根/
はこねえきでん /箱根駅伝/
はこねさんしょううお /箱根山椒魚/
はこねざいく /箱根細工/
はこねしんどう /箱根新道/
はこねじ /箱根路/
はこねとざん /箱根登山/
はこねとざんてつどう /箱根登山鉄道/
はこねはちり /箱根八里;-は馬でも越すが/
はこねほうめん /箱根方面/
はこねゆもと /箱根湯本/
はこねわん /箱根湾/
はこはんぶん /箱半分/
はこばしゃ /箱馬車/
はこひだ /箱襞;box pleat/
はこび /運び/
はこびや /運び屋;密輸の実行者/
はこぶね /箱舟/方舟/箱船/方船/
はこべ /繁縷;野草/
はこぼれ /刃毀れ/刃こぼれ/
はこまつ /筥松/
はこめがね /箱眼鏡/
はこもの /箱物/
はこものぎょうせい /箱物行政/
はこもり /箱守/
はこや /箱屋/
はこん /破婚/
はご /羽子/
はごいた /羽子板/
はごく /破獄/
はごし /葉越し/
はごたえ /歯応え/
はごろも /羽衣/
はさい /破砕/破摧/
はさいき /破砕機;grinder/
はさき /波崎/刃先/
はさこ /羽迫/
はさつおん /破擦音/
はさま /迫/挟間/
はさみ /鋏/螯/波佐見/
はさみあげ /挟み揚げ/はさみ揚げ/
はさみうち /挟み撃ち/挟み打ち/挾み撃ち;旧字/挾み打ち;旧字/
はさみしょうぎ /挟み将棋/
はさみつけ /挾み付け;旧字/
はさん /破産;bankruptcy/破算;ご-/
はさんかんざいにん /破産管財人/
はさんさいけん /破産債権/
はさんざいだん /破産財団/
はさんしゃ /破産者/
はさんすんぜん /破産寸前/
はさんせんこく /破産宣告/
はさんほう /破産法/
はざい /端材/
はざかい /端境/
はざかいき /端境期/
はざくら /葉桜/
はざし /葉挿し;[園芸]/
はざま /間/狭間/硲/羽佐間/羽間;姓/陌間/
はざまぐみ /間組/
はざわ /羽沢/
はざわり /歯触り;シャキシャキ/
はし /橋/端/箸/梯;梯子/觜;(くちばし)/枦;?/走;動詞語幹?/
はしい /端居/
はしいた /橋板/
はしうら /橋浦/
はしお /走尾/
はしおか /橋岡/
はしおき /箸置き/
はしか /麻疹/
はしかみ /階上/
はしかわ /橋川/
はしがかり /橋掛かり/橋掛り/橋懸り/橋懸かり/
はしがき /端書/端書き/
はしがみ /橋上/
はしがみえき /橋上駅/
はしくら /橋倉/
はしくれ /端くれ/
はしぐち /橋口/
はしけ /艀/
はしげた /橋桁/橋げた/
はしご /梯子/階子/梯/
はしござけ /梯子酒/はしご酒/
はしごしゃ /梯子車/はしご車/
はしごだん /梯子段/
はしずめ /橋爪;※仮名遣い「はしづめ」/
はしぞめ /箸初め/
はした /端/端た;-金/
はしたいろ /端色/
はしたか /鷂/
はしたがね /端金/端た金/
はしたて /箸立て/
はしたに /橋谷/
はしため /婢/婢女/端女/端た女/
はしだ /橋田/
はしだて /橋立/
はしっこ /端っこ/
はしづめ /橋爪/橋詰/橋詰め/
はしの /橋野/
はしのすけ /橋之助/
はしば /羽柴/
はしばこ /箸箱/
はしばし /端々/端端/
はしばひでよし /羽柴秀吉/
はしばみ /榛/
はしばん /橋番/
はしひめ /橋姫/
はしぶとがらす /嘴太鴉/
はしぶね /端舟;boat/
はしべんけい /橋弁慶;能・長唄。「京の五条の橋の上」/
はしぼそがらす /嘴細鴉/
はしま /羽島/
はしもと /橋本/
はしもとえき /橋本駅/
はしもとてん /橋本店/
はしもとびょう /橋本病;[医]/
はしもとりゅうたろう /橋本龍太郎/
はしもり /橋守/
はしゃ /覇者/
はしやすめ /箸休め/
はしゅ /播種/把手/
はしゅき /播種機/
はしゅつ /派出/
はしゅつしょ /派出所/
はしゅつじょ /派出所/
はしゅつふ /派出婦/
はしょうが /葉生姜/葉生薑/
はしょうふう /破傷風/
はしょうふうきん /破傷風菌;tetanus/
はしょく /波食/
はしら /柱/
はしらごよみ /柱暦/
はしらざい /柱材/
はしらたに /柱谷/
はしらどけい /柱時計/
はしらま /柱間;[建築]column span/
はしらわり /柱割/柱割り;[建築]柱の位置の決定/
はしり /走り/
はしりい /走井/
はしりかた /走り方/
はしりがき /走り書き/
はしりたかとび /走り高跳び;high-jump/
はしりづかい /走り使い/
はしりで /走り出/
はしりどころ /走野老/
はしりはばとび /走り幅跳び/
はしりや /走り屋/
はしりゆ /走り湯;温泉/
はしりよみ /走り読み/
はしわたし /橋渡し/
はじ /恥/端/把持/土師/耻;「恥」の異体字/黄櫨;[植物]wax tree. 木蝋が取れる/始;動詞語幹?/初;動詞語幹?/
はじいろ /黄櫨色/
はじかみ /椒/薑/
はじかみいお /椒魚/
はじき /土師器/
はじさらし /恥曝し/
はじしらず /恥知らず/
はじとみ /半蔀/
はじま /羽島/
はじまり /始まり/
はじめ /始め/初め/一/元/初/始/創/肇/壱/哉/馨/甫/弌/壹/
はじめて /初めて/
はじめね /始値/始め値/
はじめまして /初めまして/始めまして/
はじゃ /覇者;はしゃ?/破邪/
はじゃけんしょう /破邪顕正/
はじょ /葉序/
はじょう /波状/
はじょううん /波状雲/
はじょうこうげき /波状攻撃/
はじょうねつ /波状熱;[医]undulant fever/
はじょうろ /波状路/
はじらい /羞じらい/
はじろ /羽白/
はす /蓮/斜/
はすい /破水/
はすいけ /蓮池/
はすいも /白芋/蓮芋/
はすう /端数;fraction.「-切捨」/波数;[物理]wavenumber/羽数;鳥の-/歯数/
はすうしょり /端数処理/
はすか /ハス科/Nelumbonaceae/
はすかい /斜交い/
はすきーけん /ハスキー犬/
はすこ /蓮子/
はすだ /蓮田/
はすっぱ /蓮葉/蓮っ葉/
はすぬま /蓮沼/
はすぬまちょう /蓮沼町/
はすね /蓮根/
はすのはぎりか /ハスノハギリ科/Hernandiaceae/
はすのみ /蓮の実/
はすみ /蓮見/蓮實/羽須美/羽角/羽純/
はすむかい /斜向かい/はす向かい/斜向い/
はず /筈/弭/巴豆/
はずい /筈井/
はずえ /葉末/
はずかしめ /辱め/
はずまき /筈巻/弭巻/
はずみぐるま /弾み車/
はずれ /外れ/葉擦れ/外/
はせ /長谷/馳/
はせい /派生/長谷井/
はせいきそく /派生規則/
はせいけい /派生型/
はせいげん /派生源/
はせいご /派生語/
はせいてき /派生的/
はせいぶつ /派生物/
はせがわ /長谷川/
はせがわこうむてん /長谷川工務店/
はせがわとうはく /長谷川等伯/
はせがわまちこ /長谷川町子;(1920-92) 漫画家。『サザエさん』/
はせくら /支倉/
はせべ /長谷部/
はせみ /長谷見/
はせん /破線;― ― ―/波線;〜〜〜/破船;難破船/
はせんぶ /波線部/
はぜ /櫨/鯊/黄櫨/枦;「櫨」の異体字/蝦虎魚/沙魚/
はぜのき /櫨の木/櫨/黄櫨/
はそく /波束/把捉/
はそん /破損/
はそんじこ /破損事故/
はそんりつ /破損率/
はた /旗/傍;かたわら/端;≒傍/側;物のフチ/機;-織/畑/畠/圃/幡;(垂れ下げる旗)/将;副詞/秦;人名/羽田/幡多/波多/波田/籏;「旗」の異体字/旛;≒幡/旙;「旛」の異体字/幟;のぼり/旌/
はたあげ /旗揚げ/旗揚/
はたい /波帯/
はたいけ /幡池/
はたいも /畑芋/
はたいろ /旗色/
はたうえ /畑上/
はたうち /畑打ち/
はたえ /波多江/二十重/
はたおか /畑岡/
はたおり /機織り/機織/旗折/
はたがしら /旗頭/
はたがや /幡ヶ谷/
はたきこみ /叩き込み/
はたぎょうれつ /旗行列/
はたぐも /旗雲/
はたけ /畑/畠;(国字) =畑/疥;(皮膚の)scab/
はたけいも /畑芋/
はたけしごと /畑仕事/
はたけちがい /畑違い/
はたけなか /畠中/
はたけやま /畠山/畑山/
はたご /旅籠/
はたごや /旅籠屋/
はたさ /畑佐/
はたさく /畑作/
はたさしもの /旗指物/
はたざお /旗竿/
はたざき /畑崎/
はたしあい /果たし合い/果し合い/
はたしじょう /果たし状/果し状/
はたした /旗下/
はたして /果たして/果して/
はたしょう /秦荘/
はたじるし /旗印/旗標/
はたたて /旗立/
はただ /畑田/畠田/
はたち /二十/畑地/二十歳/２０歳/廿/
はたて /旗手/
はたとせ /二十歳/
はたなか /畑中/畠中/畑仲/
はたの /波多野/畑野/秦野/幡野/羽田野/籏野/
はたのう /畑農/
はたのえき /秦野駅/
はたのえきまえ /秦野駅前/
はたのし /秦野市/
はたのだい /旗の台/
はたはた /鰰/
はたば /機場/
はたばこ /葉タバコ;leaf tobacco/葉煙草/葉たばこ/
はたび /旗日/
はたふり /旗振り/
はたふりやく /旗振り役/
はたぶ /幡生/
はたむら /畑村/
はため /傍目/はた目/
はためいわく /傍迷惑/
はたもち /旗持/
はたもと /旗本/畑本/播本/
はたもとやっこ /旗本奴/
はたや /機屋/畑谷/
はたやま /畑山/畠山/
はたら /働/
はたらき /働き/
はたらきあり /働き蟻/
はたらきかけ /働き掛け/
はたらきがい /働き甲斐/
はたらきぐち /働き口/
はたらきざかり /働き盛り/
はたらきづめ /働き詰め/
はたらきて /働き手/
はたらきばち /働き蜂/
はたらきもの /働き者/
はたん /破綻/
はたんきょう /巴旦杏/
はたんちょう /ハ短調/
はだ /肌/膚/羽田/
はだあい /肌合い/肌合/
はだあれ /肌荒れ/肌あれ/肌荒/膚荒れ/
はだいろ /肌色/
はだか /裸/
はだかいっかん /裸一貫/
はだかうま /裸馬/
はだかおどり /裸踊り/
はだかぎ /裸木/
はだかけ /肌掛け/
はだかそうば /裸相場/
はだかてがた /裸手形/
はだかでんきゅう /裸電球/
はだかび /裸火/
はだかまつり /裸祭り/裸祭/
はだかみ /裸身/
はだかむぎ /裸麦/
はだかやま /裸山/
はだかんぼう /裸ん坊;やだ、今-なのよ/
はだぎ /肌着/
はださむ /肌寒/
はだざわり /肌触り/膚触り/
はだし /裸足/跣/
はだしつ /肌質;skin type. 「月面のような-」/
はだじゅばん /肌襦袢/
はだつけ /肌付け/
はだの /秦野/
はだぶとん /肌布団/
はだみ /肌身/
はだん /破断/破談/
はち /鉢/八/蜂/８/捌/椀/
はち> /八/
はちあげ /鉢上げ/
はちあわせ /鉢合わせ/鉢合せ/
はちうえ /鉢植え/鉢植/
はちおうじ /八王子/
はちおうじかん /八王子間/
はちおうじがわ /八王子側/
はちおうじこうこう /八王子高校/
はちおうじし /八王子市/
はちおうじじっせん /八王子実践/
はちおうじじっせんこうこう /八王子実践高校/
はちおうじせん /八王子線/
はちおうじほうめん /八王子方面/
はちおうじりょうきんじょ /八王子料金所/
はちかい /八開/
はちがつ /八月/８月/8月/葉月;※連想,旧暦/
はちく /破竹;-の勢い/淡竹;=呉竹/
はちけん /八軒/
はちけんや /八軒屋/
はちげんすう /八元数/
はちこう /ハチ公/
はちこうだい /八工大/
はちごうめ /八合目/
はちざかな /鉢肴/
はちしょうじん /八将神/
はちじ /八時/
はちじゅう /八十/
はちじゅうそう /八重奏/
はちじゅうにぎんこう /八十二銀行/
はちじゅうはちや /八十八夜/
はちじゅうはっかしょ /八十八箇所/
はちじょう /八条/八丈/鉢状/
はちじょうぐち /八条口/
はちじょうじま /八丈島/
はちす /蜂巣/蓮/
はちすおり /蜂巣織/
はちすか /蜂須賀/
はちぞこ /鉢底/
はちだいしゅう /八代集/
はちだいじごく /八大地獄/
はちど /八度/
はちにん /八人/
はちねん /八年/
はちねんいじょう /八年以上/
はちのこ /蜂の子;食材/
はちのじ /八の字/
はちのす /蜂の巣/
はちのへ /八戸/
はちのへこうぎょうだい /八戸工業大/
はちのへこうぎょうだいがく /八戸工業大学/
はちのへこうだいいち /八戸工大一/
はちのへせん /八戸線/
はちはちかんたい /八八艦隊/
はちばん /八番/
はちばんめ /八番目/
はちぶ /八分/八部/８分/
はちぶおんぷ /八分音符/８分音符/♪/
はちぶしゅう /八部衆;[仏教]/
はちぶせやま /鉢伏山/
はちぶんぎ /八分儀/
はちぶんぎざ /八分儀座;Octans(Oct)/
はちぶんめ /八分目/
はちべえ /八兵衛;うっかり―/
はちほん /八本/
はちほんまつ /八本松/
はちぼく /八木/
はちまい /八枚/
はちまき /鉢巻/鉢巻き/
はちまん /八幡/八万/
はちまんぐう /八幡宮/
はちまんざ /八幡座/
はちまんじんじゃ /八幡神社/
はちまんたい /八幡平/
はちまんだいぼさつ /八幡大菩薩/
はちまんづくり /八幡造り;[建築]/八幡造;[建築]/
はちまんまち /八幡町/
はちまんやま /八幡山/
はちみつ /蜂蜜/
はちみり /八ミリ/
はちめん /八面/
はちめんたい /八面体/
はちめんれいろう /八面玲瓏/
はちめんろっぴ /八面六臂/
はちもの /鉢物/
はちもり /八森/
はちもんじ /八文字/
はちゃ /葉茶;leaf tea/
はちや /蜂屋/八谷/鉢谷/
はちゅう /爬虫/
はちゅうるい /爬虫類/爬蟲類/
はちょう /波長/刃長/ハ調/破調/
はちょういぞんせい /波長依存性/
はちょうごと /波長毎/
はちょうせいぶん /波長成分/
はちょうちょう /ハ長調/
はちりゅう /八竜/
はちろ /八路/
はちろう /八郎/
はちろうがた /八郎潟/
はちろぐん /八路軍/
はちわり /八割/
はぢゃ /葉茶;leaf tea/
はぢゃや /葉茶屋;茶葉を販売する/
はっ /発/法/發;「発」の旧字/
はっか /発火/薄荷/白化/客家;漢民族の一派/
はっかい /発会/八戒/白海/
はっかいさん /八海山/
はっかいしき /発会式/
はっかく /発覚/八角/
はっかくけい /八角形/
はっかくとうしょ /発覚当初/
はっかけ /八掛/歯っ欠け/
はっかせい /発火性/
はっかせき /発火石/
はっかち /発火値/
はっかてん /発火点/
はっかひんど /発火頻度/
はっかゆ /薄荷油/
はっかりつ /発火率/
はっかん /発刊;issue/発汗;perspire/発艦/
はっかんび /発刊日/
はっき /発揮/発起;=ほっき/白旗/発輝;?/
はっきゅう /発給;issue/白球/薄給;low salary/
はっきょう /発狂/
はっきょうし /発狂死/
はっきょうすんぜん /発狂寸前/
はっきん /発禁/白金/白筋;white muscle/Pt/Platinum/
はっきんしょぶん /発禁処分/
はっく /八苦/発句/八九;72/
はっくつ /発掘/
はっくつけっか /発掘結果/
はっくつちょうさ /発掘調査/
はっくつばんぐみ /発掘番組/
はっけ /八卦/
はっけい /八景/発勁/
はっけいおき /八景沖/
はっけいじま /八景島/
はっけっきゅう /白血球/
はっけつびょう /白血病/
はっけみ /八卦見/
はっけん /発見/発券;issue/白鍵/発遣;dispatch.「特使の-」/
はっけんいこう /発見以降/
はっけんいち /発見位置/
はっけんかがく /発見科学/
はっけんがくしゅう /発見学習/
はっけんしゃ /発見者/
はっけんじこく /発見時刻/発券時刻/
はっけんてき /発見的/
はっけんてきがくしゅう /発見的学習/
はっけんでん /八犬伝/
はっけんねん /発見年/
はっけんばん /白鍵盤/
はっけんほうほう /発見方法/発券方法/
はっこ /発呼/
はっこう /発行;†issue.「チケットの-」/発酵;ferment/発光;†emit light/発効;†take effect.「条約の-」/醗酵;=発酵/薄幸/白光/八紘;-一宇/発航/八講/発向/薄倖;ill-starred. 「-の少女」/
はっこういちう /八紘一宇/
はっこうかかく /発行価格/
はっこうかがく /発行価額/
はっこうがいしゃ /発行会社/
はっこうき /発行機/
はっこうきかん /発行機関/
はっこうしじょう /発行市場/
はっこうしゃ /発行者/
はっこうしゅ /発酵酒/
はっこうしゅう /発酵臭/
はっこうしゅうりょう /発酵終了/
はっこうしょ /発行所/
はっこうしょくひん /発酵食品/
はっこうじ /発行時/
はっこうじかん /発光時間/
はっこうじき /発行時期/
はっこうじぎょう /発行事業/
はっこうじゅみょう /発光寿命/
はっこうじょ /発行所/
はっこうじょうきょう /発行状況/
はっこうじょうたい /発酵状態/
はっこうすう /発行数/
はっこうずみ /発行済/発行済み/
はっこうずみかぶしき /発行済株式/
はっこうずみかぶしきすう /発行済株式数/
はっこうずみかぶしきそうすう /発行済株式総数/
はっこうせいぶつ /発光生物/
はっこうせん /八高線/
はっこうたい /発光体/
はっこうだ /八甲田/
はっこうだいおーど /発光ダイオード/
はっこうださん /八甲田山/
はっこうてすうりょう /発行手数料/
はっこうにん /発行人/
はっこうねつ /発酵熱/
はっこうねん /発行年/
はっこうねんがっぴ /発行年月日/
はっこうねんど /発行年度/
はっこうばんごう /発行番号/
はっこうび /発行日/発効日/
はっこうびぜんじつ /発行日前日/
はっこうびとりひき /発行日取引/
はっこうぶ /発光部/
はっこうぶすう /発行部数/
はっこうぶつ /発行物/
はっこうほうほう /発行方法/
はっこうまいすう /発行枚数/
はっこうもと /発行元/
はっこうよていび /発行予定日/
はっこうりょう /発光量/発行量/
はっこつ /白骨/
はっこつか /白骨化/
はっこつしたい /白骨死体/
はっこよう /発呼用/
はっこん /発根;rhizogenesis, taking root/
はっさい /髪際/八歳/
はっさく /八朔/
はっさむ /発寒/
はっさん /発散/
はっさんていり /発散定理/
はっしうむ /Hs/Hassium/
はっしゃ /発射/発車/
はっしゃおん /発射音/
はっしゃかくど /発射角度/
はっしゃかん /発射管/
はっしゃこう /発射口/
はっしゃご /発車後/
はっしゃじ /発射時/発車時/
はっしゃじかん /発車時間/
はっしゃじこく /発車時刻/
はっしゃじこくひょう /発車時刻表/
はっしゃそうち /発射装置/
はっしゃだい /発射台/
はっしゃちょくぜん /発車直前/
はっしゃばんせん /発車番線/
はっしゃび /発車日/
はっしゃほうこう /発射方向/
はっしゃまえ /発車前/
はっしゅう /八宗/
はっしゅうけんがく /八宗兼学/
はっしゅち /ハッシュ値/
はっしゅつ /発出/
はっしゅひょう /ハッシュ表/
はっしょう /発祥/発症/八章/八省/発消/
はっしょういも /八升芋/
はっしょういん /八省院;朝堂院/
はっしょうご /発症後/
はっしょうじん /八将神;[陰陽道]/
はっしょうち /発祥地/
はっしょうどう /八正道/
はっしょうねんれい /発症年齢/
はっしょうまえ /発症前/
はっしょく /発色/
はっしょくげんしょう /発色現象/
はっしょくざい /発色剤/
はっしょくすう /発色数/
はっしょくせい /発色性/
はっしょくだん /発色団;chromophore/
はっしょくとくせい /発色特性/
はっしん /発信;send.「メールの-」/発進;start.「車の-」/発疹;rash/発振;oscillation/八神/発震;quake/
はっしんおん /発信音/発振音/
はっしんかいろ /発振回路/
はっしんかそく /発進加速/
はっしんがわ /発信側/
はっしんき /発振器/発信機/発信器/発振機/
はっしんきょく /発信局/
はっしんげん /発信源/
はっしんさき /発信先/
はっしんし /発振子/
はっしんしゃ /発信者/
はっしんじ /発進時;when starting/発信時;time of origin/発震時/
はっしんじこく /発信時刻/
はっしんせんよう /発信専用/
はっしんちゅう /発信中/
はっしんちょくご /発進直後/
はっしんていし /発進停止/
はっしんどうさ /発信動作/
はっしんにん /発信人/
はっしんび /発信日/
はっしんふのう /発進不能/
はっしんぶ /発信部/
はっしんほうしき /発振方式/
はっしんほうほう /発進方法/発振方法/
はっしんもと /発信元/
はっしんよう /発信用/
はっすい /撥水/
はっすいかこう /撥水加工/
はっすいざい /撥水剤/
はっすいせい /撥水性/
はっすん /八寸/
はっすんくぎ /八寸釘/
はっすんぜん /八寸膳/
はっせい /発生;generation/発声;vocalisation/八世/
はっせいえいが /発声映画/
はっせいかいすう /発生回数/
はっせいかいろ /発生回路/
はっせいかくりつ /発生確立/
はっせいかしょ /発生箇所/
はっせいかんかく /発生間隔/
はっせいがく /発生学/
はっせいき /発生器;generator/発生期;developing (stage)/
はっせいきかん /発声器官/
はっせいきげん /発生起源/
はっせいきこう /発声機構/
はっせいげん /発生源/
はっせいげんいん /発生原因/
はっせいご /発生後/
はっせいしゃ /発声者/
はっせいしゅぎ /発生主義/
はっせいじ /発生時/
はっせいじこく /発生時刻/
はっせいじゅん /発生順/
はっせいすう /発生数/
はっせいせいぶつがく /発生生物学;developmental biology/
はっせいてき /発生的/
はっせいてきていぎ /発生的定義/
はっせいてきにんしきろん /発生的認識論/
はっせいてん /発生点/
はっせいとうじ /発生当時/
はっせいないよう /発声内容/
はっせいねん /発生年/
はっせいねんがっぴ /発生年月日/
はっせいねんど /発生年度/
はっせいばしょ /発生場所/
はっせいひん /発生品/
はっせいひんど /発生頻度/
はっせいび /発生日/
はっせいぶんか /発生分化/
はっせいほう /発声法/発生法/
はっせいほうこう /発生方向/
はっせいもと /発生元/
はっせいよういん /発生要因/
はっせいりつ /発生率/
はっせいりゆう /発生理由/
はっせいりょう /発生量/
はっせいれんしゅう /発声練習/
はっせき /発赤/
はっせん /八仙/八千/
はっそう /発送;ship/発想;idea/発走;start/八相/八双/
はっそうき /発走機/
はっそうきごう /発想記号;[音楽]Moderate,cresc.など/
はっそうきぼう /発送希望/
はっそうぎょうむ /発送業務/
はっそうけい /発想系/
はっそうご /発送後/
はっそうさき /発送先/
はっそうしえん /発想支援/
はっそうしゃ /発送者/
はっそうしゅだん /発送手段/
はっそうしょり /発送処理/
はっそうじ /発送時/
はっそうじたい /発想自体/
はっそうじょがい /発走除外/
はっそうひ /発送費/
はっそうひょうご /発想標語/
はっそうふかのう /発送不可能/
はっそうぶつ /発送物/
はっそうほう /発想法/発送法;?/
はっそうほうほう /発想方法/
はっそうまえ /発走前/
はっそうよう /発送用/
はっそうよてい /発送予定/
はっそうりょう /発送料/
はっそうりょく /発想力/
はっそく /発足/八足/
はった /八田/
はったい /八体/
はったつ /発達/八達;四通-/
はったつしょうがい /発達障害/
はったつしんり /発達心理/
はったつしんりがく /発達心理学/
はったつしんりがくしゃ /発達心理学者/
はったつだんかい /発達段階/
はったつど /発達度/
はったん /発端/八反/八丹;姓/
はったんだ /八反田;姓/
はったんにしき /八反錦/
はっちゃく /発着/
はっちゃくしん /発着信/
はっちゃくじかん /発着時間/
はっちゃくじょ /発着所/
はっちゃくじょう /発着場/
はっちゃくすう /発着数/
はっちゃくち /発着地/
はっちゃくてん /発着点/
はっちゃくびん /発着便/
はっちゃくわく /発着枠/
はっちゅう /発注/八中/
はっちゅうがく /発注額/
はっちゅうしゃ /発注者/
はっちゅうじゅん /発注順/
はっちゅうずみ /発注済/
はっちゅうぬし /発注主/
はっちょう /八丁/
はっちょうぼり /八丁堀/
はっちょうみそ /八丁味噌/
はってん /発展/
はってんかてい /発展過程/
はってんかのうせい /発展可能性/
はってんき /発展期/
はってんけい /発展形/発展型/
はってんけいい /発展経緯/
はってんせい /発展性/
はってんだんかい /発展段階/
はってんてき /発展的/
はってんてきかいさん /発展的解散/
はってんてきかいしょう /発展的解消/
はってんとじょう /発展途上/
はってんとじょうこく /発展途上国/
はってんとじょうちゅう /発展途上中/
はってんとちゅう /発展途中/
はってんば /ハッテン場/
はってんほうこう /発展方向/
はってんもんだい /発展問題/
はっと /法度/
はっとう /法堂/八東/
はっとうしん /八頭身/八等身;?/
はっとがき /法度書/
はっとく /八徳/
はっとり /服部/
はっとりせいこー /服部セイコー/
はっとりとけいてん /服部時計店/
はっぱ /葉っぱ/発破/
はっぱく /八白/
はっぴ /法被/半被/
はっぴき /八匹/
はっぴゃく /八百/
はっぴゃくやちょう /八百八町/
はっぴょう /発表/
はっぴょういらい /発表以来/
はっぴょうかい /発表会/
はっぴょうかいし /発表開始/
はっぴょうがいよう /発表概要/
はっぴょうきじ /発表記事/
はっぴょうきぼうしゃ /発表希望者/
はっぴょうけいしき /発表形式/
はっぴょうけいたい /発表形態/
はっぴょうけんすう /発表件数/
はっぴょうこうえん /発表講演/
はっぴょうご /発表後/
はっぴょうさき /発表先/
はっぴょうしゃ /発表者/
はっぴょうしゃしめい /発表者氏名/
はっぴょうしゃぼしゅう /発表者募集/
はっぴょうしゃめい /発表者名/
はっぴょうしゅうりょう /発表終了/
はっぴょうしりょう /発表資料/
はっぴょうじ /発表時/
はっぴょうじかん /発表時間/
はっぴょうじき /発表時期/
はっぴょうじゅん /発表順/
はっぴょうずみ /発表済/
はっぴょうだいめい /発表題名/
はっぴょうだいもく /発表題目/
はっぴょうてんじかい /発表展示会/
はっぴょうとうしょ /発表当初/
はっぴょうとうじ /発表当時/
はっぴょうないよう /発表内容/
はっぴょうねん /発表年/
はっぴょうねんだい /発表年代/
はっぴょうばんごう /発表番号/
はっぴょうび /発表日/
はっぴょうぼしゅう /発表募集/
はっぴょうまえ /発表前/
はっぴょうもうしこみ /発表申込/
はっぴょうもうしこみさき /発表申込先/
はっぴょうもうしこみしめきり /発表申込締切/
はっぴょうようし /発表要旨/発表用紙/
はっぴょうよていしゃ /発表予定者/
はっぴょうれんしゅう /発表練習/
はっぴょうろんぶん /発表論文/
はっぷ /発布/髪膚/
はっぷん /発奮/発憤;≒発奮/
はっぺい /八平/
はっぽう /発泡;foaming/八方/発砲;fire/発疱;vesicate/
はっぽうえん /八芳園/
はっぽうおね /八方尾根/
はっぽうおん /発砲音/
はっぽうさい /八宝菜/
はっぽうざい /発泡剤/
はっぽうしゅ /発泡酒/
はっぽうじけん /発砲事件/
はっぽうすちろーる /発泡スチロール/
はっぽうせい /発泡性/
はっぽうせつ /発砲説/
はっぽうびじん /八方美人/
はっぽうびじんてき /八方美人的/
はっぽうふさがり /八方塞がり/
はっぽうもく /八方目/
はっぽうやぶれ /八方破れ/
はつ /初/発/發;「発」の旧字/髪/鉢;托鉢/醗;醗酵/溌;溌剌/撥;撥音/癶;はつがしら/秡/釟/捌;さば・く/髮;「髪」の旧字(人名用漢字)/
はつ> /初/
はつあわせ /初袷/
はつあん /発案/
はつあんしゃ /発案者/
はつあんだ /初安打/
はつい /発意/
はついく /発育/
はついくがく /発育学/
はついくじょう /発育上/
はついし /初石/
はついち /初市/
はつうま /初午/
はつうり /初売り/初売/
はつえ /初江/初絵/
はつえき /発駅/
はつえきけん /発駅券/
はつえん /発煙/
はつえんとう /発煙筒/発炎筒/
はつお /初穂;=はつほ/初男/
はつおもて /初表;[俳諧]/
はつおり /初折;[俳諧]/
はつおん /発音/撥音;ん/
はつおんき /発音器/
はつおんきこう /発音機構/
はつおんきごう /発音記号/
はつおんけい /発音系/
はつおんしゃ /発音者/
はつおんじょう /発音上/
はつおんすう /発音数/
はつおんたい /発音体/
はつおんひょうき /発音表記/
はつおんびん /撥音便/
はつおんふめい /発音不明/
はつおんれんしゅう /発音練習/
はつか /二十日/廿日/２０日/20日/
はつかいごう /初会合/
はつかいち /廿日市/
はつかおあわせ /初顔合わせ;相撲など/初顔合せ/
はつかがみ /初鏡;(お正月の)初化粧/
はつかぜ /初風/
はつかだいこん /二十日大根/
はつかねずみ /二十日鼠/
はつかり /初雁/
はつかん /発艦/
はつかんせつ /初冠雪/
はつかんせん /初感染/初観戦/
はつかんそう /初完走/
はつかんとう /初完投/
はつかんとうしょうり /初完投勝利/
はつかんぷう /初完封/
はつかんぷうしょうり /初完封勝利/
はつが /発芽/
はつがい /初買い/
はつがお /初顔/
はつがげんまい /発芽玄米/
はつがしら /発頭/
はつがすみ /初霞/
はつがつお /初鰹/初松魚/
はつがぼうし /発芽防止/
はつがま /初釜;[茶道]新年最初の茶事/
はつがまい /発芽米/
はつがり /初狩/
はつがりつ /発芽率/
はつがん /発癌/発ガン/発がん/
はつがんせい /発癌性/発がん性/発ガン性/
はつがんぶっしつ /発癌物質/発がん物質/発ガン物質/
はつがんらん /発眼卵;[生物]eyed egg/
はつぎ /発議/
はつぎしゃ /発議者/
はつくに /肇国;=初国/初国/
はつくろぼし /初黒星/
はつげいこ /初稽古/
はつげん /発言/発現;manifest/発源;source/撥弦/
はつげんがっき /撥弦楽器/
はつげんけいしつ /発現形質/
はつげんけん /発言権/
はつげんしゃ /発言者/
はつげんじ /発言時/
はつげんちゅう /発言中/
はつげんないよう /発言内容/
はつげんほうほう /発言方法/
はつげんりょう /発現量/
はつげんりょく /発言力/
はつこい /初恋/
はつこうかい /初公開/
はつこうぎょう /初興行/
はつこうはん /初公判/
はつご /発語/初子/
はつごおり /初氷/
はつさいよう /初採用/
はつさわ /初沢/
はつさんか /初参加/
はつさんせん /初参戦/
はつざくら /初桜/
はつざん /初産/
はつしぐれ /初時雨/
はつしごと /初仕事/
はつしば /初芝/
はつしま /初島/
はつしも /初霜/
はつしゅえん /初主演/
はつしゅっきん /初出勤/
はつしゅっそう /初出走/
はつしゅっそうば /初出走馬/
はつしゅってい /初出艇/
はつしゅっぱん /初出版/
はつしゅつじょう /初出場/
はつしゅつじょうこう /初出場校/
はつしゅつじょうゆうしょう /初出場優勝/
はつしゅつば /初出馬/
はつしゅび /初守備/
はつしょうり /初勝利/
はつしろぼし /初白星/
はつしん /発進/
はつしんしゅつ /初進出/
はつじこく /発時刻/
はつじも /初霜/
はつじゅしょう /初受賞/
はつじょう /発情/発条;spring/
はつじょうき /発情期/
はつすべり /初滑り/
はつずり /初刷/
はつずりぶん /初刷分/
はつせいたい /初聖体/
はつせいは /初制覇/
はつせき /初席/
はつせんぱつ /初先発/
はつぜっく /初節句/
はつぜみ /初蝉/
はつそうこう /初走行/
はつた /初田/
はつたいけつ /初対決/
はつたいけん /初体験/
はつたいせん /初対戦/
はつたけ /初茸/
はつたろう /初太郎/
はつだ /発兌/
はつだい /初台/発題/
はつだいえき /初台駅/
はつだいひょう /初代表/
はつだせき /初打席/
はつだより /初便り/
はつちょうせん /初挑戦/
はつつき /初月/
はつづき /初月/
はつづり /初釣/
はつで /初出/
はつでーと /初デート/
はつでん /発電/
はつでんき /発電機/発電器/
はつでんぎょ /発電魚/
はつでんげんり /発電原理/
はつでんこうりつ /発電効率/
はつでんしせつ /発電施設/
はつでんしょ /発電所/
はつでんせつび /発電設備/
はつでんよう /発電用/
はつでんりょう /発電量/
はつとうこう /初投稿/
はつとうさい /初搭載/
はつとうじょう /初登場/
はつとうじょうおんげん /初登場音源/
はつとうばん /初登板/
はつとみ /初富/
はつどう /発動/
はつどうき /発動機/
はつどうじ /発動時/
はつどうちゅう /発動中/
はつどひょう /初土俵/
はつなつ /初夏/
はつに /初荷/
はつね /初音/初値/
はつねつ /発熱/發熱;「発」旧字/
はつねつせい /発熱性/
はつねつたい /発熱体/
はつねつちゅう /発熱中/
はつねつはんのう /発熱反応;[化学]exothermic reaction/
はつねつりょう /発熱量/
はつのり /初乗り;-運賃/
はつはな /初花/
はつはる /初春/
はつばい /発売/
はつばいえき /発売駅/
はつばいえんき /発売延期/
はつばいかいし /発売開始/
はつばいかいしご /発売開始後/
はつばいかいしび /発売開始日/
はつばいがく /発売額/
はつばいきかん /発売期間/
はつばいきねん /発売記念/
はつばいきんし /発売禁止/
はつばいけってい /発売決定/
はつばいご /発売後/
はつばいしゃ /発売者/
はつばいしょにち /発売初日/
はつばいじ /発売時/
はつばいじかん /発売時間/
はつばいじき /発売時期/
はつばいじこく /発売時刻/
はつばいじゅん /発売順/
はつばいじょ /発売所/
はつばいじょうきょう /発売状況/
はつばいじょうほう /発売情報/
はつばいすう /発売数/
はつばいずみ /発売済/
はつばいぜんご /発売前後/
はつばいぜんじつ /発売前日/
はつばいちゅう /発売中/
はつばいちゅうし /発売中止/
はつばいちょくご /発売直後/
はつばいちょくぜん /発売直前/
はつばいつき /発売月/
はつばいづき /発売月/
はつばいとうしょ /発売当初/
はつばいとうじ /発売当時/
はつばいとうじつ /発売当日/
はつばいひづけ /発売日付/
はつばいび /発売日/
はつばいびご /発売日後/
はつばいびとうじつ /発売日当日/
はつばいびまえ /発売日前/
はつばいびみてい /発売日未定/
はつばいびよくじつ /発売日翌日/
はつばいぶすう /発売部数/
はつばいぶん /発売分/
はつばいほうほう /発売方法/
はつばいまいすう /発売枚数/
はつばいまえ /発売前/
はつばいまどぐち /発売窓口/
はつばいみてい /発売未定/
はつばいもと /発売元/
はつばいよてい /発売予定/
はつばいよていひょう /発売予定表/
はつばいよていび /発売予定日/
はつばいわく /発売枠/
はつばしょ /初場所/
はつひ /初日/
はつひこう /初飛行/
はつひので /初日の出/
はつびょう /発病/
はつびょうしゃ /発病者/
はつびょうりつ /発病率/
はつふじ /初富士/
はつふゆ /初冬/
はつぶたい /初舞台/
はつほ /初穂/
はつほん /発本/
はつほんるいだ /初本塁打/
はつぼうえいせん /初防衛戦/
はつぼく /発墨/
はつぼし /初星/
はつぼん /初盆/
はつまいり /初参り/
はつまご /初孫/
はつみ /初見/初実/
はつみせ /初店/初見世/
はつみみ /初耳/
はつめい /発明/
はつめいおう /発明王/
はつめいか /発明家/
はつめいしゃ /発明者/
はつめいひん /発明品/
はつもう /発毛/
はつもうで /初詣/初詣で/
はつもの /初物/
はつものぐい /初物食い/
はつもん /発問/
はつやくまん /初役満/
はつやま /初山/
はつゆ /初湯/
はつゆうしょう /初優勝/
はつゆき /初雪/
はつゆめ /初夢/
はつよう /発揚/
はつらいにち /初来日/
はつらつ /溌剌/溌溂/
はつらん /撥乱/
はつらんはんせい /撥乱反正/
はつれい /発令/
はつれいじ /発令時/
はつれいちゅう /発令中/
はつれん /発輦/
はつろ /発露/
はつわ /発話/
はつわしゃ /発話者/
はつわじ /発話時/
はつわちょう /発話長/
はつわないよう /発話内容/
はつわらい /初笑い/初笑/
はづき /葉月/
はづくろい /羽繕い/
はづな /端綱/
はて /果て/
はてい /破堤/
はてし /果てし/
はてな /？/
はてんこう /破天荒/
はで /派手/端手;=破手/破手;=破手組/
はでぐみ /破手組/端手組;=破手組/
はでめ /派手目/
はと /鳩/鴿/
はとう /波頭/波濤/波涛/坡頭/陂塘/坡塘/
はとがや /鳩ヶ谷/鳩谷/
はとこ /再従兄弟/再従姉妹/
はとごや /鳩小屋/
はとざ /鳩座;Columba(Col)/
はとどけい /鳩時計/
はとの /鳩野/
はとは /鳩派;穏健派/ハト派/
はとば /波止場/
はとばいろ /鳩羽色/
はとばねずみ /鳩羽鼠/
はとぶえ /鳩笛;ocarina/
はとまぶし /鳩間節;[民謡]沖縄/
はとむぎ /鳩麦/
はとむね /鳩胸/
はとめ /鳩目/
はともと /波戸元/
はとやま /鳩山/
はとやまいちろう /鳩山一郎/
はとやまちょう /鳩山町/
はとり /羽鳥/
はとりべ /服部/
はとろんし /ハトロン紙/
はどう /波動/覇道/波導/
はどうおんきょう /波動音響/
はどうかんすう /波動関数/
はどうけん /波動拳/
はどうせい /波動性/
はどうば /波動場/
はどうほう /波動砲/
はどうほうていしき /波動方程式/
はどうりきがく /波動力学;wave mechanics/
はどめ /歯止め/歯止/
はどり /羽鳥/
はな /花/鼻/華;-がある/端;(はじめ)「-から聞いてない」/洟;はなみず/纏頭;祝儀/塙;はなわ?/離;動詞語幹?/
はなあさぎ /花浅葱/
はなあらし /鼻嵐/
はない /花井/
はないき /鼻息/
はないくさ /花軍/
はないけ /花生け/花活け/
はないずみ /花泉/
はないた /花板/
はないち /花市/
はないちもんめ /花一匁;負けて悔しい/
はないれ /花入れ/
はないろ /花色/
はなうた /鼻歌/鼻唄/
はなうらない /花占い/
はなうり /花売り/
はなうりむすめ /花売娘/
はなえ /英恵/花江/
はなお /鼻緒/
はなおか /花岡/華岡/
はなおかこうざん /花岡鉱山/
はなおかせいしゅう /華岡青洲/
はなかい /花会;資金調達パーティ/
はなかくし /鼻隠し/
はなかげ /花陰/
はなかご /花籠/
はなかざり /花飾り/
はなかぜ /鼻風邪/鼻カゼ/
はなかつら /花鬘/
はなから /端から/
はなが /花香/
はながき /花垣/
はながさ /花笠/
はながさおんど /花笠音頭;[民謡]山形県/
はながしら /鼻頭/
はながすみ /花霞/
はながた /花形;star.「-選手」/花型;†華道の型/鼻型;nasal/
はながたさんぎょう /花形産業/
はながたじょゆう /花形女優/
はながつお /花鰹/
はながみ /鼻紙/花紙/
はながめ /花瓶/
はながら /花柄/花殻;[園芸]枯れたのに落ちずに枝に残った花/
はなき /花木/花紀/
はなきゃべつ /花キャベツ;cauliflower/
はなきん /花金/
はなぎ /鼻木/
はなぎれ /花布/
はなくそ /鼻糞/鼻くそ/鼻クソ/鼻屎/
はなくま /花隈/
はなぐすり /鼻薬/
はなぐみ /花組;[芸能]宝塚/
はなぐもり /花曇り/花曇/
はなげ /鼻毛/
はなこ /花子/華子/
はなこうぼう /花工房/
はなことば /花言葉/
はなごえ /鼻声/
はなごおり /花氷/
はなごころ /花心/
はなごよみ /花暦/
はなさ /鼻差/
はなさか /花阪/
はなさかじじい /花咲爺/
はなさき /鼻先/花咲/
はなさきがに /花咲蟹/
はなさきせん /花咲線/
はなざかり /花盛り/
はなざくら /花桜/
はなざけ /花酒/
はなざわ /花沢/
はなし /話/噺;(聞かせるための作り話)/咄;≒噺/譚;(物語)/話し;NB:名詞としては送らぬ方が一般的/
はなしあい /話し合い/話合い/話合/
はなしあいて /話し相手/話相手/
はなしいぜん /話以前/
はなしか /噺家/
はなしかた /話し方/
はなしがい /放し飼い/
はなしことば /話言葉/話し言葉/
はなしごえ /話し声/
はなしじたい /話自体/
はなしじょうず /話し上手/話上手/
はなしずき /話好き/
はなしちゅう /話中/話し中/
はなして /話し手/
はなしてき /話的/
はなしのたね /話の種/
はなしはんぶん /話半分/
はなしぶり /話し振り/
はなしべ /花蕊/
はなしべた /話下手/話し下手/
はなしぼん /咄本/噺本/
はなしま /花島/
はなしゅくしゃ /花縮砂/
はなしょうぶ /花菖蒲/
はなしんじゅ /花真珠/
はなじ /鼻血/衄;=鼻血/衂;「衄」の異体字/
はなじる /鼻汁;ズルズル/洟/
はなじるし /花印/
はなじろ /鼻白/
はなすじ /鼻筋/鼻梁/
はなすすき /花薄/
はなずもう /花相撲/
はなずら /鼻面/
はなせ /花背/
はなせん /鼻栓/
はなせんじょう /鼻洗浄/
はなぞの /花園/華園/
はなぞのしゅつじょう /花園出場/
はなぞのじんじゃ /花園神社/
はなぞのてんのう /花園天皇/
はなぞめ /花染/
はなた /花田/
はなたか /花高/
はなたかだか /鼻高々/
はなたけ /鼻茸;[医]nasal polyp/
はなたちばな /花橘/
はなたて /花立て/
はなたに /花谷/
はなたば /花束/
はなたばぞうてい /花束贈呈/
はなたれ /洟垂れ;-小僧/
はなたれこぞう /洟垂れ小僧/
はなだ /縹;light blue/花田;人名/
はなだい /花代/
はなだいろ /縹色/
はなだきよてる /花田清輝;(1909-74) 批評家/
はなだより /花便り/
はなちゃ /花茶/
はなちょうちん /鼻提灯/
はなちるさと /花散里;人名,源氏物語/
はなぢ /鼻血/
はなっつら /鼻っ面/
はなっぱし /鼻っぱし/
はなっぱしら /鼻っ柱/
はなつまみ /鼻摘まみ/鼻つまみ/鼻摘;?/
はなつまみもの /鼻つまみ者/
はなつみ /花摘み/
はなづつ /花筒/
はなづな /花綵/鼻綱/
はなづまり /鼻詰まり/鼻詰り/
はなづら /鼻面/
はなてん /放出/
はなでんしゃ /花電車/
はなどき /花時/
はなどけい /花時計/
はなにら /花韮/
はなぬすびと /花盗人/
はなの /花野/
はなのいろ /花の色/
はなのえん /花宴/
はなのき /花の木/
はなのさ /鼻の差;by a nose (<[競馬])/
はなのさき /鼻の先;-で笑う/
はなのした /鼻の下;-を伸ばす/
はなのまき /花巻/
はなのみやこ /花の都/
はなのもと /花の下/花の本/
はなはく /花博/
はなはくかいじょう /花博会場/
はなはた /花畑/
はなはだ /甚だ/甚/
はなばさみ /花鋏/
はなばしら /鼻柱/
はなばたけ /花畑/
はなばち /花蜂/
はなばな /花々/華華/花花/
はなばんか /花挽歌/
はなひゃっけい /花百景/
はなび /花火/煙火/
はなびえ /花冷え/花冷/
はなびし /花火師/花菱;模様/
はなびたいかい /花火大会/
はなびだま /花火玉/
はなびや /花火屋/
はなびら /花弁/花びら/
はなふさ /花房/
はなふだ /花札/
はなふぶき /花吹雪/
はなぶえ /鼻笛/
はなぶさ /花房/英;=花房/萼;(がく,うてな)/蕚;「萼」の異体字/
はなぺちゃ /鼻ぺちゃ/鼻ペチャ/
はなまがり /鼻曲り/
はなまき /花巻/
はなまち /花街/
はなまつり /花祭り/花祭/
はなまめ /花豆/
はなまる /花丸/
はなみ /花見/花実/歯並/羽並/歯並み/
はなみく /花見区/
はなみざけ /花見酒/
はなみず /鼻水/花水/洟/
はなみずがわ /花水川/
はなみずき /花水木/
はなみぞ /鼻溝/
はなみち /花道/
はなみづき /花見月/
はなみどう /花御堂/
はなみどき /花見時/
はなみね /鼻梁/
はなみょうが /花茗荷/
はなむけ /餞/贐;=餞/
はなむこ /花婿/
はなむすび /花結び/
はなむら /花村/
はなめ /花芽;flower bud/
はなめがね /鼻眼鏡/
はなもじ /花文字/
はなもち /花持ち;-のいい品種/鼻持ち;-ならない/花餅;笹餅/
はなもと /花本/
はなもの /花物/
はなもよう /花模様/
はなもり /花森;姓/花守/
はなや /花屋/
はなやか /華やか/花やか/
はなやぎ /花柳/
はなやしき /花屋敷/
はなやなぎ /花柳/
はなやま /花山/
はなよめ /花嫁/
はなよめいしょう /花嫁衣裳/花嫁衣装/
はなよめがっこう /花嫁学校/
はなよめしゅぎょう /花嫁修行/
はなよめすがた /花嫁姿/
はなよめにんぎょう /花嫁人形/
はならび /歯並び/
はなれ /離れ/放れ/
はなれこじま /離れ小島/
はなれじま /離れ島/
はなればなれ /離れ離れ/
はなれもの /離れ物/
はなれや /離れ家/
はなれわざ /離れ業/離れ技/
はなわ /花輪/塙/花環/鼻輪/
はなわせん /花輪線/
はなわほきいち /塙保己一/
はに /埴/羽仁/
はにうだ /羽生田/
はにおか /埴岡;姓/
はにかみや /はにかみ屋/
はにかむこうぞう /ハニカム構造;honeycomb structure/
はにしな /埴科/
はにゅう /羽生/埴生/
はにゅうだ /羽生田/
はにゅうのやど /埴生の宿/
はにわ /埴輪/
はにわり /半月/
はぬけ /歯抜け/
はね /羽/羽根;(esp.加工したもの)「-布団」/翅;昆虫の-/跳ね/撥ね/
はねいし /羽石/
はねおか /羽丘/
はねぎ /羽根木/葉葱/葉ネギ/
はねぐるま /羽根車/
はねごし /跳ね腰/
はねじ /羽地/
はねだ /羽田/
はねだおき /羽田沖/
はねだくうこう /羽田空港/
はねっかえり /跳ねっ返り/
はねばし /跳ね橋/
はねぶとん /羽根布団/羽布団/
はねまくら /羽根枕/
はねまん /跳満;[麻雀]/ハネ満;[麻雀]/
はねむし /羽虫/
はねもの /羽根物/羽物/
はの /羽野/
はのうら /羽ノ浦/
はのね /歯の根/
はは /母/義母/
はは> /母;母猫,母象,母イルカ/
ははいぬ /母犬/
ははうえ /母上/
ははおや /母親/
ははおやいがい /母親以外/
ははおやがわ /母親側/
ははおやぞう /母親像/
ははおやたち /母親達/
ははおやに /母親似/
ははおややく /母親役/
ははおやゆらい /母親由来/
ははかた /母方/
ははきぎ /帚木/
ははきぐさ /帚草/
ははきぼし /帚星;彗星/
ははぎみ /母君/
ははこ /母子/母娘/
ははこぐさ /母子草/
ははこしょうひ /母娘消費/
ははご /母御/
ははじま /母島/
ははじゃ /母者/
ははそ /柞/
ははねこ /母猫/
ははのひ /母の日;五月の第二日曜日/
ははびと /母人/
はば /幅/巾/掵/
はばうえ /巾上/
はばき /幅木/
はばきき /幅利き/
はばたき /羽撃き/羽搏き/
はばつ /派閥/
はばつあらそい /派閥争い/
はばつじんじ /派閥人事/
はばとび /幅跳び/幅跳/
はばのり /幅海苔/
はばひろ /幅広/巾広/
はばびろ /幅広;broad. 「-のネクタイ」/
はばゆうせん /幅優先/
はばよせ /幅寄せ/
はびきの /羽曳野/
はふ /破風/
はふにうむ /Hf/Hafnium/
はふり /祝/
はふりべ /祝部/
はぶ /土生/羽生/埴生/波布;毒蛇/飯匙倩/
はぶくうこう /ハブ空港;hub airport/
はぶそう /波布草/
はぶたえ /羽二重/
はぶたえもち /羽二重餅;福井/
はぶちゃ /波布茶/
はぶらし /歯ブラシ/
はぶり /羽振り;-が良い/葉振り;庭木の-/
はぷすぶるくけ /ハプスブルク家;[世界史] Habsburger/
はへい /派兵/
はへん /破片/歯偏/
はほろ /羽幌/
はほろせん /羽幌線/
はほん /端本/
はぼう /破帽/
はぼうほう /破防法/
はぼたん /葉牡丹/
はぼたんしょう /葉牡丹賞/
はぼまい /歯舞/
はぼまいしょとう /歯舞諸島/
はぼろ /羽幌/
はま /浜/破魔/濱/
はまいで /浜出/
はまお /浜尾/
はまおおつ /浜大津/
はまおおつえき /浜大津駅/
はまおか /浜岡/
はまおぎ /浜荻/
はまおもと /浜万年青;[植物]=ハマユウ/
はまかいどう /浜街道;江戸-水戸-岩沼(-奥州街道)/
はまかぜ /浜風/
はまかた /浜方/
はまかつ /浜勝/
はまかど /濱角/
はまかわ /浜川/濱川/
はまかわさき /浜川崎/
はまがくえん /浜学園/
はまがみ /浜上/濱上/
はまがわ /浜側/
はまき /葉巻/
はまきがた /葉巻型/
はまきた /浜北/
はまきょう /浜響/
はまぐち /浜口/
はまぐちおさち /浜口雄幸/
はまぐちちょう /浜口町/
はまぐり /蛤/
はまこ /浜子/
はまさか /浜坂/
はまさき /浜崎/濱崎/
はまざき /浜崎/
はましぎ /浜鷸/
はましま /濱島/
はまじ /浜路/
はまじま /浜島/
はまたけ /浜竹/
はまだ /浜田/濱田/
はまだしょうご /浜田省吾/
はまだじどうしゃどう /浜田自動車道/
はまち /刃区/
はまちどり /浜千鳥/
はまちょう /浜町/
はまっこ /浜っ子/
はまつか /濱塚/
はまで /濱出/
はまとんべつ /浜頓別/
はまどおり /浜通り/
はまな /浜名/
はまなか /浜中/濱中;「浜」旧字/
はまなこ /浜名湖/
はまなこおおはし /浜名湖大橋/
はまなし /浜梨;=はまなす/
はまなす /浜茄子/浜梨/
はまの /浜野/濱野/
はまびと /浜人/
はまべ /浜辺/浜部/
はまぼうふう /浜防風/
はまます /浜益/
はままつ /浜松/
はままついかだいがく /浜松医科大学/
はままついだい /浜松医大/
はままつえき /浜松駅/
はままつかん /浜松間/
はままつきち /浜松基地/
はままつきゅうぎじょう /浜松球技場/
はままつきゅうじょう /浜松球場/
はままつぎじゅつ /浜松技術/
はままつし /浜松市/
はままつしえいきゅうじょう /浜松市営球場/
はままつしたいいくかん /浜松市体育館/
はままつしない /浜松市内/
はままつしぶ /浜松支部/
はままつしみんかいかん /浜松市民会館/
はままつじょう /浜松城/
はままつじょうこうえん /浜松城公園/
はままつたいかい /浜松大会/
はままつだこ /浜松凧/
はままつちゅうなごんものがたり /浜松中納言物語;菅原孝標の女/
はままつちょう /浜松町/
はままつちょうえき /浜松町駅/
はままつてん /浜松店/
はままつにし /浜松西/
はままつばん /浜松版/
はままつほうめん /浜松方面/
はままで /浜迄/
はまみち /浜道/
はまみやせん /浜宮線/
はまむら /浜村;姓/
はまめし /浜飯/
はまもと /浜元/濱本/
はまや /破魔矢/浜屋/
はまやき /浜焼/
はまやす /浜靖/
はまゆう /浜木綿/
はまゆみ /破魔弓/
はまりきゅう /浜離宮/
はまりやく /嵌まり役/填役/嵌役/
はみ /馬銜/葉美/
はみがき /歯磨き/歯磨/
はみがきこ /歯磨き粉/
はみず /葉水;[園芸]leaf watering/
はむし /羽虫/
はむら /羽村/葉叢/
はむらびほうてん /ハムラビ法典;[世界史]目には目を、歯には歯を、奴隷には現金を/
はむろ /葉室/
はめ /羽目;-を外す/破目;-になる/
はめいた /羽目板/
はめこみ /嵌め込み/
はめころし /嵌め殺し/
はめごろし /嵌め殺し/
はめつ /破滅/
はめつかん /破滅感/
はめつがた /破滅型/
はめつてき /破滅的/
はめつぶつ /破滅物/
はめつもの /破滅物/
はめて /填め手/
はめん /波面;wavefront/破面;fracture surface/
はめんほう /波面法/
はも /鱧/羽茂;地名,新潟/
はもの /刃物/葉物;-野菜/端物/釖/
はものるい /刃物類/
はもん /波紋/破門/刃文/
はもんせんこく /破門宣告/
はもんほう /波紋法/
はや /早/鮠/速/頓;?/
はや> /早;早駆け,早抜け,早とちり/
はやあがり /早上がり/
はやあし /早足/速足/
はやあるき /速歩き/
はやい /速い/
はやいとこ /早い所/
はやいものがち /早い者勝ち/
はやうた /早歌/
はやうち /早撃ち;-ガンマン/早打ち;キーボードの-/速打ち/
はやうま /早馬/
はやうまれ /早生まれ/早生れ/
はやうり /早売り/
はやお /駿/早生/
はやおき /早起き/
はやおくり /早送り/
はやおし /早押し/
はやかご /早駕籠/
はやかわ /早川/
はやかわこう /早川港/
はやかわしょぼう /早川書房/
はやかわでんき /早川電気/
はやかわでんきこうぎょう /早川電機工業;[企業名]/
はやかわぶんこ /ハヤカワ文庫/早川文庫;※正式名「ハヤカワ文庫」/
はやがけ /早駆け/
はやがてん /早合点/
はやがね /早鐘/
はやがわり /早変わり/
はやき /勇樹/隼輝/
はやきた /早来/
はやく /端役/破約/早く/
はやくさ /早草/
はやくち /早口/
はやくちえいご /早口英語/
はやくちことば /早口言葉/
はやくも /早くも/
はやぐい /早食い/早喰い/
はやけ /葉焼け/
はやさ /速さ/
はやさか /早坂/
はやざき /早咲き/
はやざし /早指し/
はやし /林/囃子/囃/
はやしお /早潮/
はやしかた /囃子方;能楽・歌舞伎/
はやしことば /囃子詞;あらえっさっさー、どっこいしょ/
はやししへい /林子平;(1739-1793)経世家。『海国兵談』/
はやした /早下/
はやしたつお /林達夫/
はやしだ /林田/
はやしば /林葉/
はやしばら /林原/
はやしま /早島/
はやしや /林家/林屋/
はやしゆうてき /早矢仕有的/
はやしらざん /林羅山/
はやじに /早死に/早死/
はやじまい /早仕舞/
はやせ /早瀬/早勢/
はやた /早田/
はやだし /早出し/
はやだち /早立ち/
はやちね /早池峰/
はやちねさん /早池峰山/
はやて /疾風/
はやてまわし /早手回し/
はやで /早出/
はやと /隼人/勇人/早戸/
はやとき /早解き/
はやとちり /早とちり/
はやね /早寝/
はやねはやおき /早寝早起き/
はやの /早野/
はやのみこみ /早呑み込み/
はやば /早場/
はやばまい /早場米/
はやばや /早々/早早/
はやばん /早番/早版/
はやひと /隼人/
はやひとのつかさ /隼人司/
はやびき /早引き;quick reference.「-字典」/速弾き;ギターの-/早退き;=早退け/
はやびきゃく /早飛脚/
はやびけ /早引け;早退/早退け/
はやびん /早便;⇔遅便/
はやふえ /早笛/
はやふじ /早藤;姓/
はやぶさ /隼/鶻;=隼/
はやべん /早弁/
はやま /葉山/羽山;姓/端山/早馬/
はやまき /早蒔き;⇔遅蒔き/
はやまちょう /葉山町/
はやままち /葉山町/
はやみ /早見;-表/速水;人名/速見;地名,大分/
はやみぎょしゅう /速水御舟;(1894-1935) 日本画家/
はやみず /速水/早水/
はやみち /早道/
はやみばん /早見板/
はやみひょう /早見表/
はやみみ /早耳/
はやみや /早宮/
はやめ /早め/早目/速目/
はやめし /早飯/
はやものがたり /早物語/
はやり /流行/流行り/
はやりかぜ /流行り風邪/
はやりことば /流行り言葉/
はやりすたり /流行り廃り/
はやりめ /流行目/
はやりもの /流行り物/
はやりやまい /流行病/流行り病/
はやわかり /早分かり/早分り/
はやわざ /早業/早技/
はやわり /早割;[新語]早期予約割引/
はら /腹/原/肚;(字義:食物を詰め込む胃)/波羅/
はらあて /腹当/
はらい /払い/払/祓い;穢れを除くこと/祓/拂;「払」の旧字(人名用漢字)/赦い;?/
はらいかた /払い方/
はらいかわ /祓川/秡川/
はらいこみ /払込/払い込み/払込み/
はらいこみしょ /払込書/
はらいこみようし /払込用紙/
はらいごし /払い腰/
はらいさげ /払い下げ/払下げ/
はらいせ /腹癒せ/腹いせ/
はらいた /腹痛/
はらいだし /払い出し/
はらいっぱい /腹一杯/
はらいどの /払殿/
はらいもどし /払い戻し/払戻/払戻し/
はらいもどしきん /払戻金/
はらいわたし /払渡し/払い渡し/
はらお /原尾/
はらおか /原岡/
はらおび /腹帯/
はらか /腹赤/
はらから /同胞/
はらかわ /原川/
はらがまえ /腹構え/
はらき /原木/
はらきり /腹切り/
はらくだし /腹下し/
はらくだり /腹下り/
はらぐあい /腹具合/
はらぐち /原口/
はらぐろ /腹黒/
はらげい /腹芸/
はらこ /腹子/原子/
はらこし /原越/
はらごころ /腹心/
はらごしらえ /腹拵え/
はらごなし /腹ごなし/
はらさき /原崎/
はらさわ /原澤/原沢/
はらしま /原島/原嶋/
はらしょぼう /原書房/
はらじま /原島/
はらじゅく /原宿/
はらじゅくえき /原宿駅/
はらじゅくてん /原宿店/
はらせつこ /原節子/
はらたけ /原茸/
はらたつのり /原辰徳/
はらだ /原田/
はらだかい /原田甲斐;伊達騒動/
はらだきわこ /原田貴和子/
はらだち /腹立ち/
はらだちまぎれ /腹立ち紛れ/
はらちがい /腹違い/
はらっぱ /原っぱ/
はらつづみ /腹鼓/
はらづもり /腹積もり;どういう-だ？/腹積り/
はらてっけつ /爬羅剔抉/
はらどけい /腹時計/
はらなか /原中/
はらにく /腹肉/
はらの /原野/
はらのうち /腹の中/
はらのかわ /腹の皮/
はらのなか /腹の中/
はらのまち /原町/原ノ町/
はらのむし /腹の虫/
はらのや /原野谷/
はらはちぶ /腹八分/
はらはちぶんめ /腹八分目/
はらばい /腹這い/
はらひでこ /原日出子/
はらびれ /腹鰭/
はらぺこ /腹ペコ/腹ぺこ/
はらまき /腹巻/
はらまち /原町/
はらまちだ /原町田/
はらみおんな /孕み女/
はらみず /原水/
はらみった /波羅蜜多/
はらみつ /波羅蜜/
はらもち /腹持ち/
はらやま /原山/
はらよし /原良/
はらわた /腸/腑/
はらん /波乱;ひと-/波瀾;-万丈/葉蘭;[植物]aspidistra/波蘭;Poland/
はらんばんじょう /波瀾万丈/波乱万丈/
はらんぶくみ /波乱含み/
はり /針/梁;[建築]beam/鍼;-治療/榛;はんのき/玻璃/鉤;釣針/張/張り;声の-/貼/播;播磨,?/
はりあい /張り合い/張合い/
はりあな /針穴/
はりあみ /張り網/張網/
はりい /鍼医/
はりいた /張板/
はりいち /針位置/
はりうお /針魚/
はりうっどえいが /ハリウッド映画/
はりおうぎ /張り扇;講釈グッズ/
はりかえ /張り替え/張替え/張替/
はりかた /張形/張型/張り型/張り形/
はりかべ /張り壁/貼り壁/
はりがた /張形/張型/張り型/張り形/
はりがね /針金/
はりがみ /張り紙/貼り紙/はり紙/貼紙/張紙/
はりがや /針谷/針ヶ谷/
はりき /針木/
はりくよう /針供養/
はりぐすり /貼り薬/
はりぐち /播口/
はりけん /破裏拳/
はりこ /張子;-の虎/針子;お-/
はりこうかん /針交換/
はりこみ /張り込み;-捜査/貼り込み;paste/
はりさき /針先/
はりさし /針刺し;裁縫道具/
はりし /鍼師/
はりしごと /針仕事/
はりしょうが /針生姜/
はりじょう /針状/
はりす /鉤素;釣道具/
はりせん /張り扇/
はりせんぼん /針千本/
はりだし /張り出し/張出/張出し/
はりだしおおぜき /張出大関/
はりだしこむすび /張出小結/
はりだしせきわけ /張出横綱/張出関脇/
はりだしよこづな /張出横綱/
はりちりょう /鍼治療/針治療/
はりつ /破笠/
はりつけ /磔/貼り付け/貼付/張り付け/
はりつけばしら /磔柱/
はりて /張り手/張手/
はりぬい /針縫/
はりねずみ /針鼠/蝟/
はりのあな /針の穴;-をも通す/
はりのむしろ /針の筵/
はりのやま /針の山;地獄名物/
はりはりづけ /はりはり漬け/
はりばこ /針箱/
はりばん /張り番/
はりふだ /はり札/張り札/貼り札/張札/
はりぼて /張りぼて/
はりま /播磨;旧国名,兵庫/梁間;[建築]span/針間/播摩;人名?/
はりまど /玻璃窓/
はりまなだ /播磨灘/
はりまのくに /播磨国/
はりまびと /播磨人/
はりまや /播磨屋/針間矢/
はりみち /針道/
はりめ /針目/
はりもと /張本/播本/
はりや /針谷/
はりやま /針山/張山/
はりゆき /梁行;[建築]/
はりよ /針魚/
はりん /破倫/
はる /春/治/晴/温/玄/請/榛/青春/
はるあき /春秋/
はるあきれんぱ /春秋連覇/
はるいがい /春以外/
はるいちばん /春一番/
はるうらら /春麗/
はるえ /春江/治恵/
はるお /春夫/晴夫/春男/春雄/晴雄/治夫/治雄/治男/晴朗/東生/
はるおか /春岡/
はるおみ /晴臣/
はるか /遥/遙;「遥」の旧字(人名用漢字)/悠/遥か/美佳/晴香/春歌;名/
はるかぜ /春風/
はるかわ /春川/
はるがすみ /春霞/
はるがっしゅく /春合宿/
はるき /春樹/春木/治己/
はるきち /春吉/
はるきゃべつ /春キャベツ/
はるぎ /春着/
はるぐち /春口/
はるけいば /春競馬/
はるげしき /春景色/
はるこ /晴子/春子/治子/
はるごう /春号/
はるごえ /春肥/
はるごころ /春心/
はるごたつ /春炬燵/
はるごろ /春頃/
はるさき /春先/
はるさく /春作/
はるさめ /春雨/
はるさめものがたり /春雨物語;(1808-09)上田秋成/
はるし /治志/
はるしぐれ /春時雨/
はるじ /春治/
はるぞら /春空/
はるた /春田/
はるだ /春田/
はるだんじ /春団次/
はるつげうお /春告魚/
はるな /春菜/榛名/
はるなさん /榛名山/
はるなつ /春夏/
はるなつあきふゆ /春夏秋冬/
はるの /春野/榛野/
はるのうみ /春の海/
はるのこころ /春の心/
はるのひ /春の日/
はるのよ /春の夜/
はるばしょ /春場所/
はるばる /遥々/遥遥/
はるひ /春日/晴日/
はるひこ /晴彦/春彦/治彦/晴比古/
はるひさ /晴久/治久/陽久/春久/
はるひで /治秀/
はるひと /治人/
はるひろ /晴弘/
はるび /腹帯/
はるびん /哈爾浜/
はるふじ /春藤/
はるまき /春巻/春蒔き;[園芸]spring sowing/
はるまつり /春祭り/春祭/
はるまんかい /春満開/
はるみ /晴美/春美/晴海/はる美/晴見/
はるみだい /晴美台/
はるみちのつらき /春道列樹;山川に 風のかけたる しがらみは ながれもあへぬ もみぢなりけり/
はるみつ /晴光/
はるみない /晴海内/
はるみふとう /晴海埠頭/
はるもの /春物/
はるもよう /春模様/
はるやさい /春野菜/
はるやす /晴康/陽保/
はるやすみ /春休み/
はるやま /春山/
はるゆき /治之/晴幸/治幸/春幸/陽之/
はるよ /春代/
はるよし /晴芳/
はるらんまん /春爛漫/
はれ /晴/晴れ/腫れ/霽れ;(天候)=晴れ/
はれーすいせい /ハレー彗星;[天文]Halley/
はれお /晴夫/
はれぎ /晴れ着/晴着/
はれすがた /晴れ姿/
はれつ /破裂/
はれつおん /破裂音/
はれつせい /破裂性/
はれて /晴れて/
はればれ /晴れ晴れ/晴々/
はれぶたい /晴れ舞台/晴舞台/
はれま /晴れ間/晴間/
はれもの /腫れ物/腫物/
はれやま /晴山/
はれんち /破廉恥/
はれんちざい /破廉恥罪/
はろ /波呂/
はろう /波浪/
はろうけいほう /波浪警報/
はろうちゅういほう /波浪注意報/
はわい /羽合;地名,鳥取/布哇;Hawaii/
はわいとう /ハワイ島/
はわたり /刃渡り/
はん /班;group/斑;まだら/範/半/藩/犯/反/版/飯/汎;汎用/凡;凡例/帆;帆船/坂;登坂/阪;阪神/叛;叛徒/板;板刻/販;販売/鈑;鈑金/搬;搬入/般;諸般/瘢;あと/磐;いわ/槃;涅槃/判;判決/伴;同伴/畔;湖畔/拌;攪拌/絆;脚絆/胖/袢;袢纏/幡;はた/旛;はた/蕃/翻;翻本/潘/燔;燔祭/繙;ひもと・く/膰;ひもろぎ/蟠;わだかま・る/頒;頒布/煩;煩瑣/攀;登攀/樊/氾;氾濫/笵;≒範/范;≒範/繁;繁栄/釆/泛;う・く/
はん> /反;(anti) 反重力/半;(half) 半泣き/汎;(pan-) 汎アジア,汎スラブ主義,汎関数/
はんあい /汎愛/
はんあらぶしゅぎ /汎アラブ主義;Pan-Arabism/
はんい /範囲/藩医/犯意;[法]criminal intent/叛意;謀叛の意志/
はんいがい /範囲外/
はんいご /反意語/
はんいしき /半意識/
はんいしてい /範囲指定/
はんいせんたく /範囲選択/
はんいない /範囲内/
はんいぶんせき /範囲分析/
はんいめい /範囲名/
はんいん /班員/
はんいんよう /半陰陽/
はんうちゅう /反宇宙/
はんえい /反映/繁栄/半影/
はんえいきゅう /半永久/
はんえいきゅうてき /半永久的/
はんえいちゅう /半影中/
はんえいてき /反映的/
はんえいろん /反映論/
はんえり /半襟/
はんえん /半円/攀援/
はんえんけい /半円形/攀縁茎;[植物]climbing stem/
はんおう /反応/藩王/
はんおうこく /藩王国/
はんおし /半押/
はんおち /半落ち;[俗]一部自供/
はんおん /半音/
はんおんかい /半音階/
はんおんした /半音下/
はんか /頒価/繁華/汎化/般化;=汎化/半跏/反歌/半価/
はんかい /半壊/半開/半解/半潰/
はんかいしんけい /反回神経/
はんかいてん /半回転/
はんかがい /繁華街/
はんかく /半角/反核/
はんかくえいすう /半角英数/
はんかくえいすうじ /半角英数字/
はんかくえいすうにゅうりょく /半角英数入力/
はんかくかたかな /半角カタカナ/半角片仮名/
はんかくかな /半角カナ/半角仮名/
はんかくきごう /半角記号/
はんかくすうじ /半角数字/
はんかくぜんかく /半角全角/
はんかくにゅうりょく /半角入力/
はんかくぶん /半角分/
はんかくへんかん /半角変換/
はんかくめい /反革命/
はんかくもじ /半角文字/
はんかくもじすう /半角文字数/
はんかこ /半過去/
はんかこけい /半過去形/
はんかさん /半加算/
はんかせい /汎化性/
はんかた /汎型/
はんかちおとし /ハンカチ落とし/
はんかちょう /犯科帳/
はんかつう /半可通/
はんかのうりょく /汎化能力/
はんかわき /半乾き/
はんかん /反感/繁閑/反間/繁簡;繁雑と簡略／繁体字と簡体字/半環/
はんかんすう /汎関数/
はんかんせい /半完成/
はんかんせいひん /半完成品/
はんかんせいゆ /半乾性油/
はんかんはんみん /半官半民/
はんかんひ /販管費;勘定科目。販売費及び一般管理費/
はんが /版画/
はんがい /斑蓋/半舁/
はんがえし /半返し/
はんがか /版画家/版画化/
はんがきょうしつ /版画教室/
はんがく /半額/藩学/
はんがくいか /半額以下/
はんがくくらい /半額位/
はんがくけい /半額系/
はんがくけん /半額券/
はんがくせつ /半楽節/
はんがくていど /半額程度/
はんがくぶん /半額分/
はんがくめんじょ /半額免除/
はんがげいじゅつ /版画芸術/
はんがそ /半画素/
はんがた /判型/版型/判形/
はんがてん /版画展/
はんがりー /洪牙利;Hungary/
はんがるい /版画類/
はんがわき /半乾き/
はんがん /判官/半眼/
はんき /半期;half-year/反旗;-を翻す/叛旗;=反旗/半旗;half-mast. NB:弔意を表す/搬器/半季/
はんきかん /半規管/
はんきちすう /半吉数/
はんきゃくしき /半脚式/
はんきゅう /阪急/半休/半球/阪九/半弓/班給/
はんきゅういしばしえき /阪急石橋駅/
はんきゅういたみ /阪急伊丹/
はんきゅういまづせん /阪急今津線/
はんきゅううめだ /阪急梅田/
はんきゅううめだえき /阪急梅田駅/
はんきゅうえんせん /阪急沿線/
はんきゅうきたせんりえき /阪急北千里駅/
はんきゅうけいれつ /阪急系列/
はんきゅうこうべせん /阪急神戸線/
はんきゅうこしょ /阪急古書/
はんきゅうさいいん /阪急西院/
はんきゅうさんのみや /阪急三宮/
はんきゅうしじょうおおみや /阪急四条大宮/
はんきゅうじょう /半球状/半球上/
はんきゅうせん /阪急線/
はんきゅうせんりせん /阪急千里線/
はんきゅうたい /半球体/
はんきゅうたからづかせん /阪急宝塚線/
はんきゅうつかぐち /阪急塚口/
はんきゅうでんしゃ /阪急電車/
はんきゅうでんてつ /阪急電鉄/
はんきゅうとうほう /阪急東宝/
はんきゅうとっきゅう /阪急特急/
はんきゅうにしのみや /阪急西宮/
はんきゅうにしのみやきたぐち /阪急西宮北口/
はんきゅうはい /阪急杯/
はんきゅうふぇりー /阪九フェリー/
はんきゅうみかげえき /阪急御影駅/
はんきょう /反響/反共;anticommunist/般教;[略語]一般教養(科目)/
はんきょうおん /反響音/
はんきょうしん /反共振/
はんきょうせい /半強制/
はんきょうばん /反響板/
はんきょうらん /半狂乱/
はんきょり /汎距離/
はんきりすと /反キリスト/
はんきれ /半切れ/
はんきん /半金/
はんぎ /版木/板木;=版木/半技/
はんぎご /反義語;antonym/
はんぎゃく /反逆/叛逆/
はんぎゃくしゃ /反逆者/
はんぎゃくじ /反逆児/
はんぎょ /半漁/板魚/
はんぎょく /半玉/
はんぎょじん /半魚人/
はんぎり /半切り/
はんぎれ /半切れ/
はんく /半句/
はんくうかん /半空間/
はんくら /半クラ/
はんくらっち /半クラッチ/
はんぐん /反軍/半群/叛軍/
はんけい /半径/判型/
はんけい> /半径;-6370キロ/
はんけつ /判決/
はんけつしょ /判決書/
はんけつぶん /判決文/
はんけつぶんちゅう /判決文中/
はんけつりゆう /判決理由/
はんけん /版権/半券/半研/
はんけんしょゆう /版権所有/
はんけんしんせい /版権申請/
はんけんじ /判検事/
はんげ /半夏/
はんげき /反撃/繁劇/
はんげきかいし /反撃開始/
はんげきじょう /半劇場/
はんげきそち /反撃措置/
はんげきほうほう /反撃方法/
はんげしょう /半夏生/
はんげっぽう /半月報/
はんげつ /半月/
はんげつけい /半月形/
はんげつじょう /半月状/
はんげつそんしょう /半月損傷/
はんげつばん /半月板/
はんげん /半減/半舷;左舷と右舷の乗組員/半源;?/
はんげんか /半減化/
はんげんき /半減期/
はんげんご /半言語/
はんげんしりょく /反原子力/
はんげんぱつ /反原発/
はんこ /判子/
はんこう /犯行/反抗;rebellion/反攻;counterattack/藩校/版行/板行/藩侯/
はんこうえい /半公営/
はんこうき /反抗期/
はんこうげんば /犯行現場/
はんこうしん /反抗心/
はんこうせいめい /犯行声明/
はんこうたく /半光沢/
はんこうてき /反抗的/
はんこうよこく /犯行予告/
はんこく /翻刻/汗国/
はんこけい /半固形/
はんこっかてき /反国家的/
はんこつ /反骨/
はんこつせいしん /反骨精神/
はんこてい /半固定/
はんこていていこう /半固定抵抗/
はんこてんろん /半古典論/
はんこや /はんこ屋/
はんこん /瘢痕;scar/斑痕;まだらなあと/
はんご /反語/
はんごう /飯盒/半合/
はんごうすいさん /飯盒炊爨/
はんごてき /反語的/
はんごひょうげん /反語表現/
はんごほう /反語法/
はんごろし /半殺し/
はんごん /反魂/
はんごんこう /反魂香/
はんごんたん /反魂丹/
はんさ /煩瑣/
はんさい /半裁/燔祭/半済/半歳/半截/
はんさき /飯崎/
はんさく /半作/
はんさつ /藩札/
はんさよう /反作用/
はんざ /半座/反坐/
はんざい /犯罪/
はんざいがく /犯罪学/
はんざいきろく /犯罪記録/
はんざいげんば /犯罪現場/
はんざいこうい /犯罪行為/
はんざいご /犯罪後/
はんざいしゃ /犯罪者/
はんざいしゃかいがく /犯罪社会学;criminal sociology/
はんざいしゃしんり /犯罪者心理/
はんざいしゅうだん /犯罪集団/
はんざいしんりがく /犯罪心理学;criminal psychology/
はんざいせい /犯罪性/
はんざいそうさ /犯罪捜査/
はんざいそしき /犯罪組織/
はんざいたいこく /犯罪大国/
はんざいてき /犯罪的/
はんざいとし /犯罪都市/
はんざいにん /犯罪人/
はんざいはくしょ /犯罪白書/
はんざいぼうし /犯罪防止/
はんざいりつ /犯罪率/
はんざいれき /犯罪歴/
はんざつ /煩雑/繁雑/
はんざつか /煩雑化/
はんざわ /半澤/半沢/
はんざん /飯山/
はんし /藩士/半紙/範士;剣道の最高位の称号/半死;―半生/
はんしき /版式/範式/
はんした /版下/
はんしちとりものちょう /半七捕物帳/
はんしつ /半室/
はんしはんしょう /半死半生/
はんしぼん /半紙本/
はんしゃ /反射/販社/
はんしゃおん /反射音/
はんしゃかい /反社会/
はんしゃかいせい /反社会性/
はんしゃかいてき /反社会的/
はんしゃかいてきこうい /反社会的行為/
はんしゃかく /反射角/
はんしゃかんすう /反射関数/
はんしゃがた /反射型/
はんしゃきゅう /反射弓;[解剖]reflex arc/
はんしゃきょう /反射鏡/
はんしゃきょうど /反射強度/
はんしゃけい /反射系/
はんしゃけいすう /反射係数/
はんしゃけいろ /反射経路/
はんしゃこう /反射光/
はんしゃこうしき /反射光式/
はんしゃこうぞう /反射構造/
はんしゃざい /反射材/
はんしゃざいりょう /反射材料/
はんしゃしき /反射式/
はんしゃしょく /反射色/
はんしゃしんけい /反射神経/
はんしゃせい /反射性/
はんしゃせいぶん /反射成分/
はんしゃそく /反射則/反射束/
はんしゃぞう /半写像/
はんしゃたい /反射体/
はんしゃてき /反射的/
はんしゃてん /反射点/
はんしゃとくせい /反射特性/
はんしゃのう /反射能/
はんしゃは /反射波/
はんしゃばん /反射板/
はんしゃぼうえん /反射望遠/
はんしゃぼうえんきょう /反射望遠鏡/
はんしゃめん /反射面/
はんしゃりつ /反射率;†reflectance.「天体の-」/反射律;†reflexive law./
はんしゃろ /反射炉/
はんしゅ /藩主/
はんしゅう /半周/
はんしゅうちょう /半周長/
はんしゅつ /搬出/
はんしゅりゅうは /反主流派/
はんしょ /繙書/
はんしょう /反証/半焼/半鐘/反照/汎称/半生;半死―/
はんしょうかのう /反証可能/
はんしょく /繁殖/蕃殖/飯食/
はんしょくかつどう /繁殖活動/
はんしょくき /繁殖期/
はんしょくじ /繁殖時/
はんしょくち /繁殖地/
はんしょくば /繁殖馬/
はんしょくひんば /繁殖牝馬/
はんしょくほうほう /繁殖方法/
はんしょくりょく /繁殖力/
はんしん /阪神/半身/半神;demigod/版心/叛臣/
はんしんあわじだいしんさい /阪神淡路大震災/阪神・淡路大震災/
はんしんかん /阪神間/
はんしんがわ /阪神側/
はんしんきゅうこう /阪神急行/
はんしんけいばじょう /阪神競馬場/
はんしんこうくう /阪神航空/
はんしんこうそく /阪神高速/
はんしんこくどう /阪神国道/
はんしんしょうがい /阪神障害/
はんしんじだい /阪神時代/
はんしんせん /阪神戦/
はんしんだいしょうてん /阪神大賞典/
はんしんだいしんさい /阪神大震災/
はんしんちく /阪神地区/
はんしんちほう /阪神地方/
はんしんでんきてつどう /阪神電気鉄道/
はんしんでんしゃ /阪神電車/
はんしんでんてつ /阪神電鉄/
はんしんのだ /阪神野田/
はんしんはんぎ /半信半疑/
はんしんひゃっかてん /阪神百貨店/
はんしんふずい /半身不随/
はんしんほんせん /阪神本線/
はんしんよく /半身浴/
はんしんろん /汎神論;pantheism/汎心論;panpsychism/
はんじ /判事/判示;裁判例の判断を「〜と判示する」などとして使います/半時/判じ/
はんじかん /半時間/
はんじせい /反磁性/
はんじせいたい /反磁性体/
はんじだい /反時代/
はんじだいてき /反時代的/
はんじつ /半日/反実/
はんじつかそう /反実仮想/
はんじどう /半自動/
はんじどうか /半自動化/
はんじどうてき /半自動的/
はんじほ /判事補/
はんじもの /判じ物;quiz/
はんじゃ /判者/
はんじゅ /判授/
はんじゅう /半獣/
はんじゅうりょく /反重力/
はんじゅく /半熟/
はんじゅくたまご /半熟卵/
はんじゅんじょ /半順序/
はんじょう /繁盛/繁昌;≒繁盛/半畳/犯情/
はんじょうき /繁盛記/
はんじょく /繁縟/
はんじん /半人/
はんすい /半睡/
はんすう /半数/反芻/版数/
はんすういか /半数以下/
はんすういじょう /半数以上/
はんすけ /半助/
はんずぼん /半ズボン/
はんせい /反省/半生/藩政/繁生/
はんせいいでん /伴性遺伝/
はんせいかい /反省会/
はんせいき /半世紀/半生記/
はんせいざいりょう /反省材料/
はんせいしゃざい /反省謝罪/
はんせいすう /半整数/
はんせいてん /反省点/
はんせいひん /半製品/
はんせいふ /反政府/
はんせいふうんどう /反政府運動/
はんせいふしゅぎしゃ /反政府主義者/
はんせいふせいりょく /反政府勢力/
はんせいふそしき /反政府組織/
はんせいぶん /反省文/
はんせかい /反世界/
はんせき /版籍/犯跡/
はんせつ /半切;-紙/反切;中国語の-/半截/
はんせん /反戦/帆船/半銭/
はんせんうんどう /反戦運動/
はんせんえいが /反戦映画/
はんせんか /反戦歌/
はんせんけい /半線形/
はんせんしそう /反戦思想/
はんせんじぬし /反戦地主/
はんせんでも /反戦デモ/
はんせんは /反戦派/
はんせんびょう /ハンセン病/
はんせんもけい /帆船模型/
はんせんろん /反戦論/
はんぜいてんのう /反正天皇/
はんぜん /判然/
はんそ /反訴/反ソ/
はんそう /搬送/帆走/
はんそうき /搬送機/
はんそうちゅう /帆走中/
はんそうは /搬送波/
はんそうよう /搬送用/
はんそく /販促;[略語]販売促進/反則/犯則;=反則/半束/反側;輾転-/
はんそくきっぷ /反則切符/
はんそくきん /反則金/
はんそくきんせいど /反則金制度/
はんそくこうい /反則行為/
はんそくとうきゅう /反則投球/
はんそくぶつ /販促物/
はんそくまけ /反則負け/
はんそくよう /販促用/
はんそくわざ /反則技/
はんそてい /反措定;Antithese/
はんそで /半袖/
はんぞう /半蔵/楾/半挿;水差し/
はんぞうもん /半蔵門/
はんぞうもんせん /半蔵門線/
はんぞく /反俗/
はんた /繁多/煩多/
はんたい /反対/繁体/
はんたいいけん /反対意見/
はんたいうんどう /反対運動/
はんたいかいしゃく /反対解釈/
はんたいがいねん /反対概念/
はんたいがわ /反対側/
はんたいきゅうふ /反対給付/
はんたいぎし /反対岸/
はんたいご /反対語/
はんたいしゃ /反対者/
はんたいしゃせん /反対車線/
はんたいしょう /反対称/
はんたいしょうせい /反対称性/
はんたいしょうりつ /反対称律/
はんたいしょく /反対色/
はんたいじ /繁体字/
はんたいじんもん /反対尋問/
はんたいすう /反対数/
はんたいせい /反体制/
はんたいせいてき /反体制的/
はんたいせいは /反体制派/
はんたいせつ /反対説/
はんたいたすう /反対多数/
はんたいとうこう /反対投稿/
はんたいとうひょう /反対投票/
はんたいは /反対派/
はんたいはのうみん /反対派農民/
はんたいひょう /反対票/
はんたいひょうめい /反対表明/
はんたいほうこう /反対方向/
はんたいほうめん /反対方面/
はんたいりゆう /反対理由/
はんたいろん /反対論/
はんたま /半玉/
はんたんい /班単位/
はんだ /半田/盤陀/
はんだーす /半ダース;6/
はんだい /飯台/版代/阪大/大阪大学;※abbrev/
はんだいきそこう /阪大基礎工/
はんだいこう /阪大工/
はんだいこうがくぶ /阪大工学部/
はんだいせい /阪大生/
はんだいり /阪大理/
はんだくおん /半濁音/
はんだくおんぷ /半濁音符;ぱぴぷぺぽ、の「゜」/゜/
はんだくてん /半濁点/゜/
はんだごて /半田鏝/半田ごて/
はんだしみん /半田市民/
はんだずけ /半田付け;※仮名遣い「いちづk」/
はんだづけ /半田付け/
はんだふりょう /半田不良/
はんだん /判断/
はんだんかのう /判断可能/
はんだんきじゅん /判断基準/判断規準/
はんだんけっか /判断結果/
はんだんざいりょう /判断材料/
はんだんてん /判断点/
はんだんのうりょく /判断能力/
はんだんほりゅう /判断保留/
はんだんようそ /判断要素/
はんだんりょく /判断力/
はんだんりょくひはん /判断力批判;Kritik der Urteilskraft,1790,Kant/
はんち /半値/
はんちか /半地下/
はんちく /斑竹/
はんちしょう /半致傷/
はんちはば /半値幅/
はんちはんかい /半知半解/
はんちゃん /半荘/
はんちゅう /範疇/藩中/範中/範衷/
はんちゅうがい /範疇外/
はんちゅうめい /範疇名/
はんちょう /班長/半丁/反跳/
はんちょうおん /半長音/
はんちょうようし /反跳陽子/
はんちょうりゅうし /反跳粒子/
はんちょくせん /半直線/
はんつき /半月/
はんつきご /半月後/
はんつきまい /半搗き米/
はんづら /版面/
はんて /半手/
はんてい /判定/藩邸/
はんていいん /判定員/
はんていかいろ /判定回路/
はんていかのう /判定可能/
はんていがち /判定勝ち/
はんていき /判定機/
はんていきじゅん /判定基準/判定規準;?/
はんていきのう /判定機能/
はんていけっか /判定結果/
はんていこう /半抵抗/
はんていじょうけん /判定条件/
はんていふかのう /判定不可能/
はんていふのう /判定不能/
はんていぶ /判定部/
はんていぶぶん /判定部分/
はんていぶん /判定文/
はんていほう /判定法/
はんていほうほう /判定方法/
はんていまけ /判定負け/
はんていめい /判定名/
はんていもんだい /判定問題/
はんていりつ /反定立;[哲学]Antithese/
はんてきおうしょうこうぐん /汎適応症候群/
はんてつ /半徹/
はんてん /反転/飯店/斑点/半纏/半天/袢纏;=半纏/反轉;「転」旧字/
はんてんおん /反転音;[音声学]retroflex/
はんてんき /反転器/
はんてんこうしき /反転公式/
はんてんじ /反転時/
はんてんじかん /反転時間/
はんてんどうさ /反転動作/
はんてんひょうじ /反転表示/
はんてんもじ /反転文字/
はんでんし /反電子/
はんでんせい /班田制/
はんと /版図/叛徒/半途/
はんとう /半島/反騰/
はんとうない /半島内/
はんとうまく /半透膜/
はんとうめい /半透明/
はんとき /半時;一時間/半刻;一時間/
はんとけい /反時計/
はんとし /半年/
はんとしいじょう /半年以上/
はんとしいじょうまえ /半年以上前/
はんとしいない /半年以内/
はんとしかん /半年間/
はんとしくらい /半年位/
はんとしけいか /半年経過/
はんとしご /半年後/
はんとしごと /半年毎/
はんとししよう /半年使用/
はんとしていど /半年程度/
はんとしぶん /半年分/
はんとしほどまえ /半年程前/
はんとしまえ /半年前/
はんとらすとほう /反トラスト法;[経済]antitrust law/
はんとりちょう /判取帳/
はんどあ /半ドア/
はんどう /反動/半藤;人名/半道/般道/
はんどういるか /半道海豚/
はんどうしそう /反動思想/
はんどうせい /半同棲/
はんどうたい /半導体/
はんどうたいかいはつ /半導体開発/
はんどうたいかんけい /半導体関係/
はんどうたいきき /半導体機器/
はんどうたいぎじゅつ /半導体技術/
はんどうたいけんきゅう /半導体研究/
はんどうたいけんきゅうじょ /半導体研究所/
はんどうたいさんぎょう /半導体産業/
はんどうたいじぎょうぶ /半導体事業部/
はんどうたいそし /半導体素子/
はんどうてき /反動的/
はんどく /判読/範読/槃特;[仏教]墓に茗荷が生えたという物忘れの名人/繙読/
はんどくふのう /判読不能/
はんどぶ /ハンド部/
はんどぼーるぶ /ハンドボール部/
はんどん /半ドン;(半分zontag)土曜日は-/
はんな /阪奈/
はんなが /半長;半長靴./
はんながぐつ /半長靴/
はんなき /半泣き;-になって/
はんなどうろ /阪奈道路/
はんなま /半生;―菓子/
はんなまがし /半生菓子;もなかなど/
はんなん /阪南/
はんなんだい /阪南大/
はんにえ /半煮え/
はんにじゅう /半二重/
はんにち /半日;†half a day/反日;†anti-Japan/
はんにちいじょう /半日以上/
はんにちかん /半日間/
はんにちかんこう /半日観光/
はんにちかんじょう /反日感情/
はんにちけん /半日券/
はんにちご /半日後/
はんにちせいりょく /反日勢力/
はんにちていど /半日程度/
はんにっし /班日誌/
はんにゃ /般若/
はんにゃきょう /般若経/
はんにゃしんきょう /般若心経/
はんにゃしんぎょう /般若心経/
はんにゃじ /般若寺/
はんにゃとう /般若湯/
はんにゅう /搬入/
はんにゅうこう /搬入口/
はんにゅうとどけ /搬入届/
はんにゅうび /搬入日/
はんにゅうぶ /搬入部/
はんにん /犯人/半人/
はんにんかん /判任官/
はんにんがわ /犯人側/
はんにんぞう /犯人像/
はんにんたち /犯人達/
はんにんまえ /半人前/
はんにんやく /犯人役/
はんね /半値/
はんねいか /半値以下/
はんねん /半年/
はんのう /反応/飯能;地名/半農/半能/半納/
はんのうかくりつ /反応確率/
はんのうきこう /反応機構/
はんのうしき /反応式/
はんのうじかん /反応時間/
はんのうせい /反応性/
はんのうせっけい /反応設計/
はんのうせんたくせい /反応選択性/
はんのうそくど /反応速度/
はんのうそくどしき /反応速度式/
はんのうそくどろん /反応速度論/
はんのうだんめんせき /反応断面積/
はんのうねつ /反応熱;[化学]heat of reaction/
はんのうはんぎょ /半農半漁/
はんのうりつ /反応率/
はんのうろ /反応炉/
はんのき /榛の木;[植物]alder/
はんはちょう /半波長/
はんはん /半々/
はんば /飯場/半場/
はんばい /販売/半杯/
はんばいあいて /販売相手/
はんばいいん /販売員/
はんばいか /販売課/
はんばいかい /販売会/
はんばいかいし /販売開始/
はんばいかかく /販売価格/
はんばいかんり /販売管理/
はんばいがいしゃ /販売会社/
はんばいがく /販売額/
はんばいき /販売機/
はんばいきかん /販売期間/
はんばいきょてん /販売拠点/
はんばいきんし /販売禁止/
はんばいけいかく /販売計画/
はんばいけいたい /販売形態/
はんばいけいやく /販売契約/
はんばいけいろ /販売経路/
はんばいけん /販売権/
はんばいさき /販売先/
はんばいし /販売士/
はんばいしゃ /販売者/
はんばいしゅうりょう /販売終了/
はんばいしょ /販売所/
はんばいじ /販売時/
はんばいじき /販売時期/
はんばいじぎょう /販売事業/
はんばいじぎょうぶ /販売事業部/
はんばいじっせき /販売実績/
はんばいじょ /販売所/
はんばいじょう /販売場/
はんばいじょうきょう /販売状況/
はんばいじょうけん /販売条件/
はんばいじょうほう /販売情報/
はんばいすう /販売数/
はんばいせいせき /販売成績/
はんばいせんりゃく /販売戦略/
はんばいそくしん /販売促進/
はんばいそしき /販売組織/
はんばいたいせい /販売体制/
はんばいたんい /販売単位/
はんばいだいすう /販売台数/
はんばいだいりてん /販売代理店/
はんばいだか /販売高/
はんばいちゅう /販売中/
はんばいちゅうし /販売中止/
はんばいてすうりょう /販売手数料/
はんばいてん /販売店/
はんばいてんとう /販売店頭/
はんばいてんぽ /販売店舗/
はんばいばしょ /販売場所/
はんばいひ /販売費/
はんばいひん /販売品/
はんばいび /販売日/
はんばいふしん /販売不振/
はんばいぶ /販売部/
はんばいぶもん /販売部門/
はんばいぶん /販売分/
はんばいほうしき /販売方式/
はんばいほうほう /販売方法/
はんばいまいすう /販売枚数/
はんばいまえ /販売前/
はんばいもう /販売網/
はんばいもと /販売元/
はんばいや /販売屋/
はんばいよう /販売用/
はんばいりえき /販売利益/
はんばいりょう /販売量/
はんばいりょういき /販売領域/
はんばいりょく /販売力/
はんばく /反駁/反ばく/
はんばつ /藩閥/
はんばつせいふ /藩閥政府/
はんぱ /半端/半波;half-wave.「-整流」/
はんぱく /半泊;†(ホテルなど)/半拍;†(リズム)/半白;白髪まじり/斑白;=半白/頒白;=半白/
はんぱせいりゅう /半波整流/
はんぱちょう /半波長/
はんぱつ /反発/反撥;=反撥/
はんぱつけいすう /反発係数;[物理]restitution coefficient/
はんぱつさよう /反発作用/
はんぱつしん /反発心/
はんぱつてき /反発的/
はんぱつりょく /反発力/
はんぱもの /半端者/
はんひかげ /半日陰/
はんひれい /反比例/
はんひん /販品/
はんびょうにん /半病人/
はんびらき /半開き/
はんぴ /反比/
はんぴゃく /凡百;ぼんぴゃく/
はんぴれい /反比例/
はんふだい /阪府大/
はんぶっしつ /反物質/
はんぶるぐ /漢堡/
はんぶん /半分/繁文/
はんぶんいか /半分以下/
はんぶんいじょう /半分以上/
はんぶんくらい /半分位/
はんぶんこ /半分こ/
はんぶんさぎ /半分詐欺/
はんぶんさんせい /半分賛成/
はんぶんししん /半分私信/
はんぶんしゅみ /半分趣味/
はんぶんじゃく /半分弱/
はんぶんじょうだん /半分冗談/
はんぶんじょくれい /繁文縟礼/
はんぶんすう /繁分数/
はんぶんぜんご /半分前後/
はんぶんていど /半分程度/
はんぶんほんき /半分本気/
はんぶんほんとう /半分本当/
はんぷ /頒布/帆布;sail cloth/
はんぷかい /頒布会/
はんぷく /反復/反覆;†ひっくりかえる/
はんぷくうんどうかたそんしょう /反復運動過多損傷/RSI/
はんぷくがくしゅう /反復学習/
はんぷくきごう /反復記号;[音楽]/
はんぷくし /反復子/
はんぷくせい /反復性/
はんぷくてき /反復的/
はんぷくはいれつ /反復配列/
はんぷくほう /反復法/
はんぷけん /頒布権/
はんべい /反米/
はんべいかんじょう /反米感情/
はんべえ /半兵衛/
はんべそ /半べそ;-をかく/半ベソ/
はんべつ /判別/
はんべつかのう /判別可能/
はんべつしき /判別式/
はんべつふかのう /判別不可能/
はんべつほう /判別法/
はんぺーじ /半ページ/
はんぺい /藩屏/汎平/
はんぺいた /半平太/
はんぺん /半平;おでんに/半片/反変;contravariant.「-テンソル」/
はんぼいん /半母音/
はんぼう /繁忙/
はんぼうき /繁忙期/
はんぽ /半歩/反哺/
はんぽてまえ /半歩手前/
はんぽん /版本;印刷した本/翻本;翻刻した本/
はんま /半間/
はんまーなげ /ハンマー投げ/
はんまい /飯米/
はんみ /半身/
はんみち /半道/
はんみっしつ /半密室/
はんみょう /斑猫/
はんむ /繁務;busy task/煩務;annoying task/
はんむげん /半無限/
はんむら /半村/
はんめい /判明/藩命/
はんめいしだい /判明次第/
はんめん /反面;†(other side)「その-」/半面;†(one side)「-しか見ない」/版面;印刷する面/
はんめんきょうし /反面教師/
はんも /繁茂/
はんもう /反毛/半盲/
はんもうしょう /半盲症;[医]/
はんもく /反目/半目/
はんもと /版元/
はんもん /斑紋/煩悶/反問/斑文/半文/
はんもんてん /板門店/
はんや /半夜/
はんやき /半焼き/
はんやく /反訳/
はんやけ /半焼け/
はんよう /汎用;all-purpose/繁用;frequently used/藩窯/
はんようおおがたき /汎用大型機/
はんようか /汎用化/
はんようき /汎用機/
はんようきよう /汎用機用/
はんようけいさんき /汎用計算機/
はんようし /反陽子/
はんようせい /汎用性/
はんようせいぎょ /汎用制御/
はんようてき /汎用的/
はんようばん /汎用版/
はんようひん /汎用品/
はんら /半裸/
はんらく /反落/
はんらん /氾濫/反乱/叛乱/汎濫/
はんらんぐん /反乱軍/叛乱軍/
はんらんげん /氾濫原;[地質]floodplain/
はんらんざい /反乱罪/
はんらんぶんし /反乱分子/
はんり /半里/
はんりつ /反立/
はんりゅう /伴流;後流。「ばんりゅう」とも/韓流;[新語]韓国の流行/
はんりゅうし /反粒子/
はんりょ /伴侶/
はんりょう /半量/半両/
はんりょく /反力/
はんりん /半輪/
はんるい /煩累/
はんれい /凡例;legend/判例;[法]precedent/反例;counterexample/範例;exemplum,模範例/范蠡;勾践の部下。「時に-無きにしも非ず」/汎例;?/煩禮/
はんれいいちらん /判例一覧/
はんれいけんきゅう /判例研究/
はんれいしゅう /判例集/
はんれいほう /判例法/
はんれつ /範列/半列/
はんれつかんけい /範列関係;[言語]rapport paradigmatique (Saussureの用語)/
はんろ /販路/坂路;さかみち/
はんろう /藩老/煩労/
はんろん /反論/汎論;summary/
はんろんがわ /反論側/
はんろんしゃ /反論者/
はんろんとうこう /反論投稿/
はんわ /阪和/
はんわこうぎょう /阪和興業;[企業名]/
はんわじどうしゃどう /阪和自動車道/
はんわせん /阪和線/
はんわどう /阪和道/
ば /場/馬/羽/葉/刃/歯/罵/婆/庭/芭;芭蕉/塲;「場」の異体字/刄;「刃」の異体字/
ばーくりうむ /Bk/Berkelium/
ばーじゃーびょう /バージャー病;[医]Buerger's disease/
ばーじょんばんごう /バージョン番号/
ばーすとう /バース党/
ばあ /婆/
ばあい /場合/
ばあいいがい /場合以外/
ばあいさくせい /場合作成/
ばあいぜんじゅつ /場合前述/
ばあいなど /場合等/
ばあいべつ /場合別/
ばあいわけ /場合分け/
ばあさま /婆様/
ばあさん /婆さん/祖母さん/
ばあたり /場当たり;-的/場当り/
ばあたりてき /場当たり的/
ばあや /婆や/
ばい /倍/売/買/賣;「売」の旧字(人名用漢字)/貝;かい/唄;うた/狽;狼狽/培;栽培/賠;賠償/陪;陪審/焙;焙煎/媒;媒介/楳;「梅」の異体字/煤;(すす)煤煙/梅;梅花/苺;(漢音) いちご/黴;黴菌/霾;つちふる/吠;ほ・える/憊;(呉音) 困憊/Ｂｙ/杯/
ばいいじょう /倍以上/
ばいいない /倍以内/
ばいいん /売淫/
ばいう /梅雨/黴雨/
ばいういこう /梅雨以降/
ばいうころ /梅雨頃/
ばいうぜんせん /梅雨前線/
ばいえん /梅園/煤煙/
ばいえんそうしょ /梅園叢書/
ばいおん /倍音/
ばいおんじょう /倍音上/
ばいおんそく /倍音速/
ばいおんれつ /倍音列/
ばいか /売価/梅花/倍加/倍化/買価;?/
ばいかい /媒介/
ばいかいしゃ /媒介者/
ばいかいてき /媒介的/
ばいかいへんすう /媒介変数/
ばいかいへんすうひょうじ /媒介変数表示/
ばいかく /倍角/
ばいかくひょうじ /倍角表示/
ばいかくもじ /倍角文字/
ばいかたんきだいがく /梅花短期大学/
ばいかん /売官/陪観/売勘/
ばいがえし /倍返し/
ばいがく /倍額/
ばいがくいじょう /倍額以上/
ばいきゃく /売却/
ばいきゃくえき /売却益/
ばいきゃくきぼうかかく /売却希望価格/
ばいきゃくさき /売却先/
ばいきゃくじ /売却時/
ばいきゃくぞん /売却損/
ばいきゅう /倍旧/
ばいきん /黴菌/
ばいくとう /バイク盗/
ばいくびん /バイク便;bike messenger/
ばいくらい /倍位/
ばいけつ /売血/
ばいけん /買券/
ばいこく /売国/
ばいこくど /売国奴/
ばいごう /媒合/
ばいごま /貝独楽;ベーゴマ/
ばいざい /媒材/
ばいし /貝子/
ばいしつ /媒質/
ばいしつちゅう /媒質中/
ばいしゃく /媒酌/媒妁;=媒酌/倍尺/
ばいしゃくにん /媒酌人/
ばいしゅう /買収/
ばいしゅん /売春/買春;[新語]「売春」を買う側から見た語。=かいしゅん/
ばいしゅんふ /売春婦/
ばいしゅんぼうしほう /売春防止法/
ばいしゅんやど /売春宿/買春宿;「売春宿」の言い換え語/
ばいしょ /貝書/
ばいしょう /賠償/焙焼/売笑;=売春/
ばいしょうがく /賠償額/
ばいしょうきん /賠償金/
ばいしょうせいきゅう /賠償請求/
ばいしょうせいきゅうけん /賠償請求権/
ばいしょうせきにん /賠償責任/
ばいしょうせきにんほけん /賠償責任保険;生産物-,旅館-,自動車-(=自賠責)/
ばいしょうふ /売笑婦/
ばいしょうめいれい /賠償命令/
ばいしょうろ /焙焼炉/
ばいしょく /売色/陪食/
ばいしん /陪審;jury/陪臣;家来の家来/
ばいしんいん /陪審員/
ばいしんいんせいど /陪審員制度/
ばいしんせい /陪審制/
ばいしんせいど /陪審制度/
ばいしんにん /陪審人/
ばいじゅう /陪従/
ばいじょう /陪乗/
ばいじん /煤塵/
ばいすう /倍数/
ばいすうけい /倍数系/
ばいすうたい /倍数体;[生物]polyploid/
ばいせい /媒精/
ばいせいど /倍精度/
ばいせいどえんざん /倍精度演算/
ばいせいどじっすう /倍精度実数/
ばいせき /陪席/
ばいせきさいばんかん /陪席裁判官/
ばいせん /焙煎/媒染/煤煎/
ばいせんざい /媒染剤;mordant/
ばいそう /黴瘡/
ばいそく /倍速/
ばいそくさいせい /倍速再生/
ばいぞう /倍増/
ばいぞうかん /倍増管/倍増感/
ばいた /売女/
ばいたい /媒体/倍体/
ばいだい /倍大/
ばいち /培地/
ばいちょう /倍長/陪聴/倍調/
ばいていど /倍程度/
ばいてん /売店/
ばいでん /売電/買電/
ばいとく /買得/売得/
ばいとくきん /売得金/
ばいとさき /バイト先/
ばいとすう /バイト数/
ばいとだい /バイト代/
ばいとりょう /バイト料/
ばいどく /梅毒/
ばいにく /梅肉/
ばいにん /売人/
ばいはば /倍幅/
ばいばい /売買/倍々/
ばいばいえき /売買益/
ばいばいけいやく /売買契約/
ばいばいこうしょう /売買交渉/
ばいばいしゅん /売買春/
ばいばいしょうこきん /売買証拠金/
ばいばいだいきん /売買代金/
ばいばいだか /売買高/
ばいばら /莪原/
ばいひん /売品/
ばいふうかん /培風館/
ばいぶん /売文/
ばいべんてき /買弁的/
ばいぼく /売卜/
ばいまん /倍満;[麻雀]/
ばいめい /売名/
ばいめいしん /売名心/
ばいやく /売約/売薬/
ばいやくしょ /売約書/
ばいやくずみ /売約済み/
ばいやくまん /倍役満/
ばいゆう /培雄/
ばいよう /培養/
ばいようえき /培養液/
ばいようき /培養器;incubator/培養基;culture medium/
ばいようど /培養土/
ばいようりょう /倍容量/
ばいりつ /倍率/
ばいりつかくだい /倍率拡大/
ばいりつき /倍率器/
ばいりょう /倍量/
ばいりん /梅林/
ばう /芒/
ばえ /蠅/
ばおり /羽織/
ばか /馬鹿;(当て字)/莫迦/
ばかうれ /バカ売れ/
ばかおや /バカ親/
ばかおんな /馬鹿女/
ばかがい /馬鹿貝/
ばかく /馬格/
ばかさわぎ /馬鹿騒ぎ/バカ騒ぎ/
ばかしょうじき /馬鹿正直/
ばかじから /馬鹿力/
ばかず /場数/
ばかたか /馬鹿高;形容詞[φik(sg)]/バカ高/
ばかたれ /馬鹿たれ/
ばかぢから /馬鹿力/バカ力/
ばかづら /馬鹿面/
ばかていねい /馬鹿丁寧/
ばかとの /馬鹿殿/
ばかね /馬鹿値/
ばかばか /馬鹿馬鹿/
ばかばなし /馬鹿話/
ばかばやし /馬鹿囃子;すっとこどっこい♪/
ばかもの /馬鹿者/
ばかやす /馬鹿安/バカ安/
ばかやろう /馬鹿野郎/バカ野郎/
ばかり /許り/許/秤/
ばかわらい /馬鹿笑い/
ばかん /馬関/馬韓/
ばきゃく /馬脚/
ばきん /馬琴/
ばぎょう /バ行/ば行/
ばく /爆/貘;[動物]tapir/獏;=貘/漠;漠然/莫;莫大/幕;幕府/寞;寂寞/驀;驀進/瀑;瀑布/曝;被曝/暴;(慣用音)暴露/縛;緊縛/博;賭博/麦/麥;「麦」の旧字/駁;反駁/藐;(はるか)/
ばくえい /幕営/
ばくえき /博奕/
ばくえん /爆炎/爆煙/
ばくおん /爆音/
ばくか /幕下/
ばくが /麦芽/
ばくがいんりょう /麦芽飲料/
ばくがとう /麦芽糖/
ばくぎ /博戯/
ばくげき /爆撃/駁撃/
ばくげきき /爆撃機/
ばくげきせいど /爆撃精度/
ばくげきたい /爆撃隊/
ばくさい /爆砕/博才/
ばくさつ /爆殺/
ばくし /爆死/
ばくしゃ /幕舎/
ばくしゅう /麦秋/
ばくしゅく /爆縮/
ばくしょ /曝書/
ばくしょう /爆笑/
ばくしょうげきじょう /爆笑劇場/
ばくしょうへん /爆笑編/
ばくしょうもの /爆笑物/
ばくしん /驀進/幕臣/爆心/爆進/
ばくしんち /爆心地/
ばくすい /爆睡/麦穂/
ばくせい /幕政/
ばくせつ /駁説/
ばくせん /瀑泉/
ばくぜん /漠然/驀然;まっしぐら,にわか/
ばくそう /爆走/麦草/爆装/
ばくそく /爆速/
ばくだい /莫大/
ばくだん /爆弾/爆彈;「弾」旧字/
ばくだんおとこ /爆弾男/
ばくだんしょり /爆弾処理/
ばくだんとうか /爆弾投下/
ばくだんはつ /爆弾発/
ばくだんはつげん /爆弾発言/
ばくだんや /爆弾屋/
ばくだんりょう /爆弾量/
ばくち /博打/博奕/驀地;まっしぐら/
ばくちうち /博打打ち/博奕打ち/
ばくちく /爆竹/
ばくちゃく /縛着/
ばくちん /爆沈/
ばくてん /バク転/
ばくと /博徒/
ばくにゅう /爆乳;[俗]/
ばくにょう /麥繞/
ばくねん /爆燃/
ばくは /爆破/
ばくはじけん /爆破事件/
ばくはつ /爆発/
ばくはつえんじょう /爆発炎上/
ばくはつおん /爆発音/
ばくはつじこ /爆発事故/
ばくはつすんぜん /爆発寸前/
ばくはつせい /爆発性/
ばくはつちゅう /爆発中/
ばくはつてき /爆発的/
ばくはつてきりゅうこう /爆発的流行/
ばくはつぶつ /爆発物/
ばくはつりょく /爆発力/
ばくはん /幕藩/麦飯/
ばくはんたいせい /幕藩体制/
ばくふ /幕府/瀑布/
ばくふう /爆風/
ばくふぐん /幕府軍/
ばくまつ /幕末/
ばくやく /爆薬/
ばくらい /爆雷/
ばくらいせん /爆雷戦/
ばくりゅう /瀑流/
ばくりゅうしゅ /麦粒腫;ものもらい/
ばくりょう /幕僚/曝涼/
ばくりょうかんぶ /幕僚監部/
ばくりょうちょう /幕僚長;自衛隊/
ばくれつ /爆裂/
ばくれつだん /爆裂弾/
ばくれん /莫連/
ばくろ /暴露/曝露/
ばくろう /馬喰/伯楽/博労/伯労/
ばくろうちょう /馬喰町;現在は「ばくろちょう」。/
ばくろちょう /馬喰町;総武快速線の駅名/
ばくろばなし /暴露話/
ばくろぼん /暴露本/
ばくろれべる /暴露レベル/
ばくろん /駁論/
ばぐ /馬具/
ばぐとり /バグ取り/
ばぐん /馬群/
ばけ /化け/化/
ばけかた /化け方/
ばけがく /化学/
ばけがくしゃ /化学者/
ばけがくてき /化学的/
ばけねこ /化け猫/化猫/
ばけのかわ /化けの皮/
ばけもの /化け物/化物/
ばけん /馬券/
ばけんこうにゅう /馬券購入/
ばけんさくせん /馬券作戦/
ばけんだい /馬券代/
ばけんてき /馬券的/
ばげん /罵言/
ばこ /箱/
ばさし /馬刺し;馬肉の刺身/馬刺/
ばさら /婆娑羅/伐折羅/
ばさん /馬産/
ばさんち /馬産地/
ばし /橋/箸/
ばしご /梯子/
ばしゃ /馬車/
ばしゃうま /馬車馬/
ばしゃく /馬借/
ばしゃじだい /馬車時代/
ばしゃみち /馬車道/
ばしゅ /馬主/馬首/
ばしょ /場所/
ばしょいがい /場所以外/
ばしょいどう /場所移動/
ばしょいり /場所入り;[相撲]/
ばしょう /芭蕉/
ばしょうしちぶしゅう /芭蕉七部集/
ばしょうふ /芭蕉布/
ばしょがら /場所柄/
ばしょく /馬謖;三国時代・蜀漢の臣で、馬良の弟。「泣いて-を斬る」/馬食;「牛飲-」/
ばしょせつ /場所説/
ばしょせんてい /場所選定/
ばしょだい /場所代/
ばしょちゅう /場所中/
ばしょちょくぜん /場所直前/
ばしょてき /場所的/
ばしょふさぎ /場所塞ぎ/
ばしょふめい /場所不明/
ばしょまえ /場所前/
ばしょみてい /場所未定/
ばしょわり /場所割り/
ばしら /柱/
ばしん /馬身/
ばじとうふう /馬耳東風/
ばじゅつ /馬術/
ばじょう /馬上/馬乗/
ばすいぼく /馬酔木/
ばすえ /場末/
ばすがた /バス型/
ばすくご /バスク語;Basque/
ばすけっとぶ /バスケット部/
ばすけっとぼーるぶ /バスケットボール部/
ばすけぶ /バスケ部/
ばすてい /バス停/
ばすはば /バス幅/
ばずーかほう /バズーカ砲;bazooka/
ばせい /罵声/
ばせき /場席/
ばせん /場銭/
ばそり /馬橇/
ばぞく /馬賊/馬族/
ばた /畑/端/
ばたーいため /バター炒め/
ばたーやき /バター焼き/
ばたあし /バタ足/
ばたい /馬体/
ばたいじゅう /馬体重/
ばたく /馬鐸/
ばたけ /畑/畠/
ばたち /場立ち/
ばたや /ばた屋/
ばだい /場代/
ばち /罰/撥;三味線の-/桴;太鼓の-/枹;太鼓の-/鉢/蜂/罸;異体字/
ばちあたり /罰当たり/罰当り/
ばちおと /撥音/
ばちがい /場違い/
ばちすもく /バチス目/Batidales/
ばちゅう /馬柱/
ばちる /撥鏤/
ばっか /幕下/麦価/
ばっかく /幕閣/麦角/
ばっかん /麦稈/
ばっかんさなだ /麦稈真田/
ばっき /曝気/
ばっきょ /抜去/
ばっきん /罰金/
ばっきんがく /罰金額/
ばっきんがむきゅうでん /バッキンガム宮殿;Buckingham Palace/
ばっきんけい /罰金刑/
ばっきんせい /罰金制/
ばっきんせいど /罰金制度/
ばっきんとうりんじそちほう /罰金等臨時措置法/
ばっくてん /バック転/
ばっくねっとうら /バックネット裏/
ばっくよらく /抜苦与楽/
ばっけん /抜剣/
ばっこ /跋扈/
ばっさい /伐採/伐裁/
ばっさつ /抜刷/
ばっし /抜歯/抜糸/末子/
ばっしじ /抜歯時/
ばっしゅ /罰酒/
ばっしゅつ /伐出/
ばっしょう /跋渉/
ばっすい /抜粋/抜萃/
ばっせき /末席/
ばっせん /抜染/
ばっそく /罰則/
ばっそくきてい /罰則規定/
ばっそん /末孫/
ばった /飛蝗/蝗虫/
ばったい /罰退/
ばったく /抜擢;=ばってき/
ばったもの /バッタ物/
ばっちしょり /バッチ処理/
ばってい /末弟/
ばってき /抜擢/抜てき/
ばってん /罰点/×/
ばっとう /抜刀/伐倒/
ばっとうじゅつ /抜刀術/
ばっとうたい /抜刀隊/
ばっぱい /罰杯/
ばっぷ /罰符/
ばっぽん /抜本/
ばっぽんかいかく /抜本改革/
ばっぽんそくげん /抜本塞源/
ばっぽんてき /抜本的/
ばつ /罰/閥;財閥/跋;跋文/抜;海抜/拔;「抜」の旧字(人名用漢字)/伐;討伐/筏;いかだ/魃;旱魃/末;(漢音)/罸;「罰」の異体字/×;記号のバツ/
ばついっぱん /罰一般/
ばつえい /末裔/
ばつぐん /抜群/
ばつげーむ /罰ゲーム/
ばつご /跋語/
ばつざんがいせい /抜山蓋世/
ばつぞく /閥族/
ばつたい /罰退/
ばつだ /罰打/
ばつとうばん /罰当番/
ばつばつ /××/
ばつびょう /抜錨/
ばつぶん /跋文/
ばつぼく /伐木/
ばつよう /末葉/
ばつりゅう /末流/
ばてい /馬蹄/馬丁/
ばていけい /馬蹄形/
ばてれん /伴天連/
ばとう /罵倒/馬頭/
ばとうかんのん /馬頭観音/
ばとうきん /馬頭琴/
ばとうご /罵倒語/
ばとうせいうん /馬頭星雲/
ばどみんとんぶ /バドミントン部/
ばな /鼻/花/端/
ばなか /場中/
ばなし /話/
ばなじうむ /V/Vanadium/
ばなじうむこう /バナジウム鋼;vanadium steel/
ばななあじ /バナナ味/
ばなれ /場慣れ/場馴れ/離れ/
ばにく /馬肉/
ばにゅうしゅ /馬乳酒/
ばにらあじ /バニラ味/
ばぬし /馬主/
ばぬしめい /馬主名/
ばね /発条/羽/羽根/
ばば /馬場/婆/屎/糞/
ばばあ /婆/
ばばぐち /馬場口/
ばばさき /馬場先/
ばばさきもん /馬場先門/
ばばさま /婆様/
ばばじょうたい /馬場状態/
ばばじる /婆汁/
ばばない /馬場内/
ばばぬき /ババ抜き/
ばひつ /馬匹/
ばび /馬尾/
ばふく /馬腹/
ばふだ /場札/
ばふん /馬糞/
ばふんうに /馬糞海胆/
ばふんし /馬糞紙/
ばぶるけいざい /バブル経済/
ばぶるほうかい /バブル崩壊/
ばぼう /馬房/
ばぼうさく /馬防柵/
ばめい /馬名/
ばめん /場面/
ばめんごと /場面毎/
ばめんせってい /場面設定/
ばめんてんかん /場面転換/
ばや /早/速/
ばやし /林/囃子/
ばら /薔薇/原/腹/
ばらい /払い/祓い/
ばらいろ /薔薇色/バラ色/
ばらうり /バラ売り/ばら売り/散売り;<rare>/
ばらえん /薔薇園/バラ園/
ばらか /バラ科/
ばらき /原木/
ばらきなかやま /原木中山/
ばらじゅうじ /薔薇十字/
ばらじゅうじうんどう /薔薇十字運動/
ばらせんそう /薔薇戦争/
ばらぞく /薔薇族/
ばらにく /バラ肉/
ばらのぷすもく /バラノプス目/Balanopales/
ばらばらしたい /バラバラ死体/
ばらまき /ばら撒き/
ばらみず /薔薇水/バラ水/
ばらもく /バラ目/Rosales/
ばらもくあぐん /バラ目亜群/
ばらもくぐん /バラ目群/
ばらものがたり /薔薇物語;Roman de la Rose/
ばらもん /婆羅門/
ばらもんきょう /バラモン教;Brahmanism/
ばらんすかんかく /バランス感覚/
ばらんすがた /バランス型/
ばり /罵詈/張り/針/尿/
ばりうむ /Ba/Barium/
ばりうむかごうぶつ /バリウム化合物/
ばりき /馬力/
ばりきさ /馬力差/
ばりざんぼう /罵詈讒謗/
ばりぞうごん /罵詈雑言/
ばりとう /バリ島;(Bali) Indonesia/
ばる /原/
ばるかん /巴爾幹/
ばるかんはんとう /バルカン半島;ヨーロッパの火薬庫/
ばるかんほう /バルカン砲;Vulcan/
ばるくひん /バルク品/
ばるさみこす /バルサミコ酢/
ばるちっくかんたい /バルチック艦隊;[世界史]ロシアの艦隊。日露戦争で潰滅/
ばれーぶ /バレー部/
ばれーぼーるぶ /バレーボール部/
ばれい /馬齢/馬鈴/
ばれいしょ /馬鈴薯/
ばれん /馬連/
ばろっくおんがく /バロック音楽/
ばろっくちょう /バロック調/
ばろっくようしき /バロック様式/
ばん /番/晩/判/盤;disk/版;version/板;plate/万/萬;「万」の旧字(人名用漢字)/鷭;moorhen/蕃;蕃族/幡;はた/旛;はた/旙;「旛」の異体字/播;(慣用音)播州/絆;絆創膏/伴;伴奏/挽;挽歌/悗/輓;輓馬/磐;磐石/礬;明礬/蛮;南蛮/蠻;「蛮」の旧字/鑁/塙;人名/坂;坂東/阪;(慣用音)/
ばんあれんたい /バンアレン帯/
ばんえつ /磐越/
ばんえつさいせん /磐越西線/
ばんえつじどうしゃどう /磐越自動車道/
ばんえつとうせん /磐越東線/
ばんか /挽歌;elegy/晩夏;late summer/蕃茄;トマト/晩霞;夕焼け/晩歌;?/
ばんかい /挽回/
ばんかず /番数/
ばんから /蛮カラ/
ばんかん /万感;-こもごも/万巻;-の書/
ばんがい /番外/番街/
ばんがいち /番外地/
ばんがいへん /番外編/
ばんがく /晩学/
ばんがさ /番傘/
ばんがた /晩方/
ばんき /晩期/万機/
ばんきょ /蟠踞/
ばんきん /板金/鈑金;=板金/輓近;最近/
ばんきんこう /板金工/
ばんきんや /板金屋/
ばんぎ /板木/盤木/
ばんぎく /晩菊/
ばんくーばー /晩香坡;Vancouver/
ばんくみ /版組/
ばんくるわせ /番狂わせ/
ばんぐせつ /万愚節/
ばんぐみ /番組/
ばんぐみあんない /番組案内/
ばんぐみか /番組化/
ばんぐみかいしとうしょ /番組開始当初/
ばんぐみかいへん /番組改編/番組改変/
ばんぐみかいへんき /番組改編期/
ばんぐみかんけいしゃ /番組関係者/
ばんぐみこうせい /番組構成/
ばんぐみざっし /番組雑誌/
ばんぐみしゅうりょう /番組終了/
ばんぐみしゅうりょうご /番組終了後/
ばんぐみしゅうろくちゅう /番組収録中/
ばんぐみしょき /番組初期/
ばんぐみじたい /番組自体/
ばんぐみじょう /番組上/
ばんぐみじょうほうし /番組情報誌/
ばんぐみせいさく /番組製作/
ばんぐみせいさくしゃ /番組制作者/番組製作者/
ばんぐみせんでん /番組宣伝/
ばんぐみぜんたい /番組全体/
ばんぐみぜんぱん /番組全般/
ばんぐみたいこう /番組対抗/
ばんぐみだい /番組第/
ばんぐみちゅう /番組中/
ばんぐみちゅうし /番組中止/
ばんぐみない /番組内/
ばんぐみないよう /番組内容/
ばんぐみはいきゅう /番組配給/
ばんぐみはつ /番組初/
ばんぐみばんごう /番組番号/
ばんぐみひひょう /番組批評/
ばんぐみひょう /番組表/
ばんぐみへんこう /番組変更/
ばんぐみへんせい /番組編成/
ばんぐみほうそう /番組放送/
ばんぐみめい /番組名/
ばんぐみよやく /番組予約/
ばんぐみらん /番組欄/
ばんけい /晩景/
ばんけん /番犬/
ばんけんもと /版権元/
ばんこ /万戸/万古;ancient/萬古;「万」旧字/盤古;中国の天地開闢の神/
ばんこう /蛮行/万考;千思-/磐高/
ばんこく /万国/盤谷/万斛/
ばんこくおんぴょうもじ /万国音標文字/
ばんこくき /万国旗/
ばんこくきょうつう /万国共通/
ばんこくこうほう /万国公法/
ばんこくはく /万国博/
ばんこくはくらんかい /万国博覧会/
ばんこくゆうびんれんごう /万国郵便連合;UPU/
ばんこっき /万国旗/
ばんこつ /蛮骨/万骨;一将功成りて-枯る/
ばんこふえき /万古不易/
ばんこやき /万古焼/
ばんこん /晩婚/盤根/
ばんこんか /晩婚化/
ばんこんさくせつ /盤根錯節/
ばんご /番後/蛮語/
ばんごう /番号/
ばんごうあんない /番号案内/
ばんごういがい /番号以外/
ばんごうかんり /番号管理/
ばんごうごと /番号毎/
ばんごうしてい /番号指定/
ばんごうじゅん /番号順/
ばんごうたいけい /番号体系/
ばんごうつうち /番号通知/
ばんごうとくてい /番号特定/
ばんごうはんい /番号範囲/
ばんごうひょう /番号表/
ばんごうひょうじ /番号表示/
ばんごうぼ /番号簿/
ばんごうらん /番号欄/
ばんごうわく /番号枠/
ばんごはん /晩御飯/晩ご飯/
ばんごや /番小屋/
ばんさい /磐西/
ばんさく /万策/盤錯/
ばんさん /晩餐/晩産;晩婚-/
ばんさんかい /晩餐会/
ばんざい /万歳/
ばんざいさんしょう /万歳三唱/
ばんし /万死/
ばんしき /盤渉/
ばんしきちょう /盤渉調/
ばんしつ /盤質/
ばんしゃ /万謝/
ばんしゃく /晩酌/
ばんしゅう /晩秋/播州/磐州/
ばんしゅうあこう /播州赤穂/
ばんしゅうじん /播州人/
ばんしゅうちほう /播州地方/
ばんしゅん /晩春/
ばんしょ /板書/番所/蕃書/
ばんしょう /万象;森羅-/万障;-繰り合わせ/番匠;大工/晩鐘/
ばんしょく /伴食/
ばんしん /蕃神/
ばんしんどう /板振動/
ばんじ /万事/
ばんじきゅうす /万事休す/
ばんじゃく /磐石/盤石;=磐石/
ばんじゅく /晩熟/
ばんじょ /磐女/
ばんじょう /盤上/万丈/番匠/万乗/
ばんじん /万人/蛮人;野蛮人/
ばんすい /晩翠/
ばんすいそうどう /晩翠草堂/
ばんすう /番数/
ばんせい /万世/晩成;大器-/晩生;おくて/伴星/蛮声/
ばんせいいっけい /万世一系/
ばんせいいでん /伴性遺伝;[生物]sex-linked inheritance/
ばんせいせつ /万聖節;11.1/
ばんせき /磐石;=ばんじゃく/
ばんせつ /晩節/
ばんせん /番線/番宣;[略語]番組宣伝/
ばんぜん /万全/
ばんそう /伴奏;accompany/伴走;escort/晩霜/
ばんそうこう /絆創膏/ばん創膏/
ばんそうしゃ /伴奏者/
ばんそうばん /伴奏版/
ばんそうぶ /伴奏部/
ばんそつ /番卒/
ばんぞく /蛮族/蕃族;≒蛮族/
ばんたい /万態/
ばんたむきゅう /バンタム級;[ボクシング]53.5kg以下(bantam=鶏)/
ばんたん /万端/播但/盤端/
ばんたんせん /播但線/
ばんだ /万朶/
ばんだい /番台/磐梯;地名/万代/番代/
ばんだいあたみおんせん /磐梯熱海温泉/
ばんだいくぶん /番台区分/
ばんだいさん /磐梯山/
ばんだいちょう /磐梯町/
ばんだいふえき /万代不易/
ばんち /番地/蕃地;未開の地/番値/
ばんちゃ /番茶/
ばんちょう /番長/番町/番丁/
ばんづけ /番付/
ばんづけがい /番付外/
ばんづけひょう /番付表/
ばんて /番手/
ばんてき /蛮的/
ばんとう /番頭/晩冬/晩稲/晩唐/蛮刀/
ばんど /礬土/
ばんどう /坂東/阪東/
ばんどうたまさぶろう /坂東玉三郎/
ばんどうたろう /坂東太郎/
ばんどころ /番所/
ばんない /坂内/判内/
ばんなぐろ /花畔/
ばんなん /万難/
ばんにん /番人;guard/万人;everybody/
ばんにんきょうつう /万人共通/
ばんにんびょうどう /万人平等/
ばんねん /晩年/
ばんの /坂野/伴野/番野/
ばんのう /万能/
ばんのうかぎ /万能鍵/
ばんのうがた /万能型/
ばんのうきかい /万能機械/
ばんのうざお /万能竿/
ばんのうせい /万能性/
ばんのうねぎ /万能葱/万能ネギ/
ばんのうやく /万能薬/
ばんば /輓馬/馬場/番場/
ばんばやし /番囃子;舞なし/
ばんばんいつ /万々一/
ばんばんざい /万々歳/万万歳/
ばんばんじー /棒々鶏/棒棒鶏/
ばんぱく /万博/
ばんぱん /万般/
ばんぶつ /万物/
ばんぶつるてん /万物流転/
ばんぷう /蛮風/
ばんぷく /万福/
ばんぷふとう /万夫不当/
ばんべつ /万別/
ばんぺい /番兵/
ばんぽう /万邦/
ばんみん /万民/
ばんめ /番目/
ばんめし /晩飯/
ばんめん /盤面/
ばんもく /万目/
ばんや /番屋/
ばんゆう /万有/蛮勇/
ばんゆういんりょく /万有引力/
ばんゆういんりょくていすう /万有引力定数/
ばんらい /万来/万雷/万籟/
ばんり /万里/萬里/
ばんりどうふう /万里同風/
ばんりのちょうじょう /万里の長城/
ばんりばし /万里橋/
ばんりゅう /伴流;後流。「はんりゅう」とも/
ばんりょく /万緑/蛮力/
ばんれいしか /バンレイシ科/Annonaceae/
ばんれいせつ /万霊節;11.2/
ばんれき /万暦;中国の年号(1573-1620)/
ばんれきあかえ /万暦赤絵/
ぱ /波/羽/破/播/
ぱーきんそんびょう /パーキンソン病;[医]Parkinson's disease/
ぱーせんと /％;percent/
ぱーてぃーけん /パーティー券/
ぱーとふ /パート譜/
ぱーみる /‰;permill/
ぱーむゆ /パーム油;(palm oil) 椰子油/
ぱーりご /パーリ語;Pali/
ぱーれんちゃん /八連荘;[麻雀]/
ぱあそう /八索/
ぱい /牌/敗/杯/配/盃/π;pi/Π;Pi/
ぱいきじ /パイ生地/
ぱいこー /排骨/
ぱいちゅー /白酒/
ぱいなげ /パイ投げ/
ぱいなっぷるもく /パイナップル目/Bromeliales/
ぱいぱん /白板/
ぱいぷいす /パイプ椅子/
ぱいぷやく /パイプ役;橋渡し/
ぱうだーじょう /パウダー状/
ぱお /包/
ぱおず /包子/
ぱきすたんじん /パキスタン人/
ぱぎょう /パ行/ぱ行/
ぱく /拍/泊/博/愽/駮/朴/
ぱけっとすう /パケット数/
ぱけっとつうしん /パケット通信/
ぱこ /箱/
ぱじゃますがた /パジャマ姿/
ぱすたざら /パスタ皿/
ぱすたや /パスタ屋/
ぱすてるが /パステル画;pastel drawings/
ぱすてるちょう /パステル調/
ぱすまわし /パス回し/
ぱすめい /パス名/
ぱそこんつうしん /パソコン通信/
ぱそつう /パソ通/
ぱたーんか /パターン化/
ぱたーんにんしき /パターン認識/
ぱち /八/
ぱちんこだい /パチンコ台/
ぱちんこだま /パチンコ玉/
ぱちんこてん /パチンコ店/
ぱちんこや /パチンコ屋/
ぱっくりょうきん /パック料金/
ぱっくりょこう /パック旅行;package tour/
ぱっちあて /パッチ当て/
ぱっと /パッと/
ぱつ /発/發;「発」の旧字/
ぱなま /巴奈馬;Panama/
ぱなまうんが /パナマ運河/
ぱなまそうもく /パナマソウ目/Cyclanthales/Synanthae/
ぱなまぼう /パナマ帽;Panama hat/
ぱねるちょうさ /パネル調査;panel survey/
ぱのらましゃしん /パノラマ写真/
ぱぱさん /パパさん/
ぱぶりしてぃけん /パブリシティ権/
ぱら /腹/
ぱらじうむ /Pd/Palladium/
ぱらふぃんし /パラフィン紙/
ぱられるせつぞく /パラレル接続/
ぱり /巴里;Paris/
ぱりさい /パリ祭;フランスの革命記念日。7.14/
ぱりじょうやく /パリ条約/
ぱりだいがく /パリ大学;Universite de Paris. NB:13ある/
ぱりっこ /パリっ子/
ぱるすはば /パルス幅/
ぱれーとさいてき /パレート最適;[ゲーム理論]Pareto optimum/
ぱれすちなじん /パレスチナ人/
ぱん /麺麭/版/幇/搬/板/播/犯/
ぱんきじ /パン生地/
ぱんこ /パン粉/
ぱんしょく /パン食/
ぱんだね /パン種;[料理]leaven/
ぱんづくり /パン作り/
ぱんとてんさん /パントテン酸/
ぱんや /パン屋/
ひ /日/火/比/非/費/秘/被/妃/否/陽/灯/飛/悲/緋;vermillion/皮/杼;織機の-/梭;=杼/干/乾;(ハ行上一段 未然・連用形)/卑;卑語/碑;碑文/俾/婢;奴婢/痺;麻痺/脾;脾臓/裨;裨益/髀;髀肉/避;避難/臂;ひじ/譬;譬喩/彼;彼我/披;披露/疲;疲労/鞁;むながい/匪;卑俗/扉;門扉/斐;斐紙/誹;誹謗/暃/腓;こむら/菲;(うすい)/蜚;蜚語/霏/批;批判/妣;(死んだ母)/砒;砒素/秕;しいな/紕/貔/豼;「貔」の異体字/庇;(ひさし)庇護/毘;荼毘/蓖;蓖麻子油/轡;くつわ/罷;罷免/肥;肥満/樋;とい/簸/氷;氷室/丕;おおきい/匕;匕首(あいくち)/朏;みかづき/狒;狒々/痞;つかえ/贔;贔屓/鄙;辺鄙/鞴;ふいご/檜;ひのき/桧;「檜」の異体字/泌;泌尿器/祕;「秘」の旧字(人名用漢字)/昜;?/
ひ> /被/非/乾;(ハ行上一段 未然・連用形)乾物,乾反る,乾死ぬ,乾涸びる/干;(ハ行上一段 未然・連用形)干潮,干上がる,干死に,干付く/
ひあい /悲哀/非愛/
ひあそび /火遊び/
ひあたり /日当たり/日当り/陽当たり;-良好/陽当り/
ひあっしゅく /非圧縮/
ひあっしゅくじ /非圧縮時/
ひあっしゅくせい /非圧縮性/
ひあぶり /火炙り/火焙り/
ひあみ /火網;こんろの-/
ひあるろんさん /ヒアルロン酸;hyaluronic acid/
ひあんだ /被安打/
ひい /非違/緋衣/曾/贔;贔屓/
ひい> /曾;-[爺婆](さん|ちゃん)/
ひいき /贔屓/
ひいきめ /贔屓目/
ひいきりきし /贔屓力士/
ひいく /肥育/
ひいじじ /曽祖父/
ひいぞん /非依存/
ひいちにち /日一日/
ひいて /延いて/
ひいては /延いては;更には/
ひいな /雛/
ひいなぼん /雛本/
ひいまご /曾孫/
ひいらぎ /柊/
ひいれ /火入れ/
ひいれしき /火入式/
ひいろ /緋色/
ひいんがてき /非因果的/
ひいんじ /非印字/
ひう /日宇/非有;nonexistence/
ひうお /氷魚/干魚/乾魚/
ひうち /火打ち/燧/
ひうちいし /火打ち石/燧石/
ひうちやま /火打山/
ひうちょう /日宇町/
ひうら /日浦/火浦/樋浦/日裏/
ひうん /悲運;doom/飛雲/非運;hard luck/
ひえ /稗/冷え/
ひえい /比叡/飛影/飛栄/
ひえいごけん /非英語圏/
ひえいざん /比叡山/
ひえいざんこうこう /比叡山高校/
ひえいり /非営利/
ひえいりかつどう /非営利活動/
ひえいりせい /非営利性/
ひえいりそしき /非営利組織/
ひえいりだんたい /非営利団体/
ひえいりほうじん /非営利法人/
ひえいりもくてき /非営利目的/
ひえいりりよう /非営利利用/
ひえき /裨益/桧枝岐/
ひえこみ /冷え込み/冷えこみ/
ひえしょう /冷え性/
ひえじんじゃ /日枝神社/
ひえたいしゃ /日吉大社/
ひえだ /稗田/檜枝/
ひえだのあれ /稗田阿礼;古事記/
ひえつ /飛越/
ひえづ /日吉津/
ひえぬき /稗貫/
ひえびえ /冷え冷え/
ひえまき /稗蒔き/
ひえめし /稗飯/
ひえん /飛燕/
ひえんざんすう /被演算数/
ひお /氷魚/
ひおう /秘奥/
ひおうぎ /檜扇/
ひおうどう /非王道/
ひおおい /日覆い/
ひおき /日置/
ひおけ /火桶/
ひおとこ /火男/
ひおんせい /非音声/
ひか /皮下/悲歌/砒化/
ひかいいん /非会員/
ひかいいんがくせい /非会員学生/
ひかいいんりょうきん /非会員料金/
ひかいせき /被解析/
ひかいてん /非回転/
ひかえ /控え/控/
ひかえしつ /控室/控え室/
ひかえせんしゅ /控え選手/
ひかえばしら /控柱/控え柱/
ひかえめ /控え目/
ひかかい /非可解/
ひかかん /非可換/
ひかかんぐん /非可換群/
ひかがくてき /非科学的/
ひかがみ /膕/
ひかき /火掻き/
ひかきん /非課金/
ひかぎゃく /非可逆/
ひかぎゃくあっしゅく /非可逆圧縮/
ひかく /比較/皮革/非核/飛角/皮角/
ひかく> /比較;(comparative) -言語学,-民俗学,-文法/
ひかくあいて /比較相手/
ひかくえんざんし /比較演算子/
ひかくおん /比較音/
ひかくか /非核化/
ひかくかのう /比較可能/
ひかくかんすう /比較関数/
ひかくき /比較器/
ひかくきじ /比較記事/
ひかくきゅう /比較級/
ひかくけっか /比較結果/
ひかくけんきゅう /比較研究;comparative study/
ひかくけんとう /比較検討/
ひかくげんごがく /比較言語学/
ひかくさんげんそく /非核三原則;持たず・作らず・持ち込ませず/
ひかくしげき /比較刺激/
ひかくしちょう /比較視聴/
ひかくしゅうきょうがく /比較宗教学;comparative religion/
ひかくしんわがく /比較神話学;comparative mythology/
ひかくじっけん /比較実験/
ひかくたいしょう /比較対象/
ひかくてい /非確定/
ひかくてき /比較的/
ひかくてき> /比較的/
ひかくはんだん /比較判断/
ひかくひょう /比較表/
ひかくぶんがく /比較文学;comparative litterature/
ひかくぶんぽう /比較文法;comparative grammer/
ひかくほう /比較法/
ひかくほうがく /比較法学;comparative law/
ひかくゆうい /比較優位;comparative advantage/
ひかくろん /比較論/
ひかげ /日陰;†日光の当たらぬ場所。「-の身」/日影;†太陽の光。「-が射す」/火影/日蔭/
ひかげきせい /日影規制;[建築]/
ひかげず /日影図;[建築]建物が作る影を記した図面/
ひかげぶぶん /日陰部分/
ひかげもの /日陰者/
ひかげん /火加減/
ひかこうがい /悲歌慷慨/
ひかさん /非可算/
ひかさんむげん /非可算無限/
ひかしぼう /皮下脂肪/
ひかず /日数/
ひかぜい /非課税/
ひかぜいぎょうしゃ /非課税業者/
ひかぜいしょとく /非課税所得/
ひかぜいわく /非課税枠/
ひかそしき /皮下組織/
ひかた /干潟/日方/
ひかちゅうしゃ /皮下注射/
ひかっせい /非活性/
ひかっせいか /非活性化/
ひかねつ /非加熱/
ひかねつせいざい /非加熱製剤/
ひかみ /氷上/
ひかめい /非加盟/
ひかめいこく /非加盟国/
ひかり /光/芒/
ひかりかいせん /光回線/
ひかりかんれん /光関連/
ひかりがおか /光が丘/
ひかりきゅうしゅう /光吸収/
ひかりぎじゅつ /光技術/
ひかりぎょうこ /光凝固/
ひかりこうかん /光交換/
ひかりこうがく /光工学/
ひかりごけ /光蘚/
ひかりしげき /光刺激/
ひかりしゅうよう /光収容/
ひかりしゅつりょく /光出力/
ひかりしょくばい /光触媒/
ひかりしんごう /光信号/
ひかりじき /光磁気/
ひかりじきでぃすく /光磁気ディスク;magnet-optical disk(MO)/
ひかりじゅうごう /光重合;[化学]photo polymerisation/
ひかりじゅようき /光受容器/
ひかりじょうほう /光情報/
ひかりそうさ /光走査/
ひかりたんし /光端子/
ひかりだい /光台/
ひかりちゅうせいし /光中性子;photoneutron/
ひかりつうしん /光通信/
ひかりつうしんほうしき /光通信方式/
ひかりてんじょう /光天井;[建築]luminous ceiling/
ひかりでぃすく /光ディスク;optical disk/
ひかりでんち /光電池/
ひかりどけい /光時計/
ひかりはつでん /光発電/
ひかりはんのう /光反応/
ひかりふぁいば /光ファイバ/
ひかりふぁいばー /光ファイバー/
ひかりもの /光り物/光物/
ひかる /光/熈/
ひかるげんじ /光源氏/
ひかわ /氷川/斐川/簸川/
ひかわじんじゃ /氷川神社/火川神社/
ひかわまる /氷川丸/
ひかん /悲観/避寒/被官/被管;=被官/卑官;低い官位/
ひかんさいじん /非関西人/
ひかんさん /比換算/
ひかんし /悲観視/
ひかんしゅぎ /悲観主義/
ひかんじ /非漢字/
ひかんじけん /非漢字圏/
ひかんせいけい /非慣性系/
ひかんせん /非感染/
ひかんぜいしょうへき /非関税障壁/
ひかんつう /非貫通/
ひかんてき /悲観的/
ひかんよう /非寛容/
ひかんり /非管理/
ひかんろん /悲観論/
ひが /彼我/非我;Nicht-Ich/僻/比嘉/
ひがい /被害/鰉/
ひがいいしき /被害意識/
ひがいがく /被害額/
ひがいがわ /被害側/
ひがいきゅうさい /被害救済/
ひがいきんがく /被害金額/
ひがいしゃ /被害者/
ひがいしゃいしき /被害者意識/
ひがいしゃがわ /被害者側/
ひがいしゃほご /被害者保護/
ひがいしんこく /被害申告/
ひがいじゅうみん /被害住民/
ひがいじょうきょう /被害状況/
ひがいじんだい /被害甚大/
ひがいそうがく /被害総額/
ひがいたいおう /被害対応/
ひがいとどけ /被害届/
ひがいはっせい /被害発生/
ひがいもうそう /被害妄想/
ひがいもうそうてき /被害妄想的/
ひがえり /日帰り/
ひがえりしゅじゅつ /日帰り手術;day surgery/
ひがえりりょこう /日帰り旅行/
ひがき /檜垣/桧垣/
ひがく /非学/
ひがくしゅう /非学習/
ひがけ /日掛け/
ひがごと /僻事/
ひがさ /日傘/日暈;solar halo/
ひがし /東/干菓子/
ひがし> /東;-アジア,-ヨーロッパ/
ひがしあおもり /東青森/
ひがしあおやま /東青山/
ひがしあわくら /東粟倉/
ひがしいけ /東池/
ひがしいけぶくろ /東池袋/
ひがしいこま /東生駒/
ひがしいず /東伊豆/
ひがしいずほうめん /東伊豆方面/
ひがしいずみ /東和泉/
ひがしいずも /東出雲/
ひがしいちき /東市来/
ひがしいちじょう /東一条/
ひがしいばらき /東茨城/
ひがしいややま /東祖谷山/
ひがしいわい /東磐井/
ひがしいんどがいしゃ /東インド会社;[世界史]East India Company/
ひがしうすき /東臼杵/
ひがしうめだえき /東梅田駅/
ひがしうら /東浦/
ひがしうわ /東宇和/
ひがしえき /東駅/
ひがしお /東尾/
ひがしおうめ /東青梅/
ひがしおおぎじま /東扇島/
ひがしおおさか /東大阪/
ひがしおおさかし /東大阪市/
ひがしおおさかせん /東大阪線/
ひがしおおじ /東大路/
ひがしおおたに /東大谷/
ひがしおかざき /東岡崎/
ひがしかいがん /東海岸/
ひがしかぐら /東神楽/
ひがしかすがい /東春日井/
ひがしかぜ /東風/
ひがしかた /東方/
ひがしかつしか /東葛飾/
ひがしかながわ /東神奈川/
ひがしかも /東加茂/
ひがしかるいざわ /東軽井沢/
ひがしかわ /東川/
ひがしかわぐち /東川口/
ひがしかわぐちえき /東川口駅/
ひがしかん /東館/
ひがしかんとう /東関東/
ひがしかんばら /東蒲原/
ひがしがわ /東側/
ひがしがわしょこく /東側諸国/
ひがしがわじんえい /東側陣営/
ひがしきたざわ /東北沢/
ひがしきたざわえき /東北沢駅/
ひがしきりゅう /東桐生/
ひがしぎんざ /東銀座/
ひがしく /東区/
ひがしくしろ /東釧路/
ひがしくち /東口/
ひがしくにさき /東国東/
ひがしくにのみや /東久邇宮/
ひがしくびき /東頚城/
ひがしくるめ /東久留米/
ひがしぐち /東口/
ひがしぐちてん /東口店/
ひがしこう /東高/
ひがしこうえん /東公園/
ひがしこうえんじ /東高円寺/
ひがしこうべ /東神戸/
ひがしこがねい /東小金井/
ひがしこむすび /東小結/
ひがししいじ /東椎路/
ひがししおじり /東塩尻/
ひがししずおか /東静岡/
ひがししらかわ /東白川/
ひがししりいけ /東尻池/
ひがしじま /東島/
ひがしじゅうじょう /東十条/
ひがしじゅうりょう /東十両/
ひがしすみよし /東住吉/
ひがしせきわけ /東関脇/
ひがしせふり /東背振/
ひがしせんだまち /東千田町/
ひがしそのぎ /東彼杵/
ひがしたがわ /東田川/
ひがしたてやま /東館山/
ひがしだ /東田/
ひがしちく /東地区/
ひがしちくま /東筑摩/
ひがしちちぶ /東秩父/
ひがしちば /東千葉/
ひがしちもーる /東チモール;East Timor/
ひがしちょう /東町/
ひがしつがる /東津軽/
ひがしつの /東津野/
ひがしてぃもーる /東ティモール;East Timor. 2002年、インドネシアから独立/
ひがしでぐち /東出口/
ひがしとう /東棟/
ひがしとうきょう /東東京/
ひがしとうきょうたいかい /東東京大会/
ひがしとうきょうだいひょう /東東京代表/
ひがしところざわ /東所沢/
ひがしとつか /東戸塚/
ひがしとつかえき /東戸塚駅/
ひがしとなみ /東砺波/東礪波/
ひがしどいつ /東ドイツ;Ostdeutschland/
ひがしどうり /東通/
ひがしなか /東中/
ひがしなかす /東中州/
ひがしなかの /東中野/
ひがしなかやま /東中山/
ひがしなだ /東灘/
ひがしなだく /東灘区/
ひがしなりた /東成田/
ひがしなるせ /東成瀬/
ひがしにほん /東日本/
ひがしにほんいがい /東日本以外/
ひがしにほんけい /東日本系/
ひがしにほんじん /東日本人/
ひがしにほんだいひょう /東日本代表/
ひがしにほんへん /東日本編/
ひがしね /東根/
ひがしの /東野/
ひがしのしろ /東能代/
ひがしのしろえき /東能代駅/
ひがしはま /東浜/
ひがしはら /東原/
ひがしはんきゅう /東半球/
ひがしはんのう /東飯能/
ひがしはんぶん /東半分/
ひがしばる /東原/
ひがしひろしま /東広島/
ひがしひろしまえき /東広島駅/
ひがしひろしまし /東広島市/
ひがしふしみ /東伏見/
ひがしふしみのみや /東伏見宮/
ひがしふじ /東富士/
ひがしべついん /東別院/
ひがしほんがんじ /東本願寺/
ひがしほんがんじまえ /東本願寺前/
ひがしまいづる /東舞鶴/
ひがしまち /東町/
ひがしまつうら /東松浦/
ひがしまつやま /東松山/
ひがしまつやまし /東松山市/
ひがしむき /東向き/
ひがしむこうじま /東向島/
ひがしむら /東村/
ひがしむらやま /東村山/
ひがしむらやましみん /東村山市民/
ひがしむろ /東牟婁/
ひがしむろらん /東室蘭/
ひがしめいはん /東名阪/
ひがしもろかた /東諸県/
ひがしもん /東門/
ひがしやつしろ /東八代/
ひがしやま /東山/
ひがしやまこ /東山湖/
ひがしやまごじょう /東山五条/
ひがしやまさんじょう /東山三条/
ひがしやまじだい /東山時代;1449-73/
ひがしやません /東山線/
ひがしやまてんのう /東山天皇/
ひがしやまと /東大和/
ひがしやまとし /東大和市/
ひがしやまどの /東山殿;銀閣寺／足利義政/
ひがしやまなし /東山梨/
ひがしゆり /東由利/
ひがしよーろっぱ /東ヨーロッパ/
ひがしよか /東与賀/
ひがしよしの /東吉野/
ひがしよどがわ /東淀川/
ひがしりしり /東利尻/
ひがしわかやま /東和歌山/
ひがた /干潟/
ひがないちにち /日がな一日/
ひがね /日金/
ひがみ /僻み/
ひがみこんじょう /僻み根性/
ひがめ /僻目/
ひがら /日柄/日雀/
ひがわり /日替わり/日替り/日変わり/
ひがわりていしょく /日替わり定食/
ひがん /彼岸/悲願/飛雁;-は行を乱さず/
ひがんえ /彼岸会/
ひがんざくら /彼岸桜/
ひがんたっせい /悲願達成/
ひがんばな /彼岸花/
ひき /匹/悲喜/誹毀;-侮辱/疋;≒匹/蟇;蟇蛙/引き/比企;人名/日置;地名/引/曳/挽/蟆;(がま) NB:生物としてはガマガエル=ヒキガエル/
ひきあい /引き合い;-に出す/引合/引合い/
ひきあけ /引明け/
ひきあげ /引き上げ/引上げ/
ひきあげしゃ /引揚者/引き揚げ者/引揚げ者/
ひきあげせん /引上線/
ひきあて /引当/引き当て/引当て/
ひきあてきん /引当金/
ひきあみ /引き網/引網/曳き網/
ひきあわせ /引合せ/
ひきうけ /引受/引き受け/引受け/
ひきうけがいしゃ /引受会社/
ひきうけて /引き受け手/引受け手/
ひきうけにん /引受人/
ひきうた /引歌/
ひきお /引尾/
ひきおとし /引き落とし/
ひきかえ /引き換え/引換/引き替え/引替/引替え/
ひきかえけん /引換券/引き換え券/引替券/
ひきかえしょう /引換証/
ひきかた /弾き方/引き方/挽き方/
ひきかたり /弾き語り/
ひきがえる /蟾蜍/蟇蛙/
ひきがし /引き菓子;引き出物のお菓子/引菓子/
ひきがたり /弾き語り/
ひきがね /引き金/引金/引き鉦/
ひきがわ /日置川/
ひきぎわ /引き際/退き際/
ひきぐん /比企郡/
ひきげき /悲喜劇/
ひきこみ /引き込み/引込/引込み/
ひきこみせん /引込線/引き込み線;鉄道・電線の/引込み線/
ひきこみど /引込み戸/引き込み戸/
ひきこもごも /悲喜交々/
ひきこもり /引きこもり/
ひきごう /非記号/
ひきごと /引言/
ひきさげ /引下げ/引き下げ/
ひきざん /引き算/引算/
ひきしお /引き潮/引き汐/
ひきしめ /引き締め/引締め/
ひきすう /引数/引き数/
ひきすうかんすう /引数関数/
ひきぞめ /弾き初め/
ひきた /疋田/引田/
ひきたえき /引田駅/
ひきたて /引き立て/引立て/
ひきたてやく /引き立て役/引立て役/
ひきだ /疋田/引田/
ひきだし /引き出し/引出し/抽斗/抽き出し/抽出;NB:「ちゅうしゅつ」と同形/抽出し/引出/
ひきだししき /引出式/
ひきち /引地/
ひきちがい /引き違い/引違い/引違/
ひきちがいど /引き違い戸/引違い戸/
ひきちだい /引地台/
ひきつえん /非喫煙/
ひきつえんしゃ /非喫煙者/
ひきつぎ /引き継ぎ/引継ぎ/引きつぎ/
ひきつけ /引き付け/引付け/痙/
ひきつづき /引き続き/引続き/
ひきつる /痙/
ひきづな /引き綱;tug/
ひきて /引き手/引手/弾き手/
ひきてぢゃや /引手茶屋/
ひきでもの /引出物/引き出物;結婚式の-/
ひきとり /引き取り/引取り/引取/
ひきとりさき /引取先/
ひきとりて /引き取り手/引取手/
ひきとりにん /引取人/
ひきど /引き戸/引戸/
ひきどき /引き時/
ひきにく /挽肉/挽き肉/ひき肉/
ひきにげ /轢き逃げ/ひき逃げ/
ひきぬき /引き抜き/
ひきのばし /引き伸ばし;写真の-/引き延ばし;-を図る/引伸ばし/
ひきのばしき /引伸機/
ひきはじめ /引き始め/
ひきふだ /引札/
ひきふね /曳舟/曳船/引船/引き船/曳き船/引き舟/引舟/曳き舟/
ひきまく /引幕/
ひきみ /匹見/
ひきめ /蟇目/
ひきめかぎはな /引目鉤鼻/
ひきもきらず /引きも切らず/
ひきもの /引物/引き物;(雅楽の)弦楽器/
ひきゃく /飛脚/
ひきや /曳家;建築物の水平移動/引家/
ひきやま /引山/
ひきゅう /飛球/悲泣/秘笈/
ひきゅうせん /飛球線/
ひきゅうほうこう /飛球方向/
ひきゅうめん /非球面/
ひきょう /秘境/卑怯/秘教/悲境/比況/悲況/
ひきょうかい /非境界/
ひきょうごうてき /非競合的/
ひきょうてき /秘教的/
ひきょうもの /卑怯者/
ひきょうゆう /非共有/
ひきょうりょく /非協力/
ひきょうりょくてき /非協力的/
ひきょく /秘曲/悲曲/
ひきょくしょ /非局所/
ひきょくしょてき /非局所的/
ひきょじゅうしゃ /非居住者/
ひきょり /飛距離/
ひきりょう /引両/
ひきわけ /引き分け/引分/引分け/
ひきわけすう /引分数/
ひきわざ /引き技/
ひきわたし /引渡し/引き渡し;delivery/引渡/
ひきわたしび /引渡日/
ひきわり /挽き割り/引き割り;歌舞伎の-/引割/引割り/碾き割り;-納豆/
ひきん /卑近/
ひきんいつ /非均一/
ひきんしつ /非均質/
ひきんぞく /非金属;nonmetal/卑金属;base metal. 酸化されやすい金属。⇔貴金属/
ひぎ /秘技/秘儀/秘義/秘戯/非議/非義/氷木/誹議/比擬/
ひぎしゃ /被疑者/
ひぎゃく /被虐;⇔加虐/
ひぎゃくたいじ /被虐待児/
ひぎゃくたいじしょうこうぐん /被虐待児症候群/
ひぎょう /罷業/飛行;[仏教]神足通/非業;=ひごう/非形/
ひぎんえんしゃしん /非銀塩写真/
ひぎんこう /非銀行/
ひく /低/引く/−;minus/攣/牽/佗/
ひくいどり /火喰鳥/
ひくいな /緋水鶏/緋秧鶏/
ひくう /非空/
ひくうてい /飛空艇/
ひくうはくもじ /非空白文字/
ひくつ /卑屈/
ひくて /引く手/
ひくてあまた /引く手数多/
ひくま /曳馬;地名/
ひくみ /低み/
ひくめ /低め/低目/
ひぐち /樋口/火口/
ひぐちいちよう /樋口一葉/
ひぐちうち /火口内/
ひぐま /羆/日熊/
ひぐらし /蜩/日暮らし/日暮/日暮し/茅蜩/
ひぐれ /日暮/日暮れ/
ひぐれがた /日暮れ方/
ひぐんじてき /非軍事的/
ひけ /引け/
ひけい /秘計/
ひけいけんしゃ /非経験者/
ひけいざいてき /非経済的/
ひけいしき /非形式/
ひけいしきてき /非形式的/
ひけいやく /非契約/
ひけぎわ /引け際/
ひけし /火消し/
ひけしやく /火消し役/
ひけそうば /引け相場/
ひけた /引田/
ひけっしょう /非結晶/
ひけってい /非決定/
ひけっていせい /非決定性/
ひけっていてき /非決定的/
ひけっていろん /非決定論/
ひけつ /秘訣/否決/秘結;便秘/碑碣/
ひけどき /引け時/退け時/
ひけね /引け値/
ひけめ /引け目/
ひけん /比肩/被験/披見;開いて読む/卑見;「-では」/
ひけんさく /被検索/
ひけんしゃ /被験者;†(実験の)/被検者;†(検査の)/
ひけんじゃ /被験者;†(実験の)/被検者;†(検査の)/
ひけんせつてき /非建設的/
ひげ /髭;口ひげ/卑下/鬚;顎ひげ/髯;頬ひげ/
ひげい /秘芸/
ひげいじゅつてき /非芸術的/
ひげき /悲劇/
ひげきせい /悲劇性/
ひげきてき /悲劇的/
ひげくじら /鬚鯨;mysticete/
ひげくろ /髭黒/
ひげけっしょう /髭結晶/
ひげそり /髭剃り/ひげ剃り/
ひげづら /髭面/
ひげね /鬚根/ひげ根/
ひげねけい /ひげ根系/鬚根系/
ひげもじゃ /髭もじゃ/
ひげんぎょう /非現業/
ひげんごてき /非言語的/
ひげんしょう /非減少/
ひげんじつ /非現実/
ひげんじつせい /非現実性/
ひげんじつてき /非現実的/
ひげんてい /非限定/
ひこ /彦/比古/曾孫/秘湖/
ひこう /飛行/非行/肥厚/秘孔/比高;地表の高度差/披講/飛蝗/飛光/飛講/
ひこうか /非行化/
ひこうかい /非公開/
ひこうかいがいしゃ /非公開会社/
ひこうかいじょうほう /非公開情報/
ひこうかいぶ /非公開部/
ひこうかんぱん /飛行甲板/
ひこうき /飛行機/
ひこうきえいこう /飛行機曳航/
ひこうきぐも /飛行機雲/
ひこうきじこ /飛行機事故/
ひこうきだい /飛行機代/飛行機台;[パチンコ]/
ひこうきない /飛行機内/
ひこうきょり /飛行距離/
ひこうきりょこう /飛行機旅行/
ひこうきろく /飛行記録/
ひこうけんにん /被後見人/
ひこうこうど /飛行高度/
ひこうこうばん /飛行甲板/
ひこうさ /非交差/
ひこうし /飛行士/
ひこうしき /非公式/
ひこうしきけんかい /非公式見解/
ひこうしょうねん /非行少年/
ひこうしれい /飛行指令/
ひこうしん /粃糠疹/
ひこうじかん /飛行時間/
ひこうじょう /飛行場/
ひこうじょうあと /飛行場跡/
ひこうじょうたい /飛行状態/
ひこうせいてき /非構成的/
ひこうせき /飛行石;[アニメ]『天空の城ラピュタ』/
ひこうせん /飛行船/
ひこうたい /飛行隊/
ひこうち /非公知/
ひこうちゅう /飛行中/
ひこうてい /飛行艇/
ひこうにん /非公認/
ひこうひょう /非公表/
ひこうびん /飛行便/
ひこうぶったい /飛行物体/
ひこうりつ /非効率/
ひこうりつてき /非効率的/
ひこえ /彦衛/
ひこがみ /彦神;⇔姫神/比古神;⇔比売神/
ひこく /被告/
ひこくがわ /被告側/
ひこくにん /被告人/
ひこくみん /非国民/
ひこくみんあつかい /非国民扱い/
ひこさぶろう /彦三郎/
ひこしま /彦島/
ひこしまぐち /彦島口/
ひこじま /彦島/
ひこじん /非個人/
ひこたろう /彦太郎/
ひこつ /腓骨/
ひこてい /非固定/
ひこてんろんり /非古典論理/
ひこなり /彦生;姓/
ひこね /彦根/
ひこねしりつ /彦根市立/
ひこねじょう /彦根城/
ひこねひがし /彦根東/
ひこの /彦野/
ひこのじょう /彦之丞/
ひこばえ /蘖/
ひこぼし /彦星/
ひこようしゃ /被雇用者/
ひこん /非婚;[新語]敢えて結婚しないこと/
ひこんか /非婚化/
ひご /庇護/肥後/飛語/卑語/籤/蜚語;流言-/籖;「籤」の異体字/秘語/
ひごい /緋鯉/
ひごう /非業;-の死/非合;?/
ひごうし /火格子/
ひごうほう /非合法/
ひごうり /非合理/
ひごうりてき /非合理的/
ひごか /庇護下/
ひごかん /非互換/
ひごかんせい /非互換性/
ひごぎんこう /肥後銀行/
ひごけん /庇護権;[法]right of asylum/
ひごたのうら /肥後田浦/
ひごと /日毎/
ひごのかみ /肥後の守/
ひごばし /肥後橋/
ひごよみ /日暦/
ひごろ /日頃/
ひさ /飛砂;blown sand/久/尚/寿/央/壽;「寿」の旧字(人名用漢字)/
ひさあき /久昭/
ひさい /被災/久居;地名,三重/非才;浅学-/菲才;≒非才 NB:「菲」は「薄い」/
ひさいし /久石/
ひさいしゃ /被災者/
ひさいしょういそう /非最小位相/
ひさいち /被災地/
ひさいべんさい /非債弁済/
ひさえ /久恵/寿恵/寿江/久栄/
ひさお /久雄/久夫/久男/寿夫/寿雄/寿男/尚夫/尚生/尚勇/
ひさおじゅうらん /久生十蘭/
ひさか /樋坂/日阪/桶坂/
ひさかず /久和/久一/永和/
ひさかた /久方/
ひさかたぶり /久方振り/久方振/
ひさかど /久門/
ひさかわ /久川/
ひさき /火先/久木/寿樹/
ひさきち /久吉/
ひさく /秘策/
ひさくせい /非作成/
ひさくに /久国/
ひさこ /久子/寿子/比佐子/妃沙子/
ひさご /瓢/瓠/匏/蠡/
ひさし /庇/廂;=庇/久/尚/寿/央/恒/久志/壽;「寿」の旧字(人名用漢字)/尚志/久司/寿史/
ひさしがみ /庇髪/廂髪/
ひさした /久下/
ひさしぶり /久し振り/久しぶり/
ひさしま /久島/
ひさずみ /久住;姓/
ひさたか /尚敬/
ひさだ /久田/
ひさつせん /肥薩線/
ひさと /久人/尚登/尚人/久登/
ひさとし /久敏/尚敏/
ひさとみ /久富/
ひさとめ /久留/
ひさどめ /久留/
ひさなお /久尚/
ひさなが /久永/久長/
ひさの /久野/
ひさのぶ /久信/
ひさのり /久典/尚典/寿則/久寛/寿憲/
ひさはら /久原/
ひさはる /尚玄/寿春/
ひさば /久馬/
ひさひこ /寿彦/
ひさひろ /久寛/久浩/
ひさびさ /久々/
ひさべつ /被差別/
ひさべついしき /被差別意識/
ひさべつしゃ /被差別者/
ひさべつぶらく /被差別部落/
ひさべつぶらくみん /被差別部落民/
ひさま /久馬/
ひさまつ /久松/
ひさみち /久道/
ひさみつ /久光/
ひさみつせいやく /久光製薬;[企業名]/
ひさみどう /久美堂/
ひさむら /久村/
ひさめ /氷雨/大雨;=おおあめ/
ひさもと /久本/
ひさや /久弥/久屋/
ひさやま /久山/
ひさゆき /尚幸/
ひさよ /久代/
ひさよし /久吉/久佳/
ひさん /悲惨/飛散/砒酸;H3AsO4/
ひさんいつ /非散逸/
ひざ /膝/
ひざあて /膝当て;kneepad/
ひざうえ /膝上/
ひざかけ /膝掛け/
ひざかな /干魚/乾魚/
ひざかり /日盛り/
ひざかんせつ /膝関節/
ひざがしら /膝頭/
ひざくら /緋桜/
ひざくりげ /膝栗毛/
ひざぐるま /膝車/
ひざげり /膝蹴り/
ひざこぞう /膝小僧/
ひざし /日差し/陽射し/日射し/日ざし/陽射/日差/日射/
ひざした /膝下/
ひざしたていど /膝下程度/
ひざまくら /膝枕/
ひざもと /膝元/膝下/ひざ元/
ひざら /火皿/
ひし /菱/皮脂/秘史/彼此/斐紙/蔆;「菱」の異体字/◇;dia/
ひしお /醤/醢/
ひしおいろ /醤色;襲の色目/
ひしおす /醤酢/
ひしかり /菱刈/
ひしかわ /菱川/
ひしがた /菱形/◇/◆/
ひしごと /日仕事/
ひししょくぶつ /被子植物/
ひししょくぶつあもん /被子植物亜門/Angiospermae/
ひしずめのまつり /鎮火の祭/
ひしせん /皮脂腺/
ひした /菱田/
ひしだ /菱田/
ひしつ /皮質/
ひしつない /皮質内/
ひしつもんしゃ /被質問者/
ひしと /犇と/緊と/
ひしぬま /菱沼/
ひしね /菱根/
ひしはいしゃ /被支配者/
ひしひし /犇々/緊々/
ひしまく /皮脂膜/
ひしむけ /被仕向/
ひしもち /菱餅/
ひしゃ /飛車/扉車/
ひしゃかいしんど /被写界深度/
ひしゃかいてき /非社会的/
ひしゃかく /飛車角/
ひしゃく /柄杓/杓/
ひしゃたい /被写体/
ひしゃたいしんど /被写体深度/
ひしゅ /脾腫/匕首/秘酒/
ひしゅう /悲愁/飛州;飛騨/肥州;肥前・肥後/
ひしゅうきてき /非周期的/
ひしゅうぎょうしゃ /非就業者/
ひしゅうしょくご /被修飾語;[文法]/
ひしゅうたん /非終端/
ひしゅうたんきごう /非終端記号/
ひしゅりゅう /非主流/
ひしゅりゅうは /非主流派/
ひしょ /秘書/避暑/秘所;(ひめどころ)/
ひしょう /飛翔/卑小/費消/悲傷/婢妾/
ひしょうかいしゃ /被紹介者/
ひしょうがいしゃ /非障害者/
ひしょうぐん /飛将軍/
ひしょうざめ /飛翔鮫/
ひしょうしつ /非晶質/
ひしょうしゃ /非照射/
ひしょうじけん /非訟事件/
ひしょうたい /飛翔体/
ひしょうてん /被昇天/
ひしょうひししゅつ /非消費支出/
ひしょうよう /非商用/
ひしょか /秘書課/秘書科/
ひしょかん /秘書官/
ひしょく /比色/非職/
ひしょくけい /比色計/
ひしょくしゃ /被食者/
ひしょくぶんせき /比色分析/
ひしょけんてい /秘書検定/
ひしょしつ /秘書室/
ひしょしょう /秘書省/
ひしょじょ /非処女/
ひしょち /避暑地/
ひしん /皮疹/秘唇/
ひしんけい /披針形/
ひしんしてきこうい /非紳士的行為/
ひしんしゅう /非侵襲/
ひしんしゅうてき /非侵襲的/
ひじ /肘/秘事/肱/樋地/日出/臂/
ひじあて /肘当/肘当て;elbow pad/
ひじうち /肘撃/
ひじかけ /肘掛け/肘掛/
ひじかけいす /肘掛け椅子;armchair/
ひじかた /土方/
ひじかたとしぞう /土方歳三/
ひじかわ /肱川/
ひじき /肘木;[建築]/鹿尾菜;海藻/非食;[仏教]/非色/羊栖菜/
ひじきも /鹿尾菜藻/
ひじこ /非自己/
ひじこうげき /肘攻撃/
ひじせいたい /非磁性体/
ひじちょうもく /飛耳長目/
ひじつようてき /非実用的/
ひじつりょくは /非実力派/
ひじつりょくはせんげん /非実力派宣言/
ひじてっぽう /肘鉄砲/
ひじてつ /肘鉄/
ひじでっぽう /肘鉄砲/
ひじみん /非自民/
ひじみんせいりょく /非自民勢力/
ひじゅう /比重/
ひじゅうけい /比重計/
ひじゅうふく /非重複/
ひじゅつ /秘術/
ひじゅられき /ヒジュラ暦/
ひじゅん /批准/
ひじゅんきょ /非準拠/
ひじゅんこく /批准国/
ひじゅんしょ /批准書/
ひじゅんせい /非純正/
ひじょ /秘女/
ひじょう /非常;†very, emergency.「-手段」/非情;†cruel.「-な男」/
ひじょう> /非常;-出口,-ブレーキ/
ひじょうかいだん /非常階段/
ひじょうきん /非常勤/
ひじょうきんこうし /非常勤講師/
ひじょうぐち /非常口/
ひじょうしき /非常識/
ひじょうしきにん /非常識人/
ひじょうしゅだん /非常手段/
ひじょうしょく /非常食/
ひじょうしょくりょう /非常食糧/
ひじょうじ /非常時/
ひじょうじいがい /非常時以外/
ひじょうじたい /非常事態/
ひじょうじょうこく /非常上告/
ひじょうじよう /非常時用/
ひじょうすう /被乗数/
ひじょうせいどう /非常制動/
ひじょうせん /非常線/
ひじょうとう /非常灯/
ひじょうに /非常に/
ひじょうにんりじこく /非常任理事国/
ひじょうべる /非常ベル/
ひじょうほう /秘情報/
ひじょうほうけい /非情報系/
ひじょうよう /非常用/
ひじょすう /被除数/
ひじり /聖/
ひじりがおか /聖ヶ丘/
ひじりばし /聖橋/
ひじりばしぐち /聖橋口/
ひじんしょ /肥人書/
ひじんどうてき /非人道的/
ひすい /翡翠/
ひすいいろ /翡翠色/
ひすいしょう /非推奨/
ひすがら /終日/
ひず /氷頭;魚の頭の軟骨/秘図/
ひずけ /日付;※仮名遣い「ひづけ」/日付け;※仮名遣い「ひづけ」/
ひずみ /歪み;distortion/歪/
ひずみりつ /歪率/歪み率;distortion rate/
ひずみりょう /歪量/
ひせい /批正/悲悽/
ひせいきぐん /非正規軍/
ひせいさんてき /非生産的/
ひせいしょく /非生殖/
ひせいしょくてき /非生殖的/
ひせいじ /非斉次/
ひせいじん /非成人/
ひせいそく /非正則/
ひせいてき /非静的/
ひせいふそしき /非政府組織/
ひせいほう /非正方/
ひせき /秘跡;sacrament/秘蹟;=秘跡/飛跡;track/碑石/砒石;[鉱物]arsenious anhydride/
ひせきぶん /被積分/
ひせきぶんかんすう /被積分関数/
ひせっしょく /非接触/
ひせっしょくがた /非接触型/
ひせっしょくしき /非接触式/
ひせつ /飛雪/秘説/
ひせつぞく /非接続/
ひせつどうてき /非摂動的/
ひせん /非戦/卑賤/飛箭/卑賎;「賤」異体字/
ひせんきょけん /被選挙権/
ひせんけい /非線形/非線型;=非線形/
ひせんけいかいろ /非線形回路/
ひせんけいかがく /非線形科学/
ひせんけいげんしょう /非線型現象/
ひせんけいしょり /非線形処理/
ひせんけいせい /非線形性/非線型性/
ひせんけいてき /非線形的/
ひせんけいへんかん /非線形変換/
ひせんけいりきがく /非線型力学/
ひせんけいりろん /非線形理論/
ひせんでん /非宣伝/
ひせんとういん /非戦闘員/
ひせんとうちいき /非戦闘地域/
ひせんもんか /非専門家/
ひせんろん /非戦論/
ひぜき /火堰/
ひぜに /日銭/
ひぜめ /火攻め/火責め/
ひぜろ /非ゼロ/非零/
ひぜん /肥前/
ひぜんかしま /肥前鹿島/
ひぜんやまぐち /肥前山口/
ひぜんやまぐちえき /肥前山口駅/
ひそ /砒素/As/Arsenic/
ひそう /悲壮;悲しくも勇壮/悲愴;悲しく、いたましい/皮相;表面(的)/皮層;cortex/肥痩/悲想/
ひそうかん /悲壮感/悲愴感/非相関/
ひそうぞくにん /被相続人/
ひそうたいろんてき /非相対論的/
ひそうちゃく /非装着/
ひそうちゃくしゃ /非装着車/
ひそうてき /皮相的/
ひそうでんりょく /皮相電力/
ひそうび /悲壮美/
ひそか /密か/密/
ひそかごうぶつ /砒素化合物/
ひそかに /窃/
ひそく /秘色/
ひそすう /非素数/
ひそひそばなし /ひそひそ話/
ひそみ /顰み/
ひそやか /密やか/
ひそんざい /非存在/
ひぞう /秘蔵/脾臓/
ひぞうか /非増加/
ひぞうっこ /秘蔵っ子/
ひぞうぶつ /被造物/
ひぞく /卑俗/卑属/匪賊/
ひぞっこ /秘蔵っ子/
ひた /日田/
ひたい /額/
ひたいいくかいけい /非体育会系/
ひたいおう /非対応/
ひたいかく /非対角/
ひたいかくせいぶん /非対角成分/
ひたいがみ /額髪/
ひたいぎわ /額際/
ひたいしょう /非対称/
ひたいしょうぎょうれつ /非対称行列/
ひたいしょうせい /非対称性/
ひたいしょうまく /非対称膜/
ひたかくし /直隠し/ひた隠し/
ひたき /火焼/鶲/
ひたすら /一向/只管/頓/
ひたたれ /直垂/
ひたち /日立/常陸/肥立/
ひたちいちこう /日立一高/
ひたちおおた /常陸太田/
ひたちおおたし /常陸太田市/
ひたちかせい /日立化成/
ひたちかせいこうぎょう /日立化成工業;[企業名]/
ひたちきそけん /日立基礎研/
ひたちきんぞく /日立金属/
ひたちくれじっと /日立クレジット/
ひたちけい /日立系/
ひたちけんきゅうしょ /日立研究所/
ひたちけんきゅうじょ /日立研究所/
ひたちこうき /日立工機/
ひたちし /日立市/
ひたちじょうほう /日立情報/
ひたちじょし /日立女子/
ひたちせい /日立製/
ひたちせいき /日立精機/
ひたちせいさくしょ /日立製作所;[企業名]/
ひたちせいさくじょ /日立製作所;[企業名]/
ひたちぞうせん /日立造船/
ひたちちゅうけん /日立中研/
ひたちでんせん /日立電線/
ひたちとうほく /日立東北/
ひたちのみや /常陸宮/
ひたちばん /日立版/
ひたちぶつりゅう /日立物流/
ひたちべん /日立弁/
ひたちぼうかいそん /常陸坊海尊/
ひたちまくせる /日立マクセル/
ひたちやま /常陸山/
ひたぶる /一向/頓/
ひたむき /直向き/直向/
ひたん /悲嘆/悲歎/
ひたんちょう /非単調/
ひたんちょうすいろん /非単調推論/
ひたんちょうろんり /非単調論理/
ひだ /飛騨/襞/肥田/飛田/樋田/
ひだい /肥大/比田井/
ひだいか /肥大化/
ひだか /日高/肥高/
ひだかちほう /日高地方/
ひださんみゃく /飛騨山脈/
ひだすき /火襷/
ひだたかやま /飛騨高山/
ひだち /肥立ち/
ひだね /火種/
ひだひこやません /日田彦山線/
ひだま /火玉/
ひだまり /日溜まり/日溜り/陽溜り/
ひだら /干鱈/
ひだり /左/←/「/『/＜/（/【/
ひだり> /左;左投手,左方面/
ひだりあごした /左顎下/
ひだりあし /左足/
ひだりいっぱい /左一杯/
ひだりうえ /左上/
ひだりうえすみ /左上隅/
ひだりうしろ /左後/
ひだりうち /左打ち;[野球]/左打/
ひだりうで /左腕/
ひだりえだ /左枝/
ひだりおく /左奥/
ひだりかた /左肩/
ひだりかっこ /左括弧/『/
ひだりがき /左書き/
ひだりがわ /左側/
ひだりがわしゃせん /左側車線/
ひだりがわぜんぽう /左側前方/
ひだりがわつうこう /左側通行/
ひだりがわはし /左側端/
ひだりきき /左利き/
ひだりきんぼう /左近傍/
ひだりくりっく /左クリック/
ひだりけつごう /左結合/
ひだりこうほう /左後方/
ひだりこうりん /左後輪/
ひだりこし /左腰/
ひだりさいき /左再帰/
ひだりさいど /左サイド/
ひだりざま /左様/
ひだりした /左下/
ひだりしたすみ /左下隅/
ひだりしゃせん /左車線/
ひだりじんごろう /左甚五郎/
ひだりず /左図/
ひだりぜん /左膳/
ひだりぜんぶ /左前部/
ひだりぜんぽう /左前方/
ひだりぜんりん /左前輪/
ひだりそくほう /左側方/
ひだりそで /左袖/
ひだりだしゃ /左打者/
ひだりだせき /左打席/
ひだりづかい /左遣い;人形浄瑠璃の-/
ひだりづめ /左詰め/
ひだりて /左手/
ひだりてくび /左手首/
ひだりてこゆび /左手小指/
ひだりてなかゆび /左手中指/
ひだりてぶ /左手部/
ひだりてまえ /左手前/
ひだりてんかい /左転回/
ひだりとうしゅ /左投手/
ひだりどなり /左隣/
ひだりどもえ /左巴/
ひだりなげ /左投げ/
ひだりのり /左乗/
ひだりはし /左端/
ひだりはじ /左端/
ひだりはんどる /左ハンドル/
ひだりはんぶん /左半分/
ひだりはんめん /左半面/
ひだりひざ /左膝/
ひだりひじ /左肘/
ひだりふともも /左太股/
ひだりぶぶん /左部分/
ひだりぶんき /左分岐/
ひだりほうこう /左方向/
ひだりほお /左頬/
ひだりほほ /左頬/
ひだりぼたん /左ボタン/
ひだりまえ /左前/
ひだりまえあし /左前足/左前脚/
ひだりまき /左巻き/左巻;[俗]パー/
ひだりまわり /左回り/
ひだりみぎ /左右/
ひだりみぎはし /左右端/
ひだりみみ /左耳/
ひだりむき /左向き/
ひだりむね /左胸/
ひだりめ /左目/
ひだりめよう /左目用/
ひだりや /←/左矢/
ひだりやじるし /左矢印/←/
ひだりよう /左用/
ひだりようそ /左要素/
ひだりよこ /左横/
ひだりよせ /左寄/左寄せ/
ひだりよつ /左四つ/
ひだりより /左寄り/左寄/
ひだりわき /左脇/
ひだるま /火達磨/火だるま/火ダルマ/
ひだん /被弾/
ひだんせい /非弾性/
ひだんせいさんらん /非弾性散乱/
ひだんせいさんらんだんめんせき /非弾性散乱断面積/
ひだんせいしょうとつ /非弾性衝突/
ひちくじょう /肥畜場/
ひちしゃ /被治者/
ひちそう /七宗/
ひちゃくしゅつ /非嫡出/
ひちゃくしゅつし /非嫡出子/
ひちゃくよう /非着用/
ひちゅう /秘中/
ひちゅうのひ /秘中の秘/
ひちょう /飛鳥/悲調/
ひちょうきん /腓腸筋/
ひちょくせん /非直線/
ひちょくせんせい /非直線性/
ひちょっこう /非直交/
ひちりき /篳篥/
ひっ /必/
ひっ> /引っ;引っ掛ける,引っ返す,引っ捕える/
ひっか /筆禍/筆架;ふでかけ/
ひっかかり /引っ掛かり/引っ掛り/
ひっかききず /引っ掻き傷/
ひっかく /筆画/
ひっかけ /引っ掛け/
ひっかん /筆管/
ひっき /筆記/
ひっきぐ /筆記具/
ひっきしけん /筆記試験/
ひっきたい /筆記体/
ひっきょう /畢竟/
ひっきようぐ /筆記用具/
ひっきりなし /引っ切り無し/
ひっけい /必携/
ひっけいぼん /必携本/
ひっけん /必見/筆硯/
ひっこう /筆耕/筆工/
ひっこし /引越し/引っ越し/引越/
ひっこしさき /引越し先/引っ越し先/引越先/
ひっこしだい /引越し代/引っ越し代/引越代/
ひっこしや /引越し屋/引越屋/引っ越し屋/
ひっこみ /引っ込み/引込み/
ひっこみじあん /引っ込み思案/
ひっさいぼん /筆彩本/
ひっさつ /必殺/
ひっさつしかけにん /必殺仕掛人/
ひっさつしごとにん /必殺仕事人/
ひっさつわざ /必殺技/
ひっさん /筆算/
ひっし /必死;†desperate.「-の努力」/必至;†inevitable.「決裂は-だ」/筆紙/
ひっしゃ /筆者;writer/筆写;copy/
ひっしゃぼん /筆写本/
ひっしゅ /必須/
ひっしゅう /必修/必習;?/
ひっしゅうかもく /必修科目/
ひっしゅうたんい /必修単位/
ひっしゅつ /必出/
ひっしょう /必勝/
ひっしょうこうざ /必勝講座/
ひっしょうたいせい /必勝体制/
ひっしょうほう /必勝法/
ひっしょうぼん /必勝本/
ひっしょく /筆触/
ひっす /必須/
ひっすあみのさん /必須アミノ酸;EAA/
ひっすい /必衰/
ひっすう /必須;「ひっす」が正しいが、この読みも定着・通用している/
ひっすかく /必須格/
ひっすこうもく /必須項目/
ひっすじこう /必須事項/
ひっすじょうけん /必須条件/
ひっせい /畢生/筆勢/筆生;scribe/
ひっせき /筆跡/筆蹟;=筆跡/筆迹;≒筆跡/
ひっせん /筆洗/筆戦/
ひっそく /逼塞/
ひったいとご /ヒッタイト語;Hittite/
ひったくり /引っ手繰り/
ひったん /筆端/
ひっち /筆致/必置/
ひっちゃく /必着/
ひっちゅう /必中/筆誅/
ひっちょう /必聴/
ひっちょうばん /必聴盤/
ひっちょうもの /必聴物/
ひっつめ /引っ詰め/
ひってき /匹敵/
ひっとう /筆頭/筆答/
ひっとうかく /筆頭格/
ひっとうしゃ /筆頭者/
ひっときょく /ヒット曲/
ひっとさく /ヒット作/
ひっとしょうひん /ヒット商品/
ひっとすう /ヒット数/
ひっぱい /必敗/
ひっぱく /逼迫/
ひっぱつ /必発/
ひっぱり /引っ張り;-応力/引張/
ひっぱりおうりょく /引っ張り応力/
ひっぱりだこ /引っ張り凧/引っ張り蛸/引っ張りだこ/
ひっぱりつよさ /引っ張り強さ/
ひっぷ /匹夫/匹婦/
ひっぷのゆう /匹夫の勇/
ひっぷひっぷ /匹夫匹婦/
ひっぽう /筆法/筆鋒/
ひつ /必/筆/櫃/泌;分泌/弼;輔弼/逼;逼迫/謐;静謐/畢;畢竟/篳;篳篥/蹕;(さきばらい)/匹;匹夫/疋;ひき/
ひつあつ /筆圧/
ひつい /筆意/
ひつう /悲痛/
ひつうち /非通知/
ひつき /火付き/
ひつぎ /棺/柩/
ひつけ /火付け/
ひつけやく /火付け役/
ひつじ /羊/未;[十二支]8/日辻/
ひつじかい /羊飼い/
ひつじぐも /羊雲/
ひつじさる /坤/未申;南西/
ひつじどし /未年/
ひつじゅ /必需/
ひつじゅしょうひ /必需消費/
ひつじゅつ /筆述/
ひつじゅてきしょうひ /必需的消費/
ひつじゅひん /必需品/
ひつじゅん /筆順/
ひつじょう /必定/
ひつじん /筆陣/
ひつぜつ /筆舌/
ひつぜん /必然/謐然/□;記号の四角/
ひつぜんか /必然化/
ひつぜんせい /必然性/
ひつぜんてき /必然的/
ひつだん /筆談/
ひつどく /必読/
ひつどくしょ /必読書/
ひつにょう /泌尿/
ひつねい /謐寧/
ひつば /弼馬/
ひつばつ /必罰/
ひつひつ /謐謐/
ひつび /必備/
ひつぼく /筆墨/
ひつまぶし /櫃まぶし;[料理]名古屋の鰻料理/
ひつめい /筆名/
ひつめつ /必滅/
ひつもんひっとう /筆問筆答/
ひつよう /必要/必用/
ひつようあく /必要悪/
ひつようあくてき /必要悪的/
ひつよういじょう /必要以上/
ひつようかんきりょう /必要換気量/
ひつようがく /必要額/
ひつようけいひ /必要経費/
ひつようげんど /必要限度/
ひつようこうせい /必要構成/
ひつようさいしょうげん /必要最小限/
ひつようさいてい /必要最低/
ひつようさいていげん /必要最低限/
ひつようさいていげんど /必要最低限度/
ひつようしょうひ /必要消費/
ひつようしょるい /必要書類/
ひつようじこう /必要事項/
ひつようじゅうぶん /必要十分/必要充分/
ひつようじゅうぶんじょうけん /必要十分条件/
ひつようじょう /必要上/
ひつようじょうけん /必要条件/
ひつようせい /必要性/
ひつようど /必要度/
ひつようなし /必要無/
ひつようふかけつ /必要不可欠/
ひつようぶすう /必要部数/
ひつようぶぶん /必要部分/
ひつようぶん /必要分/
ひつようまいすう /必要枚数/
ひつようりょう /必要量/
ひつりょく /筆力/
ひつろく /筆録/
ひづくり /火造り/
ひづけ /日付/日付け/日附;別字/
ひづけいん /日付印/
ひづけしょしき /日付書式/
ひづけじゅん /日付順/
ひづけへんこうせん /日付変更線/
ひづけよやく /日付予約/
ひづつ /火筒;鉄砲/
ひづめ /蹄/
ひてい /否定/比定;類似物との比較による推定/飛程/¬/
ひていいけん /否定意見/
ひていきてき /非定期的/
ひていけい /非定型/
ひていざいりょう /否定材料/
ひていじょう /非定常/
ひていじょうせい /非定常性/
ひていじょうてき /非定常的/
ひていてき /否定的/
ひていてきいみ /否定的意味/
ひていてきたちば /否定的立場/
ひていてきひょうか /否定的評価/
ひていは /否定派/
ひていぶん /否定文/
ひていろん /否定論/
ひてきごう /非適合/
ひてつ /非鉄/
ひてつきんぞく /非鉄金属/
ひてつづき /非手続き/
ひてん /飛天/批点/
ひてんしゅうさ /非点収差/
ひで /英/秀/映/
ひであき /英明/秀明/秀昭/英昭/英朗/秀章/英亮/
ひでいち /秀市/
ひでお /英雄/秀夫/英夫/秀雄/英男/秀男/日出男/日出夫/英生/英朗/秀郎/秀生/周男/映夫/
ひでおき /秀起/
ひでか /秀香/秀加/
ひでかず /秀和/秀一/英和/英一/
ひでかつ /秀勝/英勝/
ひでき /秀樹/英樹/英紀/秀紀/秀記/秀規/秀貴/秀起/秀己/偉紀/
ひできち /秀吉/
ひできよ /英清/
ひでこ /秀子/英子/
ひでさく /秀作/
ひでさち /秀幸/
ひでさと /秀郷/
ひでし /日出志/
ひでじ /英司/秀司/
ひでずみ /秀純/
ひでぞう /秀三/
ひでたか /秀隆/英孝/秀孝/秀貴/栄孝/英卓;名/
ひでただ /秀忠/
ひでたつ /英辰/
ひでつぐ /秀次/秀嗣/
ひでと /秀人/英人/秀仁/日出登/
ひでとし /英俊/秀敏/英敏/秀利/秀年/
ひでとも /英智/秀智/
ひでなお /秀尚/
ひでのぶ /秀信/英信/
ひでのり /秀典/秀則/英典/英則/秀紀/英憲/英紀/
ひではる /英治/英晴/
ひでひこ /英彦/秀彦/
ひでひさ /秀寿/
ひでひと /秀仁/英仁/
ひでひろ /秀博/英裕/秀浩/英宏/秀宏/
ひでふみ /秀文/
ひでまさ /豪将;名/
ひでまる /秀丸/
ひでみ /秀美/秀実/英美/英実/英巳/
ひでみつ /秀光/英光/
ひでもと /秀基/
ひでや /英也/秀也/英哉/日出谷/秀哉/
ひでやす /秀康/英育/秀育/
ひでゆき /秀行/秀幸/英之/秀之/英幸/英行/
ひでよ /英世/秀世/
ひでよし /秀吉/秀善/
ひでより /秀頼/
ひでり /日照り/旱/魃/
ひでろう /秀郎/
ひでん /秘伝/飛電/悲田/
ひでんいん /悲田院/
ひでんか /妃殿下/非電化/比電荷/
ひでんかくかん /非電化区間/
ひでんかろせん /非電化路線/
ひでんこうかい /秘伝公開/
ひでんし /非電子/
ひでんしゃ /被伝者/
ひと /人/一/費途/女/他人/壱;「一」の大字/弌;「一」の異体字/壹;「壱」の旧字/仁/史/
ひと> /一;一騒動,一働き,一眠り/
ひとあいて /人相手/
ひとあき /仁明/
ひとあし /一足/人足/
ひとあしさき /一足先/
ひとあしちがい /一足違い/
ひとあしらい /人あしらい/
ひとあじ /一味/
ひとあせ /一汗/
ひとあたり /人当たり/人当り/
ひとあつめ /人集め/
ひとあな /人穴/一穴/
ひとあめ /一雨/
ひとあらため /人改め/
ひとあれ /一荒れ/
ひとあわ /一泡/
ひとあんしん /一安心/
ひといがい /人以外/
ひといき /一息/
ひといきれ /人いきれ/
ひといくさ /一軍;敵寄せ来たらば-して(太平記)/
ひといじょう /人以上/
ひといちばい /人一倍/
ひといろ /一色/人色/
ひとう /秘湯/比島;地名,Philippine Islands/
ひとうか /非透過/
ひとうさい /非搭載/
ひとうち /一打ち/
ひとうり /人売り/
ひとえ /一重/単/單;「単」の旧字(人名用漢字)/
ひとえき /一駅/
ひとえきぶん /一駅分/
ひとえぐさ /一重草/
ひとえざき /一重咲き/
ひとえに /偏に/
ひとえばおり /単羽織/
ひとえまぶた /一重瞼/
ひとえもの /単物/
ひとおし /一押し;もう-/
ひとおじ /人怖じ/
ひとおと /人音/
ひとおに /人鬼/
ひとおもい /一思い/
ひとかい /人買い/
ひとかかえ /一抱え/
ひとかけら /一欠片/
ひとかげ /人影/
ひとかすみ /一霞/
ひとかず /人数/
ひとかせぎ /一稼ぎ/
ひとかぞく /一家族/
ひとかた /一方/
ひとかたならず /一方ならず/
ひとかたまり /一塊/
ひとかど /一角;-の人物/一廉/
ひとかぶ /一株/
ひとからげ /一絡/一絡げ;十把-/
ひとかわ /一皮/
ひとかん /一缶/
ひとがき /人垣/
ひとがた /人形/人型/人像/
ひとがら /人柄/
ひとがんばり /一頑張り/
ひときり /人斬り/一切り/
ひときわ /一際/
ひとぎき /人聞き/
ひとぎらい /人嫌い/
ひとく /秘匿/
ひとくい /人食い;cannibal/人喰い/非特異/人食/
ひとくいじんしゅ /人喰い人種/
ひとくいてき /非特異的/
ひとくぎり /一区切り/
ひとくくり /一括り/
ひとくせ /一癖/
ひとくせい /秘匿性/
ひとくだり /一行/
ひとくち /一口/
ひとくちだい /一口大/
ひとくちめ /一口目/
ひとくに /他国/人国/
ひとくふう /一工夫/
ひとくみ /一組/
ひとくら /一庫/
ひとくろう /一苦労/
ひとけ /人気/
ひとけた /一桁/1桁/
ひとけため /一桁目/1桁目/
ひとこえ /一声/
ひとこえせんりょう /一声千両/
ひとこきゅう /一呼吸/
ひとこじん /人個人/
ひとこと /一言/
ひとことちゅうい /一言注意/
ひとことぬしのかみ /一言主神/
ひとことふたこと /一言二言/
ひとこま /一齣/一コマ/一こま/ひとコマ/
ひところ /一頃/ひと頃/
ひとごえ /人声/
ひとごこち /人心地/
ひとごころ /人心/
ひとごと /他人事/人事;=他人事/人言;他人の言葉、噂/他人言;=人言/
ひとごみ /人込み/人混み;=人込み/人ごみ/
ひとごろし /人殺し/
ひとさがし /人探し/
ひとさしゆび /人差し指/人指し指/人差指/
ひとさま /人様/
ひとさら /一皿/
ひとさらい /人攫い/
ひとさわがせ /人騒がせ/
ひとざいさん /一財産/
ひとざと /人里/
ひとし /等/仁/均/準/斉/斎/仁志/倫/人志;名/仁司/仁史/倫史/等し/
ひとしお /一入/一塩/
ひとしきり /一頻り/
ひとしくない /≠;!=/
ひとしごと /一仕事/
ひとしだい /人次第/
ひとしな /一品/
ひとしなみ /等し並み/
ひとしばい /一芝居/
ひとしょうぶ /一勝負/
ひとしれず /人知れず/
ひとじしん /人自身/
ひとじたい /人自体/
ひとじち /人質/
ひとじちかいほう /人質解放/
ひとじちしゃくほう /人質釈放/
ひとじに /人死/人死に/
ひとすじ /一筋/
ひとすじなわ /一筋縄/
ひとずき /人好き/
ひとせだい /一世代/
ひとせだいまえ /一世代前/
ひとぜんいん /人全員/
ひとぜんたい /人全体/
ひとそうどう /一騒動/
ひとたち /人達/一太刀/
ひとたば /一束/
ひとたび /一度/
ひとたま /一玉/
ひとたまり /一溜り/
ひとだかり /人集り/
ひとだすけ /人助け/
ひとだね /人種/
ひとだのみ /人頼み/
ひとだま /人魂/
ひとだまり /人溜り/
ひとだんらく /一段落/
ひとちがい /人違い/
ひとっこ /人っ子/
ひとっこひとり /人っ子一人/
ひとっとび /ひとっ飛び/
ひとっぱしり /一っ走り/ひとっ走り/
ひとつ /一つ/非凸/１つ/1つ/
ひとつおぼえ /一つ覚え/
ひとつかま /一つ釜/
ひとつかみ /一掴み/
ひとつき /一月/ひと月/一突き/
ひとつきいじょう /一月以上/
ひとつきいじょうまえ /一月以上前/
ひとつきいない /一月以内/
ひとつきはん /一月半/
ひとつきぶん /一月分/
ひとつきほど /一月程/
ひとつぎ /一木/
ひとつづき /一続き/
ひとつところ /一つ所/
ひとつばし /一橋/一ッ橋/一ツ橋/
ひとつばしだい /一橋大/
ひとつばしだいがく /一橋大学/
ひとつひきりょう /一つ引両/
ひとつひとつ /一つ一つ/１つひとつ/
ひとつぶ /一粒/
ひとつぶえり /一粒選り/
ひとつぶだね /一粒種/
ひとつぶひとつぶ /一粒一粒/
ひとつぶより /一粒選り/
ひとつぼし /一つ星;☆/
ひとつまつ /一松/
ひとつまみ /一摘み/一撮み/
ひとつみ /一つ身/
ひとつめ /一つ目/一つめ/
ひとつもん /一つ紋/
ひとつや /一つ家/
ひとつら /一連/一列/一行/
ひとづかい /人使い/
ひとづかれ /人疲れ/
ひとづき /人付き/
ひとづきあい /人付き合い;-が悪い/人付合い/
ひとづくり /人作り/
ひとづて /人伝/
ひとづま /人妻/
ひとて /一手/
ひとていど /人程度/
ひとで /人手;hand/人出;crowd/海星;starfish☆ (「人出」とも書く)/
ひとでなし /人で無し/人でなし/
ひとでぶそく /人手不足/
ひととおり /一通り/
ひととき /一時/
ひとところ /一所/一処/
ひととせ /一年/稘/
ひととなり /為人/人となり/
ひととび /一飛び/
ひとどうし /人同士/人同志;?/
ひとどおり /人通り/
ひとなか /人中/
ひとなかせ /人泣かせ/
ひとなつ /一夏/
ひとなど /人等/
ひとなみ /人波;crowd of people/人並;common/人並み/
ひとなみいじょう /人並以上/
ひとなり /仁成/
ひとにぎり /一握り/
ひとねいり /一寝入り/
ひとねむり /一眠り/
ひとのき /一軒;[建築]/
ひとのこ /人の子/
ひとのみ /一飲み/
ひとのみち /人の道/
ひとのよ /人の世/人の代;=人の世/
ひとは /一葉/
ひとはこ /一箱/
ひとはこぶん /一箱分/
ひとはし /一端/
ひとはしり /一走り/
ひとはた /一旗/
ひとはたらき /一働き/
ひとはだ /人肌;-が恋しい/一肌;-脱ぐ/
ひとはな /一花/
ひとはぶね /一葉舟/
ひとはら /一腹/
ひとはらん /一波乱/
ひとはり /一針/
ひとばし /人橋/
ひとばしら /人柱/
ひとばらい /人払い/
ひとばん /一晩/
ひとばんいじょう /一晩以上/
ひとばんご /一晩後/
ひとばんじゅう /一晩中/
ひとぱっく /一パック/
ひとひ /一日/
ひとひとり /人一人/
ひとひねり /一捻り/一ひねり/
ひとひら /一片/一枚/
ひとびと /人々/人びと/人人/
ひとふくろ /一袋/
ひとふし /一節/
ひとふで /一筆/
ひとふでがき /一筆書/一筆書き/
ひとふゆ /一冬/
ひとふり /一振り;刀剣類の一本/
ひとふろ /一風呂/
ひとふんばり /一踏ん張り/
ひとぶそく /人不足/
ひとへや /一部屋/
ひとべらし /人減らし;リストラ/
ひとほね /一骨/
ひとま /一間/
ひとまえ /人前/
ひとまかせ /人任せ/
ひとまき /一巻/
ひとまく /一幕/
ひとまくみ /一幕見/
ひとまくもの /一幕物;one-act play/
ひとまず /一先ず/
ひとまたぎ /一跨ぎ/
ひとまち /人待ち/
ひとまちがお /人待ち顔/
ひとまとめ /一纏め/
ひとまね /人真似/
ひとまろ /人麻呂/人麿/一麿/
ひとまわり /一回り/
ひとみ /瞳/人見/仁美/一美/
ひとみきねんこうどう /人見記念講堂/
ひとみごくう /人身御供/
ひとみしり /人見知り/
ひとみすいしょう /瞳水晶/
ひとむかし /一昔/
ひとむかしまえ /一昔前/
ひとむね /一棟/
ひとむら /一叢/一群/
ひとむれ /一群/
ひとめ /人目/一目/ひと眼/
ひとめいわく /人迷惑/
ひとめぐり /一巡り/一周り/
ひとめぼれ /一目惚れ/
ひともうけ /一儲け/
ひともじ /一文字/人文字/
ひともと /一本;-の花/
ひともなげ /人も無げ/
ひともの /一物/
ひともんちゃく /一悶着/
ひとや /人屋/
ひとやく /一役/
ひとやすみ /一休み/
ひとやま /一山/人山/
ひとよ /一夜/一世/
ひとよぎり /一節切/
ひとよし /人吉/
ひとよせ /人寄せ/
ひとよたけ /一夜茸/
ひとり /一人/独り/１人/独/獨り/1人/ひとり/
ひとりあそび /一人遊び/
ひとりあたま /一人頭;-20万円の増税/
ひとりあたり /一人当/
ひとりあるき /独り歩き/一人歩き/
ひとりい /独り居/
ひとりいじょう /一人以上/
ひとりいちだい /一人一台/
ひとりいっさつ /一人一殺/
ひとりうき /一人浮き/
ひとりうち /一人打ち/
ひとりがち /一人勝ち/独り勝ち/
ひとりがてん /独り合点/
ひとりきり /一人きり/
ひとりぎめ /独り決め/
ひとりくらい /一人位/
ひとりぐち /一人口/
ひとりぐらし /一人暮らし/一人暮し/独り暮らし/独り暮し/
ひとりごと /独り言/ひとり言/一人言/
ひとりしずか /一人静/
ひとりしばい /一人芝居/
ひとりじかんさ /一人時間差/
ひとりじめ /独り占め/一人占め/
ひとりずまい /一人住まい/
ひとりずもう /一人相撲/独り相撲/
ひとりせんよう /一人専用/
ひとりたび /一人旅/
ひとりだち /独り立ち/一人立ち/一人立/
ひとりっきり /一人っきり/
ひとりっこ /一人っ子/
ひとりね /独り寝;-の夜/
ひとりのり /一人乗り/
ひとりひとり /一人一人/
ひとりぶたい /一人舞台/独り舞台/
ひとりぶん /一人分/
ひとりべや /一人部屋/
ひとりぼっち /一人ぼっち/独りぼっち/一人法師/
ひとりまえ /一人前/
ひとりまけ /一人負け/
ひとりみ /独り身/
ひとりむすこ /一人息子/
ひとりむすめ /一人娘/
ひとりめ /一人目/
ひとりもの /独り者/
ひとりよう /一人用/
ひとりよがり /独り善がり/
ひとりわらい /独り笑い/
ひど /肥土/
ひどいめ /酷い目/
ひどう /非道/
ひどうき /非同期/
ひどうきがた /非同期型/
ひどうきしき /非同期式/
ひどうきしょうこうぐん /非同期症候群/
ひどうきしょり /非同期処理/
ひどうきつうしん /非同期通信/
ひどうきてき /非同期的/
ひどうきどうさ /非同期動作/
ひどうさじ /非動作時/
ひどうじ /非同時/
ひどうとくてき /非道徳的/
ひどけい /日時計/
ひどこ /火床/
ひどのらか /ヒドノラ科/Hydnoraceae/
ひどらすちすあか /ヒドラスチス亜科/Hydrastidoideae/
ひどり /日取り/
ひどろきしるき /ヒドロキシル基;(hydroxyl) 水酸基/
ひどろすたきすもく /ヒドロスタキス目/Hydrostachydales/
ひな /雛/鄙/
ひなあそび /雛遊び/
ひなあられ /雛霰/雛あられ/
ひない /比内/皮内/
ひないどり /比内鶏/
ひなか /日中/
ひなかざり /雛飾り/
ひながし /雛菓子;雛祭り用のお菓子/
ひながた /雛形/ひな形/雛型/ひな型/
ひなぎく /雛菊/
ひなげし /雛罌粟/
ひなこ /雛子;名/日向子/比奈子/日名子/
ひなずし /雛鮨/
ひなせ /日生/
ひなた /日向/
ひなたぼっこ /日向ぼっこ/
ひなだん /雛壇/
ひなつ /日夏/
ひなどり /雛鳥/
ひなにんぎょう /雛人形/ひな人形/
ひなまつり /雛祭り;今日は楽しい-/ひな祭り/雛祭/
ひなまめほん /雛豆本/
ひなもと /雛元/
ひならず /日ならず/
ひならずして /日ならずして/
ひなわ /火縄/
ひなわじゅう /火縄銃/
ひなん /避難;†escape/非難;†blame/批難;=非難/
ひなんかのうせい /非難可能性/
ひなんかんこく /避難勧告/
ひなんきじ /非難記事/
ひなんくんれん /避難訓練/
ひなんけつぎ /非難決議/
ひなんごや /避難小屋/
ひなんさき /避難先/
ひなんじょ /避難所/
ひなんせいかつ /避難生活/
ひなんせいめい /非難声明/
ひなんばしょ /避難場所/
ひなんみん /避難民/
ひなんめいれい /避難命令/
ひにく /皮肉/髀肉;腿の肉。「-の嘆」/
ひにくや /皮肉屋/
ひにち /日々/日日/日にち/
ひにちじょう /非日常/
ひにちじょうせい /非日常性/
ひにちじょうてき /非日常的/
ひにひに /日に日に;day by day/
ひにほんご /非日本語/
ひにゅう /泌乳/
ひにょう /泌尿/
ひにょうき /泌尿器/
ひにょうきか /泌尿器科/
ひにん /避妊/否認/非人/
ひにんぐ /避妊具/
ひにんけん /否認権/
ひにんげん /非人間/
ひにんげんてき /非人間的/
ひにんしょう /非人称/
ひにんじょう /非人情/
ひにんほう /避妊法/
ひね /陳/老成/
ひねくれもの /捻くれ者/ひねくれ者/
ひねしょうが /陳生姜/
ひねずみ /火鼠;伝説上の鼠/
ひねつ /比熱/
ひねの /日根野/
ひねもす /終日/
ひねり /捻り/
ひねん /比年/
ひの /日野/火野/樋野/
ひのいり /日の入り/日入/
ひのうち /日の中/
ひのうみ /火の海/
ひのうりつ /非能率/
ひのうりつてき /非能率的/
ひのえ /丙;[十干]3/
ひのえいぬ /丙戌/
ひのえうま /丙午/
ひのえさる /丙申/
ひのえたつ /丙辰/
ひのえとら /丙寅/
ひのえね /丙子/
ひのえまた /檜枝岐/桧枝岐/
ひのおか /日ノ岡/
ひのかげ /日之影/
ひのかみ /火の神/日の神;天照大神/
ひのき /檜/桧/
ひのきぶたい /桧舞台/檜舞台/
ひのきぶろ /檜風呂/
ひのくち /樋ノ口/樋の口/
ひのくま /日隈/
ひのくるま /火の車/
ひのけ /火の気/
ひのこ /火の粉/
ひのし /日野市/
ひのじどうしゃ /日野自動車;[企業名]/
ひのたま /火の玉/
ひのて /火の手/
ひので /日の出/日出/日之出/
ひのでじょし /日出女子/
ひのでじょしがくえん /日出女子学園/
ひのでまえ /日の出前/
ひのと /丁;[十干]4/
ひのとい /丁亥/
ひのとう /丁卯/
ひのとうし /丁丑/
ひのととり /丁酉/
ひのとひつじ /丁未/
ひのとみ /丁巳/
ひのとり /火の鳥/
ひのはら /桧原/
ひのはる /日之春/
ひのばし /日野橋/
ひのべ /日延べ/
ひのまる /日の丸/
ひのまるべんとう /日の丸弁当;白飯と梅干しのみで構成される弁当/
ひのまわり /火の回り/
ひのみ /火の見;-櫓/
ひのみこ /日の御子/
ひのみさき /日御碕/日御崎/
ひのみやぐら /火の見櫓/
ひのめ /日の目/
ひのもと /日の本/火の元/
ひのもり /日野森;姓/
ひのようじん /火の用心/
ひはい /疲憊/
ひはかいけんさ /非破壊検査/
ひはかいてき /非破壊的/
ひはく /菲薄/皮帛/
ひはつ /被髪/
ひはなち /樋放/
ひはら /日原/
ひはん /批判/
ひはんいがい /批判以外/
ひはんかくご /批判覚悟/
ひはんきじ /批判記事/
ひはんしゃ /批判者/
ひはんせいしん /批判精神/
ひはんせいりょく /批判勢力/
ひはんたいしょう /批判対象/
ひはんてき /批判的/
ひはんてきいけん /批判的意見/
ひはんてつがく /批判哲学/
ひはんひょう /批判票/
ひはんりょく /批判力/
ひはんりろん /批判理論;kritische Theorie(独)/
ひば /比婆/
ひばい /肥培/非売/
ひばいひん /非売品/
ひばかま /緋袴/
ひばかり /日計/
ひばく /被爆;†爆発にあう/被曝;†放射線にさらされる/飛瀑;高い滝/被縛/
ひばくしゃ /被爆者;†「原爆-」/被曝者;†「放射能漏れの-」/
ひばくせんりょうけい /被曝線量計/
ひばくち /被爆地/
ひばくりょう /被曝量/被爆量;?/
ひばこ /火箱/
ひばご /卑罵語/
ひばし /火箸/
ひばしら /火柱/
ひばち /火鉢/
ひばな /火花/
ひばら /桧原/檜原/脾腹;脇腹/
ひばらむら /桧原村/
ひばり /雲雀/告天子/
ひばん /非番/
ひひ /狒狒/比比/霏霏/霏々/比々/狒々/
ひひょう /批評/
ひひょうか /批評家/
ひひょうがん /批評眼/
ひひょうき /批評器/
ひひょうし /批評誌/
ひひょうしゃ /批評者/
ひひょうじ /非表示/
ひひょうじゅん /非標準/
ひび /日々/日日/皹/罅/皸/日比/
ひびき /響き/響/
ひびこよう /日々雇用/
ひびこれこうじつ /日々是好日/
ひびつ /火櫃;火鉢/
ひびの /日比野/
ひびや /日比谷/
ひびやえき /日比谷駅/
ひびやこうえん /日比谷公園/
ひびやこくさい /日比谷国際/
ひびやせん /日比谷線/
ひびやせんちょくつう /日比谷線直通/
ひびやとしょかん /日比谷図書館/
ひびややおん /日比谷野音/
ひびややがいおんがくどう /日比谷野外音楽堂/
ひびょういん /避病院/
ひびわれ /罅割れ/ひび割れ/
ひぴりんけい /非ピリン系/
ひふ /皮膚/被布/非負/
ひふえん /皮膚炎/
ひふか /皮膚科/
ひふかい /皮膚科医/
ひふかがく /皮膚科学/
ひふかんかく /皮膚感覚;-で捉える/
ひふがん /皮膚癌/皮膚がん/皮膚ガン/
ひふきだけ /火吹き竹/
ひふきんえん /皮膚筋炎;[医]/
ひふく /被覆/被服/
ひふくき /被覆木/
ひふくきん /腓腹筋/
ひふくぎ /被覆木/
ひふくざい /被覆材/
ひふくひ /被服費/
ひふくりつ /被覆率/
ひふこう /非負項/
ひふこきゅう /皮膚呼吸/
ひふせいすう /非負整数/
ひふそしき /皮膚組織/
ひふち /非負値/
ひふていち /非不定値/非負定値/
ひふびょう /皮膚病/
ひふみ /日文/一二三/
ひふやく /皮膚薬/
ひふようしゃ /被扶養者/
ひふん /悲憤/
ひふんこうがい /悲憤慷慨/
ひぶ /日歩/秘部/
ひぶせ /火伏せ/
ひぶそう /非武装/
ひぶそうちたい /非武装地帯;DMZ/
ひぶそうちゅうりつ /非武装中立/
ひぶた /火蓋/
ひぶつ /秘仏/
ひぶつりてき /非物理的/
ひぶん /碑文/非分/非文;*/
ひぶんかつ /非分割/
ひぶんかてき /非文化的/
ひぶんしょう /飛蚊症/
ひぶんは /非文派/
ひぶんめいてき /非文明的/
ひへい /疲弊/
ひへいこう /非平衡/
ひへいこうけい /非平衡系/
ひへいこうじょうたい /非平衡状態/
ひへいそく /非閉塞/
ひへいそくせい /非閉塞性/
ひへん /火偏/日偏/
ひほう /秘宝;†hidden treasure.「インカの-」/秘法;†mystique.「若返りの-」/悲報/非法;out of law.「-の行い」/秘方;†secret recipe/飛報/
ひほうかん /秘宝館/
ひほうしゃせい /非放射性/
ひほうわ /非飽和/
ひほけんしゃ /被保険者/
ひほけんぶつ /被保険物/
ひほしょく /被補食/
ひほじ /非保持/
ひほん /秘本/
ひほんしつてき /非本質的/
ひぼう /誹謗/非望/
ひぼうちゅうしょう /誹謗中傷/
ひぼうりょく /非暴力/
ひぼうりょくていこう /非暴力抵抗/
ひぼし /干乾し/日干/
ひぼたん /緋牡丹/
ひぼん /非凡/
ひま /暇/閑/隙;(すきま)/蓖麻;唐胡麻/
ひまく /皮膜;membrane/被膜;capsule/
ひまご /曾孫/
ひまし /日増し/蓖麻子;-油/
ひましに /日増しに/
ひましゆ /蓖麻子油/ヒマシ油/ひまし油/
ひまじん /暇人/閑人/
ひまち /日待ち/
ひまつ /飛沫/
ひまつかんせん /飛沫感染/
ひまつでんせん /飛沫伝染/
ひまつぶし /暇潰し/暇つぶし/
ひまつり /火祭/火祭り/
ひまひま /暇々/暇暇/
ひまらやすぎ /ヒマラヤ杉;Himalaya/
ひまわり /向日葵/火回り/
ひまわりいろ /向日葵色/
ひまわりゆ /ひまわり油/
ひまん /肥満/
ひまんがた /肥満型/
ひまんさいぼう /肥満細胞;[生物]mast cell/
ひまんしょう /肥満症/
ひまんじ /肥満児/
ひまんたい /肥満体/
ひまんたんどらか /ヒマンタンドラ科/Himantandraceae/
ひみ /氷見/
ひみこ /卑弥呼;3世紀ごろの邪馬台国の女王/日美子/
ひみせん /氷見線/
ひみつ /秘密/
ひみつかい /秘密会/
ひみつかいだん /秘密会談/
ひみつかぎ /秘密鍵/
ひみつがいこう /秘密外交;secret diplomacy/
ひみつきち /秘密基地/
ひみつけいさつ /秘密警察/
ひみつけっしゃ /秘密結社/
ひみつげんしゅ /秘密厳守/
ひみつしゅうかい /秘密集会/
ひみつしゅぎ /秘密主義/
ひみつしれい /秘密指令/
ひみつせんきょ /秘密選挙/
ひみつそしき /秘密組織/
ひみつたんてい /秘密探偵/
ひみつちょうさいん /秘密調査員/
ひみつつみたてきん /秘密積立金/
ひみつとうひょう /秘密投票/
ひみつど /秘密度/
ひみつへいき /秘密兵器/
ひみつほじけいやく /秘密保持契約/
ひみつぼん /秘密本/
ひみつり /秘密裏/秘密裡/
ひみょう /秘妙/
ひみん /卑民/
ひみんしゅせい /非民主性/
ひみんしゅてき /非民主的/
ひむか /日向/
ひむかい /日向/
ひむら /日村/
ひむろ /氷室/
ひむろさえこ /氷室冴子/
ひめ /姫/媛/
ひめい /悲鳴/碑銘/非命/
ひめかいどう /姫街道/
ひめかわ /姫川/
ひめがみ /姫神;⇔彦神/比売神;⇔比古神/
ひめがわ /姫川/
ひめき /姫木/
ひめぎみ /姫君/
ひめくり /日捲り;毎日めくるカレンダー/日めくり/
ひめこ /姫子/
ひめごぜ /姫御前/
ひめごと /秘め事/
ひめさま /姫様/
ひめしま /姫島/
ひめしんせん /姫新線/
ひめじ /姫路/
ひめじえき /姫路駅/
ひめじかん /姫路間/
ひめじし /姫路市/
ひめじじょう /姫路城/
ひめじどっきょうだいがく /姫路獨協大学/姫路独協大学/
ひめじひがし /姫路東/
ひめじほうめん /姫路方面/
ひめじま /姫嶋/
ひめたけ /姫竹/
ひめど /姫戸/
ひめの /姫野/
ひめのき /姫乃樹/
ひめのぎ /姫ノ樹/姫乃樹/
ひめはじめ /姫始め;正月/
ひめまつ /姫松/
ひめみこ /姫御子/
ひめみや /姫宮/
ひめゆり /姫百合/
ひめゆりぶたい /ひめゆり部隊;[日本史](1945)/
ひめん /罷免/
ひめんけん /罷免権/
ひも /紐/綬/
ひもう /被毛/
ひもく /費目/皮目/
ひもくぎょ /比目魚/
ひもくべつ /費目別/
ひもじ /火文字/緋文字;Hawthorne, The Scarlet Letter (1850)/
ひもじょう /紐状/
ひもすがら /終日/
ひもち /日持ち/日保ち;卵は意外と-する/火持ち;-のよい炭/
ひもつき /紐付き/
ひもつけ /紐付け/
ひもと /火元/
ひもとおし /紐通し;ホイッスルの-/
ひもとせきにんしゃ /火元責任者/
ひもの /干物/檜物/
ひもぱん /紐パン;[新語]紐で結ぶパンツ/
ひもよう /紐用/
ひもろぎ /胙;神籬のお供え/神籬/
ひもん /秘文;秘密の呪文/
ひもんじ /緋文字;Hawthorne, The Scarlet Letter (1850)/
ひもんや /碑文谷/
ひゃく /百/岶/襞/辟/珀/
ひゃくい /百位/
ひゃくいち /百一;うそつき/
ひゃくえん /百円/
ひゃくえんだま /百円玉/
ひゃくえんらいたー /百円ライター/
ひゃくおく /百億/
ひゃくがい /百害/
ひゃくぎょう /百行/
ひゃくげん /百元/
ひゃくごぎんこう /百五銀行/
ひゃくしきしてい /百式司偵/
ひゃくしぜんしょ /百子全書/
ひゃくしゃくかんとう /百尺竿頭/
ひゃくしゅうねん /百周年/
ひゃくしゅつ /百出/
ひゃくしょう /百姓/百勝/
ひゃくしょういっき /百姓一揆/
ひゃくしょうや /百姓家/
ひゃくしょうよみ /百姓読み/
ひゃくじ /百事/
ひゃくじゅう /百獣/
ひゃくじゅうおう /百獣王/
ひゃくすうじゅう /百数十/
ひゃくすうじゅうにん /百数十人/
ひゃくせい /百世/
ひゃくせつ /百折/
ひゃくせつふとう /百折不撓/
ひゃくせん /百選/百戦/百千/
ひゃくせんひゃくしょう /百戦百勝/
ひゃくせんれんま /百戦錬磨/百戦練磨/
ひゃくそく /百足/
ひゃくたい /百態/
ひゃくたけ /百武/
ひゃくたたき /百叩き/
ひゃくたろう /百太郎/
ひゃくだい /百代/
ひゃくだいいじょう /百台以上/
ひゃくちょう /百兆/
ひゃくてんまんてん /百点満点/
ひゃくど /百度/
ひゃくどまいり /百度参り/
ひゃくにじゅうにち /百二十日/
ひゃくにち /百日/
ひゃくにちいも /百日芋/
ひゃくにちさいばん /百日裁判;公選法/
ひゃくにちぜき /百日咳/
ひゃくにちそう /百日草/
ひゃくにちてんか /百日天下;[世界史]les Cent-Jours/
ひゃくにん /百人/
ひゃくにんいじょう /百人以上/
ひゃくにんいっしゅ /百人一首/
ひゃくにんぎり /百人斬り/
ひゃくにんちょう /百人町/
ひゃくにんひゃくよう /百人百様/
ひゃくにんりき /百人力/
ひゃくねん /百年/
ひゃくねんかせい /百年河清/
ひゃくねんせんそう /百年戦争/
ひゃくねんのけい /百年の計;国家-/
ひゃくねんまえ /百年前/
ひゃくはちじゅうど /百八十度/
ひゃくはちぼんのう /百八煩悩/
ひゃくばい /百倍/
ひゃくひろ /百尋/
ひゃくぶん /百聞/百分/
ひゃくぶんひ /百分比/
ひゃくぶんりつ /百分率/
ひゃくまい /百枚/
ひゃくまた /百又/
ひゃくまん /百万/
ひゃくまんえん /百万円/
ひゃくまんかい /百万回/
ひゃくまんごく /百万石/
ひゃくまんだい /百万台/
ひゃくまんだら /百万陀羅/
ひゃくまんにん /百万人/
ひゃくまんねん /百万年/
ひゃくまんべん /百万遍/
ひゃくまんりょう /百万両/百萬両/
ひゃくみ /百味/
ひゃくみだんす /百味箪笥/
ひゃくめ /百目/
ひゃくめいざん /百名山/
ひゃくめんそう /百面相/
ひゃくもじ /百文字/
ひゃくものがたり /百物語/
ひゃくやく /百薬/
ひゃくやくのちょう /百薬の長/
ひゃくようばこ /百葉箱/
ひゃくらい /百雷/
ひゃくり /百里/
ひゃくりょう /百僚/
ひゃくれつ /百裂/
ひゃくれん /百錬/
ひゃくれんぱつ /百連発/
ひゃくろん /百論/
ひゃっか /百科;「-事典」/百花;「-繚乱」/百貨;「-店」/百家;「諸子-」/
ひゃっかい /百回/
ひゃっかじてん /百科事典/百科辞典/
ひゃっかせいほう /百花斉放/
ひゃっかぜんしょ /百科全書/
ひゃっかぜんしょか /百科全書家/
ひゃっかぜんしょは /百科全書派;les Encyclopedistes/
ひゃっかそうめい /百家争鳴/
ひゃっかてん /百貨店/
ひゃっかてんがた /百貨店型/
ひゃっかりょうらん /百花繚乱/
ひゃっかん /百貫/百官/
ひゃっき /百鬼/
ひゃっきえん /百鬼園/
ひゃっきやぎょう /百鬼夜行/
ひゃっきやこう /百鬼夜行/
ひゃっきん /百均;[新語][略語]百円均一/
ひゃっけい /百景/百計/
ひゃっけん /百間/百見/
ひゃっこう /百行/
ひゃっぱつ /百発/
ひゃっぱつひゃくちゅう /百発百中/
ひゃっぱん /百般/
ひゃっぴき /百匹/
ひゃっぴょう /百票/
ひゃっぺん /百遍/
ひゃっぽ /百歩/
ひゃっぽう /百方/
ひゃっぽだ /百歩蛇/
ひや /火屋/冷や/
ひやあせ /冷や汗/冷汗/
ひやかし /素見/冷やかし/
ひやく /飛躍/秘薬/非役/秘鑰/
ひやくてき /飛躍的/
ひやくてきしんてん /飛躍的進展/
ひやけ /日焼け/日焼/
ひやけどめ /日焼止め/日焼け止め;sun block/
ひやざけ /冷や酒/冷酒/
ひやし /冷やし;cold/
ひやしちゅうか /冷やし中華/冷し中華/
ひやそうめん /冷や素麺/
ひやとい /日雇い/
ひやといろうどうしゃ /日雇い労働者;casual worker/
ひやひや /冷や冷や/
ひやま /檜山/桧山/日山/樋山/
ひやみず /冷や水;年寄の-/冷水/
ひやみづ /冷水/
ひやむぎ /冷麦/
ひやめし /冷や飯;-を食う/冷飯/
ひややか /冷やか/
ひややっこ /冷奴/冷や奴/
ひゅーむかん /ヒューム管/
ひゅうが /日向/
ひゅうがなだ /日向灘/
ひゅうま /飛雄馬/
ひゆ /比喩/譬喩;≒比喩/
ひゆーくりっどきかがく /非ユークリッド幾何学/
ひゆうきてき /非有機的/
ひゆうり /非有理/
ひゆか /譬喩歌/
ひゆてき /比喩的/
ひゆひょうげん /比喩表現/
ひゆほう /比喩法/
ひょう /表/豹/票;vote/雹/評/標;目標/漂;漂白/瓢;瓢箪/剽;剽軽/嫖;かるい/慓;慓悍/縹;はなだ/飄;飄々/飃;「飄」の異体字/驃/氷/冰;「氷」の異体字/冫;(にすい)/馮/憑;憑依/彪/殍;うえじに/飆;つむじかぜ/驫/髟;(かみがしら)/拍;拍子/俵;たわら/兵;(呉音)/平;平韻/凭;もた・れる/
ひょうあつめ /票集め/
ひょうい /憑依/表意/
ひょういつ /飄逸/
ひょういてき /表意的/
ひょういもじ /表意文字/
ひょういれ /票入/
ひょういん /平韻/
ひょうえ /兵衛/
ひょうおん /表音/氷温;NB:-2〜+2℃/
ひょうおんご /表音語/
ひょうおんせい /表音性/
ひょうおんてき /表音的/
ひょうおんぶん /表音文/
ひょうおんもじ /表音文字/
ひょうか /評価/氷菓/氷花/評家/瓢果/
ひょうかい /氷解/氷塊/氷海/
ひょうかいがい /評価以外/
ひょうかえき /評価益/
ひょうかおち /評価落/
ひょうかかいせき /評価解析/
ひょうかかかく /評価価格/
ひょうかかんきょう /評価環境/
ひょうかかんすう /評価関数/
ひょうかがく /評価額/評価学/
ひょうかき /評価機/評価器/評価期/
ひょうかきじ /評価記事/
ひょうかきじゅん /評価基準/
ひょうかきそく /評価規則/
ひょうかぎじゅつ /評価技術/
ひょうかぎほう /評価技法/
ひょうかく /嫖客/
ひょうかけい /評価系/
ひょうかけっか /評価結果/
ひょうかけんきゅうしつ /評価研究室/
ひょうかご /評価後/評価語/
ひょうかごさ /評価誤差/
ひょうかさがくきん /評価差額金/
ひょうかしえん /評価支援/
ひょうかしき /評価式/
ひょうかしけん /評価試験/
ひょうかししん /評価指針/
ひょうかしゃ /評価者/
ひょうかしゃくど /評価尺度/
ひょうかじっけん /評価実験/
ひょうかじゅんい /評価順位/
ひょうかじゅんじょ /評価順序/
ひょうかじょうけん /評価条件/
ひょうかず /評価図/
ひょうかせいど /評価制度/
ひょうかぞん /評価損/
ひょうかたいしょう /評価対象/
ひょうかち /評価値/
ひょうかてき /評価的/
ひょうかてん /評価点/
ひょうかてんすう /評価点数/
ひょうかのうりょく /評価能力/
ひょうかばん /評価版/
ひょうかふのう /評価不能/
ひょうかぶ /評価部/
ひょうかほう /評価法/
ひょうかほうしき /評価方式/
ひょうかほうほう /評価方法/
ひょうかよう /評価用/
ひょうかりょう /評価量/
ひょうかん /氷冠;ice cap/剽悍/慓悍;=剽悍/
ひょうが /氷河/
ひょうがい /表外/
ひょうがき /氷河期/
ひょうがじだい /氷河時代/
ひょうがじょう /氷河上/
ひょうがど /氷河土/
ひょうがわ /豹皮/
ひょうき /表記/標記;mark,title/氷期/標旗/兵機/
ひょうきこうしゅうかい /標記講習会/
ひょうきじょう /表記上/
ひょうきたいけい /表記体系/
ひょうきへい /驃騎兵/
ひょうきほう /表記法/
ひょうきほうほう /表記方法/
ひょうきゅう /氷球/
ひょうきょ /憑拠/
ひょうきよう /表記用/
ひょうきん /剽軽/標金/
ひょうきんもの /剽軽者/ひょうきん者/
ひょうぎ /評議/
ひょうぎいいんかい /評議委員会/
ひょうぎいん /評議員/
ひょうぎかい /評議会/
ひょうぎん /兵銀/
ひょうぐ /表具/
ひょうぐし /表具師/
ひょうぐみ /表組み/
ひょうぐや /表具屋/
ひょうぐやぶし /表具屋節/
ひょうけい /表敬/
ひょうけいさん /表計算/
ひょうけいさんきのう /表計算機能/
ひょうけいしき /表形式/
ひょうけいほうもん /表敬訪問/
ひょうけつ /氷結/表決;†議案への賛否を表明する/評決;†評議し決定する/票決;†投票して決定する/
ひょうけつけん /表決権/
ひょうけん /憑肩/憑険/
ひょうけんさく /表検索/
ひょうけんだいり /表見代理/
ひょうげん /表現/氷原/評言/
ひょうげんいぜん /表現以前/
ひょうげんかつどう /表現活動/
ひょうげんかのう /表現可能/
ひょうげんかのうせい /表現可能性/
ひょうげんがた /表現型;[生物]phenotype/
ひょうげんきのう /表現機能/
ひょうげんぎじゅつ /表現技術/
ひょうげんぎほう /表現技法/
ひょうげんぎょうれつ /表現行列/
ひょうげんけい /表現型;phenotype/表現系;expression system/
ひょうげんけいしき /表現形式/
ひょうげんけいたい /表現形態/
ひょうげんこうい /表現行為/
ひょうげんご /表現語/
ひょうげんしき /表現式/
ひょうげんしゃ /表現者/
ひょうげんしゅぎ /表現主義/
ひょうげんしゅだん /表現手段/
ひょうげんしゅほう /表現手法/
ひょうげんじたい /表現自体/
ひょうげんじょう /表現上/
ひょうげんぜんたい /表現全体/
ひょうげんちょう /表現長/
ひょうげんてき /表現的/
ひょうげんない /表現内/
ひょうげんないよう /表現内容/
ひょうげんのうりょく /表現能力/
ひょうげんのじゆう /表現の自由;憲法21条/
ひょうげんは /表現派/
ひょうげんふかのう /表現不可能/
ひょうげんぶつ /表現物/
ひょうげんほう /表現法/
ひょうげんほうほう /表現方法/
ひょうげんもじれつ /表現文字列/
ひょうげんよく /表現欲/
ひょうげんりょく /表現力/
ひょうげんりょくぶそく /表現力不足/
ひょうげんろん /表現論/
ひょうこう /標高/
ひょうこうさ /標高差/
ひょうご /兵庫/標語/評語/
ひょうごけん /兵庫県/
ひょうごけんちょう /兵庫県庁/
ひょうごけんほくぶ /兵庫県北部/
ひょうごけんよせん /兵庫県予選/
ひょうごけんりつ /兵庫県立/
ひょうごふう /標語風/
ひょうごもじ /表語文字/
ひょうごりょう /兵庫寮/
ひょうさ /票差/
ひょうさくさん /氷酢酸/
ひょうさつ /表札/標札/
ひょうざい /表在/
ひょうざいせい /表在性/
ひょうざん /氷山/
ひょうし /表紙/拍子/
ひょうしえ /表紙絵/
ひょうしが /表紙画/
ひょうしき /標識/表式/
ひょうしきごう /拍子記号;[音楽]/
ひょうしきしょく /標識色/
ひょうしきとう /標識灯/
ひょうしきどおり /標識通り/
ひょうしきばんごう /標識番号/
ひょうしぎ /拍子木/
ひょうしぎきり /拍子木切り;じゃがいもの-/
ひょうしつ /氷室/
ひょうしぬけ /拍子抜け/
ひょうしゃ /評者/
ひょうしゃく /評釈/
ひょうしゅつ /表出/
ひょうしょ /表書/
ひょうしょう /表彰/表象/標章/氷床/氷晶/平声/
ひょうしょうきのう /表象機能/
ひょうしょうしき /表彰式/
ひょうしょうしきしゅうりょうご /表彰式終了後/
ひょうしょうしゅぎ /表象主義/
ひょうしょうじょう /表彰状/
ひょうしょうだい /表彰台/
ひょうしょく /氷食/
ひょうじ /表示/標示/票時/憑恃/
ひょうじいき /表示域/
ひょうじいち /表示位置/
ひょうじか /表示可/
ひょうじかかく /表示価格/
ひょうじかのう /表示可能/
ひょうじかのうしょく /表示可能色/
ひょうじかん /表示管/
ひょうじかんけい /表示関係/
ひょうじがめん /表示画面/
ひょうじき /表示器/表示機/
ひょうじきかく /表示規格/
ひょうじきじゅん /表示基準/
ひょうじきのう /表示機能/
ひょうじぎむ /表示義務/
ひょうじぎょう /表示行/
ひょうじけい /表示系/
ひょうじけいしき /表示形式/
ひょうじけいたい /表示形態/
ひょうじけたすう /表示桁数/
ひょうじこうもく /表示項目/
ひょうじさき /表示先/
ひょうじざか /表示坂/
ひょうじしき /表示式/
ひょうじしきすう /表示色数/
ひょうじしゅうはすう /表示周波数/
ひょうじしょく /表示色/
ひょうじじ /表示時/
ひょうじじかん /表示時間/
ひょうじじょう /表示上/
ひょうじじょうほう /表示情報/
ひょうじせいのう /表示性能/
ひょうじせってい /表示設定/
ひょうじそう /表示相/
ひょうじそうち /表示装置/
ひょうじそくど /表示速度/
ひょうじち /表示値/
ひょうじちゅう /表示中/
ひょうじてき /表示的/
ひょうじてきいみろん /表示的意味論/
ひょうじとう /表示灯/
ひょうじないよう /表示内容/
ひょうじのうりょく /表示能力/
ひょうじはば /表示幅/
ひょうじはんい /表示範囲/
ひょうじばいりつ /表示倍率/
ひょうじばん /表示板/表示盤/表示版/
ひょうじぶ /表示部/
ひょうじぶつ /表示物/
ひょうじぶぶん /表示部分/
ひょうじほう /表示法/
ひょうじほうしき /表示方式/
ひょうじほうほう /表示方法/
ひょうじまど /表示窓/
ひょうじめん /表示面/
ひょうじめんせき /表示面積/
ひょうじもじ /表示文字/
ひょうじもじすう /表示文字数/
ひょうじゃ /評者/
ひょうじゅん /標準/
ひょうじゅん> /標準;-温度,-ロウソク/
ひょうじゅんあん /標準案/
ひょうじゅんいがい /標準以外/
ひょうじゅんいち /標準位置/
ひょうじゅんえき /標準液;[化学]standard solution/
ひょうじゅんおん /標準音/
ひょうじゅんおんがくじてん /標準音楽辞典/
ひょうじゅんか /標準化/標準課/
ひょうじゅんかいいんかい /標準化委員会/
ひょうじゅんかかく /標準価格/
ひょうじゅんかかくまい /標準価格米/
ひょうじゅんかかつどう /標準化活動/
ひょうじゅんかしぼうりつ /標準化死亡率/
ひょうじゅんかじぎょう /標準化事業/
ひょうじゅんかせき /標準化石/
ひょうじゅんかだんたい /標準化団体/
ひょうじゅんかつどう /標準活動/
ひょうじゅんかどうこう /標準化動向/
ひょうじゅんかんきょう /標準環境/
ひょうじゅんかんじ /標準漢字/
ひょうじゅんかんすう /標準関数/
ひょうじゅんき /標準機/標準軌/
ひょうじゅんきかく /標準規格/
ひょうじゅんきかん /標準軌間/
ひょうじゅんきどう /標準軌道/
ひょうじゅんきのう /標準機能/
ひょうじゅんきょく /標準局/
ひょうじゅんきんり /標準金利;prime rate/
ひょうじゅんけい /標準形/標準型/
ひょうじゅんけいしき /標準形式/
ひょうじゅんげんぞう /標準現像/
ひょうじゅんこうげん /標準光源/
ひょうじゅんこうせい /標準構成/
ひょうじゅんこうりかかく /標準小売価格/
ひょうじゅんご /標準語/
ひょうじゅんごいがい /標準語以外/
ひょうじゅんざひょう /標準座標/
ひょうじゅんしげき /標準刺激/
ひょうじゅんしてい /標準指定/
ひょうじゅんしゅつりょく /標準出力/
ひょうじゅんしょく /標準色/
ひょうじゅんしよう /標準仕様/
ひょうじゅんじ /標準時/
ひょうじゅんじかん /標準時間/
ひょうじゅんじっそう /標準実装/
ひょうじゅんじょうたい /標準状態/
ひょうじゅんじん /標準人/
ひょうじゅんぜいりつ /標準税率/
ひょうじゅんそうちゃく /標準装着/
ひょうじゅんそうび /標準装備/
ひょうじゅんたいけい /標準体型/
ひょうじゅんち /標準値/
ひょうじゅんてき /標準的/
ひょうじゅんてききょうかしょ /標準的教科書/
ひょうじゅんてつづき /標準手続/標準手続き/
ひょうじゅんてんぷ /標準添付/
ひょうじゅんでんぱ /標準電波/
ひょうじゅんとうさい /標準搭載/
ひょうじゅんとくてん /標準得点/
ひょうじゅんにほんご /標準日本語/
ひょうじゅんにゅうしゅつりょく /標準入出力/
ひょうじゅんにゅうりょく /標準入力/
ひょうじゅんのう /標準脳/
ひょうじゅんはつおん /標準発音/
ひょうじゅんひょうき /標準表記/
ひょうじゅんひん /標準品/
ひょうじゅんびせいぶつがく /標準微生物学/
ひょうじゅんふく /標準服/
ひょうじゅんふぞく /標準付属/
ひょうじゅんぶひん /標準部品/
ひょうじゅんへんさ /標準偏差/
ひょうじゅんもけい /標準模型/
ひょうじゅんりろん /標準理論/
ひょうじゅんろしゅつ /標準露出/
ひょうじょう /表情/氷上/評定/平調/
ひょうじょうがわら /評定河原/
ひょうじょうきん /表情筋/
ひょうじょうしゅう /評定衆/
ひょうじよう /表示用/
ひょうじようそ /表示要素/
ひょうじらん /表示欄/
ひょうじりょういき /表示領域/
ひょうじれい /表示例/
ひょうじわく /表示枠/
ひょうじん /氷人/
ひょうすう /票数/
ひょうせき /漂石/
ひょうせつ /氷雪/剽窃/評説/
ひょうぜん /飄然/
ひょうそう /表層/表装;書画の-/氷層/
ひょうそうかんきょう /表層環境/
ひょうそうぎょ /表層魚/
ひょうそうこうぞう /表層構造;surface structure/
ひょうそうてき /表層的/
ひょうそうなだれ /表層雪崩/
ひょうそく /表側/平仄/
ひょうぞう /氷像/
ひょうたん /瓢箪/氷炭/
ひょうたんなまず /瓢箪鯰/
ひょうだい /表題/標題/
ひょうだいおんがく /標題音楽/
ひょうだいきょく /表題曲/
ひょうだいさく /表題作/
ひょうだいぶ /表題部/
ひょうだいらん /表題欄/
ひょうだん /評壇/
ひょうちゃく /漂着/
ひょうちゃくぶつ /漂着物/
ひょうちゅう /表中/氷柱/標柱;†目印のハシラ。「バス停の-」/氷中/標注;†annotation.「原著の-」/評註;†批評し注釈する/標註;=標注/評注;=評註/
ひょうちょう /表徴/漂鳥/標徴/憑弔/
ひょうちょうせき /氷長石;adularia/
ひょうちん /氷枕/
ひょうてい /評定/標定/
ひょうていしゃくど /評定尺度/
ひょうていしゃくどほう /評定尺度法/
ひょうていそくど /表定速度/
ひょうていち /評定値/
ひょうてき /標的/
ひょうてきかく /標的核/
ひょうてん /評点/氷点/瓢天/
ひょうてんか /氷点下/
ひょうでん /評伝/票田/
ひょうとう /表頭/
ひょうど /表土/
ひょうどう /兵藤/兵頭/
ひょうのう /氷嚢/
ひょうはく /漂白;†bleach.「シャツの-」/漂泊;†wander.「-の詩人」/表白;confess.「胸中を-する」/
ひょうはくざい /漂白剤/
ひょうはくしゃ /漂泊者/
ひょうばく /氷瀑/
ひょうばん /評判/
ひょうばんき /評判記/
ひょうばんけんさく /評判検索/
ひょうばんごう /表番号/
ひょうひ /表皮/
ひょうひょう /飄々/飄飄/瓢々;?/
ひょうび /豹尾;[陰陽道]八将神の一。計都星/
ひょうびょう /縹渺/縹緲/縹眇/
ひょうふう /飄風/
ひょうぶ /兵部/
ひょうぶきょう /兵部卿/
ひょうぶしょう /兵部省;[律令制]三省/
ひょうへき /氷壁/表壁/
ひょうへん /豹変/
ひょうほう /兵法/
ひょうほん /標本/
ひょうほんか /標本化/
ひょうほんかしゅうはすう /標本化周波数/
ひょうほんしつ /標本室/
ひょうほんすう /標本数/
ひょうほんち /標本値/
ひょうほんちょうさ /標本調査;sampling/
ひょうほんてん /標本点/
ひょうほんてんすう /標本点数/
ひょうほんびん /標本瓶/
ひょうぼう /標榜/
ひょうま /豹馬/
ひょうむ /氷霧/
ひょうめい /表明/
ひょうめいけん /表明権/
ひょうめいしゃ /表明者/
ひょうめいほうほう /表明方法/
ひょうめん /表面/
ひょうめんおんど /表面温度/
ひょうめんか /表面化/
ひょうめんかこう /表面加工/
ひょうめんきょうかい /表面境界/
ひょうめんけいじょう /表面形状/
ひょうめんしょく /表面色/
ひょうめんしょり /表面処理/
ひょうめんじっそう /表面実装/
ひょうめんじょう /表面上/
ひょうめんじょうたい /表面状態/
ひょうめんせいぎょ /表面制御/
ひょうめんせき /表面積/
ひょうめんちょうりょく /表面張力/
ひょうめんてき /表面的/
ひょうめんは /表面波/
ひょうもく /標目/
ひょうもくひょう /標目表/
ひょうもん /平文/豹紋/
ひょうよみ /票読み/
ひょうり /表裏/
ひょうりいったい /表裏一体/
ひょうりゅう /漂流/
ひょうりゅうき /漂流記/
ひょうりゅうしゃ /漂流者/
ひょうりゅうぶつ /漂流物/
ひょうりょう /秤量/兵糧/
ひょうりょうかへい /秤量貨幣/
ひょうりん /評林/
ひょうれい /憑霊/
ひょうろう /兵糧/兵粮;異体字/
ひょうろうぜめ /兵糧攻め/
ひょうろん /評論/
ひょうろんか /評論家/
ひょうろんかつどう /評論活動/
ひょうろんかれんちゅう /評論家連中/
ひょうろんき /評論器/
ひょうろんし /評論誌/
ひょうろんしゃ /評論社;[出版社名]児童書。www.hyoronsha.co.jp/
ひよ /鵯/
ひよう /費用/飛揚/比容/日傭/
ひようか /費用化/
ひようかかく /費用価格/
ひようしゃ /被用者/
ひようしゃほけん /被用者保険/
ひようたいこうか /費用対効果/
ひようふたん /費用負担/
ひようべんえきぶんせき /費用便益分析;[経済]cost-benefit analysis/
ひよく /肥沃/比翼/
ひよくのとり /比翼の鳥;天に在らば-/
ひよくれんり /比翼連理/
ひよけ /日除け/火除け/日避け/
ひよけち /火除け地/
ひよこ /雛/
ひよこまめ /雛豆/
ひよし /日吉/日義/
ひよしえき /日吉駅/
ひよどり /鵯/
ひよどりごえ /鵯越/
ひより /日和/
ひよりざき /日和崎/
ひよりみ /日和見/
ひよりみしゅぎ /日和見主義/
ひよわ /ひ弱/
ひら /平/片/衡/比良/曹白魚/
ひら> /平;(flat)平籠,(地位のない)平巡査,平隊員/
ひらあやまり /平謝り/
ひらい /飛来/避雷/平井/
ひらいし /平石/
ひらいしん /避雷針/
ひらいずみ /平泉/
ひらいで /平出/
ひらいと /平糸/
ひらいわ /平岩/
ひらうち /平打ち/平打/
ひらお /平尾/平生/
ひらおか /平岡/
ひらおかえき /平岡駅/
ひらおし /平押し/
ひらおよぎ /平泳ぎ/平泳/
ひらおり /平織/平織り/
ひらか /平賀/平鹿/
ひらかた /枚方/平形/
ひらかたこうえん /枚方公園/
ひらかたし /枚方市/
ひらかたしえき /枚方市駅/
ひらかたしみん /枚方市民/
ひらかな /平仮名/
ひらかわ /平川/平河/
ひらかわしゅっぱんしゃ /平河出版社;[出版社名]/
ひらが /平賀/
ひらがげんない /平賀源内/
ひらがた /平型/
ひらがな /平仮名/平假名/
ひらがなひょうき /平仮名表記/ひらがな表記/
ひらがま /平釜/
ひらがわら /平瓦/
ひらき /平木/開/
ひらきかげん /開き加減/
ひらきど /開き戸/
ひらきなおり /開き直り/
ひらきふう /開き封/
ひらぎぬ /平絹/
ひらく /啓/
ひらこ /平子/
ひらこう /平光/
ひらさわ /平沢/平澤/
ひらさん /比良山/
ひらざら /平皿/
ひらざわ /平澤/
ひらしま /平島/平嶋/
ひらしゃいん /平社員/
ひらじ /平地/
ひらじょう /平城/
ひらじろ /平城/
ひらせ /平瀬/
ひらぞこ /平底/
ひらた /平田/枚田/
ひらたあつたね /平田篤胤/
ひらたえき /平田駅/
ひらたけ /平茸/
ひらたちょう /平田町/
ひらたに /平谷/
ひらだい /平台/
ひらち /平地/
ひらつか /平塚/
ひらつかえき /平塚駅/
ひらつかおき /平塚沖/
ひらつかきょうぎじょう /平塚競技場/
ひらつかし /平塚市/
ひらつかしない /平塚市内/
ひらつぼ /平坪/
ひらづみ /平積み/
ひらて /平手/
ひらてうち /平手打ち/
ひらで /平出/
ひらと /平戸/
ひらとじ /平綴じ/
ひらとり /平取/
ひらど /平戸/
ひらどま /平土間/
ひらない /平内/
ひらなか /平中/
ひらなが /平長/
ひらなべ /平鍋/
ひらにわ /平庭/
ひらぬま /平沼/
ひらぬまばし /平沼橋/
ひらね /平根/
ひらの /平野/
ひらのじんじゃ /平野神社/
ひらはし /平橋/
ひらはら /平原/
ひらば /平場/
ひらばせん /平場戦/
ひらばやし /平林/
ひらばり /平針/
ひらばる /平原/
ひらひも /平紐/
ひらび /平日/
ひらふく /平福/
ひらぶたい /平舞台/
ひらぶち /平縁/
ひらぶん /平文/
ひらま /平間/
ひらまく /平幕/
ひらまくゆうしょう /平幕優勝/
ひらまくりきし /平幕力士/
ひらまつ /平松/
ひらみち /平道/
ひらみつ /平光/
ひらめ /平目/鮃/比目魚/
ひらめき /閃き/
ひらめきん /平目筋/
ひらもと /平本/
ひらや /平屋/平谷/
ひらやだて /平屋建て/平屋建/
ひらやね /平屋根/
ひらやま /平山/
ひらゆ /平湯/
ひらら /平良/
ひり /非理/
ひりき /非力/
ひりつ /比率/
ひりつてき /比率的/
ひりゅう /飛龍/飛竜/
ひりゅうづ /飛竜頭/
ひりょう /肥料/
ひりょうか /肥料化/
ひりょうず /飛竜頭;がんもどき/
ひりょうてき /比量的/
ひりょく /非力;ひりき?/臂力/
ひりようしゃ /非利用者/
ひりん /比隣/比倫/
ひりんりてき /非倫理的/
ひる /昼/蛭/蒜;強い臭いのある野菜一般/晝;「昼」の旧字(人名用漢字)/葫/簸;※動詞(ひ・る)/
ひるあんどん /昼行灯/
ひるい /比類/
ひるいし /蛭石;vermiculite/
ひるいじど /非類似度/
ひるいち /昼一/
ひるかわ /蛭川/比留川/
ひるがお /昼顔/
ひるがた /昼型/
ひるげ /昼餉/
ひるこ /蛭子/
ひるころ /昼頃/
ひるごはん /昼御飯/昼ご飯/
ひるごろ /昼頃/
ひるさがり /昼下がり/昼下り/昼下/
ひるざけ /昼酒/
ひるすぎ /昼過ぎ/昼過/
ひるせん /蒜山/
ひるぜん /蒜山/
ひるぜんご /昼前後/
ひるた /蛭田/
ひるてい /昼定/
ひるどき /昼時/
ひるなか /昼中/
ひるね /昼寝/
ひるひなか /昼日中/
ひるべるとくうかん /ヒルベルト空間/
ひるま /昼間/晝間/
ひるまえ /昼前/
ひるむしろもく /ヒルムシロ目/Potamogetonales/
ひるめし /昼飯/昼メシ/
ひるめしだい /昼飯代/
ひるめしどき /昼飯時/
ひるめろ /昼メロ/
ひるやすみ /昼休み/
ひれ /鰭/肩巾/領巾/
ひれあしるい /鰭脚類;[動物]Pinnipedia/
ひれい /比例/非礼/∝/
ひれいかんけい /比例関係/
ひれいく /比例区/
ひれいけいすうかん /比例計数管/
ひれいぜい /比例税/
ひれいだいひょう /比例代表/
ひれいだいひょうせい /比例代表制/
ひれいていすう /比例定数/
ひれいてき /比例的/
ひれいはいぶん /比例配分/
ひれいぼう /非冷房/
ひれいぼうしゃ /非冷房車/
ひれき /披瀝/飛礫/
ひれつ /卑劣/
ひれつかん /卑劣漢/
ひれにく /ヒレ肉/
ひれん /悲恋/
ひれんけつ /非連結/
ひれんじゃく /緋連雀/
ひれんぞくてき /非連続的/
ひろ /尋/大/広/太/洋/史/博/宏/裕/央/浩/弘/寛/祐/啓/泰/拓/拡/廣/比呂/洪/伯/紘/宥/恕/絋/仞/仭/愽;「博」の異体字/
ひろあき /宏明/弘明/博明/博昭/広明/浩明/裕明/裕章/博章/宏昭/浩昭/裕昭/寛明/洋明/広昭/啓明/弘昭/浩晃/宏晃/洋昭/宏朗/広朗/広章/浩秋/弘朗/洋晶/祐彰/祐昭/宏顕/
ひろあきら /寛晰/
ひろい /広井;姓/
ひろいぐい /拾い食い/拾い喰い/
ひろいけ /広池/廣池/
ひろいご /拾い子;⇔捨て子/
ひろいし /広石/
ひろいぬし /拾い主/
ひろいもの /拾い物/
ひろいよみ /拾い読み/
ひろう /披露/疲労/疲勞/
ひろうえん /披露宴/
ひろうかい /披露会/
ひろうかいふく /疲労回復/疲勞恢復/
ひろうかん /疲労感/
ひろうこうぎょう /披露興行/
ひろうこっせつ /疲労骨折/
ひろうこんぱい /疲労困憊/
ひろうしき /披露式/
ひろうす /飛竜頭/
ひろうち /浩内/
ひろうど /疲労度/
ひろえ /広江/浩江/広恵/廣江/宏枝/弘枝/裕江/宏江/浩恵/広絵/
ひろえん /広縁/
ひろお /広尾/浩生/博雄/洋夫/宏雄/洋男/博生/
ひろおえき /広尾駅/
ひろおか /広岡/弘岡/
ひろおかかんとく /広岡監督/
ひろか /裕香/祥加/
ひろかず /博一/浩一/宏和/弘一/博和/裕和/浩和/泰一/大一/博万/
ひろかみ /広神/
ひろかわ /広川/廣川/紘川/
ひろかわしょてん /廣川書店/
ひろがり /広がり/
ひろがわ /広川/
ひろき /弘樹/宏樹/広樹/裕樹/博樹/裕貴/裕紀/博紀/弘毅/洋樹/浩貴/博基/弘城/浩基/博己/宏喜/浩喜/央樹/寛紀/啓樹/寛己/裕毅/
ひろきち /広吉/
ひろく /秘録/
ひろくち /広口/
ひろくに /裕邦/
ひろぐ /弘具/
ひろこ /裕子/寛子/浩子/ひろ子/博子/弘子/広子/倫子/宏子/紘子/宙子/欧子/
ひろこうじ /広小路/
ひろさ /広さ/
ひろさか /広坂/
ひろさき /弘前/広崎/
ひろさきし /弘前市/
ひろさきじょう /弘前城/
ひろさきだい /弘前大/
ひろさきだいがく /弘前大学/
ひろさと /浩郷/宏郷/
ひろさわ /広沢/廣澤/廣沢/
ひろし /大/博/洋/宏/浩/弘/裕/寛/博士/広/泰/央/浩司/博史/浩史/裕司/浩志/ひろ志/広志/博司/広司/大志/弘志/博嗣;名/裕史/洋司/博志/洋史/比呂志/啓之/裕志/弘史/弘司/煕/熙/宏司/宏志/大士/宏史/廣志/浩士/大史/啓志/広史/熈/愽/廣;「広」の旧字(人名用漢字)/
ひろしき /広敷/
ひろしげ /広重/博茂/浩重/
ひろしま /広島/
ひろしまいがい /広島以外/
ひろしまえき /広島駅/
ひろしまかん /広島間/
ひろしまがす /広島ガス;[企業名]/
ひろしまがわ /広島側/
ひろしまきた /広島北/
ひろしまきゅうじょう /広島球場/
ひろしまぎんこう /広島銀行/廣島銀行/
ひろしまくうこう /広島空港/
ひろしまくれどうろ /広島呉道路/
ひろしまけん /広島県/
ひろしまけんせつ /広島建設;[企業名]/
ひろしまけんない /広島県内/
ひろしまけんふちゅうちょう /広島県府中町/
ひろしまこうだい /広島工大/
ひろしまこくぜいきょく /広島国税局/
ひろしまさん /広島産/
ひろしまし /広島市/
ひろしましがい /広島市街/
ひろしまししゃ /広島支社/
ひろしましだい /広島市大/
ひろしましない /広島市内/
ひろしましみんきゅうじょう /広島市民球場/
ひろしましゅうどうだいがく /広島修道大学/
ひろしましょうぎょう /広島商業/
ひろしましりつだい /広島市立大/
ひろしましりつだいがく /広島市立大学/
ひろしましんこうつう /広島新交通/
ひろしまじ /広島路/
ひろしまじょがくいん /広島女学院/
ひろしません /広島戦/
ひろしまたいかい /広島大会/
ひろしまだい /広島大/広島大学;※abbrev/
ひろしまだいがく /広島大学/
ひろしまちく /広島地区/
ひろしまちほう /広島地方/
ひろしまちゅうしんぶ /広島中心部/
ひろしまちょう /広島町/
ひろしまてん /広島店/
ひろしまでんきだい /広島電機大/
ひろしまでんてつ /広島電鉄/
ひろしまとうよう /広島東洋/
ひろしまなづけ /広島菜漬/
ひろしまひがし /広島東/
ひろしまふう /広島風/
ひろしまべん /広島弁/
ひろしまや /広島屋/
ひろしまやき /広島焼/
ひろしょう /広商/
ひろじ /宏治/広治/
ひろすえ /広末/
ひろすえりょうこ /広末涼子/
ひろせ /広瀬/廣瀬/
ひろせがわ /広瀬川/
ひろせどおり /広瀬通/
ひろぜがわ /広瀬川/
ひろそで /広袖/
ひろぞう /弘蔵/
ひろた /広田/廣田/弘田/
ひろたか /弘隆/宏隆/博孝/宏高/浩孝/浩貴/弘崇/宏貴/宏孝/
ひろたき /広瀧/
ひろたけ /博丈/
ひろただ /博唯/裕忠/
ひろたつ /広達/
ひろたに /広谷/
ひろたまみ /広田まみ/
ひろだい /広大/弘大/広島大学;※abbrev/
ひろつ /広津/
ひろつぐ /博嗣/博次/裕次/
ひろづ /広津/
ひろでん /広電/
ひろと /裕人/博人/寛人/浩登/
ひろとし /浩俊/宏寿/
ひろとも /弘具/寛知/
ひろなお /弘尚/弘直/
ひろなか /広中/弘中/弘仲/
ひろなかへいすけ /広中平祐/
ひろなが /広長/
ひろにわ /広庭/
ひろの /広野/
ひろのぶ /博信/裕信/広宣/宏伸/博宣/弘宣/弘宜/
ひろのみや /浩宮/
ひろのり /博紀/博則/博徳/浩則/広徳;名/裕徳/博典/弘法/
ひろはし /広橋/
ひろはば /広幅/
ひろはばとびら /広幅扉/
ひろはら /広原/
ひろば /広場/
ひろばきょうふしょう /広場恐怖症/
ひろひこ /裕彦/博彦/飛呂彦/浩彦/洋彦/恕彦/
ひろひさ /裕久/博久/浩久/浩寿/
ひろひと /裕仁/博人/裕人/宏仁/
ひろひとてんのう /裕仁天皇/
ひろびろ /広々/
ひろふみ /博文/弘文/博史/啓文/宏文/洋文/裕文/寛文/洋史/弘史/大史/廣文/洋典/
ひろぶみ /博文/浩史/弘史/
ひろべ /広部/
ひろま /広間/
ひろまえ /広前/
ひろまさ /宏昌/浩正/裕真/弘昌/広正/洋正/裕昌/弘征/弘真/
ひろまつ /廣松/広松/
ひろまど /広窓/
ひろみ /広美/裕美/博美/弘美/宏美/浩美/洋美/裕実/寛美/ひろ美/広見/比呂美/博己/弘巳/浩巳/弘海/引美/拡稔/
ひろみち /弘道/博道/広道/寛道/拓路/晃道/
ひろみつ /博光/弘光/宏光/博満/広光/廣光/博三/博允/
ひろめ /披露目/広め/
ひろもち /裕望/
ひろや /博也/浩也/
ひろやす /博康/裕康/大和/弘康/浩康/博保/浩靖/博泰/弘安/容靖/
ひろゆき /博之/浩之/裕之/弘之/宏之/寛之/博幸/弘幸/博行/宏幸/啓之/裕幸/弘行/洋之/裕行/広之/浩幸/広幸/宏行/広行/祐之/弘征/洋征/周行/弘恭/陽之/裕由/幸展/
ひろよし /博義/博喜/浩由/博芳/弘恭/浩喜/寛善/敬昌/
ひろん /比論/
ひろんりてき /非論理的/
ひわ /秘話/悲話/鶸/比和/
ひわい /卑猥/鄙猥/卑わい/
ひわいろ /鶸色/
ひわき /樋脇/
ひわきのう /秘話機能/
ひわさ /日和佐/
ひわさき /日和崎/
ひわせい /秘話性/
ひわそうち /秘話装置/
ひわたり /火渡り/樋渡/日渡/
ひわだ /檜皮/
ひわだいろ /檜皮色/
ひわだぶき /檜皮葺き/
ひわちゃ /鶸茶/
ひわり /日割/日割り/
ひわりけいさん /日割計算/
ひわれ /干割れ/
ひん /品/牝/貧/頻;頻度/瀕;瀕死/蘋;うきくさ/稟;稟議/禀;「稟」の異体字/賓;来賓/嬪;別嬪/擯/繽/殯;もがり/濱;「浜」の旧字/浜/斌;文武両道/彬;あきら/顰;顰蹙/
ひんい /品位/
ひんか /貧家/
ひんかい /頻回/
ひんかく /品格/賓客/賓格;[文法]目的格/
ひんかくほう /品確法/
ひんかん /貧寒/
ひんきゃく /賓客/
ひんきゅう /貧窮/殯宮/
ひんぎ /稟議/
ひんく /貧苦/
ひんけい /牝系/牝鶏;-晨す/
ひんけつ /貧血/
ひんこう /品行/貧鉱/
ひんこうほうせい /品行方正/
ひんこん /貧困/
ひんこんこく /貧困国/
ひんこんしゃ /貧困者/
ひんこんしゃかい /貧困社会/
ひんこんせん /貧困線;poverty line. 生活できるギリギリのライン/
ひんこんそう /貧困層/
ひんし /瀕死/品詞/
ひんしかん /品詞間/
ひんしじゅん /品詞順/
ひんしじょうたい /瀕死状態/
ひんしじょうほう /品詞情報/
ひんしつ /品質/稟質/
ひんしついじ /品質維持/
ひんしつかくにん /品質確認/
ひんしつかくほ /品質確保/
ひんしつかんり /品質管理/
ひんしつきかく /品質規格/
ひんしつこうじょう /品質向上/
ひんしつさ /品質差/
ひんしつじょう /品質上/
ひんしつてき /品質的/
ひんしつひょうか /品質評価/
ひんしつふりょう /品質不良/
ひんしつほしょう /品質保証/
ひんしつほしょうぶ /品質保証部/
ひんしつほじきげん /品質保持期限/
ひんしぶんかい /品詞分解/
ひんしめい /品詞名/
ひんしもく /貧歯目;[生物]Dysodonta/
ひんしゅ /品種/
ひんしゅかいりょう /品種改良/
ひんしゅく /顰蹙/
ひんしゅつ /頻出/瀕出/
ひんしゅとうろく /品種登録/
ひんしゅめい /品種名/
ひんしょう /貧小/
ひんしるい /貧歯類/
ひんじ /賓辞/
ひんじゃ /貧者/
ひんじゃく /貧弱/
ひんじょ /貧女;-の一灯/
ひんすう /頻数/
ひんずーきょう /ヒンズー教/
ひんせい /品性/稟性/
ひんせいげれつ /品性下劣/
ひんせき /擯斥/
ひんせん /貧賤/
ひんそ /貧素/
ひんそう /貧相/貧僧/
ひんそん /貧村/
ひんだ /貧打/
ひんてき /貧的/
ひんでぃーご /ヒンディー語;namaste/
ひんでぃご /ヒンディ語/
ひんとう /品等/
ひんど /頻度/貧土/
ひんどう /貧道/
ひんどじゅん /頻度順/
ひんどじょうほう /頻度情報/
ひんどち /頻度値/
ひんどてき /頻度的/
ひんどめい /頻度名/
ひんにゅう /貧乳/
ひんにょ /貧女;-の一灯/
ひんにょう /頻尿/
ひんのう /貧農/
ひんば /牝馬/
ひんばげんていせん /牝馬限定戦/
ひんばん /品番/
ひんぱく /頻拍/
ひんぱつ /頻発/
ひんぱん /頻繁/
ひんぴょう /品評/
ひんぴょうかい /品評会/
ひんぴん /頻々/
ひんぷ /貧富/稟賦/
ひんぷん /繽紛/
ひんみゃく /頻脈/
ひんみん /貧民/
ひんみんがい /貧民街/
ひんみんくつ /貧民窟/
ひんめい /品名/
ひんもく /品目/
ひんもくべつ /品目別/
ひんよう /頻用/
ひんよく /品良く/
び /美/尾/微/鼻/日;(連濁)/火;(連濁)/眉;焦眉/媚;媚態/嵋;峨嵋山/枇;枇杷/琵;琵琶/毘;荼毘/濔;みちる/瀰;瀰漫/備;準備/糒;ほしいい/糜;糜爛/縻;羈縻/麋;おおじか/靡;淫靡/未;(十二支の)ひつじ/寐;≒寝/弭;はず/贔;(呉音) 贔屓/比;(連濁?)/
び> /微/美;美肌,美少女,美文章/
びーがた /Ｂ型/B型/
びーがたかんえん /Ｂ型肝炎;[医]/B型肝炎;[医]hepatitis B/
びーきゅう /Ｂ級/B級/
びーきゅうえいが /Ｂ級映画/B級映画;低予算・非芸術/
びーさいぼう /Ｂ細胞;[医]B cell/
びーしーへいき /BC兵器;[時事](Biological and Chemical weapons) 生物化学兵器/
びーだま /ビー玉/
びーばん /Ｂ判/B判/
びーふん /米粉;食材/
びーぷおん /ビープ音/
びーめん /Ｂ面/B面/
びーる /麦酒/
びーるけん /ビール券/
びーるばら /ビール腹/
びーるびん /ビール瓶/
びあだる /ビア樽/
びい /微意/
びいしき /美意識/
びいん /鼻音/
びいんか /鼻音化/
びいんとう /鼻咽頭/
びう /微雨/眉宇/
びえい /美瑛/
びえん /鼻炎/
びえんやく /鼻炎薬/
びおとーぷ /ビオトープ;野生生物の生育場所。ギリシャ語のBIO(生物)とTOP(場所)の合成語/biotope;英語/Biotop;独語/
びおん /美音/鼻音/微温/微音/
びおんか /鼻音化/
びおんてき /微温的;ヌルい/
びおんとう /微温湯/
びか /美化/美果/微瑕/
びかこうどう /美化行動/
びかご /美化語/
びかん /美観/美感/
びがく /美学/
びがくしゃ /美学者/
びがくじょう /美学上/
びがくてき /美学的/
びがん /美顔/
びがんき /美顔器/
びがんじゅつ /美顔術/
びき /美姫/匹/引き/引/美肌/
びきにすがた /ビキニ姿/
びきゃく /美脚/
びきゅう /備給/
びきょ /美挙/
びきょう /鼻鏡/
びぎ /美技/美妓/
びぎん /微吟/
びく /比丘/魚籠/魚篭/
びくう /鼻腔/
びくしょう /微苦笑/
びくに /比丘尼/
びくん /微醺/
びけい /美形/美景/
びけいすう /微係数/
びけいやく /美形役/
びげいこう /美藝公/
びげん /微減/美言/
びこう /備考/尾行/鼻腔;[解剖](鼻孔よりも奥の)nasal cavity/鼻孔;[解剖]nostril/微香/微光/鼻口;muzzle/備荒/微行;お忍び/
びこうけん /美工研/
びこうせい /微香性/微光星/
びこうらん /備考欄/
びこつ /鼻骨;[解剖]nasal bone/尾骨;[解剖]coccyx/
びこん /鼻根/
びご /寐語/
びさ /微差/
びさい /微細/尾西;地名,愛知/
びさいか /微細化/
びさいかこう /微細加工/
びさいこうぞう /微細構造/
びさん /靡散;糜散の typo?/
びざい /微罪/
びし /微視/
びしつ /美質/
びしてき /微視的/
びしゃ /飛車/
びしゃもん /毘沙門/
びしゃもんてん /毘沙門天/
びしゃもんどう /毘沙門堂/
びしゅ /美酒/
びしゅう /美醜/尾州;尾張/備州;備前・備中・備後/
びしゅく /糜粥/
びしゅっけつ /鼻出血/
びしょう /微笑/微小;micro.「-粒子」/微少;very little.「-量」/美称/美粧;make-up/微傷;slight wound/媚笑/
びしょううんどう /微小運動/
びしょうかく /微小角/
びしょうきょり /微小距離/
びしょうくかん /微小区間/
びしょうしんごう /微小信号/
びしょうじしん /微小地震/
びしょうじゅうりょく /微小重力/
びしょうじゅうりょくか /微小重力下/
びしょうじょ /美少女/
びしょうじょせんし /美少女戦士/
びしょうじょまんが /美少女漫画/
びしょうじょまんがか /美少女漫画家/
びしょうせかい /微小世界/
びしょうでんきょく /微小電極/
びしょうねん /美少年/
びしょうぶぶん /微小部分/
びしょうへんい /微小変位/
びしょうへんか /微少変化/
びしょうめんせき /微小面積/
びしょうりゅうし /微小粒子/
びしょうりょう /微少量/微小量/
びしょく /美食/
びしょくか /美食家/
びしょぬれ /びしょ濡れ/
びしり /美尻/
びしん /美神/微震/美身/
びじ /美辞/鼻茸/
びじく /糜竺/
びじねすし /ビジネス誌/
びじゃく /微弱/
びじゃくでんぱ /微弱電波/
びじゅあるけい /ビジュアル系/
びじゅう /鼻汁/
びじゅうりょく /微重力/
びじゅつ /美術/
びじゅつあいこうか /美術愛好家/
びじゅついん /美術院/
びじゅつか /美術家/
びじゅつかい /美術界/美術会/
びじゅつかん /美術館/
びじゅつかんけい /美術関係/
びじゅつかんしょう /美術観賞/
びじゅつかんしょぞう /美術館所蔵/
びじゅつかんちょう /美術館長/
びじゅつかんてん /美術館展/
びじゅつかんとく /美術監督/
びじゅつがっこう /美術学校/
びじゅつきょういく /美術教育/
びじゅつけい /美術系/
びじゅつさくひん /美術作品/
びじゅつさっか /美術作家/
びじゅつし /美術史/
びじゅつしか /美術史家/
びじゅつしつ /美術室/
びじゅつしにゅうもん /美術史入門/
びじゅつしゅっぱんしゃ /美術出版社;[出版社名]/
びじゅつしょ /美術書/
びじゅつしょう /美術商/
びじゅつじてん /美術辞典/
びじゅつぜんしゅう /美術全集/
びじゅつだい /美術大/
びじゅつてん /美術展/
びじゅつはくぶつかん /美術博物館/
びじゅつひん /美術品/
びじゅつぶ /美術部/
びじょ /美女/
びじょう /尾錠/鼻茸/
びじょうふ /美丈夫/
びじょぎ /美女木/
びじょざくら /美女桜/
びじれいく /美辞麗句/
びじん /美人/
びじんぞう /美人像/
びじんはくめい /美人薄命/
びじんひしょ /美人秘書/
びじんふう /美人風/
びじんろん /美人論/
びすい /微睡;まどろみ/微酔;ほろ酔い/
びすます /Bi/Bismuth/
びせい /美声/美星/
びせいちょう /美星町/
びせいぶつ /微生物/
びせいぶつがく /微生物学;microbiology/
びせいぶつぞうしょく /微生物増殖/
びせいぶつばいよう /微生物培養/
びせき /微積/
びせきぶん /微積分/
びせきぶんがく /微積分学/
びせつ /微雪/
びせん /美泉/微賤/
びぜん /備前/美髯/靡然/
びぜんやき /備前焼/
びそ /鼻祖;意味：その事を始めた人。始祖。/
びそう /美装/
びそうじゅつ /美爪術;[医]/
びそく /微速/尾側/
びそくぜんしん /微速前進/
びそくどさつえい /微速度撮影/
びぞう /微増/
びぞく /美俗/
びた /鐚/
びたい /媚態/額/
びたいちもん /鐚一文/
びたせん /鐚銭/
びたみんいー /ビタミンＥ/ビタミンE/
びたみんえー /ビタミンＡ/ビタミンA/
びたみんけー /ビタミンＫ/ビタミンK/
びたみんざい /ビタミン剤/
びたみんしー /ビタミンＣ/ビタミンC/
びたみんでぃー /ビタミンＤ/ビタミンD/
びたみんびー /ビタミンＢ/ビタミンB/
びたみんるい /ビタミン類/
びたん /尾端/
びだい /尾大/
びだいそつ /美大卒/
びだくおん /鼻濁音/
びだん /美談/
びだんし /美男子/
びちく /備蓄/
びちくまい /備蓄米;たくわえくん/
びちゅう /微衷/
びちゅうかく /鼻中隔/
びちょう /微調/
びちょうせい /微調整/
びっくり /吃驚/！/
びっくりぎょうてん /びっくり仰天/
びっくりばこ /びっくり箱/
びっくりみず /びっくり水;[料理]麺類を茹でる時に差して沸騰を抑える水/
びっこ /跛/
びっちゅう /備中/
びっちゅうぐわ /備中鍬/
びっとすう /ビット数/
びっとれつ /ビット列/
びつ /謐/
びていこつ /尾てい骨;NB:「てい」1-94-21/
びてき /美的/
びてきかんかく /美的感覚/
びてん /美点/
びでおがぞう /ビデオ画像/
びでおてん /ビデオ店/
びでん /美田/
びと /人/
びとう /尾灯;tail lamp/微糖/尾筒;tail covert.鳥の尾羽の付け根にある羽毛/尾藤;人名/
びとく /美徳/
びどう /微動/美童/美道/
びなん /美男/
びなんし /美男子/
びなんびじょ /美男美女/
びにーるがさ /ビニール傘/
びにーるせい /ビニール製/
びにーるぶくろ /ビニール袋/
びにぼん /ビニ本/
びにゅう /美乳;[俗]/微乳;[俗]/
びにるじゅし /ビニル樹脂;vinyl resin/
びねつ /微熱/
びねんまく /鼻粘膜/
びはく /美白/靡薄/
びはだ /美肌/
びはっぽうせい /微発泡性/
びはつ /美髪/
びばい /美唄/
びひん /備品/美品/
びひんひ /備品費/
びび /微々/靡靡/
びびたる /微々たる/
びふぃずすきん /ビフィズス菌;(bifidus) ヨーグルト等に含まれる善玉菌/
びふう /微風;breeze/美風;fine custom/
びふういき /微風域/
びふうじ /微風時/
びふえ /美笛/
びふか /美深/
びふく /美服/微服;お忍び姿/
びふん /微粉/
びぶ /尾部/
びぶん /微分/美文/
びぶんかのう /微分可能/
びぶんかのうせい /微分可能性/
びぶんがく /微分学/
びぶんき /微分器/
びぶんきか /微分幾何/
びぶんきかがく /微分幾何学/
びぶんきかがくてき /微分幾何学的/
びぶんけいしき /微分形式/
びぶんけいすう /微分係数/
びぶんこう /微分項/
びぶんさようそ /微分作用素/
びぶんしょ /美文書/
びぶんしょう /美文章/
びぶんせきぶん /微分積分/
びぶんせきぶんがく /微分積分学/
びぶんせきぶんほう /微分積分法/
びぶんだんめんせき /微分断面積/
びぶんほう /微分法/
びぶんほうそく /微分法則/
びぶんほうていしき /微分方程式/
びへい /鼻閉/尾柄/靡敝/
びへいそく /鼻閉塞;[医]鼻詰まり/
びほう /弥縫/備砲/彌縫;「弥」旧字/
びほうさく /弥縫策/
びほろ /美幌/
びほろちょう /美幌町/
びほん /美本/
びぼいん /鼻母音/
びぼう /美貌/備忘/微茫;ぼんやり/
びぼうじん /未亡人/
びぼうろく /備忘録/
びまん /瀰漫;蔓延/靡曼;きめ細かく美しい/弥漫/
びまんせい /瀰漫性/
びみ /美味/
びみょう /微妙/美妙/
びめい /美名/
びもく /眉目/
びもくしゅうれい /眉目秀麗/
びもん /鼻紋;muzzle pattern.「牛の-」/
びゃく /百/闢;開闢/白;(呉音)白檀/帛;(呉音) 布帛(ふはく)/辟;(呉音の一つ) 辟易(へきえき)/
びゃくい /白衣/
びゃくえ /白衣/
びゃくごう /白毫/
びゃくしん /柏槙/
びゃくじゅつ /白朮/
びゃくだん /白檀/
びゃくだんもく /ビャクダン目/Santalales/
びゃくや /白夜/
びゃくやしょぼう /白夜書房/
びゃくやものがたり /白夜物語/
びゃくり /白痢/
びゃくれん /白蓮/
びゃくろく /白緑/
びゃっこ /白虎/白狐/
びゃっこたい /白虎隊/
びやく /媚薬/
びやだる /ビヤ樽/
びゅう /謬/繆/
びゅうけん /謬見/
びゅうせつ /謬説/
びゅうまち /別府町;地名/
びゅうろん /謬論/
びょう /秒/鋲/病/廟;mausoleum.「孔子廟」/票/猫;(ねこ)老猫/描;(えが・く)描写/苗;(なえ)育苗/錨;(いかり)投錨/杪;こずえ/眇;すがめ/渺/緲/平;平等/屏;屏風/憑;つ・く/藐/″;second/
びょういん /病院/病因/
びょういんおくり /病院送り/
びょういんがよい /病院通い/
びょういんしょく /病院食/
びょういんせん /病院船/
びょうえい /苗裔;遠い子孫(「苗字」の語源)/
びょうか /病家/
びょうかん /秒間/病患/病間/
びょうが /描画/病臥/描畫;「画」旧字/
びょうがい /病害/
びょうがいち /描画位置/
びょうがいちゅう /病害虫/
びょうがかてい /描画過程/
びょうがかんすう /描画関数/
びょうがきのう /描画機能/
びょうがしょく /描画色/
びょうがじ /描画時/
びょうがじょうほう /描画情報/
びょうがそくど /描画速度/
びょうがへんしゅう /描画編集/
びょうがほうほう /描画方法/
びょうき /病気/病期/
びょうきいぜん /病気以前/
びょうきざみ /秒刻み/
びょうきじたい /病気自体/
びょうきよぼう /病気予防/
びょうきりょうよう /病気療養/
びょうきん /病菌/
びょうぎ /廟議/
びょうく /病苦/病躯/
びょうけい /病型/
びょうけつ /病欠/
びょうげん /病原/病源;=病原/
びょうげんきん /病原菌/病源菌;=病原菌/
びょうげんせい /病原性/
びょうげんせいだいちょうきん /病原性大腸菌;O-157など/
びょうげんたい /病原体/病源体/
びょうげんたいかんせん /病原体感染/
びょうこん /病根/
びょうご /病後/秒後/
びょうごう /廟号/
びょうごと /秒毎/
びょうさ /秒差/錨鎖/
びょうさい /病妻/
びょうさつ /秒殺/
びょうし /病死/表紙/拍子/病誌/
びょうしき /病識/
びょうししゃ /病死者/
びょうしつ /病室/病質/
びょうしゃ /描写/病者/病舎;hospital building/
びょうしゃおんがく /描写音楽/
びょうしゃせいのう /描写性能/
びょうしゃりょく /描写力/
びょうしゅつ /描出/
びょうしょ /廟所/
びょうしょう /病床/病症/病牀;=病床/
びょうしょうろくしゃく /病牀六尺;(1902)正岡子規/
びょうしん /秒針/病身/
びょうじ /病児/
びょうじつ /病日/
びょうじゃく /病弱/
びょうじゃくしゃ /病弱者/
びょうじょう /病状/苗条/
びょうすう /秒数/
びょうせい /病勢/
びょうせきがく /病跡学/
びょうせん /描線/
びょうぜん /病前/
びょうそう /病巣/
びょうそく /秒速/
びょうぞう /描像/病像/
びょうたい /病態/病体/
びょうたんい /秒単位/
びょうち /錨地/
びょうちゅう /病中/
びょうちゅうがい /病虫害/
びょうてき /病的/
びょうとう /病棟/
びょうどう /平等/廟堂/
びょうどういん /平等院/
びょうどうか /平等化/
びょうどうかん /平等観/
びょうどうしゅぎ /平等主義/
びょうどく /病毒/
びょうなん /病難/
びょうにん /病人/
びょうのう /病悩/
びょうは /描破/
びょうはく /錨泊/
びょうはくちゅう /錨泊中/
びょうびょう /渺渺;果てしない/眇眇;ちっぽけ/渺々/眇々/
びょうふ /病夫/病父/
びょうぶ /屏風/病部/廟風/
びょうぶえ /屏風絵/
びょうへい /病弊/
びょうへき /病癖/
びょうへん /病変/
びょうへんぶ /病変部/
びょうほ /苗圃/
びょうほう /描法/兵法;(連濁?)/
びょうぼ /病母/
びょうぼつ /病没/病歿;=病没/
びょうま /病魔/
びょうまえ /秒前/
びょうめい /病名/
びょうゆう /病友/
びょうよみ /秒読み/秒読/
びょうよみだんかい /秒読み段階/
びょうり /病理/
びょうりい /病理医/
びょうりかいぼう /病理解剖/
びょうりがく /病理学/
びょうりがくきょうしつ /病理学教室/
びょうりがっか /病理学科/
びょうりてき /病理的/
びょうるい /病羸/
びょうれき /病歴/
びよう /美容/
びよういん /美容院/
びようがっこう /美容学校/
びようきき /美容機器/
びようげか /美容外科/
びようし /美容師/
びようしつ /美容室/
びようじゅつ /美容術/
びようせいけい /美容整形/
びよく /尾翼;飛行機の-/鼻翼;小鼻/
びより /日和/
びらき /開き;海開き、俎開き、片開き/
びらくばり /ビラ配り/
びらん /糜爛/
びらんせい /糜爛性/
びりやーどじょう /ビリヤード場/
びりゅう /微粒/
びりゅうし /微粒子/
びりょう /微量/鼻梁/
びりょうげんそ /微量元素/
びりょうせいぶん /微量成分/
びりょうぶんせき /微量分析;microanalysis/
びりょく /微力/
びるいかん /鼻涙管/
びるかぜ /ビル風/
びるがい /ビル街/
びるぐん /ビル群/
びるしゃな /毘盧遮那/
びるしゃなぶつ /毘盧遮那仏/
びるま /緬甸/
びるまご /ビルマ語;ミャンマーの公用語/
びれい /美麗/靡麗/
びろーど /天鵞絨/
びろう /尾籠/尾篭;「籠」異体字/
びろうど /天鵞絨/
びろく /美禄/微禄/
びわ /琵琶;(楽器)/枇杷;(果物)/
びわき /琵琶記/
びわくせい /微惑星;[天文]planetesimal/
びわこ /琵琶湖/
びわこおおはし /琵琶湖大橋/
びわこきせん /琵琶湖汽船/
びわこすいけい /琵琶湖水系/
びわこせん /琵琶湖線/
びわことうがん /琵琶湖東岸/
びわこはくぶつかん /琵琶湖博物館/
びわこほうめん /琵琶湖方面/
びわじま /枇杷島/
びわほうし /琵琶法師/
びん /瓶/便/敏/鬢;横髪/壜;≒瓶 (字の本義は「酒甕」)/罎;≒瓶 (字の本義は「徳利」)/貧;貧乏/憫;憐憫/緡/旻;sky/檳;檳榔樹(びんろうじゅ)/梹;「檳」の異体字/紊;紊乱/閔;≒憫/愍;≒憫/泯;ほろ・びる/岷/頻/秤;天秤 NB:誤読/
びんいれ /瓶入/
びんかつ /敏活/
びんかん /敏感/
びんかんはだ /敏感肌/
びんが /頻伽/
びんぎ /便宜/
びんぐし /鬢櫛/
びんご /備後/
びんごおちあい /備後落合/
びんごおもて /備後表;畳の./
びんさつ /憫察/
びんざさら /拍板/編木/
びんし /鬢糸/
びんしけん /閔子騫;孔子の弟子/
びんしょう /敏捷/憫笑/
びんしょうせい /敏捷性/
びんじょう /便乗/
びんじょうしつもん /便乗質問/
びんすう /便数/
びんずる /賓頭盧/
びんせん /便箋/便船/
びんぜん /愍然/
びんそく /敏速/
びんぞこ /瓶底/
びんだい /瓶代/
びんちょう /備長/
びんちょうずみ /備長炭/
びんちょうたん /備長炭/
びんづめ /瓶詰め/瓶詰/壜詰/壜詰め/
びんびーる /瓶ビール/
びんほう /便法/
びんぼう /貧乏/
びんぼうがくせい /貧乏学生/
びんぼうがみ /貧乏神/
びんぼうくじ /貧乏籤/
びんぼうけん /貧乏県/
びんぼうしょう /貧乏性/貧乏症;?/
びんぼうしょく /貧乏食/
びんぼうせいかつ /貧乏生活/
びんぼうにん /貧乏人/
びんぼうものがたり /貧乏物語;(1917)河上肇/
びんぼうゆすり /貧乏揺すり/
びんぼうりょこう /貧乏旅行/
びんめい /便名/
びんらん /便覧/紊乱/
びんろう /檳榔/
びんろうじ /檳榔子/
びんろうじゅ /檳榔樹/
びんわん /敏腕/
ぴ /日/
ぴーえるほう /ＰＬ法/
ぴーくじ /ピーク時/
ぴーけーせん /PK戦;[soccer]penalty kicks/
ぴーたん /皮蛋/
ぴーは /Ｐ波;疎密波/
ぴあにっしっしも /pianississimo;ppより弱く/
ぴあにっしも /pianissimo;pより弱く/
ぴあの /piano;弱く/
ぴあのきょうしつ /ピアノ教室/
ぴあのきょく /ピアノ曲/
ぴあのせん /ピアノ線/
ぴあのそうしゃ /ピアノ奏者/
ぴあのふ /ピアノ譜/
ぴかいち /光一/
ぴき /匹/
ぴくせるすう /ピクセル数/
ぴこ /pico;[SI接頭語]p,10^-12/
ぴさのしゃとう /ピサの斜塔;Campanile di Pisa/
ぴざや /ピザ屋/
ぴすとんうんどう /ピストン運動/
ぴすとんゆそう /ピストン輸送;shuttle/
ぴっぷ /比布/
ぴつ /泌/
ぴゅーりたんかくめい /ピューリタン革命;[世界史]/
ぴょう /票/憑;憑依/俵/
ぴょんやん /平壌/
ぴらみっどがた /ピラミッド形/
ぴりから /ピリ辛/
ぴりんけい /ピリン系/
ぴるびんさん /ピルビン酸/
ぴろりきん /ピロリ菌/
ぴん /品/筒;[麻雀]/
ぴんあん /平安/
ぴんくいろ /ピンク色/
ぴんず /筒子/
ぴんはね /ピン撥ね/
ぴんふ /平和/
ぴんぽんだま /ピンポン玉/
ふ /負/不/府;大阪-/腑;-抜け/符/麩/歩/付/附/普/賦/譜/腐/浮/布/富/父/婦/夫/斑;まだら/俯;俯瞰図/咐/坿/拊/柎/苻;さや/鮒;ふな/孚/桴;いかだ/俘;俘虜/孵;孵化/蜉;蜉蝣/郛;くるわ/扶;扶助/畉/趺;結跏趺坐/芙;芙蓉/麸;「麩」の異体字/傅;かしず・く/賻;おく・る/榑;節榑立つ/溥;あまね・し/鯆;いるか,さば/舗;(呉音)/鋪;(呉音)/赴;赴任/訃;訃報/仆;たお・れる/巫;(慣用音) 巫医/誣;(慣用音) 誣言/阜;(慣用音) 岐阜/埠;埠頭/俛;俛伏/罘;あみ/斧;おの/怖;恐怖/敷;敷設/風;破風/膚;皮膚/生/冨;「富」の旧字(人名用漢字)/
ふ> /不/負/府;府知事,府行政/
ふーよーはい /芙蓉蟹;[中国語](furongxie) かに玉/
ふーりえかいせき /フーリエ解析/
ふーりえきゅうすう /フーリエ級数/
ふーりえへんかん /フーリエ変換;[数学]Fourier transformation/
ふーるー /腐乳;[中国語](fu ru)/
ふぁい /φ;phi/Φ;Phi/
ふぁいるかんり /ファイル管理/
ふぁいるきょうゆう /ファイル共有/
ふぁいるぐん /ファイル群/
ふぁいるこうかん /ファイル交換/
ふぁいるちゅう /ファイル中/
ふぁいるてんそう /ファイル転送/
ふぁいるめい /ファイル名/
ふぁっしょんし /ファッション誌/
ふぁっしょんせい /ファッション性/
ふぁん /翻/飜/
ふぁんそう /ファン層/
ふぁんでるわーるすりょく /ファンデルワールス力;[物理]van der Waals' force/
ふぁんとうひょう /ファン投票/
ふあつ /負圧/
ふあん /不安/
ふあんかん /不安感/
ふあんがお /不安顔/
ふあんげ /不安気/
ふあんざいりょう /不安材料/
ふあんし /不安視/
ふあんしんけいしょう /不安神経症/
ふあんてい /不安定/
ふあんていか /不安定化/
ふあんていかん /不安定感/
ふあんていせい /不安定性/
ふあんていよういん /不安定要因/
ふあんない /不案内/
ふぃーと /呎/
ふぃーるずしょう /フィールズ賞;数学者の賞/
ふぃりぴん /比律賓;Philippine/
ふぃりぴんかい /フィリピン海/
ふぃりぴんじん /フィリピン人/
ふぃんらんど /芬蘭;Finland/
ふぃんらんどご /フィンランド語;(Suomi) フィンランドの公用語/
ふい /不意/怖畏/巫医/
ふいうち /不意打ち/不意打/
ふいく /扶育/傅育/
ふいご /鞴/吹子/
ふいちょう /吹聴/
ふいっち /不一致/
ふいつ /不一/
ふいふいきょう /回回教/
ふいり /斑入り;[園芸]variegation. 葉の一部がマダラになること/不入り/
ふいん /訃音/
ふう /風/封/楓;かえで/諷;諷刺/瘋;瘋癲(ふうてん)/殕/夫/富;(漢音)/
ふうあい /風合い/風合/
ふうあつ /風圧/
ふうい /風位/
ふういき /風域/
ふういん /封印/風韻/
ふういんじょう /封印城/
ふういんぼく /封印木/
ふうう /風雨/
ふううん /風雲/
ふううんき /風雲記/
ふううんきゅう /風雲急/
ふううんじ /風雲児/
ふううんろく /風雲録/
ふうえい /諷詠/風営;[略語]風俗営業/
ふうえいてん /風営店/
ふうえいほう /風営法/
ふうえいほういはん /風営法違反/
ふうえいほうかいせい /風営法改正/
ふうか /風化/
ふうかい /風解;風化/風懐;心の中/諷戒/
ふうかく /風格/
ふうかん /封緘/風乾/
ふうかんし /封緘紙/
ふうかんはがき /封緘葉書/
ふうが /風雅/
ふうがい /風害/
ふうがら /風柄/
ふうがわり /風変わり/風変り/
ふうがん /風眼/
ふうき /風紀/富貴/
ふうきょう /風狂/風教/
ふうきり /封切/封切り/
ふうきりかん /封切館;[映画]/
ふうきん /風琴/
ふうぎ /風儀/
ふうぎり /封切り/
ふうけい /風景/
ふうけいいん /風景印/
ふうけいが /風景画/
ふうけいしゃしん /風景写真/
ふうけつ /風穴/
ふうげつ /風月/
ふうこう /風向/風光;-明媚/
ふうこうけい /風向計/
ふうこうふうそくけい /風向風速計/
ふうこうめいび /風光明媚/
ふうさ /封鎖/
ふうさい /風采/風災/
ふうささくせん /封鎖作戦/
ふうさつ /封殺/
ふうさぼう /封鎖棒/
ふうさんろしゅく /風餐露宿/
ふうし /風刺/封止/風姿/諷刺;=風刺/夫子/
ふうしえ /風刺絵/
ふうしかでん /風姿花伝/
ふうしが /風刺画/
ふうしつ /風湿/
ふうしゃ /風車/
ふうしゃごや /風車小屋/
ふうしゃしき /風車式/
ふうしゅ /風趣/
ふうしゅう /風習/
ふうしょ /封書/
ふうしょう /諷誦/
ふうしょく /風食/
ふうしん /風疹/
ふうしんき /風信器/
ふうしんし /風信子;ヒヤシンスの異名/
ふうしんしこう /風信子鉱/
ふうじ /封じ/
ふうじこめ /封じ込め/
ふうじて /封じ手/
ふうじめ /封じ目/
ふうじゅ /風樹;-の嘆/諷誦/
ふうじん /風神/風塵/
ふうすい /風水/
ふうすいがい /風水害/
ふうすいし /風水師/風水士/
ふうせい /風成;-土,-海流/風声/風勢/
ふうせいかくれい /風声鶴唳/
ふうせいど /風成土/
ふうせつ /風雪;snowstorm/風説;rumour/
ふうせつがき /風説書/
ふうせん /風船/風選/
ふうせんかずら /風船葛/
ふうせんがむ /風船ガム;bubblegum/
ふうせんだま /風船玉/
ふうせんばくだん /風船爆弾/
ふうぜん /風前/
ふうぜんのともしび /風前の灯/
ふうそう /風葬/風霜/風騒/
ふうそく /風速/
ふうそくけい /風速計/
ふうぞく /風俗/
ふうぞくえいぎょう /風俗営業/
ふうぞくえいぎょうほう /風俗営業法/
ふうぞくが /風俗画;genre/
ふうぞくぎょう /風俗業/
ふうぞくし /風俗史/
ふうぞくじょう /風俗嬢/
ふうぞくつう /風俗通/
ふうぞくてん /風俗店/
ふうぞくようご /風俗用語/
ふうたい /風体/風袋/風帯/
ふうたく /風鐸/
ふうたろう /風太郎/
ふうち /風致/
ふうちちく /風致地区/
ふうちょう /風潮/風鳥/風調/風聴/
ふうちょうざ /風鳥座;Apus(Aps)/
ふうちりん /風致林/
ふうちん /風鎮/
ふうつう /風通/
ふうつうおり /風通織/
ふうてい /風体/
ふうてん /瘋癲/
ふうとう /封筒/風濤/
ふうとうがた /封筒型/
ふうとうぼく /風倒木/
ふうど /風土/
ふうどう /風洞/
ふうどしょく /風土色/
ふうどびょう /風土病/
ふうにゅう /封入/
ふうにゅうざい /封入材/
ふうにゅうしき /封入式/
ふうは /風波/
ふうはく /風伯/
ふうはつ /風発/
ふうばいか /風媒花/
ふうばぎゅう /風馬牛/
ふうひ /封皮/
ふうひょう /風評/
ふうひょうひがい /風評被害/
ふうび /風靡/
ふうびょう /風病/
ふうふ /夫婦/
ふうふあい /夫婦愛/
ふうふうてい /風風亭/
ふうふえんまん /夫婦円満/
ふうふかん /夫婦間/
ふうふかんけい /夫婦関係/
ふうふげんか /夫婦喧嘩/
ふうふざいさんせい /夫婦財産制/
ふうふせいかつ /夫婦生活/
ふうふそうほう /夫婦双方/
ふうふとも /夫婦共/
ふうふどうし /夫婦同士/
ふうふない /夫婦内/
ふうふなか /夫婦仲/
ふうふべっせい /夫婦別姓/
ふうふやく /夫婦役/
ふうふよう /夫婦用/
ふうふりょうほう /夫婦両方/
ふうぶつ /風物/
ふうぶつし /風物詩/
ふうぶん /風聞/
ふうぼう /風貌/風防/
ふうま /風魔/
ふうましゅりけん /風魔手裏剣/
ふうまにんじゃ /風魔忍者/
ふうみ /風味/
ふうみづけ /風味付け/
ふうみんしゃ /風眠舎/
ふうむ /風夢/
ふうもん /風紋/
ふうゆ /諷諭/
ふうゆほう /諷喩法/
ふうらい /風来/
ふうらいぼう /風来坊/
ふうりゅう /風流/
ふうりゅういんじ /風流韻事/
ふうりゅうじん /風流人/
ふうりょう /風量/
ふうりょく /風力/
ふうりょくけい /風力計/
ふうりょくはつでん /風力発電/
ふうりん /風鈴/
ふうりんかざん /風林火山/
ふうれん /風連/
ふうろう /風浪/封蝋/
ふうろそうか /フウロソウ科/Geraniaceae/
ふうろそうぞく /フウロソウ属/
ふうろそうもく /フウロソウ目/Geraniales/
ふうろそうもくあぐん /フウロソウ目亜群/
ふうん /不運/浮雲/
ふぇーんげんしょう /フェーン現象/
ふぇざーきゅう /フェザー級;[ボクシング]57kg以下/
ふぇにきあじん /フェニキア人;Phoenician/
ふぇのーるじゅし /フェノール樹脂/
ふぇむと /femto;[SI接頭語]f,10^-15/
ふぇるみうむ /Fm/Fermium/
ふぇるみりゅうし /フェルミ粒子;fermion/
ふえ /笛/不壊/吭;(のどぶえ)/鰾;(うきぶくろ)/
ふえい /府営/
ふえいせい /不衛生/
ふえいようか /富栄養化/
ふえかた /増え方/笛方;flutists/
ふえき /不易/賦役/
ふえきりゅうこう /不易流行/
ふえたいこ /笛太鼓/
ふえたけ /笛竹;竹笛(の材料)/
ふえて /不得手/
ふえふき /笛吹き/
ふえふきどうじ /笛吹童子/
ふえん /敷衍/敷延;=敷衍/不縁/布衍;=敷衍/
ふぉるて /forte;強く/
ふぉるてっししも /fortessissimo;ffより強く/
ふぉるてっしも /fortessimo;fより強く/
ふぉるてぴあの /forte piano;強く、ただちに弱く/
ふおう /不応/
ふおうき /不応期/
ふおうせんそう /普墺戦争/
ふおうとう /不応答/
ふおん /不穏/
ふおんじゅかい /不飲酒戒/
ふおんとう /不穏当/
ふか /不可/深;形容詞語幹/負荷/付加/賦課/孵化/府下/附加/鱶/富家/浮華/負化/孚化/鯊/
ふかい /不快/深井/腐海/付会;牽強-/府会;府議会/不会;discord/附会;=付会/渓井/深い/
ふかいかん /不快感/
ふかいぎいん /府会議員/
ふかいし /深石/
ふかいしすう /不快指数/
ふかいにゅう /不介入/
ふかいり /深入り;事件に-する/深煎り;-コーヒー/深炒り;≒深煎り/
ふかうら /深浦/
ふかうらえき /深浦駅/
ふかえ /深江/
ふかえはま /深江浜/
ふかお /深尾/
ふかおい /深追い/
ふかかい /不可解/
ふかかち /付加価値/
ふかかちきょうそう /付加価値競争/
ふかかちぜい /付加価値税/
ふかがわ /深川/負荷側/
ふかがわしゃこ /深川車庫/
ふかきん /賦課金/付加金/
ふかぎゃく /不可逆/
ふかぎゃくあっしゅく /不可逆圧縮/
ふかぎゃくせい /不可逆性/
ふかぎゃくてき /不可逆的/
ふかぎゃくはんのう /不可逆反応/
ふかぎゃくへんか /不可逆変化/
ふかく /不覚/俯角/
ふかくさ /深草/
ふかくさん /不拡散;核兵器の-を訴える/
ふかくじつ /不確実/
ふかくじつせい /不確実性/
ふかくだい /不拡大/
ふかくだいほうしん /不拡大方針/
ふかくてい /不確定/
ふかくていきげん /不確定期限/
ふかくていじこう /不確定事項/
ふかくていせい /不確定性/
ふかくていせいかんけい /不確定性関係/
ふかくていせいげんり /不確定性原理/
ふかくていようそ /不確定要素/
ふかぐつ /深靴/
ふかけい /付加刑;[法]accessory penalty.⇔主刑/
ふかけいげん /負荷軽減/
ふかけつ /不可欠/
ふかけつせい /不可欠性/
ふかこう /不可抗;irresistible/付加項/
ふかこうりょく /不可抗力/
ふかさ /深さ/負荷差/
ふかさく /深作/
ふかさわ /深沢/深澤/
ふかさんめいし /不可算名詞/
ふかざけ /深酒/
ふかざつおん /付加雑音/
ふかざら /深皿/
ふかざわ /深沢/深澤/
ふかし /不可視/
ふかしぎ /不可思議;10^64/
ふかしょう /不可称/
ふかしょくみん /不可触民/
ふかしょり /付加処理/
ふかしん /不可侵/
ふかしんじょうやく /不可侵条約/
ふかじょうほう /付加情報/負荷情報/
ふかすぎ /深過ぎ/
ふかせ /深瀬/
ふかせつ /不可説/
ふかぜい /付加税/附加税/
ふかそうち /付加装置/
ふかそく /不可測/
ふかぞうだい /負荷増大/
ふかぞり /深剃り/
ふかた /深田;姓/
ふかたに /深谷/
ふかだ /深田/
ふかち /不可知/
ふかちろん /不可知論/
ふかっせい /不活性/
ふかっせいか /不活性化/
ふかっせいがす /不活性ガス;inert gas/
ふかっぱつ /不活発/
ふかつ /深津/賦活/
ふかつか /不活化/
ふかづめ /深爪/
ふかてき /付加的/
ふかてん /付加点/
ふかで /深手/深傷;⇔浅傷/
ふかでんあつ /負荷電圧/
ふかなさけ /深情け/
ふかなせん /深名線/
ふかなべ /深鍋/
ふかの /深野/
ふかのう /不可能/
ふかのうせい /不可能性/
ふかのうせいていり /不可能性定理/
ふかはた /深畑/
ふかはんのう /付加反応;[化学]addition reaction/
ふかばつ /不可罰/
ふかひ /不可避/深緋/
ふかひてき /不可避的/
ふかひれ /鱶鰭;高級食材.「-スープ」/
ふかぶか /深々/深深/
ふかぶかと /深々と/
ふかぶん /不可分/
ふかぶんさん /負荷分散/
ふかぶんさんほうしき /負荷分散方式/
ふかへんどう /負荷変動/
ふかほうしき /賦課方式;医療保険や国民年金等の財政方式。現役世代の保険料を高齢世代の年金に仕送りのようにまわす方式。/
ふかまち /深町/
ふかみ /深み/深見;地名/深海/
ふかみず /深水/
ふかみどり /深緑/
ふかむし /深蒸し/
ふかむらさき /深紫/
ふかや /深谷/
ふかやし /深谷市/
ふかやま /深山/
ふかよい /深酔い/
ふかようりょう /負荷容量/
ふかよみ /深読み/
ふかりつ /孵化率/
ふかりょう /負荷量/
ふかわ /布川/府川/
ふかん /俯瞰/不感/不完/不乾/
ふかんしへい /不換紙幣/
ふかんしょう /不感症/不干渉/
ふかんず /俯瞰図/
ふかんせい /不乾性/
ふかんせいゆ /不乾性油/
ふかんぜん /不完全/
ふかんぜんか /不完全花;[植物]imperfect flower/
ふかんぜんきょうそう /不完全競争/
ふかんぜんぎょう /不完全行/
ふかんぜんじょうほう /不完全情報/
ふかんぜんせい /不完全性/
ふかんぜんせいていり /不完全性定理/
ふかんぜんねんしょう /不完全燃焼/
ふかんぜんばん /不完全版/
ふかんてき /俯瞰的/
ふかんび /不完備/
ふかんよう /不寛容/
ふがい /府外/腑甲斐/
ふがいない /腑甲斐無い/
ふがく /富嶽/不学/
ふがくさんじゅうろっけい /富嶽三十六景/
ふがね /府金/
ふき /付記/蕗;(山菜)/附記;=付記/不帰/不羈;†拘束されない。「独立-」/不軌;†レールから外れる。「-をなす」/不期/葺/吹/苳;=蕗/款冬/菜蕗/
ふきあげ /吹上/吹上げ/
ふきあげぎょえん /吹上御苑;皇居/
ふきいど /噴井戸/
ふきかえ /吹替/吹き替え;洋画の-/吹替え/葺き替え;屋根の-/
ふきかえばん /吹替版/吹替え版/吹き替え版/
ふきかん /負帰還;NFB(Negative Feed Back)のこと/
ふきげん /不機嫌/
ふきこし /吹越;姓/
ふきごし /吹越;姓/
ふきさらし /吹き曝し/
ふきそ /不起訴/
ふきそうじ /拭き掃除/
ふきそく /不規則/
ふきそくか /不規則化/
ふきそくがた /不規則型/
ふきそくどうし /不規則動詞;[文法]see-saw-seen/
ふきそくへんか /不規則変化/
ふきそくへんどう /不規則変動/
ふきそしょぶん /不起訴処分/
ふきだけ /吹き竹/
ふきだし /吹き出し/吹出/
ふきだまり /吹き溜まり/吹き溜り/
ふきつ /不吉/
ふきつけ /吹付/吹き付け/吹付け/
ふきでもの /吹き出物/吹出物/
ふきとおし /吹き通し/吹通し/
ふきながし /吹き流し/吹流し/
ふきぬけ /吹き抜け/吹抜け/吹抜/
ふきの /吹野/
ふきのとう /蕗の薹/
ふきはつ /不揮発/
ふきはつせい /不揮発性/
ふきぶり /吹き降り/
ふきまわし /吹き回し/
ふきもの /吹き物;(雅楽の)管楽器。龍笛など/吹物/
ふきや /吹き矢/吹矢/吹屋/蕗谷/
ふきゅう /普及/不朽;everlasting.「-の名作」/腐朽;decay.「木材の-」/不休;「不眠-」/不急;not urgent.「不要-」/
ふきゅういいん /普及委員/
ふきゅうかつどう /普及活動/
ふきゅうき /普及期/普及機/
ふきゅうしき /普及式/
ふきゅうだいすう /普及台数/
ふきゅうど /普及度/
ふきゅうどあい /普及度合/
ふきゅうばん /普及版/
ふきゅうりつ /普及率/
ふきょ /不許;interdit. 「-複製,-転載」/
ふきょう /不況/布教/不興/富強/不協/
ふきょうい /府教委;府教育委員会/
ふきょうか /不況下/
ふきょうかつどう /布教活動/
ふきょうじ /不況時/
ふきょうたいさく /不況対策/
ふきょうほう /不競法;不正競争防止法/
ふきょうわ /不協和/
ふきょうわおん /不協和音/
ふきょうわおんてい /不協和音程/
ふきょか /不許可/
ふきょく /負極/
ふきょくせい /負極性/
ふきょふくせい /不許複製/
ふきん /付近/附近/布巾/賦金/
ふきんいったい /付近一帯/
ふきんいつ /不均一/
ふきんこう /不均衡/
ふきんしつ /不均質/
ふきんしつせい /不均質性/
ふきんしん /不謹慎/
ふきんじゅうみん /付近住民/
ふきんとう /不均等/
ふぎ /付議/不義/府議/附議/
ふぎかい /府議会/
ふぎみっつう /不義密通/
ふぎょう /俯仰/
ふぎょうぎ /不行儀/
ふぎょうじょう /不行状/
ふぎょうせき /不行跡/
ふぎり /不義理/
ふく /服/福;fortune/副;sub/幅;(はば)車幅/輻;輻射/匐;匍匐前進/復;往復/腹;腹部/複;複数/覆;被覆/愎;(もとる)/蔔;蘿蔔/蝠;蝙蝠(こうもり)/輹/馥;馥郁/伏;伏兵/袱;袱紗/茯/箙;えびら/富久/吹/含;動詞語幹/
ふく> /副;(sub) 副議長/複;(multiple) 複事象/
ふくあつ /腹圧/
ふくあん /腹案/
ふくい /福井/福居/復位/
ふくいいんちょう /副委員長/
ふくいえき /福井駅/
ふくいぎんこう /福井銀行/
ふくいく /馥郁/
ふくいくうこう /福井空港/
ふくいけん /福井県/
ふくいけんちょう /福井県庁/
ふくいけんりつだいがく /福井県立大学/
ふくいし /福井市/
ふくいずみ /福泉;姓/
ふくいたいかい /福井大会/
ふくいだい /福井大/
ふくいだいがく /福井大学/
ふくいべん /福井弁/
ふくいほうそう /福井放送/
ふくいん /福音;evangel.「-となる出来事」/幅員;width.「道路の-」/復員;demobilise.「兵士の-」/副因/
ふくいんかん /福音館/副印鑑/
ふくいんかんしょてん /福音館書店/
ふくいんしゅぎ /福音主義;[キリスト教]Evangelicalism/
ふくいんしょ /福音書/
ふくいんへい /復員兵/
ふくう /不空/
ふくうじょうじゅにょらい /不空成就如来;[仏教]/
ふくうりば /服売場/
ふくうん /福運/
ふくえ /福江/福栄/
ふくえき /服役/
ふくえきしゅう /服役囚/
ふくえきちゅう /服役中/
ふくえん /復縁/復円/
ふくえんせん /福塩線/
ふくおう /福王/
ふくおか /福岡/
ふくおかえき /福岡駅/
ふくおかかん /福岡間/
ふくおかきょういくだいがく /福岡教育大学/
ふくおかきんこう /福岡近郊/
ふくおかぎんこう /福岡銀行/
ふくおかくうこう /福岡空港/
ふくおかけん /福岡県/
ふくおかけんない /福岡県内/
ふくおかこう /福岡校/
ふくおかこうぎょうだいがく /福岡工業大学/
ふくおかこうだい /福岡工大/
ふくおかこくぜいきょく /福岡国税局/
ふくおかし /福岡市/
ふくおかしない /福岡市内/
ふくおかしないせん /福岡市内線/
ふくおかしみん /福岡市民/
ふくおかせん /福岡線/
ふくおかだい /福岡大/
ふくおかだいがく /福岡大学/
ふくおかちく /福岡地区/
ふくおかちさい /福岡地裁/
ふくおかちゃく /福岡着/
ふくおかてんじん /福岡天神/
ふくおかとしこうそく /福岡都市高速/
ふくおかはつ /福岡発/
ふくおかばしょ /福岡場所/
ふくおかびん /福岡便/
ふくおかほうそう /福岡放送/
ふくおん /複音/
ふくおんがく /複音楽;polyphony/
ふくおんせい /副音声/
ふくか /複果/
ふくかいちょう /副会長/
ふくかわ /福川/
ふくかん /副官/
ふくかんきょう /複環境/
ふくかんりにん /副管理人/
ふくが /腹臥/伏臥/
ふくがく /復学/
ふくがくちょう /副学長/
ふくがじょう /覆瓦状/
ふくがみ /福紙/
ふくがん /複眼/
ふくがんてき /複眼的/
ふくきょうざい /副教材/
ふくきょうだい /福教大/
ふくぎ /福木/副木/
ふくぎちょう /副議長/
ふくぎょう /副業/
ふくくう /腹腔/
ふくくうきょう /腹腔鏡/
ふくくっせつ /複屈折/
ふくくみあいちょう /副組合長/
ふくけい /復啓/
ふくけいしき /副形式/
ふくけん /復権/
ふくけんじ /副検事/
ふくげん /復元/復原;≒復元≒復元/
ふくげんこうか /復元効果/
ふくげんさぎょう /復元作業/
ふくげんそうち /復元装置/
ふくげんばん /復元版/
ふくげんほうほう /復元方法/
ふくげんりつ /復元率/
ふくげんりょう /副原料/
ふくげんりょく /復元力/復原力/
ふくこう /腹腔/
ふくこうかんしんけい /副交感神経/
ふくこうがん /副睾丸/
ふくこうじょうせん /副甲状腺;[解剖]parathyroid/
ふくこうない /腹腔内/
ふくこうまえ /福高前/
ふくこん /複婚;polygamy/
ふくごう /複合;complex/復号;decode/複号;±/
ふくごう> /複合;-建築,-火山,-施設/
ふくごうおせん /複合汚染/
ふくごうおん /複合音/
ふくごうか /複合化;compound/復号化;decrypt/
ふくごうかく /複合核/
ふくごうかこ /複合過去/
ふくごうがた /複合型/
ふくごうき /複合機/
ふくごうきぎょう /複合企業/
ふくごうきのう /複合機能/
ふくごうきょくせん /複合曲線/
ふくごうげんじつ /複合現実/
ふくごうこう /複合項/
ふくごうこうげき /複合攻撃/
ふくごうご /複合語/
ふくごうざい /複合材/
ふくごうししつ /複合脂質/
ふくごうしせつ /複合施設/
ふくごうじせい /複合時制/
ふくごうそうこう /複合装甲/
ふくごうたい /複合体/
ふくごうたんぱく /複合蛋白/
ふくごうてき /複合的/
ふくごうどうきしんごう /複合同期信号/
ふくごうどうし /複合動詞/
ふくごうどうじゅん /複号同順;[数学]/
ふくごうにんい /複号任意;[数学]/
ふくごうひょうげん /複合表現/
ふくごうびょうし /複合拍子/
ふくごうふきょう /複合不況/
ふくごうぶん /複合文/
ふくごうほう /復号法/
ふくごうまく /複合膜/
ふくごうゆそう /複合輸送/
ふくごうりょういき /複合領域/
ふくさ /袱紗/副査/帛紗;=袱紗/服紗;=袱紗/
ふくさい /副菜/
ふくさいぼう /副細胞/
ふくさや /福砂屋/
ふくさよう /副作用/
ふくさようてき /副作用的/
ふくさわ /福澤/
ふくさんぶつ /副産物/
ふくざ /複座/
ふくざい /伏在/服罪/
ふくざいりょう /副材料/
ふくざがた /複座型/
ふくざき /福崎/
ふくざさ /福笹/
ふくざつ /複雑/
ふくざつか /複雑化/
ふくざつかいき /複雑怪奇/
ふくざつけい /複雑系/
ふくざつこっせつ /複雑骨折/
ふくざつさ /複雑さ/
ふくざつせい /複雑性/
ふくざつたき /複雑多岐/
ふくざつど /複雑度/
ふくざわ /福沢/福澤/
ふくざわゆきち /福沢諭吉/
ふくし /福祉;welfare/副詞;[文法]adverb/福士;地名,姓/複視/副使/福司/復氏/
ふくしか /福祉課/
ふくしかんけい /福祉関係/
ふくしがっか /福祉学科/
ふくしき /複式/腹式/
ふくしきこきゅう /腹式呼吸/
ふくしきぼき /複式簿記/
ふくしく /副詞句/
ふくしげ /福重/
ふくしこうがく /福祉工学/
ふくしこっか /福祉国家/
ふくしざい /副資材/
ふくしし /福祉士;社会-,介護-/
ふくしししゅつ /福祉支出/
ふくししゃちょう /副支社長/
ふくしじぎょう /福祉事業/
ふくしせいさく /福祉政策/
ふくしぜい /福祉税/
ふくしぞうしん /福祉増進/
ふくしだい /福祉大/
ふくしだんたい /福祉団体/
ふくしちょう /副市長/
ふくしつしき /副室式/
ふくしてき /福祉的;†welfare/副詞的;†[文法]adverbial/
ふくしてちょう /福祉手帳/
ふくしどう /副指導/
ふくしねんきん /福祉年金/
ふくしぶもん /福祉部門/
ふくしま /福島/福嶋/副島/
ふくしまえき /福島駅/
ふくしまきねん /福島記念/
ふくしまきょく /福島局/
ふくしまけん /福島県/
ふくしまけんなんぶ /福島県南部/
ふくしまこうこう /福島高校/
ふくしまこうつう /福島交通/
ふくしまし /福島市/
ふくしまだい /福島大/
ふくしまだいにげんぱつ /福島第二原発/
ふくしまべん /福島弁/
ふくしまみんぽうはい /福島民報杯/福島民放杯/
ふくしゃ /複写/輻射/福者;[キリスト教]gospeler, (Fr)bienheureux NB:尊者<福者<聖人/伏射/
ふくしゃおんど /輻射温度/
ふくしゃき /複写機/
ふくしゃけん /複写権/
ふくしゃさいはいふ /複写再配布/
ふくしゃし /複写紙/
ふくしゃしき /複写式/
ふくしゃしつ /複写室/
ふくしゃせん /輻射線/
ふくしゃちょう /副社長/
ふくしゃてん /輻射点/
ふくしゃねつ /輻射熱/
ふくしゃりょう /複写料/
ふくしゅ /副手/
ふくしゅう /復習;†⇔予習/復讐;†revenge/福州;地名,(Fuzhou) 福建省の省都/
ふくしゅうき /復讐鬼/
ふくしゅうげき /復讐劇/
ふくしゅうしゃ /復讐者/
ふくしゅうしん /復讐心/
ふくしゅうせん /復讐戦/
ふくしゅうにゅう /副収入/
ふくしゅかん /副主幹/
ふくしゅしつ /副手室/
ふくしゅしょう /副首相/
ふくしゅじんこう /副主人公/
ふくしゅせき /副主席/
ふくしょ /副書/副署/
ふくしょう /副賞;bonus/副将;subcaptain/復唱;命令を-する/複勝/復誦;詩を-する/副章;⇔正章/復勝;?/
ふくしょうぐん /副将軍/
ふくしょうしき /複勝式/
ふくしょく /服飾/復職/副食/
ふくしょくひん /服飾品/
ふくしょくぶつ /副食物/
ふくしょちょう /副所長/副署長/
ふくしりょういき /福祉領域/
ふくしん /腹心/副審/腹診/復申;reply/
ふくしんけい /副神経/
ふくじ /福地/服地/副次/福治/
ふくじこうか /副次効果/
ふくじしょう /副時称/
ふくじてき /副次的/
ふくじてきこうか /副次的効果/
ふくじゃく /副尺/
ふくじゅ /福寿/
ふくじゅう /服従/複重/
ふくじゅうせん /複縦線;[音楽]double bar/
ふくじゅそう /福寿草/
ふくじょうし /腹上死;[俗](主に男性が)性交中に死ぬこと/
ふくじょし /副助詞/
ふくじん /副腎/副神/
ふくじんずいしつ /副腎髄質/
ふくじんづけ /福神漬/福神漬け/
ふくじんひしつ /副腎皮質/
ふくじんひしつほるもん /副腎皮質ホルモン;[生物]adrenocorticotropic hormone(ACTH). 各種steroid/
ふくすい /腹水;[医]abdominal dropsy/復水;-器/覆水;-盆に返らず/
ふくすいき /復水器;condenser/
ふくすう /複数/
ふくすうおん /複数音/
ふくすうか /複数可/
ふくすうかい /複数回/
ふくすうかいとう /複数回答/
ふくすうかいとうか /複数回答可/
ふくすうかしょ /複数箇所/
ふくすうかん /複数艦/
ふくすうがいしゃ /複数会社/
ふくすうきしゅ /複数機種/
ふくすうきどう /複数起動/
ふくすうきぼう /複数希望/
ふくすうぎょう /複数行/
ふくすうけい /複数形/
ふくすうけいとう /複数系統/
ふくすうこ /複数個/
ふくすうこうほ /複数候補/
ふくすうごび /複数語尾/
ふくすうさんか /複数参加/
ふくすうしてい /複数指定/
ふくすうしていか /複数指定可/
ふくすうしゃせん /複数車線/
ふくすうしゅ /複数種/
ふくすうしゅるい /複数種類/
ふくすうじ /複数持/
ふくすうせんたく /複数選択/
ふくすうせんたくか /複数選択可/
ふくすうそんざい /複数存在/
ふくすうだい /複数台/
ふくすうとうひょう /複数投票/
ふくすうどうさ /複数動作/
ふくすうどうじ /複数同時/
ふくすうにゅうりょく /複数入力/
ふくすうにん /複数人/
ふくすうねん /複数年/
ふくすうねんけいやく /複数年契約/
ふくすうねんじ /複数年次/
ふくすうねんど /複数年度/
ふくすうはん /複数犯/
ふくすうひょう /複数票/
ふくすうほゆう /複数保有/
ふくすうほん /複数本/
ふくすうまい /複数枚/
ふくすうめい /複数名/
ふくすうもじ /複数文字/
ふくすうようい /複数用意/
ふくすうりょう /複数両/
ふくすうれい /複数例/
ふくすうろ /複数路/
ふくすけ /福助/
ふくずみ /福住/
ふくせい /複製/服制/復姓/
ふくせいか /複製可/
ふくせいかん /複製間/
ふくせいけん /複製権/
ふくせいけんしゃ /複製権者/
ふくせいけんしんがい /複製権侵害/
ふくせいげんがしゅう /複製原画集/
ふくせいし /複製子/
ふくせいはんが /複製版画/
ふくせいひん /複製品/
ふくせいぶつ /複製物/
ふくせいもと /複製元/
ふくせいわざ /複製技/
ふくせき /復籍/復席/
ふくせってん /副節点/
ふくせつ /副節/
ふくせん /伏線;物語の-/複線;double line/複占;[経済]duopoly/
ふくせんか /複線化/
ふくせんかかんせい /複線化完成/
ふくせんかこうじ /複線化工事/
ふくせんかんかく /複線間隔/
ふくせんくかん /複線区間/
ふくせんちょう /副船長/
ふくせんでんか /複線電化/
ふくせんりつ /副旋律/
ふくそ /複素/福祚;†happiness/復祚;†=重祚(=天皇の復位)/
ふくそう /服装/輻輳;物事が集まること/複層;multilayer.「-ガラス」/副葬;「-品」/輻湊;=輻輳/複相;multiphase/福相;⇔貧相/副層;sublayer/
ふくそうかく /輻輳角/
ふくそうさ /副走査/
ふくそうさい /副総裁;vice president/
ふくそうじ /輻輳時/
ふくそうじょうかじょ /複総状花序/
ふくそうひん /副葬品/
ふくそうり /副総理/
ふくそうりん /複層林/
ふくそかいせき /複素解析/
ふくそかんすう /複素関数/
ふくそかんすうろん /複素関数論/
ふくそきょうやく /複素共役/
ふくそく /腹側/
ふくそくるい /腹足類/
ふくそしゅうはすう /複素周波数/
ふくそすう /複素数/
ふくそすうえんざん /複素数演算/
ふくそすうがた /複素数型/
ふくそすうたい /複素数体/
ふくそすうち /複素数値/
ふくそせきぶん /複素積分/
ふくそたようたい /複素多様体/
ふくそへいめん /複素平面/
ふくそへいめんじょう /複素平面上/
ふくそへんすう /複素変数/
ふくそりきがくけい /複素力学系/
ふくそりょういき /複素領域/
ふくぞう /腹蔵;-なく/福蔵;人名/伏蔵/
ふくぞく /服属/
ふくたい /腹帯/複体/
ふくたけ /福武/
ふくたけしょてん /福武書店;[出版社名]NB:現・ベネッセ/
ふくたけぶんこ /福武文庫/
ふくたに /福谷/
ふくたろう /福太郎/
ふくだ /福田/
ふくだい /副題/福大/
ふくだいじん /副大臣/
ふくだいとうりょう /副大統領/
ふくだいひょう /副代表/
ふくだいり /復代理/
ふくだつねあり /福田恆存;評論家。シェークスピアの翻訳で知られる/
ふくだんちょう /副団長/
ふくち /福地/
ふくちじ /副知事/
ふくちやま /福知山/
ふくちやまかん /福知山間/
ふくちやましない /福知山市内/
ふくちやません /福知山線/
ふくちゅう /腹中/
ふくちょう /復調/副長/
ふくちょうかん /副長官/
ふくちょうじく /復調軸/
ふくつ /不屈/
ふくつう /腹痛/
ふくで /福田/
ふくでん /復電/福田;[仏教]/
ふくと /河豚魚/
ふくとう /復党/
ふくとうこう /複投稿/
ふくとく /福徳/
ふくとくえんまん /福徳円満/
ふくとしん /副都心/
ふくとしんせん /副都心線/
ふくとみ /福富/
ふくとめ /福留/
ふくど /覆土/
ふくどう /複道/
ふくどく /服毒/副読/
ふくどくじさつ /服毒自殺/
ふくどくほん /副読本/
ふくどみ /福富/
ふくなが /福永/
ふくながたけひこ /福永武彦;作家/
ふくにし /福西/
ふくの /福野/
ふくのかみ /福の神/
ふくはい /復配/腹背/伏拝/
ふくはら /福原/
ふくはんぎゃくどうめい /服反逆同盟/
ふくはんそう /副搬送/
ふくはんそうは /副搬送波/
ふくはんのう /副反応/
ふくばち /覆鉢/
ふくばんごう /副番号/
ふくひ /複比/
ふくひれい /複比例/
ふくびき /福引/福引き/
ふくびきけん /福引券/福引き券/
ふくびこう /副鼻腔/
ふくびこうえん /副鼻腔炎/
ふくふく /福々/福福/
ふくふくせん /複々線/複複線/
ふくぶ /腹部/
ふくぶく /福々/
ふくぶくろ /福袋/
ふくぶちょう /副部長/
ふくぶん /複文/副文/福分/復文/
ふくぶんすう /複分数/
ふくぶんせつ /複文節/
ふくぷろぐらむ /副プログラム/
ふくへい /伏兵/
ふくへいそう /副兵装/
ふくへき /腹壁/
ふくへんそくき /副変速機/
ふくべ /福部/
ふくべっぷ /福別府/
ふくほう /副砲/複方/
ふくほうとう /副砲塔/
ふくほん /副本;†subbook/複本;†additional copy.「手形の-」/
ふくぼく /副木/
ふくぼつ /覆没/
ふくま /福間/
ふくまかいがん /福間海岸/
ふくまく /腹膜/
ふくまくえん /腹膜炎/
ふくまさ /福政/
ふくまさむね /福正宗/
ふくます /福桝/
ふくまつ /福松/
ふくまでん /伏魔殿/
ふくまめ /福豆/
ふくまれる /⊂;真部分集合/⊆;部分集合/
ふくみ /含み/
ふくみえき /含み益/
ふくみごえ /含み声/
ふくみしさん /含み資産/
ふくみそん /含み損;⇔含み益/
ふくみそんえき /含み損益/
ふくみつ /福光/
ふくみみ /福耳/
ふくみわた /含み綿/
ふくみわらい /含み笑い/
ふくむ /服務/⊃;真部分集合/⊇;部分集合/
ふくむいん /服務員/
ふくむきてい /服務規程/
ふくむら /福村/
ふくめい /復命/
ふくめつ /覆滅/
ふくめに /含め煮/
ふくめん /覆面/
ふくめんぱとかー /覆面パトカー/
ふくめんよう /覆面用/
ふくも /服喪/
ふくもと /福本/福元/
ふくもり /福盛/
ふくや /服屋/福屋/福家/
ふくやく /服薬/
ふくやしょてん /福屋書店/
ふくやす /福安/
ふくやま /福山/富久山/
ふくやまえき /福山駅/
ふくやまし /福山市/
ふくやまつううん /福山通運;[企業名]/
ふくよう /服用/複葉/
ふくようき /複葉機/
ふくようじ /服用時/
ふくようちゅう /服用中/
ふくようりょう /服用量/
ふくよか /膨よか/脹よか/
ふくよし /福吉/
ふくらい /福来/
ふくらくえん /復楽園;Paradise Regained,1671,Milton/
ふくらしこ /膨らし粉/
ふくらはぎ /脹脛/腓/
ふくらみ /膨らみ;胸の-/脹らみ/
ふくり /福利;walfare.「-厚生」/複利;compound interest.「-計算」/
ふくりき /福力/
ふくりこうせい /福利厚生/
ふくりこうせいしせつ /福利厚生施設/
ふくりこうせいてき /福利厚生的/
ふくりこうせいひ /福利厚生費/
ふくりじちょう /副理事長/
ふくりひ /福利費/
ふくりゅう /伏流/
ふくりゅうえん /副流煙/
ふくりゅうすい /伏流水/
ふくりょう /伏竜/
ふくりょうちょう /副寮長/
ふくりょうほうすう /伏竜鳳雛/
ふくりょうりちょう /副料理長/
ふくりん /覆輪;[植物]merginal variegation/
ふくれ /膨れ/脹れ/
ふくれっつら /膨れっ面/ふくれっ面/脹れっ面/
ふくろ /袋/復路;return path/嚢/副露/複路;dual path/
ふくろあみ /袋網/
ふくろい /袋井/
ふくろいり /袋入/
ふくろいりぼん /袋入本/
ふくろう /梟/
ふくろおび /袋帯/
ふくろおり /袋織/
ふくろくじゅ /福禄寿/
ふくろこうじ /袋小路/
ふくろじょう /袋状/
ふくろぞうし /袋草紙/
ふくろたけ /袋茸/
ふくろたに /袋谷/
ふくろだ /袋田/
ふくろだおんせん /袋田温泉/
ふくろだたき /袋叩き/袋だたき/袋叩/
ふくろだな /袋棚/
ふくろづの /袋角;鹿の-/
ふくろづめ /袋詰/袋詰め/
ふくろとじ /袋とじ/袋綴じ/袋閉じ/
ふくろとだな /袋戸棚/
ふくろど /袋戸/
ふくろぬい /袋縫い/
ふくろのねずみ /袋の鼠/
ふくろのり /袋海苔/
ふくろはり /袋貼り/
ふくろばら /袋原/
ふくろばり /袋貼り/
ふくろまち /袋町/
ふくろみみ /袋耳/
ふくろもの /袋物/
ふくろんぶん /副論文/
ふくわじゅつ /腹話術/
ふくわらい /福笑い;正月/
ふくん /夫君/父君/
ふぐ /河豚/不具/鰒;=河豚 (NB:「あわび」とも読む)/
ふぐあい /不具合/
ふぐあいてん /不具合点/
ふぐう /不遇/
ふぐか /不具化/
ふぐしゃ /不具者/
ふぐじる /河豚汁/
ふぐたいてん /不倶戴天/
ふぐどく /河豚毒/
ふぐり /睾丸/陰嚢/
ふぐりょうり /河豚料理/
ふけ /普化;人名,(?-860)/雲脂;dandruff/頭垢;=雲脂/冨家;人名? 「富」異体字/冨宅;「富」異体字/普家/
ふけい /父兄/府警/婦警/父系/不敬/噴井/譜系/腐刑;=宮刑/
ふけいかい /父兄会/
ふけいき /不景気/
ふけいざい /不経済/不敬罪/賦形剤/
ふけいせい /父系制/
ふけいせき /父兄席/
ふけいたい /不携帯/
ふけいどうはん /父兄同伴/
ふけがお /老け顔/
ふけしゃくはち /普化尺八/
ふけしゅう /普化宗/
ふけそう /普化僧/
ふけだ /深田/
ふけっか /不結果/
ふけつ /不潔/
ふけつかん /不潔感/
ふけまちづき /更待月;陰暦二十日の月/
ふけやく /老け役/老役/
ふけん /府県/父権/夫権;(旧民法)/
ふけんこう /不健康/
ふけんしき /不見識/
ふけんせい /父権制/
ふけんぜん /不健全/
ふけんぜんせい /不健全性/
ふけんぜんとしょ /不健全図書/
ふげき /巫覡;シャーマン/
ふげん /普賢/付言;remark/附言;=付言/不言;-実行/富源/誣言;嘘/
ふげんじっこう /不言実行/
ふげんぞう /普賢象;[植物]里桜/
ふげんだけ /普賢岳/
ふげんふご /不言不語/
ふげんぼさつ /普賢菩薩/
ふこ /封戸/巫蠱/浮誇/
ふこう /不幸/不孝;親-/附高/
ふこうしん /負更新/
ふこうせい /不公正/
ふこうせいとりひき /不公正取引/
ふこうちゅう /不幸中/
ふこうへい /不公平/
ふこうへいかん /不公平感/
ふこうへいせい /不公平性/
ふこうもの /不孝者/
ふこうよう /不効用/
ふこく /布告/富国/腐刻/
ふこくきょうへい /富国強兵/富國強兵;「国」旧字/
ふこころえ /不心得/
ふこころえもの /不心得者/
ふこつ /腐骨/
ふご /不語/附語/付語/
ふごう /符号;†code.「モールス-」/富豪/符合;†correspond.「規定に-する」/付合;†[法]adhesion/附合;=付合/負号;(-) minus sign/不合/
ふごうか /符号化/
ふごうかく /不合格/
ふごうかくしゃ /不合格者/
ふごうかほうしき /符号化方式/
ふごうかほうほう /符号化方法/
ふごうき /符号器/
ふごうけい /符号系/
ふごうご /符号語/
ふごうちょう /符号長/符号帳/
ふごうなし /符号無し/
ふごうひょう /符号表/
ふごうほう /不合法/
ふごうり /不合理/
ふごうりせい /不合理性/
ふごうりろん /符号理論/
ふさ /房/総/總;「総」の旧字/惣;(人名用)/絃;?/
ふさい /夫妻/負債/不採/付載/不才/負載/
ふさいがく /負債額/
ふさいごうけい /負債合計/
ふさいさん /不採算/
ふさいそうがく /負債総額/
ふさいたく /不採択/
ふさいよう /不採用/
ふさいろく /不採録/
ふさがる /閼/
ふさきち /房吉/
ふさぎ /塞ぎ;-の虫/
ふさぎのむし /塞ぎの虫;鬱/
ふさく /不作/
ふさくい /不作為/
ふさくいさいむ /不作為債務/
ふさくいはん /不作為犯/
ふさぐ /閼/
ふさこ /房子/扶佐子/夫査子/
ふさざくらか /フサザクラ科/Eupteleaceae/
ふさじょう /ふさ状/
ふさふさ /房々/
ふさん /不参/不讃/
ふさんか /不参加/
ふさんかしゃ /不参加者/
ふさんせい /不賛成/
ふざ /趺坐/
ふざい /不在/
ふざいしゃ /不在者/
ふざいしゃとうひょう /不在者投票/
ふざいしょうめい /不在証明/
ふざいじ /不在時/
ふざいちゅう /不在中/
ふざいひょう /不在票/
ふざけ /巫山戯/
ふざん /釜山/巫山;地名/
ふし /節/父子/不死/浮子;網用の「うき」/伏/臥/
ふしあな /節穴/
ふしあわせ /不幸せ/不仕合せ/
ふしいと /節糸/
ふしかてい /父子家庭/
ふしき /伏木/
ふしぎ /不思議/
ふしくれ /節榑/
ふしじ /不支持/
ふしじしゃ /不支持者/
ふしじひょうめい /不支持表明/
ふしじりつ /不支持率/
ふしぜん /不自然/
ふしたに /伏谷/
ふしちょう /不死鳥/
ふしつ /不悉/
ふしつりょう /負質量/
ふしづくり /節旁;[部首]/
ふしづけ /節付け/罧/
ふしてん /節点/
ふしど /臥所/臥床/
ふしぶし /節々/節節;-が痛い/
ふしまちづき /臥待月;陰暦十九日の月,寝待月に同じ/
ふしまつ /不始末/
ふしまわし /節回し/
ふしみ /伏見/
ふしみく /伏見区/
ふしみこう /伏見工/
ふしみじょう /伏見城/
ふしみてんのう /伏見天皇/
ふしみばん /伏見版/
ふしめ /節目/伏し目/伏目/
ふしめふしめ /節目節目/
ふしゃ /富者/巫者/府社/
ふしゃくしんみょう /不惜身命/
ふしゅ /浮腫/
ふしゅう /腐臭/俘囚/浮舟;float/
ふしゅうぎ /不祝儀/
ふしゅうぎょう /不就業/
ふしゅうこう /不銹鋼/
ふしゅく /巫祝/
ふしゅつ /不出/
ふしゅつじょう /不出場/
ふしゅつば /不出馬/
ふしゅび /不首尾/
ふしょう /負傷/不詳;unknown/不肖;親や師に似ず、劣る。「-の息子」/不祥;不吉・災難。「-事」/富商/不承;不承不承/府省/父称/不精;ぶしょう?/鳧鐘;[音楽]/
ふしょうか /不消化/
ふしょうけつじょう /負傷欠場/
ふしょうしゃ /負傷者/
ふしょうじ /不祥事/
ふしょうじき /不正直/
ふしょうたいじょう /負傷退場/
ふしょうち /不承知/
ふしょうちゅう /負傷中/
ふしょうにん /不承認/
ふしょうはんてい /負傷判定/
ふしょうふずい /夫唱婦随/
ふしょうふめつ /不生不滅/
ふしょうぶしょう /不承不承/
ふしょうわたくし /不肖私/
ふしょく /腐食/腐蝕;=腐食/腐植;humic/不食/扶植/
ふしょくざい /腐食剤/腐蝕剤/
ふしょくせい /腐食性/腐蝕性;=腐食性/
ふしょくど /腐植土/
ふしょくふ /不織布/
ふしょぞん /不所存/
ふしよう /不使用/
ふしん /不振;†slump/不信;†信用できない。「-感」/不審;†不明で疑わしい。「-人物」/普請;construction/腐心/
ふしんかん /不信感;distrust/不審感;doubt/
ふしんがみ /不審紙/
ふしんしゃ /不審者/
ふしんじん /不信心;impious. 「-者」/
ふしんじんぶつ /不審人物/
ふしんじんもん /不審尋問/
ふしんせつ /不親切/
ふしんてん /不審点/
ふしんにん /不信任/
ふしんにんあん /不信任案/
ふしんにんけつぎ /不信任決議/
ふしんにんひょう /不信任票/
ふしんばん /不寝番/
ふしんび /不審火/
ふじ /藤/富士/不治;incurable.「-の病」/不二/冨士;「富」異体字/不時;-着/
ふじい /藤井/
ふじいち /富士市/
ふじいでら /藤井寺/
ふじいでらきゅうじょう /藤井寺球場/
ふじいろ /藤色/
ふじう /藤生/
ふじうつぎか /フジウツギ科/Buddlejaceae/
ふじうら /藤浦/
ふじえ /藤江/
ふじえだ /藤枝/
ふじえだえき /藤枝駅/
ふじえだし /藤枝市/
ふじえだひがし /藤枝東/
ふじお /不二雄/富士夫/不二夫/藤尾/富士雄/藤雄/冨士雄;「富」異体字/
ふじおか /藤岡/富士岡/
ふじおかえき /富士岡駅/
ふじおやま /富士小山/
ふじか /藤花/
ふじかけ /藤掛/藤懸;姓/
ふじかわ /藤川/富士川/
ふじがおか /藤が丘/藤ヶ丘/
ふじがわ /富士川/
ふじき /藤木/藤城/
ふじきゅう /富士急/
ふじきゅうこう /富士急行/
ふじぎん /富士銀/
ふじぎんこう /富士銀行/
ふじくら /藤倉/
ふじくらでんせん /藤倉電線/
ふじけい /フジ系/
ふじこ /藤子/富士子/不二子/冨士子;「富」異体字/
ふじこし /不二越/藤越/
ふじこふじお /藤子不二雄/
ふじごこ /富士五湖/
ふじさき /藤崎/
ふじさく /藤咲/
ふじさと /藤里/
ふじさわ /藤沢/藤澤/
ふじさわえき /藤沢駅/
ふじさわし /藤沢市/
ふじさわばし /藤沢橋/
ふじさん /富士山/
ふじさんがた /富士山型/
ふじさんごう /富士参號/
ふじさんごごうめ /富士山五合目/
ふじさんちょう /富士山頂/
ふじさんちょうじょう /富士山頂上/
ふじさんへん /富士山編/
ふじさんろく /富士山麓/
ふじし /富士市/
ふじしま /藤島/藤嶋/
ふじしまべや /藤島部屋/
ふじしゃしん /富士写真/
ふじしゃりょう /富士車輌/
ふじしろ /藤代/藤城/
ふじじゅうこう /富士重工/
ふじせ /藤瀬/
ふじぜろっくす /富士ゼロックス/
ふじそうけん /富士総研/
ふじた /藤田/冨士田;「富」異体字/
ふじたいこ /富士太鼓;[能]/
ふじたか /藤孝/
ふじたかんこう /藤田観光/
ふじたに /藤谷/富士谷/
ふじたりゅう /藤田流;笛方/
ふじだな /藤棚/
ふじちゃく /不時着/
ふじっこう /不実行/
ふじつ /不実/不日/藤津/
ふじつう /富士通;[企業名]/
ふじつうおおいた /富士通大分/
ふじつうけいれつ /富士通系列/
ふじつうけん /富士通研/
ふじつうけんきゅうしょ /富士通研究所/
ふじつうせい /富士通製/
ふじつうぜねらる /富士通ゼネラル/
ふじつうほっかいどう /富士通北海道/
ふじつか /藤塚/
ふじつぼ /藤壺/藤壷;「壺」異体字/富士壺;[動物]balanoid. 船底につく/
ふじづか /富士塚/
ふじでんき /富士電機;[企業名]/
ふじと /藤戸/
ふじなが /藤永/
ふじなみ /藤波/
ふじなやき /布志名焼/
ふじなわ /藤縄/
ふじの /藤野/
ふじのうらば /藤裏葉/
ふじのみや /富士宮/藤ノ宮/
ふじのみやし /富士宮市/
ふじのもり /藤森/
ふじはし /藤橋/
ふじはら /冨士原;「富」異体字/
ふじばかま /藤袴/
ふじばやし /藤林/
ふじひこ /不二彦/
ふじひろ /不二洋/
ふじびたい /富士額/
ふじふいるむ /富士フイルム;[企業名]www.fujifilm.co.jp/
ふじへいげん /富士平原/
ふじほうめん /富士方面/
ふじま /藤間/
ふじまき /藤巻/
ふじまつ /藤松/
ふじまめ /藤豆/
ふじまりゅう /藤間流/
ふじみ /不死身/富士見/富士美/
ふじみがおか /富士見丘/
ふじみこうこう /富士見高校/
ふじみこうじょう /富士見工場/
ふじみしゅっぱん /富士美出版;[出版社名](辰巳出版グループ)www.tg-net.co.jp/
ふじみしょぼう /富士見書房/
ふじみだい /富士見台/
ふじみちょう /富士見町/
ふじみぶんこ /富士見文庫/
ふじむすめ /藤娘/
ふじむら /藤村/
ふじむらさき /藤紫/
ふじむらじょしこうこう /藤村女子高校/
ふじむらみき /藤村美樹/
ふじもと /藤本/藤元/
ふじもり /藤森/
ふじや /不二家;[企業名]www.fujiya-peko.co.jp/富士屋/藤屋/不二屋/
ふじやま /藤山/
ふじやまかんび /藤山寛美/
ふじゅう /藤生/
ふじゅうぶん /不十分/不充分/
ふじゅうぶんせい /不十分性/
ふじゅく /不熟/
ふじゅつ /巫術/
ふじゅり /不受理/
ふじゅん /不順;irregular.「天候-」/不純;impure.「-な動機」/
ふじゅんいせいこうゆう /不純異性交遊/
ふじゅんぶつ /不純物/
ふじゆう /不自由/
ふじょ /扶助/婦女/巫女/
ふじょう /不定/浮上/不浄/
ふじょうそうち /浮上装置/
ふじょうちゅう /浮上中/
ふじょうほうほう /浮上方法/
ふじょうり /不条理/
ふじょうりげき /不条理劇;(Fr)theatre d'absurdite/
ふじょうりにっき /不条理日記/
ふじょうりょく /浮上力/
ふじょし /婦女子/
ふじょぼうこう /婦女暴行/
ふじょりょう /扶助料/
ふじよし /藤吉/
ふじよしだ /富士吉田/
ふじよしだえき /富士吉田駅/
ふじれい /負事例/
ふじわか /藤若/
ふじわら /藤原/冨士原;「富」異体字/
ふじわらきょう /藤原京/
ふじわらじだい /藤原時代/
ふじわらのおきかぜ /藤原興風;誰をかも しる人にせむ 高砂の 松も昔の 友ならなくに/
ふじわらのすみとも /藤原純友/
ふじわらのていか /藤原定家;歌人。新古今集の撰者。(1162-1241)/
ふじわらのみちなが /藤原道長;966-1027/
ふじわらのもととし /藤原基俊;ちぎりおきし させもが露を いのちにて あはれ今年の 秋もいぬめり/
ふじわらのよしたか /藤原義孝;君がため 惜しからざりし いのちさへ 長くもがなと 思ひけるかな/
ふじん /夫人;†wife.「社長-」/婦人;†lady.「-服」/布陣/不尽/
ふじん> /婦人;-服,-靴,-参政権/
ふじんか /婦人科/
ふじんかい /婦人会/
ふじんけいかん /婦人警官/
ふじんご /婦人語/
ふじんさんせいけん /婦人参政権/
ふじんしゃ /婦人車/
ふじんたいおんけい /婦人体温計/
ふじんだんたい /婦人団体/
ふじんびょう /婦人病/
ふじんふく /婦人服/
ふじんぶ /婦人部/
ふじんもんだい /婦人問題/
ふじんやく /婦人薬/
ふじんよう /婦人用/
ふすう /負数/
ふすべ /贅/燻/
ふすべうめ /燻べ梅/
ふすべがお /燻顔/
ふすべがき /燻柿/
ふすべがわ /燻革/
ふすべぎん /燻銀/
ふすま /襖;障子/衾;布団/麩;小麦の製粉カス/
ふすまえ /襖絵/
ふず /付図/
ふずい /付随;†accompany.「-音楽」/不随;†paralysis.「半身-」/附随;=付随/
ふずいい /不随意/
ふずいいきん /不随意筋/
ふずいおんがく /付随音楽;incidental music/
ふずいか /付随果/
ふずいご /付随語/
ふずいしゃ /付随車/
ふずいてき /付随的/
ふせ /布施/伏せ/防/
ふせい /不正/不整;irregular/父性/府政/不斉;≒不整/腐生;[生物]/負性/夫姓/不省;人事-/
ふせい> /不正;-操作,-取引,-コピー/
ふせいあい /父性愛;paternal love.⇔母性愛/
ふせいあくせす /不正アクセス/
ふせいあくせすきんしほう /不正アクセス禁止法/
ふせいかい /不正解/
ふせいかいぞう /不正改造/
ふせいかく /不正確/
ふせいかくせい /不正確性/
ふせいき /不正規/
ふせいきょうそう /不正競争;unfair competition. -防止法/
ふせいきょうそうぼうしほう /不正競争防止法/
ふせいけい /不整形/
ふせいけいり /不正経理/
ふせいげんり /父性原理/
ふせいこう /不成功/
ふせいこうい /不正行為/
ふせいこぴー /不正コピー/
ふせいごう /不整合/
ふせいししゅつ /不正支出/
ふせいしゅっけつ /不正出血/
ふせいしゅつ /不世出/
ふせいしょくぶつ /腐生植物;saprophyte/
ふせいしょり /不正処理/
ふせいしよう /不正使用/
ふせいじつ /不誠実/
ふせいじょうしゃ /不正乗車/
ふせいせき /不成績/
ふせいち /不整地/
ふせいてき /父性的/
ふせいとうひょう /不正投票/
ふせいび /不整備/
ふせいほんのう /父性本能/
ふせいみゃく /不整脈/
ふせいゆうし /不正融資/
ふせいりつ /不成立/
ふせいりよう /不正利用/
ふせき /布石/
ふせぎ /伏木/
ふせじ /伏せ字/伏字/ふせ字/×××/○○○/□□□/△△△/
ふせっせい /不摂生/
ふせつ /敷設/布設;≒敷設/付設;付属して設ける/符節/浮説/負節/
ふせつてんじかい /付設展示会/
ふせや /伏屋/
ふせん /付箋/不戦/普選;[略語]普通選挙/附箋;=付箋/不宣/富贍/
ふせんし /付箋紙/
ふせんしょう /不戦勝/
ふせんぱい /不戦敗/
ふせんめい /不鮮明/
ふぜい /風情/府税/
ふぜん /不全/不善/
ふそ /父祖/
ふそう /扶桑/
ふそうおう /不相応/
ふそうしゃ /扶桑社;[出版社名]産経系。www.fusosha.co.jp/
ふそうとう /不相当/
ふそうりゃっき /扶桑略記;神武-1094の歴史書/
ふそく /不足/附則/不測;unexpected.「-の事態」/付則;=附則/
ふそくかん /不足感/
ふそくがく /不足額/
ふそくぎみ /不足気味/
ふそくじ /不足時/
ふそくふり /不即不離/
ふそくぶん /不足分/
ふそびょう /腐蛆病/
ふそん /不遜/
ふそんざい /不存在/
ふぞく /付属/附属;別字,=付属/
ふぞくかい /付属海/
ふぞくがっこう /付属学校/
ふぞくきのう /付属機能/
ふぞくけんきゅうじょ /付属研究所/
ふぞくこう /附属校/
ふぞくこうこう /付属高校/附属高校/
ふぞくこうじょう /付属工場/
ふぞくご /付属語/附属語/
ふぞくし /付属肢/
ふぞくしょ /附属書/
ふぞくせつび /附属設備/
ふぞくてき /付属的/
ふぞくひん /付属品/附属品;=付属品/
ふぞくびょういん /附属病院/付属病院/
ふぞくぶつ /付属物/附属物;=付属物/
ふぞくへんせい /付属編成/附属編成/
ふぞくめいさいしょ /附属明細書/
ふぞくめいさいひょう /付属明細表;財務諸表の1つ/
ふぞろい /不揃い/
ふた /蓋/二/双;(熟字訓)双子,双葉/弍;「二」の異体字/盖;「蓋」の異体字1/葢;「蓋」の異体字2/
ふたあい /二藍/
ふたあけ /蓋明け/
ふたあし /二足/
ふたあじ /二味/
ふたい /付帯/附帯;=付帯/
ふたいおう /不対応/
ふたいか /不胎化/
ふたいけつぎ /付帯決議/
ふたいこうそ /付帯控訴/
ふたいじこう /付帯事項/
ふたいじょうけん /付帯条件/
ふたいせつび /付帯設備/附帯設備/
ふたいぜい /付帯税/
ふたいてき /付帯的/
ふたいてん /不退転/
ふたいとこ /二従兄弟/二従姉妹/
ふたいほとっけん /不逮捕特権/
ふたえ /二重/
ふたえき /二駅/
ふたえじ /二重字/
ふたえまぶた /二重瞼;ぱっちり/
ふたえもじ /二重文字/
ふたおもて /双面/
ふたおや /二親/
ふたかた /二方/
ふたかみ /二上/
ふたかわ /二川/
ふたかわめ /二皮目/
ふたがみ /二神/二上/
ふたがわ /二川/
ふたく /付託;submit.「特別委に-する」/負託;mandate.「権限を-する」/
ふたくせ /二癖/
ふたくみ /二組/
ふたけた /二桁/
ふたこ /二子/
ふたこしんち /二子新地/
ふたこたまがわ /二子玉川/
ふたこと /二言/
ふたことみこと /二言三言/
ふたことめ /二言目/
ふたご /双子/
ふたごころ /二心/
ふたござ /双子座;Gemini(Gem),(5.21-6.20)/
ふたござりゅうせいぐん /双子座流星群/
ふたごしまい /双子姉妹/
ふたごたまがわ /二子玉川/
ふたごたまがわえん /二子玉川園/
ふたごたまがわえんえき /二子玉川園駅/
ふたごやま /二子山/
ふたごやまおやかた /二子山親方/
ふたごやまべや /二子山部屋/
ふたごよう /双子用/
ふたしか /不確か/
ふたすじ /二筋/
ふたせ /二瀬/
ふたせがわ /二瀬川/
ふたたび /再び/
ふたたま /二玉/
ふたつ /二つ/不達/布達/２つ/2つ/二/双/弍/
ふたつい /二ツ井/
ふたつおり /二つ折り/二つ折/
ふたつき /二月/蓋付/蓋付き;lidded/ふた月/
ふたつぎ /二木/
ふたつざわ /二ツ沢/
ふたつつうち /不達通知/
ふたつひきりょう /二つ引両/
ふたつへんじ /二つ返事/
ふたつぼし /二つ星/
ふたつめ /二つ目/二つめ/
ふたつや /二ッ谷/
ふたつわり /二つ割り/
ふたて /二手/
ふたとおり /二通り/2通り/
ふたなり /二形/
ふたのき /二軒;[建築]/
ふたはこ /二箱/
ふたば /双葉/二葉/雙葉/
ふたばがおか /双葉ヶ丘/
ふたばこうこう /雙葉高校/
ふたばしゃ /双葉社;[出版社名]www.futabasha.co.jp/
ふたばていしめい /二葉亭四迷/
ふたばやま /双葉山/
ふたばん /二晩/
ふたへや /二部屋/
ふたま /二間/
ふたませ /二間瀬/
ふたまた /二股/二又/二叉/
ふたまたがわ /二俣川/
ふたまたごうやく /二股膏薬/
ふたまたじょう /二又状/
ふたまたせん /二俣線/
ふたまただいこん /二股大根/
ふたまたぶね /二股舟/
ふたまたみち /二股道/
ふたまたみゃくけい /二又脈系/
ふたまわり /二回り/
ふたみ /二見/双海/双三/二美/
ふたみち /二道/
ふたむかしまえ /二昔前/
ふたむら /二村/
ふため /二目/不為/
ふたもじ /二文字/
ふたもの /蓋物/
ふたやく /二役/
ふたよ /二夜/
ふたり /二人/２人/2人/
ふたりいじょう /二人以上/
ふたりかぞく /二人家族/
ふたりきり /二人きり/
ふたりぐみ /二人組/
ふたりぐらし /二人暮らし/二人暮し/
ふたりしずか /二人静;多年草/
ふたりしばい /二人芝居/
ふたりじょうしゃ /二人乗車/
ふたりたび /二人旅/
ふたりっきり /二人っきり/
ふたりとも /二人共/
ふたりどうじ /二人同時/
ふたりのり /二人乗/
ふたりぶん /二人分/
ふたりべや /二人部屋/２人部屋/
ふたりまえ /二人前/
ふたりめ /二人目/
ふたりよう /二人用/
ふたわ /二和/
ふたん /負担/
ふたんかん /負担感/
ふたんがく /負担額/
ふたんきん /負担金/
ふたんげん /負担減/
ふたんしゃ /負担者/
ふたんじゅうりょう /負担重量/
ふたんぞう /負担増/
ふたんぶん /負担分/
ふたんほうほう /負担方法/
ふたんぽ /不担保/
ふたんりつ /負担率/
ふだ /札/簡/布田/
ふだい /譜代;-大名/府大/普代;地名/
ふだいだいみょう /譜代大名/
ふだしょ /札所/
ふだつき /札付き/札付/
ふだどめ /札止め;満員/札止/
ふだのつじ /札の辻/
ふだば /札場/
ふだまもり /札守り/
ふだらく /補陀落/補陀洛/普陀落/
ふだらくとかい /補陀落渡海/
ふだん /普段/不断/
ふだん> /普段/
ふだんいしき /普段意識/
ふだんぎ /普段着/不断着;=普段着/
ふだんざくら /不断桜;天然記念物/
ふだんしよう /普段使用/
ふだんづかい /普段使い/
ふだんどおり /普段通り/
ふち /縁;margin.「額縁」/淵;深み。「絶望の-」/不治;-の病/不知/附置;つけておく/付置;=附置/布置;配置/扶持/負値/付値/潭;≒淵/渕;「淵」の異体字1/渊;「淵」の異体字2/
ふちあんない /不知案内/
ふちかざり /縁飾り/
ふちがみ /渕上/
ふちけん /付置研/
ふちざき /渕崎/
ふちじ /府知事/
ふちじせん /府知事選/
ふちどり /縁取り/
ふちなし /縁無し;frameless.「-眼鏡」/
ふちの /渕野/
ふちのべ /淵野辺/渕野辺/
ふちまい /扶持米/
ふちゃ /普茶/
ふちゃく /付着/不着;nonarrival.「メールの-」/
ふちゃくぶ /付着部/
ふちゃくぶつ /付着物/
ふちゃりょうり /普茶料理/
ふちゅう /府中/婦中/不忠/釜中/
ふちゅうい /不注意/
ふちゅうえき /府中駅/
ふちゅうかいどう /府中街道/
ふちゅうし /府中市/
ふちゅうしけんじょう /府中試験場/
ふちゅうしみん /府中市民/
ふちゅうほんまち /府中本町/
ふちょう /不調/婦長/府庁/符丁/符牒;≒符丁/符帳;=符丁/
ふちょうしゃ /府庁舎/
ふちょうわ /不調和/
ふちん /浮沈;浮き沈み/不沈;沈まない。「-空母」/
ふちんかん /不沈艦/
ふちんくうぼ /不沈空母/
ふちんせんかん /不沈戦艦/
ふっか /フッ化/弗化;[化学]「-水素,-カルシウム」/
ふっかい /復改/
ふっかく /伏角/
ふっかすいそ /弗化水素/フッ化水素/
ふっかつ /復活/
ふっかつげき /復活劇/
ふっかつご /復活後/
ふっかつさい /復活祭/
ふっかつしゃ /復活者/
ふっかつじ /復活時/
ふっかつせつ /復活説/
ふっかつせんげん /復活宣言/
ふっかつちょくご /復活直後/
ふっかつとうせん /復活当選/
ふっかつばん /復活盤/
ふっかん /復刊/副官/
ふっき /復帰/伏羲/
ふっきいらい /復帰以来/
ふっきしょせん /復帰初戦/
ふっきじょうほう /復帰情報/
ふっきせつ /復帰説/
ふっきせん /復帰戦/
ふっきち /復帰値/
ふっきほうほう /復帰方法/
ふっきゅう /復旧/復仇/
ふっきゅうさぎょう /復旧作業/
ふっきゅうしゃ /復旧車/
ふっきゅうじょうきょう /復旧状況/
ふっきゅうほうほう /復旧方法/
ふっきん /腹筋/
ふっきんうんどう /腹筋運動/
ふっけん /復権/福建/復建;(企業名の一部?)/
ふっけんご /福建語/
ふっこ /復古/
ふっこう /復興/腹腔/復交;国交回復/復航;⇔往航/復校;復学/
ふっこうきょう /腹腔鏡/
ふっこうしえん /復興支援/
ふっこうだい /福工大/
ふっこく /復刻/覆刻;=復刻/
ふっこくしょ /復刻書/
ふっこくばん /復刻版;reprint/復刻盤;reissued disk/覆刻版;=復刻版/
ふっこしゅ /復古酒/
ふっこしゅぎ /復古主義/
ふっこしゅぎしゃ /復古主義者/
ふっこしんとう /復古神道/
ふっこてき /復古的/
ふっさ /福生/
ふっさし /福生市/
ふっしょ /仏書/
ふっしょく /払拭/
ふっせき /沸石/
ふっそ /フッ素/弗素/Flourine/F/
ふっそじゅし /フッ素樹脂/
ふっつ /富津/
ふってい /払底/
ふってん /沸点/
ふってんじょうしょう /沸点上昇/
ふっとう /沸騰/沸湯/
ふっとうすい /沸騰水/
ふっとうすいがたげんしろ /沸騰水型原子炉;BWR/
ふっとうせき /沸騰石/
ふっとうてん /沸騰点/
ふつ /仏/布津;地名/払;払拭/拂;「払」の旧字(人名用漢字)/弗;弗素/沸;沸騰/佛;「仏」の旧字(人名用漢字)/彿;彷彿/髴;髣髴(=彷彿)/怫;(いかる)/祓;(おはらい)/黻;(ひざかけ)/
ふつ> /仏;[略語]フランス.-文学,-下院選/
ふついでんし /不対電子/
ふついん /仏印/
ふつう /普通/不通/
ふつううんちん /普通運賃/
ふつううんよう /普通運用/
ふつうおおがた /普通大型/
ふつうか /普通科/不通過/
ふつうがた /普通型/
ふつうがっきゅう /普通学級/
ふつうきって /普通切手/
ふつうきっぷ /普通切符/
ふつうきょういく /普通教育/
ふつうぎんこう /普通銀行;commercial bank/
ふつうけつぎ /普通決議/
ふつうこう /普通校/
ふつうこうざ /普通口座/
ふつうこうにゅう /普通購入/
ふつうご /普通語/
ふつうし /普通紙/
ふつうしゃ /普通車/
ふつうしゃしていせき /普通車指定席/
ふつうしゃじゆうせき /普通車自由席/
ふつうしゃめんきょ /普通車免許/
ふつうじどうしゃ /普通自動車/
ふつうじょうしゃけん /普通乗車券/
ふつうじょうよう /普通乗用/
ふつうじょうようしゃ /普通乗用車/
ふつうじん /普通人/
ふつうせき /普通席/
ふつうせんきょ /普通選挙/
ふつうぜい /普通税/
ふつうそうきん /普通送金/
ふつうだんたい /普通団体/
ふつうていど /普通程度/
ふつうでんしゃ /普通電車/
ふつうどうろ /普通道路/
ふつうにゅうじょうけん /普通入場券/
ふつうはだ /普通肌/
ふつうば /普通馬/
ふつうばん /普通盤/
ふつうほう /普通法/
ふつうほうじん /普通法人/
ふつうめいし /普通名詞/
ふつうめんきょ /普通免許/
ふつうめんきょしゅとく /普通免許取得/
ふつうもり /普通盛り/
ふつうゆうびん /普通郵便/
ふつうよう /普通葉;[植物]foliage leaf/
ふつうよきん /普通預金/
ふつうよきんこうざ /普通預金口座/
ふつうりょうきん /普通料金/
ふつうりょきゃくうんちん /普通旅客運賃/
ふつうれっしゃ /普通列車/
ふつうわ /普通話;(putonghua)中国の共通語/
ふつえい /仏英/
ふつか /二日/２日/2日/
ふつかいち /二日市/
ふつかかん /二日間/2日間/
ふつかご /二日後/
ふつかすいそさん /弗化水素酸/
ふつかまち /二日町/
ふつかめ /二日目/
ふつかよい /二日酔い/二日酔/宿酔/宿酔い/
ふつかれんぞく /二日連続/
ふつぎょう /払暁/
ふつぐん /仏軍/
ふつけん /仏検/
ふつこく /仏国;仏蘭西/
ふつご /仏語/
ふつごう /不都合/
ふつごうてん /不都合点/
ふつごやく /仏語訳/
ふつごよみ /仏語読み/
ふつしゃ /仏車/
ふつじん /仏人/
ふつつか /不束/
ふつつかもの /不束者/ふつつか者/
ふつどく /仏独/
ふつのみたま /布都御魂/
ふつふつ /沸々;(お湯・勇気が)-と沸く/沸沸/仏仏/
ふつぶん /仏文/
ふつぶんか /仏文科/
ふつぶんがく /仏文学;フランス文学/
ふつやく /仏訳;フランス語訳/
ふつりあい /不釣り合い;mismatch/不釣合/不釣合い/
ふつりょう /仏領/
ふつれき /仏暦/
ふつわ /仏和/
ふづき /文月;陰暦7月/
ふづくえ /文机/
ふてい /不定/不貞;adultery.「-を働く」/不逞;lawless.「-の輩」/不弟;年上に逆らう/婦弟;妻の弟/不悌;=不弟/
ふていかこ /不定過去/
ふていかんし /不定冠詞/
ふていが /不定芽;[植物]adventive bud/
ふていき /不定期/
ふていきかんこう /不定期刊行/
ふていきけい /不定期刑/
ふていきせん /不定期船/
ふていきてき /不定期的/
ふていきれんさい /不定期連載/
ふていけい /不定形/
ふていこん /不定根/
ふていさい /不体裁/
ふていし /不定詞/
ふていしゅうそ /不定愁訴/
ふていしょう /不定称/
ふていじほう /不定時法/
ふていせい /不定性/
ふていせきぶん /不定積分/
ふていち /不定値/
ふていのやから /不逞の輩/
ふていほう /不定法/
ふてき /不適;†inadequate/不敵;†audacious.「-な笑み」/
ふてきおう /不適応/
ふてきおうしゃ /不適応者/
ふてきかく /不適格/
ふてきかくしゃ /不適格者/
ふてきごう /不適合/
ふてきごうしゃ /不適合者/
ふてきせい /不適正/
ふてきせつ /不適切/
ふてきちゅう /不的中/
ふてきとう /不適当/
ふてきにん /不適任/
ふてきほう /不適法/
ふてぎわ /不手際/
ふてってい /不徹底/
ふてね /ふて寝/不貞寝;当て字/
ふてん /付点;[音楽]dot/普天/符点/
ふてん> /付点;[音楽] -四分音符,-16分休符/
ふてんそっと /普天率土/
ふで /筆/
ふであらい /筆洗い/
ふでいれ /筆入れ/
ふでおろし /筆下ろし/
ふでが /筆画/
ふでがしら /筆頭/
ふでき /不出来/
ふでくせ /筆癖/
ふでさき /筆先/
ふでし /筆師/
ふでじまん /筆自慢/
ふでたて /筆立て/
ふでづかい /筆遣い/筆使い/
ふでづつ /筆筒;筆立て/
ふではこび /筆運び/
ふでばこ /筆箱/
ふでぶしょう /筆不精/筆無精/
ふでぶと /筆太/
ふでぺん /筆ペン/
ふでまき /筆巻;筆を簀巻にします/
ふでまめ /筆忠実;⇔筆不精/筆まめ/
ふでもじ /筆文字/
ふでんき /負電気/
ふと /太/不図;-気が付く (当て字)/富戸/
ふと> /太;太糸,太笛,太箸/
ふといと /太糸/
ふとう /不当/埠頭/不等;-式/不撓;-不屈/不凍;antifreeze.「-液」「-港」/不倒;最長-距離/不党;不偏-/符頭;[音楽]⇔符尾/
ふとう> /不当;不当逮捕,不当請求/
ふとういつ /不統一/
ふとうえき /不凍液/
ふとうおう /不倒翁/
ふとうかいこ /不当解雇/
ふとうかこうかん /不等価交換/
ふとうがた /不等型/
ふとうきょり /不倒距離/
ふとうこう /不登校/不凍港/
ふとうごう /不等号/≦;<=/≧;>=/≪;<</≫;>>/＜/＞/≠;!=/
ふとうしき /不等式/
ふとうしょぶん /不当処分/
ふとうせい /不当性/
ふとうはんけつ /不当判決/
ふとうひょうじ /不当表示/
ふとうふくつ /不撓不屈/
ふとうめい /不透明/
ふとうめいかん /不透明感/
ふとうめいけっちゃく /不透明決着/
ふとうめいせい /不透明性/
ふとうりとく /不当利得/
ふとうれんばい /不当廉売/
ふとうろうどうこうい /不当労働行為/
ふとおり /太織/
ふとがき /太書き/
ふとく /不徳/婦徳/
ふとくい /不得意/
ふとくぎ /不徳義/
ふとくさく /不得策/
ふとくてい /不特定/
ふとくていたすう /不特定多数/
ふとくていわしゃ /不特定話者/
ふとくようりょう /不得要領/
ふとぐち /太口/
ふところ /懐/懷;「懐」の旧字(人名用漢字)/
ふところがたな /懐刀/
ふところがみ /懐紙/
ふところぐあい /懐具合/
ふところで /懐手/
ふとざお /太棹/
ふとし /太/太司/
ふとじ /太字/
ふとせん /太線/
ふとせんか /太線化/
ふとっちょ /太っちょ/
ふとっぱら /太っ腹/太腹/
ふとつごう /不突合/
ふとどき /不届き/不届/
ふとどきもの /不届き者/
ふとばし /太箸/
ふとぶと /太々/太太/
ふとまき /太巻き;寿司/太巻/
ふとまきずし /太巻き寿司/
ふとまに /太占/
ふとみ /太身/
ふとめ /太め/太目/
ふとめん /太麺/
ふともじ /太文字/
ふともの /太物/
ふともも /太股/太腿;=太股/太もも/
ふともももく /フトモモ目/Myrtales/
ふともももくあぐん /フトモモ目亜群/
ふとり /太織/
ふとりじし /太り肉/
ふとわく /太枠/
ふとわくない /太枠内/
ふとん /布団;(当て字)/蒲団/
ふとんかばー /布団カバー/
ふとんかんそうき /布団乾燥機/
ふとんぶくろ /布団袋/
ふどう /不動;†immobile/浮動;†float/不同/府道/
ふどうい /不同意/
ふどうさん /不動産/
ふどうさんかんていし /不動産鑑定士/
ふどうさんがいしゃ /不動産会社/
ふどうさんぎょう /不動産業/
ふどうさんぎょうしゃ /不動産業者/
ふどうさんこうこく /不動産広告/
ふどうさんしゅとくぜい /不動産取得税/
ふどうさんしょとく /不動産所得;real estate income/
ふどうさんしんだつざい /不動産侵奪罪/
ふどうさんじぎょう /不動産事業/
ふどうさんちゅうかい /不動産仲介/
ふどうさんとうき /不動産登記/
ふどうさんとうきほう /不動産登記法/
ふどうさんとうししんたく /不動産投資信託;REIT/
ふどうさんぶもん /不動産部門/
ふどうさんほけん /不動産保険/
ふどうさんや /不動産屋/
ふどうしょうすう /浮動小数/
ふどうしょうすうてん /浮動小数点/
ふどうしょうすうてんがた /浮動小数点型/
ふどうしょうすうてんすう /浮動小数点数/
ふどうしょうすうてんち /浮動小数点値/
ふどうしょうすうてんていすう /浮動小数点定数/
ふどうしん /不動心/
ふどうせい /不動性;†immobility/浮動性;†mobility/
ふどうそう /浮動層/
ふどうそん /不動尊/
ふどうたい /不動態;†[化学]passivity/不導体;†[電気]nonconductor/
ふどうてん /不動点;fixed point/浮動点;floating point/
ふどうてんていり /不動点定理/
ふどうとうげ /不動峠/
ふどうとく /不道徳/
ふどうにょざん /不動如山/
ふどうひょう /浮動票/
ふどうまえ /不動前/
ふどうみょうおう /不動明王/
ふどき /風土記/
ふな /鮒/船/舟/舩;「船」の異体字/
ふなあか /船淦/
ふなあし /船足/船脚/
ふなあそび /船遊び/
ふない /船井/府内/
ふないくさ /船軍/
ふないた /船板/
ふないり /舟入/
ふないりなかまち /舟入中町/
ふないりまち /舟入町/
ふなうた /舟歌/
ふなおか /船岡/
ふなか /不仲/
ふなかた /船方/
ふながいしゃ /船会社/
ふながた /舟形/船形/船型/舟型/
ふなき /船木/舟木/
ふなくいむし /船食虫/
ふなくぎ /舟釘/
ふなくぼ /舟久保/
ふなぐ /船具/
ふなぐら /船倉/船蔵/艙/
ふなけん /舟券;競艇の-/
ふなこ /舟子/
ふなこう /船高/
ふなこし /船越/
ふなごや /船小屋/
ふなさか /舟阪;姓/
ふなじ /船路/
ふなずし /鮒鮨/
ふなせ /船瀬/
ふなぞこ /船底/舟底/
ふなたび /船旅/
ふなだ /船田/
ふなだいく /船大工/
ふなちん /船賃/
ふなつ /船津/舟津/
ふなつきば /船着場/船着き場/
ふなづみ /船積み/
ふなづみこう /船積港/
ふなづり /船釣り/船釣/舟釣/
ふなで /船出/
ふなと /舟渡/船渡/
ふなど /船戸/
ふなどめ /船留め/
ふなに /船荷/
ふなにしょうけん /船荷証券/
ふなぬし /船主/
ふなのり /船乗り/船乗/舟乗/
ふなはし /船橋/舟橋/
ふなはしせいいち /舟橋聖一/
ふなば /船場/
ふなばし /船橋/舟橋/
ふなばしえき /船橋駅/
ふなばしかん /船橋間/
ふなばしけいばじょう /船橋競馬場/
ふなばしし /船橋市/
ふなばた /船端/舷/
ふなばり /船梁/
ふなびき /船曳/
ふなびと /舟人/船人/
ふなびん /船便/
ふなべり /船縁/舷/
ふなべんけい /船弁慶;能・長唄/
ふなほ /船穂/
ふなま /船間/
ふなまち /船待ち/
ふなまど /船窓/
ふなみず /船水/
ふなむし /船虫/舟虫;=船虫/
ふなむら /舟村/
ふなもり /舟盛り/
ふなや /舟屋/
ふなやど /船宿/
ふなやま /船山/舟山/舩山/
ふなゆ /淦/船湯;船に入った水/
ふなよい /船酔い/船酔/
ふなり /不成/
ふなれ /不慣れ/不馴れ/
ふなわ /舟和/
ふなわたし /船渡し/
ふに /不二/
ふにあい /不似合い/
ふにく /腐肉/
ふにゅう /不入/腐乳/船生;地名,栃木県/
ふにょい /不如意/
ふにん /赴任/不妊/補任/
ふにんか /不妊化/
ふにんき /不人気/
ふにんききしゅ /不人気機種/
ふにんきしゃ /不人気車/
ふにんさき /赴任先/
ふにんしゃ /赴任者/
ふにんしゅじゅつ /不妊手術/
ふにんしょう /不妊症/
ふにんじょう /不人情/
ふにんち /赴任地/
ふにんちゅう /赴任中/
ふにんちりょう /不妊治療/
ふにんてあて /赴任手当/
ふにんてい /不認定/
ふぬけ /腑抜け/
ふね /船;ship/舟;boat/艦;warship/舩;「船」の異体字/
ふねかんけい /船関係/
ふねひき /船引/
ふねへん /舟偏/
ふねや /船屋/
ふねよう /船用/
ふねん /不燃;incombustible.「-ゴミ」/不稔;sterile/
ふねんか /不燃化/
ふねんごみ /不燃ゴミ/
ふねんざい /不燃材/
ふねんざいりょう /不燃材料/
ふねんせい /不燃性/
ふねんぶつ /不燃物/
ふの /布野/
ふのあたい /負の値/
ふのう /不能/不納/富農/
ふのうこう /不能項/
ふのうしゃ /不能者/
ふのうしょう /不能症/
ふのうじょうけん /不能条件/
ふのうせい /不能性/
ふのうはん /不能犯/
ふのり /布海苔/海蘿/
ふは /不破/
ふはい /腐敗/不敗/
ふはいきん /腐敗菌;putrid bacteria/
ふはいしゅう /腐敗臭/
ふはいしんわ /不敗神話/
ふはいぶつ /腐敗物/
ふはいぼうし /腐敗防止/
ふはく /布帛/浮薄/
ふはつ /不発/
ふはついく /不発育/
ふはつだん /不発弾/
ふはつだんしょり /不発弾処理/
ふばい /不買/
ふばいうんどう /不買運動/
ふばこ /文箱/
ふばつ /不抜/
ふばらい /不払い/
ふばらいざんぎょう /不払い残業;[新語]サービス残業(の違法性を明確にした言い換え語)/
ふばらいろうどう /不払い労働;unpaid labor.「サービス残業などの-」/
ふばん /付番;numbering/符番;†符号番号(?)/
ふひつよう /不必要/
ふひょう /不評/付表;appendix table/附票;label/浮標;buoy/附表;=付表/付票;=附票/譜表;[音楽]五線-/浮氷/歩兵/
ふひんこう /不品行/
ふび /不備/符尾;[音楽]⇔符頭/
ふびじん /不美人/
ふびょうどう /不平等/
ふびょうどうじょうやく /不平等条約/
ふびん /不憫/不便;NB:「ふびん(な子)」はこちらが本来の表記/不敏;非才/
ふふく /不服/俯伏/俛伏/
ふふくじゅう /不服従/
ふふつせんそう /普仏戦争/
ふぶ /布武/
ふぶき /吹雪/風吹/
ふぶん /不文/腑分/
ふぶんけんぽう /不文憲法;イギリスなど/
ふぶんほう /不文法/
ふぶんめい /不分明/
ふぶんりつ /不文律/
ふへい /不平/浮萍/
ふへいか /不平家/
ふへいこう /不平衡/
ふへいこうがた /不平衡型/
ふへいふまん /不平不満/
ふへき /扶壁/
ふへん /不変;†constant/普遍;universal/不偏;†unbiased.「-不党」/布片/不遍;?/
ふへんか /普遍化/
ふへんがいねん /普遍概念/
ふへんしき /不変式/
ふへんしほん /不変資本/
ふへんしゅうきょう /普遍宗教/
ふへんしんにょ /不変真如/
ふへんせい /普遍性;universality/不変性;†constancy/不偏性;†[統計]unbiasedness/
ふへんていすう /普遍定数/
ふへんてき /普遍的;universal/不変的;constant/
ふへんてきほうそく /普遍的法則/
ふへんふとう /不偏不党/
ふへんぶんさん /不偏分散/
ふへんぶんぽう /普遍文法;[言語]universal grammar/
ふへんほうそく /普遍法則/
ふへんりょう /不変量/
ふへんろんそう /普遍論争/
ふべん /不便/
ふべんきょう /不勉強/
ふべんきょうもの /不勉強者/
ふほ /付保/
ふほう /不法/訃報/
ふほう> /不法;-入国,-侵入,-行為/
ふほうかいぞう /不法改造/
ふほうかんきん /不法監禁/
ふほうげんいんきゅうふ /不法原因給付/
ふほうこうい /不法行為/
ふほうこういせきにん /不法行為責任/
ふほうしゅうろう /不法就労/
ふほうしょじ /不法所持/
ふほうしよう /不法使用/
ふほうしんにゅう /不法侵入/
ふほうせい /不法性/
ふほうたいざい /不法滞在/
ふほうたいざいしゃ /不法滞在者/
ふほうとうき /不法投棄/
ふほうにゅうこく /不法入国/
ふほうらん /訃報欄/
ふほうわ /不飽和;-化合物、-ポリエステル/
ふほうわかごうぶつ /不飽和化合物;[化学]unsaturate/
ふほうわしぼうさん /不飽和脂肪酸/
ふほじ /不保持/
ふほんい /不本意/
ふぼ /父母/
ふぼかい /父母会/
ふぼく /浮木/
ふぼん /不犯/
ふまい /不昧/
ふまえ /踏まえ/
ふまえどころ /踏まえ所/
ふまじめ /不真面目/不まじめ/
ふまるさん /フマル酸/
ふまん /不満/
ふまんかいしょう /不満解消/
ふまんがお /不満顔/
ふまんぞく /不満足/
ふまんてん /不満点/
ふみ /文/不味;⇔美味/踏み/史/章/郁/二三/芙美;名/
ふみあき /文明/文昭/史光/
ふみあけ /文朱/
ふみいし /踏石/
ふみいた /踏板/踏み板;footboard/
ふみえ /踏み絵/踏絵/文絵/
ふみお /文雄/文夫/文男/文郎/史夫/二三男/史男/史緒/郁雄/
ふみか /史佳/
ふみかず /文一/
ふみがら /文殻/
ふみきり /踏切/踏み切り/
ふみきりじこ /踏切事故/
ふみきりせいぎょ /踏切制御/
ふみきりたいさく /踏切対策/
ふみきりない /踏切内/
ふみきりもんだい /踏切問題/
ふみこ /文子/史子/富美子/ふみ子/冨美子;「富」異体字/
ふみことば /文言葉/
ふみこみ /踏み込み/踏込み/踏みこみ/
ふみこみだたみ /踏込畳;[茶道]/
ふみし /二三四/
ふみたか /文隆/文孝/
ふみたけ /文武/
ふみただ /文忠/
ふみだい /踏み台/踏台/
ふみだん /踏み段/踏段/
ふみつけ /踏み付け/踏付け/
ふみづき /文月/
ふみづくえ /文机/
ふみづら /踏面;階段の水平部分/
ふみと /文人/史人/
ふみとし /文俊/文敏/
ふみとよ /文豊/
ふみどの /文殿/
ふみのつかさ /書司;[律令制]/図書寮;[律令制]/
ふみのぶ /文信/
ふみのり /文典/
ふみば /踏み場;足の踏み場もない/
ふみばこ /文箱/
ふみひこ /文彦/史彦/郁彦/
ふみひで /文秀/
ふみひと /文仁/史人/
ふみひろ /文博/史裕/文浩/文礼/
ふみまさ /章雅/
ふみもち /不身持/
ふみや /文屋/文也/郁也/
ふみやす /文康/文保/
ふみゆき /文之/文行/
ふみよ /文代/扶三代/
ふみよし /文義/文良/文嘉/
ふみん /不眠/府民/富民/
ふみんしょう /不眠症/
ふみんぜい /府民税/
ふみんふきゅう /不眠不休/
ふむき /不向き/
ふめい /不明/
ふめいかい /不明解/不明快/
ふめいかく /不明確/
ふめいきん /不明金/
ふめいしゃ /不明者/
ふめいすう /不名数/
ふめいてん /不明点/
ふめいよ /不名誉/
ふめいりょう /不明瞭/
ふめいろう /不明朗/
ふめつ /不滅/
ふめん /譜面/普免/符面/
ふめんじょう /譜面上/
ふめんぼく /不面目/
ふめんもく /不面目/
ふもう /不毛/
ふもうか /不毛化/
ふもじ /不文字/
ふもと /麓/梺/
ふもん /不問/
ふもんじ /不文字/
ふもんぼん /普門品;[仏教]=観音経/
ふやじょう /不夜城/
ふゆ /冬/
ふゆいがい /冬以外/
ふゆいらい /冬以来/
ふゆう /浮遊/富裕/富有/浮有/
ふゆうかん /浮遊感/
ふゆうせき /浮遊石/
ふゆうそう /富裕層/
ふゆうたいりく /浮遊大陸/
ふゆうぶつ /浮遊物/
ふゆうれい /浮遊霊/
ふゆかい /不愉快/
ふゆがこい /冬囲い/
ふゆがしら /冬頭/
ふゆがすみ /冬霞/
ふゆがた /冬型/
ふゆがっしゅく /冬合宿/
ふゆがれ /冬枯れ/
ふゆき /冬木/冬樹/冬季/
ふゆきとどき /不行き届き/不行届き/
ふゆぎ /冬着/
ふゆぎぬ /冬衣/
ふゆくいな /冬水鶏/
ふゆくさ /冬草/
ふゆげ /冬毛/
ふゆげしき /冬景色/
ふゆげしょう /冬化粧/
ふゆこ /冬子/
ふゆこだち /冬木立/
ふゆこみ /冬コミ/
ふゆごう /冬号/
ふゆごし /冬越し/
ふゆごもり /冬籠り/
ふゆごろ /冬頃/
ふゆさくもつ /冬作物/
ふゆざれ /冬ざれ/
ふゆしょうぐん /冬将軍/
ふゆじかん /冬時間/
ふゆじたく /冬支度/
ふゆぞら /冬空/
ふゆつばき /冬椿/
ふゆとうらい /冬到来/
ふゆどり /冬鳥/
ふゆな /冬菜/
ふゆねこ /冬猫/
ふゆの /冬野/
ふゆのじん /冬の陣/
ふゆのたび /冬の旅;Winterreise(1827), Schubert&Muller/
ふゆのひ /冬の日/
ふゆはる /冬春/
ふゆば /冬場/
ふゆばれ /冬晴れ/
ふゆひこ /冬彦/
ふゆび /冬日/
ふゆびより /冬日和/
ふゆふく /冬服/
ふゆぶとり /冬太り/
ふゆまつり /冬祭り/冬祭/
ふゆみ /冬美/
ふゆみち /冬道/
ふゆめ /冬芽;⇔夏芽/
ふゆもの /冬物/
ふゆものがたり /冬物語/
ふゆもよう /冬模様/
ふゆやさい /冬野菜/
ふゆやすみ /冬休み/
ふゆやま /冬山/
ふゆやまや /冬山屋/
ふゆやまよう /冬山用/
ふゆよう /冬用/
ふよ /付与;give/賦与;endow. 割り当てて与える/
ふよう /不要/扶養/不用;-の用/芙蓉;ハスの花/浮揚/不溶;insoluble/浮葉;[植物]floating leaves/芙容;?/
ふようい /不用意/
ふようかぞく /扶養家族/
ふようかぞくてあて /扶養家族手当/
ふようぎむ /扶養義務/
ふようこうじょ /扶養控除/
ふようしゃ /扶養者/
ふようしゃこうじょ /扶養者控除/
ふようしんぞく /扶養親族/
ふようじょう /不養生/
ふようせい /不溶性/
ふようだい /芙蓉台;地名,静岡/
ふようど /腐葉土/
ふようひん /不用品/不要品/
ふようふきゅう /不要不急/
ふようふくしゃ /不要輻射/
ふようぶつ /不要物/
ふようぶぶん /不要部分/
ふようりょく /浮揚力/
ふようろん /不要論/不用論/
ふよく /扶翼/
ふらいがえし /フライ返し/
ふらいきゅう /フライ級;[ボクシング]50.8kg以下(fly=蠅)/
ふらいすばん /フライス盤;(<仏 fraise) milling machine/
ふらく /不落/
ふらここ /鞦韆/
ふらご /フラ語/
ふらち /不埒/不埓/
ふらっと /♭;flat/
ふらの /富良野/
ふらのえき /富良野駅/
ふらん /腐乱/不乱;一心-/孵卵/腐爛;≒腐乱/
ふらんき /孵卵器/
ふらんしうむ /Fr/Francium/
ふらんしたい /腐乱死体/
ふらんす /仏蘭西;France/佛蘭西/仏/
ふらんすえいが /フランス映画/
ふらんすかくめい /フランス革命/
ふらんすぐん /フランス軍/
ふらんすご /フランス語/
ふらんすさん /フランス産/
ふらんすじん /フランス人/
ふらんすせい /フランス製/
ふらんすにんぎょう /フランス人形;la poupee/
ふらんすぶんか /フランス文化/
ふらんすぶんがく /フランス文学/
ふらんすりょうり /フランス料理/
ふらんどるがくは /フランドル楽派/
ふらんどるは /フランドル派;[美術] l'ecole flamande. (Rubens, Brueghelなど)/
ふり /不利/振/振り/降り/不離/
ふりーきしゃ /フリー記者/
ふりあて /振り当て/
ふりえき /不利益/
ふりかえ /振替/
ふりかえきゅうじつ /振替休日/
ふりかえけっさいせいど /振替決済制度/
ふりかえこうざ /振替口座;(postal) transfer account/
ふりかえてすうりょう /振替手数料/
ふりかえのうぜい /振替納税/
ふりかえひょう /振替票/
ふりかえゆそう /振替輸送/
ふりかけ /振り掛け/振掛け/
ふりかた /振り方/
ふりがな /振り仮名/振仮名/
ふりこ /振り子/振子/
ふりこう /不履行/
ふりこぐるま /振子車/
ふりこどけい /振り子時計/振子時計/
ふりこみ /振込/振り込み/振込み/
ふりこみき /振込機/振り込み機/
ふりこみこうざ /振込口座/
ふりこみさき /振込先/
ふりこみしゃめい /振込者名/
ふりこみてすうりょう /振込手数料/
ふりこみにん /振込人/
ふりこみび /振込日/
ふりこみようし /振込用紙/
ふりこみよていび /振込予定日/
ふりこめさぎ /振り込め詐欺/
ふりごま /振り駒/
ふりそで /振袖/振り袖/
ふりそですがた /振袖姿/
ふりだし /振出/振り出し/振出し/
ふりだしきょく /振出局/
ふりだしにん /振出人/
ふりつ /府立/振津/
ふりつけ /振り付け/振付/振付け/
ふりつけか /振付家/
ふりつけし /振付師/
ふりつこうこう /府立高校/
ふりつだいがく /府立大学/
ふりつもんじ /不立文字/
ふりてん /振聴/
ふりにげ /振り逃げ/
ふりはた /降籏/
ふりびしゃ /振り飛車/振飛車;[将棋]/
ふりゅう /風流/浮流/
ふりゅうもんじ /不立文字/
ふりょ /不慮/俘虜/俘慮/
ふりょう /不良/不漁/不猟/
ふりょうかいいん /不良会員/
ふりょうかしょ /不良箇所/
ふりょうけん /不料簡/
ふりょうこうこうせい /不良高校生/
ふりょうさいけん /不良債権/
ふりょうさいけんか /不良債権化/
ふりょうさいけんしょり /不良債権処理/
ふりょうざいこ /不良在庫/
ふりょうしゃかいじん /不良社会人/
ふりょうしょうじょ /不良少女/
ふりょうせくた /不良セクタ/
ふりょうとうこうしゃ /不良投稿者/
ふりょうばば /不良馬場/
ふりょうひん /不良品/
ふりょうぶっけん /不良物件/
ふりょうりつ /不良率/
ふりょく /浮力/富力/
ふりわけ /振り分け/振分/振分け/
ふりん /不倫/
ふりんあいて /不倫相手/
ふる /古/
ふる> /古;古雑誌,古証文,古自転車/
ふるい /篩/古井/古い/
ふるいえ /古家/
ふるいけ /古池/
ふるいち /古市/
ふるいど /古井戸/
ふるう /古宇/
ふるうち /古内/
ふるえ /震え/古江/古恵/
ふるえごえ /震え声/
ふるおや /古尾谷/
ふるかいてん /フル回転/
ふるかつよう /フル活用/
ふるかどう /フル稼働/
ふるかぶ /古株/
ふるかわ /古川/古河/
ふるかわえきにしぐち /古河駅西口/
ふるかわこうぎょう /古河鉱業/
ふるかわし /古川市/
ふるかわちょう /古川町/
ふるかわでんきこうぎょう /古河電気工業;[企業名]/
ふるかわでんこう /古河電工;[企業名]/
ふるかわでんち /古河電池/
ふるがお /古顔/
ふるがっき /古楽器/
ふるがね /古鉄/
ふるき /古木/
ふるきず /古傷/
ふるぎ /古着/
ふるぎって /古切手/
ふるぎつね /古狐/
ふるぎや /古着屋/
ふるくさい /古臭い/
ふるこおり /古郡/
ふること /古言/
ふることぶみ /古事記/
ふるごう /古国府/
ふるごおり /古郡/
ふるごよみ /古暦/
ふるさか /古坂/
ふるさと /故郷/古里/故里/
ふるさわ /古澤/古沢/
ふるざけ /古酒/
ふるざっし /古雑誌/
ふるしま /古島/
ふるしゅつじょう /フル出場/
ふるしょう /古庄;姓/
ふるしんぶん /古新聞/
ふるじゅうでん /フル充電/
ふるす /古巣/
ふるせ /古瀬/
ふるそう /古荘/
ふるそうび /フル装備/
ふるた /古田/
ふるたか /古鷹/
ふるたち /古館/古舘;(異体字)/
ふるたちいちろう /古舘伊知郎/
ふるたて /古舘;異体字/
ふるたに /古谷/
ふるだたみ /古畳/
ふるだち /古舘;異体字/
ふるだて /古舘;異体字/
ふるだぬき /古狸/
ふるつわもの /古強者/古兵/
ふるづけ /古漬け/古漬/
ふるて /古手/
ふるでら /古寺/
ふると /古戸/
ふるとり /隹/
ふるどうぐ /古道具/
ふるどうぐや /古道具屋/
ふるどけい /古時計/
ふるどの /古殿/
ふるどり /隹/
ふるなじみ /古馴染/
ふるにょうぼう /古女房/
ふるぬの /古布/
ふるの /古野/
ふるはし /古橋/
ふるはた /古畑/古籏/
ふるび /古び/
ふるびら /古平/
ふるほん /古本/
ふるほんいち /古本市/
ふるほんかい /古本界/
ふるほんや /古本屋/
ふるほんやがい /古本屋街/
ふるまい /振舞/振舞い/振る舞い/
ふるまいざけ /振舞い酒/
ふるまち /古町/
ふるみち /古道/
ふるみや /古宮/
ふるむら /古村/
ふるめ /古妻/古め/
ふるもと /古本/
ふるもの /古物/
ふるものがたり /古物語/
ふるや /古屋/古谷/古家/古矢/
ふるやま /古山/
ふれ /触れ/振れ/
ふれあい /ふれ合い/
ふれい /譜例/布令;order/不例;貴人の病気/負例/
ふれかく /振れ角/
ふれこみ /触れ込み/触込み/
ふれだいこ /触れ太鼓/
ふれはば /振れ幅/
ふれぶみ /触文/
ふれんぞく /不連続/
ふれんぞくせい /不連続性/
ふれんぞくせん /不連続線/
ふれんぞくてき /不連続的/
ふれんぞくてん /不連続点/
ふれんぞくめん /不連続面/
ふれんど /普連土/
ふれんどがくえん /普連土学園/
ふろ /風呂/風炉/
ふろあがり /風呂上がり/風呂あがり/
ふろう /不老/不労/浮浪/
ふろうしゃ /浮浪者/
ふろうしょとく /不労所得/
ふろうじ /浮浪児/
ふろうちょう /不老町/
ふろうちょうじゅ /不老長寿/
ふろうふし /不老不死/
ふろうりん /不老林/
ふろおけ /風呂桶/
ふろがま /風呂釜/
ふろく /付録/附録/不陸/不直/
ふろしき /風呂敷/
ふろそうじ /風呂掃除/
ふろたき /風呂焚き/
ふろば /風呂場/
ふろふき /風呂吹き;-大根/
ふろみず /風呂水/
ふろや /風呂屋/
ふろよう /風呂用/
ふろんり /負論理/
ふわ /不和;discord.「嫁との-」/付和;「-雷同」/不破/
ふわく /不惑;40歳/
ふわけ /腑分け/
ふわずいこう /付和随行/
ふわたり /不渡り/不渡/
ふわたりてがた /不渡手形/
ふわらいどう /付和雷同/
ふわり /譜割/譜割り/
ふん /分/糞/粉;powder/扮;扮装/紛;紛争/雰;雰囲気/氛;≒雰/吩/忿;≒憤/枌;そぎ/汾/芬;芬芬(ふんぷん)/噴;噴出/墳;古墳/憤;憤慨/濆/賁/吻;口吻/刎;刎頸/奮;興奮/焚;焚書/′;minute/
ふんあつ /分圧/
ふんい /雰囲/
ふんいき /雰囲気/氛圍氣;「雰」別字、「囲」「気」旧字/
ふんいきてき /雰囲気的/
ふんうん /紛紜/
ふんえん /噴煙/
ふんか /噴火/
ふんかこう /噴火口/
ふんかさいがい /噴火災害/
ふんかわん /噴火湾/
ふんかん /分間/
ふんかんかく /分間隔/
ふんがい /憤慨/
ふんき /奮起/噴気/
ふんきこう /噴気孔/
ふんきざみ /分刻み/
ふんきゅう /紛糾/
ふんきゅうぼ /墳丘墓/
ふんぎ /紛議/
ふんぎり /踏ん切り;-が付かない/
ふんけい /刎頚;頚(くび)を刎(は)ねること/焚刑/刎頸;=刎頚/
ふんげき /憤激/
ふんこつ /粉骨/
ふんこつさいしん /粉骨砕身/
ふんころ /分頃/
ふんご /分後/
ふんごう /吻合/
ふんごと /分毎/
ふんさい /粉砕/粉彩;[陶芸]/
ふんさつ /焚殺/
ふんざい /粉剤/
ふんし /憤死/
ふんしつ /紛失/
ふんしつきゅう /紛失球/
ふんしつじ /紛失時/
ふんしつとどけ /紛失届/
ふんしゃ /噴射/
ふんしゃこう /噴射口/
ふんしゃしき /噴射式/
ふんしゃねんりょう /噴射燃料/
ふんしゃまえ /噴射前/
ふんしゃりょう /噴射量/
ふんしゅうは /分周波/
ふんしゅつ /噴出/
ふんしゅつおん /噴出音/
ふんしゅつこう /噴出口/
ふんしょ /焚書/
ふんしょく /粉飾;†(原義:白粉で)見た目をごまかす。「-決算」/粉食;⇔粒食/扮飾;†身なりを飾る/
ふんしょくけっさん /粉飾決算/
ふんしょこうじゅ /焚書坑儒/
ふんしん /分針/
ふんじょう /紛擾/
ふんじん /粉塵/奮迅/
ふんじんばくはつ /粉塵爆発/
ふんすい /噴水/
ふんせき /噴石;(火山の) cinder/糞石;(鳥糞の) coprolite/
ふんせつ /粉雪/
ふんせん /奮戦/噴泉/
ふんせんき /奮戦記/
ふんぜん /憤然/奮然/紛然/
ふんそう /紛争/扮装/
ふんそうしょり /紛争処理/
ふんそうちいき /紛争地域/
ふんそうとうじしゃ /紛争当事者/
ふんそく /分速/吻側/
ふんぞうえ /糞掃衣;僧衣/
ふんぞく /フン族;Hun/
ふんたい /粉体/粉黛/
ふんたいこうがく /粉体工学/
ふんたいこうがっかい /粉体工学会/
ふんたいとそう /粉体塗装/
ふんたん /粉炭/
ふんたんい /分単位/
ふんづまり /糞詰まり/糞詰り/
ふんとう /奮闘/粉糖/
ふんとうき /奮闘記/
ふんど /憤怒/忿怒/糞土/
ふんどう /分銅/
ふんどし /褌/
ふんどしすがた /褌姿/
ふんにゅう /粉乳/
ふんにょう /糞尿/
ふんぬ /憤怒/忿怒;=憤怒/
ふんはん /分半/
ふんばり /踏ん張り;-が利かない/
ふんぱつ /奮発/
ふんぱん /噴飯/
ふんびょう /分秒/
ふんぷん /紛々/芬々/
ふんべつ /分別/
ふんべつがお /分別顔/
ふんべつざかり /分別盛り/
ふんべん /糞便/
ふんぼ /墳墓/
ふんぼはっくつざい /墳墓発掘罪/
ふんぽん /粉本/
ふんまえ /分前/
ふんまつ /粉末/
ふんまつじょう /粉末状/
ふんまつせんざい /粉末洗剤/
ふんまん /憤懣/忿懣/
ふんみまん /分未満/
ふんみょう /分明/
ふんむ /噴霧/
ふんむき /噴霧器/
ふんめつ /焚滅/
ふんもん /噴門/憤悶/
ふんや /文屋/
ふんやのあさやす /文屋朝康;白露に 風の吹きしく 秋の野は つらぬきとめぬ 玉ぞ散りける/
ふんやのやすひで /文屋康秀;吹くからに 秋の草木の しをるれば むべ山風を 嵐といふらむ/
ふんらん /紛乱/
ふんりゅう /噴流/粉瘤;[医]atheroma/
ふんりゅうしき /噴流式/
ふんれい /奮励/
ぶ /分/部/武/不/無/撫;慰撫/舞;舞踊/蕪;かぶ/嘸;さぞ/廡;ひさし/憮;憮然/侮;侮辱/毋;なかれ/誣;誣告/錻;錻力(ブリキ)/蒲;菖蒲/葡;葡萄/歩;歩合/奉;奉行/悔;?/
ぶーどぅーきょう /ブードゥー教/
ぶーるだいすう /ブール代数;Boolean algebra/
ぶあい /歩合/部合/無愛/
ぶあいきゅう /歩合給/
ぶあいきょう /無愛敬/
ぶあいそ /無愛想/不愛想/
ぶあいそう /無愛想/
ぶあく /武悪/
ぶあんない /不案内/
ぶい /部位/武威/
ぶいく /撫育/
ぶいしねま /Ｖシネマ/Vシネマ/
ぶいじ /Ｖ字/V字/
ぶいじかいふく /Ｖ字回復/
ぶいち /武一/
ぶいねっく /Ｖネック/Vネック/
ぶいん /部員/無音/
ぶいんすう /部員数/
ぶうん /武運/
ぶうんちょうきゅう /武運長久/
ぶえ /笛/
ぶえき /無射/
ぶえん /無塩/
ぶえんりょ /無遠慮/不遠慮;=無遠慮/
ぶおとこ /醜男/
ぶおんな /醜女/
ぶおんぷ /分音符/
ぶか /部下/部課/部科/深/
ぶかい /部会/
ぶかいしゅさい /部会主催/
ぶかいせい /部会制/
ぶかたち /部下達/
ぶかちょう /部課長/
ぶかっこう /不恰好/不格好/
ぶかつ /部活/
ぶかつどう /部活動/
ぶかめい /部課名/
ぶかん /武官/武漢;Wuhan/武鑑/
ぶが /舞歌/
ぶがい /部外/
ぶがいしゃ /部外者/
ぶがいひ /部外秘/
ぶがく /舞楽/
ぶき /武器/
ぶきえんじょ /武器援助/
ぶきか /武器化/
ぶききんゆ /武器禁輸/
ぶきこ /武器庫/
ぶきしょうにん /武器商人/
ぶきてん /武器店/
ぶきとりひき /武器取引/
ぶきはかい /武器破壊/
ぶきみ /不気味/
ぶきや /武器屋/
ぶきゆしゅつ /武器輸出/
ぶきゆしゅつこく /武器輸出国/
ぶきょう /武侠/不興/無興;=不興/
ぶきょく /部局/舞曲;Tanz/部曲;[日本史]=かきべ/
ぶきょくかん /部局間/
ぶきょくじゅん /部局順/
ぶきょくちょう /部局長/
ぶきょくめい /部局名/
ぶきよう /不器用/無器用/
ぶきりょう /不器量/
ぶきるい /武器類/
ぶぎ /武技/部議/
ぶぎょう /奉行/
ぶぎょうしょ /奉行所/
ぶく /伏/
ぶくうじゅつ /舞空術/
ぶくりょう /茯苓/
ぶくりょうさい /茯苓菜/
ぶくろ /袋/
ぶくん /武勲/
ぶぐ /武具/
ぶけ /武家/
ぶけがた /武家方;⇔公家方/
ぶけぎりものがたり /武家義理物語/
ぶけさま /武家様/
ぶけしゃかい /武家社会/
ぶけしょはっと /武家諸法度/
ぶけじだい /武家時代;鎌倉以降/
ぶけづくり /武家造り;[建築]/武家造;[建築]/
ぶけやしき /武家屋敷/
ぶけん /武見/
ぶげい /武芸/
ぶげいしゃ /武芸者/
ぶげいちょう /武芸帳/
ぶげいひゃっぱん /武芸百般/
ぶげん /分限/侮言/無限/
ぶこう /武功/武后;則天武后/
ぶこうやわ /武功夜話/
ぶこく /誣告/
ぶこくざい /誣告罪/
ぶこつ /無骨/武骨;≒無骨 (特に、洗練されてないこと)/
ぶさ /房/
ぶさいく /不細工/
ぶさく /部作/
ぶさた /無沙汰/不沙汰/
ぶさつ /撫擦/
ぶさほう /無作法/不作法/
ぶざーおん /ブザー音/
ぶざい /部材/
ぶざつ /蕪雑/
ぶざま /無様/不様;=無様/
ぶし /武士/節/部誌/附子/付子/
ぶしお /無潮/
ぶしかいきゅう /武士階級/
ぶしつ /部室/
ぶしつけ /不躾/不しつけ;※不自然な交ぜ書き?/
ぶしどう /武士道/
ぶしや /付子矢/
ぶしゅ /部首/
ぶしゅう /武州;武蔵/
ぶしゅうぎ /不祝儀/
ぶしゅうぎぶくろ /不祝儀袋/
ぶしゅさくいん /部首索引/
ぶしゅにゅうりょく /部首入力/
ぶしゅめい /部首名/
ぶしょ /部署/部所;?/
ぶしょう /武将/無精/不精;=無精/部将;部隊長/
ぶしょうひげ /無精髭/不精髭/
ぶしょうもの /不精者/無精者/
ぶしょがい /部署外/
ぶしょない /部署内/
ぶしょめい /部署名/
ぶしん /武神/
ぶじ /無事/武事;military/
ぶじかいけつ /無事解決/
ぶじきかん /無事帰還/
ぶじきこく /無事帰国/
ぶじこれめいば /無事是名馬/
ぶじしゅうりょう /無事終了/
ぶじつうか /無事通過/
ぶじとうちゃく /無事到着/
ぶじとっぱ /無事突破/
ぶじに /無事に/
ぶじにゅうしゅ /無事入手/
ぶじはっけん /無事発見/
ぶじゅつ /武術/撫恤/
ぶじゅん /撫順/
ぶじょく /侮辱/
ぶじょくいがい /侮辱以外/
ぶじょくこうい /侮辱行為/
ぶじょくざい /侮辱罪/
ぶじょくてき /侮辱的/
ぶじん /武人/
ぶす /附子/付子/
ぶすい /無粋/不粋/
ぶすう /部数/
ぶすじま /毒島/
ぶすや /附子矢/
ぶせい /部制/
ぶぜい /無勢/
ぶぜん /憮然;NB:本義は「失望」/豊前;福岡県東部/
ぶそう /武装/
ぶそうかいじょ /武装解除/
ぶそうがったい /武装合体/
ぶそうしゅうだん /武装集団/
ぶそうせいりょく /武装勢力/
ぶそうそしき /武装組織/
ぶそうちゅうりつ /武装中立/
ぶそうへり /武装ヘリ/
ぶそく /不足/
ぶそん /武尊/蕪村/
ぶそんしちぶしゅう /蕪村七部集;1809/
ぶぞく /部族/部属/
ぶた /豚/蓋/盖;「蓋」の異体字1/葢;「蓋」の異体字2/
ぶたい /舞台/部隊/
ぶたいあいさつ /舞台挨拶/
ぶたいいしょう /舞台衣装/
ぶたいうら /舞台裏/
ぶたいえんしゅつ /舞台演出/
ぶたいおんがく /舞台音楽/
ぶたいおんきょう /舞台音響/
ぶたいか /舞台化/
ぶたいかんとく /舞台監督;regisseur/
ぶたいがわ /舞台側/
ぶたいげいこ /舞台稽古/
ぶたいげいじゅつ /舞台芸術/
ぶたいげき /舞台劇/
ぶたいこうえん /舞台公演/
ぶたいこうか /舞台効果/
ぶたいさつえい /舞台撮影/
ぶたいしょうめい /舞台照明;stage lighting/
ぶたいじょう /舞台上/
ぶたいじょゆう /舞台女優/
ぶたいすう /部隊数/
ぶたいせってい /舞台設定/
ぶたいぜんたい /舞台全体/
ぶたいそうち /舞台装置/
ぶたいそで /舞台袖/
ぶたいたんい /部隊単位/
ぶたいちゅうおう /舞台中央/
ぶたいちゅうけい /舞台中継/
ぶたいちょう /部隊長/
ぶたいどきょう /舞台度胸;stage presence/
ぶたいはいゆう /舞台俳優/
ぶたいびじゅつ /舞台美術/
ぶたいへんせい /部隊編成/
ぶたいめん /舞台面/
ぶたいゆか /舞台床/
ぶたいよう /舞台用/
ぶたがわ /豚革/豚皮/
ぶたこま /豚小間/
ぶたごや /豚小屋/
ぶたしゃぶ /豚しゃぶ/
ぶたじる /豚汁/
ぶたじるふう /豚汁風/
ぶたたま /豚玉/
ぶたたまてん /豚玉天/
ぶたどん /豚丼/
ぶたにく /豚肉/
ぶたばこ /豚箱/ブタ箱/
ぶたひれ /豚ヒレ/
ぶたまん /豚饅/豚まん/
ぶたまんや /豚饅屋/
ぶたもも /豚モモ/
ぶたろーす /豚ロース/
ぶだいか /舞台化/
ぶだん /武断/
ぶち /斑;(まだら)-犬/縁;(連濁,はじっこ)窓縁/淵;(連濁,深み)絶望の淵/渕;「淵」の異体字1/渊;「淵」の異体字1/鞭;むち/駁;≒斑/
ぶちぎれ /ブチ切れ/
ぶちこわし /打ち壊し;NB:「うちこわし」と同形/
ぶちょう /部長/
ぶちょうかい /部長会/
ぶちょうしつ /部長室/
ぶちょうせき /部長席/
ぶちょうづき /部長付/
ぶちょうほう /不調法/
ぶちょうほさ /部長補佐/
ぶっ> /打っ;打っ壊す,打っ潰す/
ぶっか /物価/物化;万物の変化。死。/仏果/仏家/
ぶっかい /物界/仏界/
ぶっかかんかく /物価感覚/
ぶっかき /打っ欠き/
ぶっかく /仏閣/物覚/
ぶっかけ /打っ掛け/
ぶっかしすう /物価指数/
ぶっかじじょう /物価事情/
ぶっかじょうしょう /物価上昇/
ぶっかじょうしょうりつ /物価上昇率/
ぶっかだか /物価高/
ぶっかつろん /物活論/
ぶっきょう /仏教/佛教;旧字/物狂/仏経;仏教の経文/
ぶっきょういせき /仏教遺跡/
ぶっきょうおんがく /仏教音楽/
ぶっきょうがく /仏教学/
ぶっきょうきょうてん /仏教教典/
ぶっきょうけい /仏教系/
ぶっきょうけんちく /仏教建築/
ぶっきょうこく /仏教国/
ぶっきょうし /仏教史/
ぶっきょうしき /仏教式/
ぶっきょうしゃ /仏教者/
ぶっきょうせいてん /仏教聖典/
ぶっきょうせつわ /仏教説話/
ぶっきょうぜんぱん /仏教全般/
ぶっきょうだい /仏教大/
ぶっきょうと /仏教徒/
ぶっきょうびじゅつ /仏教美術/
ぶっきょうようご /仏教用語/
ぶっけ /仏家/
ぶっけん /物件/物権;[法]real right/物研/
ぶっけんこうい /物権行為/
ぶっけんこうにゅうしゃ /物件購入者/
ぶっけんしょうけん /物権証券/
ぶっけんてきせいきゅうけん /物権的請求権/
ぶっけんひ /物件費/
ぶっけんほう /物権法/
ぶっこ /物故/
ぶっこう /物工/
ぶっこく /仏国/
ぶっこくど /仏国土/
ぶっこしゃ /物故者/
ぶっさつ /仏刹/
ぶっさん /物産/仏参/
ぶっさんてん /物産展/物産店/
ぶっし /物資/仏師/仏子/
ぶっしき /仏式/
ぶっしつ /物質/
ぶっしつか /物質化/
ぶっしつかがく /物質科学/
ぶっしつかん /物質間/
ぶっしつけい /物質系/
ぶっしつけん /物質研/
ぶっしつげんしょう /物質現象/
ぶっしつこうぞう /物質構造/
ぶっしつしゅぎ /物質主義/
ぶっしつせいめいかがく /物質生命科学/
ぶっしつたいしゃ /物質代謝/
ぶっしつちゅう /物質中/
ぶっしつてき /物質的/
ぶっしつてきじゅうそく /物質的充足/
ぶっしつでんそう /物質伝送/
ぶっしつは /物質波/
ぶっしつば /物質場/
ぶっしつぶんぷ /物質分布/
ぶっしつぶんめい /物質文明/
ぶっしつめい /物質名/
ぶっしつめいし /物質名詞/
ぶっしつゆそう /物質輸送/
ぶっしゃり /仏舎利/
ぶっしょ /仏書/
ぶっしょう /物証;物的証拠/仏性/物象;materlal phenomena/
ぶっしょうい /仏正意/
ぶっしょうえ /仏生会;=灌仏会/
ぶっしょうか /物象化/
ぶっしょく /物色/
ぶっしょくちゅう /物色中/
ぶっしん /仏心/物心/物神;物神崇拝/仏身/
ぶっせい /物性/仏性/
ぶっせいがく /物性学/
ぶっせいきそろん /物性基礎論/
ぶっせいけい /物性系/
ぶっせいけん /物性研/
ぶっせいけんきゅう /物性研究/
ぶっせいぶつりがく /物性物理学/
ぶっせいや /物性屋/
ぶっせいりろん /物性理論/
ぶっせいろん /物性論/
ぶっせき /仏跡/
ぶっせつ /仏説/
ぶっそ /仏祖/
ぶっそう /物騒/仏葬/
ぶっそうげ /仏桑花/
ぶっそくせき /仏足石;釈迦の足跡を象った石/
ぶっそん /物損/
ぶっそんじこ /物損事故/
ぶったい /物体/仏体/
ぶったいがわ /物体側/
ぶったいない /物体内/
ぶったいないぶ /物体内部/
ぶったいにんしき /物体認識/
ぶったいひょうめん /物体表面/
ぶっだ /仏陀/
ぶっだしゃくそん /仏陀釈尊/
ぶっち /仏智/
ぶっちょうずら /仏頂面;※仮名遣い「ぶっちょうづら」/
ぶっちょうづら /仏頂面/
ぶっつけほんばん /打っ付け本番/
ぶってき /物的/
ぶってきしょうこ /物的証拠/
ぶってん /仏典/
ぶってんちゅう /仏典中/
ぶっと /仏徒/
ぶっとう /仏塔/仏頭/
ぶっとおし /打っ通し;<rare>/ぶっ通し/
ぶっぱん /物販/
ぶっぴん /物品/
ぶっぴんぜい /物品税/
ぶっぴんだい /物品代/
ぶっぽう /仏法/
ぶっぽうそう /仏法僧/
ぶつ /物/仏/勿;なかれ/佛;「仏」の旧字(人名用漢字)/
ぶつえん /仏縁/
ぶつえんほう /仏炎苞/
ぶつおん /仏恩/
ぶつが /仏画/
ぶつがく /仏学/
ぶつがん /仏龕/仏願/
ぶつきつ /勿吉;古代中国の少数民族。「もっきつ」/
ぶつぎ /物議/
ぶつぎり /ぶつ切り/
ぶつぐ /仏具/物具/
ぶつぐてん /仏具店/
ぶつげん /仏眼/
ぶつご /仏語/
ぶつざ /仏座/
ぶつざん /仏山/
ぶつじ /仏事/仏寺/仏地/
ぶつじょう /物情/
ぶつじょうそうぜん /物情騒然/
ぶつじょうだいい /物上代位/
ぶつじょうほしょうにん /物上保証人/
ぶつじん /仏神/
ぶつぜん /仏前/
ぶつぞう /仏像/
ぶつだ /仏陀/
ぶつだい /仏大/
ぶつだん /仏壇/
ぶつだんてん /仏壇店/
ぶつでし /仏弟子/
ぶつでん /仏殿/仏伝/
ぶつど /仏土/
ぶつどう /仏道/仏堂/
ぶつのう /物納/
ぶつばつ /仏罰/
ぶつぶつ /物々/勿勿/
ぶつぶつこうかん /物々交換/
ぶつほけん /物保険/
ぶつま /仏間/
ぶつみょう /仏名/
ぶつめつ /仏滅;[六輝]/
ぶつもう /勿罔/
ぶつもつ /仏物/
ぶつもん /仏門/
ぶつよく /物欲/
ぶつり /物理/
ぶつりいがい /物理以外/
ぶつりか /物理科/
ぶつりかい /物理界/
ぶつりかがく /物理化学/
ぶつりかてい /物理過程/
ぶつりかんけい /物理関係/
ぶつりがく /物理学/物理學/
ぶつりがくえんしゅう /物理学演習/
ぶつりがくきょういく /物理学教育/
ぶつりがくきょうしつ /物理学教室/
ぶつりがくけんきゅう /物理学研究/
ぶつりがくけんきゅうかい /物理学研究会/
ぶつりがくけんきゅうしょ /物理学研究所/
ぶつりがくし /物理学史/
ぶつりがくしゃ /物理学者/
ぶつりがくしょ /物理学書/
ぶつりがくしょう /物理学賞/
ぶつりがくじっけん /物理学実験/
ぶつりがくじてん /物理学辞典/
ぶつりがくてき /物理学的/
ぶつりがっか /物理学科/
ぶつりがっかい /物理学会/
ぶつりがっかいし /物理学会誌/
ぶつりき /仏力/
ぶつりきょういく /物理教育/
ぶつりきょうしつ /物理教室/
ぶつりけい /物理系/
ぶつりけいさん /物理計算/
ぶつりけん /物理研/
ぶつりけんきゅうぶ /物理研究部/
ぶつりげんしょう /物理現象/
ぶつりげんり /物理原理/
ぶつりこうぎ /物理講義/
ぶつりこうげき /物理攻撃/
ぶつりさよう /物理作用/
ぶつりじっけん /物理実験/
ぶつりじっけんしつ /物理実験室/
ぶつりじょうすう /物理定数/
ぶつりじょうたい /物理状態/
ぶつりすうがく /物理数学/
ぶつりせい /物理性/
ぶつりせいぶつ /物理生物/
ぶつりせかい /物理世界/
ぶつりせんこう /物理専攻/
ぶつりそう /物理層/
ぶつりていすう /物理定数/
ぶつりてき /物理的/
ぶつりてきあんていせい /物理的安定性/
ぶつりてきいち /物理的位置/
ぶつりてきいみ /物理的意味/
ぶつりてきかいしゃく /物理的解釈/
ぶつりてきかこう /物理的加工/
ぶつりてきかてい /物理的過程/
ぶつりてきかんきょう /物理的環境/
ぶつりてききょり /物理的距離/
ぶつりてきけいたい /物理的形態/
ぶつりてきげんかい /物理的限界/
ぶつりてきげんしょう /物理的現象/
ぶつりてきこうい /物理的行為/
ぶつりてきこうぞう /物理的構造/
ぶつりてきさよう /物理的作用/
ぶつりてきしょうがい /物理的障害/
ぶつりてきじげん /物理的次元/
ぶつりてきじったい /物理的実体/
ぶつりてきじつざい /物理的実在/
ぶつりてきじょうきょう /物理的状況/
ぶつりてきじょうけん /物理的条件/
ぶつりてきせいげん /物理的制限/
ぶつりてきそんざい /物理的存在/
ぶつりてきたいしょう /物理的対象/
ぶつりてきとくせい /物理的特性/
ぶつりてきほうそく /物理的法則/
ぶつりてきよういん /物理的要因/
ぶつりとくせい /物理特性/
ぶつりにゅうもん /物理入門/
ぶつりぶ /物理部/
ぶつりほうそく /物理法則/
ぶつりめい /物理名/
ぶつりもんだい /物理問題/
ぶつりや /物理屋/
ぶつりゅう /物流/
ぶつりゅうぶもん /物流部門/
ぶつりゅうめん /物流面/
ぶつりょう /物量/物療/
ぶつりようご /物理用語/
ぶつりりょう /物理量/
ぶつりりょうほう /物理療法;[医]/
ぶつりりろん /物理理論/
ぶつるいしょうこ /物類称呼/
ぶてい /武帝/
ぶでん /舞殿/
ぶと /太/
ぶとう /舞踏/武闘/
ぶとうおんがく /舞踏音楽/
ぶとうか /舞踏家;dancer/武闘家;fighter/
ぶとうかい /舞踏会;ball/武闘会/
ぶとうたいかい /武闘大会/
ぶとうだん /舞踏団/
ぶとうてき /舞踏的/
ぶとうは /武闘派/
ぶとうびょう /舞踏病;[医]chorea/
ぶとん /布団/蒲団/
ぶどう /武道/葡萄/
ぶどういろ /葡萄色/
ぶどうか /武道家/ブドウ科/
ぶどうかん /武道館/武道舘;異体字/
ぶどうかんこうえん /武道館公演/
ぶどうかんたいかい /武道館大会/
ぶどうがり /ぶどう狩り/
ぶどうきゅうきん /葡萄球菌/
ぶどうしゅ /葡萄酒/ぶどう酒/ブドウ酒/
ぶどうじょ /武道所/
ぶどうじょう /武道場/葡萄状/
ぶどうたいかい /武道大会/
ぶどうだな /葡萄棚;grape arbor/
ぶどうとう /葡萄糖/ブドウ糖/
ぶどうねずみ /葡萄鼠/
ぶどうばたけ /葡萄畑/
ぶどまり /歩留まり/歩留り/
ぶな /椈/山毛欅/樗;「おうち」,「ぶな」じゃないのか?/
ぶない /部内/
ぶないしゃ /部内者/
ぶないりょこう /部内旅行/
ぶなもく /ブナ目/Fagales/
ぶなもくあぐん /ブナ目亜群/
ぶなもくぐん /ブナ目群/
ぶなん /無難/武南/
ぶにん /無人/補任/
ぶね /船/
ぶはぶっきょう /部派仏教/
ぶばいがわら /分倍河原/
ぶばいがわらえき /分倍河原駅/
ぶひ /部費/
ぶひん /部品/
ぶひんか /部品化/
ぶひんかかく /部品価格/
ぶひんきょうきゅう /部品供給/
ぶひんきょうはん /部品共販/
ぶひんこうかん /部品交換/
ぶひんすう /部品数/
ぶひんたんい /部品単位/
ぶひんだい /部品代/
ぶひんだいきん /部品代金/
ぶひんていきょう /部品提供/
ぶひんてんすう /部品点数/
ぶひんとり /部品取り/
ぶひんひょう /部品表/
ぶひんめい /部品名/
ぶひんや /部品屋/
ぶび /武備/
ぶびき /歩引き/
ぶふうりゅう /無風流/
ぶぶづけ /ぶぶ漬け/
ぶぶん /部分/舞文/
ぶぶんいがい /部分以外/
ぶぶんいっち /部分一致/
ぶぶんいんよう /部分引用/
ぶぶんおん /部分音/
ぶぶんかいぎょう /部分開業/
ぶぶんかいつう /部分開通/
ぶぶんかいてい /部分改訂/部分改定/
ぶぶんかくてい /部分確定/
ぶぶんかんすう /部分関数/
ぶぶんきょうか /部分強化/
ぶぶんきょくひつ /舞文曲筆/
ぶぶんぎ /部分木/
ぶぶんくうかん /部分空間/
ぶぶんくうかんほう /部分空間法/
ぶぶんぐん /部分群/
ぶぶんけい /部分系/
ぶぶんけいさん /部分計算/
ぶぶんこう /部分項/
ぶぶんこうぞう /部分構造/
ぶぶんし /部分枝/
ぶぶんしき /部分式/
ぶぶんしてい /部分指定/
ぶぶんしゅうごう /部分集合/
ぶぶんしょく /部分食/
ぶぶんせいげん /部分制限/
ぶぶんせつじょ /部分切除;partial excision. 「肝臓を-」/
ぶぶんぜんたい /部分全体/
ぶぶんそっこう /部分測光/
ぶぶんてき /部分的/
ぶぶんどうし /部分同士/
ぶぶんにく /部分肉/
ぶぶんにっしょく /部分日食/
ぶぶんはいれつ /部分配列/
ぶぶんひてい /部分否定/
ぶぶんひょうか /部分評価/
ぶぶんひん /部分品/
ぶぶんぶぶん /部分部分/
ぶぶんへんこう /部分変更/
ぶぶんもじれつ /部分文字列/
ぶぶんもんだい /部分問題/
ぶぶんやく /部分訳/
ぶぶんよく /部分浴/
ぶぶんりょういき /部分領域/
ぶぶんれつ /部分列/
ぶぶんわ /部分和/
ぶへん /武辺/
ぶべつ /侮蔑/部別;classify/
ぶべつてき /侮蔑的/
ぶま /不間/
ぶみ /文/
ぶめい /部名/武名/
ぶめん /部面/
ぶもどし /歩戻し/
ぶもん /部門/武門/
ぶもんかん /部門間/
ぶもんごと /部門毎/
ぶもんすう /部門数/
ぶもんせつりつ /部門設立/
ぶもんない /部門内/
ぶもんひ /部門費/
ぶもんべつ /部門別/
ぶもんめい /部門名/
ぶもんゆうしょう /部門優勝/
ぶゆ /蚋/
ぶゆう /武勇/
ぶゆうでん /武勇伝/
ぶよ /蚋/
ぶよう /舞踊/
ぶようか /舞踊家/
ぶようげき /舞踊劇/
ぶようじん /不用心/無用心/
ぶようどう /武揚堂/
ぶらい /無頼/不頼;=無頼/
ぶらいかん /無頼漢/
ぶらいは /無頼派/
ぶらうんうんどう /ブラウン運動;[化学]/
ぶらうんかん /ブラウン管/
ぶらく /部落/
ぶらくかいほううんどう /部落解放運動/
ぶらくかいほうどうめい /部落解放同盟/
ぶらくさべつ /部落差別/
ぶらくしゅっしんしゃ /部落出身者/
ぶらくみん /部落民/
ぶらくもんだい /部落問題/
ぶらじる /伯剌西爾;Brazil/
ぶらじるじん /ブラジル人/
ぶらすばんどぶ /ブラスバンド部/
ぶらんこ /鞦韆/
ぶらんどひん /ブランド品/
ぶらんどまい /ブランド米/
ぶらんどもの /ブランド物/
ぶらんどりょく /ブランド力/
ぶり /鰤/風/振り;二年-,益荒男-/
ぶりきかん /ブリキ缶/
ぶりだいこん /鰤大根/ブリ大根/
ぶりっこ /ぶりっ子/
ぶりゃく /武略/
ぶりょう /無聊/
ぶりょうとうげん /武陵桃源/
ぶりょく /武力/
ぶりょくかいにゅう /武力介入/
ぶりょくかくめい /武力革命/
ぶりょくかんしょう /武力干渉/
ぶりょくこうげき /武力攻撃/
ぶりょくこうし /武力行使/
ぶりょくこうしけつぎ /武力行使決議/
ぶりょくしんこう /武力侵攻/武力進攻/
ぶりょくせいさい /武力制裁/
ぶりょくふんそう /武力紛争/
ぶるい /部類/
ぶるがりあ /勃牙利;Bulgaria/
ぶるまい /振舞い/
ぶれい /無礼/
ぶれいこう /無礼講/
ぶれいもの /無礼者/
ぶれつ /武烈/
ぶれつてんのう /武烈天皇/
ぶれんどまい /ブレンド米/
ぶろ /風呂/
ぶろっくか /ブロック化/
ぶろっくくずし /ブロック崩し/
ぶろっくけいざい /ブロック経済;bloc economy/
ぶろっくし /ブロック紙;block newspaper/
ぶろっくべい /ブロック塀/
ぶろんずいろ /ブロンズ色;bronze/
ぶろんずぞう /ブロンズ像/
ぶわけ /部分け/
ぶわり /歩割/
ぶん /分/文/聞/紊;紊乱/馼/蚊;(漢音)/
ぶん> /分;(section) 分局,分苑/
ぶんあつ /分圧/
ぶんあん /文案/文安;年号(1444-49)/
ぶんい /文意/
ぶんいき /分域/
ぶんいち /文一/
ぶんいちそうごうしゅっぱん /文一総合出版;[出版社名]/
ぶんいん /分院/
ぶんうん /文運;⇔武運/
ぶんえい /文永;年号(1264-1275)/
ぶんえいどう /文永堂/
ぶんえん /分煙/分園/文苑;文壇/文園;=文苑/
ぶんえんか /分煙化/分煙可/
ぶんえんしせつ /分煙施設/
ぶんえんどう /文苑堂/
ぶんおう /文応;年号(1260-1261)/
ぶんか /文化;culture/分化;differentiation.「機能-」/文科;arts/分科;section.「-会」/文華/分課/分果/
ぶんかい /分解/分会/分界;delimination/文界/
ぶんかいかいしゅう /分解回収/
ぶんかいかのう /分解可能/
ぶんかいげんり /分解原理/
ぶんかいこうそ /分解酵素/
ぶんかいこうてい /分解工程/
ぶんかいさぎょう /分解作業/
ぶんかいさん /文化遺産/
ぶんかいしき /文化意識/
ぶんかいしゃ /分解者;[生物]decomposer/
ぶんかいしゃしん /分解写真/
ぶんかいしゅうり /分解修理/
ぶんかいせい /分解性/
ぶんかいせいび /分解整備/
ぶんかいせき /文解析/
ぶんかいそうじ /分解掃除/
ぶんかいてん /分界点/
ぶんかいのう /分解能/
ぶんかいほう /分解法/
ぶんかいほうほう /分解方法/
ぶんかいりょく /分解力/
ぶんかえいが /文化映画/
ぶんかかい /分科会/文化会/
ぶんかかいいん /分科会員/
ぶんかかいかつどう /分科会活動/
ぶんかかいかん /文化会館/文化会舘;「館」異体字/
ぶんかかいほうこく /分科会報告/
ぶんかかがく /文化科学;Kulturwissenschaft/
ぶんかかくめい /文化革命/
ぶんかかち /文化価値/
ぶんかがっか /文化学科/
ぶんかきごう /文化記号/
ぶんかく /分画/文革/文格/
ぶんかくんしょう /文化勲章/
ぶんかけい /文化系/文科系/
ぶんかけいがくせい /文科系学生/
ぶんかけいだいがく /文科系大学/
ぶんかけん /文化圏/
ぶんかげんしょう /文化現象/
ぶんかこっか /文化国家/
ぶんかさ /文化差/
ぶんかさい /文化祭/
ぶんかざい /文化財/
ぶんかざいほごほう /文化財保護法/
ぶんかし /文化史/文化誌/
ぶんかしせつ /文化施設/
ぶんかしはい /文化支配/
ぶんかしほん /文化資本;[社会学]capital culturel/
ぶんかしゃかいがく /文化社会学;cultural sociology/
ぶんかしゃったー /文化シャッター/
ぶんかしゅぎ /文化主義;culturism/
ぶんかしょう /文化賞;†(award) 「芸術-,出版-」/文化省;†ministry of culture/文化相;†大臣/
ぶんかしんりゃく /文化侵略/
ぶんかじょうほう /文化情報/
ぶんかじょし /文華女子/
ぶんかじょしだい /文化女子大/
ぶんかじん /文化人/
ぶんかじんるいがく /文化人類学/
ぶんかすいじゅん /文化水準/
ぶんかせいかつ /文化生活/
ぶんかせんたー /文化センター;cultural centre/
ぶんかたいいくかん /文化体育館/
ぶんかだいかくめい /文化大革命/
ぶんかだんたい /文化団体/
ぶんかちょう /文化庁/
ぶんかちょうちょうかん /文化庁長官/
ぶんかつ /分割/分轄;区分・管轄/
ぶんかつあん /分割案/
ぶんかついがい /分割以外/
ぶんかついどう /分割移動/
ぶんかつうんよう /分割運用/
ぶんかつがた /分割型/
ぶんかつがわ /分割側/
ぶんかつご /分割後/
ぶんかつさき /分割先/
ぶんかつじかん /分割時間/
ぶんかつじょうほう /分割情報/
ぶんかつすう /分割数/
ぶんかつず /分割図/
ぶんかつぜんご /分割前後/
ぶんかつたいしょう /分割対象/
ぶんかつてん /分割点/
ぶんかつは /分割派/
ぶんかつはんたい /分割反対/
ぶんかつばらい /分割払い/
ぶんかつへいごう /分割併合/
ぶんかつほう /分割法/
ぶんかつほうしき /分割方式/
ぶんかつほうほう /分割方法/
ぶんかつみんえいか /分割民営化/
ぶんかつめい /分割名/
ぶんかつもんだい /分割問題/
ぶんかてき /文化的/
ぶんかてきさい /文化的差異/
ぶんかてきせいかつ /文化的生活/
ぶんかてきはいけい /文化的背景/
ぶんかてきよういん /文化的要因/
ぶんかてきよっきゅう /文化的欲求/
ぶんかてつがく /文化哲学/
ぶんかどう /文化堂/文華堂/
ぶんかのひ /文化の日;11.3 旧・明治節/
ぶんかはいけい /文化背景/
ぶんかぶ /文化部/
ぶんかぶんせいじだい /文化文政時代;1804-30/
ぶんかほうそう /文化放送/
ぶんかまさつ /文化摩擦/
ぶんかまち /文化町/
ぶんかむら /文化村/
ぶんかめん /文化面/
ぶんからん /文化欄/
ぶんかろん /文化論/
ぶんかん /分館/文官/
ぶんかんすう /文関数/
ぶんが /文雅/
ぶんがい /分外/
ぶんがく /文学/文學;「学」旧字/
ぶんがくかい /文学界/
ぶんがくかくめい /文学革命;[世界史]1917,中国/
ぶんがくけい /文学系/
ぶんがくこうぎ /文学講義/
ぶんがくさくひん /文学作品/
ぶんがくざっし /文学雑誌/
ぶんがくし /文学史/文学誌/
ぶんがくしゃ /文学者/
ぶんがくしょ /文学書/
ぶんがくしょう /文学賞/
ぶんがくしょうじょ /文学少女/
ぶんがくしょうねん /文学少年/
ぶんがくせい /文学性/
ぶんがくせいねん /文学青年/
ぶんがくぜんしゅう /文学全集/
ぶんがくてき /文学的/
ぶんがくはかせ /文学博士/
ぶんがくぶ /文学部/
ぶんがくろん /文学論/
ぶんがっか /文学科/
ぶんき /分岐/文亀;年号(1501-1504)/
ぶんきえき /分岐駅/
ぶんきかいせん /分岐回線/
ぶんきき /分岐器/
ぶんきげんしょう /分岐現象/
ぶんきさき /分岐先/
ぶんきすう /分岐数/
ぶんきせん /分岐線/
ぶんきせんたく /分岐選択/
ぶんきそうち /分岐装置/
ぶんきてん /分岐点/
ぶんきひ /分岐比/
ぶんきぶ /分岐部/
ぶんきめいれい /分岐命令/
ぶんきゅう /文久/分球/
ぶんきょう /文教/文京/
ぶんきょうかんけい /文教関係/
ぶんきょうがくえん /文京学園/
ぶんきょうく /文京区/文教区/
ぶんきょうくみん /文京区民/
ぶんきょうじょう /分教場/
ぶんきょうじょしたんだい /文京女子短大/
ぶんきょうぞく /文教族/
ぶんきょうだい /文教大/
ぶんきょうだいがく /文教大学/
ぶんきょうちょう /文京町/
ぶんきょうぶ /文教部/
ぶんきょく /分極/分局/
ぶんきょくか /分極化/
ぶんきよう /分岐用/
ぶんきよそく /分岐予測/
ぶんきりろん /分岐理論/
ぶんきん /分近/
ぶんきんたかしまだ /文金高島田/
ぶんぎ /分木/文義/
ぶんぎょう /分業/文業/
ぶんぎょうか /分業化/
ぶんぎょうせい /分業制/
ぶんぎょうたいせい /分業体制/
ぶんく /分区/
ぶんぐ /文具/
ぶんぐかん /文具館/
ぶんぐてん /文具店/
ぶんけ /分家/
ぶんけい /文系/文型/
ぶんけいがっか /文系学科/
ぶんけいりけい /文系理系/
ぶんけん /文献/分権/分県/分遣;-隊/文検;[略語]文部省中等学校教員検定試験/
ぶんけんあんない /文献案内/
ぶんけんがく /文献学/
ぶんけんけんさく /文献検索/
ぶんけんさんしょう /文献参照/
ぶんけんしゅう /文献集/
ぶんけんしょうかい /文献紹介/
ぶんけんしりょう /文献資料/
ぶんけんじょうほう /文献情報/
ぶんけんたい /分遣隊/
ぶんけんちず /分県地図/
ぶんけんちょうさ /文献調査/
ぶんけんてき /分権的/
ぶんけんとう /文献等/
ぶんけんなど /文献等/
ぶんけんひょう /文献表/
ぶんけんもくろく /文献目録/
ぶんげい /文芸/文藝/
ぶんげいえいが /文芸映画/
ぶんげいか /文芸家/
ぶんげいがく /文芸学/
ぶんげいがくぶ /文芸学部/
ぶんげいきょうかい /文芸協会;[文学史]/
ぶんげいさくひん /文芸作品/
ぶんげいざ /文芸坐/文芸座/
ぶんげいざっし /文芸雑誌/
ぶんげいし /文芸誌/
ぶんげいしゅんじゅう /文藝春秋;正式名称/文芸春秋;※「文藝春秋」が正式/
ぶんげいしゅんじゅうしゃ /文芸春秋社/
ぶんげいしょ /文芸書/
ぶんげいじだい /文芸時代;新感覚派/
ぶんげいてき /文芸的/
ぶんげいひょうろん /文芸評論/
ぶんげいひょうろんか /文芸評論家/
ぶんげいふっこう /文芸復興;Renaissance/
ぶんげいぶ /文芸部/
ぶんげん /文言/分限/
ぶんげんさいばん /分限裁判/
ぶんこ /文庫/
ぶんこいがい /文庫以外/
ぶんこう /分光/分校/
ぶんこうがく /分光学/
ぶんこうがくてき /分光学的/
ぶんこうき /分光器/
ぶんこうけい /分光計;spectrometer/
ぶんこうこうどけい /分光光度計;spectrophotometer/
ぶんこうそくてい /分光測定/
ぶんこうぞう /文構造/
ぶんこうぶんせき /分光分析/
ぶんこうほう /分光法/
ぶんこうれんせい /分光連星;[天文]spectroscopic binary star/
ぶんこか /文庫化/
ぶんこかん /文庫刊/
ぶんこく /分国/
ぶんこつ /分骨/
ぶんことも /文庫共/
ぶんこばん /文庫版/文庫判/
ぶんこぼん /文庫本/
ぶんこめい /文庫名/
ぶんこもくろく /文庫目録/
ぶんご /豊後/文語/
ぶんごう /文豪/分合/
ぶんごけい /文語形/
ぶんごし /文語詩/
ぶんごすいどう /豊後水道/
ぶんごたい /文語体/
ぶんごたかだ /豊後高田/
ぶんごちょう /文語調/
ぶんごてき /文語的/
ぶんごふう /文語風/
ぶんごぶし /豊後節;[浄瑠璃]/
ぶんごぶん /文語文/
ぶんごぶんぽう /文語文法/
ぶんごほう /文語法/
ぶんごやく /文語訳/
ぶんさい /文才/文彩/
ぶんさく /文作/
ぶんさつ /分冊/
ぶんさん /分散/
ぶんさんか /分散化/
ぶんさんかんきょう /分散環境/
ぶんさんかんけい /分散関係/
ぶんさんかんけいしき /分散関係式/
ぶんさんかんり /分散管理/
ぶんさんかんりほうしき /分散管理方式/
ぶんさんがた /分散型/
ぶんさんきのう /分散機能/
ぶんさんきょうちょう /分散協調/
ぶんさんきょうぶんさんぎょうれつ /分散共分散行列/
ぶんさんきょうゆう /分散共有/
ぶんさんきょうゆうめもり /分散共有メモリ/
ぶんさんけい /分散系;[化学]disperse system/
ぶんさんけいさん /分散計算/
ぶんさんけん /分散研/
ぶんさんこうぞう /分散構造/
ぶんさんざい /分散剤;dispersant/
ぶんさんしすてむ /分散システム/
ぶんさんしょり /分散処理/
ぶんさんしょりかんきょう /分散処理環境/
ぶんさんしょりきのう /分散処理機能/
ぶんさんじんこうちのう /分散人工知能/
ぶんさんせい /分散性/
ぶんさんせいぎょ /分散制御/
ぶんさんだい /分散大/
ぶんさんち /分散値/
ぶんさんてき /分散的/
ぶんさんでんげん /分散電源/
ぶんさんど /分散度/
ぶんさんはいち /分散配置/
ぶんさんひょうげん /分散表現/
ぶんさんぶんせき /分散分析/
ぶんさんへいれつしょり /分散並列処理/
ぶんさんめもり /分散メモリ/
ぶんさんわおん /分散和音/
ぶんざい /分際/
ぶんし /分子;molecule/分詞;[文法]participle/文士;penman/分枝;[植物]branching/分祀;戦犯の-/
ぶんしうんどう /分子運動/
ぶんしかがく /分子化学/
ぶんしかん /分子間/
ぶんしかんりょく /分子間力/
ぶんしきどう /分子軌道/
ぶんしきどうほう /分子軌道法/
ぶんしきどうりろん /分子軌道理論/
ぶんしけい /分子系/
ぶんしけん /分子研/
ぶんしげんし /分子原子/
ぶんしこうがく /分子工学/
ぶんしこうぞう /分子構造/
ぶんしこうぶん /分詞構文/
ぶんししき /分子式/
ぶんししゅうごうたい /分子集合体/
ぶんししんか /分子進化;[生物]molecular evolution/
ぶんししんけいせいぶつがく /分子神経生物学/
ぶんししんどう /分子振動/
ぶんしじょうたい /分子状態/
ぶんしせいぎょ /分子制御/
ぶんしせいぶつがく /分子生物学/
ぶんしせいぶつじょうほう /分子生物情報/
ぶんしせっけい /分子設計/
ぶんしつ /分室/
ぶんしつひんぴん /文質彬彬/
ぶんしでんし /分子電子/
ぶんしでんしこうがく /分子電子工学/
ぶんしどうし /分子同士/
ぶんしどうりょくがく /分子動力学/
ぶんしどけい /分子時計;[生物]molecular clock/
ぶんしないしんどう /分子内振動/
ぶんしめい /分子名/
ぶんしめんえきがく /分子免疫学/
ぶんしもけい /分子模型/
ぶんしゃ /分社/
ぶんしゃか /分社化/
ぶんしゅう /文集/分周/
ぶんしゅうひ /分周比/
ぶんしゅうりつ /分周率/
ぶんしゅく /分宿/
ぶんしゅつ /分出/
ぶんしゅん /文春/
ぶんしゅんぶんこ /文春文庫/
ぶんしゅんまんがしょう /文春漫画賞/
ぶんしょ /文書/分署/分所/
ぶんしょいがい /文書以外/
ぶんしょう /文章/分掌/文相/文正;年号(1466-1467)/
ぶんしょうか /文章化/文章家/
ぶんしょうがたていぎ /文章型定義/
ぶんしょうご /文章語/
ぶんしょうじょう /文章上/
ぶんしょうぜんたい /文章全体/
ぶんしょうだい /文章題/
ぶんしょうちゅう /文章中/
ぶんしょうちゅうしん /文章中心/
ぶんしょうない /文章内/
ぶんしょうないよう /文章内容/
ぶんしょうひょうげん /文章表現/
ぶんしょうひょうげんりょく /文章表現力/
ぶんしょうほう /文章法/
ぶんしょうもんだい /文章問題/
ぶんしょうりかい /文章理解/
ぶんしょうりょう /文章量/
ぶんしょうりょく /文章力/
ぶんしょか /文書化/文書課/
ぶんしょかん /文書館;「もんじょかん」とも/
ぶんしょがぞう /文書画像/
ぶんしょがぞうしょり /文書画像処理/
ぶんしょがたていぎ /文書型定義/
ぶんしょく /文飾/
ぶんしょけい /文書型/
ぶんしょこ /文書庫/
ぶんしょこうかん /文書交換/
ぶんしょこうぞう /文書構造/
ぶんしょさくせい /文書作成/
ぶんしょさくせいかんきょう /文書作成環境/
ぶんしょさくせいちゅう /文書作成中/
ぶんしょしょり /文書処理/
ぶんしょせいしょ /文書清書/
ぶんしょぜんたい /文書全体/
ぶんしょちゅう /文書中/
ぶんしょでんしか /文書電子化/
ぶんしょとが /文書図画/
ぶんしょない /文書内/
ぶんしょぶんるい /文書分類/
ぶんしょへんしゅう /文書編集/
ぶんしょりょく /文書力/
ぶんしりょう /分子量/
ぶんしん /分身/文身;tatoo/聞診/
ぶんじ /文治;年号(1185-90)/文二/文事/文辞/
ぶんじたい /文自体/
ぶんじゃく /文弱/
ぶんじょう /分譲/分乗/
ぶんじょうしゃ /分乗車/
ぶんじょうじゅうたく /分譲住宅/
ぶんじょうち /分譲地/
ぶんじょうまんしょん /分譲マンション/
ぶんじん /文人/
ぶんじんぼっかく /文人墨客/
ぶんすい /分水/
ぶんすいかい /分水界/
ぶんすいれい /分水嶺/
ぶんすう /分数/
ぶんすうしき /分数式/
ぶんせい /文政;年号(1818-1830)/文勢/
ぶんせいせい /文生成/
ぶんせいどう /文盛堂/
ぶんせき /分析/文責/
ぶんせきか /分析家/
ぶんせきかがく /分析化学/
ぶんせきかのう /分析可能/
ぶんせきがく /分析学/
ぶんせきき /分析器/
ぶんせききじ /分析記事/
ぶんせきけっか /分析結果/
ぶんせきしゃ /分析者/文責者/
ぶんせきじっけん /分析実験/
ぶんせきそうち /分析装置/
ぶんせきてき /分析的/
ぶんせきてきしゅほう /分析的手法/
ぶんせきてきていぎ /分析的定義/
ぶんせきてつがく /分析哲学;analytic philosophy/
ぶんせきはんだん /分析判断/
ぶんせきほう /分析法/
ぶんせきほうほう /分析方法/
ぶんせきりょく /分析力/
ぶんせつ /文節;†[文法]clause「連-変換」/分節;†segment.「言語による世界の-」/
ぶんせついどう /文節移動/
ぶんせつぎり /文節切/
ぶんせつすう /文節数/
ぶんせつせい /分節性;articulateness/文節性;?/
ぶんせつちゅう /文節中/分節中/
ぶんせつちょう /文節長/
ぶんせつへんかん /文節変換/
ぶんせん /文選/
ぶんせんどう /文泉堂/
ぶんせんめい /文鮮明/
ぶんぜんたい /文全体/
ぶんそう /分奏/文藻/
ぶんそうおう /分相応/
ぶんそん /分村/分損/
ぶんた /文太;名/
ぶんたい /文体/分隊/
ぶんたいおう /文対応/
ぶんたいし /分隊士/
ぶんたいちょう /分隊長/
ぶんたいろん /文体論;stylistics/
ぶんたん /分担/文旦;ミカン科/
ぶんたんきん /分担金/
ぶんたんしゃ /分担者/
ぶんたんせい /分担制/
ぶんたんはんい /分担範囲/
ぶんたんひょう /分担表/
ぶんたんほうしき /分担方式/
ぶんたんりつ /分担率/
ぶんたんわりあい /分担割合/
ぶんだい /分大/文台/文題/
ぶんだん /分断/分団/文壇/
ぶんだんしょうじ /分段生死;[仏教]六道輪廻/
ぶんち /文治/分地/分置/聞知/
ぶんちゅう /文中;年号(1372-1375)/分注/
ぶんちゅうじょ /分駐所/
ぶんちょう /文鳥/文調/
ぶんちん /文鎮/文珍;人名/
ぶんつう /文通/
ぶんてい /文帝;[中国史](曹丕,楊堅)/
ぶんてん /分店/分点/文展/文典/
ぶんでん /分電/
ぶんでんばん /分電盤/
ぶんとう /文頭/
ぶんとん /分屯/
ぶんどき /分度器/
ぶんにょう /文繞/
ぶんにん /分任/
ぶんのいち /分の一/分の１/
ぶんのう /分納/
ぶんは /分派/
ぶんばい /分売/
ぶんばんごう /文番号/
ぶんぱ /分派;sect/分波;-器/
ぶんぱい /分配/
ぶんぱいかんすう /分配関数/
ぶんぱいき /分配器/
ぶんぱいそく /分配束/
ぶんぱいひ /分配比/
ぶんぱいほうそく /分配法則/
ぶんぱいほうほう /分配方法/
ぶんぱいりつ /分配律/
ぶんぱき /分波器/
ぶんぱん /文範/
ぶんび /文尾/
ぶんぴ /分泌/
ぶんぴつ /分泌;secretion/文筆;writing/分筆;division/
ぶんぴつえき /分泌液/
ぶんぴつか /文筆家/
ぶんぴつきこう /分泌機構/
ぶんぴつぎょう /文筆業/
ぶんぴつせいかつ /文筆生活/
ぶんぴつせん /分泌腺/
ぶんぴつぶつ /分泌物/
ぶんぴぶつ /分泌物/
ぶんふそうおう /分不相応/
ぶんぶ /文武/
ぶんぶくちゃがま /文福茶釜/分福茶釜;童話/
ぶんぶつ /文物/
ぶんぶりょうどう /文武両道/
ぶんぷ /分布/分賦/
ぶんぷかんすう /分布関数/
ぶんぷけいじょう /分布形状/
ぶんぷず /分布図/
ぶんぷちょうさ /分布調査/
ぶんぷとくせい /分布特性/
ぶんぷらんすう /分布乱数/
ぶんべつ /分別/
ぶんべつかいしゅう /分別回収/
ぶんべつけいすう /分別係数/
ぶんべつけっしょう /分別結晶/
ぶんべつしゅうしゅう /分別収集;-にご協力を/
ぶんべん /分娩/
ぶんべんだい /分娩台/
ぶんぺい /文平/
ぶんぼ /分母/
ぶんぼうぐ /文房具/
ぶんぼうぐてん /文房具店/
ぶんぼうぐや /文房具屋/
ぶんぽう /文法/文保;年号(1317-1319)/分封/
ぶんぽうか /文法化/
ぶんぽうかいせき /文法解析/
ぶんぽうきごう /文法記号/
ぶんぽうきじゅつ /文法記述/
ぶんぽうきそく /文法規則/
ぶんぽうこうぞう /文法構造/
ぶんぽうしょ /文法書/
ぶんぽうじこう /文法事項/
ぶんぽうじょう /文法上/
ぶんぽうていぎ /文法定義/
ぶんぽうてき /文法的/
ぶんぽうようご /文法用語/
ぶんぽうりろん /文法理論/
ぶんぽうろん /文法論/
ぶんまつ /文末/
ぶんみつとう /分蜜糖/
ぶんみゃく /文脈/
ぶんみゃくいぞん /文脈依存/
ぶんみゃくいぞんせい /文脈依存性/
ぶんみゃくいぞんぶんぽう /文脈依存文法/
ぶんみゃくこうか /文脈効果/
ぶんみゃくしょり /文脈処理/
ぶんみゃくじゆう /文脈自由/
ぶんみゃくじゆうげんご /文脈自由言語/
ぶんみゃくじゆうぶんぽう /文脈自由文法/
ぶんみゃくじょう /文脈上/
ぶんみゃくじょうほう /文脈情報/
ぶんみゃくてき /文脈的/
ぶんみん /文民/
ぶんみんけいさつ /文民警察/
ぶんみんけいさつかん /文民警察官/
ぶんみんとうせい /文民統制/
ぶんみんほご /文民保護/
ぶんめい /文明;年号(1469-1487)/分明;distinct/文名/
ぶんめいか /文明化/
ぶんめいかいか /文明開化/
ぶんめいこく /文明国/
ぶんめいし /文明史/
ぶんめいしゃかい /文明社会/
ぶんめいじん /文明人/
ぶんめいてき /文明的/
ぶんめいどう /文明堂/
ぶんめいひはん /文明批判/
ぶんめいひひょう /文明批評/
ぶんめいびょう /文明病/
ぶんめいろん /文明論/
ぶんめん /文面/
ぶんめんじょう /文面上/
ぶんや /分野/文屋/
ぶんやかん /分野間/
ぶんやがい /分野外/
ぶんやたんとう /分野担当/
ぶんやぶし /文弥節;[浄瑠璃]/
ぶんやべつ /分野別/
ぶんやめい /分野名/
ぶんゆう /分有/
ぶんよ /分与/
ぶんよう /文葉/
ぶんらく /文楽/
ぶんらくざ /文楽座/
ぶんらん /紊乱/
ぶんり /分離/文理/分利/
ぶんりあん /分離案/
ぶんりか /分離果/
ぶんりかいしゃく /文理解釈/
ぶんりかぜい /分離課税/
ぶんりかのう /分離可能/
ぶんりがた /分離型/
ぶんりき /分離機/分離器/
ぶんりきゅうゆ /分離給油/
ぶんりこうり /分離公理/
ぶんりすう /分離数/
ぶんりせい /分離性/
ぶんりたい /分離帯/
ぶんりだい /文理大/
ぶんりつ /分立/分率/
ぶんりていすう /分離定数/
ぶんりど /分離度/
ぶんりどくりつ /分離独立/
ぶんりのう /分離脳/
ぶんりのうりょく /分離能力/
ぶんりは /分離派/
ぶんりふかのう /分離不可能/
ぶんりふのう /分離不能/
ぶんりぶんかつ /分離分割/
ぶんりほう /分離法/
ぶんりまえ /分離前/
ぶんりもじ /分離文字/
ぶんりもんだい /分離問題/
ぶんりゃく /文暦;年号(1234-1235)/
ぶんりゅう /分流/分留/分溜/
ぶんりゅうき /分流器/
ぶんりょう /分量/分領/
ぶんりょうがい /分量外/
ぶんりょうてき /分量的/
ぶんりょく /分力/
ぶんりよう /分離用/
ぶんるい /分類/
ぶんるいか /分類化/
ぶんるいがく /分類学/
ぶんるいがくしゅう /分類学習/
ぶんるいがくじょう /分類学上/
ぶんるいき /分類器/
ぶんるいきじゅん /分類基準/
ぶんるいぎ /分類木/
ぶんるいぐん /分類群/
ぶんるいけい /分類系/
ぶんるいこうもく /分類項目/
ぶんるいこんなん /分類困難/
ぶんるいさいけん /分類債権/
ぶんるいじょう /分類上/
ぶんるいぜんたい /分類全体/
ぶんるいたいけい /分類体系/
ぶんるいばんごう /分類番号/
ぶんるいふめい /分類不明/
ぶんるいほう /分類法/
ぶんるいほうほう /分類方法/
ぶんるいめい /分類名/
ぶんるいもんだい /分類問題/
ぶんれい /文例/分霊/
ぶんれつ /分裂/分列/
ぶんれつか /分裂果/
ぶんれつこうしん /分列行進/
ぶんれつしき /分列式/
ぶんれつしつ /分裂質/
ぶんれつしょう /分裂症/
ぶんれつせい /分裂性/
ぶんれつそしき /分裂組織/
ぶんれつてき /分裂的/
ぶんれつびょう /分裂病/
ぶんれつまえ /分裂前/
ぶんろく /文禄;年号(1592-1596)/
ぶんろくけいちょうのえき /文禄慶長の役;[日本史]朝鮮出兵(1592-1597)/
ぶんろくのえき /文禄の役;[日本史]朝鮮出兵(1592)/
ぶんわ /文和;年号(1352-1356)/文話/
ぷ /腐/布/符/
ぷーるせい /プール制;料金-,給与-/
ぷーるねつ /プール熱;[医]咽頭結膜熱(PCF). 水泳プールで感染しやすい/
ぷーるびらき /プール開き/
ぷう /風/
ぷく /幅/服/
ぷさい /ψ;psi/Ψ;Psi/
ぷさん /釜山/
ぷしー /ψ;psi/Ψ;Psi/
ぷっしゅがた /プッシュ型/
ぷっしゅしき /プッシュ式/
ぷらいばしーけん /プライバシー権/
ぷらいばしーしんがい /プライバシー侵害/
ぷらざごうい /プラザ合意/
ぷらす /＋/
ぷらすあるふぁ /プラスα/
ぷらすしこう /プラス思考/
ぷらすちっくせい /プラスチック製/
ぷらすちっくばくだん /プラスチック爆弾;plastic bomb/
ぷらすまいなす /±/
ぷらすめん /プラス面/
ぷらすよういん /プラス要因/
ぷらすようそ /プラス要素/
ぷらせおじむ /Pr/Praseodymium/
ぷらとんしゅぎ /プラトン主義;platonism/
ぷらまい /±/
ぷらんくていすう /プランク定数/
ぷらんとゆしゅつ /プラント輸出/
ぷりぺいどしき /プリペイド式/
ぷりんえんき /プリン塩基;[化学]purine base/
ぷりんたい /プリン体/
ぷりんとがら /プリント柄/
ぷりんときばん /プリント基板/
ぷるがた /プル型/
ぷるとにうむ /Pu/Plutonium/
ぷれいちゅう /プレイ中/
ぷれすき /プレス機/
ぷれはぶごや /プレハブ小屋/
ぷろいしき /プロ意識/
ぷろぐらみんぐげんご /プログラミング言語/
ぷろぐらむごうせい /プログラム合成/
ぷろこんじょう /プロ根性/
ぷろしあ /普魯西/
ぷろせすかん /プロセス間/
ぷろせんしゅ /プロ選手/
ぷろそう /プロ相/
ぷろとあくちにうむ /Pa/Protactinium/
ぷろばいだーせきにんほう /プロバイダー責任法/
ぷろぺらき /プロペラ機/
ぷろめちうむ /Pm/Promethium/
ぷろもばん /プロモ盤/
ぷろやきゅう /プロ野球/
ぷろよう /プロ用/
ぷろれすわざ /プロレス技/
ぷろれたりあぶんがく /プロレタリア文学;proletarian litterature/
ぷん /分/
ぷんかん /分間/
ぷんはん /分半/
ぷんまえ /分前/
へ /屁/経/舳;舳先/戸/辺/邊;「辺」の旧字1/邉;「辺」の旧字2/
へーべー /平米/
へい /兵/塀/屏;≒塀/丙;甲乙丙/閉/平/並/幣;貨幣/幤;「幣」の異体字/弊;弊社/蔽;隠蔽/敝;(やぶれる)/斃;斃死/柄;(つか) 横柄/病;(漢音)歌病/炳;あきらか/併;併合/并;≒併/餅;もち/瓶;(漢音) びん/聘;招聘/娉/嬖/睥;睥睨/坪;つぼ/箆;へら/陛;陛下/閇;「閉」の異体字/竝;「並」の旧字/
へい> /閉/平;(「平成」の略) 平11,最判平9・8・18/
へいあん /平安/
へいあんきぞく /平安貴族/
へいあんきょう /平安京/
へいあんこうこう /平安高校/
へいあんじだい /平安時代/
へいあんじんぐう /平安神宮/
へいあんちょう /平安朝/
へいあんどう /平安堂/
へいい /平易/弊衣/
へいいき /閉域/
へいいち /平一/
へいいど /平易度/
へいいはぼう /弊衣破帽/
へいいん /兵員/閉院/
へいえい /兵営/併映;同時上映/
へいえき /兵役/
へいえん /閉園/閉宴/
へいおく /弊屋/
へいおん /平穏/平温;normal temperature/平音/併音/閉音/
へいおんせつ /閉音節/
へいおんぶじ /平穏無事/
へいか /陛下/閉架/平価/兵火/兵科/併科/閉果/併課/
へいかい /閉会/
へいかいあいさつ /閉会挨拶/
へいかいしき /閉会式/
へいかいろ /閉回路/
へいかしき /閉架式/
へいかつ /平滑/
へいかつか /平滑化/
へいかつかいろ /平滑回路/
へいかつきん /平滑筋/
へいかとしょ /閉架図書/
へいかん /閉館/閉管/
へいかんご /閉館後/
へいかんまぎわ /閉館間際/
へいが /平臥/
へいがい /弊害/
へいがく /兵学/
へいがっこう /兵学校/
へいがん /併願/
へいき /兵器/平気/併記;両論-/並記;(単に)並べて書く/兵機/
へいきこ /兵器庫/
へいきしょう /兵器廠/
へいきち /平吉/
へいきばいばい /兵器売買/
へいきゃく /閉脚/
へいきゅう /閉球/
へいきょ /閉居/
へいきょく /平曲/
へいきょくせん /閉曲線/
へいきょくめん /閉曲面/
へいきん /平均/
へいきんいか /平均以下/
へいきんおうとうじかん /平均応答時間/
へいきんか /平均化/
へいきんかいすう /平均回数/
へいきんかぜい /平均課税;averaging taxation/
へいきんかぶか /平均株価/
へいきんきおん /平均気温/
へいきんきょくりつ /平均曲率/
へいきんきょり /平均距離/
へいきんしゅうにゅう /平均収入/
へいきんしゅつりょく /平均出力/
へいきんしんちょう /平均身長/
へいきんしんぷく /平均振幅/
へいきんじじょう /平均二乗/平均2乗/
へいきんじじょうごさ /平均二乗誤差/平均2乗誤差/
へいきんじそく /平均時速/
へいきんじゅみょう /平均寿命/
へいきんじゅんい /平均順位/
へいきんじゆうこうてい /平均自由行程/
へいきんじょうしゃりつ /平均乗車率/
へいきんすいみんじかん /平均睡眠時間/
へいきんそくど /平均速度/
へいきんだい /平均台/
へいきんち /平均値/
へいきんちょう /平均長/
へいきんてき /平均的/
へいきんてん /平均点/
へいきんとくてん /平均得点/
へいきんにっしょうじかん /平均日照時間/
へいきんねんしゅう /平均年収/
へいきんねんれい /平均年齢/
へいきんば /平均場/
へいきんひきょり /平均飛距離/
へいきんひよう /平均費用/
へいきんまちじかん /平均待ち時間/
へいきんりつ /平均律;[音楽]temperament/平均率;average rate?/
へいきんりゅう /平均流/
へいぎょう /閉業/
へいくうかん /閉空間/
へいくかん /閉区間/
へいけ /平家/
へいけい /閉経/
へいけいしき /閉形式/
へいけがに /平家蟹/
へいけだに /平家谷/
へいけつ /併結/
へいけつじ /併結時/
へいけびわ /平家琵琶/
へいけものがたり /平家物語/
へいげい /睥睨/
へいげん /平原/
へいこう /平行;†parallel.「-線」/並行;†concurrent.「-作業」/平衡;†balance.「-を保つ」/閉口/閉校/併行;≒並行/平向/閉項/敝垢/
へいこういどう /平行移動/
へいこうかんかく /平衡感覚/
へいこうがた /平衡型/平行型/並行型/
へいこうぎ /平衡木/
へいこうくかん /並行区間/
へいこうけい /平衡系/
へいこうけいさん /並行計算/
へいこうこう /平行光/
へいこうざいらいせん /並行在来線/
へいこうし /平行視/
へいこうしへんけい /平行四辺形/
へいこうしょり /並行処理/
へいこうしんか /平行進化/並行進化;?/
へいこうじっこう /並行実行/
へいこうじょうたい /平衡状態/
へいこうせい /並行性/
へいこうせいぎょ /並行制御/
へいこうせかい /平行世界/
へいこうせん /平行線;parallel/並行線;並んで走る線路/
へいこうちょう /平行調/
へいこうていすう /平衡定数/
へいこうてき /並行的/
へいこうてん /平衡点/
へいこうど /平行度/並行度/
へいこうどうさ /並行動作/
へいこうはんのう /平衡反応/
へいこうひん /並行品/
へいこうぶんぷ /平衡分布/
へいこうへき /平行壁/
へいこうほう /平行法/
へいこうほうこう /平行方向/
へいこうぼう /平行棒/
へいこうみゃく /平行脈/
へいこうゆにゅう /並行輸入/
へいこうゆにゅうぎょうしゃ /並行輸入業者/
へいこうゆにゅうひん /並行輸入品/
へいこうゆにゅうぶつ /並行輸入物/
へいご /平語/兵語/
へいごう /併合/并合;=併合/
へいごうざい /併合罪/
へいさ /閉鎖/
へいさい /併催;同時開催/併載;同時掲載/
へいさおん /閉鎖音;[音声学]occlusive/
へいさか /閉鎖花;[植物]cleistogamous flower. つぼみのままで開かない。eg.スミレ/
へいさく /平作/平朔/
へいさけい /閉鎖系/
へいさこうじ /閉鎖工事/
へいさしき /閉鎖式/
へいさせい /閉鎖性/
へいさちゅう /閉鎖中/
へいさつ /併殺/
へいさつだ /併殺打/
へいさてき /閉鎖的/
へいさぶ /閉鎖部/
へいざん /閉山/
へいし /兵士/弊誌/平氏/閉止/斃死/瓶子/弊紙/
へいしき /閉式/
へいしたち /兵士達/
へいしゃ /弊社/兵舎/平射/
へいしゃがい /弊社外/
へいしゃぞう /閉写像/
へいしゃない /弊社内/
へいしゃほう /平射砲/
へいしゅ /丙種/兵種/
へいしゅう /弊習/
へいしゅうごう /閉集合/
へいしゅつ /平出/併出/迸出/
へいしょ /閉所/弊所/兵書/
へいしょきょうふしょう /閉所恐怖症/claustrophobia/
へいしん /平身/並進/平信/
へいしんうんどう /並進運動/
へいしんていとう /平身低頭/
へいじ /平時/平治;年号(1159-60)/兵事/平次/
へいじつ /平日/
へいじつあさ /平日朝/
へいじつしんや /平日深夜/
へいじつじょせい /平日女性/
へいじつはんにち /平日半日/
へいじつよう /平日用/
へいじものがたり /平治物語/
へいじゅつ /兵術/
へいじゅん /平準/
へいじゅんか /平準化/
へいじょ /平叙/
へいじょう /平城/平壌/閉場/平常/
へいじょううんてん /平常運転/
へいじょうきょう /平城京/
へいじょうしん /平常心/
へいじょうじ /平常時/
へいじょうてん /平常点/
へいじょぶん /平叙文/
へいじん /敝人/
へいすいめん /平水面/
へいすう /兵数/
へいすけ /平助/平祐/
へいせい /平成;年号(1989-)/平静/兵制/幣制/弊政/
へいせい#ねん /平成#0年/平成#1年/平成#2年/平成#3年/
へいせい#ねんど /平成#0年度/
へいせいいしん /平成維新/
へいせいがんねん /平成元年/
へいせいしょたい /平成書体/
へいせいちくほうてつどう /平成筑豊鉄道/
へいせいちょう /平成町/
へいせいばん /平成版/
へいせいふきょう /平成不況/
へいせかい /閉世界/
へいせき /平積/兵籍/
へいせつ /併設/
へいせん /兵船/
へいぜい /平生/
へいぜいごうじょう /平生業成/
へいぜいてんのう /平城天皇/
へいぜん /平然/炳然;obvious/
へいそ /平素/
へいそう /併走/並走/兵装/兵曹/
へいそうちょう /兵曹長/
へいそく /閉塞/屏息;息を殺す/
へいそくおん /閉塞音;[音声学]occlusive/
へいそくかん /閉塞感/
へいそくじょうたい /閉塞状態/
へいそくぜんせん /閉塞前線/
へいそくもう /閉塞網/
へいそつ /兵卒/
へいそん /併存/並存/
へいぞく /平俗/
へいぞん /併存/並存/
へいたい /兵隊/平体;⇔長体/
へいたいあり /兵隊蟻/
へいたいたち /兵隊達/
へいたく /弊宅/
へいたん /平坦/兵站/平淡/
へいたんか /平坦化/
へいたんせい /平坦性/
へいたんせん /兵站線;補給線/
へいたんち /平坦地/
へいだん /兵団/
へいち /平地/併置/並置/
へいちきょうそう /平地競走/
へいちゅうものがたり /平仲物語/平中物語/
へいちょう /閉庁/兵長/平調/敝腸/
へいちょうび /閉庁日/
へいてい /平定/閉廷/
へいてん /閉店/弊店/
へいてんじ /閉店時/
へいてんせーる /閉店セール/
へいてんちゅう /閉店中/
へいてんまぎわ /閉店間際/
へいとう /平等/弊竇/
へいとうしょうしゅつ /平頭抄出/
へいどく /併読/
へいどん /併呑/
へいない /平内/
へいにん /併任/
へいねつ /平熱/
へいねん /平年/
へいねんさく /平年作/
へいねんち /平年値;normal value. 「-を下回る」/
へいねんなみ /平年並/
へいのうぶんり /兵農分離/
へいはく /幣帛/
へいはち /平八/
へいはちろう /平八郎/
へいはつ /併発/
へいはん /平版/
へいば /兵馬/
へいばい /併売/
へいばよう /兵馬俑/
へいばん /平板/
へいばんか /平板化/
へいび /兵備/
へいふ /敝賦/
へいふう /弊風/
へいふく /平伏/平服/平復/
へいぶ /弊部/
へいぶん /平文/平分/
へいへい /平平/平々/
へいへいぼんぼん /平々凡々/平平凡凡/
へいべい /平米/
へいほう /平方/兵法/閉包/
へいほう> /平方;(square) -(ミリ|センチ|キロ)メートル,-マイル,-数/
へいほうこん /平方根/
へいほうじょうよ /平方剰余/
へいほうすう /平方数;[数学]square number. 1,4,9,16.../
へいほうせい /閉包性/
へいほうめーとる /平方メートル/平方米/
へいぼん /平凡/
へいぼんしゃ /平凡社;[出版社名]www.heibonsha.co.jp/
へいぼんしゃはっこう /平凡社発行/
へいまく /閉幕/
へいみゃく /平脈/
へいみん /平民/
へいみんしゃ /平民社;[日本史]幸徳秋水の結社/
へいみんしんぶん /平民新聞;[日本史]平民社の機関紙/
へいめい /平明/
へいめん /平面/
へいめんきか /平面幾何/
へいめんきょう /平面鏡/
へいめんきょくせん /平面曲線/
へいめんけい /平面型/平面系/
へいめんこうさ /平面交差/
へいめんこうせい /平面構成/
へいめんしゃしん /平面写真/
へいめんじょう /平面上/平面状/
へいめんず /平面図/
へいめんずけい /平面図形/
へいめんせい /平面性/
へいめんてき /平面的/
へいめんど /平面度/
へいめんは /平面波/
へいめんばん /平面板/
へいもつ /幣物/
へいもん /閉門/
へいや /平野/
へいやぶ /平野部/
へいゆ /平癒/
へいゆう /併有/
へいよう /併用/並用;?/
へいようきょう /併用橋/
へいようばし /併用橋/
へいよん /海永/
へいらん /兵乱/
へいり /弊履;破れた靴/敝履;=弊履/
へいりつ /並立/
へいりつご /並立語/
へいりつじょし /並立助詞/
へいりつせい /並立制/
へいりゃく /兵略/
へいりょういき /閉領域/
へいりょく /兵力/
へいりょくさ /兵力差/
へいりょくしよう /兵力使用/
へいりょくぞうきょう /兵力増強/
へいりょくてき /兵力的/
へいれつ /並列/
へいれつか /並列化/
へいれつがた /並列型/
へいれつき /並列機/
へいれつきおく /並列記憶/
へいれつけい /並列系/
へいれつけいさん /並列計算/
へいれつけいさんき /並列計算機/
へいれつげんご /並列言語/
へいれつこうぶん /並列構文/
へいれつごうせい /並列合成/
へいれつしき /並列式/
へいれつしょり /並列処理/
へいれつしょりぎじゅつ /並列処理技術/
へいれつしょりげんご /並列処理言語/
へいれつじっこう /並列実行/
へいれつじょし /並列助詞/
へいれつすいろん /並列推論/
へいれつせい /並列性/
へいれつせつぞく /並列接続/
へいれつたんさく /並列探索/
へいれつてき /並列的/
へいれつど /並列度/
へいれつどうさ /並列動作/
へいれつぶんさん /並列分散/
へいれつぶんさんがた /並列分散型/
へいれつぶんさんしょり /並列分散処理/
へいれつほうしき /並列方式/
へいれつましん /並列マシン/
へいれつもでる /並列モデル/
へいれつろんり /並列論理/
へいれつろんりがた /並列論理型/
へいろ /閉路/平炉/
へいろく /併録/
へいわ /平和/
へいわいじ /平和維持/
へいわいじかつどう /平和維持活動/
へいわいじぐん /平和維持軍/
へいわかいけつ /平和解決/
へいわかくめい /平和革命/
へいわかつどう /平和活動/
へいわきねんこうえん /平和記念公園/
へいわきねんどう /平和祈念堂/
へいわきょうてい /平和協定/
へいわぎていしょ /平和議定書/
へいわけんぽう /平和憲法/
へいわこうえん /平和公園/
へいわしゅぎ /平和主義/
へいわしゅぎしゃ /平和主義者/
へいわしょう /平和賞/
へいわじま /平和島/
へいわじょうこう /平和条項/
へいわじょうやく /平和条約/
へいわだい /平和台/
へいわてき /平和的/
へいわてきかいけつ /平和的解決/
へいわてきしゅだん /平和的手段/
へいわとう /平和党/
へいわどおり /平和通り/
へいわふどうさん /平和不動産/
へいわぼけ /平和ボケ/
へいわりよう /平和利用/
へいわろん /平和論/
へえ /兵衛/
へおんきごう /ヘ音記号/
へき /壁/癖/碧/僻/璧/劈/甓/躄/辟/闢/日置/
へきあつ /壁厚/
へきうん /碧雲/
へきえき /辟易/へき易/
へきえん /僻遠/
へきかい /碧海/劈開/
へきかん /壁間/
へきが /壁画/
へきがん /碧眼/壁龕/
へきぎょく /碧玉/
へきくう /碧空/
へきけん /僻見/
へきこういき /壁孔域/
へきざい /壁材/
へきしょ /壁書/
へきしょく /碧色/
へきじゃ /辟邪/
へきすい /碧水/
へきすう /僻陬/
へきせつ /僻説/
へきせん /壁泉;wall fountain. 「ライオンの-」/
へきそん /僻村/
へきたい /壁体/
へきたん /碧潭/
へきち /僻地/
へきちゅう /壁中/
へきちゅうしょ /壁中書/
へきとう /劈頭/
へきない /壁内/
へきなん /碧南/
へきはく /璧帛/
へきめん /壁面/
へきめんせん /壁面線/
へきらく /碧落;天空/
へきるり /碧瑠璃/
へきれき /霹靂/
へきろん /僻論/
へくと /hecto;[SI接頭語]h,10^2/
へくとぐらむ /瓸/
へくとめーとる /粨/
へくとりっとる /竡/
へぐらじま /舳倉島/
へぐり /平群/
へこおび /兵児帯/
へこみ /凹み/
へご /竹畚/
へさき /舳先/舳/
へしきや /平敷屋/
へそ /臍/巻子/綜麻/
へそくり /臍繰り/
へそのお /臍の緒/
へそまがり /へそ曲がり/ヘソ曲がり/臍曲がり/臍曲り/
へた /下手/蔕;果物の-/戸田/蒂;異体字/
へたくそ /下手糞/
へたっぴ /下手っぴ/
へたんちょう /ヘ短調/
へだ /戸田/
へだたり /隔/隔たり/
へだて /隔て/
へちま /糸瓜/
へちょうちょう /ヘ長調/
へっぴりごし /屁っ放り腰/へっぴり腰/
へつ /丿/暼/
へつらい /諂い/
へど /嘔吐/反吐/
へな /埴/
へなちょこ /埴猪口/
へのかっぱ /屁の河童;何のこれしき-/
へのこ /陰核/
へのじ /への字;口を-に結ぶ/
へび /蛇/巳;[十二支]6/
へびーきゅう /ヘビー級;[ボクシング]86kg超/
へびいちご /蛇苺/
へびくち /蛇口/
へびざ /蛇座;Serpens(Ser)/
へびつかいざ /蛇遣い座;Ophiuchus(Oph)/
へびどく /蛇毒/
へびどし /巳年/
へぶらいご /ヘブライ語;イスラエルの公用語。ユダヤの言語。/
へぶらいもじ /ヘブライ文字/
へぼんしき /ヘボン式/
へみ /逸見/
へや /部屋/廳/廰/
へやかず /部屋数/
へやぎ /部屋着/
へやさがし /部屋探し/
へやしょく /部屋食/
へやじゅう /部屋中/
へやすう /部屋数/
へやずみ /部屋住み/
へやぜんたい /部屋全体/
へやだい /部屋代/
へやづき /部屋付き/
へやばき /部屋履き/
へやわり /部屋割り/部屋割/
へら /篦/箆;「篦」の異体字/
へらい /戸来/
へらくれすざ /ヘラクレス座;Hercules(Her)/
へらさぎ /篦鷺/
へらずぐち /減らず口/
へり /縁/辺/邊;「辺」の旧字1/邉;「辺」の旧字2/
へりうむ /He/Helium/
へりくつ /屁理屈/
へるくれすざ /ヘルクレス座;Hercules(Her)/
へるすじょう /ヘルス嬢/
へん /変/辺/編;(あむこと)/篇;(あまれたもの)/片/返/遍;遍歴/偏;人偏/扁;扁平/翩;翩翻/蝙;蝙蝠/褊;褊狭/諞/騙;騙取,だま・す/胼;たこ/駢;駢儷体/貶;毀誉褒貶/變;「変」の旧字/邊;「辺」の旧字1/邉;「辺」の旧字2/
へん> /変;変ニ長調/
へんあい /偏愛/
へんあつ /変圧/
へんあつき /変圧器/
へんい /変異;†mutation.「突然-」/変位;†displacement/変移;†移り変わり/偏位;偏り/偏移;shift/変イ;[音楽]As/偏倚/
へんいがた /変異型/
へんいき /変域/
へんいせい /変位性/変移性/
へんいせいぶん /変位成分/
へんいたん /変異譚/
へんいたんちょう /変イ短調/
へんいちょうちょう /変イ長調/
へんうん /片雲/
へんえい /片影/
へんえき /変易/
へんえん /辺縁/
へんえんけい /辺縁系/
へんおん /変温/変音/
へんおんどうぶつ /変温動物/
へんか /変化/返歌/
へんかい /変改/
へんかきゅう /変化球/
へんかく /変革/偏角/変格/
へんかくかつよう /変格活用/
へんかぐあい /変化具合/
へんかけい /変化形/
へんかず /変化図/
へんかせい /変化性/
へんかてん /変化点/
へんかはんい /変化範囲/
へんかひょう /変化表/
へんかぶぶん /変化部分/
へんかぶん /変化分/
へんかりつ /変化率/
へんかりょう /変化量/
へんかん /変換/返還/
へんかんかてい /変換過程/
へんかんかのう /変換可能/
へんかんかんすう /変換関数/
へんかんき /変換器/変換機/
へんかんきそく /変換規則/
へんかんきのう /変換機能/
へんかんぎじゅつ /変換技術/
へんかんぎょう /変換行/
へんかんぎょうれつ /変換行列/
へんかんけーぶる /変換ケーブル/
へんかんけい /変換系/
へんかんけいすう /変換係数/
へんかんけっか /変換結果/
へんかんこうがく /変換工学/
へんかんこうほ /変換候補/
へんかんこうりつ /変換効率/
へんかんこねくた /変換コネクタ/
へんかんご /変換後/返還後/
へんかんさき /変換先/
へんかんし /変換史/
へんかんしき /変換式/
へんかんしっぱい /変換失敗/
へんかんしゅほう /変換手法/
へんかんしょり /変換処理/
へんかんじ /変換時/
へんかんじしょ /変換辞書/
へんかんじょうたい /変換状態/
へんかんすう /偏関数/
へんかんせいど /変換精度/
へんかんそうさ /変換操作/
へんかんそうち /変換装置/
へんかんそくど /変換速度/
へんかんそふと /変換ソフト/
へんかんたいしょう /変換対象/
へんかんたんい /変換単位/
へんかんち /変換値/
へんかんちゅう /変換中/
へんかんてーぶる /変換テーブル/
へんかんてん /変換点/
へんかんのうりょく /変換能力/
へんかんひょう /変換表/
へんかんふのう /変換不能/
へんかんぶ /変換部/
へんかんぶぶん /変換部分/
へんかんほう /変換法/
へんかんほうしき /変換方式/
へんかんほうほう /変換方法/
へんかんまえ /変換前/返還前/
へんかんよう /変換用/
へんかんりつ /変換率/
へんかんれつ /変換列/
へんがく /変額;⇔定額/扁額/
へんがくほけん /変額保険/
へんがん /片岩;schist/
へんき /偏倚/偏奇/
へんきごう /変記号;♭/
へんきゃく /返却/
へんきゃくきげん /返却期限/
へんきゃくじかん /返却時間/
へんきゃくち /返却値/
へんきゃくび /返却日/
へんきゅう /返球/扁球/
へんきょう /辺境/偏狭/
へんきょうけいび /辺境警備/
へんきょく /編曲/偏極/変局/
へんきょくか /編曲家/
へんきょくしゃ /編曲者/
へんきょくしょう /編曲賞/
へんきょくたんとう /編曲担当/
へんきょくてん /変曲点/
へんきょくばん /編曲版/
へんきん /返金/
へんきんしょり /返金処理/
へんきんたいしょう /返金対象/
へんくつ /偏屈/
へんぐう /片隅;=かたすみ/辺隅;片田舎/
へんけい /変形/変型/扁形/辺形/
へんけいきん /変形菌/
へんけいご /変形後/
へんけいじざい /変形自在/
へんけいせい /変形性/
へんけいせいかんせつしょう /変形性関節症;[医]osteoarthritis/
へんけいたい /変形体/
へんけいどうぶつ /扁形動物;[生物]platyhelminth/
へんけいはんけい /変形半径/
へんけいばん /変形版/
へんけいぶんぽう /変形文法;[言語]transformational grammer/
へんけいほう /変形法/
へんけいろうどうじかんせい /変形労働時間制/
へんけん /偏見/
へんけんし /偏見視/
へんけんてき /偏見的/
へんげ /変化/
へんげもの /変化物;歌舞伎の-/
へんげん /片言/変幻/
へんげんじざい /変幻自在/
へんげんせきご /片言隻語/
へんこ /偏固/
へんこう /変更/偏光;†polarisation.「-プリズム」/偏向;†tendency.「政治的-」/変光;-星/変項;variable/
へんこうあん /変更案/
へんこういらい /変更依頼/
へんこうか /変更可/
へんこうかしょ /変更箇所/
へんこうかのう /変更可能/
へんこうくかん /変更区間/
へんこうこう /偏向光/
へんこうご /変更後/
へんこうさき /変更先/
へんこうさぎょう /変更作業/
へんこうし /偏光子/
へんこうしょ /変更書/
へんこうしんせい /変更申請/
へんこうしんせいしょ /変更申請書/
へんこうしんせいちゅう /変更申請中/
へんこうじ /変更時/
へんこうじゆう /変更自由/
へんこうじょうほう /変更情報/
へんこうせい /変光星/
へんこうせいかんそく /変光星観測/
へんこうせいぎょ /変更制御/
へんこうそち /変更措置/
へんこうたいしょう /変更対象/
へんこうちゅう /変更中/
へんこうてん /変更点/
へんこうとくせい /偏光特性/
へんこうとどけ /変更届/
へんこうないよう /変更内容/
へんこうばん /偏光板/変更版/
へんこうひょうじ /変更表示/
へんこうび /変更日/
へんこうふかのう /変更不可能/
へんこうふのう /変更不能/
へんこうぶぶん /変更部分/
へんこうぶん /変更分/
へんこうほうどう /偏向報道/
へんこうほうほう /変更方法/
へんこうまえ /変更前/
へんこうまく /偏光膜/
へんこうよう /変更用/
へんこうようきゅう /変更要求/
へんこうようし /変更用紙/
へんこうりょう /変更料/変更量/
へんこうりれき /変更履歴/
へんご /片語/
へんごう /辺合/
へんさ /偏差/騙詐/
へんさい /返済/変災/辺際/
へんさち /偏差値/
へんさん /編纂/偏衫/
へんさんしゃ /編纂者/
へんざい /偏在;かたよって存在/遍在;あまねく存在/辺材/
へんざいせい /遍在性/
へんし /変死/返詩/
へんしたい /変死体/
へんしつ /変質/偏執;=へんしゅう/
へんしつきょう /偏執狂/
へんしつきょうてき /偏執狂的/
へんしつしゃ /変質者/
へんしつしょう /偏執症/
へんしつてき /変質的/偏執的/
へんしゃ /編者/
へんしゃぞう /偏写像/
へんしゃちゅう /編者注/
へんしゅ /変種/騙取/
へんしゅう /編集/編輯;≒編集/編修;国史の-/偏執;paranoia/扁舟;boat/
へんしゅういいん /編集委員/
へんしゅういいんかい /編集委員会/
へんしゅういいんちょう /編集委員長/
へんしゅういと /編集意図/
へんしゅういん /編集員/
へんしゅうかい /編集会/
へんしゅうかのう /編集可能/
へんしゅうかんきょう /編集環境/
へんしゅうがめん /編集画面/
へんしゅうがわ /編集側/
へんしゅうき /編集機/
へんしゅうきのう /編集機能/
へんしゅうきょう /偏執狂/
へんしゅうきょうてき /偏執狂的/
へんしゅうきょく /編集局/
へんしゅうきょくちょう /編集局長/
へんしゅうけっか /編集結果/
へんしゅうけん /編集権/
へんしゅうこうい /編集行為/
へんしゅうこうき /編集後記/
へんしゅうご /編集後/
へんしゅうさぎょう /編集作業/
へんしゅうしつ /編集室/
へんしゅうしゃ /編集者/編輯者/
へんしゅうしゃかいぎ /編集者会議/
へんしゅうしゃちゅう /編集者注/
へんしゅうしゅかん /編集主幹/
へんしゅうしゅにん /編集主任/
へんしゅうしょう /偏執症/
へんしゅうじ /編集時/
へんしゅうじょう /編集上/
へんしゅうずみ /編集済/
へんしゅうせいど /編集精度/
へんしゅうせきにんしゃ /編集責任者/
へんしゅうそしき /編集組織/
へんしゅうたいしょう /編集対象/
へんしゅうちゅう /編集中/
へんしゅうちょう /編集長/
へんしゅうちょさく /編集著作/
へんしゅうちょさくけん /編集著作権/
へんしゅうちょさくぶつ /編集著作物/
へんしゅうてき /偏執的/
へんしゅうとちゅう /編集途中/
へんしゅうないよう /編集内容/
へんしゅうにん /編集人/
へんしゅうはっこうにん /編集発行人/
へんしゅうばん /編集盤/
へんしゅうびょう /偏執病/
へんしゅうぶ /編集部/
へんしゅうぶへん /編集部編/
へんしゅうほうしん /編集方針/
へんしゅうまえ /編集前/
へんしゅうもの /編集物/
へんしゅうや /編集屋/
へんしゅうよう /編集用/
へんしょ /返書/
へんしょう /返照/
へんしょく /変色/偏食/
へんしん /返信/変身/偏心;eccentricity.「モーターの-」/変心;こころがわり。「恋人の-」/遍身;全身/
へんしんきのう /変身機能/
へんしんご /変身後/
へんしんさき /返信先/
へんしんじ /返信時/変身時/
へんしんちゅう /変身中/
へんしんのうりょく /変身能力/
へんしんまえ /変身前/
へんしんよう /返信用/
へんしんようきって /返信用切手/
へんしんようふうとう /返信用封筒/
へんしんりつ /偏心率/
へんじ /返事/片時/変事/返辞/
へんじこ /偏自己/
へんじまち /返事待/
へんじゃ /編者/
へんじゅつ /編述/
へんじょう /返上/変状;(地盤|住宅)の-/遍照/辺上/変成/
へんじょうか /編上靴;あみあげぐつ/
へんじょうこんごう /遍照金剛;[仏教]大日如来/
へんじん /変人/變人;「変」旧字/
へんすう /変数/
へんすうかんきょう /変数環境/
へんすうかんすう /変数関数/
へんすうきごう /変数記号/
へんすうけい /変数型/
へんすうじょうけん /変数条件/
へんすうじょうほう /変数情報/
へんすうせんげん /変数宣言/
へんすうそくばく /変数束縛/
へんすうていぎ /変数定義/
へんすうてんかい /変数展開/
へんすうひょう /変数表/
へんすうめい /変数名/
へんずつう /偏頭痛/
へんせい /編成/変性;†degeneration.「でんぷんの-」/編制;†軍隊・団体の編成/変成;†transform.「-岩」/変声;声変わり/遍性;?/
へんせいがん /変成岩/
へんせいき /変声期/
へんせいさよう /変成作用;[化学]metamorphism/
へんせいぜんたい /編成全体/
へんせいたん /編成端/
へんせいたんい /編成単位/
へんせいちゅう /編成中/
へんせいちょう /編成長/
へんせいばんごう /編成番号/
へんせいひょう /編成表/
へんせいふ /変成譜/
へんせいふう /偏西風/
へんせいへんこう /編成変更/
へんせいもの /編成物/
へんせきうん /片積雲/
へんせつ /変節/変説/
へんせつかん /変節漢/
へんせん /変遷/
へんせんこう /変旋光/
へんせんし /変遷史/
へんそ /編組/辺素/
へんそう /返送/変装/変奏;[音楽]variation/変相/
へんそううん /片層雲/
へんそうきげん /返送期限/
へんそうきょく /変奏曲/
へんそうさき /返送先/
へんそうじ /返送時/
へんそうよう /返送用/
へんそうりょう /返送料/
へんそうりょうきん /返送料金/
へんそく /変速;†-ギア/変則;†irregular/
へんそくき /変速機/
へんそくきこう /変速機構/
へんそくきのう /変速機能/
へんそくじ /変速時/
へんそくせいのう /変速性能/
へんそくそうさ /変速操作/
へんそくちゅう /変速中/
へんそくてき /変則的/
へんそくひ /変速比/
へんそせん /編組線/
へんぞう /変造/
へんたい /変態/編隊/変体;anomalous.「-仮名」/
へんたいおんがく /変態音楽/
へんたいがな /変体仮名/
へんたいこうい /変態行為/
へんたいごと /編隊毎/
へんたいせいよく /変態性欲/
へんたいてき /変態的/
へんたいひこう /編隊飛行/
へんたいやろう /変態野郎/
へんち /辺地/
へんちゅう /編注/
へんちょ /編著/
へんちょう /変調/偏重/変長/
へんちょうおん /変調音/
へんちょうき /変調器/
へんちょうそくど /変調速度/
へんちょうど /変調度/
へんちょうは /変調波/
へんちょうほうしき /変調方式/
へんつう /変通/
へんてこ /変梃/変てこ/変テコ/
へんてつ /変哲/
へんてん /変転/
へんでん /変電/返電;返信の電報/
へんでんしょ /変電所/
へんでんしょない /変電所内/
へんでんじょ /変電所/
へんと /変ト/
へんとう /返答/扁桃/
へんとうえん /扁桃炎/
へんとうせん /扁桃腺/
へんとたんちょう /変ト短調/
へんとちょうちょう /変ト長調/
へんど /辺土/
へんどう /変動/
へんどうおん /変動音/
へんどうかん /変動感/
へんどうかんすう /偏導関数/
へんどうきんり /変動金利/
へんどうしょとく /変動所得/
へんどうせい /変動性/変動制/
へんどうそうば /変動相場/
へんどうそうばせい /変動相場制/
へんどうちゅう /変動中/
へんどうはば /変動幅/
へんどうひ /変動費/
へんどうりょう /変動量/
へんに /変ニ/
へんにたんちょう /変ニ短調/
へんにちょうちょう /変ニ長調/
へんにゅう /編入/
へんにゅうがく /編入学/
へんにゅうしかく /編入資格/
へんにゅうしけん /編入試験/
へんにゅうせい /編入生/
へんねん /編年/
へんねんし /編年史/
へんねんたい /編年体/
へんのう /返納/
へんのうゆ /片脳油/
へんは /変ハ/
へんはたんちょう /変ハ短調/
へんはちょうちょう /変ハ長調/
へんばい /変倍/反閇/
へんばいりつ /変倍率/
へんぱ /偏波;polarised wave/偏頗;unfair/
へんぱい /変敗/返杯/返盃/
へんびぶん /偏微分/∂/
へんびぶんけいすう /偏微分係数/
へんびぶんほうていしき /偏微分方程式/
へんびょうし /変拍子/
へんぴ /辺鄙/
へんぴん /返品/
へんぴんかのう /返品可能/
へんふくちょう /変復調/
へんぶん /変分/
へんぶんほう /変分法/
へんぷ /返付/
へんぷく /蝙蝠;bat/辺幅;うわべ/
へんへ /変ヘ/
へんへたんちょう /変ヘ短調/
へんへちょうちょう /変ヘ長調/
へんぺい /扁平/
へんぺいそく /扁平足/偏平足/
へんぺいりつ /偏平率/
へんぺん /片々;†(trivial) -たる問題/辺々;†[数学]両辺/翩々/
へんほ /変ホ/
へんほたんちょう /変ホ短調/
へんほちょうちょう /変ホ長調/
へんぼいん /変母音;[音声学]umlaut/
へんぼう /変貌/偏旁/
へんぽう /返報/偏法/
へんぽん /返本/翩翻/
へんぽんりつ /返本率/
へんまひ /片麻痺;[医]hemiplegia/
へんまもう /偏摩耗/
へんまん /遍満/
へんみ /逸見/辺見/
へんみん /辺民/
へんむ /片務/
へんむけいやく /片務契約/
へんめい /変名/
へんやく /編訳/変約/
へんよう /変容/変様;様相(のみ)が変わること/遍用/
へんらん /変乱/
へんりょう /変量/
へんりん /片鱗/
へんれい /返礼;お返し/返戻;return.「-金」/
へんれいきん /返戻金/
へんれき /遍歴/
へんろ /遍路/変ロ/
へんろたんちょう /変ロ短調/
へんろちょうちょう /変ロ長調/
べ /部/辺/倍/邊;「辺」の旧字1/邉;「辺」の旧字2/
べーじゅいろ /ベージュ色/
べーじゅじ /ベージュ地/
べーた /β;beta/Β;Beta/
べーたかろちん /βカロチン/
べーたせん /β線/ベータ線/
べーたは /β波/
べーたばん /β版/
べーたほうかい /β崩壊/
べーちぇっとびょう /ベーチェット病;[医]Behcet's disease/
べい /米/塀/
べい> /米/
べいえい /米英/
べいえいが /米映画/
べいえいぐん /米英軍/
べいえいらん /米英蘭/
べいおう /米欧/
べいか /米菓;煎餅などのこと。/米価/米貨/
べいかしんぎかい /米価審議会/
べいかんたい /米艦隊/
べいがわ /米側/
べいぎかい /米議会/
べいくうぼ /米空母/
べいぐん /米軍/
べいぐんあいて /米軍相手/
べいぐんき /米軍機/
べいぐんきち /米軍基地/
べいぐんきちあと /米軍基地跡/
べいぐんしせつない /米軍施設内/
べいぐんしゅくしゃ /米軍宿舎/
べいぐんとうちか /米軍統治下/
べいぐんへいし /米軍兵士/
べいぐんよう /米軍用/
べいけい /米系/
べいこく /米国/米穀/
べいこくえいが /米国映画/
べいこくがい /米国外/
べいこくがた /米国型/
べいこくがわ /米国側/
べいこくきかく /米国規格/
べいこくきしゃ /米国記者/
べいこくぎかい /米国議会/
べいこくけい /米国系/
べいこくけんぽう /米国憲法/
べいこくこくぼうそうしょう /米国国防総省/
べいこくご /米国語/
べいこくさい /米国債/
べいこくさん /米国産/
べいこくしき /米国式/
べいこくしゅどう /米国主導/
べいこくしよう /米国仕様/
べいこくしんぞうきょうかい /米国心臓協会/
べいこくじん /米国人/
べいこくせい /米国製/
べいこくせいふ /米国政府/
べいこくせんしゅ /米国選手/
べいこくだい /米国大/
べいこくだいひょう /米国代表/
べいこくてき /米国的/
べいこくない /米国内/
べいこくないせん /米国内線/
べいこくなんぶ /米国南部/
べいこくはつ /米国発/
べいこくばん /米国版/米国盤/
べいこくほうじん /米国法人/
べいこくほうめん /米国方面/
べいこくほんど /米国本土/
べいこくぼうしょう /米国防省/
べいこくみん /米国民/
べいご /米語/
べいごま /貝独楽/
べいさく /米作/
べいさくのうか /米作農家/
べいさん /米産/
べいさんち /米産地/
べいし /米紙/
べいしきしゅうきゅう /米式蹴球/
べいしゃ /米車/
べいしゅう /米収/
べいしゅうきこう /米州機構;OAS/
べいしゅん /米春/
べいしょく /米食/
べいじゅ /米寿;88歳/
べいじょういん /米上院/
べいじん /米人/
べいせいけん /米政権/
べいせいせんそう /米西戦争/
べいせいふ /米政府/
べいそ /米ソ/
べいたいしかん /米大使館/
べいだいがく /米大学/
べいだいとうりょう /米大統領/
べいちゅう /米中/米駐/
べいちょう /米朝/
べいてい /米帝/
べいどる /米ドル/
べいはん /米飯/
べいはんきゅうしょく /米飯給食/
べいばく /米麦/
べいふん /米粉/
べいへい /米兵/
べいべつ /袂別/
べいほんごく /米本国/
べいろ /米ロ/米露/
べえ /兵衛/
べえた /β/
べき /羃;^/冪;「羃」の異体字/巾;「羃」の代用字/冖;(わかんむり)/幎;(とばり)/汨;汨水(湖南省の川)/覓;(もとめる)/
べきしゅうごう /冪集合/
べきじょう /べき乗/冪乗/巾乗/羃乗/
べきすう /冪数/
べく /可/
べくさかずき /可杯/
べくとるか /ベクトル化/
べくとるかいせき /ベクトル解析;[数学]vector analysis/
べくとるくうかん /ベクトル空間;[数学]vector space. 線形空間/
べくとるせき /ベクトル積;[数学]vector product. 外積/
べくとるち /ベクトル値/
べくとるば /ベクトル場/
べくとるりょう /ベクトル量;[物理]vector quantity/
べじぇきょくせん /ベジェ曲線/
べじえきょくせん /ベジエ曲線/
べすと# /ベスト#0/
べすとてん /ベスト10/
べすとでんき /ベスト電器;[企業名]/
べすとばん /ベスト盤/
べた /下手/
べたきそ /ベタ基礎/
べたぐみ /べた組み/
べたなぎ /べた凪/
べたぬり /ベタ塗り/べた塗り/
べたぼめ /べた褒め/べた賞め/
べたぼれ /べた惚れ/ベタ惚れ/
べたゆき /べた雪/
べっか /別科/別家;=べっけ/
べっかい /別解/
べっかく /別格/
べっかん /別館/別巻/
べっき /別記/
べっきょ /別居/
べっけ /別家/
べっけい /別掲/
べっけん /別件/瞥見/
べっけんこん /別乾坤/
べっけんたいほ /別件逮捕/
べっこ /別個/別箇/
べっこう /別項/鼈甲/別稿/
べっこうあめ /鼈甲飴/
べっこういろ /鼈甲色/
べっこん /別懇/
べっさつ /別冊/
べっさつごう /別冊号/
べっさつたからじま /別冊宝島/
べっさつてき /別冊的/
べっさつふろく /別冊付録/
べっさつほうせき /別冊宝石/
べっさつもの /別冊物/
べっし /別紙/蔑視/別使/
べっしつ /別室/
べっしやま /別子山/
べっしゅ /別種/別趣/
べっしゅう /別集/
べっしょ /別所/別書/
べっしょう /別称/蔑称/別証/
べっせい /別姓/別製/
べっせかい /別世界/
べっせき /別席/
べっせつ /別節/
べっせん /別線/
べっそ /別訴/
べっそう /別荘/別送/
べっそうち /別荘地/
べっそうひん /別送品/
べったい /別体/
べったく /別宅/
べったらづけ /べったら漬け/
べっちゃく /別役/
べっちゅう /別注/
べっちん /別珍/
べってい /別定/別邸/
べってん /別添/
べってんち /別天地/
べってんようしき /別添様式/
べっと /別途/
べっとう /別当/
べっとうや /別当家/
べっときょうぎ /別途協議/
べっとぎろん /別途議論/
べっとこうにゅう /別途購入/
べっとさんしょう /別途参照/
べっとそうだん /別途相談/
べっととうこう /別途投稿/
べっとにゅうしゅ /別途入手/
べっとひつよう /別途必要/
べっとひょうじ /別途表示/
べっとふたん /別途負担/
べっとれんらく /別途連絡/
べっぱ /別派/
べっぴつ /別筆/
べっぴょう /別表/
べっぴん /別嬪;美人/別品;秀れた品,また=別嬪/
べっぷ /別府/
べっぷう /別封/
べっぷちょう /別府町;地名/
べっぽう /別法/別報/
べっぽん /別本/
べつ /別/蔑;蔑視/韈;(たび)/瞥;一瞥/鼈;鼈甲/
べつ> /別;別日程,別ファイル/
べつあつかい /別扱い/
べつあつらえ /別誂え;特注/
べつあん /別案/
べつい /別異/
べついけん /別意見/
べついん /別院/
べつうちゅう /別宇宙/
べつうり /別売/別売り/
べつえん /別宴/
べつかい /別海/
べつかいけい /別会計/
べつかいひ /別会費/
べつかんり /別管理/
べつがいしゃ /別会社/
べつがいねん /別概念/
べつがく /別学;⇔共学/
べつがっこう /別学校/
べつがめん /別画面/
べつきかく /別規格/
べつきじ /別記事/
べつきじさんしょう /別記事参照/
べつぎ /別儀/別義/
べつぎょう /別行/別業/
べつぎょうしゅ /別業種/
べつくち /別口/
べつけいえい /別経営/
べつけいしき /別形式/
べつけいとう /別系統/
べつけいやく /別契約/
べつけいゆ /別経由/
べつけいろ /別経路/
べつげん /別言/
べつこう /別項;別の項目/別稿/
べつこうどう /別行動/
べつご /別語/
べつごう /別号/
べつさくひん /別作品/
べつしほん /別資本/
べつしゃしゅ /別車種/
べつしょうひん /別商品/
べつしょり /別処理/
べつしんごう /別信号/
べつしんぱん /別審判/
べつじ /別事/別字/別辞;別れの言葉/
べつじげん /別次元/
べつじたて /別仕立て/
べつじゅうしょ /別住所/
べつじょ /蔑如/
べつじょう /別状;(かわった状態) 命に-はない/別条;(かわったこと)/
べつじょけん /別除権/
べつじん /別人/
べつじんかく /別人格/
べつじんぶつ /別人物/
べつすじ /別筋/
べつず /別図/
べつずり /別刷/別刷り/
べつずりだい /別刷代/
べつせかい /別世界/
べつせっけい /別設計/
べつせんめい /別線名/
べつそしき /別組織/
べつそんざい /別存在/
べつたいけい /別体系/
べつたいしき /別体式/
べつだい /別大/
べつだいまいにち /別大毎日/
べつだて /別建て/
べつだん /別段/
べつだんたい /別団体/
べつだんよきん /別段預金;勘定科目/
べつてんち /別天地/
べつでん /別伝/
べつとうこう /別投稿/
べつとうひょう /別投票/
べつどうたい /別働隊/別動隊;=別働隊/
べつどり /別録り/
べつに /別に/
べつにゅうじょう /別入場/
べつのう /別納/
べつばい /別売/
べつばら /別腹;甘い物は―/
べつばんぐみ /別番組/
べつばんごう /別番号/
べつびん /別便/
べつふ /別布/
べつぶんしょ /別文書/
べつぶんや /別分野/
べつべつ /別々/
べつべや /別部屋/
べつほうこう /別方向/
べつま /別間/
べつみや /別宮/
べつみょう /別名/
べつむね /別棟/
べつめい /別名/別命/
べつめいあて /別名宛/
べつめいれい /別命令/
べつめん /別面/
べつもじ /別文字/
べつもの /別物/
べつもんだい /別問題/
べつやく /別役/
べつよう /別様/
べつようそ /別要素/
べつり /別離/
べつりょうきん /別料金/
べつりょうきんたいけい /別料金体系/
べつるい /別涙/
べつれっしゃ /別列車/
べつろく /別録/
べつろせん /別路線/
べつわく /別枠/
べとなむご /ベトナム語;ベトナムの公用語/
べとなむせんそう /ベトナム戦争/
べに /紅/
べにいろ /紅色/
べにうこん /紅鬱金/
べにえ /紅絵/
べにお /紅緒/
べにがら /紅殻/
べにくじらだん /紅鯨団/
べにこ /紅粉/
べにざけ /紅鮭/
べにざら /紅皿/
べにしゃけ /紅鮭/
べにしょうが /紅生姜/紅生薑/
べにじゃけ /紅鮭/
べにじゃけいろ /紅鮭色/
べにぞめ /紅染/
べにたけ /紅茸/
べにづる /紅鶴/
べにてんぐたけ /紅天狗茸/
べにはぎ /紅萩/
べにばな /紅花/
べにばないんげん /紅花隠元/
べにばなつみうた /紅花摘み唄/
べにばなゆ /紅花油/
べにばやし /紅林/
べにふで /紅筆/
べにまる /紅丸/
べにむらさき /紅紫/
べにむらさきいろ /紅紫色/
べにやいた /ベニヤ板/
べねちあは /ベネチア派;[美術] scuola veneziana (Giottoなど)/
べびーよう /ベビー用/
べびーようひん /ベビー用品/
べふ /別府/
べふちょう /別府町;地名/
べみん /部民/
べや /部屋/
べら /倍良;[魚]wrasse/遍羅;=倍良/
べらぼう /篦棒;当て字/箆棒;当て字,「篦」異体字/
べらんめえくちょう /べらんめえ口調;てやんでぇ、こん畜生のこんこんちきめ/
べり /縁/
べりりうむ /Be/Beryllium/
べるぎー /白耳義/
べるけん /ベル研/
べるさいゆきゅうでん /ベルサイユ宮殿/
べるさいゆじょうやく /ベルサイユ条約;[世界史]第一次世界大戦の講和条約(1919)/
べるぬじょうやく /ベルヌ条約/
べるりん /伯林;Berlin/
べれーぼう /ベレー帽/
べん /弁/便/勉/遍;(連濁)/辮;辮髪/辨;(弁別の)「弁」の旧字/辧;「辨」の異体字/瓣;(花弁の)「弁」の旧字/辯;(弁舌の)「弁」の旧字/冕;冕冠/卞/抃/汳;「抃」の異体字/宀/湎/眄;左顧右眄/娩;分娩/鞭;先鞭/采;?/
べんい /便意/便衣;普段着/
べんいたい /便衣隊/
べんえき /便益/
べんかい /弁解/
べんかん /弁官/弁韓/冕冠/
べんがく /勉学/
べんき /便器/
べんきょう /勉強/
べんきょうか /勉強家/
べんきょうかい /勉強会/
べんきょうきかんちゅう /勉強期間中/
べんきょうじかん /勉強時間/
べんきょうちゅう /勉強中/
べんきょうづくえ /勉強机/
べんきょうねっしん /勉強熱心/
べんきょうぶそく /勉強不足/
べんきょうべや /勉強部屋/
べんきょうほう /勉強法/
べんきょうほうほう /勉強方法/
べんきょうよう /勉強用/
べんぎ /便宜/
べんぎさいりょう /便宜裁量/
べんぎしゅぎ /便宜主義;opportunism/
べんぎじょう /便宜上/
べんぎせい /便宜性/
べんぎちせきせん /便宜置籍船/
べんぎてき /便宜的/
べんけい /弁慶/
べんげい /眄睨/
べんこ /便壺/
べんこう /弁口/弁巧/
べんご /弁護/
べんごがわ /弁護側/
べんごし /弁護士/
べんごしかい /弁護士会/
べんごしひよう /弁護士費用/
べんごしほう /弁護士法/
べんごだん /弁護団/
べんごにん /弁護人/
べんごりょう /弁護料/
べんさい /弁済/弁才/
べんざ /便座/
べんざいてん /弁財天/
べんざかばー /便座カバー/
べんし /弁士/
べんしき /弁識/
べんしつ /弁室/
べんしゅつ /娩出/
べんしょう /弁償/
べんしょうがく /弁証学;apologetics/
べんしょうきん /弁償金/
べんしょうほう /弁証法/
べんしょうほうてきろんりがく /弁証法的論理学/
べんしんろん /弁神論/
べんじょ /便所/
べんじょそうじ /便所掃除/
べんず /ベン図;Venn diagram/
べんぜつ /弁舌/
べんぜんかん /ベンゼン環;[化学]benzene ring/
べんそう /便槽/
べんぞう /勉三/
べんたつ /鞭撻/
べんち /胼胝/弁知/
べんちいり /ベンチ入り/
べんちうら /ベンチ裏/
べんちゅう /鞭虫/
べんつう /便通/
べんつぼ /便壺/
べんてん /弁天/
べんてんさま /弁天様/
べんてんじま /弁天島/
べんてんちょう /弁天町/
べんとう /弁当/
べんとうがいしゃ /弁当会社/
べんとうじさん /弁当持参/
べんとうだい /弁当代/
べんとうばこ /弁当箱/
べんとうぶくろ /弁当袋/
べんとうや /弁当屋/
べんとうりょう /弁当料/
べんなん /弁難/
べんばく /弁駁/
べんぱつ /弁髪/辮髪/
べんぴ /便秘/
べんぴしょう /便秘症/
べんぴやく /便秘薬/
べんべつ /弁別/
べんべついき /弁別閾;differential threshold/
べんべつげん /弁別限/
べんべつてき /弁別的/
べんべつのうりょく /弁別能力/
べんべん /便々/
べんぽう /便法/
べんまく /弁膜/
べんむ /弁務;-官/
べんむかん /弁務官/
べんめい /弁明/
べんもう /鞭毛/
べんもううんどう /鞭毛運動/
べんらん /便覧/
べんり /便利/弁理/
べんりきのう /便利機能/
べんりこうし /弁理公使/
べんりし /弁理士/
べんりちょう /便利帳/便利帖/
べんりひん /便利品/
べんりや /便利屋/
べんりゅう /冕旒/
べんれい /勉励/
べんろん /弁論/
べんろんしゅぎ /弁論主義/
べんろんたいかい /弁論大会/
べんろんぶ /弁論部/
ぺ /屁/
ぺーじ /頁/
ぺーじじょう /ページ上/
ぺーじすう /ページ数/頁数/
ぺーじない /ページ内/
ぺーじばんごう /ページ番号/
ぺーすとじょう /ペースト状/
ぺい /平/閉/併/蔽/閇;「閉」の異体字/北;bei/
ぺいじ /頁/
ぺえ /北;bei/
ぺえじ /頁/
ぺがさすざ /ペガサス座;Pegasus(Peg)/
ぺがすすざ /ペガスス座;Pegasus(Peg)/
ぺき /北/
ぺきん /北京/
ぺきんげんじん /北京原人/
ぺきんご /北京語/
ぺきんだいがく /北京大学;中国の名門校/
ぺきんだっく /北京ダック/
ぺきんにっぽう /北京日報/
ぺきんりょうり /北京料理/
ぺけ /×/
ぺけぺけ /××/
ぺすときん /ペスト菌;plague/
ぺた /peta;[SI接頭語]P,10^15/
ぺっとや /ペット屋/
ぺっとよう /ペット用/
ぺてんし /ペテン師/
ぺとりさら /ペトリ皿/
ぺとりざら /ペトリ皿;petri dish/
ぺぷちどけつごう /ペプチド結合;[生物]peptide bind/
ぺるー /祕魯/祕露/
ぺるしあ /波斯/
ぺるしあご /ペルシア語/
ぺるしあせんそう /ペルシア戦争;BC492-BC480/
ぺるしゃご /ペルシャ語;Persian/
ぺるしゃじゅうたん /ペルシャ絨毯/
ぺるしゃねこ /ペルシャ猫;Persian cat/
ぺるしゃわん /ペルシャ湾/
ぺるせうすざ /ペルセウス座;Perseus(Per)/
ぺるむき /ペルム紀;[地質年代]Permian. 2900-2450万年前/
ぺろぽねそすせんそう /ペロポネソス戦争;BC431-BC404/
ぺん /片/辺/遍;(連濁) 一遍,十遍/編;(連濁)/篇;(連濁) 第三篇/邊;「辺」の旧字1/邉;「辺」の旧字2/
ぺんが /ペン画;pen-and-ink/
ぺんがた /ペン型/
ぺんさき /ペン先/
ぺんしゅうじ /ペン習字;美子ちゃん/
ぺんじ /ペン字/
ぺんじく /ペン軸;万年筆の-/
ぺんたて /ペン立て/
ぺんときしろんあこう /Pentoxylidae/
ぺんぺんぐさ /ペンペン草/ぺんぺん草/
ほ /帆/穂/補/歩/保/火;(古訓)火群/舗;店舗/鋪;≒舗/舖;「舗」の旧字/輔;輔佐/捕;逮捕/圃;圃場/堡;橋頭堡/葆/畝;うね/浦;うら/甫;杜甫/哺;哺乳/匍;匍匐前進/葡;葡萄酒/埔/脯;ほじし/餔;(くらう)/鯆;イルカ,サバ/黼;(縫取り)/蒲;蒲公英/逋;にげる/穗;「穂」の旧字(人名用漢字)/
ほーこー /火鍋/
ほーていらおゆい /河底撈魚/
ほーむらんおう /ホームラン王/
ほーら /和了;[麻雀]/
ほーるこうか /ホール効果/
ほーろーなべ /ホーロー鍋/
ほあし /帆足/
ほあん /保安/
ほあんか /保安課/
ほあんかん /保安官/
ほあんきじゅん /保安基準/
ほあんしゅにん /保安主任/
ほあんしょぶん /保安処分/
ほあんじょう /保安上/
ほあんせつび /保安設備/
ほあんそうち /保安装置/
ほあんたい /保安隊/
ほあんちょう /保安庁/
ほあんぶ /保安部/
ほあんぶいん /保安部員/
ほあんぶひん /保安部品/
ほあんぼう /保安帽;helmet/
ほあんよう /保安用/
ほあんよういん /保安要員/
ほあんりん /保安林/
ほい /補遺/本意/
ほいく /保育/哺育;乳などを与え育てる/
ほいくえん /保育園/
ほいくえんじ /保育園児/
ほいくか /保育科/
ほいくき /保育器/
ほいくし /保育士/
ほいくしせつ /保育施設/
ほいくしつ /保育室/
ほいくしゃ /保育者/保育社;[出版社名]www.hoikusha.co.jp/
ほいくしょ /保育所/
ほいくしょしょくいん /保育所職員/
ほいくしょにゅうしょ /保育所入所/
ほいくじょ /保育所/
ほいくよさん /保育予算/
ほいくりょう /保育料/
ほいこーろー /回鍋肉/
ほいこうろう /回鍋肉/
ほいだ /穂井田/
ほいっぽ /歩一歩/
ほいつ /捕逸/
ほいるやき /ホイル焼き/
ほいろ /焙炉;お茶用/
ほう /方/法/砲/報/邦;邦楽/放;放出/倣;模倣/抛;抛棄/包;包囲/庖;(くりや)庖丁/抱;抱擁/泡;水泡/胞;細胞/飽;飽和/匏;ひさご/咆;咆哮/垉;(いわゆる幽霊漢字)/炮;炮烙/焙;焙烙/疱;「皰」の異体字/皰;面皰(にきび)/苞;つと/袍;上衣/麭;麺麭(パン)/鞄;かばん/芳;芳香/訪;訪問/彷;彷徨/枋;まゆみ/舫;もやい/魴;(おしきうお)/髣;髣髴/磅;pond,pound/膀;膀胱/棚;たな/崩;崩壊/朋;朋輩/萌;萌芽/堋;あずち/弸/硼;硼酸/繃;繃帯(=包帯)/萠;「萌」の異体字(人名用漢字)/鵬;おおとり/鳳;おおとり(のオス)/俸;年俸/奉;奉仕/捧;抱腹絶倒/棒;(漢音) ぼう/逢;(あ・う)逢着/峰;最高峰/峯;「峰」の旧字(人名用漢字)/縫;裁縫/蓬;よもぎ/蜂;(はち)養蜂/鋒;(切っ先)/烽;のろし/篷;とま/呆;痴呆/保;たも・つ/褒;褒美/襃;「褒」の異体字/褓;襁褓/彭;彭湃(=澎湃)/澎;澎湃/怦/泙/蔀;しとみ/鴇;トキ/封;封建/烹;割烹/幇;幇助/抔;など/琺;琺瑯/迸;ほとばし・る/豊;豊富/豐;「豊」の旧字/宝;宝庫/寳;「宝」の異体字/寶;「宝」の旧字/勹;つつみがまえ/匚;はこがまえ/瀑;瀑布(ばくふ)/朴;ほお?/
ほう> /訪/邦/
ほうあん /保安;年号(1120-1124)/法案/奉安/
ほうあんか /法案化/
ほうあんせいりつ /法案成立/
ほうあんていしゅつ /法案提出/
ほうあんでん /奉安殿/
ほうい /方位/包囲/法衣/胞衣;=えな/
ほういかいぼう /法医解剖/
ほういかく /方位角/
ほういがく /法医学/
ほういがくきょうしつ /法医学教室/
ほういき /法域/
ほういけん /放医研/
ほういさ /方位差/
ほういじしゃく /方位磁石/
ほういじしん /方位磁針/
ほういせん /包囲戦/
ほういち /芳一/
ほういつ /放逸/
ほういもう /包囲網/
ほういん /法印/宝印/
ほうえ /法会/法衣/胞衣;=えな/
ほうえい /放映/宝永;年号(1704-11)/泡影/訪英/
ほうえいきかん /放映期間/
ほうえいきんし /放映禁止/
ほうえいけん /放映権/
ほうえいけんりょう /放映権料/
ほうえいご /放映後/
ほうえいじ /放映時/
ほうえいじかん /放映時間/
ほうえいじき /放映時期/
ほうえいじゅん /放映順/
ほうえいじょうきょう /放映状況/
ほうえいちいき /放映地域/
ほうえいちゅう /放映中/
ほうえいちゅうし /放映中止/
ほうえいちょくご /放映直後/
ほうえいとうじ /放映当時/
ほうえいにちじ /放映日時/
ほうえいび /放映日/
ほうえいぶん /放映分/
ほうえいまえ /放映前/
ほうえいよう /放映用/
ほうえいりょう /放映料/
ほうえいわすう /放映話数/
ほうえき /法益/
ほうえきのほう /縫腋の袍/
ほうえつ /法悦/
ほうえん /保延;年号(1135-1141)/方円/砲煙/豊艶/
ほうえんだんう /砲煙弾雨/
ほうおう /鳳凰/法王;Pope/法皇;出家した天皇/訪欧/鳳王;?/
ほうおうざ /鳳凰座;Phoenix(Phe)/
ほうおうちょう /法王庁;Curia/
ほうおうどう /鳳凰堂/
ほうおく /蓬屋/
ほうおん /報恩/
ほうか /放火;arson/法科/砲火;gunfire.「-を交える」/放課/邦貨;￥/烽火;のろし/法家;韓非子など/放下/蜂窩;beehive/邦家;国家/砲架/法貨;法定貨幣/
ほうかい /崩壊/法界/抱懐/崩潰/崩解/
ほうかいいん /法界院/
ほうかいけいれつ /崩壊系列/
ほうかいご /崩壊後/
ほうかいしゃく /法解釈/
ほうかいじ /法界寺/
ほうかいじょうたい /崩壊状態/
ほうかいず /崩壊図/
ほうかいせい /法改正/
ほうかいせき /方解石/
ほうかいていすう /崩壊定数/
ほうかいねつ /崩壊熱/
ほうかいまえ /崩壊前/
ほうかいりんき /法界悋気/
ほうかいれい /崩壊例/
ほうかく /方格/
ほうかこうぎん /放歌高吟/
ほうかご /放課後/
ほうかざい /放火罪/
ほうかしきえん /蜂窩織炎/
ほうかじけん /放火事件/
ほうかだいがくいん /法科大学院;[新語]law school/
ほうかだて /邦貨建/
ほうかつ /包括/
ほうかついぞう /包括遺贈/
ほうかついにんじょう /包括委任状/
ほうかつきょうぎ /包括協議/
ほうかつざいさん /包括財産/
ほうかつしょうけい /包括承継/
ほうかつせいど /包括制度/
ほうかつてき /包括的/
ほうかつめんきょ /包括免許/
ほうかはん /放火犯/
ほうかん /奉還/訪韓/砲艦/宝冠/幇間/法官/宝鑑/
ほうかんがいこう /砲艦外交/
ほうかんげきたく /抱関撃柝/
ほうかんしょう /宝冠章/
ほうかんじょう /法感情/
ほうが /邦画/萌芽/芳賀;姓/奉賀;-新年/奉加;寺の造営のための寄進/萠芽;「萌」異体字(人名用漢字)/
ほうがい /法外/方外;†out of bound.「-の士」/
ほうがいねん /法概念/
ほうがく /方角/邦楽/法学/放学/
ほうがくか /法学科/
ほうがくけい /邦楽系/
ほうがくしゃ /法学者/
ほうがくちがい /方角違い/
ほうがくぶ /法学部/
ほうがくぶしゅっしんしゃ /法学部出身者/
ほうがっか /法学科/
ほうがっき /邦楽器/
ほうがてき /胞芽的/
ほうがん /包含/判官/方眼/砲丸/砲眼/
ほうがんかんけい /包含関係/
ほうがんし /方眼紙/
ほうがんせい /包含性/
ほうがんなげ /砲丸投げ/
ほうがんびいき /判官贔屓/
ほうき /法規/放棄/箒/蜂起/伯耆;鳥取県西部/芳紀;女性の年齢/宝亀;年号(770-781)/抛棄;≒放棄/宝器/法器/帚/菷;「帚」の異体字/彗;彗星/
ほうきかんれい /法規慣例/
ほうきがみ /箒神/
ほうきぎ /箒木/
ほうきぐさ /箒草/
ほうきさいりょう /法規裁量/
ほうきじあい /放棄試合;[野球]forfeited game/
ほうきせい /法規制/
ほうきはん /法規班/
ほうきぼし /箒星/彗星/ほうき星/
ほうきゃく /訪客/
ほうきゅう /俸給/
ほうきょう /豊胸/豊凶/法橋/豊頬/奉教/
ほうきょういんとう /宝篋印塔/
ほうきょうじゅつ /豊胸術/
ほうきょうにん /奉教人/
ほうきりゅう /伯耆流/
ほうきん /砲金/宝金/
ほうぎょ /崩御/鮑魚/
ほうぎょく /宝玉/
ほうぎん /邦銀;日本の銀行/放吟/
ほうぐ /法具/反故/
ほうけい /包茎/方形/法経/法系/
ほうけいしゅじゅつ /包茎手術/
ほうけいは /方形波/
ほうけん /封建/宝剣/奉献/
ほうけんしゃかい /封建社会/
ほうけんしゅぎ /封建主義;feudalism/
ほうけんじだい /封建時代/
ほうけんせい /封建制/封建性/
ほうけんてき /封建的/
ほうげ /放下/
ほうげい /奉迎/
ほうげき /砲撃/崩撃/
ほうげきしゅ /砲撃手/
ほうげきせん /砲撃戦/
ほうげん /方言/放言/保元;年号(1156-59)/法源/法眼/法諺/
ほうげんがく /方言学/
ほうげんちりがく /方言地理学/
ほうげんのらん /保元の乱/
ほうげんものがたり /保元物語/
ほうこ /宝庫/
ほうこう /方向/芳香/彷徨/奉公;service/咆哮/砲口/放校/砲熕;大砲/奉行;=ぶぎょう/
ほうこうあわせ /方向合わせ/
ほうこういどう /方向移動/
ほうこうおんち /方向音痴/
ほうこうかく /方向角/
ほうこうかん /方向感/
ほうこうかんかく /方向感覚/
ほうこうきん /縫工筋/
ほうこうこてい /方向固定/
ほうこうざい /芳香剤/
ほうこうしじき /方向指示器/方向指示機;?/
ほうこうしゅう /芳香臭/
ほうこうしゅうせい /方向修正/
ほうこうじ /方広寺/
ほうこうせい /方向性/芳香性/
ほうこうぞく /芳香族;[化学]/
ほうこうぞくかごうぶつ /芳香族化合物;[化学]aromatic/
ほうこうだ /方向舵/
ほうこうていい /方向定位/
ほうこうてき /方向的/
ほうこうてんかん /方向転換/
ほうこうにん /奉公人/
ほうこうへんかん /方向変換/
ほうこうべつ /方向別/
ほうこうまく /方向幕/
ほうこうゆ /芳香油/
ほうこく /報告;report/報国;尽忠-/豊国/邦国;state(s)/奉告/封国/
ほうこくかい /報告会/
ほうこくき /報告記/
ほうこくきじ /報告記事/
ほうこくぎむ /報告義務/
ほうこくしゃ /報告者/
ほうこくしゅう /報告集/
ほうこくしょ /報告書/
ほうこくじこう /報告事項/
ほうこくひょう /報告票/
ほうこくぶん /報告文/
ほうこくぶんしょ /報告文書/
ほうことう /澎湖島/
ほうこん /方今/
ほうご /法語;[仏教]/邦語;Japanese/放語/
ほうごう /縫合;suture/抱合;conjugation/法号;[仏教]/
ほうごうご /抱合語;[言語]incorporating language/
ほうごうじゅつ /縫合術/
ほうさい /放哉;俳人/奉斎/朋斎/
ほうさか /逢坂/
ほうさく /方策/豊作/
ほうさくびんぼう /豊作貧乏/
ほうさん /放散/ホウ酸/硼酸;H3BO3/
ほうさんちゅう /放散虫/
ほうざ /砲座/
ほうざい /包材/
ほうざわ /寶澤/
ほうし /奉仕/法師/胞子/奉祀;まつる/芳志/放恣/包子;パオズ/方士/奉伺;伺い申し上げる/褒詞/
ほうしかつどう /奉仕活動/
ほうしき /方式/法式;作法/
ほうしきかん /方式間/
ほうしきけん /方式研/
ほうしきけんとう /方式検討/
ほうしきしゅぎ /方式主義/
ほうしきじょう /方式上/
ほうしきへんかん /方式変換/
ほうししゃ /奉仕者/
ほうしたい /胞子体/
ほうしちゅう /胞子虫;[生物]sporozoan/
ほうしちゅうるい /胞子虫類;[生物]Sporozoa/
ほうしちょうだ /封豕長蛇/
ほうしのう /胞子嚢/
ほうしひん /奉仕品/
ほうしゃ /放射/報謝/硼砂;borax/砲車/
ほうしゃあつ /放射圧/
ほうしゃおん /放射音/
ほうしゃか /放射化/
ほうしゃかいがく /法社会学/
ほうしゃかいへん /放射壊変/
ほうしゃかっせい /放射活性/
ほうしゃき /放射器/
ほうしゃきど /放射輝度/
ほうしゃきん /放射菌;=放線菌/
ほうしゃぎり /放射霧/
ほうしゃくじ /宝積寺/
ほうしゃけい /放射計;radiometer/
ほうしゃげん /放射源/
ほうしゃこう /放射光/
ほうしゃじょう /放射状/
ほうしゃせい /放射性/
ほうしゃせいかくしゅ /放射性核種/
ほうしゃせいかごうぶつ /放射性化合物/
ほうしゃせいげんそ /放射性元素/
ほうしゃせいこうかぶつ /放射性降下物/
ほうしゃせいどういたい /放射性同位体/
ほうしゃせいはいきぶつ /放射性廃棄物/
ほうしゃせいぶっしつ /放射性物質/
ほうしゃせん /放射線/
ほうしゃせんか /放射線科/
ほうしゃせんけんきゅうしつ /放射線研究室/
ほうしゃせんげん /放射線源/
ほうしゃせんしょうい /放射線照射/
ほうしゃせんしょうがい /放射線障害/
ほうしゃせんしょり /放射線処理/
ほうしゃせんじっけん /放射線実験/
ほうしゃせんそくてい /放射線測定/
ほうしゃせんたい /放射線帯/
ほうしゃせんたいさく /放射線対策/
ほうしゃせんちりょう /放射線治療/
ほうしゃせんひばく /放射線被曝/
ほうしゃせんりょうほう /放射線療法/
ほうしゃそうしょう /放射相称/
ほうしゃそくてい /放射測定/
ほうしゃそしき /放射組織/
ほうしゃたいりゅうへいこう /放射対流平衡/
ほうしゃち /放射値/
ほうしゃてん /放射点/
ほうしゃとくせい /放射特性/
ほうしゃねつ /放射熱/
ほうしゃのう /放射能/
ほうしゃのうおせん /放射能汚染/
ほうしゃのうそくてい /放射能測定/
ほうしゃのうひばく /放射能被曝/
ほうしゃのうもれ /放射能漏れ/
ほうしゃりょう /放射量/
ほうしゃれいきゃく /放射冷却/
ほうしゅ /宝珠/法主/砲手/
ほうしゅう /報酬/豊州;豊前・豊後/
ほうしゅういいんかい /報酬委員会;委員会等設置会社の取締役会内に設置される委員会/
ほうしゅうせいきゅうけん /報酬請求権/
ほうしゅく /奉祝/
ほうしゅつ /放出/法出/
ほうしゅつおん /放出音;[音声学]ejective/
ほうしゅつかてい /放出過程/
ほうしゅつきゅうしゅう /放出吸収/
ほうしゅつめん /放出面/
ほうしゅつりゅうし /放出粒子/
ほうしゅつりょう /放出量/
ほうしゅやま /宝珠山/
ほうしゅん /芳春/
ほうしょ /法書;law books/奉書;命令書/報書;report/邦書;Japanese books/方所/芳書/方処/倣書/
ほうしょう /報奨;†reward and encourage.「定住-金」/褒章;†medal,「紫綬-」/報償;†compensation.「損害を-する」/褒賞;†prize.「受賞者への-」/法相;法務大臣/宝生/放縦;ほうじゅう/報賞;†prize and reward/奉唱/法性;[仏教]/宝商/
ほうしょうきん /報奨金;†reward.「功労者への-」/報償金;†compensation.「被害者への-」/
ほうしょうじ /宝生寺/
ほうしょうひ /報償費/
ほうしょうめい /褒賞名/
ほうしょうりゅう /宝生流/
ほうしょがみ /奉書紙/
ほうしょく /宝飾/飽食/奉職/
ほうしょくだんい /飽食暖衣;ぬくぬく/
ほうしょくひん /宝飾品/
ほうしよう /胞子葉/
ほうしん /方針/放心/疱疹/砲身/芳信;your letter/芳心;親切心/庖疹;?/
ほうしんけってい /方針決定/
ほうしんしょ /方針書/
ほうしんじょうたい /放心状態/
ほうしんてんかん /方針転換/
ほうしんのう /法親王;[日本史]/
ほうしんへんこう /方針変更/
ほうじ /法事/邦字/報時/宝治;年号(1247-1249)/捧持/
ほうじし /邦字紙/
ほうじちゃ /焙じ茶/
ほうじゅ /宝珠/
ほうじゅう /放縦;気まま/放銃;[麻雀]/放縱;「縦」旧字/
ほうじゅく /豊熟/
ほうじゅつ /砲術;artillery/法術;方法／法運用／陰陽師の術/方術;方法／方士の術/
ほうじゅつちょう /砲術長/
ほうじゅん /芳醇;香り高く味良い。「-なワイン」/豊潤;豊かで潤った。「-な土地」/芳潤;芳しく潤った/
ほうじょ /幇助/ほう助/
ほうじょう /豊穣;豊かにみのる。「五穀-」/豊饒;豊かで多い。『-の海』/北条/法帖;書道の手本/方丈;四畳半/法条/方城;地名,福岡/北條;「条」旧字/褒状;≒賞状/芳情;親切/宝条;人名/方乗/豊穰;「穣」旧字(人名用漢字)/蓬生;?/
ほうじょうえ /放生会;[仏教]陰暦8.15/
ほうじょうき /方丈記;(1212) 鴨長明/
ほうじょうきたい /胞状奇胎/
ほうじょうけ /北条家/
ほうじょうし /北条氏/
ほうじょうじ /法成寺/
ほうじょうそううん /北条早雲;1432-1519/
ほうじょうちょう /北条町/
ほうじょざい /幇助罪/
ほうじょはん /幇助犯;accessory/
ほうじん /法人;corporation/邦人;Japanese/方陣/報身/
ほうじんいん /法人印/
ほうじんか /法人化/
ほうじんかいいん /法人会員/
ほうじんかく /法人格/
ほうじんさま /法人様/
ほうじんしょとく /法人所得/
ほうじんじぎょうぜい /法人事業税/
ほうじんぜい /法人税/
ほうじんぜいほう /法人税法/
ほうじんちょさく /法人著作/
ほうじんなど /法人等/
ほうじんぶつ /報身仏/
ほうじんほう /法人法/
ほうじんめい /法人名/
ほうすい /放水/豊水/烹炊/
ほうすいき /豊水期/
ほうすいしゃ /放水車/
ほうすいろ /放水路/
ほうすう /鳳雛/砲数/
ほうすけ /保介/
ほうすん /方寸/
ほうず /方図/
ほうせ /法施;[仏教]/
ほうせい /法制;legislation.「有事-」/法政;law and politics/縫製/方正;品行-/砲声/
ほうせいか /法制化/
ほうせいきょく /法制局/
ほうせいし /法制史;法制度の歴史/
ほうせいしんぎかい /法制審議会/
ほうせいだい /法政大/
ほうせいだいがく /法政大学/
ほうせいだいこう /法政大工/
ほうせいど /法制度/
ほうせいにこう /法政二高/
ほうせいび /法整備/
ほうせき /宝石/
ほうせきしょう /宝石商/
ほうせきてん /宝石店/
ほうせきばこ /宝石箱/
ほうせきや /宝石屋/
ほうせきるい /宝石類/
ほうせつ /包摂;[論理]subsumption/抱接;[生物]amplexus/包接;[化学]clathrate/
ほうせつかごうぶつ /包接化合物/
ほうせん /法線/芳泉/豊泉/砲戦/奉先/烹鮮/
ほうせんいん /宝泉院/
ほうせんか /鳳仙花/
ほうせんがくえん /宝仙学園/
ほうせんきん /放線菌;[生物]actinomycete/
ほうせんべくとる /法線ベクトル/
ほうせんほうこう /法線方向/
ほうぜん /宝前/封禅/
ほうぜんじ /法善寺;大阪ミナミの名所/
ほうそ /硼素/ホウ素/彭祖;700歳/柞;=ははそ/B/Boron/
ほうそう /放送/包装/法曹/法相/疱瘡/奉送/法曽/蜂巣/
ほうそういがい /放送以外/
ほうそうえいせい /放送衛星/
ほうそうえんちょう /放送延長/
ほうそうかい /法曹界/
ほうそうかいし /放送開始/
ほうそうかんけい /放送関係/
ほうそうがた /放送型/
ほうそうききてん /放送機器展/
ほうそうきざい /放送機材/
ほうそうきゅうし /放送休止/
ほうそうきょう /放送響/
ほうそうきょうかい /放送協会/
ほうそうきょく /放送局/
ほうそうきょくめい /放送局名/
ほうそうきょくよう /放送局用/
ほうそうきんし /放送禁止/
ほうそうきんしようご /放送禁止用語/
ほうそうぎじゅつ /放送技術/
ほうそうぎょうかい /放送業界/
ほうそうけいたい /放送形態/
ほうそうけん /放送権/
ほうそうけんりょう /放送権料/
ほうそうげき /放送劇/
ほうそうこうきょうがくだん /放送交響楽団/
ほうそうさっか /放送作家/
ほうそうさんぎょう /放送産業/
ほうそうし /包装紙/
ほうそうしきえん /蜂巣織炎/
ほうそうしつ /放送室/
ほうそうしゅうはすう /放送周波数/
ほうそうしゅうりょう /放送終了/
ほうそうしゅうりょうご /放送終了後/
ほうそうしゅうりょうじ /放送終了時/
ほうそうしゅっぱん /放送出版/
ほうそうしょう /放送賞/
ほうそうじ /放送時/
ほうそうじかん /放送時間/
ほうそうじかんたい /放送時間帯/
ほうそうじき /放送時期/
ほうそうじぎょうしゃ /放送事業者/
ほうそうじこ /放送事故/
ほうそうじこく /放送時刻/
ほうそうじゅん /放送順/
ほうそうじゅんじょ /放送順序/
ほうそうせいど /放送制度/
ほうそうせき /放送席/
ほうそうせつび /放送設備/
ほうそうだいがく /放送大学/
ほうそうちゅう /放送中/
ほうそうでんぱ /放送電波/
ほうそうとうじ /放送当時/
ほうそうとうじつ /放送当日/
ほうそうないよう /放送内容/
ほうそうにちじ /放送日時/
ほうそうは /放送波/
ほうそうはん /放送班/
ほうそうばんぐみ /放送番組/
ほうそうび /放送日/
ほうそうぶ /放送部/
ほうそうぶん /放送分/
ほうそうほう /放送法/
ほうそうほうしき /放送方式/
ほうそうまえ /放送前/
ほうそうみてい /放送未定/
ほうそうもう /放送網/
ほうそうよう /放送用/
ほうそうようご /放送用語/
ほうそうよてい /放送予定/
ほうそうよていじかん /放送予定時間/
ほうそうよていび /放送予定日/
ほうそうろくが /放送録画/
ほうそうわく /放送枠/
ほうそく /法則/方則/
ほうそくじょう /法則上/
ほうそくせい /法則性/
ほうそくてき /法則的/
ほうぞう /宝蔵/包蔵/法蔵/
ほうぞうかん /法蔵館/
ほうたい /包帯/砲隊/胞体/法体/奉戴/繃帯;=包帯/奉体/方体/
ほうたいけい /法体系/
ほうたく /飽託/
ほうたん /放胆/
ほうだ /法田/
ほうだい /放題/邦題/砲台/法大/
ほうだん /砲弾/放談;at-random talk.「時事-」/法談;仏法の談話/砲彈;「弾」旧字/
ほうだんかい /放談会/
ほうだんがた /砲弾型/
ほうち /放置/報知/法治/封地/
ほうちき /報知器/報知機/
ほうちきかん /放置期間/
ほうちく /放逐/方竹/
ほうちこく /法治国/
ほうちこっか /法治国家/
ほうちしき /法知識/
ほうちしゃ /放置車/
ほうちしゃかい /法治社会/
ほうちしゅぎ /法治主義/
ほうちしんぶん /報知新聞/
ほうちじてんしゃ /放置自転車/
ほうちちゅうしゃ /放置駐車/
ほうちつじょ /法秩序/
ほうちぷれい /放置プレイ/
ほうちゃく /逢着/縫着/
ほうちゅう /訪中/包虫/庖厨/
ほうちょう /包丁/訪朝/庖丁;=包丁 NB:本来の用字(「庖」は台所)/放鳥/
ほうづえ /方杖/
ほうてい /法定;legal.「-金利」/法廷;court/奉呈;献上する/捧呈;捧げ持つ/
ほうていかじつ /法定果実/
ほうていかへい /法定貨幣/
ほうていがいもくてきぜい /法定外目的税;自治体の独自課税/
ほうていきかん /法定期間/
ほうていきじゅん /法定基準/
ほうていけい /法定刑/
ほうていけつぞく /法定血族/
ほうていしき /方程式/
ほうていしきけい /方程式系/
ほうていじゅんびきん /法定準備金;資本準備金、利益準備金の2つ/
ほうていせいさん /法定清算/
ほうていそくど /法定速度/
ほうていだいり /法定代理/
ほうていだいりにん /法定代理人/
ほうていてんけん /法定点検/
ほうていでんせんびょう /法定伝染病/
ほうていとうそう /法廷闘争/
ほうていない /法廷内/法定内/
ほうていはん /法定犯/
ほうていひよう /法定費用/
ほうていふくりひ /法定福利費/
ほうていりそく /法定利息/
ほうていりりつ /法定利率/
ほうてき /法的/放擲/抛擲;=放擲/法敵/
ほうてきいち /法的位置/
ほうてききせい /法的規制/
ほうてきぎむ /法的義務/
ほうてきけんげん /法的権限/
ほうてきけんち /法的見地/
ほうてきけんり /法的権利/
ほうてきこうそくりょく /法的拘束力/
ほうてきこんきょ /法的根拠/
ほうてきしゅだん /法的手段/
ほうてきせいり /法的整理/
ほうてきせきにん /法的責任/
ほうてきそち /法的措置/
ほうてきちい /法的地位/
ほうてきてつづき /法的手続き/
ほうてきばつ /法的罰/
ほうてきひょうか /法的評価/
ほうてきほご /法的保護/
ほうてきめん /法的面/
ほうてつがく /法哲学/
ほうてん /法典/奉天/宝典/方転/
ほうでん /放電/宝殿/
ほうでんかこう /放電加工/
ほうでんかん /放電管/
ほうでんき /放電器/
ほうでんきのう /放電機能/
ほうでんじ /放電時/
ほうと /方途/
ほうとう /放蕩/砲塔/包頭/宝塔/宝刀/法灯/法統/奉答/蓬頭/
ほうとうこうめん /蓬頭垢面/
ほうとうない /砲塔内/
ほうとく /報徳/宝徳;年号(1449-1452)/
ほうとくがくえん /報徳学園/
ほうとり /放取/
ほうど /封土/報土;[仏教](報われて住む)浄土/邦土/
ほうどう /報道/法堂/報導;?/
ほうどうかくしゃ /報道各社/
ほうどうかん /報道官;(米)Press Secretary/
ほうどうかんけい /報道関係/
ほうどうかんけいしゃ /報道関係者/
ほうどうかんせい /報道管制/
ほうどうきかん /報道機関/
ほうどうきせい /報道規制/
ほうどうきょうてい /報道協定/
ほうどうきょく /報道局/
ほうどうしせい /報道姿勢/
ほうどうしゃしん /報道写真/
ほうどうしゃしんか /報道写真家/
ほうどうじん /報道陣/
ほうどうはっぴょう /報道発表/
ほうどうはっぴょうしりょう /報道発表資料/
ほうどうばんぐみ /報道番組/
ほうどうぶ /報道部/
ほうどうぶもん /報道部門/
ほうどく /奉読/
ほうなん /方南/豊南/法難/
ほうなんこうこう /豊南高校/
ほうなんちょう /方南町/
ほうに /法爾/
ほうにち /訪日/
ほうにょう /放尿/
ほうにん /放任/
ほうにんしゅぎ /放任主義/
ほうにんじょうたい /放任状態/
ほうねつ /放熱/
ほうねつき /放熱器/
ほうねつこうか /放熱効果/
ほうねつたいさく /放熱対策/
ほうねつばん /放熱板/
ほうねつりょう /放熱量/
ほうねん /豊年/法然/芳年/放念/芳念/
ほうねんせいゆ /豊年製油/
ほうのう /奉納/
ほうのうきん /奉納金/
ほうのせいしん /法の精神;De l'esprit des lois,1748,Montesquieu/
ほうはい /澎湃/奉拝/
ほうはく /方伯/鵬搏/
ほうはつ /蓬髪/
ほうはん /訪販;[略語]訪問販売/
ほうば /放馬/
ほうばい /朋輩/傍輩;≒朋輩/
ほうばつ /放伐/
ほうひ /放屁/包皮/豊肥;-本線/包被/
ほうひほんせん /豊肥本線/
ほうび /褒美/
ほうびちく /鳳尾竹/
ほうびょう /宝瓶/
ほうふ /豊富/抱負/防府;地名,山口県/豊府;地名,大分県/豊冨;「富」異体字/
ほうふく /報復/抱腹/法服/
ほうふくかんぜい /報復関税/
ほうふくこうい /報復行為/
ほうふくこうげき /報復攻撃/
ほうふくじ /豊福寺/
ほうふくぜっとう /抱腹絶倒/
ほうふくそち /報復措置/
ほうふつ /彷彿/髣髴;=彷彿/
ほうふん /方墳/
ほうぶ /邦舞/
ほうぶつ /放物/
ほうぶつうんどう /放物運動/
ほうぶつせん /放物線/抛物線/
ほうぶつめん /放物面/
ほうぶん /法文/邦文/報文/
ほうぶんか /法文化/
ほうぶんしゃ /芳文社;[出版社名]www.houbunsha.co.jp/
ほうへい /砲兵/奉幣/
ほうへいきゅう /宝瓶宮;[十二宮]みずがめ座(1.20-2.18)/
ほうへきざん /豊碧山/
ほうへん /褒貶/方偏/
ほうべい /訪米/
ほうべいちゅう /訪米中/
ほうべん /方便/
ほうほう /方法/這う這う;-の体(てい)/
ほうほういがい /方法以外/
ほうほうじたい /方法自体/
ほうほうじょせつ /方法序説/
ほうほうてき /方法的;methodic.「-懐疑」/
ほうほうなど /方法等/
ほうほうのてい /這う這うの体/
ほうほうろん /方法論/
ほうほく /豊北/
ほうほんはんし /報本反始/
ほうぼう /方々/方方/謗法/鋒鋩/蜂房/竹麦魚/宝坊/魴ボウ/
ほうぼく /放牧/芳墨/
ほうぼくじょう /放牧場/
ほうぼくち /放牧地/
ほうぼくちゅう /放牧中/
ほうまつ /泡沫/
ほうまん /豊満;†glamour.「-な乳房」/放漫/飽満;†satiate.「美食に-する」/
ほうまんけいえい /放漫経営/
ほうみ /芳味/法味/
ほうみょう /法名/
ほうむ /法務/放夢/
ほうむか /法務課/
ほうむかん /法務官/
ほうむきょく /法務局/
ほうむしょう /法務省/
ほうむたんとう /法務担当/
ほうむだいじん /法務大臣/
ほうむぶ /法務部/
ほうめい /芳名/法明/邦名/
ほうめいちょう /芳名帳/
ほうめいぼ /芳名簿/
ほうめん /方面/放免/
ほうめんぐん /方面軍/
ほうめんたい /方面隊/
ほうめんべつ /方面別/
ほうもう /法網/
ほうもつ /宝物/
ほうもつこ /宝物庫/
ほうもつでん /宝物殿/
ほうもん /訪問/法門/砲門/法文/法問/
ほうもんかいご /訪問介護/
ほうもんかのう /訪問可能/
ほうもんかんご /訪問看護/
ほうもんき /訪問記/
ほうもんきゃく /訪問客/
ほうもんぎ /訪問着/
ほうもんこく /訪問国/
ほうもんさき /訪問先/
ほうもんしゃ /訪問者/
ほうもんじ /訪問時/
ほうもんだん /訪問団/
ほうもんちゅう /訪問中/
ほうもんとし /訪問都市/
ほうもんはんばい /訪問販売/
ほうもんはんばいほう /訪問販売法/
ほうもんび /訪問日/
ほうや /保谷/
ほうやく /邦訳/
ほうやくずみ /邦訳済/
ほうやし /保谷市/
ほうゆう /朋友/邦友/包有/
ほうよう /法要/抱擁;†hug.「熱い-」/包容;†tolerate.「-力」/苞葉/包葉;=苞葉/放鷹/泡影;=ほうえい/
ほうようりょく /包容力/
ほうよく /豊沃/
ほうら /和了/法螺/
ほうらい /蓬莱/宝来/鳳来/寳来/
ほうらいさん /蓬莱山;霊山/
ほうらいじ /鳳来寺/
ほうらく /崩落/法楽/包絡;-線/焙烙/炮烙;=焙烙/
ほうらくせん /包絡線/
ほうらくのうたげ /炮烙之宴/炮烙の宴/
ほうらくのけい /炮烙之刑/
ほうらくまんじゅう /蜂楽饅頭/
ほうらくめん /包絡面/
ほうらけい /和了形/
ほうらつ /放埒/
ほうらん /抱卵/
ほうり /法理/宝利/
ほうりがく /法理学;jurisprudence/
ほうりき /法力/
ほうりつ /法律/
ほうりつあん /法律案/
ほうりついはん /法律違反/
ほうりつか /法律家/法律化/
ほうりつかいせい /法律改正/
ほうりつかんけい /法律関係/
ほうりつがく /法律学/
ほうりつがくしゃ /法律学者/
ほうりつけい /法律系/
ほうりつこうい /法律行為/
ほうりつこん /法律婚/
ほうりつご /法律語/
ほうりつしょ /法律書/
ほうりつしん /法律審/
ほうりつじしん /法律自身/
ほうりつじほう /法律時報;[雑誌名]/
ほうりつじむしょ /法律事務所/
ほうりつじょう /法律上/
ほうりつじょうかのう /法律上可能/
ほうりつじょうほご /法律上保護/
ほうりつせいど /法律制度/
ほうりつせいれい /法律政令/
ほうりつそうだん /法律相談/
ほうりつそうだんぶ /法律相談部/
ほうりつてき /法律的/
ほうりつてきこんきょ /法律的根拠/
ほうりつてきせいやく /法律的制約/
ほうりつてきもんだい /法律的問題/
ほうりつはんだん /法律判断/
ほうりつふじょ /法律扶助/
ほうりつめい /法律名/
ほうりつめん /法律面/
ほうりつもんだい /法律問題/
ほうりつようご /法律用語/
ほうりつろん /法律論/
ほうりつろんそう /法律論争/
ほうりゃく /方略/宝暦;=ほうれき/
ほうりゅう /放流/
ほうりゅうぎょ /放流魚/
ほうりゅうじ /法隆寺/
ほうりょう /豊漁/法量/方領/
ほうりろん /法理論/
ほうりろんてき /法理論的/
ほうりん /法林/法輪/
ほうりんこう /法輪功;[時事]中国の宗教団体。当局の弾圧を受けている/
ほうりんじ /法輪寺/
ほうりんどうしょてん /芳林堂書店/
ほうるい /堡塁/砲塁/
ほうれい /法令;法律と命令/豊麗/法例;法に適用される法や規則/
ほうれいしゅう /法令集/
ほうれいしんさけん /法令審査権/
ほうれいぜんしょ /法令全書/
ほうれいめい /法令名/
ほうれき /宝暦;年号(1751-1764)/
ほうれきほん /宝暦本/
ほうれつ /放列/砲列/芳烈/
ほうれん /法蓮/
ほうれんそう /菠薐草/法蓮草/ほうれん草/鳳蓮草/
ほうろう /放浪/琺瑯/法臈/法臘/報労/鳳楼/
ほうろうき /放浪記/
ほうろうしゃ /放浪者/
ほうろうびき /琺瑯引き/
ほうろうへき /放浪癖/
ほうろうわくせい /放浪惑星/
ほうろく /俸禄/焙烙/炮烙;=焙烙/
ほうろん /法論/放論/
ほうわ /飽和/法話/豊和/
ほうわかごうぶつ /飽和化合物;[化学]saturated compound/
ほうわがた /飽和型/
ほうわしき /飽和式/
ほうわしぼうさん /飽和脂肪酸/
ほうわじそくみつど /飽和磁束密度/
ほうわじょうき /飽和蒸気;saturated vapour/
ほうわじょうきあつ /飽和蒸気圧/
ほうわじょうたい /飽和状態/
ほうわすいじょうきあつ /飽和水蒸気圧/
ほうわすいじょうきりょう /飽和水蒸気量/
ほうわすいようえき /飽和水溶液/
ほうわてん /飽和点/
ほうわようえき /飽和溶液/
ほえき /補益/
ほえづら /吠え面/吠面/
ほお /頬/朴/
ほおかぶり /頬被り/
ほおげた /頬桁/
ほおじろ /頬白/
ほおずき /酸漿/鬼灯;=酸漿/
ほおずきいち /ほおずき市/
ほおずきぢょうちん /酸漿提灯/
ほおずり /頬擦り/頬ずり/ほお擦り/
ほおづえ /頬杖/
ほおのき /朴の木/
ほおば /朴歯/
ほおひげ /髯/頬髯/
ほおぶくろ /頬袋/
ほおべに /頬紅/
ほおぼね /頬骨/
ほおん /保温/
ほおんき /保温器/保温機/
ほおんこうか /保温効果/
ほおんじょうたい /保温状態/
ほおんせい /保温性/
ほおんせいのう /保温性能/
ほおんなべ /保温鍋/
ほおんよう /保温用/
ほおんりょく /保温力/
ほか /他/外/
ほかいちめい /他一名/
ほかおおぜい /他大勢/
ほかく /捕獲/保革/補角;†[数学]supplementary angle/補格;†[文法]/
ほかくだんめんせき /捕獲断面積/
ほかけぶね /帆掛け船/
ほかげ /火影/帆影/灯かげ/
ほかすうめい /他数名/
ほかぜ /帆風/
ほかたすう /他多数/
ほかならない /他ならない/
ほかならぬ /他ならぬ/
ほかなんにん /他何人/
ほかに /他に/
ほかの /他の/
ほかふたり /他二人/
ほかん /保管/補完;completion/補間;[数学]interpolation/
ほかんきげん /保管期限/
ほかんきのう /補完機能/
ほかんこ /保管庫/
ほかんざい /補完財/
ほかんしょり /補間処理/補完処理/
ほかんじょ /保管所/
ほかんじょうきょう /保管状況/
ほかんじょうたい /保管状態/
ほかんち /補間値/
ほかんちゅう /保管中/
ほかんてき /補完的/
ほかんばしょ /保管場所/
ほかんほう /補間法/
ほかんほうほう /補間方法/
ほかんよう /保管用/
ほかんりょう /保管料/
ほがい /補外/
ほがいほう /補外法;[数学]extrapolation/
ほがた /保型/
ほがらか /朗らか/
ほき /補機/補記/補器/
ほきもと /保木本/
ほきゃく /歩脚/
ほきゅう /補給/捕球/
ほきゅうかん /補給艦/
ほきゅうきち /補給基地/
ほきゅうしゅだん /補給手段/
ほきゅうじ /補給時/
ほきゅうじょうたい /補給状態/
ほきゅうせん /補給線/
ほきゅうち /補給値/
ほきゅうぶっし /補給物資/
ほきゅうぶつ /補給物/
ほきゅうへい /補給兵/
ほきゅうほうほう /補給方法/
ほきゅうもくてき /補給目的/
ほきゅうよう /補給用/
ほきゅうりょう /補給量/
ほきょう /補強/
ほきょうけいかく /補強計画/
ほきょうざい /補強材/
ほきょうしょうこ /補強証拠/
ほきょうせん /補強線/
ほきょうせんしゅ /補強選手/
ほきるい /補機類/
ほきん /保菌/
ほきんしゃ /保菌者/
ほぎ /穂木;[園芸]挿し穂./
ほぎうた /寿歌/
ほく /北/攴;とまた/攵/殕;(くさる)/蹼;みずかき/瀑;たき/
ほく> /北/
ほくい /北緯/
ほくうかん /補空間/
ほくえい /北瑛/
ほくえつ /北越/
ほくえつぎんこう /北越銀行/
ほくえつせいし /北越製紙;[企業名]/
ほくえつほくせん /北越北線/
ほくおう /北欧/
ほくおうけい /北欧系/
ほくおうしょこく /北欧諸国/
ほくおうしんわ /北欧神話/
ほくおうてき /北欧的/
ほくが /北画/
ほくがん /北岸/
ほくぎ /北魏;[中国史]西魏と東魏に分裂(386-534)/
ほくぎしょ /北魏書/
ほくぐん /北軍/
ほくげん /北限/
ほくこう /北興/
ほくさい /北斎/
ほくし /北史;二十一史/
ほくしゅう /北州/北宗;禅/
ほくしゅうが /北宗画/
ほくしゅうしょ /北周書/
ほくしん /北辰/北進/
ほくしんえつ /北信越/
ほくしんきゅうこう /北神急行/
ほくじょう /北上/
ほくせい /北西/北星/北勢/北征/
ほくせいがわ /北西側/
ほくせいしょ /北斉書;二十一史/
ほくせいせん /北勢線/
ほくせいそう /北誠荘/
ほくせいぶ /北西部/
ほくせいほうこう /北西方向/
ほくせつ /北摂/
ほくせん /北線/
ほくそ /樮/
ほくそう /北宋/北倉/北叟/
ほくそうかいはつてつどう /北総開発鉄道/
ほくそうせん /北総線/
ほくそうちいき /北総地域/
ほくそうてつどう /北総鉄道/
ほくたん /北端/
ほくたんてつどう /北丹鉄道/
ほくだい /北大/北海道大学;※abbrev/
ほくだいこうがくぶ /北大工学部/
ほくだいせいきょう /北大生協/
ほくだいない /北大内/
ほくだいびょういん /北大病院/
ほくだん /北淡/
ほくち /火口/
ほくちょう /北朝/
ほくてき /北狄/
ほくてつ /北鉄/
ほくてん /北天/
ほくてんゆう /北天佑/
ほくでん /北電;[企業名]北海道電力,北陸電力/北伝/
ほくでんぶっきょう /北伝仏教/
ほくと /北斗/北都/
ほくとう /北東/
ほくとうがわ /北東側/
ほくとうぶ /北東部/
ほくとうみ /北勝海/
ほくとき /北斗旗/
ほくとしちせい /北斗七星/
ほくとせい /北斗星/
ほくとのけん /北斗の拳/
ほくどう /北堂/
ほくばく /北爆/
ほくばつ /北伐/
ほくふう /北風/
ほくぶ /北部/
ほくぶきゅうしゅう /北部九州/
ほくぶほうめん /北部方面/
ほくへき /北壁/
ほくへん /北辺/
ほくべい /北米/
ほくべいいがい /北米以外/
ほくべいさん /北米産/
ほくべいしよう /北米仕様/
ほくべいたいりく /北米大陸/
ほくべいばん /北米版/
ほくべいほうめん /北米方面/
ほくほくせい /北北西/
ほくほくとう /北北東/北々東/
ほくぼう /北房/
ほくめい /北溟/
ほくめん /北面/
ほくもん /北門/
ほくよう /北洋/
ほくようだい /北陽台/
ほくら /神庫/
ほくりく /北陸/
ほくりくぎんこう /北陸銀行/
ほくりくさんけん /北陸三県/
ほくりくしぶ /北陸支部/
ほくりくしんかんせん /北陸新幹線/
ほくりくじ /北陸路/
ほくりくじどうしゃどう /北陸自動車道/
ほくりくせん /北陸線/
ほくりくせんたん /北陸先端/
ほくりくせんたんかがくぎじゅつだいがくいんだいがく /北陸先端科学技術大学院大学/
ほくりくせんたんだい /北陸先端大/
ほくりくだいひょう /北陸代表/
ほくりくちく /北陸地区/
ほくりくてつどう /北陸鉄道/
ほくりくでんりょく /北陸電力;[企業名]/
ほくりくどう /北陸道/
ほくりくほうそう /北陸放送/
ほくりくほうめん /北陸方面/
ほくりくほんせん /北陸本線/
ほくりくほんせんとっきゅう /北陸本線特急/
ほくりゅう /北竜/北龍/
ほくりょう /北陵/
ほくりょなんわ /北虜南倭/
ほくれい /北嶺/
ほくろ /黒子/
ほくろく /北麓/
ほぐし /火串/
ほぐみ /穂組み/
ほけきょう /法華経/
ほけつ /補欠/補闕;=補欠/
ほけつせんきょ /補欠選挙/
ほけつば /補欠馬/
ほけん /保険;†insurance.「生命-」/保健;†health.「-体育」/
ほけんい /保険医/
ほけんいりょう /保険医療/
ほけんえいせい /保健衛生/
ほけんかがく /保険価額/
ほけんかんゆういん /保険勧誘員/
ほけんがい /保険外/
ほけんがいこういん /保険外交員/
ほけんがいしゃ /保険会社/
ほけんがく /保険額/
ほけんがっか /保健学科/
ほけんきのうしょくひん /保健機能食品/
ほけんきん /保険金/
ほけんきんがく /保険金額/
ほけんきんさぎ /保険金詐欺/
ほけんきんさつじん /保険金殺人/
ほけんぎょう /保険業/
ほけんぎょうほう /保険業法/
ほけんけいやく /保険契約/
ほけんけいやくしゃほごきこう /保険契約者保護機構/
ほけんし /保健師;保健婦助産婦看護婦法一部改正による呼称変更/保健士/
ほけんしつ /保健室/保険室;保険を扱うsection/
ほけんしゃ /保険者/
ほけんしょ /保健所/
ほけんしょう /保険証/保健省/保健相;†大臣/
ほけんしょうけん /保険証券/
ほけんしょうひん /保険商品/
ほけんしんりょう /保険診療/
ほけんじこ /保険事故;insured event. 保険金の支払対象となる事故/
ほけんじょ /保健所/
ほけんせいきゅう /保険請求/
ほけんせいど /保険制度/保健制度;?/
ほけんたいいく /保健体育/
ほけんだい /保険代/
ほけんてき /保健的/
ほけんふ /保健婦/
ほけんや /保険屋/
ほけんやく /保険薬/
ほけんやっかん /保険約款/
ほけんやっきょく /保険薬局/
ほけんりょう /保険料/
ほけんりょうきん /保険料金/
ほけんりょうりつ /保険料率/
ほげい /捕鯨/
ほげいせん /捕鯨船/
ほげいもんだい /捕鯨問題/
ほげた /帆桁/
ほげん /保元;年号(1156-1159)/補元/
ほこ /鉾;≒矛/矛;(刃が柄と水平、槍に近い)/戈;(刃が柄と垂直)/戟;(柄と垂直・水平両方の刃がある)/桙;(日本のみの用字)/
ほこう /歩行/補講/
ほこうえい /蒲公英/
ほこうき /歩行器/
ほこうきつえん /歩行喫煙/
ほこうきつえんしゃ /歩行喫煙者/
ほこうきょり /歩行距離/
ほこうしゃ /歩行者/
ほこうしゃせんよう /歩行者専用/
ほこうしゃてんごく /歩行者天国/
ほこうしゃゆうせん /歩行者優先/
ほこうしゃよう /歩行者用/
ほこうしゃようしんごう /歩行者用信号/
ほこうそ /補酵素/
ほこうちゅう /歩行中/
ほこさき /矛先/鉾先;=矛先/鋒;=矛先/鋒先;(ほこさきさき?)/
ほこすぎ /鉾杉/矛杉/
ほこた /鉾田/
ほこてん /歩行者天国/
ほこら /祠/叢祠/
ほこらか /誇らか/
ほこり /埃/誇り/
ほこりたいさく /埃対策/
ほころび /綻び/
ほご /保護/反故/補語/反古/
ほごあずかり /保護預り/
ほごえ /穂肥;[農業]稲の穂が出る頃に施す追肥/
ほごえき /保護液/
ほごかいろ /保護回路/
ほごかつどう /保護活動/
ほごかのう /保護可能/
ほごかんさつ /保護観察/
ほごかんさつしょぶん /保護観察処分/
ほごかんぜい /保護関税/
ほごきかん /保護期間/
ほごきこう /保護機構/
ほごきてい /保護規定/
ほごきのう /保護機能/
ほごきょく /保護局/
ほごく /保護区/
ほごこく /保護国/
ほごさく /保護策/
ほござい /保護剤/
ほごし /保護司/
ほごしせつ /保護施設/
ほごしゃ /保護者/
ほごしゅぎ /保護主義/
ほごしゅだん /保護手段/
ほごしょく /保護色/
ほごしょぶん /保護処分/
ほごじょうれい /保護条例/
ほごせいさく /保護政策/
ほごせつび /保護設備/
ほごぞくせい /保護属性/
ほごたんい /保護単位/
ほごちょう /保護鳥/
ほごどうぶつ /保護動物/
ほごのうりょく /保護能力/
ほごはんい /保護範囲/
ほごぼう /保護帽;helmet/
ほごぼうえき /保護貿易;⇔自由貿易/
ほごまく /保護膜/
ほごよう /保護用/
ほごりん /保護林/
ほごわく /保護枠/
ほさ /補佐/保佐/輔佐/
ほさいん /補佐員/
ほさか /保坂/
ほさかん /補佐官/
ほさき /穂先/芒/
ほさく /補作/
ほさたい /補佐隊/
ほさつ /捕殺/補殺;assist/
ほさにん /保佐人/補佐人/
ほさやく /補佐役/
ほざ /帆座;Vela(Vel)/
ほざわ /保沢/
ほし /星/干し/☆/★/※/＊/欲し/
ほしあい /星合/
ほしあかり /星明かり/星明り/
ほしい /糒/星井/
ほしいい /糒/干し飯/乾し飯/
ほしいお /乾し魚/干し魚/
ほしいってつ /星一徹/
ほしいまま /恣/擅/縦/
ほしいも /干し芋/
ほしうお /乾し魚/干し魚/干魚/
ほしうらない /星占い/
ほしえび /干し海老/乾し海老/
ほしおき /星置/
ほしかげ /星影/
ほしかわ /星川/
ほしがおか /星ヶ丘/
ほしがき /干し柿/干柿/
ほしがた /星型/星形;☆/
ほしがれい /干鰈;†(ひもの)/星鰈;†(魚の種類)/干し鰈/乾鰈;=干鰈/
ほしくさ /干し草/干草/乾し草/
ほしくさもく /ホシクサ目/Eriocaulales/
ほしくず /星屑/
ほしくら /星倉/
ほしぐみ /星組/
ほしさと /星里/
ほしざかな /干し魚/干魚/
ほしざわ /星沢/
ほししいたけ /干し椎茸/干椎茸/
ほししば /星芝/
ほししんいち /星新一;SF作家/
ほしじし /干肉/
ほしじるし /星印/
ほしずめのまつり /鎮火祭/
ほしぞら /星空/
ほしたに /星谷/
ほしだいこん /干大根/
ほしつ /保湿/
ほしつえき /保湿液/
ほしつこうか /保湿効果/
ほしつざい /保湿剤/
ほしつせい /保湿性/
ほしつりょく /保湿力/
ほしづき /星月/
ほしづきよ /星月夜/
ほしづくよ /星月夜/
ほしで /星出/
ほしとり /星取/星取り/
ほしとりひょう /星取表/
ほしな /保科/星名/
ほしにく /干し肉/乾し肉/
ほしの /星野/
ほしのおんせん /星野温泉/
ほしのかず /星の数/
ほしば /干場/保志場/
ほしひょうめん /星表面/
ほしぶどう /干し葡萄/乾し葡萄/
ほしぼし /星々/
ほしまつり /星祭り/星祭;七夕/
ほしみ /星見/
ほしみや /星宮/
ほしもと /星本/
ほしもの /乾し物/干し物/
ほしゃく /保釈/
ほしゃくきん /保釈金/
ほしや /星矢/星谷/
ほしやま /星山/
ほしゅ /保守/捕手;catcher/補手;assistant/
ほしゅいん /保守員/
ほしゅう /補修;repair/補習;-授業/捕囚;captivity/
ほしゅうきょういく /補習教育/
ほしゅうごう /補集合/
ほしゅうじゅぎょう /補習授業/
ほしゅうひ /補修費/
ほしゅうぶひん /補修部品/
ほしゅうよう /補修用/
ほしゅうようぶひん /補修用部品/
ほしゅうんよう /保守運用/
ほしゅおうこく /保守王国/
ほしゅかかく /保守価格/
ほしゅかんり /保守管理/
ほしゅけい /保守系/
ほしゅけいやく /保守契約/
ほしゅけいやくりょう /保守契約料/
ほしゅさぎょう /保守作業/
ほしゅしゅぎ /保守主義/
ほしゅせい /保守性/
ほしゅたいおう /保守対応/
ほしゅてき /保守的/
ほしゅてんけん /保守点検/
ほしゅとう /保守党/
ほしゅは /保守派/
ほしゅひ /保守費/
ほしゅび /保守日/
ほしゅぶひん /保守部品/
ほしゅよう /保守用/
ほしゅようしゃ /保守用車/
ほしゅりょう /保守料/
ほしゅりょうきん /保守料金/
ほしょう /保証;†guarantee.「-人」/保障;†security.「安全-」/補償;†compensation.「損害の-」/歩哨/堡礁/
ほしょうかいろ /補償回路/
ほしょうかのう /保証可能/
ほしょうがく /保証額/
ほしょうがた /補償型/
ほしょうきかん /保証期間/
ほしょうきかんない /保証期間内/
ほしょうきげん /保証期限/
ほしょうきん /保証金;deposit/補償金;compensation/
ほしょうきんがく /補償金額/
ほしょうぎれ /保証切れ/
ほしょうげんどがく /保障限度額/
ほしょうさいむ /保証債務/
ほしょうしょ /保証書/
ほしょうしょり /補償処理/
ほしょうじつげん /補償実現/
ほしょうじょう /保証状/
ほしょうじょうけん /補償条件/
ほしょうせいきゅうけん /補償請求権/
ほしょうせいど /保証制度;guarantee system/補償制度;compensation system/
ほしょうそち /補償措置/
ほしょうち /保証値/
ほしょうないよう /保証内容/補償内容/保障内容/
ほしょうにん /保証人/
ほしょうにんてい /保証認定/
ほしょうぶん /補償分/
ほしょうほけん /補償保険;compensation insurance.「所得-」/保証保険;guarantee insurance. 「住宅ローン-」/
ほしょうもんだい /補償問題/保障問題/
ほしょうりょう /保証料/
ほしょうれい /蒲松齢;聊斎志異/
ほしょく /捕食;predation/補色;complementary colour/補食;おやつ/補職;assistant/
ほしょくしゃ /捕食者/
ほしょくちゅう /補食中/
ほしよう /補仕様/
ほしん /保身/
ほじ /保持/
ほじきんびょう /ホジキン病;[医]Hodgkin's disease/
ほじしゃ /保持者/
ほじそ /穂紫蘇;刺身のツマに/
ほじゅう /補充/
ほじゅうえき /補充液/
ほじゅうげんしょう /補充現象/
ほじゅうぶつ /補充物/
ほじょ /補助/輔助;=補助/
ほじょいん /補助員/
ほじょう /圃場;田畑のこと/捕縄/
ほじょかんじ /補助漢字/
ほじょかんすう /補助関数/
ほじょがく /補助額/
ほじょきおく /補助記憶/
ほじょきおくそうち /補助記憶装置/
ほじょきかん /補助機関/
ほじょきごう /補助記号/
ほじょきん /補助金/
ほじょきんがく /補助金額/
ほじょきんせいど /補助金制度/
ほじょぐ /補助具/
ほじょけいようし /補助形容詞/
ほじょけん /補助犬/補助券/
ほじょこう /補助光/
ほじょさんか /補助参加/
ほじょざい /補助剤/補助材/
ほじょしょくひん /補助食品/
ほじょしんごう /補助信号/
ほじょじっけん /補助実験/
ほじょじょうけん /補助条件/
ほじょせき /補助席/
ほじょせん /補助線/
ほじょそうび /補助装備/
ほじょたんい /補助単位/
ほじょていり /補助定理/
ほじょてき /補助的/
ほじょとう /補助灯/
ほじょどうし /補助動詞/
ほじょねんりょう /補助燃料/
ほじょひょうしき /補助標識/
ほじょへんすう /補助変数/
ほじょぼ /補助簿/
ほじょよう /補助用/
ほじょよく /補助翼/
ほじょよさん /補助予算/
ほじょりん /補助輪/
ほじょろ /補助路/
ほじりょく /保持力/保磁力/
ほすい /保水/
ほすいせい /保水性/
ほすいりょく /保水力/
ほすう /歩数/補数/
ほすうけい /歩数計;万歩計って商標だったんだね。/
ほすうひょうげん /補数表現/
ほすとがわ /ホスト側/
ほすとこく /ホスト国/
ほすとめい /ホスト名/
ほずみ /穂積;※仮名遣い「ほづみ」/
ほせい /補正;correct/補整;manipulate/
ほせいいた /補正板/
ほせいかいろ /補正回路/
ほせいかくど /補正角度/
ほせいかじょう /補正過剰/補性過剰/
ほせいかのう /補正可能/
ほせいきのう /補正機能/
ほせいけいすう /補正係数/
ほせいこう /補正項/
ほせいしゅだん /補正手段/
ほせいしょり /補正処理/
ほせいじょうきょう /補正状況/
ほせいち /補正値/
ほせいとくせい /補正特性/
ほせいよう /補正用/
ほせいよさん /補正予算/
ほせいりょう /補正量/
ほせき /舗石/
ほせつ /補説/
ほせん /補選/保線/
ほせんさぎょう /保線作業/
ほぜい /保税/
ほぜいうわや /保税上屋/
ほぜいこうじょう /保税工場/
ほぜいそうこ /保税倉庫/
ほぜいちいき /保税地域/
ほぜいちく /保税地区/
ほぜん /保全/
ほぜんしょぶん /保全処分/
ほぜんせい /保全性/
ほそ /細/
ほそ> /細;細糸,細橋,細物/
ほそい /細井/
ほそいと /細糸/
ほそいり /細入/
ほそう /舗装/鋪装;=舗装/
ほそうこうじ /舗装工事/
ほそうで /細腕/
ほそうどう /舗装道/
ほそうどうろ /舗装道路/
ほそうろ /舗装路/
ほそえ /細江/
ほそえちょう /細江町/
ほそおか /細岡/
ほそおび /細帯/
ほそおもて /細面/
ほそかわ /細川/
ほそかわがみ /細川紙/
ほそかわはん /細川藩/
ほそがい /細貝/
ほそき /細木/
ほそぎ /細木/
ほそぎり /細切り/
ほそく /補足;complement.「-説明」/捕捉;capture,「レーダーに-する」/補則;supplementary rules.「法律の-」/歩測;距離を歩いて測る/歩速;歩く速度/
ほそくざい /捕捉剤/
ほそくしりょう /補足資料/
ほそくじっけん /補足実験/
ほそくじょうほう /補足情報/
ほそくせつめい /補足説明/
ほそくていせい /補足訂正/
ほそくていど /補足程度/
ほそくてき /補足的/
ほそくら /細倉/
ほそくりつ /捕捉率/
ほそぐち /細口/
ほそごし /細腰/
ほそざお /細棹;三味線/
ほそざわ /細澤/
ほそじ /細字/
ほそせん /細線/
ほそだ /細田/
ほそだけ /細竹/
ほそつ /歩卒/
ほそづくり /細作り/
ほそなが /細長/
ほその /細野/
ほそはら /細原/
ほそびき /細引き/
ほそぶち /細渕/
ほそべ /細部/
ほそぼそ /細々/
ほそまき /細巻き;寿司/細巻/
ほそまゆ /細眉/
ほそまる /細丸/
ほそみ /細身/細見;人名/細み/
ほそみち /細道/
ほそみんちょうたい /細明朝体/
ほそめ /細目/細め/
ほそめん /細麺/
ほそもの /細物;素麺/
ほそや /細谷/細矢/
ほそよこちょう /細横町/
ほぞ /臍/蔕/
ほぞう /保蔵/
ほぞく /保続/
ほぞくてき /保続的/
ほぞん /保存/
ほぞんうんどう /保存運動/
ほぞんおんど /保存温度/
ほぞんかのう /保存可能/
ほぞんかんり /保存管理/
ほぞんきかん /保存期間/
ほぞんけいしき /保存形式/
ほぞんけいたい /保存形態/
ほぞんこ /保存庫/
ほぞんこうい /保存行為/
ほぞんさき /保存先/
ほぞんしゃ /保存車/
ほぞんしょく /保存食/
ほぞんじ /保存時/
ほぞんじょうたい /保存状態/
ほぞんせい /保存性/
ほぞんそく /保存則/
ほぞんちゅう /保存中/
ほぞんてき /保存的/
ほぞんにちじ /保存日時/
ほぞんばしょ /保存場所/
ほぞんばん /保存版/
ほぞんほう /保存法/
ほぞんほうほう /保存方法/
ほぞんよう /保存用/
ほぞんりょう /保存料/保存量/
ほぞんりょく /保存力/
ほぞんりよう /保存利用/
ほぞんろくが /保存録画/
ほた /榾/
ほたい /保体/補体/
ほたおり /保多織/
ほたか /穂高/
ほたかじんじゃ /穂高神社/
ほたて /帆立/
ほたてがい /帆立貝/ホタテ貝/
ほたに /保谷/
ほたる /蛍/螢;「蛍」の旧字/火垂る;(「蛍」の語源の一説)/
ほたるいか /蛍烏賊/
ほたるいし /蛍石/
ほたるかご /蛍籠/
ほたるがいけ /蛍池/蛍ケ池/
ほたるがり /蛍狩り/蛍狩/
ほたるがわ /蛍川/
ほたるじゃこ /蛍雑魚/
ほたるじゃや /蛍茶屋/
ほたるぞく /蛍族/
ほたるのひかり /蛍の光/
ほたるび /蛍火/
ほたるぶくろ /蛍袋;[植物]キキョウ科/
ほたるまつり /蛍祭/
ほたんちょう /ホ短調/
ほだ /絆/
ほだい /補題/
ほだか /穂高/
ほだかおんせん /穂高温泉/
ほだぎ /榾木/
ほちゅう /補注/捕虫;-網/補註;=補注/
ほちゅうあみ /捕虫網/
ほちょう /歩調/補聴/
ほちょうき /補聴器/
ほちょうこうか /補聴効果/
ほちょうちょう /ホ長調/
ほっ /法/発/發;「発」の旧字/
ほっかい /北海/法界;[仏教]/
ほっかいえんぎ /法界縁起/
ほっかいがくえんだいがく /北海学園大学/
ほっかいこうこう /北海高校/
ほっかいどう /北海道/
ほっかいどうえんがん /北海道沿岸/
ほっかいどうかいはつちょう /北海道開発庁/
ほっかいどうげんてい /北海道限定/
ほっかいどうさん /北海道産/
ほっかいどうさんまい /北海道産米/
ほっかいどうししゃ /北海道支社/
ほっかいどうしぶ /北海道支部/
ほっかいどうしよう /北海道仕様/
ほっかいどうしんぶん /北海道新聞/
ほっかいどうじゅうだん /北海道縦断/
ほっかいどうじん /北海道人/
ほっかいどうだいがく /北海道大学/
ほっかいどうちほう /北海道地方/
ほっかいどうつうしん /北海道通信/
ほっかいどうてん /北海道展/
ほっかいどうとうぶ /北海道東部/
ほっかいどうとくしゅう /北海道特集/
ほっかいどうどくじ /北海道独自/
ほっかいどうにっき /北海道日記/
ほっかいどうべん /北海道弁/
ほっかいどうほんぶ /北海道本部/
ほっかいどうみなみ /北海道南/
ほっかいどうりょこう /北海道旅行/
ほっかいどうろせん /北海道路線/
ほっかいゆでん /北海油田/
ほっかむり /頬っ被り;知らんぷり/
ほっかん /北漢;[中国史]十国の一(951-979)/
ほっき /発起/発企/
ほっきがい /北寄貝/
ほっきしゃ /発起者/
ほっきせつりつ /発起設立/
ほっきにん /発起人/
ほっきにんいちどう /発起人一同/
ほっきょく /北極/
ほっきょくかい /北極海/
ほっきょくかん /北極冠/
ほっきょくぐま /北極熊/
ほっきょくけん /北極圏/
ほっきょくせい /北極星/
ほっきょくてん /北極点/
ほっく /発句/
ほっけ /法華/北家;[日本史]藤原氏-/
ほっけきょう /法華経/
ほっけしゅう /法華宗/
ほっけど /法花堂;姓/
ほっこう /北郊/
ほっこく /北国/
ほっこくかいどう /北国街道;北陸道-中山道/
ほっこくぎんこう /北國銀行;[企業名]/北国銀行;※「北國銀行」が正式/
ほっこくしんぶん /北国新聞/
ほっさ /発作/
ほっさてき /発作的/
ほっしょう /法性;[仏教]/
ほっしん /発疹;[医]eruption/発心;[仏教]菩提心を起こす/法身;[仏教](dharma-kaya)宇宙の理法としての仏/
ほっしんのう /法親王;[日本史]/
ほっしんぶつ /法身仏/
ほっす /払子/法主/法子/
ほっせき /発赤/
ほっそうしゅう /法相宗/
ほっそく /発足/
ほっそくいらい /発足以来/
ほっそくかい /発足会/
ほっそくじ /発足時/
ほっそくとうじ /発足当時/
ほった /堀田;(つちへん)/掘田;(てへん)/
ほったい /法体/
ほったて /掘建/掘っ立て/掘っ建て/
ほったてごや /掘っ建て小屋/
ほったん /発端/
ほっとう /発頭/
ほっとうにん /発頭人/
ほっぴょうよう /北氷洋/
ほっぺ /頬っぺ;林檎のような-/
ほっぺた /頬っぺた/
ほっぽう /北方/
ほっぽうけい /北方系/
ほっぽうせん /北方線/
ほっぽうみんぞく /北方民族/
ほっぽうよんとう /北方四島/
ほっぽうりょうど /北方領土/
ほつ /発/
ほつい /発意/
ほつうきょう /保通協/
ほつえ /上枝;⇔下枝(しずえ)/
ほつがん /発願/
ほつぎ /発議/
ほつご /発語/
ほつま /秀真/
ほつれ /解れ/
ほづ /保津/
ほづがわ /保津川/
ほづきょう /保津峡/
ほづつ /火筒/
ほづな /帆綱/
ほづみ /穂積/
ほてい /布袋/補綴/補訂/保定/
ほていあおい /布袋葵/
ほていか /補綴科/
ほていちく /布袋竹/
ほていぶつ /補綴物/
ほてつ /補綴/
ほてん /補填/保典/
ほと /陰/
ほとぎ /缶/
ほとぎへん /缶偏/
ほとけ /仏/佛;「仏」の旧字(人名用漢字)/
ほとけごころ /仏心/
ほとけさま /仏様/仏さま/
ほとけのざ /仏の座/
ほととぎす /不如帰/子規/時鳥/杜鵑/杜宇/蜀魂/
ほとほと /幾;almost,very.「-懲りました」/殆;=幾/
ほとぼり /熱/
ほとり /辺;(字義:行き詰まった所)/畔;(字義:分かれる場所)/滸;(字義:水際)/邊;「辺」の旧字1/邉;「辺」の旧字2/
ほとんど /殆ど/殆んど/幾ど/殆/
ほど /程/歩度/火床;囲炉裏の-/塊芋/塊/
ほど> /程;程近い,程経て/
ほどあい /程合い/程合/
ほどいも /塊芋/
ほどう /歩道/補導/舗道;pavement.舗装した(歩)道/舖道;「舗」旧字/
ほどうがわ /歩道側/
ほどうきょう /歩道橋/補導協/
ほどうれき /補導歴/
ほどがや /保土ヶ谷/保土が谷/
ほどがやく /保土ヶ谷区/
ほどこし /施し/
ほどこしもの /施し物/
ほどなく /程なく/
ほどの /程野/
ほどほど /程々/程程/
ほない /保内/
ほなか /火中/
ほなが /穂長/保永/
ほなみ /穂波/保奈美/
ほにゅう /哺乳/
ほにゅうどうぶつ /哺乳動物/
ほにゅうびん /哺乳瓶/
ほにゅうるい /哺乳類/
ほにん /補任/
ほぬの /帆布/
ほね /骨/
ほねおしみ /骨惜しみ/
ほねおり /骨折り/
ほねおりぞん /骨折り損/
ほねかわ /骨皮/骨川/
ほねかわすじえもん /骨皮筋右衛門/
ほねぐみ /骨組/骨組み/
ほねざかな /骨魚/
ほねしごと /骨仕事/
ほねっぷし /骨っ節/
ほねつき /骨付き/
ほねつきかるび /骨付きカルビ/
ほねつぎ /骨接ぎ/
ほねつりょく /保熱力/
ほねなし /骨無し/
ほねなしさかな /骨なし魚/
ほねぬき /骨抜き/骨抜/
ほねぬきさかな /骨抜き魚/
ほねばなれ /骨離れ/
ほねぶと /骨太/
ほねぼそ /骨細/
ほねみ /骨身/
ほねやすみ /骨休み/
ほねやすめ /骨休め/
ほの /仄/
ほのお /炎/焔/
ほのか /仄か/側か;=仄か/
ほのじ /ほの字/ホの字/
ほのぼの /仄々/仄仄/
ほはば /歩幅/
ほばく /捕縛/
ほばしら /帆柱/檣;=帆柱/艢;=檣/
ほばら /保原/
ほひ /補肥/
ほひつ /補筆;touch.「草稿に-する」/輔弼;assist.「大臣を-する」/補弼;=輔弼/
ほふ /保父/
ほふく /匍匐/
ほふくぜんしん /匍匐前進/
ほふる /屠る/
ほぶ /歩武/
ほぶね /帆船/
ほへい /歩兵/
ほべつ /穂別/
ほほ /頬/
ほほえみ /微笑み/微笑/頬笑み;=微笑み/
ほほずゑ /頬杖;※仮名遣い「ほほづえ」or旧仮名遣い「ほほづゑ」/
ほほづえ /頬杖/
ほほぼね /頬骨;=ほおぼね/
ほぼ /保母/略/保姆;=保母/
ほまえ /帆前/
ほまれ /誉れ/誉/
ほむぎ /穂麦/
ほむら /焔/炎/
ほめことば /誉め言葉/褒め言葉/
ほめごろし /褒め殺し/誉め殺し/
ほや /火屋;ランプの-/海鞘;[動物]sea squirt/穂屋/火舎;≒火屋/老海鼠;=海鞘/寄生;やどりぎ/
ほやがらす /保谷硝子;[企業名]/
ほやなぎ /保柳/
ほやの /保屋野;姓/
ほゆう /保有/
ほゆうき /保有機/
ほゆうこく /保有国/
ほゆうしゃ /保有者/
ほゆうすう /保有数/
ほゆうぜい /保有税/
ほゆうねんすう /保有年数/
ほゆうひりつ /保有比率/
ほゆうりょう /保有量/
ほよう /保養/歩容/
ほようしょ /保養所/
ほようじょ /保養所/
ほようち /保養地/
ほら /洞/法螺/
ほらーえいが /ホラー映画/
ほらあな /洞穴/
ほらがい /法螺貝/ほら貝/
ほらがとうげ /洞ヶ峠/
ほらぐち /洞口/
ほらど /洞戸/
ほらふき /法螺吹き/ホラ吹き/ほら吹き/
ほり /堀/捕吏/壕;原義:水のないほり/濠;原義:水を入れたほり/彫り/
ほりい /堀井/堀居/
ほりいけ /堀池/
ほりうち /堀内/
ほりえ /堀江/
ほりお /堀尾/
ほりかわ /堀川/堀河/
ほりかわてんのう /堀河天皇/
ほりがね /堀金/
ほりきり /堀切/
ほりぐち /堀口/
ほりげん /堀玄/
ほりこし /堀越/
ほりこしこうこう /堀越高校/
ほりこみ /彫り込み/彫込み/
ほりごたつ /掘り炬燵/堀ごたつ/
ほりごめ /堀込/堀米/
ほりさき /堀崎/
ほりし /彫師/彫り師/
ほりた /堀田/
ほりたつお /堀辰雄/
ほりだし /掘り出し/
ほりだしもの /掘り出し物/
ほりどめ /堀留/
ほりの /堀野/
ほりのうち /堀之内/堀の内/
ほりのくち /堀之口/
ほりば /堀場/
ほりばせいさくしょ /堀場製作所;[企業名]/
ほりばた /堀端/
ほりべ /堀部/堀辺/
ほりまつ /堀松/
ほりもと /堀本/
ほりもの /彫物/
ほりものし /彫物師/彫り物師/
ほりゅう /保留/蒲柳/補流/
ほりゅうおん /保留音/
ほりゅうきん /保留金/
ほりゅうじかん /保留時間/
ほりゅうじこう /保留事項/
ほりゅうじょうたい /保留状態/
ほりゅうのしつ /蒲柳の質;ひ弱/
ほりゅうぶん /保留分/
ほりょ /捕虜/
ほりょく /補力/
ほりわり /掘割/
ほるい /堡塁/
ほるみうむ /Ho/Holmium/
ほるもんざい /ホルモン剤/
ほるもんやき /ホルモン焼き;[料理]broiled innards/ホルモン焼/
ほるもんりょうほう /ホルモン療法/
ほれい /保冷/
ほれいざい /保冷剤/保冷材/
ほれいよう /保冷用/
ほれぐすり /惚れ薬/
ほれぼれ /惚れ惚れ/
ほろ /幌/保呂/袰/母衣;鎧の飾り/
ほろいずみ /幌泉/
ほろう /歩廊/
ほろかない /幌加内/
ほろくさ /保呂草;姓/
ほろつき /幌付き/
ほろにが /ほろ苦/
ほろのべ /幌延/
ほろばしゃ /幌馬車/
ほろべつ /幌別/
ほろほろちょう /ほろほろ鳥/珠鶏/
ほろよい /ほろ酔い/微酔い/
ほろよいきげん /微酔い機嫌/
ほわんちゅー /黄酒/
ほん /本/翻;翻訳/飜;「翻」の旧字(人名用漢字)/奔;奔放/犇;ひし・めく/畚;もっこ/笨;粗笨/反;(呉音)謀反/叛;(慣用音) 謀叛/
ほん> /本/
ほんあざ /本字/
ほんあつぎ /本厚木/
ほんあみ /本阿弥/
ほんあみこうえつ /本阿弥光悦;1558-1637/
ほんあん /翻案/本案/
ほんあんけん /翻案権/
ほんあんはんけつ /本案判決/
ほんあんぶつ /翻案物/
ほんい /本位/品位/本意/翻意/
ほんいーそー /混一色/
ほんいいんかい /本委員会/
ほんいがい /本以外/
ほんいせい /本位制/
ほんいせいど /本位制度/
ほんいだ /本位田/
ほんいつ /奔逸/
ほんいでん /本位田/
ほんいん /本院/本因/本員/
ほんいんぼう /本因坊/
ほんいんぼうせん /本因坊戦/
ほんう /本有/
ほんうんよう /本運用/
ほんえ /本絵/
ほんえい /本営/本影/
ほんえんそうかい /本演奏会/
ほんおく /本屋/
ほんか /本科/本歌;(和歌の)-取り/
ほんかい /本会/本懐;-を遂げる/
ほんかいぎ /本会議/
ほんかいどう /本街道/
ほんかいほう /本会報/
ほんかく /本格/
ほんかくうんよう /本格運用/
ほんかくか /本格化/
ほんかくさくひん /本格作品/
ほんかくさんか /本格参加/
ほんかくしょうちゅう /本格焼酎;乙類焼酎/
ほんかくすいり /本格推理/
ほんかくすいりしょうせつ /本格推理小説/
ほんかくてき /本格的/
ほんかくは /本格派/
ほんかくはとうしゅ /本格派投手/
ほんかくもの /本格物/
ほんかせい /本科生/
ほんかどり /本歌取り/
ほんかわ /本革/
ほんかわね /本川根/
ほんかわらぶき /本瓦葺き;[建築]平瓦と丸瓦で葺く/
ほんかん /本館/本管/本官/本艦/
ほんかんすう /本関数/
ほんがかり /本係/
ほんがく /本学/
ほんがくだいがくいん /本学大学院/
ほんがっかい /本学会/
ほんがつお /本鰹/
ほんがま /本窯/
ほんがわ /本川/
ほんがん /本願/
ほんがんじ /本願寺/
ほんき /本気/本機/本期/
ほんきかく /本企画/
ほんきしゅ /本機種/
ほんきじ /本記事/
ほんきじる /本気汁;[卑]/
ほんきそく /本規則/
ほんきてい /本規定/
ほんきやく /本規約/
ほんきゅう /本給/
ほんきょ /本拠/本挙/
ほんきょく /本局/
ほんきょち /本拠地/
ほんきょちいがい /本拠地以外/
ほんきょちいてん /本拠地移転/
ほんきょちきゅうじょう /本拠地球場/
ほんきん /本金/
ほんぎ /本紀/本義/
ほんぎまり /本決まり/
ほんぎょう /本業/本行/
ほんくげぬま /本鵠沼/
ほんくげぬまえき /本鵠沼駅/
ほんぐう /本宮/
ほんぐうさん /本宮山/
ほんぐみ /本組/
ほんぐもり /本曇り/
ほんけ /本家/
ほんけい /本刑/本慧/
ほんけいさい /本掲載/
ほんけいやく /本契約/
ほんけってい /本決定/
ほんけつ /本決/
ほんけほんもと /本家本元/
ほんけん /本件/本券/本権/
ほんけんきゅう /本研究/
ほんけんきゅうかい /本研究会/
ほんけんきゅうしつ /本研究室/
ほんけんきゅうしゅうかい /本研究集会/
ほんけんきゅうじょ /本研究所/
ほんけんとう /本検討/
ほんげい /本芸/
ほんげつ /本月/
ほんげん /本源/
ほんげんてきちくせき /本源的蓄積;[経済]ursprungliche Akkumulation (Marxの用語)/
ほんこう /本校/本稿/本項/本工/本甲/
ほんこうえん /本講演/
ほんこうざ /本講座/
ほんこく /翻刻/
ほんこくぼん /翻刻本;reprint/
ほんこまごめ /本駒込/
ほんこん /香港/
ほんこんえいが /香港映画/
ほんこんおうふく /香港往復/
ほんこんけいとくくうこう /香港啓徳空港/
ほんこんこくさいけいさつ /香港国際警察/
ほんこんじん /香港人/
ほんこんせい /香港製/
ほんこんせん /香港線/
ほんこんつう /香港通/
ほんこんとう /香港島/
ほんこんどる /香港ドル/
ほんこんはつ /香港発/
ほんこんもの /香港物/
ほんこんりょこう /香港旅行/
ほんご /本語/
ほんごう /本郷/本号/
ほんごうさんちょうめ /本郷三丁目/
ほんごうしん /本郷新/
ほんごうそうもく /ホンゴウソウ目/Triuridales/
ほんごうだい /本郷台/
ほんごうどおり /本郷通り/
ほんごうゆうびんきょく /本郷郵便局/
ほんごく /本国/本石/
ほんごくしよう /本国仕様/
ほんごくばん /本国版/
ほんごくほう /本国法/
ほんごくむけ /本国向け/
ほんごし /本腰/
ほんさい /本妻/
ほんさいよう /本採用/
ほんさく /本作/
ほんさくひん /本作品/
ほんさん /本三/
ほんざん /本山/
ほんし /本誌/本紙/本旨/本四/本志/
ほんしおがま /本塩釜/
ほんしかきょう /本四架橋;本州四国連絡橋の架橋/
ほんしき /本式/
ほんしけいさい /本誌掲載/
ほんしけん /本試験/
ほんしこう /本施行/
ほんしつ /本質/
ほんしつてき /本質的/
ほんしつてきかいけつ /本質的解決/
ほんしつてきぶぶん /本質的部分/
ほんしつてきもんだい /本質的問題/
ほんしびさんせん /本四備讃線/
ほんしぶ /本支部/
ほんしゃ /本社/
ほんしゃがわ /本社側/
ほんしゃきのう /本社機能/
ほんしゃきんむ /本社勤務/
ほんしゃぎじゅつぶもん /本社技術部門/
ほんしゃこうじょう /本社工場/
ほんしゃしょざいち /本社所在地/
ほんしゃびる /本社ビル/
ほんしゃべっかん /本社別館/
ほんしゃまえ /本社前/
ほんしゅう /本州/
ほんしゅういなん /本州以南/
ほんしゅうがわ /本州側/
ほんしゅうじょうりく /本州上陸/
ほんしゅうじん /本州人/
ほんしゅうせい /本修正/
ほんしゅうせいし /本州製紙;[企業名]/
ほんしゅつ /本出/奔出/
ほんしゅほう /本手法/
ほんしょ /本書/本初/本所/本署/
ほんしょう /本性/本章/本省/本生;[仏教]Jataka/本症/本賞/本証/本荘/
ほんしょうきょう /本生経;[仏教]Jataka/
ほんしょうきん /本賞金/
ほんしょく /本職/本色/
ほんしょまつび /本書末尾/
ほんしよう /本仕様/
ほんしようきょだく /本使用許諾/
ほんしれんさい /本誌連載/
ほんしん /本心/本震/本審/
ほんしんさ /本審査/
ほんしんさかい /本審査会/
ほんじ /本地/本寺/本字/翻字/本辞/
ほんじぎょう /本事業/
ほんじしょ /本辞書/
ほんじしょう /本時称/
ほんじすいじゃく /本地垂迹/
ほんじすいじゃくせつ /本地垂迹説/
ほんじたい /本自体/
ほんじっけん /本実験/
ほんじつ /本日/
ほんじつちゅう /本日中/
ほんじつはつばい /本日発売/
ほんじつよなか /本日夜中/
ほんじつよる /本日夜/
ほんじゅつしき /本術式/
ほんじょ /本所/
ほんじょあずまばし /本所吾妻橋/
ほんじょう /本庄/本荘/本条/本城/本状/本匠/
ほんじょうこう /本条項/
ほんじょうぞう /本醸造/
ほんじょうほう /本情報/
ほんじん /本陣/
ほんすう /本数/
ほんすうせいげん /本数制限/
ほんすじ /本筋/
ほんずき /本好き/
ほんせい /本性;nature.「人の-は[善悪]」/本姓;original surname.「与謝蕪村、-谷口」/本制/
ほんせいひん /本製品/
ほんせいほん /本製本/
ほんせき /本籍/
ほんせきち /本籍地/
ほんせつ /本節/本説/
ほんせん /本線;main line.「山陽-」/本戦;final.「F1の-」/本選;final selection.「コンクールの-」/本船;this ship/
ほんせんうんよう /本線運用/
ほんせんかい /本選会/
ほんせんがわ /本線側/
ほんせんぎふ /本線岐阜/
ほんせんけいとう /本線系統/
ほんせんこう /本専攻/
ほんせんしゅつじょう /本戦出場/
ほんせんしゅつじょうけん /本戦出場権/
ほんせんじょう /本線上/
ほんせんそうこう /本線走行/
ほんせんぞい /本線沿い/
ほんせんとっきゅう /本線特急/
ほんせんもんてん /本専門店/
ほんせんわたし /本船渡し;[経済]free on board(FOB). 「-価格]/
ほんぜん /本膳/本然/翻然/
ほんぜんりょうり /本膳料理/
ほんそ /本訴/
ほんそう /奔走/本葬/本送/
ほんそうち /本装置/
ほんそく /本則/
ほんぞう /本草/
ほんぞうがく /本草学/
ほんぞく /本属/
ほんぞん /本尊/
ほんたい /本体/本隊/本態/
ほんたいいがい /本体以外/
ほんたいかい /本大会/
ほんたいかかく /本体価格/
ほんたいかん /本体間/
ほんたいがわ /本体側/
ほんたいきばん /本体基盤/
ほんたいこうぶ /本体後部/
ほんたいこしょう /本体故障/
ほんたいじゅうりょう /本体重量/
ほんたいせい /本態性/
ほんたいない /本体内/
ほんたいないぞう /本体内蔵/
ほんたいないぶ /本体内部/
ほんたいひだりした /本体左下/
ほんたいよう /本体用/
ほんたいろん /本体論/
ほんたく /本宅/
ほんたて /本立て/本立/
ほんだ /本田/本多/誉田/
ほんだい /本題/本代;書籍費/
ほんだいがく /本大学/
ほんだかついち /本多勝一/
ほんだぎけん /本田技研/
ほんだげきじょう /本多劇場/
ほんだそういちろう /本田宗一郎/
ほんだち /本裁ち/
ほんだて /本立/
ほんだな /本棚/
ほんだなせいり /本棚整理/
ほんち /本地/奔馳/
ほんちすいじゃくせつ /本地垂迹説/
ほんちば /本千葉/
ほんちゅー /紅中/
ほんちゅう /本中/本注/奔注/
ほんちょう /本町/本庁/本朝/
ほんちょうさ /本調査/
ほんちょうし /本調子/
ほんちょうつがん /本朝通鑑/
ほんつや /本通夜/
ほんづけ /本付/
ほんて /本手/
ほんてい /本邸/
ほんていあん /本提案/
ほんてき /本的/
ほんてぐみ /本手組/
ほんてん /本店/本展/
ほんてんちか /本店地下/
ほんてんまえ /本店前/
ほんでん /本殿/本田/本伝/
ほんでんわき /本電話機/
ほんと /本当/
ほんとう /本当/本島/本棟/奔騰/
ほんとうこう /本投稿/
ほんとうない /本島内/
ほんとくしゅう /本特集/
ほんとじ /本綴じ/
ほんど /本土/本渡/
ほんどう /本堂/本道/
ほんどうし /本動詞/
ほんどおり /本通り/
ほんどく /本読/
ほんどけっせん /本土決戦/本土決戰;「戦」旧字/
ほんどこ /本床/
ほんどせん /本土線/
ほんどほうめん /本土方面/
ほんないよう /本内容/
ほんなだい /本名題/
ほんにん /本人/
ほんにんあて /本人宛/
ほんにんいがい /本人以外/
ほんにんかくにん /本人確認/
ほんにんしだい /本人次第/
ほんにんたち /本人達/
ほんにんだん /本人談/
ほんにんどうし /本人同士/
ほんぬ /本有/
ほんぬい /本縫い;⇔仮縫い/
ほんぬり /本塗り/
ほんね /本音/
ほんねん /本年/本然/
ほんねんど /本年度/
ほんねんどさいご /本年度最後/
ほんねんどぶん /本年度分/
ほんのう /本能/
ほんのうしゅぎ /本能主義;instinctualism/
ほんのうじ /本能寺/
ほんのうてき /本能的/
ほんのうてきよっきゅう /本能的欲求/
ほんのまち /本の街/
ほんはすぬま /本蓮沼/
ほんはっぴょう /本発表/
ほんはつめい /本発明/
ほんば /本場/本葉;[植物]true leaf/奔馬/
ほんばこ /本箱/
ほんばしょ /本場所/
ほんばば /本馬場/
ほんばばにゅうじょう /本馬場入場/
ほんばもの /本場物/
ほんばん /本番/
ほんばんちゅう /本番中/
ほんばんまえ /本番前/
ほんばんよう /本番用/
ほんぱん /紅幇/
ほんひょうしき /本標識/
ほんびき /本引/
ほんぴょう /本表/
ほんぴん /本品/
ほんぶ /本部/
ほんぶこうしゃ /本部校舎/
ほんぶこうない /本部構内/
ほんぶし /本節;本式の鰹節。⇔亀節/
ほんぶしざい /本部資材/
ほんぶしん /本普請/
ほんぶせき /本部席/
ほんぶたい /本舞台/
ほんぶちいき /本部地域/
ほんぶちょう /本部長/
ほんぶっけん /本物件/
ほんぶない /本部内/
ほんぶり /本降り/
ほんぶん /本文;†text/本分;†duty.「学生の-」/
ほんぶんかかい /本分科会/
ほんぶんさんしょう /本文参照/
ほんぶんしょ /本文書/
ほんぶんしょうりゃく /本文省略/
ほんぶんちゅう /本文中/
ほんぶんまつ /本文末/
ほんぶんりゃく /本文略/
ほんぷ /本譜/
ほんぷく /本復/
ほんべつ /本別/
ほんぺん /本編/本篇/
ほんぺんしゅうりょうご /本編終了後/
ほんぺんちゅう /本編中/
ほんほうえい /本放映/
ほんほうこく /本報告/
ほんほうしき /本方式/
ほんほうそう /本放送/
ほんほうそうじ /本放送時/
ほんほうそうとうじ /本放送当時/
ほんほうほう /本方法/
ほんぽ /本舗/本圃/
ほんぽう /本邦;-初公開/本法;this law/奔放;自由-/本報/本俸;basic salary/
ほんぽうはつ /本邦初/
ほんま /本間/本馬/
ほんまち /本町/
ほんまつ /本末/
ほんまつてんとう /本末転倒/
ほんまつり /本祭り/本祭/
ほんまる /本丸/
ほんみょう /本名/
ほんみょうしょう /本命星;[陰陽道]/
ほんむ /本務/
ほんむねづくり /本棟造り;[建築]/
ほんめ /本目/
ほんめい /本命/奔命/本名/
ほんめいし /本命視/
ほんめいば /本命馬/
ほんめんきょ /本免許/
ほんもう /本望/
ほんもく /本牧/
ほんもくちょう /本牧町/
ほんもくほうめん /本牧方面/
ほんもと /本元/
ほんもの /本物/
ほんもん /本文/本問/
ほんもんじ /本門寺/
ほんや /本屋/
ほんやがい /本屋街/
ほんやく /翻訳/飜訳;「翻」異体字/
ほんやくか /翻訳家/翻訳化/
ほんやくき /翻訳機/
ほんやくきかく /翻訳規格/
ほんやくきじ /翻訳記事/
ほんやくけい /翻訳系/
ほんやくけん /翻訳権/
ほんやくさぎょう /翻訳作業/
ほんやくしゃ /翻訳者/
ほんやくしょ /翻訳書/
ほんやくじ /翻訳時/
ほんやくじょう /翻訳上/
ほんやくちゅう /翻訳中/
ほんやくばん /翻訳版/
ほんやくぶん /翻訳文/
ほんやくぶんがく /翻訳文学/
ほんやくぼん /翻訳本/
ほんやくもの /翻訳物/
ほんやばけい /本耶馬渓/
ほんやめい /本屋名/
ほんゆう /本有/
ほんゆうてき /本有的/
ほんよさん /本予算/
ほんよみ /本読み/
ほんらい /本来/
ほんらいてき /本来的/
ほんらいべつ /本来別/
ほんらん /本欄/
ほんりゅう /本流;mainstream/奔流;torrent/
ほんりゅういき /本流域/
ほんりょう /本領/
ほんりょうはっき /本領発揮/
ほんるい /本塁/
ほんるいだ /本塁打/
ほんるいだおう /本塁打王/
ほんれい /本鈴/
ほんれき /本暦/
ほんれんさい /本連載/
ほんろう /翻弄/
ほんろせん /本路線/
ほんろん /本論/
ほんろんぶん /本論文/
ぼ /母/簿/戊;つちのえ/募;募集/墓;墓地/慕;恋慕/暮;くらす/坊;(発音綴り) 裸ん坊/姆;保姆(=保母)/拇;拇印/模;規模/謨;護謨(ゴム)/菩;菩提/姥;うば/牡;(慣用音)牡丹/保;?/
ぼーあはんけい /ボーア半径/
ぼーすりゅうし /ボース粒子;boson/
ぼーとぶ /ボート部/
ぼーりうむ /Bh/Bohrium/
ぼーりんぐじょう /ボーリング場/
ぼーるあそび /ボール遊び/
ぼーるがみ /ボール紙/
ぼーるじょう /ボール状/
ぼーるだま /ボール球/
ぼーるどたい /ボールド体/
ぼーるなげ /ボール投げ/
ぼーるばこ /ボール箱/
ぼーるばん /ボール盤;穴開け機/
ぼいき /墓域/
ぼいどりつ /ボイド率/
ぼいん /母音/拇印/
ぼいんかん /母音間/
ぼいんきごう /母音記号/
ぼいんじ /母音字/
ぼいんちょう /母音長/
ぼいんちょうわ /母音調和;[言語]vowel harmony/
ぼいんにんしき /母音認識/
ぼいんぶ /母音部/
ぼう /某/棒/房/坊/帽/暮雨/謀;謀殺/暴;暴力/瀑;瀑布(ばくふ)/膨;膨張/厖;厖大/尨;むく/抱;辛抱/胞;細胞/卯;(十二支の)うさぎ/茆/昴;すばる/蟒;蟒蛇/蠎;「蟒」の異体字/鉾;ほこ/牟/眸;(ひとみ)双眸/虻;あぶ/亡;死亡/忘;忘却/忙;多忙/望;希望/妄;(漢音)妄想/氓;蒼氓/芒;すすき/茫;茫然/鋩;(切っ先)/傍;路傍/妨;妨害/紡;紡績/肪;脂肪/防;防御/旁;偏旁/榜;標榜/滂;ひろい/膀;膀胱/蒡;牛蒡/謗;誹謗/茅;ちがや/袤/冒;冒険/冐;「冒」の異体字/瑁;玳瑁(たいまい)/惘;惘然(=呆然)/网;あみ/罔;欺罔/呆;呆然/鵬;おおとり/乏;窮乏/剖;解剖/貌;風貌/貿;貿易/儚;はかな・い/懋/旄/甍;いらか/髦;たれがみ/黽/
ぼう> /某/
ぼうあく /暴悪/
ぼうあつ /暴圧/
ぼうあんき /棒暗記/
ぼうい /暴威/
ぼういざかや /某居酒屋/
ぼういん /暴飲/
ぼういんぼうしょく /暴飲暴食/
ぼうう /暴雨/
ぼうえい /防衛/
ぼうえいいかだいがっこう /防衛医科大学校;www.ndmc.ac.jp/
ぼうえいいだい /防衛医大/
ぼうえいうんてん /防衛運転/
ぼうえいぐん /防衛軍/
ぼうえいさく /防衛策/
ぼうえいしせつちょう /防衛施設庁/
ぼうえいしょう /防衛省/
ぼうえいせいこう /防衛成功/
ぼうえいせいさく /防衛政策/
ぼうえいせん /防衛戦;defensive war/防衛線;defense line/
ぼうえいせんりゃく /防衛戦略/
ぼうえいそうち /防衛装置/
ぼうえいたい /防衛隊/
ぼうえいたいしょう /防衛対象/
ぼうえいだい /防衛大/
ぼうえいだいがっこう /防衛大学校/
ぼうえいだいそつ /防衛大卒/
ぼうえいちょう /防衛庁/
ぼうえいちょうちょうかん /防衛庁長官/
ぼうえいはくしょ /防衛白書/
ぼうえいひ /防衛費/
ぼうえいもう /防衛網/
ぼうえいよう /防衛用/
ぼうえいりょく /防衛力/
ぼうえき /貿易/防疫/某駅/
ぼうえきあかじ /貿易赤字/
ぼうえきかんけい /貿易関係/
ぼうえききゅうすいぶ /防疫給水部/
ぼうえきくろじ /貿易黒字/
ぼうえきこく /貿易国/
ぼうえきしゅうし /貿易収支/
ぼうえきしょう /貿易商/
ぼうえきしょうにん /貿易商人/
ぼうえきしょうへき /貿易障壁/
ぼうえきせいげん /貿易制限/
ぼうえきとうけい /貿易統計/
ぼうえきとりひき /貿易取引/
ぼうえきふう /貿易風/
ぼうえきまさつ /貿易摩擦/
ぼうえん /望遠/防炎/防煙/
ぼうえんがわ /望遠側/
ぼうえんきょう /望遠鏡/
ぼうえんきょうざ /望遠鏡座;Telescopium(Tel)/
ぼうえんきょうや /望遠鏡屋/
ぼうえんくかく /防煙区画/
ぼうえんけい /望遠系/
ぼうえんさつえい /望遠撮影/
ぼうえんしゃ /暴煙者/
ぼうえんぞく /暴煙族/
ぼうえんれんず /望遠レンズ/
ぼうお /防汚;-性,-剤,-塗料/
ぼうおおてきぎょう /某大手企業/
ぼうおく /茅屋/
ぼうおせい /防汚性/
ぼうおん /防音/忘恩/
ぼうおんこうか /防音効果/
ぼうおんざい /防音材/
ぼうおんしつ /防音室/
ぼうおんせい /防音性/
ぼうおんせつび /防音設備/
ぼうおんたいさく /防音対策/
ぼうおんだい /某音大/
ぼうおんへき /防音壁/
ぼうか /防火/膨化/
ぼうかいしゃ /某会社/
ぼうかくかく /防火区画/
ぼうかこうぞう /防火構造;[建築]防火材などである程度の防火性を持たせた構造。slow-burning/
ぼうかざいりょう /防火材料/
ぼうかせい /防火性/
ぼうかせつび /防火設備/
ぼうかちいき /防火地域/
ぼうかでん /某家電/
ぼうかとびら /防火扉/
ぼうかび /防カビ/
ぼうかふく /防火服/
ぼうかへき /防火壁/
ぼうかりん /防火林/
ぼうかん /防寒/傍観/暴漢/坊間/望観/
ぼうかんぎ /防寒着/
ぼうかんぐ /防寒具/
ぼうかんしゃ /傍観者/
ぼうかんたいさく /防寒対策/
ぼうかんちょう /某官庁/
ぼうかんふく /防寒服/
ぼうかんぼうすい /防寒防水/
ぼうが /忘我/
ぼうがい /妨害/望外/
ぼうがいおん /妨害音/
ぼうがいこうい /妨害行為/
ぼうがいこうさく /妨害工作/
ぼうがいざつおん /妨害雑音/
ぼうがいしゃ /妨害者/
ぼうがいしんごう /妨害信号/
ぼうがくしゃ /某学者/
ぼうがしら /棒頭/
ぼうがっかい /某学会/
ぼうがっきてん /某楽器店/
ぼうがっけん /某学研/
ぼうきぎょう /某企業/
ぼうきじ /某記事/
ぼうきゃく /忘却/
ぼうきゅうだん /某球団/
ぼうきょ /暴挙/
ぼうきょう /望郷/防共/
ぼうきょうじゅ /某教授/
ぼうきょく /某局/
ぼうきれ /棒切れ/
ぼうきん /防菌/
ぼうぎ /謀議/
ぼうぎゃく /暴虐/
ぼうぎゃくてき /暴虐的/
ぼうぎょ /防御/防禦;=防御/
ぼうぎょがわ /防御側/
ぼうぎょきこう /防御機構/
ぼうぎょこうどう /防御行動/
ぼうぎょご /防御後/
ぼうぎょじ /防御時/
ぼうぎょてん /防御点/
ぼうぎょのうりょく /防御能力/
ぼうぎょりつ /防御率/
ぼうぎょりょく /防御力/
ぼうぎん /棒銀/
ぼうぎんこう /某銀行/
ぼうくう /防空/
ぼうくうがた /防空型/
ぼうくうごう /防空壕/
ぼうくうずきん /防空頭巾/
ぼうくうのうりょく /防空能力/
ぼうくん /暴君/某君/傍訓/亡君/
ぼうぐ /防具/
ぼうぐみ /棒組/
ぼうぐらふ /棒グラフ/
ぼうけい /傍系/謀計/亡兄/
ぼうけいけつぞく /傍系血族/
ぼうけいしんぞく /傍系親族/
ぼうけん /冒険/剖検/望見/傍見/
ぼうけんえいが /冒険映画/
ぼうけんおう /冒険王/
ぼうけんか /冒険家/
ぼうけんかつげき /冒険活劇/
ぼうけんき /冒険記/
ぼうけんきゅうしょ /某研究所/
ぼうけんしゃ /冒険者/
ぼうけんしゃたち /冒険者達/
ぼうけんしゅぎ /冒険主義/
ぼうけんしょうせつ /冒険小説/
ぼうけんしん /冒険心/
ぼうけんたん /冒険譚/
ぼうけんだん /冒険談/
ぼうけんてき /冒険的/
ぼうけんもの /冒険物/
ぼうけんやろう /冒険野郎/
ぼうけんりょこう /冒険旅行/
ぼうげいにん /某芸人/
ぼうげつ /某月/
ぼうげん /暴言/妄言/防眩;-フィルム/
ぼうげんしゃ /暴言者/
ぼうこ /茫乎/
ぼうこう /暴行/膀胱/棒鋼;steel bar/
ぼうこうえん /膀胱炎/
ぼうこうがん /膀胱癌/膀胱がん/膀胱ガン/
ぼうこうこう /某高校/
ぼうこうざい /暴行罪/
ぼうこうじけん /暴行事件/
ぼうこうない /膀胱内/
ぼうこく /亡国/某国/亡國/坊刻/
ぼうこくりつだいがく /某国立大学/
ぼうこひょうが /暴虎馮河;無鉄砲/
ぼうこん /亡魂/
ぼうご /防護/妄語/
ぼうごししん /防護指針/
ぼうごてん /防護点/
ぼうごふく /防護服/
ぼうごへき /防護壁/
ぼうごむせん /防護無線/
ぼうさ /防砂/
ぼうさい /防災/亡妻/
ぼうさいかぎけん /防災科技研/
ぼうさいくんれん /防災訓練/
ぼうさいじょうほう /防災情報/
ぼうさいずきん /防災頭巾/
ぼうさいせつび /防災設備/
ぼうさいちず /防災地図/
ぼうさき /棒先/
ぼうさくひん /某作品/
ぼうさっか /某作家/
ぼうさつ /謀殺/忙殺/
ぼうさてい /防砂堤/
ぼうさま /坊様/
ぼうさりん /防砂林/
ぼうさん /坊さん/
ぼうざっし /某雑誌/
ぼうし /防止/帽子/某氏/某誌/紡糸/某紙/亡姉/暴死;急死/亡子/望祀/
ぼうしかのう /防止可能/
ぼうしきこう /防止機構/
ぼうしきのう /防止機能/
ぼうしさく /防止策/
ぼうしざい /防止剤/
ぼうしそう /防止層/
ぼうしそうち /防止装置/
ぼうしそち /防止措置/
ぼうしたいさく /防止対策/
ぼうしつ /防湿/亡失/房室/忘失/
ぼうしつざい /防湿剤/
ぼうしほう /防止法/
ぼうしゃ /某社/房舎/紡車/
ぼうしや /帽子屋/
ぼうしゅ /芒種;[二十四節気]6.6頃/
ぼうしゅう /防臭/房州;安房(千葉)/防州;周防(山口)/
ぼうしゅうかんし /某週刊誌/
ぼうしゅうざい /防臭剤/
ぼうしゅく /防縮/昴宿;Pleiades/
ぼうしゅっぱんしゃ /某出版社/
ぼうしょ /某所/防暑/謀書/
ぼうしょう /傍証/帽章/
ぼうしょうよう /某商用/
ぼうしょく /暴食/紡織/望蜀/
ぼうしょくざい /防食剤/
ぼうしょてん /某書店/
ぼうしよう /防止用/
ぼうしん /防振/望診/傍心;excentre/冒進/亡心/
ぼうしんねんかい /忘新年会/
ぼうしんぶん /某新聞/
ぼうしんぶんしゃ /某新聞社/
ぼうじ /防磁/房事/亡児/
ぼうじしゃく /棒磁石;bar magnet/
ぼうじつ /某日/望日;陰暦15日/
ぼうじどうしゃがいしゃ /某自動車会社/
ぼうじま /棒縞/
ぼうじむしょ /某事務所/
ぼうじゃくぶじん /傍若無人/
ぼうじゅ /傍受/
ぼうじゅつ /棒術/
ぼうじゅん /膨潤/
ぼうじょ /防除/
ぼうじょう /棒状/坊城;みやこ/暴状/
ぼうじょうれん /某常連/
ぼうじん /防塵/防刃;stabproof.刺されても安心/
ぼうすい /防水/紡錘/
ぼうすいえき /防水液/
ぼうすいかこう /防水加工/
ぼうすいけい /紡錘形/紡錘型/
ぼうすいこうか /防水効果/
ぼうすいざい /防水剤/
ぼうすいしよう /防水仕様/
ぼうすいせい /防水性/
ぼうすいせいのう /防水性能/
ぼうすいたいさく /防水対策/
ぼうすいちゅう /紡錘虫/
ぼうすいふ /防水布/
ぼうすいぼうかん /防水防寒/
ぼうすじ /某筋/
ぼうず /坊主/坊子/
ぼうずあたま /坊主頭/
ぼうずし /棒寿司/
ぼうずめくり /坊主めくり/坊主捲り/
ぼうせい /防錆/暴政/昴星;Pleiads/
ぼうせいしょり /防錆処理/
ぼうせいとう /某政党/
ぼうせいまる /望星丸/
ぼうせき /紡績/
ぼうせつ /防雪/
ぼうせつえん /傍接円/
ぼうせつりん /防雪林/
ぼうせん /防戦/傍線/棒線/防染/
ぼうせんいっぽう /防戦一方/
ぼうせんぱい /某先輩/
ぼうせんもう /防潜網/
ぼうぜん /呆然/茫然;広大。また≒呆然/惘然;≒呆然/
ぼうぜんじしつ /茫然自失/呆然自失/
ぼうそう /暴走/房総/
ぼうそううんてん /暴走運転/
ぼうそうかいし /暴走開始/
ぼうそうかくせん /房総各線/
ぼうそうぎみ /暴走気味/
ぼうそうしゃ /暴走車/
ぼうそうじこ /暴走事故/
ぼうそうじょうたい /暴走状態/
ぼうそうぞく /暴走族/
ぼうそうちゅう /暴走中/
ぼうそうとっきゅう /房総特急/
ぼうそうはんとう /房総半島/
ぼうそうほうめん /房総方面/
ぼうたいしゅう /某大衆/
ぼうたいほう /暴対法;暴力団対策法/
ぼうたおし /棒倒し/
ぼうたかとび /棒高跳び;vault/棒高飛び;?/
ぼうたて /棒立て/
ぼうだ /滂沱/
ぼうだい /膨大/厖大/傍題/防大/尨大/某大/
ぼうだいがく /某大学/
ぼうだいがくこうがくぶ /某大学工学部/
ぼうだち /棒立ち/
ぼうだに /防ダニ/
ぼうだま /棒球/
ぼうだら /棒鱈/
ぼうだん /防弾/妄談/
ぼうだんがらす /防弾ガラス/
ぼうだんちょっき /防弾チョッキ/
ぼうだんよう /防弾用/
ぼうちゅう /防虫/忙中/房中/傍注/
ぼうちゅうがく /某中学/
ぼうちゅうざい /防虫剤/
ぼうちょう /包丁/傍聴/膨張/膨脹;=膨張/防長;周防と長門/防潮/防諜;antispy/
ぼうちょううちゅう /膨張宇宙;expanding universe/
ぼうちょうけいすう /膨張係数;[化学]expansion coefficient/
ぼうちょうざい /膨張剤/
ぼうちょうせき /傍聴席/
ぼうちょうにん /傍聴人/
ぼうちょうへき /防潮壁/
ぼうちょうりつ /膨張率/
ぼうつい /暴追/
ぼうてい /亡弟/
ぼうてき /防滴/
ぼうてつ /耄耋/
ぼうてん /傍点/某店/
ぼうでんき /某電器/
ぼうでんきてん /某電気店/
ぼうと /暴徒/
ぼうとう /冒頭/暴投/暴騰/
ぼうとうちんじゅつ /冒頭陳述/
ぼうとうぶ /冒頭部/
ぼうとうぶぶん /冒頭部分/
ぼうとく /冒涜/
ぼうどう /暴動/
ぼうどうじんし /某同人誌/
ぼうどうすんぜん /暴動寸前/
ぼうどく /防毒/
ぼうどくますく /防毒マスク/
ぼうない /房内/
ぼうにょう /乏尿/
ぼうねん /忘年/
ぼうねんかい /忘年会/
ぼうの /房野/坊野/
ぼうのつ /坊津/
ぼうはい /暴牌/
ぼうはく /傍白/
ぼうはつ /暴発/
ぼうはてい /防波堤/
ぼうはん /防犯/謀叛/謀判/
ぼうはんかめら /防犯カメラ/
ぼうはんしそう /防犯思想/
ぼうはんじょう /防犯上/
ぼうはんせい /防犯性/
ぼうはんたいさく /防犯対策/
ぼうはんとう /防犯灯/
ぼうはんばいてん /某販売店/
ぼうはんびでお /防犯ビデオ/
ぼうはんぶざー /防犯ブザー/
ぼうはんよう /防犯用/
ぼうはんれんらくじょ /防犯連絡所/
ぼうばい /防黴/
ぼうばく /茫漠/
ぼうばり /棒針;編み物に使う針 cf.鉤針/
ぼうばりあみ /棒針編み/
ぼうばんぐみ /某番組/
ぼうひと /某人/
ぼうひょう /暴評/
ぼうひん /防貧;貧困の予防。⇔救貧/
ぼうび /防備/
ぼうびき /棒引き/
ぼうびや /棒火矢/棒火箭/
ぼうびろく /忘備録/
ぼうふ /防腐/亡父/亡夫/
ぼうふう /暴風/防風/
ぼうふういき /暴風域/
ぼうふうう /暴風雨/
ぼうふうけいほう /暴風警報/
ぼうふうけん /暴風圏/
ぼうふうせい /防風性/
ぼうふうりん /防風林/
ぼうふざい /防腐剤/
ぼうふら /孑孑/
ぼうふり /棒振り/
ぼうぶら /南瓜/
ぼうへき /防壁/
ぼうほうめん /某方面/
ぼうぼ /亡母/
ぼうぼう /某々/茫々;草-/茫茫/
ぼうまい /亡妹/茫昧;vague/
ぼうまん /膨満/暴慢/
ぼうまんかん /膨満感/
ぼうまんがか /某漫画家/
ぼうみん /暴民/
ぼうめい /亡命/
ぼうめいさき /亡命先/
ぼうめいしゃ /亡命者/
ぼうめいじけん /亡命事件/
ぼうめいせいけん /亡命政権;チベット-/
ぼうめいせいふ /亡命政府/
ぼうめつ /亡滅/
ぼうもう /紡毛/
ぼうや /坊や/坊屋;姓/
ぼうゆう /亡友/暴勇/
ぼうゆうじん /某友人/
ぼうゆうめい /某有名/
ぼうゆうめいじん /某有名人/
ぼうよう /望洋/茫洋;果てしなく広い。「-たる大海原」/亡羊;-の嘆,多岐-/滂洋/
ぼうようりょう /望洋寮/
ぼうよみ /棒読み/棒読/
ぼうらく /暴落/
ぼうり /暴利/
ぼうりゃく /謀略/
ぼうりゃくせつ /謀略説/某略説/
ぼうりゅう /傍流/
ぼうりょう /坊領/
ぼうりょく /暴力/
ぼうりょくかくめい /暴力革命/
ぼうりょくざた /暴力沙汰/
ぼうりょくしょうせつ /暴力小説/
ぼうりょくせい /暴力性/
ぼうりょくだん /暴力団/
ぼうりょくだんいん /暴力団員/
ぼうりょくだんしんぽう /暴力団新法/
ぼうりょくだんたいさくほう /暴力団対策法/
ぼうりょくてき /暴力的/
ぼうれい /亡霊/暴戻/
ぼうれいたち /亡霊達/
ぼうろう /望楼/
ぼうろん /暴論/傍論/
ぼうん /暮雲/
ぼえき /母液/
ぼおん /母音/
ぼか /簿価/
ぼかい /暮改/
ぼかし /暈し/
ぼかん /母艦/母管/
ぼかんすう /母関数/
ぼかんない /母艦内/
ぼがい /簿外;(会計)「簿外債務」「簿外資産」など、計算書類に計上されない権利義務/
ぼがいしさん /簿外資産/
ぼがん /母岩/
ぼき /簿記/
ぼきかいけい /簿記会計/
ぼきしき /簿記式/
ぼきょくせん /母曲線/
ぼきょくめん /母曲面/
ぼきん /募金/
ぼきんかつどう /募金活動/
ぼきんがく /募金額/
ぼきんばこ /募金箱/
ぼく /僕/木/牧;牧場/朴;素朴/卜;卜占/撲;撲滅/樸;こはだ/濮;(山東省の川)濮水/墨;墨跡/睦;親睦/穆/攴;とまた/攵/目;(漢音)面目/瀑;(呉音の一つ)/
ぼくあて /僕宛/
ぼくいがい /僕以外/
ぼくか /墨家/
ぼくが /墨画/
ぼくぎゅう /牧牛/
ぼくぎょ /墨魚/
ぼくこう /墨攻/
ぼくこじん /僕個人/
ぼくさつ /撲殺/
ぼくし /牧師/墨子/
ぼくしゃ /牧舎/卜者/
ぼくしゅ /墨守/
ぼくしょ /墨書/
ぼくしょう /木匠/
ぼくしょく /墨色/
ぼくしん /牧神/
ぼくしんぐぶ /ボクシング部/
ぼくじ /墨字/卜辞/
ぼくじしん /僕自身/
ぼくじゅう /墨汁/
ぼくじょう /牧場/卜定/
ぼくじょうかんけいしゃ /牧場関係者/
ぼくじょうちょう /牧場長/
ぼくじん /牧人/
ぼくすい /牧水;人名,若山-/墨水/
ぼくせき /墨跡/木石/墨蹟/
ぼくせん /卜占/
ぼくぜい /卜筮/
ぼくそう /牧草/
ぼくそうち /牧草地/
ぼくたく /木鐸/
ぼくたち /僕達/
ぼくちく /牧畜/木竹/
ぼくちくみんぞく /牧畜民族/
ぼくてき /牧笛/
ぼくとう /木刀/墨東/
ぼくとつ /朴訥/木訥;=朴訥/
ぼくどう /牧童/
ぼくにょう /攴繞;[部首]「攵」または「攴」/攵繞/
ぼくねんじん /朴念仁/
ぼくは /僕は/
ぼくひとり /僕一人/
ぼくふ /牧夫/
ぼくみん /牧民/
ぼくみんかん /牧民官/
ぼくめつ /撲滅/
ぼくめつうんどう /撲滅運動/
ぼくよう /牧羊/
ぼくようしん /牧羊神/
ぼくら /僕等/僕ら/
ぼけ /木瓜/惚け/
ぼけあじ /ボケ味;[写真]/
ぼけい /母系/母型/
ぼけいしゃかい /母系社会;[社会学]matrilineal society/
ぼけつ /墓穴/墓碣;墓石/
ぼけなす /惚け茄子/
ぼけろうじん /ボケ老人/
ぼけん /母権/
ぼけんせい /母権制/
ぼこ /凹/
ぼこう /母校/母港/母后/
ぼこく /母国/
ぼこくご /母国語/
ぼご /母語/
ぼごいがい /母語以外/
ぼごわしゃ /母語話者/
ぼさい /募債/
ぼさつ /菩薩/
ぼさつかい /菩薩戒/
ぼさつぎょう /菩薩行/
ぼさん /墓参/
ぼざい /母材/
ぼし /母子/墓誌/母指;手の親指/拇指;手の親指/母趾;足の親指/拇趾;足の親指/星/干し/乾し/
ぼしかてい /母子家庭/
ぼしかんせん /母子感染/
ぼしき /母式/
ぼしつ /墓室/
ぼしづれ /母子連れ/
ぼしてちょう /母子手帳/
ぼしほけん /母子保健/
ぼしほけんほう /母子保健法/
ぼしゅう /募集/暮秋/
ぼしゅうきかん /募集期間/
ぼしゅうきじ /募集記事/
ぼしゅうけっかほうこく /募集結果報告/
ぼしゅうこうこく /募集広告/
ぼしゅうこくち /募集告知/
ぼしゅうしめきり /募集締切/
ぼしゅうじょうけん /募集条件/
ぼしゅうじんいん /募集人員/
ぼしゅうせつりつ /募集設立/
ぼしゅうたいしょう /募集対象/
ぼしゅうだん /母集団/
ぼしゅうちゅう /募集中/
ぼしゅうていいん /募集定員/
ぼしゅうにんずう /募集人数/
ぼしゅうようこう /募集要項/募集要綱/
ぼしゅうようこうせいきゅう /募集要項請求/
ぼしゅうようりょう /募集要領/
ぼしゅん /暮春/
ぼしょ /墓所/簿書/
ぼしょう /暮鐘/
ぼしょく /暮色/
ぼしりょう /母子寮/
ぼしん /戊辰/
ぼしんしょうしょ /戊申詔書/
ぼしんせんそう /戊辰戦争/
ぼじゅつゆめものがたり /戊戌夢物語/
ぼじょう /慕情/
ぼすう /母数/
ぼすざる /ボス猿/
ぼせい /母性/母星/
ぼせいあい /母性愛/
ぼせいげんり /母性原理/
ぼせいてき /母性的/
ぼせいほご /母性保護/
ぼせいほんのう /母性本能/
ぼせき /墓石/
ぼせつ /暮雪/
ぼせん /母船/母線/
ぼぜん /墓前/
ぼたい /母体/母胎/
ぼたいない /母体内/
ぼたいほごほう /母体保護法/
ぼたにかきょう /菩多尼訶経;(1822) <botanica/
ぼたもち /牡丹餅/
ぼたやま /ボタ山/ぼた山/
ぼたゆき /ぼた雪/
ぼたん /牡丹/釦/鈕/
ぼたんあな /ボタン穴/
ぼたんいろ /牡丹色/
ぼたんか /ボタン科/Paeoniaceae/
ぼたんこう /牡丹江/
ぼたんざくら /牡丹桜/
ぼたんでんち /ボタン電池;button battery/
ぼたんどうろう /牡丹灯籠/
ぼたんなべ /牡丹鍋/
ぼたんもく /ボタン目/Paeoniales/
ぼたんゆき /牡丹雪/
ぼだい /菩提/
ぼだいしょ /菩提所/
ぼだいしん /菩提心;[仏教]/
ぼだいじ /菩提寺/
ぼだいじゅ /菩提樹/
ぼち /墓地/
ぼっ /没/坊/沒;「没」の旧字/
ぼっか /牧歌/
ぼっかい /渤海/
ぼっかく /墨客/
ぼっかてき /牧歌的/
ぼっき /勃起/
ぼっきしょうがい /勃起障害;erectile dysfunction(ED)/
ぼっきふぜん /勃起不全/
ぼっきゃく /没却/
ぼっきょう /木強/
ぼっきょうかん /木強漢/
ぼっきりょく /勃起力/
ぼっくすせき /ボックス席/
ぼっこう /勃興/墨香/
ぼっこうき /勃興期/
ぼっこうしょう /没交渉/
ぼっこせい /没個性/
ぼっこせいてき /没個性的/
ぼっこん /墨痕/
ぼっしゅ /没取/
ぼっしゅう /没収/
ぼっしゅうじあい /没収試合;[野球]forfeited game/
ぼっしゅみ /没趣味/
ぼっしょ /没書/
ぼっちゃん /坊ちゃん/坊っちゃん/
ぼっとう /没頭/
ぼっぱつ /勃発/
ぼつ /没/歿;(人の死)戦歿/沒;「没」の旧字/勃;勃発/渤;渤海/
ぼつ> /没;没論理,没交渉,没常識/
ぼつが /没我/
ぼつこうしょう /没交渉/
ぼつこせい /没個性/
ぼつこせいてき /没個性的/
ぼつご /没後/歿後/
ぼつじょうしき /没常識/
ぼつぜん /没前/勃然/歿前;=没前/
ぼつにゅう /没入/
ぼつねん /没年/歿年/
ぼつふうりゅう /没風流/
ぼつめつ /没滅/
ぼつらく /没落/
ぼつらくきぞく /没落貴族/
ぼつりぬすきん /ボツリヌス菌;(botulinum) 食中毒/
ぼてん /母点/
ぼてんたい /母天体/
ぼどう /母堂/
ぼにゅう /母乳/
ぼね /骨/
ぼはん /母斑/墓畔/
ぼば /牡馬/
ぼひ /墓碑/
ぼひめい /墓碑銘/
ぼひょう /墓標/墓表;=墓標/
ぼふ /母父/
ぼぶんさん /母分散/
ぼへい /募兵/
ぼへいきん /母平均/
ぼほう /母法;⇔子法/模倣/
ぼめい /墓銘/
ぼや /小火/暮夜/
ぼよう /慕容/
ぼら /鯔/鰡/
ぼり /堀/
ぼりゅーむかん /ボリューム感/
ぼりょう /墓陵/
ぼるつまんていすう /ボルツマン定数;1.3806503*10^-23 J・K^-1/
ぼれい /牡蛎;「蠣」異体字/
ぼろ /襤褸/
ぼろきれ /襤褸切れ/
ぼろくず /ボロ屑/
ぼろくそ /襤褸糞/
ぼろぞうきん /ボロ雑巾/
ぼろまけ /ボロ負け/ぼろ負け/
ぼろもうけ /ボロ儲け/ぼろ儲け/
ぼん /盆/凡;平凡/梵;梵字/本/煩;(呉音) 煩悩/
ぼん> /凡;(mediocre) 凡策,凡ミス,凡フライ/
ぼんおどり /盆踊り/盆踊/
ぼんがいちにょ /梵我一如/
ぼんくら /盆暗/
ぼんくれ /盆暮れ/盆暮/
ぼんぐ /凡愚/
ぼんけい /盆景/
ぼんこつ /凡骨/
ぼんご /梵語/
ぼんさい /盆栽/凡才/
ぼんさく /凡作/凡策/
ぼんしつ /凡失/
ぼんしゅ /凡手/
ぼんしょ /梵書/凡書/
ぼんしょう /梵鐘/凡小/
ぼんじ /梵字/
ぼんじん /凡人/
ぼんせき /盆石/
ぼんせん /凡戦/
ぼんそう /凡走/
ぼんぞく /凡俗/
ぼんたい /凡退/
ぼんたん /文旦;ミカン科。ぶんたん。/
ぼんだ /凡打/
ぼんだて /盆点/
ぼんだな /盆棚/
ぼんち /盆地/
ぼんちぎり /盆地霧/
ぼんぢょうちん /盆提灯/
ぼんてん /梵天/
ぼんてんたいしゃく /梵天帝釈/
ぼんのう /煩悩/
ぼんのうそくぼだい /煩悩即菩提/
ぼんぴゃく /凡百/
ぼんぶん /梵文/
ぼんぷ /凡夫/
ぼんべい /孟買/
ぼんぺい /凡平/
ぼんみす /凡ミス/
ぼんやすみ /盆休み/
ぼんよう /凡庸/
ぼんりゃくだて /盆略点/
ぼんりょ /凡慮/
ぽ /歩/舗/舖;旧字/
ぽーつますじょうやく /ポーツマス条約;(Portsmouth) 1905/
ぽーとかん /ポート間/
ぽーとばんごう /ポート番号/
ぽーらんど /波蘭/
ぽーらんどきほう /ポーランド記法/
ぽーらんどご /ポーランド語/
ぽーらんどじん /ポーランド人/
ぽあそんひ /ポアソン比;[物理]Poisson's ratio.応力に水平な方向と垂直な方法との歪みの比/
ぽあそんぶんぷ /ポアソン分布/
ぽいすて /ポイ捨て/
ぽいんたがた /ポインタ型/
ぽいんとせい /ポイント制/
ぽう /包/報/方/法/烹/砲/
ぽえにせんそう /ポエニ戦争;BC264-BC146/
ぽけっとばん /ポケット版/
ぽすとこうぞうしゅぎ /ポスト構造主義;post-structuralisme/
ぽち /・/
ぽちぶくろ /ポチ袋/ぽち袋/
ぽっくりびょう /ぽっくり病/
ぽっとで /ぽっと出/
ぽっとなえ /ポット苗/
ぽつ /・/
ぽつだむせんげん /ポツダム宣言;(Potsdam) 1945/
ぽぷらなみき /ポプラ並木/
ぽりえんかびにる /ポリ塩化ビニル/
ぽりこう /ポリ公/
ぽりぶくろ /ポリ袋/
ぽりぺぷちどさ /ポリペプチド鎖/
ぽるとがる /葡萄牙;Portugal/
ぽるとがるご /ポルトガル語;ポルトガル・ブラジルの公用語。アフリカでも使われる。/
ぽるとがるじん /ポルトガル人/
ぽろにうむ /Po/Polonium/
ぽん /本/椪/
ぽんかん /椪柑/
ぽんず /ポン酢/
ぽんちえ /ポンチ絵/
ぽんとちょう /先斗町/
ぽんど /£;pond,pound/磅/
ぽんびき /ぽん引き/ポン引き/
ぽんぷざ /ポンプ座;Antlia(Ant)/
ぽんぷしき /ポンプ式/
ぽんぷしゃ /ポンプ車/
ま /間/魔/真/麻/磨;みがく/摩;こする/馬/目/墹/媽;母/痲;痲痺/嘛;喇嘛(ラマ)/麼;(助字)/茉;茉莉/眞;「真」の旧字(人名用漢字)/万;(人名用)/満;?/
ま> /真/魔;魔酒,魔軍,魔猫/
まーじゃん /麻雀/
まーじゃんきょうしつ /麻雀教室/
まーじゃんよう /麻雀用/
まーすとりひとじょうやく /マーストリヒト条約;Maastricht Treaty(1992)/
まーぼ /麻婆/
まーぼー /麻婆/
まーぼーどうふ /麻婆豆腐/
まーぼーなす /麻婆茄子/
まーぼどーふ /麻婆豆腐/
まーぼどうふ /麻婆豆腐/
まーぼなす /麻婆茄子/
まーぼはるさめ /麻婆春雨/
まあい /間合/間合い/
まあこ /真亜子/
まあじ /真鰺/
まあじゃん /麻雀/
まあじゃんげきが /麻雀劇画/
まあじゃんたいかい /麻雀大会/
まあじゃんほうろうき /麻雀放浪記/
まあじゃんまんが /麻雀漫画/
まあぼうどうふ /麻婆豆腐/
まい /枚/毎/米/舞/麻衣/真衣/舞衣/真依/埋;埋没/邁;邁進/妹;姉妹/昧;曖昧/眛;≒昧/瑁/参;動詞語幹/
まい> /毎/
まいあさ /毎朝/
まいいがい /枚以外/
まいおうぎ /舞扇/
まいおか /舞岡/
まいおさめ /舞い納め/
まいか /真烏賊/
まいかい /毎回/
まいかいおうぼ /毎回応募/
まいかいそくてい /毎回測定/
まいかいとくてん /毎回得点/
まいかいはっぴょう /毎回発表/
まいかいまいかい /毎回毎回/
まいかぜ /舞風/
まいき /毎期/
まいきょ /枚挙/
まいぎぬ /舞衣/
まいくろ /μ/micro;[SI接頭語]μ,10^-6/
まいくろは /マイクロ波/
まいくろめーとる /μm;(10^-6)m/
まいぐみ /枚組/
まいげつ /毎月/
まいげつだい /毎月第/
まいこ /舞子/舞妓/毎戸/麻衣子/磨衣子/
まいこかいがん /舞子海岸/
まいこつ /埋骨/
まいご /迷子/
まいごう /毎号/
まいさか /舞阪/
まいし /昧死/
まいしあい /毎試合/
まいしゅう /毎週/
まいしゅうかようび /毎週火曜日/
まいしゅうきんようび /毎週金曜日/
まいしゅうすいようび /毎週水曜日/
まいしゅうどよう /毎週土曜/
まいしゅうどようび /毎週土曜日/
まいしゅうなんようび /毎週何曜日/
まいしゅうにちよう /毎週日曜/
まいしゅうにちようび /毎週日曜日/
まいしゅうはっこう /毎週発行/
まいしゅうはっぴょう /毎週発表/
まいしゅうひとり /毎週一人/
まいしゅうほうそう /毎週放送/
まいしゅうまいつき /毎週毎月/
まいしゅうまつ /毎週末/
まいしょく /毎食/
まいしん /邁進/
まいじ /毎時/毎次/
まいじかん /毎時間/
まいす /売僧/
まいすう /枚数/
まいせいじ /毎正時/
まいせき /毎夕/
まいせつ /埋設/
まいせつぶつ /埋設物/
まいそう /埋葬/昧爽/
まいそうきろく /埋葬記録/
まいそうたい /埋葬隊/
まいそうち /埋葬地/
まいぞう /埋蔵/
まいぞうきん /埋蔵金/
まいぞうひん /埋蔵品/
まいぞうぶつ /埋蔵物/
まいぞうぶんかざい /埋蔵文化財/
まいぞうりょう /埋蔵量/
まいた /毎田/
まいたけ /舞茸/
まいだ /枚田/
まいちもんじ /真一文字/
まいつき /毎月/
まいつきなんにち /毎月何日/
まいつきはっこう /毎月発行/
まいつきまつ /毎月末/
まいづる /舞鶴/
まいづるこうこう /舞鶴高校/
まいづるせん /舞鶴線/
まいとし /毎年/
まいとしいっかい /毎年一回/
まいとしけいぞく /毎年継続/
まいとしこうしん /毎年更新/
まいとしこうれい /毎年恒例/
まいとしさんか /毎年参加/
まいとしはっこう /毎年発行/
まいとしひとり /毎年一人/
まいとしほうそう /毎年放送/
まいとねりうむ /Mt/Meitnerium/
まいど /毎度/
まいない /賂/賄/
まいなす /−;minus/
まいなすあるふぁ /マイナスα/
まいなすしこう /マイナス思考/
まいなすせいちょう /マイナス成長/
まいなすめん /マイナス面/
まいなすよういん /マイナス要因/
まいなすようそ /マイナス要素/
まいなつ /毎夏/
まいにち /毎日/
まいにちいっかい /毎日一回/
まいにちうんてん /毎日運転/
まいにちおうかん /毎日王冠/
まいにちごご /毎日午後/
まいにちごぜん /毎日午前/
まいにちしんぶん /毎日新聞/
まいにちしんぶんしゃ /毎日新聞社;[企業名]www.mainichi.co.jp/
まいにちつうきん /毎日通勤/
まいにちはい /毎日杯/
まいにちほうそう /毎日放送/
まいにちまいにち /毎日毎日/
まいにちりよう /毎日利用/
まいねん /毎年/
まいねんかいさい /毎年開催/
まいねんびと /毎年人/
まいのうみ /舞の海/
まいはま /舞浜/
まいはら /米原/
まいばしょ /毎場所/
まいばら /米原/
まいばらえき /米原駅/
まいばん /毎晩/
まいひめ /舞姫/
まいびと /舞人/
まいびょう /毎秒/
まいふん /毎分/
まいぼつ /埋没/
まいまい /毎々/舞舞/
まいまいむし /舞舞虫/
まいめ /枚目/
まいや /毎夜/米谷/
まいゆう /毎夕/
まいよ /毎夜/
まいよう /枚葉/
まいようし /枚葉紙/
まいる /哩/
まいわし /真鰯/
まうえ /真上/
まうしろ /真後ろ/真後/
まうち /間内/
まうら /真裏/
まえ /前/
まえあし /前足/前脚/
まえいた /前板/
まえいわい /前祝/前祝い/
まえうけ /前受/
まえうけきん /前受金/
まえうしろ /前後ろ/
まえうた /前歌/前唄/
まえうり /前売り/前売/
まえうりかいしび /前売開始日/
まえうりけん /前売券/前売り券/
まえうりちゅう /前売中/
まえお /前尾/
まえおか /前岡/
まえおき /前置き/前置/
まえかがみ /前屈み/
まえかけ /前掛け/
まえかた /前方/
まえかれ /前彼;[口]前の彼氏/
まえかわ /前川/
まえかんじょう /前勘定/
まえがき /前書き/前書/前垣/
まえがし /前貸し/
まえがしきん /前貸金/
まえがしら /前頭/
まえがしらひっとう /前頭筆頭/
まえがみ /前髪/
まえがり /前借り/
まえがりきん /前借金/
まえがわ /前側/前川/
まえきん /前金/
まえく /前句/
まえくづけ /前句付け/前句付/
まえげいき /前景気/
まえげり /前蹴り/
まえこうか /前効果/
まえこうじょう /前口上/
まえこうてい /前工程/
まえこぐち /前小口/
まえこごみ /前屈み;=まえかがみ/
まえさがり /前下がり/
まえさと /前里/
まえさばき /前捌き;[相撲]/
まえさわ /前沢/
まえさんしょう /前参照/
まえざわ /前沢/前澤/
まえしま /前島/
まえしょうとう /前照灯/
まえしょり /前処理/
まえしょりぶ /前処理部/
まえじ /前地/
まえじた /前舌/
まえじたぼいん /前舌母音;[音声学]front vowel/
まえじま /前島/前嶋/
まえじゅんび /前準備/
まえじらせ /前知らせ/
まえすうれつ /前数列/
まえずもう /前相撲/
まえずり /前刷/前刷り/
まえせつ /前説/
まえせんでん /前宣伝/
まえぜつ /前説/
まえだ /前田/前多/
まえだおし /前倒し/
まえだせいそん /前田青邨;(1885-1977)日本画家/
まえだて /前立/
まえだとしいえ /前田利家/
まえだれ /前垂れ/
まえち /前地/
まえつえ /前津江/
まえつぼ /前壺/
まえづけ /前付/
まえどうさ /前動作/
まえどなり /前隣/
まえどまり /前泊/
まえどり /前録り/
まえにわ /前庭/
まえの /前野/
まえのひ /前の日/
まえのぶ /前信/
まえのめり /前のめり/
まえのり /前ノリ/
まえのりょうたく /前野良沢/
まえはし /前橋/
まえはた /前畑/
まえはら /前原/
まえば /前歯/前場/
まえばし /前橋/
まえばしし /前橋市/
まえばししりつ /前橋市立/
まえばら /前原/
まえばらい /前払い/前払/
まえばらいきん /前払金/
まえばらいひよう /前払費用/
まえばり /前貼り/
まえばりおおくち /前張大口/
まえばる /前原/
まえばんぐみ /前番組/
まえひょうばん /前評判/
まえび /前日/
まえびき /前弾き;前奏/
まえびろ /前広/
まえふり /前振/
まえぶれ /前触れ/
まえほ /前穂/
まえほうこう /前方向/
まえほり /前堀/
まえまえ /前々/前前/
まえみ /前身;前身頃/真恵美/
まえみごろ /前身頃/
まえみつ /前褌;[相撲]/
まえむき /前向き/
まえもって /前もって/前以て/豫て;「予」の旧字/
まえやく /前厄/
まえやち /前谷地/
まえやま /前山/
まえやまだ /前山田/
まえわ /前輪/
まえわたし /前渡し/
まえわたしきん /前渡金/
まお /真央/真緒/麻央;名/真麻/苧麻/
まおう /魔王/麻黄/
まおたいちゅー /茅台酒/
まおとこ /間男/
まおもて /真面/真表/
まおりご /マオリ語;Maori/
まか /摩訶/摩可;正しい候補か?/
まかい /魔界/
まかいじん /魔界人/
まかいとし /魔界都市/
まかいの /馬飼野/
まかいむら /魔界村/
まかお /澳門;Macao/
まかげ /目陰/目蔭/
まかじき /真旗魚/
まかず /間数/
まかせ /任せ/
まかぜ /魔風/
まかつきゅう /磨羯宮;[十二宮]やぎ座(12.22-1.19)/
まかない /賄い/
まかふしぎ /摩訶不思議/
まかべ /真壁/
まかり /真狩/
まがい /紛い;詐欺-,-物/擬/紛/
まがいもの /紛い物/擬物/紛物/
まがお /真顔/
まがき /籬/曲垣/
まがごと /禍事/禍言/
まがし /間貸し/
まがた /澗潟/
まがたま /勾玉/曲玉/
まがどり /凶鳥/
まがな /真仮名;万葉仮名/
まがも /真鴨/
まがら /真柄/
まがり /間借り/
まがりかど /曲がり角/曲り角/
まがりなり /曲がり形;NB:「まがりなり」表記が普通/曲り形/
まき /巻/薪/巻き;納豆-,河童-,-が甘い/牧/槙/槇;「槙」の旧字(人名用漢字)/蒔;蒔絵/真希/真紀/真木/真樹/麻紀/麻希/真季/真貴/麻貴/真城/卷;「巻」の旧字(人名用漢字)/
まきあげ /巻上/巻揚/捲揚/
まきあげき /巻き揚げ機;winch/巻揚げ機/
まきあみ /巻き網/巻網/
まきえ /蒔絵/撒き餌/
まきお /真樹夫/真紀夫/牧尾/牧朗/
まきおか /牧丘/牧岡/
まきおとし /巻き落とし/
まきかえし /巻き返し/
まきかわ /巻川/
まきがい /巻貝/巻き貝/
まきがみ /巻上;姓/巻紙/巻き紙/
まきがり /巻狩/
まきぐち /牧口/
まきぐも /巻雲/
まきげ /巻き毛/巻毛/
まきこ /真紀子/牧子/眞紀子/真希子/麻紀子/真喜子/真貴子/真木子/真樹子/万紀子/満喜子/マキ子/正希子/麻起子/真生子/満紀子/
まきこみ /巻き込み/
まきしま /牧島/槙島/
まきしょてん /槇書店/
まきじく /巻軸/巻き軸/
まきじた /巻き舌/巻舌/
まきじゃく /巻尺/巻き尺/
まきすう /巻数/
まきずし /巻き寿司/巻寿司/巻き鮨/
まきせ /牧瀬/
まきせん /巻線/巻き線/
まきせんすう /巻線数/
まきそのちょう /牧園町/
まきぞえ /巻き添え/巻添/
まきぞの /牧園/
まきた /牧田/蒔田/真北/
まきたばこ /巻きタバコ/
まきつき /巻き付き/巻きつき/
まきつけ /巻き付け/巻きつけ/蒔付け/
まきとり /巻取/
まきなおし /蒔き直し/
まきの /牧野/槙野/
まきのうち /牧之内/
まきのお /槇尾/
まきのこう /牧之郷/牧の郷/
まきのせ /牧之瀬/
まきのとみたろう /牧野富太郎/
まきのはら /牧の原/
まきはら /牧原/槙原/槇原/
まきば /牧場/牧葉/
まきばい /蒔き灰;[茶道]/
まきばしら /真木柱/
まきひげ /巻鬚/巻きひげ/巻ひげ/
まきひこ /眞木彦/
まきびと /牧人/
まきぶえ /牧笛/
まきほん /巻本/
まきむら /牧村/槙村/
まきもと /牧本/
まきもどし /巻き戻し/巻戻し/
まきもの /巻物/巻き物/
まきゅう /魔球/
まきょう /魔境/魔鏡/
まきょうでんせつ /魔境伝説/
まきわり /薪割り/
まぎ /間木/
まぎゃく /真逆/
まぎょう /マ行/ま行/
まぎら /紛ら/
まぎらわし /紛らわし/
まぎり /間切り/
まぎれ /紛れ/
まぎわ /間際/真際;=間際/
まく /膜;film/幕;curtain/
まくあい /幕間/
まくあいげき /幕合劇/
まくあき /幕開き/
まくあけ /幕開け/
まくあつ /膜厚/
まくいた /幕板/
まくうち /幕内/
まくうちじょうい /幕内上位/
まくうちりきし /幕内力士/
まくぎれ /幕切れ/幕切/
まくぎわ /幕際/
まくこうぞう /膜構造;[建築]eg.東京ドーム/
まくしき /幕式/
まくした /幕下/
まくしつ /膜質/
まくしもく /膜翅目;[生物]Hymenoptera/
まくしょり /膜処理/
まくそと /幕外/
まくつ /魔窟/
まくでんい /膜電位/
まくない /膜内/
まくなし /幕無し;のべつ-/
まくのうち /幕の内/
まくはり /幕張/
まくはりてん /幕張店/
まくはりでんしゃく /幕張電車区/
まくはりほんごう /幕張本郷/
まくはりほんごうえき /幕張本郷駅/
まくひき /幕引き/
まくべつ /幕別/
まくま /幕間/
まくめいがっき /膜鳴楽器;太鼓など。/
まくもの /幕物/
まくや /幕屋/
まくら /枕/
まくらえ /枕絵/
まくらかばー /枕カバー/
まくらがみ /枕上/枕紙/
まくらぎ /枕木/鍖/
まくらぎょう /枕経/
まくらげいしゃ /枕芸者;寝るしか能のない芸者/
まくらことば /枕詞/枕言葉/
まくらざき /枕崎/
まくらざきせん /枕崎線/
まくらぜに /枕銭/
まくらぞうし /枕草紙;[文学]江戸のエロ本/
まくらどけい /枕時計/
まくらのそうし /枕草子/
まくらべ /枕辺/
まくらぼん /枕本/
まくらめし /枕飯;お通夜の/
まくらもじ /枕文字/
まくらもと /枕元/枕許;-に立つ/
まくらものがたり /枕物語/
まくろけいざい /マクロ経済/
まくろけいざいがく /マクロ経済学;macroeconomics/
まくろぶんせき /マクロ分析/
まくわうり /真桑瓜/
まぐさ /秣/芻/蒭/
まぐさおけ /秣桶/
まぐし /馬櫛/
まぐそ /馬糞/
まぐち /間口/
まぐねしうむ /Mg/Magnesium/
まぐまだまり /マグマ溜り/
まぐれ /紛れ/
まぐれあたり /紛れ当たり/まぐれ当たり/
まぐろ /鮪/
まぐろぎょせん /マグロ漁船/
まぐわ /耙/
まぐん /魔軍/
まけ /負け/敗け/任/目気/
まけいくさ /負け戦/負け軍/
まけいしゅら /摩醯首羅/
まけいぬ /負け犬/負犬/
まけいろ /負け色/
まけおしみ /負け惜しみ/
まけかた /負け方/
まけかち /負け勝ち/
まけぎらい /負け嫌い/
まけぐせ /負け癖/
まけぐみ /負け組/
まけこし /負け越し/
まけじあい /負け試合/
まけじごころ /負けじ心/
まけじだましい /負けじ魂/
まけずおとらず /負けず劣らず/
まけずぎらい /負けず嫌い/
まけずもう /負け相撲/
まけっぷり /負けっ振り/
まけとうしゅ /負け投手/
まけばくち /負け博打/
まけばら /負け腹/
まけぶり /負け振り/
まけぼし /負星/
まけわざ /負け態/
まけん /魔剣/
まけんき /負けん気/
まけんし /磨研紙/
まげ /髷/曲げ/曲/
まげおうりょく /曲げ応力;[物理][建築]/
まげごうせい /曲げ剛性/
まげしんどう /曲げ振動/
まげのばし /曲げ伸ばし/
まげは /曲げ波/
まげもの /曲げ物/髷物;時代物/
まこ /麻子/真子/眞子/魔子/麻姑;まごのて/
まこう /磨香/
まこそうよう /麻姑掻痒;痒いところに手が届く。転じて思い通りにゆくこと。/
まこと /誠/実/真/眞;「真」の旧字(人名用漢字)/純;人名/信/亮;人名/真琴/真人/誠人/真湖人/
まことしやか /真しやか/
まことに /真に/実に/誠に/
まこんぶ /真昆布/
まご /孫/馬子/
まごい /真鯉/
まごうけ /孫請け;下請けの下請け/孫請/
まごうた /馬子唄/
まごおり /馬郡/
まごこ /孫子/
まごころ /真心/
まごたち /孫達/
まごでし /孫弟子/
まごのて /孫の手/
まごびき /孫引き/
まごむすめ /孫娘/
まごめ /馬籠/馬込/
まごめえき /馬込駅/
まさ /正/柾/政/征/雅/匡/昌/真/眞;「真」の旧字(人名用漢字)/将/成/麻早/
まさあき /正明/正昭/雅章/政明/雅明/雅昭/正章/昌明/政昭/正晃/昌之/昌昭/昌晃/正彰/政秋/匡章;名/真昭/
まさい /磨砕/摩砕/
まさいち /正一/政一/
まさいちろう /雅一郎/
まさえ /雅恵/正江/昌枝/正恵/雅江/優江/
まさお /正夫/正雄/正男/雅夫/政雄/政夫/政男/昌男/雅雄/昌夫/雅男/雅勇/昌生/征男/方夫/真夫/将生/誠夫/眞生/希男/
まさおか /正岡/政岡/
まさおかしき /正岡子規/
まさおき /正興/
まさおみ /正臣/
まさか /雅香/
まさかさま /真逆様/
まさかず /正和/正一/昌一/政和/雅和/賢和/
まさかつ /正勝/政勝/誠勝/
まさかど /将門/
まさかどき /将門記/
まさかね /斉加年/
まさかり /鉞/
まさがね /正金/
まさき /正樹/真樹/正木/雅樹/松前/正規/真崎/昌樹/政樹/正紀/真幸/真咲/正輝/正喜/真先/正毅/正基/正記/昌己/雅基/政木/公輝/眞幸/政輝/正宣/昌毅/仁樹/誠樹/眞希/正揮/
まさきち /政吉/
まさきよ /政清/
まさこ /雅子/昌子/正子/晶子/政子/まさ子/真砂子/真佐子/真沙子/眞砂子/誠子/真紗子/正沙子/
まさこひ /雅子妃/
まさご /真砂/
まさし /正/仁/昌/将/雅史/正史/正志/匡/雅志/正司/雅司/将司/政志/昌史/雅士/政司/昌志/将史/真史/匡史/真志/祐史/將;「将」の旧字(人名用漢字)/昌士/政資/昌嗣/
まさしく /正しく/
まさしげ /正成/政重/正茂/雅重/
まさしち /政七/
まさじ /政治/正治/政司/政次/正次/雅二/
まさすけ /正祐/
まさずみ /正純/
まさたか /正隆/正孝/昌孝/政隆/政孝/正高/雅隆/真隆/政敬/政貴/誠孝/真考/
まさたけ /正武/
まさちゅーせっつこうかだいがく /マサチューセッツ工科大学;Massachusetts Institute of Technology(MIT) web.mit.edu/
まさつ /摩擦/
まさつおん /摩擦音/
まさつぐ /正継/雅紹/仁継/
まさつけいすう /摩擦係数/
まさつそくど /摩擦速度/
まさつていこう /摩擦抵抗/
まさつてきしつぎょう /摩擦的失業;frictional unemployment/
まさつね /正恒/
まさつぶ /摩擦部/
まさつぶぶん /摩擦部分/
まさつりょく /摩擦力/
まさてつ /正哲/
まさてる /正輝/政輝/雅照/
まさと /正人/雅人/真人/政人/昌人/雅刀/雅斗/
まさとし /正敏/正俊/雅俊/正利/昌利/雅敏/政利/真俊/眞利/盛敏/
まさとみ /正富/正美/政富/
まさな /雅名/
まさなお /正直/政直/正尚/雅尚/
まさなり /正成/政成/正業/
まさに /正に/
まさの /雅野/
まさのぶ /正信/政信/雅信/正伸/昌信/雅宣/昌延/匡伸/雅修/正亘/
まさのり /正則/正典/正憲/正徳/正規/正紀/雅則/昌典/雅典/昌則/政典/正範/公則/真典/政宣/成憲/
まさはる /正治/正春/正晴/昌治/雅春/政春/
まさひこ /雅彦/正彦/昌彦/政彦/真彦/允彦/眞彦/
まさひさ /昌久/真久/
まさひで /正秀/正英/昌英/
まさひと /正人/雅仁/正仁/昌人/賢人/
まさひろ /正博/昌弘/正弘/雅弘/昌宏/正浩/正広/雅博/正裕/正洋/正宏/雅裕/政弘/昌広/政宏/正寛/真弘/雅浩/政広/雅宏/正大;名/誠広/雅洋/匡弘/政浩/昌寛/征洋/正央/将容/
まさふさ /政房/
まさふみ /正文/雅史/雅文/将史/昌文/将文/真詞/
まさぶみ /正文/
まさみ /雅美/正美/昌美/正巳/正己/正実/政美/雅巳/昌巳/雅己/昌己/真己/公美/雅実/眞美/雅三/昌未/
まさみち /正道/真理/雅道/
まさみつ /正光/昌光/真光/
まさむね /正宗/政宗/
まさめ /柾目/正目/正眼/
まさもと /政本/理元/
まさや /雅也/昌也/正也/雅哉/正哉/昌哉/正弥/匡哉/
まさやす /正康/正泰/雅康/政康/雅保/昌泰/誠康/
まさゆき /雅之/正幸/正之/正行/昌之/昌幸/雅行/政行/雅幸/真之/政幸/政之/真幸/誠之/将行/理之/政征/雅祐/
まさゆめ /正夢/
まさよ /雅代/昌代/正代/真砂代/
まさよう /将容/
まさよし /正義/昌吉/正芳/昌義/政義/雅義/正好/正良/正善/正元/
まさより /政頼/
まさりおとり /優り劣り/
まさる /大/勝/優/太/賢/秀/
まざりもの /混ざり物/
まし /麻紙/増/
ましお /真潮/
ましかく /真四角/
ましき /益城/
ましけ /増毛/
ましこ /益子/増子/猿子;[鳥]/
ましこちょう /益子町/
ましこやき /益子焼;栃木/
ました /増田/真下/間下/
まして /況して/増して/
ましてや /況してや/
ましど /益戸/
ましば /真柴/間柴/
ましばがき /真柴垣/
ましも /真下/
ましゃく /間尺/
ましゅ /魔手/
ましゅう /摩周/
ましゅうえき /摩周駅/
ましゅうこ /摩周湖/
ましょ /魔所/
ましょう /魔性/魔障/
ましょうじき /真正直/
ましょうねん /魔少年/
ましょうめん /真正面/
ましら /猿/
ましん /麻疹/真芯/
ましんご /マシン語/
まじ /真風;南風/蠱;(まじもの)/
まじか /間近/真近;人名/
まじきり /間仕切り/間仕切/
まじっくてんとう /マジック点灯/
まじない /呪い/
まじないし /呪い師/
まじのせん /マジノ線;[世界史]Ligne Maginot/
まじま /間島/真島/間嶋/
まじめ /真面目/
まじもの /蠱物/
まじゅう /魔獣/
まじゅつ /魔術/
まじゅつし /魔術師/
まじゅつしょ /魔術書/
まじゅつてき /魔術的/
まじょ /魔女/
まじょおう /魔女王/
まじょがり /魔女狩り/
まじょさいばん /魔女裁判/
まじょっこ /魔女っ子/
まじり /交じり/
まじりっけ /混じりっ気/
まじりもの /混じり物/
まじわり /交わり/∩/
まじん /魔人/魔神/
ます /鱒/升/桝/枡/舛/増/益/斗;[建築]斗形/
ますい /麻酔/増井;人名/桝井;人名/痲酔;本来の字/魔睡/魔酔/
ますいい /麻酔医/
ますいか /麻酔科/
ますいかい /麻酔科医/
ますいこうか /麻酔効果/
ますいさよう /麻酔作用/
ますいじゅう /麻酔銃/
ますいち /増市/
ますいやく /麻酔薬/
ますお /増尾/益夫/満寿夫/満洲雄/
ますおか /増岡/益岡/舛岡/
ますかがみ /増鏡;作品名/
ますかわ /増川/
ますがた /枡形;四角形/升形;四角形/真姿/斗形;[建築]受け木の一種/
ますき /増木/
ますこ /益子/増子/万寿子/
ますざわ /増沢/増澤/
ますじ /鱒二/
ますじろう /益治郎/
ますずし /鱒寿司/
ますせき /升席/桝席/枡席;box seat/
ますぞう /益造/
ますぞえ /舛添/桝添/
ますたつ /倍達/
ますたに /増谷/升谷/益谷/
ますだ /増田/益田/桝田/升田/舛田/
ますだきいとん /益田喜頓/
ますだや /増田屋/
ますづり /鱒釣/
ますとみおんせん /増富温泉/
ますど /益戸/
ますなが /増永/
ますの /増野/
ますはら /増原/
ますひこ /益彦/
ますぶち /増淵/
ますほ /増穂/
ますます /益々/
ますみ /真澄/真純/眞澄/満寿美/萬純/益美/真寿/増実/
ますみだじんじゃ /真清田神社/
ますめ /升目/桝目/枡目/
ますもと /増本/桝本/升本/
ますや /升谷/
ますやま /増山/益山/
ますらお /益荒男/丈夫/
ますらおぶり /益荒男振り;⇔手弱女振り/丈夫振り/
まず /先ず/
まずい /不味い/
ませ /籬/笆;=籬/真瀬/間瀬/
ませい /磨製;-石器/
ませき /魔石/
まぜ /馬瀬/
まぜがき /交ぜ書き/混ぜ書き/
まぜごはん /混ぜ御飯/
まぜっかえし /混ぜっ返し/
まぜもの /混ぜ物/
まそお /真赭/
まそほ /真赭/
まそん /摩損/
また /又;again/股;thigh/胯;=股/叉;fork.「三叉」/亦/複/俣/
またいじゅなんきょく /マタイ受難曲;Matthauspassion,1729,J.S.Bach/
またいとこ /又従兄弟/又従姉妹/
またうど /真人/全人/
またがし /又貸し/
またがみ /股上/
またがり /又借り/
またぎ /股木/叉木/
またぎき /又聞き/
またぐら /股座;-膏薬/股ぐら/胯座/
またぐらごうやく /股座膏薬/
またけ /真竹/
またさぶろう /又三郎/又三朗/
またした /股下/
またずれ /股擦れ/
またぞろ /又候/
またたき /瞬き;blink/
またたくま /瞬く間/
またたび /股旅/木天蓼/
またたびもの /股旅者/
まただのみ /又頼み/
またどなり /又隣/
またの /俣野/
または /又は/∪;or/∨/
またひばち /股火鉢;ぬくぬく/
またま /真玉/
またまた /又々/又又/
まためがね /股眼鏡;股座から後ろを覗く子供の遊び/
またもの /陪臣/又者/
またわり /股割/
まだ /未だ/
まだい /真鯛/
まだけ /真竹/
まだこ /真蛸/真章魚/
まだし /未だし/
まだら /斑/真鱈/
まだらお /斑尾/
まだらだけ /斑竹/
まだらねこ /斑猫/
まだらゆき /斑雪/
まだんのしゃしゅ /魔弾の射手/
まち /町/街;(商業の発展した区域)/襠;[服飾]gore/待ち/区;刀の-/甼;「町」の異体字/真知/万智/待;-受,２時間-/
まちあい /待合/待ち合い/待合い/
まちあいしつ /待合室/待合い室/
まちあかり /街明かり;遠くに見える-/街明り/
まちあるき /街歩き/
まちあわせ /待ち合わせ/待合/待合せ/
まちい /町井/町医/
まちいしゃ /町医者/
まちうけ /待受/待ち受け/待受け/
まちうけがめん /待受画面/待ち受け画面/
まちうけじかん /待受時間/
まちかた /町方/
まちかど /街角/町角/
まちかね /待兼/
まちかねやま /待兼山/
まちかねやまちょう /待兼山町/
まちが /待画;[新語][略語](携帯電話の)待ち受け画面。着メロ同様、好みのものをダウンロードして差し替えられる/待ち画;[新語][略語](携帯電話の)待ち受け画面/
まちがい /間違い/
まちがいさがし /間違い探し/
まちがいでんわ /間違い電話/
まちがえ /間違え/
まちぎ /街着/町着/
まちぎょうれつ /待ち行列/待行列/
まちく /麻竹/
まちこ /真知子/町子/満智子/麻知子/眞智子/街子/磨智子/
まちこうじょう /町工場/
まちこうば /町工場/
まちごま /待ち駒;[将棋]/
まちざわ /町沢/町澤/
まちしゅう /町衆/
まちしゅうへん /町周辺/
まちじかん /待ち時間/待時間/
まちじゅう /街中/町中/
まちじょうたい /待ち状態/
まちすじ /町筋/
まちぜんたい /町全体/
まちそだち /町育ち/
まちだ /町田/
まちだえき /町田駅/
まちだおだきゅう /町田小田急/
まちだかいどう /町田街道/
まちだかん /町田間/
まちだがくえん /町田学園/
まちだし /町田市/
まちだしみん /町田市民/
まちだてん /町田店/
まちだほうめん /町田方面/
まちぢゅう /町中/
まちっこ /町っ子/
まちでら /待寺/
まちどお /待ち遠/
まちなか /街中/町中/
まちなみ /町並み/街並み/街並/町並/
まちの /町野/
まちのり /街乗り/
まちはずれ /町外れ/
まちば /町場/
まちばり /待ち針/まち針/待針/
まちびけし /町火消し/
まちびと /待ち人/待人/
まちぶぎょう /町奉行/
まちぶせ /待ち伏せ/待伏せ/
まちぼうけ /待ち惚け/待ちぼうけ/
まちまち /区々;大小-/区区/町々/街々/
まちむすめ /町娘/街娘/
まちや /町屋/町家/町谷/
まちやくにん /町役人/
まちやくば /町役場/
まちやっこ /町奴/
まちゆく /街行く/
まちれい /町礼/
まちわり /町割/町割り/
まちんか /マチン科/Loganiaceae/
まぢか /間近/真近;?/
まっ /真っ;-赤,-茶,-黄色/
まっか /真っ赤/真赤/
まっかつ /靺鞨/
まっかり /真狩/
まっかん /末巻/
まっき /末期/末岐;人名?/
まっき> /末期;-ガン,-王朝/
まっきかんじゃ /末期患者/
まっきがん /末期癌/末期ガン/
まっきしょうじょう /末期症状/
まっきてき /末期的/
まっきゃく /末脚/
まっくあどれす /MACアドレス/
まっくら /真っ暗/真暗/
まっくらやみ /真っ暗闇/真暗闇/
まっくろ /真っ黒/真黒/
まっくろけ /真っ黒け/
まっこう /真っ向/真向/抹香/
まっこうくじら /抹香鯨/
まっこうしょうぶ /真っ向勝負/
まっさーじき /マッサージ器/マッサージ機/
まっさーじし /マッサージ師;masseur/
まっさいちゅう /真っ最中/真最中/
まっさお /真っ青/真青/
まっさかさま /真っ逆さま/真っ逆様/
まっさかり /真っ盛り/
まっさき /真っ先/真先/
まっさつ /抹殺/
まっさら /真っ新/
まっし /末子/
まっしぐら /驀地;猫-/
まっしそうぞく /末子相続/
まっしゃ /末社/
まっしゅう /末秋/
まっしょ /末書/
まっしょう /抹消;†erase.「登録-」/末梢;†peripheral.「-神経」/
まっしょうけい /末梢系/
まっしょうけっかん /末梢血管/
まっしょうけつ /末梢血/
まっしょうしんけい /末梢神経/
まっしょうじき /真っ正直/真正直/
まっしょうてき /末梢的/
まっしょうとうき /抹消登記/
まっしょうぶ /末梢部/
まっしょうめん /真正面/真っ正面/
まっしろ /真っ白/真白/
まっすぐ /真っ直ぐ/真っ直/
まっせ /末世/
まっせき /末席/
まっせつ /末節/
まっそん /末孫/
まった /待った;-なし/
まったいら /真っ平ら/
まったき /全き/
まったく /全く/全/
まっただなか /真っ只中/真只中/
まったなし /待った無し/
まったりかん /まったり感/
まったん /末端/
まったんかいいん /末端会員/
まったんかかく /末端価格/
まったんくかん /末端区間/
まったんぶ /末端部/
まっち /燐寸/
まっちうり /マッチ売り/
まっちばこ /マッチ箱/
まっちぼう /マッチ棒/
まっちゃ /抹茶/
まっちゃあいす /抹茶アイス/
まっちゃいろ /抹茶色/真っ茶色/
まっちゃまち /松屋町/
まっちょう /末長/
まってい /末弟/
まっとう /全う;まったく,完遂/真っ当;まとも、まじめ/松任/
まっとうし /松任市/
まっとうや /松任谷/
まっとうんどう /マット運動;体育の-/
まっとし /マット紙/
まっはすう /マッハ数;Mach/
まっぱ /末派/
まっぱい /末輩/
まっぱだか /真っ裸/
まっぴつ /末筆/
まっぴら /真っ平/真平/
まっぴらごめん /真っ平御免;そいつは-だ/真平御免/
まっぴるま /真っ昼間/真昼間/
まっぷたつ /真っ二つ/
まっぽう /末法/
まっぽうしそう /末法思想/
まつ /松/末;末期/抹;一抹/沫;飛沫/秣;まぐさ/茉;茉莉/靺/枩;「松」の異体字/
まつい /松井/松居/末位/松為/
まついし /松石/
まついだ /松井田/
まついち /松一/
まつうら /松浦/
まつうらてつどう /松浦鉄道/
まつえ /松江/
まつえい /末裔/
まつえし /松江市/
まつえだ /松枝/
まつえはん /松江藩/
まつえほうめん /松江方面/
まつお /松尾/松雄/松男/松夫/
まつおか /松岡/
まつおかようすけ /松岡洋右;(1880-1946)政治家/
まつおたいしゃ /松尾大社/
まつおばしょう /松尾芭蕉/
まつかさ /松毬/
まつかさうお /松毬魚/
まつかざり /松飾り/
まつかぜ /松風/
まつかた /松方/
まつかたまさよし /松方正義/
まつかわ /松川/松皮/松河/
まつかわびし /松皮菱/
まつがおか /松が丘/
まつがさき /松ヶ崎/
まつがや /松ヶ谷/
まつき /松木/
まつくいむし /松喰虫/
まつくら /松倉/
まつげ /睫毛/睫/
まつご /末期/
まつごのみず /末期の水/
まつごろう /松五郎/松吾郎/
まつさか /松坂/松阪/
まつさかぎゅう /松坂牛/
まつさき /松崎/
まつさわ /松沢/
まつざ /末座/
まつざか /松坂/松阪/
まつざかぎゅう /松坂牛/
まつざかしない /松阪市内/
まつざかにく /松坂肉/
まつざかや /松坂屋/
まつざき /松崎/松嵜/
まつざわ /松沢/松澤/
まつざわびょういん /松沢病院/
まつしげ /松茂/松重/
まつした /松下/
まつしたぎけん /松下技研/
まつしたこうのすけ /松下幸之助/
まつしたじょうほう /松下情報/
まつしたせい /松下製/
まつしたせいけいじゅく /松下政経塾/
まつしたせいこう /松下精工/
まつしたつうしん /松下通信/
まつしたつうしんこうぎょう /松下通信工業;[企業名]/
まつしたでんき /松下電器;[企業名]/
まつしたでんきさんぎょう /松下電器産業;[企業名]/
まつしたでんきじょうほう /松下電器情報/
まつしたでんこう /松下電工;[企業名]/
まつしたでんし /松下電子/
まつしたでんしこうぎょう /松下電子工業;[企業名]/
まつしたはん /松下藩/
まつしたれいき /松下冷機/
まつしま /松島/松嶋/
まつしまちょう /松島町/
まつしろ /松代/
まつじ /末寺/
まつじつ /末日/
まつじつせいと /末日聖徒/
まつじめ /末締め/
まつじょ /末女/
まつずみ /松炭/
まつた /松田/
まつたか /松高/
まつたけ /松茸/
まつたに /松谷/
まつたろう /松太郎/
まつだ /松田/
まつだい /末代/松代/
まつだいら /松平/
まつだいらさだのぶ /松平定信;(1758-1829) 寛政の改革/
まつだいらただてる /松平忠輝/
まつだぐみ /松田組/
まつだせいこ /松田聖子/
まつだゆうさく /松田優作/
まつだん /末段/
まつち /真土/
まつつか /松塚/
まつづき /松月/
まつとうや /松任谷/
まつとうやゆみ /松任谷由実/
まつとも /松友/
まつど /松戸/
まつどし /松戸市/
まつなえ /松苗/
まつなか /松中/
まつなが /松永/末永/松長/
まつなみ /松波/
まつなみき /松並木/
まつなん /末男/
まつぬま /松沼/
まつね /松根/
まつねん /末年/
まつの /松野/松乃/
まつのうち /松の内/
まつのぶ /松延/
まつのべ /松延/
まつのやま /松之山/
まつのり /松海苔/
まつはた /松畑/
まつば /松葉/
まつばいろ /松葉色/
まつばがに /松葉蟹/
まつばせ /松橋/
まつばづえ /松葉杖/
まつばめ /松羽目/
まつばめもの /松羽目物;[歌舞伎]能や狂言の翻案/
まつばやし /松林/
まつばら /松原/
まつばらこ /松原湖/
まつひろ /松弘/
まつび /末尾/
まつびさいき /末尾再帰/
まつびさんしょう /末尾参照/
まつびし /松菱/
まつびばんごう /末尾番号/
まつふじ /松藤/
まつふる /松古/
まつぶさか /マツブサ科/Schisandraceae/
まつぶし /松伏/
まつぶん /末文/
まつぼっくり /松陰嚢/松ぼっくり/
まつまい /末妹/
まつまえ /松前/
まつまえづけ /松前漬/
まつまえはん /松前藩/
まつまる /松丸/
まつみ /松見/
まつむし /松虫/
まつむしそう /松虫草/
まつむら /松村/
まつむろ /松室;姓/
まつも /松藻/
まつもか /マツモ科/Ceratopyllaceae/
まつもと /松本/松元/
まつもとくうこう /松本空港/
まつもとこうしろう /松本幸四郎/
まつもとし /松本市/
まつもとしない /松本市内/
まつもとじょう /松本城/
まつもとせいちょう /松本清張/
まつもとたいかい /松本大会/
まつもとでんてつ /松本電鉄/
まつもとほうめん /松本方面/
まつもとれいじ /松本零士/
まつもむし /松藻虫/
まつもり /松森/
まつや /松屋/
まつやに /松脂/
まつやま /松山/
まつやまかん /松山間/
まつやまし /松山市/
まつやましない /松山市内/
まつやましょう /松山商/
まつやまじょう /松山城/
まつやまだいがく /松山大学/
まつやまちはる /松山千春/
まつやまびん /松山便/
まつやまほうめん /松山方面/
まつやままち /松山町/
まつゆき /松雪/
まつよいぐさ /待宵草/
まつよう /末葉/
まつよし /松吉/
まつら /松浦/
まつらのみやものがたり /松浦宮物語/
まつり /祭/祭り/祀/祀り/
まつりか /茉莉花/
まつりごと /政/祭事/
まつりぬい /纏り縫い/まつり縫い/
まつりばやし /祭り囃子/
まつりゅう /末流/
まつろ /末路/
まつわこう /松輪港/
まづ /先づ/
まて /馬刀;-貝/馬蛤;=馬刀/蟶;=馬刀/待て/
まてがい /馬刀貝/馬蛤貝;=馬刀貝/蟶貝;=馬刀貝/
まてき /魔笛/
まてちゃ /マテ茶;mate/
まてんろう /摩天楼/
まで /迄/
まと /的/魔都/
まとい /纏/纒;異体字/纒い/
まとうだい /的鯛/
まとうど /真人/全人/
まとはずれ /的外れ/
まとば /的場/
まとまり /纒まり/
まとむ /統;名/
まとめ /纏め/
まとめうり /まとめ売り/まとめ買い/
まとめがい /まとめ買い/纏め買い/
まとめやく /纏め役/まとめ役/
まとも /真面/真艫/
まとや /的矢/
まとり /真鳥/
まど /窓/窗;「窓」の異体字/
まどい /円居/
まどいた /窓板/
まどう /魔道/魔導;ゲーム用語?/
まどうし /魔導師/魔道士/魔導士/魔道師/
まどうしょ /魔導書/
まどお /間遠/
まどか /円か/円/
まどかんすう /窓関数/
まどがらす /窓ガラス/
まどがわ /窓側/
まどぎわ /窓際/
まどぎわせき /窓際席/
まどぎわぞく /窓際族/
まどぐち /窓口/
まどぐちおく /窓口奥/
まどぐちぎょうむ /窓口業務/
まどぐちしょくいん /窓口職員/
まどぐちすう /窓口数/
まどぐちない /窓口内/
まどぐちはんばい /窓口販売/
まどぐちまえ /窓口前/
まどぐちやく /窓口役/
まどころ /政所/
まどぜんかい /窓全開/
まどぜんたい /窓全体/
まどだい /窓台/
まどだか /窓高/
まどちょう /窓長/
まどない /窓内/
まどのうち /窓の中/
まどはいち /窓配置/
まどはん /窓販;[略語]窓口販売「国債-」/
まどふき /窓拭き/
まどべ /窓辺/
まどよう /窓用/
まどり /間取り/間取/
まどりーど /馬徳里/
まどりず /間取り図/間取図/
まどろみ /微睡/
まどわく /窓枠/
まどわり /窓割/
まな /愛/真奈/真名/麻奈/茉奈/真魚/真字/
まなーいはん /マナー違反/
まないた /まな板/俎/俎板/真魚板/
まなか /真中/愛香/
まながつお /真魚鰹/
まなこ /眼/
まなご /真砂/
まなざし /眼差し/
まなしき /末那識/
まなじょ /真名序/
まなじり /眦/眥;=眦/
まなつ /真夏/
まなつのよのゆめ /真夏の夜の夢;A Midsummer Night's Dream (Shakespeare,Mendelssohn)/
まなつび /真夏日;NB:最高気温が30℃以上/
まなつる /真鶴/
まなつるこう /真鶴港/
まなづる /真鶴/真名鶴/
まなでし /愛弟子/
まなび /学び/愛日;名/
まなびかた /学び方/
まなびや /学舎/学び舎/
まなぶ /学/學/斈/
まなべ /真鍋/間部/真部/
まなみ /愛美/真奈美/真名美/
まなむすこ /愛息子/
まなむすめ /愛娘/
まに /摩尼/
まにあわせ /間に合わせ/間に合せ/
まにきょう /マニ教;Manichaeism/
まにし /真西/
まにまに /随に/
まにゅあるか /マニュアル化/
まにゅあるしゃ /マニュアル車/
まにゅあるぼん /マニュアル本/
まにら /馬尼剌/
まにらあさ /マニラ麻/
まにわ /真庭/
まにんげん /真人間/
まぬえど /真鵺道/Manued/Manuscript Editing/
まぬけ /間抜け/
まぬけづら /間抜け面/間抜面/
まぬほうてん /マヌ法典;[世界史]manusmrti/
まね /真似/
まねきねこ /招き猫/
まねごと /真似事/
まねび /学び/
まねもの /真似物/
まの /真野/間野/
まのあたり /目の当たり/
まのて /魔の手/
まのび /間延び/間延/
まは /万葉/
まはだか /真裸/
まばし /馬橋/
まばしら /間柱/
まばたき /瞬き/
まばら /疎ら/疎/
まひ /麻痺/痲痺/
まひかり /真光/
まひがし /真東/
まひじょうたい /麻痺状態/
まひと /真人/
まひる /真昼/
まひわ /真鶸/
まび /魔美/
まびき /間引き/間引/
まびきな /間引き菜/
まびさし /目庇/
まふう /魔風/
まふじえき /間藤駅/
まふね /真船/
まふゆ /真冬/
まふゆび /真冬日;NB:最低気温が0℃以下/
まぶ /間夫/
まぶか /目深/
まぶし /蔟/
まぶしさ /眩しさ/
まぶた /瞼/目蓋/
まぶち /馬渕/馬淵/
まぶに /摩文仁/
まぶね /馬槽/
まほ /真帆/真秀/
まほう /魔法/
まほうがい /魔法街/
まほうぎじゅつ /魔法技術/
まほうけん /魔法剣/
まほうけんし /魔法剣士/
まほうしょ /魔法書/
まほうしょうじょ /魔法少女/
まほうじゅうし /魔法重視/
まほうじん /魔方陣;magic square/魔法陣;?/
まほうせき /魔法石/
まほうせん /魔法戦/
まほうつかい /魔法使い/
まほうてき /魔法的/
まほうびん /魔法瓶/
まほうりょく /魔法力/
まほか /真帆香/
まほりかん /馬堀間/
まほろ /真帆呂;名/
まぼろし /幻/
まま /儘/侭;「儘」の異体字/随;=儘/継;-母/飯/圸;ガケ/墹;=圸/壗;=圸/媽媽;[中国語](mama)母/
まま> /継;(*-in-law) -母,-兄,-娘/
ままおや /継親/
ままかり /飯借り/
ままこ /継子/
ままこあつかい /継子扱い/
ままごと /飯事/
ままさん /ママさん/
ままちち /継父/
ままならぬ /儘ならぬ/
ままはは /継母/
ままむすこ /継息子/
ままむすめ /継娘/
まみ /猯/真美/麻美/真実/麻弥/麻実/茉美/魔美/舞美/眞美/魔魅/磨美/昌未/
まみこ /麻美子/真美子/麻巳子/
まみず /真水/
まみづか /馬見塚/
まみどりいろ /真緑色/
まみな /真美奈/
まみなみ /真南/
まみや /間宮/魔実也/
まみやかいきょう /間宮海峡/
まみやりんぞう /間宮林蔵/
まみれ /塗れ/
まむかい /真向かい/真向い/
まむき /真向き/
まむし /蝮/
まむしぐさ /蝮草/
まむすび /真結び/
まむろがわ /真室川/
まめ /豆/荳;=豆/肉刺;手足にできる豆状の水腫/忠実;筆-/菽;≒豆/
まめあぶら /豆油/
まめおか /豆岡/
まめか /豆科/マメ科/
まめがし /豆菓子/
まめきゅう /豆球/
まめしぼり /豆絞り/
まめじてん /豆事典/
まめせいひん /豆製品/
まめぞう /豆蔵/
まめたん /豆炭/豆単/
まめだ /豆田/
まめだいこ /豆太鼓/
まめちしき /豆知識/
まめつ /摩滅/磨滅;=摩滅/
まめつぶ /豆粒/
まめでっぽう /豆鉄砲/
まめでんきゅう /豆電球/
まめばたけ /豆畑/
まめほん /豆本/
まめまき /豆まき/豆撒き;鬼は外/豆蒔き;福は内/
まめみそ /豆味噌/
まめもち /豆餅/
まめもよう /豆模様/
まめや /豆屋/
まめるい /豆類/
まもう /摩耗/磨耗;=摩耗/
まもうぶぶん /摩耗部分/
まもうへんけい /摩耗変形/
まもなく /間も無く/
まもの /魔物/
まものたいじ /魔物退治/
まものたち /魔物達/
まもり /守り/護り/護/
まもりがみ /守り神/
まもりて /守り手/護り手/
まもりふだ /守り札/
まもる /守/衛/衞;「衛」の旧字(人名用漢字)/
まや /麻矢/麻弥/摩耶/馬屋/魔夜/麻那/
まやく /麻薬/痲薬;本来の字/
まやくけん /麻薬犬/
まやくじょうしゅうしゃ /麻薬常習者/
まやくせい /麻薬性/
まやくたんちけん /麻薬探知犬/
まやくちゅうどく /麻薬中毒/
まやくちゅうどくかんじゃ /麻薬中毒患者/
まやくてき /麻薬的/
まやくとりしまりほう /麻薬取締法/
まやくろん /麻薬論/
まやこ /麻也子/
まやさん /摩耶山/
まやぞく /マヤ族;Maya/
まやぶにん /摩耶夫人;仏陀の母/
まやぶんめい /マヤ文明;Maya/
まやべ /真矢部/
まやま /真山/間山/
まゆ /眉/繭/麻由/真由/麻愉/
まゆげ /眉毛/
まゆこ /真由子/繭子/万由子/眉子/
まゆじり /眉尻/
まゆずみ /黛/眉墨/
まゆだま /繭玉/
まゆつば /眉唾/
まゆつばもの /眉唾物/
まゆね /眉根/
まゆみ /真由美/真弓/麻由美/魔弓/真祐美/檀/雅弓;名/万友美/誠由美/
まゆむら /眉村/
まゆやま /眉山/
まよ /真世/麻世/真代/眞夜/
まよい /迷い/
まよいいぬ /迷い犬/
まよいご /迷い子/
まよいねこ /迷い猫/
まよいばし /迷い箸;マナー違反/
まよいぼし /迷い星;惑星/
まよいみち /迷い道/
まよけ /魔除け/
まよこ /真横/
まよなか /真夜中/
まよね /眉根/
まら /摩羅;<mara 梵語/魔羅;=摩羅/
まらっかかいきょう /マラッカ海峡;地名/
まらや /馬來/
まり /毬/鞠/真理/麻里/真里/茉莉/万里/麻理/茉利/満利/
まりあ /真利亜/真里亜/万梨阿/
まりい /麻利衣/
まりえ /真理絵/鞠絵;名/真理恵/麻里絵/
まりお /真理雄/眞理雄/麻利夫/
まりこ /真理子/まり子/マリ子/麻理子/真利子/万里子/麻里子/真梨子/真里子/丸子/鞠子/真璃子/満利子/茉里子/
まりこうじ /鞠小路/
まりしてん /摩利支天/
まりな /満里奈/
まりのす /横浜マリノス;※abbrev?/
まりはな /茉莉花/
まりも /毬藻/
まりょく /魔力/
まる /丸/円/圓;「円」の旧字(人名用漢字)/○;しろまる/●;くろまる/◎;二重丸/◯;文字を囲むマル/〇;漢数字のゼロ/゜;半濁点/°;degree/。;句点/・;なかぐろ/．;period/
まる> /丸;丸皿,丸坊主,丸三日/
まるあき /丸明き/
まるあな /丸穴/
まるあらい /丸洗い/
まるあんき /丸暗記/
まるい /丸井/
まるいけ /丸池/
まるいす /丸椅子/
まるいち /丸一/
まるいちにち /丸一日/
まるいん /丸印/
まるうつし /丸写し/
まるえい /丸栄/
まるえり /丸襟/
まるお /丸尾/円尾/丸生/
まるおか /丸岡/
まるおび /丸帯/
まるか /満留賀/
まるかがみ /円鏡/
まるかじり /丸齧り/丸かじり/
まるかっこ /丸括弧/（/）/
まるかめかん /丸亀間/
まるかめがわ /丸亀側/
まるかわ /丸川/
まるかん /丸漢/
まるがお /丸顔/円顔/
まるがかえ /丸抱え/
まるがた /丸型/丸形/円形;NB:「えんけい」と同形/円型/
まるがめ /丸亀/
まるがめこう /丸亀高/
まるがめこうこう /丸亀高校/
まるがめし /丸亀市/
まるがり /丸刈り/
まるがわら /丸瓦/
まるき /丸木/
まるきぶね /丸木舟/
まるきゅう /丸久/
まるきり /丸切り/
まるきん /丸金/
まるくすけいざいがく /マルクス経済学;Marxist economics/
まるくすしゅぎ /マルクス主義;Marxism/
まるくに /丸国/
まるくび /丸首/
まるぐち /丸口/
まるこ /丸子/
まるこう /丸興/
まるこし /丸腰/
まるこばし /丸子橋/
まるごし /丸腰/
まるごしっく /丸ゴシック/
まるごと /丸ごと/
まるさん /丸三/
まるざい /丸材/
まるざら /丸皿/
まるしょう /丸正/
まるしょうしょくひん /丸正食品;[企業名]www.marusyo.co.jp‖いる?/
まるじるし /丸印/
まるすうじ /丸数字/
まるせいゆ /馬耳塞;Marseille/
まるせっぷ /丸瀬布/
まるぜん /丸善;[企業名]洋書店。www.maruzen.co.jp/丸全/
まるぜんせきゆ /丸善石油;[企業名]/
まるぞこ /丸底/
まるぞん /丸損/
まるた /丸太/丸田/
まるたに /丸谷/
まるたまち /丸太町/
まるたんぼう /丸太ん棒/
まるだいしょくひん /丸大食品/
まるだいず /丸大豆/
まるだし /丸出し/
まるちしょうほう /マルチ商法/
まるちょうちん /丸提灯/
まるっきり /丸っ切り/
まるつきすうじ /丸付数字/
まるつぶれ /丸潰れ/
まるづか /丸塚/
まるづけ /丸漬/
まるてーぶる /丸テーブル/
まるてん /丸天/
まるてんじょう /丸天井/円天井/
まるとう /丸東/
まるどけい /丸時計/
まるどり /丸取り/
まるなげ /丸投げ/
まるに /丸煮/
まるにし /丸西/
まるにねん /丸二年/
まるぬま /丸沼/
まるぬまこうげん /丸沼高原/
まるの /丸野/
まるのうち /丸の内/丸ノ内/
まるのうちせん /丸の内線/
まるのこ /丸鋸/
まるのみ /丸呑み/円鑿/
まるはい /丸灰/
まるはし /丸橋/
まるはだか /丸裸/
まるはち /丸八/
まるはんにち /丸半日/
まるばし /丸橋/
まるばしら /丸柱/
まるばつ /○×/
まるばつしき /○×式/
まるばやし /丸林/
まるひ /丸秘/マル秘/
まるひじょうほう /丸秘情報/
まるびたい /丸額/
まるふく /丸福/
まるぶつ /丸物/
まるぶん /丸文/
まるべに /丸紅;[企業名]/
まるほん /丸本/
まるぼうず /丸坊主/
まるぼし /丸干し/丸干/
まるぼり /丸彫り/丸彫/
まるぽちゃ /丸ぽちゃ/
まるまげ /丸髷/
まるまど /丸窓/円窓/
まるまどでんしゃ /丸窓電車/
まるまる /丸々/丸丸/○○/
まるまる> /丸々;(entire) -半年/
まるみ /丸み/丸味/丸見/円美/
まるみえ /丸見え/
まるみつ /丸光/
まるめ /丸め/
まるめがね /丸眼鏡/
まるめごさ /丸め誤差/
まるもうけ /丸儲け/
まるもじ /丸文字/
まるもち /丸餅/
まるもと /丸本/丸元/
まるもり /丸森/
まるや /丸谷/丸屋/
まるやき /丸焼き/丸焼/
まるやけ /丸焼け/
まるやね /丸屋根/円屋根;dome/
まるやま /丸山/円山/
まるやまおうきょ /円山応挙/
まるやまかおる /丸山薫;(1899-1974)詩人。『帆・ランプ・鴎』/
まるやまこうえん /円山公園;京都/
まるやまだい /丸山台/
まるやまちょう /丸山町/円山町/
まるゆう /マル優/
まるわ /丸和/
まれ /稀/希/
まれーご /マレー語/
まれーしあご /マレーシア語/
まれいんさん /マレイン酸/
まれき /希樹/
まれすけ /希典/
まれびと /客人/賓/客/
まろ /麿/麻呂/
まろうど /客人/賓/客/
まろうどがみ /客神/客人神/
まろみ /丸み/円み/
まろやか /円やか/
まわし /回し/廻/廻し/
まわしかた /回し方/
まわしげり /廻し蹴り/
まわしもの /回し者/
まわた /真綿/
まわたり /馬渡/
まわり /周り;(周辺)「-を見る」/回り;(回転・到達)「酒の-」/廻り/
まわりえん /回り縁/
まわりかいだん /回り階段/
まわりしょうぎ /回り将棋/
まわりずみ /回り炭;[茶道]/
まわりどうろう /回り灯籠/
まわりばな /回り花;[茶道]/
まわりぶたい /回り舞台/
まわりぶち /廻り縁/回り縁;[建築]「天井-」/
まわりまわって /回り回って/
まわりみち /回り道/
まわりもち /回り持ち;-の役員/
まわれみぎ /回れ右/
まん /万/萬;「万」の旧字(人名用漢字)/満/懣;憤懣/瞞;欺瞞/蹣/滿;「満」の旧字/鰻;うなぎ/慢;慢性/漫;漫画/蔓;蔓延/曼;曼荼羅/幔/縵/謾/饅;饅頭/鬘;かずら/幡;八幡/悗;(わすれる)/
まん> /満;(満年齢) 満14歳/
まんいち /万一/
まんいつ /万一/
まんいん /満員/
まんいんおんれい /満員御礼/
まんいんじょうたい /満員状態/
まんいんでんしゃ /満員電車/
まんえつ /満悦/
まんえん /蔓延/万円/万延;年号(1860-61)/満塩/萬延;「万延」の旧字表記/
まんえんさつ /万円札/
まんえんだい /万円代/
まんかい /満開/万回/
まんかぶ /満株/
まんかん /満干/満韓/
まんかんしょく /満艦飾/
まんかんぜんせき /満漢全席/
まんが /漫画/萬画;(=漫画) 石ノ森章太郎の造語/
まんがいち /万が一/
まんがおう /漫画王/
まんがか /漫画家/マンガ家/漫画化/
まんがかい /漫画界/
まんがきっさ /漫画喫茶/マンガ喫茶;[新語]マンガやネット接続等を提供する喫茶店/
まんがきょうしつ /漫画教室/
まんがく /満額/
まんがくかいとう /満額回答/
まんがざっし /漫画雑誌/
まんがし /漫画誌/
まんがしゅう /漫画集/
まんがしょう /漫画賞/
まんがじたい /漫画自体/
まんがたんこうぼん /漫画単行本/
まんがてき /漫画的/
まんがとくゆう /漫画特有/
まんがどうじんし /漫画同人誌/
まんがのもり /まんがの森/
まんがばん /漫画版/
まんがひょうろんか /漫画評論家/
まんがぶんか /漫画文化/
まんがぶんこばん /漫画文庫版/
まんがほん /漫画本/
まんがぼん /マンガ本/
まんがん /満願/満貫;[麻雀]/万巻/Mn/Manganese/
まんがんかんでんち /マンガン乾電池/
まんがんぜんせき /満漢全席;=まんかんぜんせき/
まんがんでんち /マンガン電池/
まんき /満期/
まんききん /満期金/
まんきじつ /満期日/
まんきつ /満喫/
まんきん /万金/
まんぎょう /万行/
まんけん /万券/漫研/万件/万軒/
まんげきょう /万華鏡/
まんげつ /満月/
まんげつじ /満月時/
まんげつじょうたい /満月状態/
まんげん /万言/漫言/
まんこ /万個/万戸/
まんこう /満腔/
まんご /慢語/漫語/
まんごう /万劫/
まんごく /万石/
まんごじしょ /万語辞書/
まんさい /満載/
まんさく /万作/満作/
まんさくもく /マンサク目/Hamamelidales/
まんさつ /万冊/万札/
まんさん /蹣跚/
まんざ /万座;地名/満座/
まんざい /万歳/漫才/
まんざいし /漫才師/
まんざいらく /萬歳楽/
まんざおんせん /万座温泉/
まんざほうめん /万座方面/
まんざら /満更/
まんざん /満山/
まんしつ /満室/
まんしゃ /満車/
まんしゅいん /曼殊院/
まんしゅう /満州/満洲;=満州/滿洲;「満」旧字/
まんしゅうけんこく /満州建国/
まんしゅうこく /満州国/滿洲國/
まんしゅうこくけんこく /満州国建国/
まんしゅうご /満州語/
まんしゅうじへん /満州事変/滿洲事變/
まんしゅうじん /満州人/
まんしゅうせんりょう /満州占領/
まんしゅうぞく /満州族/
まんしゅうもじ /満州文字/
まんしょう /満床/
まんしょく /万色/
まんしん /慢心/満身/万進/
まんしんそうい /満身創痍/
まんしんほう /万進法/
まんじ /卍/万治;年号(1658-1661)/
まんじがため /卍固/
まんじどもえ /卍巴/
まんじゅ /万寿;長寿,年号(1024-1028)/
まんじゅう /饅頭/
まんじゅうがに /饅頭蟹/
まんじゅうやぼん /饅頭屋本/
まんじゅしゃげ /曼珠沙華/
まんじょう /満場/
まんじょういっち /満場一致/
まんすい /満水/
まんず /萬子/
まんせい /慢性/
まんせいか /慢性化/
まんせいかんえん /慢性肝炎;[医]chronic hepatitis(CH)/
まんせいき /慢性期/
まんせいしん /慢性心/
まんせいじゅうたい /慢性渋滞/
まんせいちゅうどく /慢性中毒;⇔急性中毒/
まんせいてき /慢性的/
まんせいばし /万世橋/
まんせいひろうしょうこうぐん /慢性疲労症候群/
まんせいびょう /慢性病/
まんせき /満席/
まんせきじ /満席時/
まんせきじょうたい /満席状態/
まんせん /満船/
まんぜん /漫然/万善/
まんぞく /満足/
まんぞくかん /満足感/
まんぞくど /満足度/
まんた /万太/
まんたく /満卓/
まんたに /萬谷/
まんたん /満タン/
まんたんい /万単位/
まんだい /万台/万代/
まんだら /曼荼羅;mandala/曼陀羅/
まんだらげ /曼陀羅華/
まんだん /漫談/
まんち /満地/
まんちゃく /瞞着/
まんちゅういん /満中陰;49日の法要/
まんちょう /満潮/
まんちょうぜんご /満潮前後/
まんちんろう /萬珍楼/
まんてつ /満鉄;(南)満州鉄道/滿鐵;旧字/
まんてん /満点;†full marks/満天;†「-の星」/万点/
まんてんか /満天下/
まんてんせい /満天星;[植物]/
まんと /満都/
まんとうえ /万灯会/
まんとみ /万富/
まんどう /万灯/
まんどうえ /万灯会/
まんどころ /政所/
まんなか /真ん中/真中/まん中/
まんにょうしゅう /万葉集/
まんにん /万人/
まんねりか /マンネリ化;<mannerism/
まんねん /万年/萬年/
まんねんぐさ /万年草/
まんねんせい /万年青;[植物]=オモト/
まんねんたけ /万年茸;霊芝/
まんねんどこ /万年床/
まんねんひつ /万年筆/
まんねんゆき /万年雪/
まんねんれい /満年齢/
まんねんれき /万年暦/
まんねんろう /迷迭香/
まんのう /満濃/
まんはったんけいかく /マンハッタン計画;[世界史](1942-45)/
まんば /万場/万馬;-券/漫罵/
まんばい /万倍/
まんばけん /万馬券/
まんぱ /万波/
まんぱい /満杯/満配/
まんぱち /万八;もっとうそつき/
まんぱん /満帆/
まんびき /万引/万引き/
まんびょう /万病/
まんぴつ /漫筆/
まんぴょう /満票/漫評/
まんぶ /万部/
まんぶん /漫文/
まんぷ /漫符/
まんぷく /満腹/万福/満幅/
まんぷくかん /満腹感/
まんぷくじ /万福寺/
まんぷくちゅうすう /満腹中枢/
まんべん /満遍;-なく/万遍/万便/
まんぼう /翻車魚/
まんぽ /漫歩/
まんぽけい /万歩計;[商標]山佐時計計器. NB:言い換え「歩数計」/
まんま /儘/飯/
まんまい /万枚/
まんまえ /真ん前/
まんまく /幔幕/
まんまる /真ん丸;-お月様雲の上/真円/
まんまん /満々/
まんまんなか /真ん真ん中/
まんめん /満面/
まんもう /満蒙/滿蒙;「満」旧字/
まんもく /万目/満目/
まんもくしょうじょう /満目蕭条/
まんゆう /漫遊/
まんゆうき /漫遊記/
まんよう /万葉/
まんようかな /万葉仮名/
まんようがな /万葉仮名/
まんようしゅう /万葉集/
まんようせん /万葉線/
まんりき /万力/
まんりょう /満了/万両/
まんりょうび /満了日/
まんるい /満塁/
まんるいさく /満塁策/
まんるいそうしゃいっそう /満塁走者一掃/
まんるいだん /満塁弾/
まんるいほんるいだ /満塁本塁打/
まんれき /万暦;=ばんれき/
み /実/身/未/味/箕/巳;[十二支](6)へび/見/御/美/三/魅;魅力/弥;阿弥陀/彌;「弥」の旧字(人名用漢字)/實;「実」の旧字(人名用漢字)/靡;(呉音) 淫靡/深;深山/己;†(人名の一部として使われることがある。「巳」との混同に注意)/壬;みずのえ?/稔;?/
み> /未/御;御魂,御手,御筆/見;(マ行上一段 未然・連用形)見詰める,見損なう,見延ぶ/
みあ /未亜/
みあい /見合い/見合/美合;地名/
みあいあいて /見合相手/
みあいけっこん /見合い結婚/見合結婚/
みあいばなし /見合い話/
みあけ /三宅/
みあげ /見上/
みあさ /美麻/
みあま /三甘/
みい /三井/御井/魅衣/
みいけ /三池/
みいけこう /三池港/
みいけこうぎょう /三池工業;[企業名]/
みいけそうぎ /三池争議/
みいし /御石;姓/
みいつ /御稜威/
みいでら /三井寺/
みいら /木乃伊/
みいらか /ミイラ化/
みいらく /三井楽/
みいり /実入り/
みうけ /身請け/身請/
みうごき /身動き/
みうた /御歌/
みうち /身内/御内/
みうら /三浦/
みうらかいがん /三浦海岸/
みうらきた /美浦北/
みうらはんとう /三浦半島/
みうらわん /三浦湾/
みうり /身売り/身売/
みえ /三重/見栄;†vanity.「-を張る」/見得;†pose.「-を切る」/美恵;人名/美枝/美江/水絵/美瑛/見え/
みえい /御影/
みえいどう /御影堂/
みえかくれ /見え隠れ/見えかくれ/
みえかた /見え方/
みえがくれ /見え隠れ/
みえぐん /三重郡/
みえけん /三重県/
みえけんじん /三重県人/
みえこ /美恵子/美枝子/三枝子/三恵子/三重子/実枝子/
みえこうつう /三重交通/
みえざるて /見えざる手;invisible hand/
みえせん /三江線/
みえだ /三枝/
みえだい /三重大/
みえだいがく /三重大学/
みえだいこう /三重大工/
みえっぱり /見栄っ張り/見栄張り/
みえぼう /見栄坊/
みえみえ /見え見え/
みお /澪/水脈;=澪/美緒;人名/美織/未央/三尾/美央/水尾/未緒/実音/美尾/
みおくり /見送り/
みおこ /美央子/
みおさめ /見納め/
みおつくし /澪標/
みおとし /見落とし/見落し/
みおとり /見劣り/
みおぼえ /見覚え/
みおも /身重/
みおや /御祖/
みおり /美織/
みか /甕/美香;人名/美佳/美加/実花/美夏/美伽/美華/美歌/三香/実可/三日;[古語]/
みかい /未開/味解/
みかいけつ /未解決/
みかいこんち /未開墾地/
みかいしゃかい /未開社会/
みかいしゅう /未回収/
みかいじん /未開人/
みかいせき /未解析/
みかいたく /未開拓/
みかいち /未開地/
みかいつう /未開通/
みかいつうぶぶん /未開通部分/
みかいとう /未回答/
みかいふう /未開封/
みかいめい /未解明/
みかえし /見返し/
みかえり /見返り/
みかえりひん /見返り品/
みかく /味覚/
みかくしょうがい /味覚障害/
みかくしんけい /味覚神経/
みかくてい /未確定/
みかくていもじ /未確定文字/
みかくていもじれつ /未確定文字列/
みかくてき /味覚的/
みかくにん /未確認/
みかくにんじょうほう /未確認情報/
みかくにんひこうぶったい /未確認飛行物体/
みかぐら /御神楽/
みかけ /見掛け/見かけ/
みかけじょう /見掛け上/
みかけだおし /見掛け倒し/
みかげ /御影/御蔭/
みかげいし /御影石/
みかげつ /三ケ月/
みかこ /美佳子/美香子/美加子/
みかこう /未加工/
みかさ /三笠/
みかさしょぼう /三笠書房/
みかさのみや /三笠宮/
みかさやま /三笠山;地名,奈良/
みかじめ /見ヶ〆/
みかじめりょう /みかじめ料;コワイコワイ/
みかた /見方;†view.「ものの-」/味方;†ally.「正義の-」/三方/美方/
みかたがわ /味方側/
みかたきょうぎしゃ /味方競技者/
みかたせんしゅ /味方選手/
みかたはら /三方原/
みかだ /三ヶ田/
みかつき /三日月/
みかづき /三日月/
みかづきがた /三日月形/
みかづきこ /三日月湖/
みかど /帝/御門/三門/
みかにゅう /未加入/
みかほ /美華保/
みかみ /三上/三神/御神/見上/
みかみね /三神峯/
みかみひろし /三上博史/
みかめ /三瓶/
みかも /三加茂/美甘/
みかり /美加理/
みかわ /三河/美川/三川/三加和/見川/実川/
みかわあんじょう /三河安城/
みかわしま /三河島/
みかわせん /三河線/
みかわたはらえき /三河田原駅/
みかわちほう /三河地方/
みかわちやき /三川内焼/
みかわべん /三河弁/
みかわもの /三河者/
みかわものがたり /三河物語/
みかわや /三河屋/
みかわわん /三河湾/
みかん /未完;incomplete/蜜柑/未刊;unpublished/味感/
みかんいろ /蜜柑色/
みかんか /ミカン科/
みかんがり /みかん狩り/
みかんけつ /未完結/
みかんさくひん /未完作品/
みかんせい /未完成/
みかんせいこうきょうきょく /未完成交響曲;Unvollendete Symphonie, 1822, Schubert/
みかんせいばん /未完成版/
みかんせいひん /未完成品/
みかんばこ /みかん箱/
みかんもく /ミカン目/Rutales/
みかんりょう /未完了/
みかんりょうかこ /未完了過去/
みかんりょうそう /未完了相/
みがき /磨き/
みがきこ /磨き粉/
みがきずな /磨き砂/
みがきにしん /身欠き鰊/
みがく /研/
みがくしゅう /未学習/
みがため /身固め/
みがって /身勝手/
みがまえ /身構え/
みがら /身柄/
みがらそうけん /身柄送検/
みがる /身軽/
みがわり /身代わり/身代り/
みき /幹/神酒/御酒/未来/美貴/美紀/美樹/美希/未稀/三木/未希/美喜/美季/光希/美来/三樹/御木/実紀/三紀/三城/三喜/三基/未木/
みきお /幹夫/幹雄/幹男/三起男/
みきき /見聞き/
みきこ /美紀子/幹子/美樹子/美貴子/美希子/実希子/
みきさーしゃ /ミキサー車;mixer truck/
みきたけお /三木武夫/
みきどう /未起動/
みきにゅう /未記入/
みきのり /幹典/
みきはら /美樹原/
みきひこ /幹彦/三紀彦/未来彦/
みきほ /美喜帆/
みきもと /美樹本/
みきや /幹哉/御喜家/
みきょうらん /美狂乱/
みきよ /幹代/
みきり /見切り/
みきりはっしゃ /見切り発車/
みきりひん /見切り品;bargains/
みきろふう /三木露風;(1889-1964) 詩人/
みきわめ /見極め/
みぎ /右/→/＞/）/】/』/」/
みぎ> /右;右打者,右方向/
みぎあし /右足/右脚/
みぎいっぱい /右一杯/
みぎうえ /右上/
みぎうえすみ /右上隅/
みぎうしろ /右後/
みぎうち /右打ち;[野球]/右打/
みぎうで /右腕/
みぎえだ /右枝/
みぎおく /右奥/
みぎかいてん /右回転/
みぎかた /右肩/
みぎかたあがり /右肩上がり/
みぎかたさがり /右肩下がり/
みぎかっこ /右括弧/』/】/
みぎがき /右書き/
みぎがわ /右側/
みぎがわつうこう /右側通行/
みぎきき /右利き/右利/
みぎぎし /右岸/
みぎくりっく /右クリック/
みぎけつごう /右結合/
みぎこ /右子/
みぎこうほう /右後方/
みぎこし /右腰/
みぎさいど /右サイド/
みぎした /右下/
みぎしたすみ /右下隅/
みぎしもて /右下手/
みぎしゃせん /右車線/
みぎしゃめん /右斜面/
みぎすみ /右隅/
みぎず /右図/
みぎぜんぽう /右前方/
みぎぜんりん /右前輪/
みぎそくめん /右側面/
みぎそで /右袖/
みぎそろえ /右揃え/
みぎだしゃ /右打者/
みぎだせき /右打席/
みぎちゅうだん /右中段/
みぎづめ /右詰め/
みぎて /右手/
みぎておやゆび /右手親指/
みぎてがわ /右手側/
みぎてくび /右手首/
みぎてけい /右手系/
みぎてぜんぽう /右手前方/
みぎてなかゆび /右手中指/
みぎてまえ /右手前/
みぎてよう /右手用/
みぎてんかい /右転回/
みぎとうしゅ /右投手/
みぎどなり /右隣/右隣り/
みぎどもえ /右巴/
みぎなげ /右投げ/
みぎのり /右乗/
みぎはし /右端/
みぎはんどる /右ハンドル/
みぎはんぶん /右半分/
みぎはんめん /右半面/
みぎひざ /右膝/
みぎひじ /右肘/
みぎひだり /右左/
みぎほうこう /右方向/
みぎほお /右頬/
みぎぼたん /右ボタン/
みぎまえ /右前/
みぎまえあし /右前足/右前脚/
みぎまがり /右曲り/
みぎまき /右巻き/右巻/
みぎまつ /右松/右末/
みぎまわり /右回り/
みぎみみ /右耳/
みぎむき /右向き/
みぎむね /右胸/
みぎめ /右目/
みぎめよう /右目用/
みぎや /→/⇒/右矢/
みぎやじるし /→/⇒/右矢印/
みぎょうしょ /御教書/
みぎよう /右様/
みぎようそ /右要素/
みぎよこ /右横/
みぎよせ /右寄せ/右寄/
みぎよつ /右四つ/
みぎより /右寄/右寄り/
みぎり /砌/
みぎれい /身綺麗/
みぎわ /汀/水際/頻/
みぎわき /右脇/
みく /未来;人名/美久/美来/
みくだりはん /三行半/三下り半/三下半/
みくち /三口/
みくに /三国;地名/御国;「国」旧字/三國;「国」旧字/皇國;「国」旧字/御國;「国」旧字/
みくにかいどう /三国街道;高崎-越後/
みくにことば /御国言葉/
みくにちょう /三国町/
みくにとうげ /三国峠/
みくにやま /三国山/
みくにれんたろう /三國連太郎/
みくま /三隈/
みくも /三雲/
みくらしま /御蔵島/
みくりや /御厨/
みくるま /御車/
みくろけいざい /ミクロ経済/
みくろけいざいがく /ミクロ経済学;microeconomics/
みくろぶんせき /ミクロ分析/
みくろん /μ;1／1000mm/
みぐし /御髪/御首/御頭/
みぐるみ /身包み/身ぐるみ/
みけ /三毛/
みけいかほけんりょう /未経過保険料/
みけいけん /未経験/
みけいけんしゃ /未経験者/
みけいさい /未掲載/
みけいさん /未計算/
みけいやく /未契約/
みけた /三桁/
みけっさい /未決済/
みけってい /未決定/
みけつ /未決/
みけつこうりゅう /未決勾留/
みけつしゅう /未決囚/
みけねこ /三毛猫/
みけん /眉間/未見/
みけんしゅつ /未検出/
みけんせつ /未建設/
みけんとう /未検討/
みこ /巫女/皇子/御子/美子/巫/親王/皇女/神子/
みこう /未稿/
みこうかい /未公開/
みこうかいかぶ /未公開株/
みこうかいきょく /未公開曲/
みこうにゅう /未購入/
みこうひょう /未公表/
みこころ /御心/
みこし /神輿/御輿;≒神輿 NB:人間が乗るのは常にこちらの字/
みこしぐさ /御輿草/
みこしば /御子柴/
みこと /命/尊/三言/御言/美琴;人名/
みことのり /詔/勅/敕;「勅」の異体字/
みことば /御言葉/
みこばら /皇女腹/
みこみ /見込/見込み/
みこみがく /見込額/
みこみちがい /見込み違い/
みこん /未婚/未墾/
みこんしゃ /未婚者/
みこんじょせい /未婚女性/
みごうしゃ /見巧者/
みごえ /実肥/
みごしらえ /身拵え/
みごたえ /見応え/見ごたえ/
みごと /見事/
みごろ /見頃;†桜の-/身頃;†ワンピースの-/
みごろし /見殺し/
みさ /弥撒;missa/美沙;人名/美砂/美佐/未沙/美紗/魅紗/
みさい /未済/
みさいぶん /未済分/
みさいるこうげき /ミサイル攻撃/
みさいるぼうえい /ミサイル防衛/
みさお /操/美沙緒/
みさか /御坂/三阪/
みさかい /見境/
みさき /岬/崎/御前/御先/美咲/三崎/三咲/美沙紀/
みさきぐち /三崎口/
みさきこう /三崎港/
みさきちょう /三崎町/
みさきょく /ミサ曲;mass/
みさくせい /未作成/
みさくぼ /水窪/
みさこ /美佐子/美沙子/美砂子/美咲子/
みさご /鶚/雎鳩/
みさごずし /鶚鮨/
みささ /三朝;地名/三篠/三笹/
みささぎ /陵/御陵;ごりょう/山陵;さんりょう/
みさだめ /見定め/
みさと /美里/三郷/美郷/箕郷/
みさとし /三郷市/
みさわ /三沢/三澤/
みさわえき /三沢駅/
みさわし /三沢市/
みさわやま /実沢山/
みさんか /未参加/
みさんしょう /実山椒/
みしお /美潮/
みしきべつ /未識別/
みしこう /未施行/
みしてい /未指定/
みしな /三品/
みしま /三島/三嶋/
みしまえき /三島駅/
みしまおこぜ /三島虎魚/
みしまし /三島市/
みしまたいしゃ /三嶋大社/
みしまたまち /三島田町/
みしまで /三島手/
みしまひろこうじ /三島広小路/
みしまひろこうじえき /三島広小路駅/
みしまふつかまち /三島二日町/
みしまゆきお /三島由紀夫/
みしゅう /未収/
みしゅうがく /未就学/
みしゅうがくじ /未就学児/
みしゅうがくじどう /未就学児童/
みしゅうきん /未収金/未集金/
みしゅうしょく /未就職/
みしゅうせい /未修正/
みしゅうにゅうきん /未収入金/
みしゅうり /未修理/
みしゅうろく /未収録/
みしゅうろくきょく /未収録曲/
みしゅうろくさくひん /未収録作品/
みしゅうろくぶん /未収録分/
みしゅく /三宿/
みしゅっそう /未出走/
みしゅっそうば /未出走馬/
みしゅつげん /未出現/
みしゅとく /未取得/
みしょう /未詳/実生;[植物]seedling/未生/御荘;地名/
みしょういぜん /未生以前/
みしょうか /未消化/
みしょうだく /未承諾/
みしょうだくこうこく /未承諾広告/
みしょうにん /未承認/
みしょうり /未勝利/
みしょうりせん /未勝利戦/
みしょうりば /未勝利馬/
みしょうりゅう /未生流;生け花/
みしょきか /未初期化/
みしょぶん /未処分/
みしょり /未処理/
みしよう /未使用/
みしようくかん /未使用区間/
みしようしんぴん /未使用新品/
みしようじ /未使用時/
みしようひん /未使用品/
みしようぶん /未使用分/
みしようりょういき /未使用領域/
みしらず /身知らず/
みしるし /御璽/
みしん /未進/
みしんばり /ミシン針/
みしんめ /ミシン目/
みじか /身近/短/
みじかうた /短歌/
みじかめ /短め/
みじかよ /短夜/
みじたく /身支度/身仕度/
みじっし /未実施/
みじっそう /未実装/
みじまい /身仕舞/身仕舞い/
みじめ /惨め/
みじゅく /未熟/
みじゅくじ /未熟児/
みじゅくもの /未熟者/
みじゅこう /未受講/
みじゅせい /未受精/
みじゅせいらん /未受精卵/
みじゅり /未受理/
みじろぎ /身じろぎ/身動ぎ/
みじん /微塵/
みじんぎり /微塵切り/みじん切り/
みじんこ /微塵子/微塵粉;もちごめで作った粉/
みじんこっぱい /微塵骨灰/
みす /御簾/三栖/
みすい /未遂/
みすいざい /未遂罪/
みすいじけん /未遂事件/
みすえ /三末/御末/
みすか /美須賀/
みすがた /御姿/
みすぎ /美杉/身過ぎ/
みすぎいそ /三杉磯/
みすぎさと /三杉里/
みすぎよすぎ /身過ぎ世過ぎ/
みすじ /三筋/
みすず /美鈴/三鈴/
みすまる /御統/
みすみ /三角/三隅/
みすみす /見す見す;-逃す/
みず /水/瑞/
みずあか /水垢/
みずあげ /水揚げ/
みずあさぎ /水浅葱/
みずあし /水足/
みずあそび /水遊び/
みずあび /水浴び/
みずあめ /水飴/
みずあらい /水洗い/
みずい /水井/
みずいけ /水池/
みずいで /水出/
みずいと /水糸/
みずいも /水芋/
みずいらず /水入らず/
みずいり /水入り/
みずいれ /水入れ/
みずいろ /水色/
みずいろじだい /水色時代;[アニメ]/
みずうみ /湖/
みずえ /水絵/瑞江/瑞枝/
みずお /瑞生/瑞男/
みずおけ /水桶/
みずおち /鳩尾/
みずおと /水音/
みずおよぎ /水泳ぎ/
みずかえ /水替え/
みずかがみ /水鏡/
みずかき /水掻き/蹼/
みずかけろん /水掛け論/水掛論/
みずかげ /水影/
みずかげん /水加減/
みずかさ /水嵩/水かさ/
みずかね /水銀/
みずかみ /水上/
みずかめざ /水瓶座;=みずがめざ/
みずから /自ら/
みずかわ /水川/
みずがかり /水掛/
みずがき /瑞垣;神山・神社などの垣/瑞籬;=瑞垣/水垣;=瑞垣/水柿;人名/
みずがし /水菓子;果物/
みずがね /水銀/
みずがめ /水瓶/水甕/
みずがめざ /水瓶座;Aquarius(Aqr),(1.20-2.18)/
みずがれ /水涸れ/
みずき /水樹/水木/水城/瑞希;名/瑞季/瑞木/美寿紀/未図紀/
みずききん /水飢饉/
みずきり /水切り/水切/
みずきん /水金/
みずぎ /水着/
みずぎすがた /水着姿/
みずぎたいかい /水着大会/
みずぎょう /水行/
みずぎれ /水切れ;[園芸]水がなくなって萎れる/
みずぎわ /水際/
みずぎわさくせん /水際作戦/
みずくき /水茎/
みずくさ /水草/
みずくさい /水臭い/
みずくぼ /水窪/
みずくぼこ /水窪湖/
みずぐすり /水薬/
みずぐち /水口/
みずぐも /水蜘蛛;water spinner/
みずぐるま /水車/
みずけ /水気/
みずけむり /水煙/
みずげい /水芸/
みずこ /水子/
みずこうばい /水勾配;[建築]排水のための勾配/
みずこくよう /水子供養/
みずこし /水越/
みずこじぞう /水子地蔵/
みずこぼし /水翻;茶道具/
みずこれい /水子霊/
みずごえ /水肥/
みずごけ /水苔;bog moss/水蘚/
みずごころ /水心/
みずごり /水垢離/
みずごろも /水衣/
みずさいばい /水栽培/
みずさかずき /水杯/水盃/
みずさき /水崎/水先/
みずさきあんない /水先案内/
みずさきあんないにん /水先案内人/
みずさきく /水先区/
みずさきにん /水先人/
みずさし /水差し/水指/水差/
みずさわ /水沢/水澤/
みずさわけいば /水沢競馬/
みずさわけいばじょう /水沢競馬場/
みずさわし /水沢市/
みずさわほたる /水沢蛍;人名/
みずし /瑞史/
みずしげん /水資源/
みずしごと /水仕事/
みずしぶき /水飛沫/水しぶき/
みずしま /水島/水嶋/水縞/水嶌/
みずしましんじ /水島新司/
みずしまや /水島屋/
みずしょうばい /水商売/
みずしょり /水処理/
みずしらず /見ず知らず/
みずしろ /水城/
みずすまし /水澄/
みずせ /水瀬/
みずせっけん /水石鹸/
みずせつやく /水節約/
みずせん /水栓/
みずぜき /水関/
みずぜめ /水攻め;城の-/水責め;拷問./
みずた /水田/
みずたき /水炊き/
みずたに /水谷/
みずたま /水玉/
みずたまもよう /水玉模様/
みずたまり /水溜り/水溜/水溜まり/
みずだこ /水蛸/水章魚/
みずだし /水出し;-麦茶/
みずち /蛟/
みずちゃや /水茶屋;湯茶を供する/
みずちゅうどく /水中毒;[医]water intoxication/
みずっぱな /水っ洟;ブワックシオォン！ズルズル…/
みずつき /七寸/水付/
みずづけ /水漬け/水漬/
みずてきりょう /水適量/
みずてっぽう /水鉄砲/
みずてん /不見転;[遊廓]/不見点;「-で買う」<花札用語/
みずでっぽう /水鉄砲/
みずとき /水溶き/
みずとり /水鳥/
みずどけい /水時計/
みずどり /水鳥/
みずな /水菜/
みずなし /水梨/水無/
みずなしがわ /水無し川/
みずなみ /瑞浪/
みずに /水煮/
みずぬき /水抜き/水抜/
みずぬま /水沼/
みずぬれ /水濡れ;-注意/
みずの /水野/
みずのあわ /水の泡/
みずのえ /壬;[十干]9/
みずのえいぬ /壬戌/
みずのえうま /壬午/
みずのえき /水野駅/
みずのえさる /壬申/
みずのえたつ /壬辰/
みずのえとら /壬寅/
みずのえね /壬子/
みずのきえき /水軒駅/
みずのただくに /水野忠邦;(1794-1851) 天保の改革/
みずのて /水の手/
みずのと /癸;[十干]10/
みずのとい /癸亥/
みずのとう /癸卯/
みずのとうし /癸丑/
みずのととり /癸酉/
みずのとひつじ /癸未/
みずのとみ /癸巳/
みずのみ /水飲み/水呑み/
みずのみば /水飲み場/水呑場/
みずのみびゃくしょう /水呑み百姓/
みずのもり /水の森/
みずはけ /水捌け/
みずはし /水橋/
みずはら /水原/
みずば /水場/
みずばしょう /水芭蕉/
みずばしら /水柱/
みずばち /水鉢/
みずばら /水腹/
みずばり /水張り/
みずばん /水番/
みずぱいぷ /水パイプ;houka/
みずひき /水引/
みずひと /瑞史/
みずひろ /瑞洋/
みずびたし /水浸し/
みずぶき /水拭き/
みずぶくれ /水膨れ/水脹れ;火傷跡の-/
みずぶそく /水不足/
みずぶとり /水太り/
みずぶろ /水風呂/
みずぶんし /水分子/
みずへびざ /水蛇座;Hydrus(Hyi)/
みずべ /水辺/
みずほ /瑞穂/
みずほきゅうぎじょう /瑞穂球技場/
みずほきょうぎじょう /瑞穂競技場/
みずほせいさくしょ /瑞穂製作所;[企業名]/
みずぼうそう /水疱瘡/
みずぼり /水堀/
みずま /三潴;地名/水間/
みずまき /水撒き/水巻/
みずまくら /水枕/
みずまし /水増し/水増/
みずまち /水町/
みずまわり /水廻り/水回り/水周り/
みずむけ /水向け/
みずむし /水虫/
みずむしやく /水虫薬/
みずもと /水本/
みずもの /水物/
みずもり /水杜/
みずもれ /水漏れ/
みずや /水屋/
みずやま /水山/
みずやり /水やり/水遣り/
みずよ /瑞代/
みずようかん /水羊羹/
みずら /髻/鬟/角子/角髪/
みずろう /水牢/
みずわり /水割り/
みせ /店/壥/廛/三瀬/見世/
みせいじゅく /未成熟/
みせいじゅくらん /未成熟卵/
みせいせい /未生成/
みせいねん /未成年/
みせいねんしゃ /未成年者/
みせいねんじだい /未成年時代/
みせいび /未整備/
みせいり /未整理/
みせうり /店売り/店売/
みせかけ /見せ掛け/
みせかた /見せ方/
みせがね /見せ金/
みせがまえ /店構え/
みせがわ /店側/
みせこう /未施行/
みせさき /店先/
みせしめ /見せしめ/
みせじたい /店自体/
みせじまい /店仕舞い/店仕舞/店じまい/
みせだな /店棚/見世棚/
みせってい /未設定/
みせつ /未設/
みせつけ /見せつけ/見せ付け/
みせつぞく /未接続/
みせづくり /店作り/
みせどころ /見せ所;腕の-/
みせば /見せ場/
みせばん /店番/
みせばんごう /店番号/
みせびらき /店開き/
みせもの /見世物/見せ物/
みせや /店屋/
みせんげん /未宣言/
みせんたく /未選択/
みぜに /身銭/
みぜん /未然/
みぜんけい /未然形/
みそ /味噌/三十/
みそあじ /味噌味/
みそあん /味噌餡/味噌あん/
みそう /未送/
みそか /三十日/晦/晦日/密か;=ひそか/
みそかつ /味噌カツ/
みそぎ /禊/
みそくそ /味噌糞/
みそくてい /未測定/
みそくばく /未束縛/
みそぐら /味噌蔵/
みそこし /味噌漉し/
みそさざい /鷦鷯/
みそしき /未組織/
みそしょうゆ /味噌醤油/
みそしる /味噌汁/
みそじ /三十路/
みそじひともじ /三十一文字/
みそだま /味噌玉/
みそっかす /味噌っ滓/
みそっぱ /味噌っ歯/
みそづけ /味噌漬/
みそに /味噌煮/
みそにこみ /味噌煮込み/味噌煮込/
みその /御園/三園/美薗;「園」異体字/
みそのう /御園生/
みそひともじ /三十一文字/
みそまめ /味噌豆/
みそもじあまりひともじ /三十文字余り一文字;=短歌,三十一文字/
みそやき /味噌焼/味噌焼き/
みそら /美空;人名/身空;若い-で/
みそらーめん /味噌ラーメン/
みそらひばり /美空ひばり/
みそんじ /見損じ/
みぞ /溝/渠;(特に)排水用のミゾ/
みぞい /溝井/
みぞう /未曾有/未曽有;「曾」異体字/
みぞうえ /溝上/
みぞうち /溝内/
みぞおち /鳩尾/
みぞきり /溝切り/
みぞぐち /溝口/
みぞた /溝田/
みぞて /溝手/
みぞのくち /溝の口/
みぞはし /溝端/
みぞぶち /溝渕/溝淵/
みぞべ /溝辺/
みぞれ /霙/
みた /三田/見田/美田/
みたいおう /未対応/
みたいけん /未体験/
みたいけんしゃ /未体験者/
みたいしょ /未対処/
みたえき /三田駅/
みたか /三鷹/
みたかえき /三鷹駅/
みたかかん /三鷹間/
みたかし /三鷹市/
みたかしやくしょまえ /三鷹市役所前/
みたかせん /三鷹線/
みたかん /三田間/
みたがわ /三田川/
みたけ /御岳/身丈/御嵩/三岳/三嶽/
みたこうぎょう /三田工業;[企業名]/
みたせん /三田線/
みたっせい /未達成/
みたつ /未達;未達成/
みたて /見立て/御館/
みたてちがい /見立て違い/
みたに /三谷/見谷/
みたび /三度/
みたぶんがく /三田文学;雑誌/
みたま /御霊/三珠/御魂/
みたまや /御霊屋/
みたむら /三田村/
みたむらえんぎょ /三田村鳶魚/
みため /見た目/
みたよしこ /三田佳子/
みたらい /御手洗/
みたらし /御手洗/御弓/御執;=御弓/
みたらしだんご /御手洗団子/
みたり /三人/
みたんさく /未探索/
みだ /弥陀/
みだい /御台/見台;?/
みだいどころ /御台所/
みだし /見出し/＊/◇/■/※/
みだしご /見出し語/
みだしなみ /身嗜み/身だしなみ/
みだら /淫ら;(字義:色事に耽る)/猥ら;(字義:秩序がない)/婬;≒淫(ら)/
みだりに /妄りに/濫りに/猥りに/
みだれ /乱れ/
みだれがみ /乱れ髪/みだれ髪;(与謝野晶子の歌集)/
みだれば /乱れ刃/
みだればん /乱れ版/
みち /道/未知/途;(字義:長く延びた道)/路;(字義:連絡路)/蹊;(字義:細い小路)/通;(人名用)/倫;(人名用)/謐;(呉音の一つ)/美知/満ち/径/
みちあき /道明/通明/通晃/道朗/
みちあんない /道案内/
みちいと /道糸/
みちうえ /道上/
みちえ /美智恵/道恵/
みちお /道夫/道雄/通夫/道男/道生/三千雄/三千夫/道央/
みちか /美智香/
みちかけ /満ち欠け;phases. 「月の-」/盈ち虧け/
みちがい /見違い/
みちがえ /見違え/
みちがみ /道上/
みちがわ /道側/
みちくさ /道草/
みちこ /美智子/道子/倫子/路子/美知子/通子/美千子/満子/三智子/光知子/
みちご /未知語/
みちさと /満里/
みちしお /満ち潮/満ち汐/
みちしるべ /道標/道導;=道標/
みちじゅん /道順/
みちすう /未知数/
みちすがら /道すがら/
みちすじ /道筋/
みちぞい /道沿/
みちた /道田/
みちたか /道隆/通隆/充隆/命孝/
みちたろう /道太郎/美知太郎/
みちつた /道蔦/
みちづら /道面/道列/
みちづれ /道連れ/
みちとし /通敏/
みちなか /道中/
みちなかば /道半ば/
みちならぬ /道ならぬ;-恋/
みちなり /道形;-に行く/道成;人名/道也/途也/
みちにし /道西/
みちのえき /道の駅;drive-in/
みちのく /陸奥/
みちのくがみ /陸奥紙/
みちのし /道師/
みちのなか /道の中/
みちのべ /道の辺/
みちのり /道程/道のり/
みちはば /道幅/
みちはら /道原/
みちはる /道春/亨治/
みちば /道場/
みちばた /道端/路傍/路端/道傍/
みちばろくさぶろう /道場六三郎/
みちひ /満ち干/
みちひき /満ち引き;潮の-/
みちひこ /導彦/
みちひで /通秀/
みちひろ /道弘/道広/通洋/道洋/道宏/通博/倫洋/倫広/
みちびき /導き/
みちぶしん /道普請/
みちへんすう /未知変数/
みちべ /道辺/
みちみち /道々/道道;みっちゃん-/
みちむこ /道向/
みちむら /道村/
みちゃく /未着/
みちゃくしゅ /未着手/
みちゃくよう /未着用/
みちゆき /道行/道行き/
みちょう /未聴/
みちょうか /未超過/
みちょうさ /未調査/
みちよ /美智代/道代/三千代/美千代/路代/満代/通代/道世/美千世/
みちよし /道由/
みちる /未散/未知瑠/
みちろう /道郎/
みちわる /道悪/
みぢか /身近/
みっか /三日/３日/3日/
みっかい /密会/
みっかいち /三日市/
みっかかん /三日間/
みっかてんか /三日天下/
みっかねつ /三日熱;[医]vivax/
みっかび /三ヶ日/三ケ日/
みっかびちょう /三ケ日町/
みっかぼうず /三日坊主/
みっかみばん /三日三晩/
みっかめ /三日目/
みっきょう /密教/
みっきょうきょうてん /密教経典/
みっきょうびじゅつ /密教美術/
みっくすけん /ミックス犬/
みっけい /密計/
みっこう /密航/密行/
みっこうしゃ /密航者/
みっこく /密告/
みっこくしゃ /密告者/
みっさつ /密殺/
みっし /密使/
みっしつ /密室/
みっしつさつじん /密室殺人/
みっしつせい /密室性/
みっしつぶつ /密室物/
みっしゅう /密集/
みっしゅうたい /密集体/
みっしょ /密書/
みっしょく /密植;⇔疎植/
みっしょんけい /ミッション系/
みっせい /密生/
みっせつ /密接/
みっせん /密栓/
みっそ /密訴/
みっそう /密葬;private funeral/密送;密かに送る/密奏;密かに奏上する/
みっちゃく /密着/
みっちゃくせい /密着性/
みっちゃくど /密着度/
みっちゃくれんけつき /密着連結器/
みっつ /三つ/３つ/3つ/
みっつう /密通/
みっつめ /三つめ/
みってい /密偵/
みっぷう /密封/
みっぷうほうそう /密封包装/
みっぷうようき /密封容器/
みっぺい /密閉/密蔽/
みっぺいがた /密閉型/
みっぺいけい /密閉型/
みっぺいしき /密閉式/
みっぺいじょうたい /密閉状態/
みっぺいせい /密閉性/
みっぺいど /密閉度/
みっぺいようき /密閉容器/
みつ /蜜;honey/密;dense/三つ/三/光/満/充/円;(人名用)/櫁;しきみ/謐;(呉音) 静謐/滿;「満」の旧字/
みつあき /光昭/光明/充章/光璋/充璋/
みつあみ /三つ編み;髪型/
みつい /三井/
みついぎんこう /三井銀行/
みついけんせつ /三井建設;[企業名]/
みついこうざん /三井鉱山/
みついし /三石/三ッ石/
みついじょうほうかいはつ /三井情報開発/
みついすみともぎんこう /三井住友銀行/
みついせいとう /三井製糖/
みついせきか /三井石化/
みついせきゆかがく /三井石油化学;[企業名]/
みついそうこ /三井倉庫/
みついぞうせん /三井造船/
みついとうあつかがく /三井東圧化学;[企業名]/
みついふとう /三井埠頭/
みついふどうさん /三井不動産/
みついぶっさん /三井物産;[企業名]/
みついわ /三岩;姓/
みつうん /密雲/
みつえ /御杖/光恵/光江/光枝/
みつお /光男/光雄/満男/光夫/三男/三雄/三夫/光生/満雄/満夫/充雄/光穂/
みつおり /三つ折り/三つ折/
みつかいどう /水海道/
みつかげ /光影/
みつかん /蜜柑/
みつが /密画/
みつがさね /三つ重ね/
みつがしわもく /Menyanthales/ミツガシワ目/
みつき /三月/美月/観月/
みつぎ /密議;†秘密の会議/密儀;†秘密の儀式/調;tax/三ツ木/三ッ木/
みつぎもの /貢ぎ物/
みつぎょうれつ /密行列/
みつぎりぼん /三つ切本/
みつくち /兎唇/
みつくり /箕作/
みつぐ /貢/
みつぐみ /三つ組/三組/
みつけ /見附/見付/
みつけつごう /密結合/
みつけつごうがた /密結合型/
みつげつ /蜜月/
みつげつりょこう /蜜月旅行;honeymoon/
みつげん /蜜源/
みつげんしょくぶつ /蜜源植物/
みつこ /光子/美津子/満子/美都子/充子/三津子/
みつこし /三越/
みつこしちか /三越地下/
みつこしほんかん /三越本館/
みつこしほんてん /三越本店/
みつこしまえ /三越前/
みつこしまええき /三越前駅/
みつご /三つ子;-の魂百まで/三子/蜜語/密語/
みつごん /密言/
みつさと /満里/
みつざわ /光澤/
みつしま /美津島/満島;姓/
みつじ /光地/密事/
みつせ /三瀬/光瀬/
みつせりゅう /光瀬龍/
みつせん /蜜腺/
みつぞう /密造/
みつぞうしゅ /密造酒/
みつぞろい /三つ揃い/
みつぞろえ /三つ揃え/
みつた /光田/
みつたか /充隆/光毅/
みつたけ /光威/満武/
みつだ /光田/満田/
みつだん /密談/
みつつじ /光辻/
みつつぼ /蜜壺/
みつづか /三塚/
みつてる /光輝/充照/
みつてん /密天/
みつとし /光俊/光年/充敏/
みつとも /三友/
みつど /密度/
みつどかんすう /密度関数/
みつどせいそう /密度成層/
みつどぶんぷ /密度分布/
みつどもえ /三つ巴/
みつどやくそう /密度躍層/
みつなが /光永/満永/
みつながしわ /御綱柏/
みつなり /三成/光成/実成/
みつにゅうこく /密入国/
みつのがしわ /三角柏/
みつのぶ /光信/光伸/光延/
みつのり /光徳/光範;名/光紀/充則/
みつはし /三橋/三ツ橋/
みつはる /光晴/充治/
みつば /三葉/三つ葉/
みつばい /密売/
みつばいにん /密売人/
みつばち /蜜蜂/
みつひきりょう /三つ引き両/
みつひこ /光彦/美比古/
みつひさ /三久/充久/
みつひで /光秀/
みつひろ /光弘/光博/光宏/光浩/充弘/充宏/光裕/充洋/充浩/充博/満弘/満浩/円博/
みつびし /三菱/
みつびしうらわ /三菱浦和;[企業名]/
みつびしえんぴつ /三菱鉛筆;[企業名]/
みつびしかがく /三菱化学;[企業名]/
みつびしかこうき /三菱化工機;[企業名]/
みつびしかせい /三菱化成;[企業名]/
みつびしきんぞく /三菱金属;[企業名]/
みつびしぎんこう /三菱銀行;[企業名]/
みつびしけい /三菱系/
みつびししょうじ /三菱商事;[企業名]/
みつびしじこうきょうと /三菱自工京都;[企業名]/
みつびしじしょ /三菱地所;[企業名]/
みつびしじどうしゃ /三菱自動車;[企業名]/
みつびしじゅうこう /三菱重工;[企業名]/
みつびしじゅうこうぎょう /三菱重工業;[企業名]/
みつびしじゅし /三菱樹脂;[企業名]/
みつびしせい /三菱製/
みつびしせいこう /三菱製鋼;[企業名]/
みつびしせいし /三菱製紙;[企業名]/
みつびしせきゆ /三菱石油;[企業名]/
みつびしそうけん /三菱総研;[企業名]/
みつびしそうこ /三菱倉庫;[企業名]/
みつびしでんき /三菱電機;[企業名]/
みつびしでんきさんぎょう /三菱電機産業;[企業名]/
みつびしはつ /三菱初;?/
みつびしゆか /三菱油化;[企業名]/
みつびしれいよん /三菱レイヨン;[企業名]/
みつぶつ /密勿/
みつぼう /密謀/
みつぼうえき /密貿易/
みつぼし /三つ星/三星/三ッ星/
みつぼしべると /三ツ星ベルト/
みつまさ /光正/光政/光雅/
みつまた /三叉/三椏/三つ股/三つ叉/
みつまたやり /三又槍/
みつまめ /蜜豆/
みつみつ /密々/密密/
みつめ /三つ目/
みつめい /密命/
みつもう /密毛/
みつもと /光本/
みつもり /見積/見積もり/見積り/三森/
みつもりいらいしょ /見積依頼書/
みつもりしょ /見積書/
みつもん /三つ紋/
みつや /三矢/三ッ矢/
みつやく /密約/
みつゆ /密輸/
みつゆき /光之/充之/三幸/
みつゆしゅつ /密輸出/
みつゆせん /密輸船/
みつゆにゅう /密輸入/
みつゆび /三つ指/三ッ指/
みつよ /光代/光世/
みつよし /光義/
みつりょう /密猟/密漁/
みつりょうしゃ /密猟者/密漁者/
みつりん /密林/
みつる /充/満/滿;旧字/美弦/
みつろう /蜜蝋/光郎/
みつわ /三輪/
みづ /美津/
みづき /観月/
みづきしょぼう /三月書房/
みづくろい /身繕い/
みづち /蛟/
みづの /美津濃/
みづら /見面/
みて /御手/見手;watcher/
みてい /未定/
みていぎ /未定義/
みていぎご /未定義語/
みていぎへんすう /未定義変数/
みていぎめいれい /未定義命令/
みていけいすう /未定係数/
みていけいすうほう /未定係数法/
みていこう /未定稿/
みていしゅつ /未提出/
みていち /未定値/
みていねん /未丁年/
みてくれ /見て呉れ/
みてぐら /幣/
みと /水戸/三戸/美都/御津/弥刀/
みといずみ /水戸泉/
みとう /未踏;†誰も立ち入らなかった。「人跡-」/未到;†誰も到達できなかった。「前人-」/美東/味到/
みとうこう /未投稿/
みとうさ /未踏査/
みとうさい /未搭載/
みとうちゃく /未到着/
みとうりょういき /未踏領域/
みとうろく /未登録/
みとうろくしゃ /未登録者/
みとうわくせい /未踏惑星/
みとえき /水戸駅/
みとおし /見通し/
みとかいどう /水戸街道/
みとがく /水戸学;[日本史]/
みとく /味得/
みとけ /水戸家/
みとげいじゅつかん /水戸芸術館/
みとこうもん /水戸黄門/
みところ /三所/
みところぜめ /三所攻め/
みとさんこう /水戸三高/
みとし /水戸市/
みとしょうけん /水戸証券;[企業名]www.mito.co.jp/
みとせ /三年/三歳/
みとせん /水戸線/
みとそう /未塗装/
みとなっとう /水戸納豆/
みとにこう /水戸二高/
みとみ /三富/
みとめ /認め/三留/
みとめいん /認印/認め印/
みとや /三刀屋/
みとよ /三豊/
みとらきょう /ミトラ教;Mithraism/
みとり /見取/
みとりず /見取り図/見取図/
みどう /御堂/
みどうかいかん /御堂会館/
みどうすじ /御堂筋/
みどうすじせん /御堂筋線/
みどうすじほんまち /御堂筋本町/
みどく /未読;unread/味読;savour/
みどくきじ /未読記事/
みどくぶん /未読分/
みどころ /見所/見どころ/見処/
みどし /巳年/
みども /身共/
みどり /緑/翠/碧/見取り;選り取り-/美登里/美土里/
みどりいし /緑石;[動物]madrepore/
みどりいろ /緑色/
みどりかい /緑会/
みどりかわ /緑川/
みどりがおか /緑ヶ丘/緑が丘/緑ケ丘/緑が岡/
みどりがめ /緑亀/
みどりく /緑区/
みどりご /嬰児/
みどりじゅうじ /ミドリ十字/
みどりちょう /緑町/
みどりでんし /緑電子/
みどりのかくめい /緑の革命;green revolution. 農業技術革新/
みどりのとう /緑の党/
みどりのまどぐち /緑の窓口;JR/
みどりまい /緑米/
みどりまち /緑町/
みどりまめ /緑豆/
みどりみ /緑味/
みどりや /緑屋/
みどりやま /緑山/
みどりやまこうこう /緑山高校/
みどるきゅう /ミドル級;[ボクシング]72.5kg以下/
みどろいけ /深泥池/
みどろがいけ /深泥池/
みな /皆/美奈/美菜/美那/
みない /南井/美内/
みないっしょ /皆一緒/
みなえ /美奈江/
みなおし /見直し/
みなかた /南方/皆方/
みなかたくまぐす /南方熊楠/
みなかみ /水上/
みなかみおんせん /水上温泉/
みなかわ /皆川/
みながわ /皆川/
みなきょうだい /皆兄弟/
みなくち /水口/
みなぐち /皆口/源口/
みなげ /身投げ/
みなこ /美奈子/みな子/美菜子/三奈子/美名子/皆子/実奈子/
みなごろし /皆殺し/鏖/
みなさま /皆様/
みなさまがた /皆様方/
みなさん /皆さん/
みなし /見做し/看做し/
みなしご /孤児/
みなせ /水無瀬/
みなそこ /水底/
みなつ /美夏/
みなつき /水無月;陰暦6月/
みなづき /水無月/水月/
みなと /港/湊;=港/
みなとおおはし /港大橋/
みなとがわ /湊川/
みなとがわこうえん /湊川公園/
みなときたく /港北区/
みなとく /港区/
みなとせいき /港製機/
みなとふじ /湊富士/
みなとまち /港町/湊町/港街/
みなとみなみぐち /港南口/
みなの /皆野/
みなのしゅう /皆の衆/
みなのもの /皆の者;-出合え出合え/
みなびょうどう /皆平等/
みなべ /南部/
みなべがわ /南部川/
みなまた /水俣/
みなまたし /水俣市/
みなまたびょう /水俣病/
みなみ /南/美波/三波/美並/皆実/南美/
みなみ> /南/
みなみあいづ /南会津/
みなみあおやま /南青山/
みなみあきた /南秋田/
みなみあざぶ /南麻布/
みなみあしがら /南足柄;地名,神奈川県西南部の市/
みなみあしがらし /南足柄市/
みなみあじあ /南アジア/
みなみあずみ /南安曇/
みなみあふりか /南アフリカ/
みなみあまべ /南海部/
みなみあめりか /南アメリカ/
みなみあめりかたいりく /南アメリカ大陸/
みなみありま /南有馬/
みなみあるぷすし /南アルプス市;山梨県の西側、南アルプス山麓に位置する4町2村がH15年4月1日に合併してできた市/
みなみいず /南伊豆/
みなみいばらき /南茨木/
みなみうおぬま /南魚沼/
みなみうらわ /南浦和/
みなみうわ /南宇和/
みなみおおさかせん /南大阪線/
みなみおおさわ /南大沢/
みなみおおさわえき /南大沢駅/
みなみおおつか /南大塚/
みなみおぎしま /南荻島/
みなみおぐに /南小国/
みなみおたり /南小谷/
みなみかいがん /南海岸/
みなみかいきせん /南回帰線;Tropic of Capricorn/
みなみかぜ /南風/
みなみかた /南方/
みなみかやべ /南茅部/
みなみかるいざわ /南軽井沢/
みなみかわ /南河/
みなみかわち /南河内/
みなみかん /南館/南舘;「館」異体字/
みなみかんとう /南関東/
みなみかんとうぜい /南関東勢/
みなみかんのんざん /南観音山/
みなみかんばら /南蒲原/
みなみがわ /南側/
みなみきゅうしゅう /南九州/
みなみく /南区/
みなみくしやま /南串山/
みなみくしやまちょう /南串山町/
みなみぐち /南口/
みなみぐちほうめん /南口方面/
みなみこいずみ /南小泉/
みなみこま /南巨摩/
みなみさいたま /南埼玉/
みなみさおり /南沙織/
みなみさく /南佐久/
みなみしが /南志賀/
みなみしこく /南四国/
みなみしたら /南設楽/
みなみしなかい /南支那海/
みなみしなの /南信濃/
みなみしまばら /南島原/
みなみしゃめん /南斜面/
みなみじゅうじざ /南十字座;Crux(Cru)/
みなみじゅうじせい /南十字星/
みなみせん /南線/
みなみたいへいよう /南太平洋/
みなみたか /南高/
みなみたかき /南高来/
みなみたかぎ /南高来/
みなみたかさき /南高崎/
みなみたま /南多摩/
みなみたまえき /南多摩駅/
みなみたまち /南田町/
みなみだ /南田/
みなみだい /南台/
みなみだいとう /南大東/
みなみだいとうじま /南大東島/
みなみだか /南高/
みなみだて /南館/
みなみちいき /南地域/
みなみちく /南地区/
みなみちしま /南千島/
みなみちた /南知多/
みなみちとせ /南千歳/
みなみちょう /南町/
みなみちょうせん /南朝鮮/
みなみつがる /南津軽/
みなみつる /南都留/
みなみで /南出/
みなみでわ /南出羽/
みなみとうきょう /南東京/
みなみとうほく /南東北/
みなみとうほくちほう /南東北地方/
みなみとみよ /南富魚/
みなみとりしま /南鳥島/
みなみどの /南殿/
みなみな /皆々/皆皆/
みなみなか /南那珂/
みなみなさま /皆々様/皆皆様/
みなみなす /南那須/
みなみの /南野/
みなみのうおざ /南魚座;Piscis Austrinus(PsA)/
みなみのかわち /南河内/
みなみのかんむりざ /南冠座;Corona Austrina(CrA)/
みなみのさんかくざ /南の三角座;Triangulum Australe(TrA)/
みなみはっこうだ /南八甲田/
みなみはるお /三波春夫/
みなみはんきゅう /南半球/
みなみはんぶん /南半分/
みなみふくおか /南福岡/
みなみふなばし /南船橋/
みなみふらの /南富良野/
みなみべっぷ /南別府/
みなみほっかいどう /南北海道/
みなみほんしゅく /南本宿/
みなみほんちょう /南本町/
みなみぼうそう /南房総/
みなみまき /南牧/
みなみまち /南町/
みなみまちだ /南町田/
みなみまちぶぎょう /南町奉行/
みなみまつうら /南松浦/
みなみまわり /南回り/
みなみまんしゅうてつどう /南満州鉄道/
みなみみのわ /南箕輪/
みなみみやざき /南宮崎/
みなみむき /南向き/
みなみむら /南村/
みなみむれ /南牟礼/
みなみむろ /南牟婁/
みなみもと /南本/
みなみもとまち /南元町/
みなみもりまち /南森町/
みなみもん /南門/
みなみやましろ /南山城/
みなみやまて /南山手/
みなみゆき /南行/
みなみゆふ /南由布/
みなみゆふえき /南由布駅/
みなみよのえき /南与野駅/
みなみりんかん /南林間/
みなみわっかない /南稚内/
みなも /水面/
みなもと /源/
みなもとけ /源家/
みなもとのかねまさ /源兼昌;淡路島 かよふ千鳥のなく声に 幾夜寝ざめぬ 須磨の関守/
みなもとのさねとも /源実朝;[日本史]三代(1192-1219 在職:1203-19)/
みなもとのしげゆき /源重之;風をいたみ 岩うつ波の おのれのみ くだけて物を 思ふころかな/
みなもとのひろまさ /源博雅;(918-980) ミュージシャン/
みなもとのよしつね /源義経;1159-1189/
みなもとのよりいえ /源頼家;[日本史]二代(1182-1204 在職:1202-03)/
みなもとのよりとも /源頼朝;[日本史]初代(1147-1199 在職:1192-99)/
みなもとよしつね /源義経/
みなもとよりよし /源頼義/
みなよ /美奈代/
みならい /見習い/見習/
みならいこう /見習工/
みなり /身形/身なり/
みなわ /水泡/水沫/
みにかぶ /ミニ株/
みにこみし /ミニコミ誌/
みにゅうしゅ /未入手/
みにゅうりょく /未入力/
みにんてい /未認定/
みね /峰/嶺;≒峰/峯;「峰」の旧字(人名用漢字)/美祢;地名,山口県/三根;地名,佐賀県/岑;≒峰/三子/美禰;「祢」旧字/美根/
みねい /嶺井/
みねうち /峰打ち/
みねお /峰夫/峰雄/峰央/岑生/峯夫/岑夫/実音夫/
みねぎし /峰岸/峯岸/嶺岸/
みねこ /峰子/
みねごし /峰越/
みねざき /峰崎/峯崎/
みねせん /美祢線/
みねの /峯野/
みねのはら /峰の原/
みねはま /峰浜/
みねひさ /峰久/
みねまつ /峰松/
みねむら /峯村/峰村/
みねやま /峰山/
みねゆき /峰幸/
みねらるぶん /ミネラル分/
みねらるるい /ミネラル類/
みねんしょう /未燃焼/
みの /蓑/美濃;岐阜県南部/三野;地名/簑;「蓑」の異体字1/簔;「蓑」の異体字2/箕;(「蓑」ではなく、助詞を含む「み・の」)/
みのいも /蓑芋/
みのう /未納/美濃;みの/箕面;※仮名遣い「みのお」/
みのうえ /身の上/
みのうえばなし /身の上話/
みのうしゃ /未納者/
みのうにゅう /未納入/
みのうぶん /未納分/
みのうら /箕浦/
みのお /箕面/
みのおおた /美濃太田/
みのおせん /箕面線/
みのかも /美濃加茂/
みのかわ /身の皮/
みのがこい /美濃囲い;[将棋]/
みのがし /見逃し/
みのがみ /美濃紙/
みのき /三軒;[建築]三重の垂木/
みのけ /身の毛/
みのげ /蓑毛/
みのしま /箕島/
みのしょう /美濃庄/
みのしろ /身の代/
みのしろきん /身代金/身の代金/
みのたけ /身の丈/
みのため /身の為/身のため/
みのだ /蓑田/簑田/箕田/
みのと /美濃戸/
みのとぐち /美濃戸口/
みのはた /蓑畑/
みのはら /蓑原/箕原/
みのばん /美濃判/
みのぶ /身延/美乃夫/
みのぶさん /身延山/
みのぶせん /身延線/
みのべ /美濃部/
みのべたつきち /美濃部達吉;天皇機関説/
みのほど /身の程/
みのほどしらず /身の程知らず/
みのぼん /美濃本/
みのまわり /身の回り/
みのむし /蓑虫/
みのやき /美濃焼;岐阜/
みのり /実り/稔り/御法/稔/美野里/
みのる /実/稔/實;「実」の旧字(人名用漢字)/穣/
みのわ /箕輪/蓑輪/
みのわた /三の焦/
みはい /未配/
みはいそう /未配送/
みはかし /御刀/
みはし /三橋/
みはた /御旗/
みはっけん /未発見/
みはったつ /未発達/
みはっぴょう /未発表/
みはっぴょうきょく /未発表曲/
みはっぴょうさくひん /未発表作品/
みはっぴょうしゃしん /未発表写真/
みはつ /未発/
みはつばい /未発売/
みはなだ /水縹/
みはば /身幅/
みはま /美浜;地名/御浜;地名,三重県南牟婁郡/
みはまく /美浜区/
みはら /三原/美原/
みはらい /未払い/
みはらいかんじょう /未払勘定/
みはらいきん /未払金/
みはらし /見晴らし/
みはらしだい /見晴らし台/
みはらちょう /美原町/
みはらやま /三原山;地名,伊豆大島/
みはり /見張り/
みはりばん /見張り番/
みはりやく /見張り役/
みはる /三春/美晴/美春/
みはるえき /三春駅/
みば /見端/
みばえ /見栄え/見映え/
みばらい /未払/未払い/
みばらいきん /未払金/
みばらいしょうひぜい /未払消費税/
みばらいひよう /未払費用/
みばん /三晩/
みひじゅん /未批准/
みひつ /未必/
みひつてき /未必的/
みひつのこい /未必の故意;自分の行為からある事実が発生しても仕方がないと認めて行為する心理状態/
みひとつ /身一つ/
みひょうか /未評価/
みひら /三平/
みひらき /見開き/
みびいき /身贔屓/
みびょう /未病;病気ではないが健康ともいえない中間の症状/
みふしとうげ /三伏峠/
みふじ /美富士/
みふたつ /身二つ/
みふね /三船/御船/
みふねとしろう /三船敏郎/
みぶ /壬生/
みぶな /壬生菜;京野菜/
みぶのただみ /壬生忠見/
みぶのただみね /壬生忠岑;ありあけの つれなく見えし 別れより あかつきばかり うきものはなし/
みぶり /身振り/身ぶり/身振/
みぶりてぶり /身振り手振り/
みぶるい /身震い/
みぶん /身分/未分/
みぶんか /未分化/
みぶんしょう /身分証/
みぶんしょうめい /身分証明/
みぶんしょうめいしょ /身分証明書/
みぶんしょうめいしょう /身分証明証/
みぶんそうおう /身分相応/
みぶんちがい /身分違い/
みぶんはん /身分犯/
みぶんふそうおう /身分不相応/
みへん /身偏/
みへんかん /未変換/
みへんとう /未返答/
みほ /美穂/美帆/美保/美歩/美豊/三保/美浦/実穂/美峰/海蜂/
みほうえい /未放映/
みほうしゃ /未放射/
みほうそう /未放送/
みほこ /美穂子/美保子/美帆子/三穂子/
みほしょう /未保証/
みほじんじゃ /美保神社/
みほぜき /美保関/
みほそう /未舗装/
みほそうくかん /未舗装区間/
みほそうどうろ /未舗装道路/
みほそうろ /未舗装路/
みほぞん /未保存/
みほた /三保田/
みほとけ /御仏/
みほのせき /美保関/
みほろ /美浦/
みほん /見本/
みほんいち /見本市/
みほんいちかいじょう /見本市会場/
みほんし /見本誌/
みほんずり /見本刷/
みほんちょう /見本帳/
みほんひん /見本品/
みぼうじん /未亡人/
みま /美馬/三間/
みまい /見舞/見舞い/
みまいきゃく /見舞客/
みまいきん /見舞金/
みまいじょう /見舞状/
みまえ /御前/
みまき /御牧/
みまさか /美作/
みまた /三股/
みまちがい /見間違い/
みまっしょう /未抹消/
みまつ /三松/
みまな /任那/
みまね /見真似/見まね/
みまわし /見回し/見廻し/
みまわり /見回り/
みまわりひん /見回品/
みまん /未満/
みみ /耳/
みみあか /耳垢/
みみあて /耳当て/
みみあな /耳穴/
みみいがい /耳以外/
みみうち /耳打ち/耳打/
みみかき /耳掻き/
みみかくし /耳隠し/
みみかざり /耳飾り/耳飾/
みみがくもん /耳学問/
みみがた /耳型/
みみくそ /耳糞/耳くそ/耳クソ/
みみこぴー /耳コピー/
みみざわり /耳障り;noisy.「-な音」/耳触り;「-が良い」 NB:「耳障り」の誤用から作られた新語/
みみしい /耳癈/
みみしっかん /耳疾患/
みみず /蚯蚓/
みみずく /木菟/角鴟/
みみずばれ /蚯蚓脹れ/
みみせん /耳栓/
みみせんよう /耳栓用/
みみそうじ /耳掃除/
みみたこ /耳タコ/
みみたぶ /耳朶/耳たぶ/
みみだれ /耳垂れ/
みみづか /耳塚/
みみどしま /耳年増/
みみないぶ /耳内部/
みみなしやま /耳成山/
みみなり /耳鳴り/耳鳴/
みみぬき /耳抜き/耳抜/
みみぶくろ /耳袋/
みみへん /耳偏/
みみもちしだぞく /Acrostichum/ミミモチシダ属/
みみもと /耳元/耳許/
みみょう /微妙/
みみより /耳寄り/
みみわ /耳輪/
みむ /美夢/
みむら /三村/
みむらさき /実紫/
みむろ /御室/三室/
みめ /見目/眉目/美芽/
みめい /未明/
みめかたち /見目形/
みもう /味盲;味覚障害/
みもだえ /身悶え/
みもち /身持ち/身持/
みもと /身元/御許;-に召される/身許/
みもとかくにん /身元確認/
みもとちょうさ /身元調査/
みもとひきうけにん /身元引受人/
みもとふめい /身元不明/
みもとほしょう /身元保証/
みもとほしょうきん /身元保証金/
みもの /見物/実物/
みもり /未森/深森/
みもりまる /美森丸/
みもん /未聞/
みゃく /脈/脉;「脈」の異体字/
みゃくあつ /脈圧/
みゃくかん /脈管/
みゃくけい /脈系/
みゃくしん /脈診/
みゃくどう /脈動/
みゃくはく /脈拍/脈搏;=脈拍/
みゃくはくすう /脈拍数/
みゃくみゃく /脈々/脈脈/
みゃくらく /脈絡/
みゃくらくまく /脈絡膜/
みゃくりゃく /脈略/
みゃくりゅう /脈流/
みや /宮/美弥/
みやい /宮井/宮居/
みやいだい /宮医大/
みやいり /宮入/
みやうち /宮内/
みやえき /宮駅/
みやお /宮尾/
みやおか /宮岡/
みやおそうか /ミヤオソウ科/Podophyllaceae/
みやおとみこ /宮尾登美子/
みやかわ /宮川/
みやがく /宮学/
みやがた /宮方/
みやがわ /宮川/
みやがわちょう /宮川町/
みやき /宮木/
みやきょう /宮教/
みやきょうだい /宮教大/宮城教育大学;※abbrev/
みやぎ /宮城;-県/宮木;宮廷の樹木/
みやぎがくいん /宮城学院/
みやぎきょういくだい /宮城教育大/
みやぎけん /宮城県/
みやぎけんみんかいかん /宮城県民会館/
みやぎこうせん /宮城高専/
みやぎざおう /宮城蔵王/
みやぎしま /宮城島/
みやぎの /宮城野/
みやぎのく /宮城野区/
みやぎみちお /宮城道雄;(1894-1956) 箏曲家。十七絃の発案者/
みやく /未訳/
みやくに /宮国/
みやくぼ /宮窪/
みやくら /宮倉/
みやぐち /宮口/
みやけ /三宅/宮家/
みやけいっせい /三宅一生/
みやけざか /三宅坂/
みやけじま /三宅島/
みやげ /土産/
みやげばなし /土産話/
みやげひん /土産品/
みやげもの /土産物/
みやげものてん /土産物店/
みやげものや /土産物屋/
みやげや /土産屋/
みやげよう /土産用/
みやこ /都/宮古/美也子/美弥子/宮子/宮戸/京都/
みやこいり /都入り/
みやこう /宮交/
みやこおおじ /都大路/
みやこおち /都落ち/
みやこじ /都路/
みやこじま /都島/宮古島/
みやこどり /都鳥;名にし負はばいざこととはむ- (伊勢物語)/
みやこのじょう /都城;地名/
みやこびと /都人/
みやこぶしおんかい /都節音階;ミファラシドミ/
みやこわん /宮古湾/
みやご /三八五/
みやごし /宮越/
みやさか /宮坂/
みやさと /宮里/
みやさま /宮様/
みやざき /宮崎/
みやざきおき /宮崎沖/
みやざきかん /宮崎間/
みやざきくうこう /宮崎空港/
みやざきくうこうえき /宮崎空港駅/
みやざきけん /宮崎県/
みやざきけんみん /宮崎県民/
みやざきし /宮崎市/
みやざきじどうしゃどう /宮崎自動車道/
みやざきだい /宮崎台/宮崎大/
みやざきだいがく /宮崎大学/
みやざきちく /宮崎地区/
みやざきどう /宮崎道/
みやざきはやお /宮崎駿/
みやざきもの /宮崎物/
みやざと /宮里/
みやざわ /宮沢/宮澤/
みやざわきいち /宮沢喜一/
みやざわけんじ /宮沢賢治/
みやざわせいけん /宮沢政権/
みやざわばし /宮沢橋/
みやした /宮下/
みやしたこうえん /宮下公園/
みやしの /宮篠/
みやしろ /宮代/
みやじ /宮地/宮路/
みやじま /宮島/宮嶋/
みやじまこうろ /宮島航路/
みやじません /宮島線/
みやじょう /宮絛/
みやすんどころ /御息所/
みやずみ /宮住/
みやずもう /宮相撲/
みやせ /宮瀬/
みやぞえ /宮副/
みやぞの /宮苑/
みやぞのぶし /宮薗節;[浄瑠璃]/
みやた /宮田/
みやたけ /宮武/宮竹/
みやたけがいこつ /宮武外骨/
みやたに /宮谷/
みやだい /宮大/
みやだいく /宮大工/
みやち /宮地/
みやちよ /宮千代/
みやぢ /宮地/
みやぢてっこうしょ /宮地鐵工所/
みやづ /宮津/
みやづかえ /宮仕え/
みやづせん /宮津線/
みやでら /宮寺/
みやと /宮戸/
みやなが /宮永/
みやなぎ /三柳/
みやにし /宮西;姓/
みやの /宮野/
みやのうえ /宮之上/
みやのぎ /宮野木/
みやのさわ /宮の沢/
みやのじょう /宮之城/
みやのぼり /宮登/
みやはら /宮原/
みやばしら /宮柱/
みやばら /宮腹/
みやび /雅/雅び/
みやびと /宮人/
みやびやか /雅びやか/
みやふくせん /宮福線/
みやべ /宮部/
みやま /美山/深山/三山/海山/御山/
みやまいり /宮参り/
みやまえ /宮前/
みやまえく /宮前区/
みやまち /宮町/
みやまちょう /美山町/
みやまる /宮丸/
みやみ /未也美/
みやむら /宮村/
みやもと /宮本/
みやもとむさし /宮本武蔵/
みやもり /宮守/宮森/
みやもんぜき /宮門跡/
みやら /宮良/
みやわき /宮脇/
みゅー /μ;mu/Μ;Mu/
みゅーりゅうし /μ粒子/
みゅう /μ/
みゆう /美憂/
みゆき /深雪/御幸/行幸/み雪/美幸/美由紀/美雪/幸/美由起/美由希/美有紀/
みゆきけおり /御幸毛織;[企業名]/
みゆきせん /美幸線/
みゆにゅう /未輸入/
みょう /妙/名/明/命/冥;冥利/榠/螟;螟蛾(めいが)/
みょうあさ /明朝/
みょうあん /妙案/
みょうえ /明恵/
みょうおう /明王/
みょうおん /妙音/
みょうおんどおり /妙音通/
みょうかい /冥界/
みょうかん /冥官/
みょうが /茗荷;[植物]japanese ginger/冥加;神仏の加護/茗加;?/
みょうがだに /茗荷谷/
みょうきょく /妙曲/
みょうぎ /妙義/妙技/
みょうぎさん /妙義山/
みょうぎしょう /名義抄/
みょうぎょう /明経/
みょうく /妙句/
みょうけい /妙計/
みょうけん /妙見/
みょうけんさん /妙見山;地名/
みょうこう /妙高/
みょうこうあかくら /妙高赤倉/
みょうこうこうげん /妙高高原/
みょうこうじ /妙興寺/
みょうごう /名号/冥合/
みょうごにち /明後日/
みょうごねん /明後年/
みょうさく /妙策/
みょうしゅ /妙手/妙趣/
みょうしゅん /明春/
みょうしょ /妙所/
みょうしんじ /妙心寺/
みょうじ /名字/苗字/
みょうじゅう /命終/
みょうじゅつ /妙術/
みょうじょ /冥助/
みょうじょう /明星/
みょうじょうしょくひん /明星食品/
みょうじょうは /明星派;[文学史]/
みょうじん /明神/
みょうせき /名跡/
みょうせんじしょう /名詮自性/
みょうぜつ /妙絶/
みょうぜんじ /妙善寺/
みょうそう /妙想/
みょうだい /名代/
みょうだに /名谷/
みょうちょう /明朝/
みょうちん /明珍/
みょうにち /明日/
みょうねん /明年/
みょうは /妙葩/
みょうばん /明礬;alum/明晩;tomorrow evening/
みょうぶ /命婦/
みょうほう /妙法/
みょうほうじ /妙法寺/
みょうみ /妙味/
みょうもく /名目/
みょうもん /名聞/
みょうもんりよう /名聞利養/
みょうや /明夜/
みょうやく /妙薬/
みょうよう /妙用/
みょうり /名利;名誉と利益。「-を貪る」/冥利;恩恵。「○○冥利に尽きる」/
みょうれい /妙齢/
みょうれん /明連/
みょうれんじ /妙蓮寺/
みょうれんじえき /妙蓮寺駅/
みょんどん /明洞/
みよ /御代/御世/美代/
みよう /見様/
みようみまね /見様見真似/見よう見まね/見よう見真似/
みよこ /美代子/
みよし /三好/三次/三芳/三吉/三善/三膳/
みよしたつじ /三好達治;(1900-64)詩人。『測量船』/
みよた /御代田/
みよはら /みよ原/
みより /身寄り/
みら /韭/韮/
みらい /未来/味蕾/
みらいえいごう /未来永劫/
みらいかんりょう /未来完了/
みらいがく /未来学/
みらいがた /未来型/
みらいき /未来記/
みらいぎじゅつ /未来技術/
みらいけい /未来形/
みらいしこう /未来志向/
みらいしゃかい /未来社会/
みらいしゅぎ /未来主義;futurismo(It)/
みらいしょうねん /未来少年/
みらいじせい /未来時制/
みらいじん /未来人/
みらいせ /未来世;[仏教]/
みらいせい /未来性/
みらいせいき /未来世紀/
みらいせかい /未来世界/
みらいぞう /未来像/
みらいてき /未来的/
みらいとし /未来都市/
みらいにほん /未来日本/
みらいは /未来派/
みらいへん /未来編/
みらいよそうず /未来予想図/
みらいよそく /未来予測/
みらいよち /未来予知/
みらさか /三良坂/
みらの /未蘭/
みり /粍/milli;[SI接頭語]m,10^-3/
みりおんしゅっぱん /ミリオン出版;[出版社名]/
みりぐらむ /瓱/
みりは /ミリ波/
みりびょう /ミリ秒/
みりめーとる /粍/
みりょう /魅了/未了/
みりょく /魅力/
みりょくてき /魅力的/
みりりっとる /竓/
みりん /味醂/未林/
みりんあじ /味醂味/
みりんかい /未臨界/
みりんかいど /未臨界度/
みりんぼし /味醂干し/味醂干/
みる /覩/海松/
みるからに /見るからに/
みるがい /海松貝/
みるくあじ /ミルク味/
みるくがゆ /ミルク粥/
みるくに /ミルク煮/
みるみる /見る見る/
みるめ /見る目/
みれい /美麗/
みれん /未練/
みれんらく /未連絡/
みろく /弥勒/彌勒/
みろくぼさつ /弥勒菩薩/
みわ /美和/三輪/三和/神酒/巳波/
みわく /魅惑/
みわくてき /魅惑的/
みわけ /見分け/見分/
みわこ /美和子/
みわざ /御業/
みわすれ /見忘れ/
みわた /三輪田/
みわだ /三輪田/
みわだがくえん /三輪田学園/
みわやま /三輪山/
みん /民/眠/明/閔;(呉音)/罠;(呉音)/
みんい /民意/
みんえい /民営/
みんえいか /民営化/
みんえいかご /民営化後/
みんおく /民屋/
みんおん /民音/
みんか /民家/
みんかつ /民活/
みんかへい /民家塀/
みんかん /民間/明槓/
みんかんかくりょう /民間閣僚/
みんかんかつりょく /民間活力/
みんかんがいこう /民間外交;private diplomacy/
みんかんがいしゃ /民間会社/
みんかんき /民間機/
みんかんきぎょう /民間企業/
みんかんこうじょう /民間工場/
みんかんごげん /民間語源;[言語]folk etymology/
みんかんしせつ /民間施設/
みんかんしゅどう /民間主導/
みんかんしんこう /民間信仰/
みんかんじん /民間人/
みんかんだんたい /民間団体/
みんかんちりょう /民間治療/
みんかんでんしょう /民間伝承/
みんかんびょういん /民間病院/
みんかんぶもん /民間部門/
みんかんほうそう /民間放送/
みんかんやく /民間薬/
みんかんりょうほう /民間療法/
みんぎょう /民業/
みんぐ /民具/
みんけん /民権/
みんげい /民芸/
みんげいひん /民芸品/
みんこー /明刻/
みんこう /民航/
みんこく /民国/民國/
みんざい /眠剤/
みんし /明史;二十四史/
みんしゃ /民社/
みんしゃとう /民社党/
みんしゅ /民主/
みんしゅう /民衆/
みんしゅうそしょう /民衆訴訟;[法]popular action/
みんしゅうてき /民衆的/
みんしゅか /民主化/
みんしゅかせいさく /民主化政策/
みんしゅかようきゅう /民主化要求/
みんしゅく /民宿/
みんしゅこく /民主国/
みんしゅこっか /民主国家/
みんしゅしゃかいしゅぎ /民主社会主義;democratic socialism/
みんしゅしゃかいとう /民主社会党/
みんしゅしゅぎ /民主主義/
みんしゅしゅぎかん /民主主義観/
みんしゅしゅぎけんぽう /民主主義憲法/
みんしゅしゅぎこく /民主主義国/
みんしゅしゅぎこっか /民主主義国家/
みんしゅしゅぎしゃ /民主主義者/
みんしゅしゅぎしゃかい /民主主義社会/
みんしゅしゅぎてき /民主主義的/
みんしゅせい /民主制;民主主義 = 民主制 = 民主政君主制と貴族制と民主制間接民主制と直接民主制/民主政/民主性/
みんしゅせいじ /民主政治/
みんしゅせいど /民主制度/
みんしゅてき /民主的/
みんしゅてきほうほう /民主的方法/
みんしゅとう /民主党/
みんしん /民心/
みんじ /民事/
みんじかいにゅう /民事介入/
みんじかいにゅうぼうりょく /民事介入暴力/
みんじさいせい /民事再生/
みんじさいせいほう /民事再生法/
みんじさいばん /民事裁判/
みんじしっこう /民事執行/
みんじしっこうほう /民事執行法/
みんじせきにん /民事責任/
みんじそしょう /民事訴訟/
みんじそしょうほう /民事訴訟法/
みんじちょうてい /民事調停/
みんじちょうていほう /民事調停法/
みんじてき /民事的/
みんじばいしょう /民事賠償/
みんじふかいにゅう /民事不介入/
みんじほぜんほう /民事保全法/
みんじゅ /民需/
みんじょう /民情/
みんせい /民生/民政/民青/民声/
みんせいいいん /民生委員/
みんせいき /民生機/
みんせいしじょう /民生市場/
みんせいとう /民政党;[日本史]立憲民政党/
みんせいどうめい /民青同盟/
みんせいひ /民生費/
みんせいひん /民生品/
みんせいぶ /民生部/
みんせいよう /民生用/
みんせいようきき /民生用機器/
みんせん /民選/
みんせんぎいんせつりつけんぱくしょ /民撰議院設立建白書/
みんそ /民訴/
みんそほう /民訴法/
みんぞく /民族;†race,nation.「北方-」/民俗;†folk.「-学」/
みんぞくいしき /民族意識/
みんぞくいしょう /民族衣装/
みんぞくいどう /民族移動/
みんぞくおんがく /民族音楽/
みんぞくかん /民族間/
みんぞくがく /民俗学;folklore/民族学;ethnology/
みんぞくがっき /民族楽器/
みんぞくがみ /民族神/
みんぞくきょういく /民族教育/
みんぞくけい /民族系/
みんぞくげいのう /民俗芸能/
みんぞくこうげい /民俗工芸/
みんぞくこっか /民族国家/
みんぞくご /民族語/
みんぞくし /民族誌/
みんぞくしゅうきょう /民族宗教/
みんぞくしゅぎ /民族主義/
みんぞくじけつ /民族自決/
みんぞくじけつけん /民族自決権/
みんぞくじょうか /民族浄化/
みんぞくせい /民族性/
みんぞくせいしん /民族精神;cf.時代精神/
みんぞくぜんたい /民族全体/
みんぞくだいいどう /民族大移動/
みんぞくちょう /民族調/
みんぞくてき /民族的/
みんぞくふく /民族服;サリーや紋付袴など/
みんぞくむら /民族村/
みんぞくめい /民族名/
みんぞくりょうり /民族料理;ethnic/
みんたろう /民太郎/
みんたんしゅう /民譚集/
みんだ /民田/
みんちょう /明朝/
みんちょうたい /明朝体/
みんちょうたいかつじ /明朝体活字/
みんていけんぽう /民定憲法;⇔欽定憲法/
みんてつ /民鉄/
みんてつかくしゃ /民鉄各社/
みんてつせん /民鉄線/
みんとう /民党;⇔吏党/
みんど /民度/
みんな /皆/皆な/
みんはく /民博/
みんぱく /民泊/民博/
みんぶ /民部/
みんぶしょう /民部省;[律令制]三省/
みんぶんか /明文化/
みんぷう /民風/
みんぺい /民兵/民平/
みんぺいそしき /民兵組織/
みんぼう /民望/
みんぽう /民法;†civil code/民放;†民間放送局/
みんぽうかいせい /民法改正/
みんぽうかくきょく /民放各局/
みんぽうかっきょく /民放各局/
みんぽうじょう /民法上/
みんぽうだい /民法第/
みんぽうてん /民法典/
みんぽんしゅぎ /民本主義/
みんまや /三厩/
みんみんぜみ /みんみん蝉/
みんめいしょぼう /民明書房/
みんゆう /民有/
みんゆうりん /民有林/
みんよう /民謡/
みんようおんかい /民謡音階;レファソラドレ/
みんようしゅう /民謡集/
みんようふう /民謡風/
みんりょく /民力/
みんわ /民話/
みんわげき /民話劇/
みんわしゅう /民話集/
む /無/夢/六/矛;矛盾/務;義務/霧;(きり)濃霧/武;(呉音)武者/鵡;鸚鵡/謀;(呉音)謀叛/牟;釈迦牟尼/无;≒無/毋;なかれ/梦;「夢」の異体字/
む> /無/
むーあじん /ムーア人;Moor/
むーたいりく /ムー大陸;Mu/
むーみん /夢民/
むーるがい /ムール貝;moule. 紫貽貝/
むあい /無愛/
むあっしゅく /無圧縮/
むあつしき /無圧式/
むあんだ /無安打/
むい /無為/無意/無位/六/
むいか /六日/６日/6日/
むいかいち /六日市/
むいかまち /六日町/
むいしき /無意識/
むいしきか /無意識下/
むいしきてき /無意識的/
むいしぜん /無為自然/
むいせ /無畏施;[仏教]/
むいそん /無医村/
むいちぶつ /無一物/
むいちもん /無一文/
むいとしょく /無為徒食/
むいはん /無違反/
むいみ /無意味/
むいみご /無意味語/
むいむさく /無為無策/
むいん /無韻/
むいんし /無韻詩;[文学]⇔押韻詩/
むうげ /無憂華/
むえき /無益/
むえん /無縁/無鉛/無塩/無援/無煙/
むえんか /無煙化/
むえんたん /無煙炭/
むえんばたー /無塩バター;unsolted butter/
むえんぼち /無縁墓地/
むえんぼとけ /無縁仏/
むおう /夢奥/
むおうとう /無応答/
むおん /無音/
むおんくかん /無音区間/
むおんせい /無音声/
むか /無化/
むかい /向井/向かい/迎/向/
むかいかぜ /向かい風/向い風/
むかいがおか /向ケ丘/
むかいがわ /向かい側/向い側/向川/
むかいがわら /向河原/
むかいさつ /無改札/
むかいしま /向島/
むかいぞう /無改造/
むかいたに /向谷/
むかいとう /無回答/
むかいなだ /向洋/
むかいの /向野/
むかいはら /向原/
むかいへん /無改変/
むかいや /向谷/
むかいやま /向山/
むかえ /迎え/迎/
むかえかく /迎え角/
むかえこう /迎え講/
むかえざけ /迎え酒;二日酔いを直すために飲む酒/
むかえび /迎え火/
むかか /無花果/
むかきゅう /無過給/
むかこう /無加工/
むかご /零余子/
むかし /昔/
むかしかたぎ /昔気質;old-fashioned/
むかしがたり /昔語り;雪降る夜の-/
むかしごころ /昔心/
むかしざま /昔様/
むかしつ /無過失/
むかしつせきにん /無過失責任/
むかしづくり /昔作り/
むかしとんぼ /昔蜻蛉/
むかしながら /昔ながら/
むかしにほん /昔日本/
むかしばなし /昔話/
むかしふう /昔風/
むかしむかし /昔々/昔昔/
むかしものがたり /昔物語/
むかじゅう /無果汁/無荷重/
むかち /無価値/
むかっぱら /向かっ腹/むかっ腹/
むかで /百足/蜈蚣/
むかでのり /百足海苔/
むかばら /向か腹/
むかひ /無花被/
むかべん /無花弁/
むかべんるい /無花弁類/Apetalae/
むかゆうきょう /無何有郷/
むかわ /鵡川/武川/
むかん /無冠/無感/無官/
むかんかく /無感覚/
むかんがえ /無考え/
むかんけい /無関係/
むかんさ /無鑑査/
むかんしょう /無干渉/
むかんしん /無関心/
むかんじょう /無感情/
むかんどう /無感動/
むが /無我/
むがあい /無我愛/
むがい /無害/無蓋/
むがいかしゃ /無蓋貨車/
むがく /無学/
むがくしゃ /無学者/
むがくめんかぶ /無額面株/
むがくもんもう /無学文盲/
むがむちゅう /無我夢中/
むがるていこく /ムガル帝国;インド。1526-1858/
むき /無機;inorganic/無期;-懲役/向き/無記;[仏教]no reply/無気;nonaspirated/無季;季語のない/
むき> /無機;[化学]-化合物,-窒素,-栄養/
むきえ /向江/
むきえん /無機塩/
むきえんき /無期延期/
むきおく /無記憶/
むきおん /無気音/
むきかがく /無機化学/
むきかごうぶつ /無機化合物/
むきかた /剥き方/
むききんこ /無期禁錮/
むきけい /無機系/無期刑;⇔有期刑/
むきげん /無期限/
むきげんゆうこう /無期限有効/
むきさん /無機酸;inorganic acid/
むきざいりょう /無機材料/
むきしつ /無機質/
むきしつてき /無機質的/
むきじょうでんしゃ /無軌条電車/
むきず /無傷/無疵;≒無傷/
むきせい /無機性/
むきだし /剥き出し;敵愾心を-にする/
むきちょうえき /無期懲役/
むきてき /無機的/
むきどう /無軌道/
むきにゅう /無記入/
むきはい /無気肺/
むきひりょう /無機肥料/
むきふむき /向き不向き/
むきぶつ /無機物/
むきみ /剥き身;-のエビ/
むきむき /向き向き/
むきめい /無記名/
むきめいうらがき /無記名裏書/
むきめいかぶけん /無記名株券/
むきめいさいけん /無記名債権/
むきめいしき /無記名式/
むきめいとうひょう /無記名投票/
むきゅう /無休;年中-/無給;unpaid.⇔有給/無窮;limitless.「天壌-」/無級;out of rank/
むきゅうどう /無窮動/
むきゅうゆ /無給油/
むきょう /無響;anechoic.「-室」/夢境/無興;=不興/
むきょういく /無教育/
むきょうしつ /無響室/
むきょうよう /無教養/
むきょか /無許可/
むきょく /無極/
むきょくせい /無極性/
むきょくせいぶんし /無極性分子/
むきょだく /無許諾/
むきりつ /無規律/
むきりょく /無気力/
むきん /無菌/
むきんしつ /無菌室/
むきんせいずいまくえん /無菌性髄膜炎/
むぎ /麦/牟岐;地名,徳島/麥;「麦」の旧字/
むぎあき /麦秋;初夏/
むぎいい /麦飯;-で鯉を釣る/
むぎくさとうげ /麦草峠/
むぎこ /麦粉/
むぎこう /無技巧;巧まぬ/
むぎこがし /麦焦がし/
むぎさく /麦作/
むぎじょうちゅう /麦焼酎/
むぎたに /麦谷/麥谷;「麦」旧字/
むぎちゃ /麦茶/
むぎとろ /麦薯蕷/
むぎのあき /麦の秋/
むぎばたけ /麦畑/
むぎひと /麦人/
むぎぶえ /麦笛/
むぎめし /麦飯/
むぎや /麦谷/
むぎやぶし /麦や節;[民謡]五箇山/
むぎゆ /麦湯/
むぎょうしゃ /無業者/
むぎらくがん /麦落雁/
むぎわら /麦藁/麦わら/麦ワラ/
むぎわらぼう /麦藁帽/
むぎわらぼうし /麦藁帽子/麦わら帽子/麦稈帽子/
むく /無垢/椋/尨;尨犬/向/
むくい /報/報い/酬い/
むくいた /無垢板/
むくいぬ /尨犬/
むくげ /槿;[植物]/毳/木槿/葮;=槿/尨毛/
むくだ /椋田/
むくだい /椋代/
むくち /無口/
むくどり /椋鳥/
むくな /椋名/
むくのき /椋木/
むくみ /浮腫/
むくろ /骸/躯/
むくろじもく /ムクロジ目/Sapindales/
むぐら /葎;雑草/
むけ /向/無卦/
むけい /無形/無茎/
むけいかく /無計画/
むけいこていしさん /無形固定資産/
むけいぶつ /無形物/
むけいぶんかざい /無形文化財;人間国宝/
むけっきん /無欠勤/
むけってい /無決定/
むけつ /無欠/無血/
むけつかくめい /無血革命/
むけん /無間/無券/
むけんしき /無見識/
むけんじごく /無間地獄/
むけんだいり /無権代理/
むげ /無碍;融通-/無下;-にする/無礙;=無碍/
むげい /無芸/
むげいたいしょく /無芸大食/
むげがわ /武芸川/
むげっけい /無月経/
むげん /無限/夢幻/無間;=むけん/無言;=むごん/無幻;‖(?)/∞;infinity/
むげん> /無限/
むげんあつ /無限厚/
むげんあつせんすい /無減圧潜水/
むげんえん /無限遠/
むげんえんてん /無限遠点/
むげんえんぽう /無限遠方/
むげんかい /無限回/
むげんかじょ /無限花序/
むげんきしゃく /無限希釈/
むげんきどう /無限軌道/
むげんきゅうすう /無限級数/
むげんぎ /無限木/
むげんけい /無限系/
むげんこ /無限個/
むげんこうり /無限公理/
むげんしゅうごう /無限集合/
むげんしょう /無限小/
むげんしょうすう /無限小数/
むげんしんし /夢幻紳士/
むげんじげん /無限次元/
むげんじごく /無間地獄/
むげんすうれつ /無限数列/
むげんせい /無限性/
むげんせきにん /無限責任/
むげんせきにんしゃいん /無限責任社員/
むげんそく /無原則/
むげんぞうしょく /無限増殖/
むげんぞうばいりつ /k$_{inf}$/無限増倍率/
むげんだい /無限大/∞/
むげんちょう /無限長/
むげんてい /無限定/
むげんてき /夢幻的/
むげんとうひきゅうすう /無限等比級数/
むげんどう /無間道/
むげんならく /無間奈落/
むげんほうよう /夢幻泡影/
むげんるーぷ /無限ループ/
むげんれつ /無限列/
むげんれんさ /無限連鎖/
むげんれんさこう /無限連鎖講/
むこ /婿/無辜/聟/壻/
むこいり /婿入り/
むこいりこん /婿入り婚/
むこう /無効/無香/向日;地名/無孔/無向/無功/向こう/向う/
むこういた /向板;お造り担当の板前/
むこういん /無効印/
むこうか /無効化/
むこうかん /無交換/
むこうがい /無公害/
むこうがおか /向ヶ丘/向ケ丘/
むこうがおかゆうえん /向ヶ丘遊園/
むこうがわ /向こう側/
むこうきず /向こう傷/向こう疵/
むこうぎし /向こう岸/
むこうぎり /向切;[茶道]/
むこうぐらふ /無向グラフ/
むこうさんげん /向こう三軒/
むこうさんげんりょうどなり /向こう三軒両隣;最重要戦略御近所圏/
むこうじあい /無効試合/
むこうじま /向島/
むこうじまえき /向島駅/
むこうじょうめん /向正面/
むこうずね /向こう脛/向う脛/
むこうせい /無香性;scent-free/無効性;invalidity/
むこうちょう /向日町/
むこうづけ /向こう付け;[懐石料理]/
むこうでんりょく /無効電力/
むこうとうひょう /無効投票/
むこうひょう /無効票/
むこうまち /向日町/
むこうみず /向こう見ず/
むこうりょう /無香料/
むこがわ /武庫川/婿側/
むこがわえき /武庫川駅/
むこがわせん /武庫川線/
むこがわだんち /武庫川団地/
むこきゅう /無呼吸/
むこく /無告/
むこくいん /無刻印/
むこくせき /無国籍/
むこくせきじょうたい /無国籍状態/
むこくせきてき /無国籍的/
むこくせきりょうり /無国籍料理/
むこさん /婿さん/
むこしょう /無故障/
むこせい /無個性/
むこたとうるい /ムコ多糖類/
むことり /婿取り/
むこのそう /武庫之荘/
むこようし /婿養子/
むこようしえんぐみ /婿養子縁組/
むこん /無根/
むこんきょ /無根拠/
むご /惨/
むごん /無言/
むごんか /無言歌/
むごんげき /無言劇/
むごんでんわ /無言電話/
むごんのぎょう /無言の行/
むさい /無才;mediocre/無妻;single/無菜/
むさいげん /無際限/
むさいしょく /無彩色/
むさく /無策/
むさくい /無作為/
むさくいちゅうしゅつ /無作為抽出/
むさし /武蔵/
むさしいつかいち /武蔵五日市/
むさしうらわ /武蔵浦和/
むさしこうぎょうだいがく /武蔵工業大学/
むさしこうだい /武蔵工大/武蔵工業大学;※abbrev/
むさしこがねい /武蔵小金井/
むさしこすぎ /武蔵小杉/
むさしこやま /武蔵小山/
むさしさかい /武蔵境/
むさししんじょう /武蔵新城/
むさしせき /武蔵関/
むさしだい /武蔵台/武蔵大/
むさしだいがく /武蔵大学/
むさしとみよ /武蔵富魚/
むさしなかはら /武蔵中原/
むさしなかはらえき /武蔵中原駅/
むさしの /武蔵野/
むさしのおんがくだいがく /武蔵野音楽大学/
むさしのおんだい /武蔵野音大/
むさしのかん /武蔵野館/
むさしのぎんこう /武蔵野銀行/
むさしのこうこう /武蔵野高校/
むさしのし /武蔵野市/
むさしのじょしがくいん /武蔵野女子学院/
むさしのせん /武蔵野線/
むさしのてつどう /武蔵野鉄道/
むさしぼうべんけい /武蔵坊弁慶/
むさしまる /武蔵丸/
むさしむらやま /武蔵村山/
むさつ /無札/
むさべつ /無差別/
むさべつきゅう /無差別級/
むさべつこうげき /無差別攻撃/
むさべつさつじん /無差別殺人/
むさべつてき /無差別的/
むさべつばくげき /無差別爆撃/
むさん /霧散/無産/無算/
むさんかいきゅう /無産階級/
むさんしゃ /無産者/
むさんせいとう /無産政党/
むさんそ /無酸素;-運動/
むさんそうんどう /無酸素運動/
むさんそじょうたい /無酸素状態/
むざい /無罪/
むざいはんけつ /無罪判決/
むざいほうめん /無罪放免/
むざつ /無雑/
むざん /無惨/無残;≒無惨/無慙;(原義:戒律を破り恥じない) ≒無惨/無慚;=無慙/
むし /虫/無視/蒸し/蟲/無死/無私/夢死;虚しく一生を終える。「酔生-」/無始/毟;「毟る」語幹？/
むしあき /虫明/
むしおくり /虫送り/
むしかえし /蒸し返し/
むしかく /無資格/
むしかくしゃ /無資格者/
むしかご /虫籠/虫かご/
むしがし /蒸し菓子/蒸菓子/
むしがた /虫型/
むしき /蒸し器/無識/無支奇;中国の神様/
むしきかい /無色界/
むしきゅうかんぷう /無四球完封/
むしくい /虫食い/虫喰い/
むしくいざん /虫食い算/
むしくだし /虫下し/
むしぐすり /虫薬/
むしけ /虫気/
むしけら /虫螻/虫けら/
むしけん /無試験/
むしこうせい /無指向性/
むしごめ /蒸し米/
むしさされ /虫刺され;痒い/
むししぐれ /虫時雨/
むししゃ /無視者/
むしず /虫酸/虫唾/
むしたおる /蒸しタオル/
むしってん /無失点/
むしつかい /蟲使い/
むしつりょう /無質量/
むしてい /無指定/
むしていじ /無指定時/
むしとり /虫取り/
むしに /蒸し煮/蒸煮/
むしのいき /虫の息/
むしば /虫歯/
むしばら /虫腹/
むしぱん /蒸しパン/
むしぴん /虫ピン/
むしふうじ /虫封じ/
むしぶろ /蒸し風呂/
むしぶんれつ /無糸分裂;[生物]amitosis/
むしへん /虫偏/
むしぼし /虫干し/
むしまんるい /無死満塁/
むしむし /蒸し蒸し/
むしむしゅう /無始無終/
むしむへん /無私無偏/
むしめがね /虫めがね/虫眼鏡/虫メガネ/
むしもの /蒸し物/
むしゃ /武者/
むしゃく /無錫/
むしゃけん /無車検/
むしゃしゅぎょう /武者修行/武者修業/
むしゃのこうじ /武者小路/
むしゃのこうじさねあつ /武者小路実篤/
むしゃのこうじせんけ /武者小路千家/
むしゃぶり /武者振り/
むしゃぶるい /武者震い/
むしやき /蒸し焼き/
むしゅ /無主/
むしゅう /無臭/
むしゅうきょう /無宗教/
むしゅうさ /無収差/
むしゅうせい /無修正/
むしゅうにゅう /無収入/
むしゅうはいきょく /無集配局/
むしゅく /無宿/
むしゅくもの /無宿者/
むしゅぶつ /無主物/
むしゅみ /無趣味/
むしょう /無償/無性/霧消/
むしょうえんじょ /無償援助/
むしょうこうい /無償行為/
むしょうこうかい /無償公開/
むしょうこうかん /無償交換/
むしょうこうふ /無償交付/
むしょうしゅうり /無償修理/
むしょうたいよ /無償貸与/
むしょうていきょう /無償提供/
むしょうはいふ /無償配布/
むしょうほしょうきかん /無償保証期間/
むしょうろうどう /無償労働/
むしょく /無職/無色/夢色/
むしょくしゃ /無職者/
むしょくとうめい /無色透明/
むしょぞく /無所属/
むしょぞくぎいん /無所属議員/
むしょり /無処理/
むしよけ /虫除け/
むしりざかな /毟り魚/
むしりょ /無思慮/
むしりょく /無資力/
むしろ /寧ろ/筵/莚/蓆/席/
むしん /無心/
むしんけい /無神経/
むしんこう /無信仰/
むしんこく /無申告/
むしんたい /無心体/
むしんろん /無神論/
むしんろんしゃ /無神論者/
むじ /無地/無事;?/
むじかく /無自覚/
むじかくてき /無自覚的/
むじげん /無次元/
むじげんすう /無次元数/
むじげんりょう /無次元量/
むじこ /無事故/
むじこむいはん /無事故無違反/
むじつ /無実/
むじな /狢/貉;=狢/豸;(むじなへん)/
むじなへん /豸偏/
むじひ /無慈悲/
むじまく /無字幕/
むじゃき /無邪気/
むじゅう /無住/
むじゅうりょう /無重量/
むじゅうりょうじょうたい /無重量状態/
むじゅうりょく /無重力/
むじゅうりょくじょうたい /無重力状態/
むじゅうりょくたいけん /無重力体験/
むじゅん /矛盾/⊥/
むじゅんじょうほう /矛盾情報/
むじゅんせい /矛盾性/
むじゅんてん /矛盾点/
むじゅんどうちゃく /矛盾撞着/
むじゅんめいだい /矛盾命題/
むじゅんりつ /矛盾律;A∧¬A=0/
むじょう /無情;†heartless.「冷酷-」/無常;†vanity.「-感」/無上;†greatest.「-の喜び」/
むじょうかん /無常観/
むじょうけん /無条件/
むじょうけんこうふく /無条件降伏/
むじょうけんぶんき /無条件分岐/
むじょうじんそく /無常迅速/
むじょそうざい /無除草剤/
むじるし /無印/
むじるしりょうひん /無印良品/
むじん /無人/無尽/無塵/
むじん> /無人;-改札,-衛星,-営業/
むじんえいぎょう /無人営業/
むじんえき /無人駅/
むじんか /無人化/
むじんかいさつ /無人改札/
むじんき /無人機/
むじんしつ /無塵室;clean room/
むじんせん /無人船/
むじんぞう /無尽蔵/
むじんとう /無人島/
むすい /無水/
むすいありゅうさん /無水亜硫酸/
むすいちょうり /無水調理/
むすいなべ /無水鍋/
むすう /無数/
むすこ /息子/
むすこたち /息子達/
むすひ /産霊;-の神/
むすび /結び/
むすびかた /結び方/
むすびさより /結び針魚/
むすびつき /結び付き/
むすびとじ /結び綴じ/
むすびめ /結び目/
むすぼれ /結ぼれ/
むすめ /娘/
むすめご /娘子/娘御/
むすめざかり /娘盛り/
むすめじだい /娘時代/
むすめたち /娘達/
むすめっこ /娘っ子/
むすめどうじょうじ /娘道成寺/
むすめばら /娘腹/
むすめむこ /娘婿/
むすめやく /娘役/
むずかしさ /難しさ/
むせい /無声/夢精/無性/
むせいえいが /無声映画/
むせいおん /無声音/
むせいか /無声化/
むせいげん /無制限/
むせいしいん /無声子音/
むせいしおん /無声子音/
むせいししょう /無精子症/
むせいせいしょく /無性生殖/
むせいせだい /無性世代/
むせいてき /無性的/
むせいふ /無政府/
むせいふしゅぎ /無政府主義/
むせいふしゅぎしゃ /無政府主義者/
むせいふしゅぎてき /無政府主義的/
むせいふじょうたい /無政府状態/
むせいぶつ /無生物/
むせいらん /無精卵/
むせき /無籍/
むせきてき /無責的/
むせきにん /無責任/
むせきにんおとこ /無責任男/
むせきにんやろう /無責任野郎/
むせっしょく /無接触/
むせっそう /無節操/
むせってい /無設定/
むせってん /無接点/
むせつ /無節/
むせびなき /咽び泣き;sob/噎び泣き;sob/
むせん /無線/無銭/
むせんいがい /無線以外/
むせんいんしょく /無銭飲食/
むせんうんよう /無線運用/
むせんか /無線家/
むせんかい /無線界/
むせんかんけい /無線関係/
むせんき /無線機/
むせんきき /無線機器/
むせんきや /無線機屋/
むせんきょく /無線局/
むせんぎし /無線技士/無線技師/
むせんぎじゅつ /無線技術/
むせんぎょうむにっし /無線業務日誌/
むせんけん /無線研/
むせんこうがく /無線工学/
むせんざっし /無線雑誌/
むせんしかく /無線資格/
むせんしき /無線式/
むせんしゅうはすう /無線周波数/
むせんしんこうきょうかい /無線振興協会/
むせんじゅうじしゃ /無線従事者/
むせんせつび /無線設備/
むせんたぐ /無線タグ/
むせんだんたい /無線団体/
むせんつうしん /無線通信/
むせんつうしんぎじゅつ /無線通信技術/
むせんつうしんし /無線通信士;第[一二三四]級(総合|海上)-/
むせんでんしん /無線電信/
むせんでんぱ /無線電波/
むせんでんわ /無線電話/
むせんでんわつうしん /無線電話通信/
むせんとじ /無線綴じ/
むせんまい /無洗米/
むせんめんきょ /無線免許/
むせんや /無線屋/
むせんゆうどう /無線誘導/
むせんよう /無線用/
むせんようご /無線用語/
むせんらん /無線LAN/
むせんりょこう /無銭旅行/
むせんるーた /無線ルータ/
むぜい /無税/無勢;多勢に-/
むぜいひん /無税品/
むぜんてい /無前提/
むそう /無双/夢想/無想/
むそうか /夢想家/
むそうかん /無相関/
むそうきょく /夢想曲;Traumerei(独)/
むそうてき /夢想的/
むそうむねん /無想無念;雑念のないこと/無相無念;(仏には)形も心もないこと/
むそうやま /武双山/
むそじ /六十路/六十/
むそんしつ /無損失/
むぞうさ /無造作/無雑作;=無造作/
むた /牟田/無佗/
むたい /無体/
むたいざいさん /無体財産/
むたいざいさんけん /無体財産権/
むたいざいさんけんほう /無体財産権法/
むたいぶつ /無体物/
むたぐち /牟田口/
むたまがわ /武玉川;(1750-76) 雑俳集/
むたんぽ /無担保/
むたんぽうらがき /無担保裏書/
むだ /無駄/徒/
むだあし /無駄足/
むだい /無題/無代/
むだがね /無駄金/
むだぐち /無駄口;-を叩くな/
むだげ /ムダ毛/無駄毛/徒毛/
むだじかん /無駄時間/
むだじに /無駄死に/
むだづかい /無駄遣い/無駄使い/徒遣い/
むだなく /無駄無く/
むだにく /無駄肉/
むだばな /徒花/
むだばなし /無駄話/
むだぼね /無駄骨/
むだめし /無駄飯/徒飯/
むだめしぐい /無駄飯食い/
むだん /無断/
むだんいんよう /無断引用/
むだんかい /無段階/
むだんかいちょうせい /無段階調整/
むだんかいへんそく /無段階変速/
むだんがいしゅつ /無断外出/
むだんけっきん /無断欠勤/
むだんけっせき /無断欠席/
むだんしゃくよう /無断借用/
むだんしよう /無断使用/
むだんちゅうしゃ /無断駐車/
むだんてんさい /無断転載/
むだんはいしゃく /無断拝借/
むだんふくせい /無断複製/
むだんへんそく /無段変速/
むだんへんそくき /無段変速機/
むち /無知/鞭;(革製のムチ)/無恥;shameless.「厚顔-」/笞;(竹製のムチ)/無智/
むちうち /鞭打ち/鞭打/
むちうちしょう /鞭打ち症/
むちく /無畜/
むちこく /無遅刻/
むちつじょ /無秩序/
むちつじょか /無秩序化/
むちつじょじょうたい /無秩序状態/
むちつじょせい /無秩序性/
むちもうまい /無知蒙昧/
むちゃ /無茶/
むちゃくしょく /無着色/
むちゃくちゃ /無茶苦茶/
むちゃくりく /無着陸/
むちゅう /夢中;†absorbed.「無我-」/霧中;†in a fog.「五里-」/
むちゅうせん /無抽選/
むちょう /無調;atonal.「-音楽」/無徴;unmarked/
むちょうおんがく /無調音楽;atonal music/
むちょうせい /無調整/
むちん /無賃/
むちんじょうしゃ /無賃乗車/
むっつ /六つ/
むつ /睦/陸奥/六つ/六/
むつあい /六会/
むつあき /睦明/
むつう /無痛/
むつうしん /無通信/
むつうせい /無痛性/
むつうぶんべん /無痛分娩/
むつうら /六浦/
むつお /睦夫/
むつき /睦月;陰暦1月/襁褓;[文語]おむつ/睦紀;人名/
むつこ /睦子/
むつごと /睦言/
むつざわ /睦沢/
むつしげ /睦茂/
むつのり /睦典/
むつひろ /睦裕/
むつび /睦び/
むつみ /睦/睦美/六実/睦都美/睦つ美/
むつものがたり /睦物語/
むつゆき /睦之/
むつよ /睦予/
むつらぼし /六連星;Pleiads/
むつれじま /六連島/
むつわり /六つ割り/
むつわん /陸奥湾/
むて /無手/
むていぎ /無定義/
むていぎようご /無定義用語/
むていけい /無定形/無定型/
むていけいいおう /無定形硫黄/
むていけいけいそ /無定形珪素/
むていけいたんそ /無定形炭素/
むていけいぶっしつ /無定形物質/
むていけん /無定見/
むていこう /無抵抗/
むていし /無停止/
むていしゃ /無停車/
むていでん /無停電/
むていでんでんげん /無停電電源/
むていりょう /無定量/
むてかつりゅう /無手勝流/
むてき /無敵/霧笛/
むてきかんたい /無敵艦隊;[世界史]スペインの艦隊。アルマダ海戦で潰滅/
むてきがったい /無敵合体/
むてきしょうぐん /無敵将軍/
むてじゅん /無手順/
むてっぽう /無鉄砲/
むてんか /無添加/
むてんとう /無転倒/
むてんぼん /無点本/
むてんぽ /無店舗/
むてんぽがた /無店舗型/
むでん /無電/
むとう /武藤;人名/無糖/無頭/無答/
むとうか /無灯火/無燈火/
むとうせい /無統制/
むとうせき /無答責/
むとうちゃ /無糖茶;清涼飲料水の一分野/
むとうは /無党派/
むとうはそう /無党派層/
むとうひょう /無投票/
むとうひょうとうせん /無投票当選/
むとうりゅう /無刀流/
むとうろく /無登録/
むとく /無徳/
むとくてん /無得点/
むとそう /無塗装/
むとどけ /無届け/無届/
むとんちゃく /無頓着/
むどう /無道/無動/武堂/
むどきじだい /無土器時代/
むどく /無毒/
むどくか /無毒化/
むな /胸/棟/宗/
むなあて /胸当て/
むないた /胸板/
むないよう /無内容/
むなかた /宗像;地名/棟方/宗方/宗形/
むなかたしこう /棟方志功;(1903-75)「板」画家/
むながい /胸懸/鞅/
むながわら /棟瓦/
むなぎ /棟木/
むなくそ /胸糞/
むなぐら /胸倉/胸座/
むなげ /胸毛/
むなごと /虚言/空言/
むなさき /胸前/胸先/
むなさわぎ /胸騒ぎ/
むなざんよう /胸算用/
むなせ /皆瀬/
むなそこ /胸底/
むなだか /胸高/
むなち /胸乳/
むなつき /胸突き/
むなつきはっちょう /胸突き八丁/
むなひも /胸紐/
むなびれ /胸鰭/
むなぼね /胸骨/
むなもと /胸元/胸許/
むに /無二/
むにねん /無二念/
むにむさん /無二無三/
むにょう /無尿/
むにんか /無認可/
むにんかほいくしょ /無認可保育所/
むにんしょ /無任所/
むにんしょだいじん /無任所大臣/
むね /胸/棟/旨/宗/刀背/
むねあき /宗明/宗昭/
むねあげ /棟上げ/
むねあげしき /棟上式/
むねあて /胸当て/
むねいっぱい /胸一杯/
むねうち /刀背打ち/
むねお /宗男/宗雄/宗夫/
むねかざり /棟飾り/
むねかた /宗片/
むねがわら /棟瓦/
むねくそ /胸糞/
むねくに /宗国/
むねさんずん /胸三寸/
むねざわ /宗澤/
むねざんよう /胸算用/
むねしげ /宗重/
むねた /崇田/
むねたか /宗高/
むねたけ /宗武/
むねだ /宗田/
むねとし /宗俊/宗敏/
むねとも /宗朋/
むねにく /胸肉/ムネ肉/
むねのり /宗典/
むねはる /宗治/
むねひさ /宗久/
むねひも /胸紐/
むねひろ /宗裕/
むねふじ /宗藤/
むねべつせん /棟別銭/
むねぼね /胸骨/
むねぽけっと /胸ポケット/
むねまち /棟区/
むねまわり /胸回り;[服飾]/胸囲り/
むねもと /胸元/
むねやけ /胸焼け/胸やけ/
むねゆき /宗幸/
むねよし /宗良/宗吉/
むねわり /棟割/棟割り/
むねわりながや /棟割長屋/棟割り長屋/
むねん /無念/
むねんきん /無年金/
むねんきんしゃ /無年金者/
むねんむそう /無念無想/
むのう /無能/
むのうしゃ /無能者/
むのうしゃいん /無能社員/
むのうやく /無農薬/
むのうやくさいばい /無農薬栽培/
むのうやくやさい /無農薬野菜/
むのうりょく /無能力/
むのうりょくしゃ /無能力者/
むは /無派/
むはい /無敗/無配/
むはいとう /無配当/
むはいりょ /無配慮/
むはんしゃ /無反射/
むはんしゃたん /無反射端/
むはんせい /無反省/
むはんどうほう /無反動砲/
むはんのう /無反応/
むばいかい /無媒介/
むばつ /無罰/
むばつてき /無罰的/
むばんそう /無伴奏/
むばんち /無番地/
むひ /無比/
むひきすう /無引数/
むひつ /無筆/
むひはん /無批判/
むひょう /霧氷/無標/
むひょうじ /無表示/
むひょうじょう /無表情/
むひょうはく /無漂白/
むび /夢寐/
むびゅう /無謬/
むびゅうせい /無謬性/
むびょう /無病/
むびょうそくさい /無病息災/
むびよくき /無尾翼機/
むふう /無風/
むふか /無負荷/
むふかかいてんすう /無負荷回転数/
むふかじょうたい /無負荷状態/
むふかでんりゅう /無負荷電流/
むふんべつ /無分別/
むへん /無辺/
むへんか /無変化/
むへんかん /無変換/
むへんけい /無変形/
むへんこう /無変更/
むへんさい /無辺際/
むへんざい /無辺際/
むへんちょう /無変調/
むべ /宜/
むべんべつ /無弁別/
むほう /無法/
むほうしきしゅぎ /無方式主義/
むほうしゃ /無法者/
むほうしゅう /無報酬/
むほうじょうたい /無法状態/
むほうちたい /無法地帯/
むほうもの /無法者/
むほきゅう /無補給/
むほけん /無保険/
むほけんしゃ /無保険車/
むほしゅ /無保守/
むほしょう /無保証/
むほせい /無補正/
むほん /謀反/謀叛/
むほんにん /謀反人/
むぼう /無謀/無帽;bareheaded.「-、無背景の写真」/
むぼうび /無防備/
むぼうびじょうたい /無防備状態/
むぼうふざい /無防腐剤/
むま /夢魔/
むみ /無味/
むみかんそう /無味乾燥/
むみむしゅう /無味無臭/
むみょう /無明/
むみょうしょう /無名抄;鴨長明/
むみょうじょうや /無明長夜/
むみょうせかい /無明世界/
むみょうぢょうや /無明長夜/
むむじゅん /無矛盾/
むむじゅんせい /無矛盾性/
むめ /無目;[建築]溝のない. transom/梅/
むめい /無名;nameless. 「-の作家」/無銘;unsigned. 「-の刀」/
むめい> /無名/
むめいじだい /無名時代/
むめいじゅく /無名塾/
むめいすう /無名数/
むめいへんすう /無名変数/
むめんきょ /無免許/
むめんきょうんてん /無免許運転/
むめんきょしゃ /無免許者/
むもう /無毛/
むもうしょう /無毛症;[医]/
むもくてき /無目的/
むもん /無文/無紋/
むやく /無益/無役/
むやま /無山/
むやみ /無闇/
むやみやたら /無闇矢鱈/
むゆう /夢遊/無釉/
むゆうげ /無憂華/
むゆうびょう /夢遊病/
むゆか /六日;[古語]/
むよう /無用/
むようちょうぶつ /無用長物/
むようのちょうぶつ /無用の長物/
むようのよう /無用の用/
むよく /無欲/無慾;=無欲/
むよくてんたん /無欲恬淡/
むら /村/斑;塗り-/群/叢/邑/屯/邨/
むらい /村井/無頼/
むらいし /村石/
むらうち /村内/
むらお /村尾/村生/
むらおか /村岡/
むらおこし /村起こし/
むらかた /村方/
むらかみ /村上/
むらかみてんのう /村上天皇/
むらかみはるき /村上春樹/
むらかみりゅう /村上龍/
むらき /村木/
むらくし /村櫛/
むらくも /叢雲/
むらくものつるぎ /叢雲剣/
むらこし /村越/
むらさき /紫/村さ来;居酒屋の名前/
むらさきいがい /紫貽貝;ムール貝/
むらさきいも /紫芋;中が紫色のサツマイモ/
むらさきいろ /紫色/
むらさきうに /紫海胆/
むらさきうまごやし /紫馬肥;アルファルファ/
むらさききゃべつ /紫キャベツ/
むらさきしきぶ /紫式部/
むらさきすいしょう /紫水晶/
むらさきつゆくさ /紫露草/
むらさきの /紫野/
むらさきのうえ /紫の上;[源氏物語]/
むらさきのり /紫海苔/
むらさきもく /Biorraginales/ムラサキ目/
むらさめ /村雨/叢雨/
むらさわ /村澤/村沢/
むらざと /村里/
むらし /蒸らし/
むらしぐれ /村時雨/叢時雨/
むらした /村下/
むらしゃかい /村社会;閉鎖的(・日本的)な社会/ムラ社会/
むらじ /連/村地/
むらじゅう /村中/
むらすずめ /群雀/
むらせ /村瀬/
むらた /村田/邑田/
むらたきかい /村田機械/
むらたけ /群竹/
むらたじょし /村田女子/
むらたせいさくしょ /村田製作所;[企業名]/
むらたせいさくじょ /村田製作所;[企業名]/
むらたに /村谷/
むらち /村地/
むらなか /村中/
むらなく /ムラ無く/
むらにし /村西/
むらの /村野/
むらはずれ /村外れ/
むらはちぶ /村八分/
むらびと /村人/
むらびとたち /村人達/
むらまさ /村正/
むらまつ /村松/
むらまつり /村祭り/村祭/
むらむすめ /村娘/
むらむら /村々/
むらもと /村本/
むらやくにん /村役人/
むらやくば /村役場/
むらやま /村山/群山/
むらゆご /ムラユ語/
むらわき /村脇/
むり /無理/
むりおうじょう /無理往生/無理圧状;=無理往生/
むりおし /無理押し/
むりかい /無理解/
むりからぬ /無理からぬ/
むりさんだん /無理算段/
むりし /無利子/
むりしんじゅう /無理心中/
むりじい /無理強い/
むりすう /無理数/
むりすじ /無理筋/
むりぜめ /無理攻め/
むりそく /無利息/
むりなんだい /無理難題/
むりむたい /無理無体/
むりやり /無理矢理;(当て字)/無理やり/
むりょ /無慮/
むりょう /無料/無量/無聊;=ぶりょう/
むりょうか /無料化/
むりょうきゅうけいじょ /無料休憩所/
むりょうけん /無料券/
むりょうこうえん /無料公演/
むりょうこうかん /無料交換/
むりょうこうくうけん /無料航空券/
むりょうごしょうたい /無料御招待/
むりょうさーびす /無料サービス/
むりょうしじょうかい /無料試乗会/
むりょうしゅうり /無料修理/
むりょうしゅくはく /無料宿泊/
むりょうしんだん /無料診断/
むりょうしんりょう /無料診療/
むりょうじゅ /無量寿/
むりょうそうげい /無料送迎/
むりょうそうだん /無料相談/
むりょうたいけん /無料体験/
むりょうたいすう /無量大数;10^68/
むりょうだいすう /無量大数;10^68/
むりょうちゅうしゃ /無料駐車/
むりょうちゅうしゃじょう /無料駐車場/
むりょうでんわ /無料電話/
むりょうはいそう /無料配送/
むりょうはいふ /無料配布/
むりょうほうそう /無料放送/
むりょうむへん /無量無辺/
むりょうりよう /無料利用/
むりょく /無力/
むりょくかん /無力感/
むりょくしょう /無力症/
むるい /無類/
むれ /群/群れ/牟礼/蒸れ/羣/
むれい /牟礼/
むれすずめ /群雀;[植物]caragana/
むろ /室/牟婁/榁/無漏/
むろあじ /室鰺/
むろい /室井/
むろう /室生/
むろうさいせい /室生犀星/
むろうじ /室生寺;女人高野/
むろおか /室岡/
むろか /無濾過/
むろかわ /室川/
むろが /室賀/
むろた /室田/
むろたに /室谷/
むろつ /室津/
むろと /室戸/
むろとし /室戸市/
むろとたいふう /室戸台風/
むろとみさき /室戸岬/
むろどう /室堂/
むろどこ /室床;[茶道]/
むろね /室根/
むろはし /室橋/
むろふし /室伏/
むろまち /室町/
むろまちじだい /室町時代/
むろまちばくふ /室町幕府/
むろみ /室見/
むろや /室屋/室谷/室哉/
むろやま /室山/
むろらん /室蘭/
むろらんし /室蘭市/
むろん /無論/
め /目/芽/眼;(字義:眼窩の中の「め」)/女/雌/奴/瑪;瑪瑙/碼;yard/海藻/海布/睨;?/
め> /牝;牝牛,牝瓦,女狐/雌;雌蕊,雌株,雌蝶/女;女餓鬼,女軍(めいくさ),女踏歌(めとうか)/
めーとるげんき /メートル原器;standard metre/
めーとるは /メートル波;VHF/
めーとるほう /メートル法/
めーるつうち /メール通知/
めーるびん /メール便/
めあかし /目明かし/
めあかん /雌阿寒/
めあき /目明き/
めあて /目当て/貭/
めい /名/命/迷/姪/銘;brand.「刀の-」/明/鳴/盟/冥;冥府/暝;くら・い/瞑;瞑目/溟/榠/酩;酩酊/茗;茗荷/謎;なぞ/
めい> /名/明;(「明治」の略) 明24,大判明28/
めいあらし /明嵐/
めいあん /明暗/名案/冥暗;dark/
めいあんじゅんのう /明暗順応/
めいあんほう /明暗法/
めいい /名医/名彙/
めいうせん /名羽線/
めいうん /命運/
めいえん /名演/
めいえんぎ /名演技/
めいえんしゅう /名演集/
めいえんそう /名演奏/
めいえんそうか /名演奏家/
めいおう /明王;明君/冥王;Pluto/明応;年号(1492-1501)/
めいおうせい /冥王星/
めいおうせいきどう /冥王星軌道/
めいおうだい /冥王代;[地質年代]Hadean. 45-38億年前/
めいおん /鳴音/
めいか /銘菓;由緒ある名(銘)を持つ菓子/名家/名歌/名花;(美女)/名菓;名高い菓子/
めいかい /明快;†clear.「単純-」/明解;†明確な説明。「-○○入門」/冥界/
めいかく /明確/
めいかくか /明確化/
めいかん /名鑑/銘肝/
めいかんとく /名監督/
めいかんぶ /名幹部/
めいが /名画/螟蛾/
めいがく /明学/
めいがくだい /明学大/
めいがざ /名画座/
めいがら /銘柄/
めいがらごと /銘柄毎/
めいがらどり /銘柄鶏/
めいがらまい /銘柄米/
めいき /明記;ハッキリ書く/銘記;心に刻む/名機;優れた機械/名器;優れた器・道具/銘機;名の通った機械/銘器;名の通った器/
めいきゅう /迷宮/
めいきゅういり /迷宮入り/
めいきゅうかい /名球会;[野球]昭和生まれの200勝投手と2000本安打野手で構成する会/
めいきゅうぶっけん /迷宮物件/
めいきゅうものがたり /迷宮物語/
めいきょう /明鏡/
めいきょうしすい /明鏡止水/
めいきょく /名曲/名局;囲碁の-/
めいきょくしゅう /名曲集/
めいきょくだいぜんしゅう /名曲大全集/
めいきょくどう /名曲堂/
めいきん /鳴禽/
めいきんせん /名金線/
めいきんるい /鳴禽類;[生物]songbirds/
めいぎ /名義/名妓;優れた芸者さん/名技;great technique/
めいぎがし /名義貸し/
めいぎがり /名義借り/
めいぎじょう /名義上/
めいぎにん /名義人/
めいぎへんこう /名義変更/
めいぎょく /名玉/
めいぎん /名吟/
めいく /名句/
めいくおとし /メイク落とし/
めいくん /名君;優れた君主/明君;賢明な君主/明訓;立派なおしえ/
めいけ /名家/女池/
めいけい /明経;科挙の科目の一/
めいけいどう /茗渓堂/
めいけつ /名血/
めいけん /名犬/名剣/迷犬/
めいげかい /名外科医/
めいげき /名劇/
めいげつ /名月;中秋の-/明月;bright moon/
めいげついん /明月院/
めいげつき /明月記/
めいげん /名言;†sayings.「先人の-」/明言;†declare.「意志を-する」/迷言;†nonsense/鳴弦/瞑眩/
めいげんしゅう /名言集/
めいこ /茗子/
めいこう /名工/名港/名香/
めいこうだい /名工大/
めいご /姪御;-さん/明午/迷語/
めいごう /冥合/
めいさい /明細/迷彩/
めいさいしょ /明細書/
めいさいしょく /迷彩色/
めいさいとそう /迷彩塗装/
めいさいひょう /明細表/
めいさいふく /迷彩服/
めいさく /名作/迷作/
めいさくげきじょう /名作劇場/
めいさくしゅう /名作集/
めいさつ /名刹;高名な寺/明察/
めいさま /名様/
めいさん /名産/
めいさんち /名産地/
めいさんひん /名産品/
めいさんぼう /名参謀/
めいざん /名山/
めいし /名刺;†card/名詞;†[文法]noun/名士;†celebrity/明視/名氏;?/
めいしいれ /名刺入れ;card case/
めいしか /名詞化/
めいしかんり /名刺管理/
めいしき /明識/
めいしく /名詞句/
めいしけい /名詞形/
めいしこうかん /名刺交換/
めいしせつ /名詞節/
めいしてき /名詞的/
めいしばん /名刺判/
めいしゃ /名車/目医者/眼医者/鳴謝/
めいしゅ /名手;expert/銘酒;名の通った酒/名酒;良い酒/盟主;leader/明珠;優れた人物/名主;名君主/明主;賢明な君主/
めいしゅう /迷執/
めいしょ /名所/名処/
めいしょう /名称/名勝/名匠/名将/明証/名相/鳴鐘/
めいしょうあん /名称案/
めいしょうけってい /名称決定/
めいしょうこうほ /名称候補/
めいしょうせん /名松線/
めいしょうてんのう /明正天皇/
めいしょうどくせん /名称独占/
めいしょうふめい /名称不明/
めいしょうぶ /名勝負/
めいしょうへんこう /名称変更/
めいしょく /明色/
めいしょずえ /名所図会/
めいしん /迷信/名神/
めいしんか /迷信家/
めいしんこうそく /名神高速/
めいじ /明治;年号(1868-1912)/明示;specify/名辞;term/
めいじ#ねん /明治#0年/明治#1年/明治#2年/明治#3年/
めいじいこう /明治以降/
めいじいご /明治以後/
めいじいしん /明治維新/
めいじいしんいぜん /明治維新以前/
めいじいぜん /明治以前/
めいじいらい /明治以来/
めいじか /明示化/
めいじがくいんだい /明治学院大/
めいじき /明治期/
めいじきいこう /明治期以降/
めいじきねんかん /明治記念館/
めいじけんぽう /明治憲法/
めいじしょき /明治初期/
めいじしんせいふ /明治新政府/
めいじじだい /明治時代/
めいじじんぐう /明治神宮/
めいじせいか /明治製菓/
めいじせいとう /明治製糖/
めいじせつ /明治節;11.3(現・文化の日)/
めいじせん /明治戦/
めいじたいしょうしょうわ /明治大正昭和/
めいじだい /明治大/
めいじだいがく /明治大学/
めいじだいがくいくた /明治大学生田/
めいじっきょう /名実況/
めいじつ /名実/名實/
めいじつとも /名実共/
めいじてき /明示的/
めいじてんのう /明治天皇/
めいじどおり /明治通り/
めいじにゅうぎょう /明治乳業/
めいじばし /明治橋/
めいじむら /明治村/
めいじゃく /名弱/
めいじや /明治屋/
めいじゅんのう /明順応/
めいじょう /名城/名状/
めいじょうせん /名城線/
めいじょうだいがく /名城大学/
めいじん /名人/明神/
めいじんい /名人位/
めいじんきゅう /名人級/
めいじんげい /名人芸/
めいじんせん /名人戦/
めいすい /名水/
めいすいひゃくせん /名水百選/
めいすいり /名推理/
めいすう /名数/命数/
めいすうひょう /命数表/
めいすうほう /命数法/
めいせい /名声/明星/名聲;「声」旧字/
めいせいこうこう /明星高校/
めいせいだいがく /明星大学/
めいせき /明晰/名跡/
めいせつ /名節/
めいせりふ /名台詞/名セリフ/
めいせん /名川/銘仙/名泉/
めいせんしゅ /名選手/
めいぜりふ /名台詞/
めいぜんりょう /明善寮/
めいそう /瞑想/迷走/名僧/明窓;-浄几/冥想;=瞑想/
めいそうしんけい /迷走神経/
めいそうじょうき /明窓浄机/明窓浄几/
めいそうてき /瞑想的/
めいそうほう /瞑想法/
めいぞく /名族/
めいた /目板/
めいたつ /明達/
めいたん /名短/
めいたんてい /名探偵/
めいだ /銘打/
めいだい /命題/名大/明大/名古屋大学;※abbrev/
めいだいかんすう /命題関数/
めいだいけいさん /命題計算/
めいだいこう /名大工/
めいだいこうがくぶ /名大工学部/
めいだいない /名大内/
めいだいなかの /明大中野/
めいだいなかのはちおうじ /明大中野八王子/
めいだいへんすう /命題変数/
めいだいまえ /明大前/名大前/
めいだいりこう /明大理工/
めいだいろんり /命題論理/
めいだいろんりがく /命題論理学;propositional logic/
めいだいろんりしき /命題論理式/
めいだん /明断/
めいち /明智/明知/名地/命知/
めいちゃ /銘茶/名茶/
めいちゅう /命中/
めいちゅうすう /命中数/
めいちゅうせいど /命中精度/
めいちゅうりつ /命中率/
めいちょ /名著/
めいちょう /明澄;clear/迷鳥;stray bird/明徴;clarify.「国体-」/鳴鳥;singing bird/名帳/
めいちょうし /名調子/
めいちんばめん /名珍場面/
めいっこ /姪っ子/
めいっぱい /目一杯/
めいてい /酩酊/名艇/
めいてき /名笛/
めいてつ /明哲/名鉄/
めいてつせとせん /名鉄瀬戸線/
めいてつとこなめせん /名鉄常滑線/
めいてつとっきゅう /名鉄特急/
めいてつひろみせん /名鉄広見線/
めいてつほしん /明哲保身/
めいてん /名店/
めいてんかい /名展開/
めいてんがい /名店街/
めいてんし /明天子/
めいでんこう /名電高/
めいでんしゃ /明電舎/
めいとう /名湯;良い温泉/名刀;優れた刀/銘刀;銘のある刀/名答;うまい答え/明答;明確な返答/名東;地名,名古屋/名糖;[企業名]/
めいとうさんぎょう /明糖産業;[企業名]/
めいとく /明徳;年号(1390-1394)/
めいど /明度;luminosity/冥土/冥途;=冥土/
めいどう /鳴動/明堂/
めいどのみやげ /冥土の土産;-に聞かせてやろう/
めいどふく /メイド服/
めいにち /命日/
めいはく /明白/
めいはん /名阪/
めいはんこくどう /名阪国道/
めいはんとっきゅう /名阪特急/
めいはんのう /明反応/
めいば /名馬/
めいばめん /名場面/迷場面/
めいばめんしゅう /名場面集/
めいばん /名盤/
めいひつ /名筆/
めいひょう /名票/
めいひん /名品/名牝/銘品/
めいび /明媚/
めいびゅう /迷謬/
めいびん /明敏/
めいふ /冥府/
めいふく /冥福/
めいふまどう /冥府魔道/
めいぶつ /名物/
めいぶつおとこ /名物男/
めいぶつぎれ /名物裂/
めいぶつし /名物紙/
めいぶつりょうり /名物料理/
めいぶん /名分;大義-/明文;明白な文章/名文;優れた文章/銘文;銘の文章/名聞;reputation/
めいぶんか /明文化/
めいぶんきてい /明文規定/
めいぶんろん /名分論/
めいへんこう /名変更/
めいへんしゅうちょう /名編集長/
めいほう /名峰/名宝/名豊/明芳/盟邦/
めいほかんきのう /名補完機能/
めいぼ /名簿/
めいぼう /明眸/名望/
めいぼうか /名望家;-政党/
めいぼうこうし /明眸皓歯/
めいぼく /銘木/名木/
めいぼさくせい /名簿作成/
めいぼじゅんい /名簿順位/
めいみ /芽美/
めいみゃく /命脈/
めいむ /迷夢/迷霧/
めいめい /明々;―白々/銘々;各自。「-のやり方」/命名/銘銘/冥々;dark/
めいめいけん /命名権;[新語]施設などに名前をつける権利。売買される/
めいめいしき /命名式/
めいめいしゃ /命名者/
めいめいはくはく /明々白々/明明白白/
めいめいほう /命名法/
めいめつ /明滅/
めいもう /迷妄/
めいもく /名目/瞑目;目を瞑る/
めいもく> /名目;-額,-賃金,-成長率/
めいもくじょう /名目上/
めいもくちんぎん /名目賃金;[経済]nominal wage/
めいもくてき /名目的/
めいもくてきていぎ /名目的定義/
めいもくろん /名目論;nominalism/
めいもん /名門/
めいもんく /名文句/
めいもんこう /名門校/
めいやく /盟約/名訳/名薬/
めいゆ /明喩/
めいゆう /名優/盟友/
めいよ /名誉/
めいよう /没有/
めいよかいいん /名誉会員/
めいよかいちょう /名誉会長/
めいよかいふく /名誉回復/
めいよかくめい /名誉革命/
めいよきそん /名誉毀損/名誉棄損;?/
めいよきそんざい /名誉毀損罪/
めいよきょうじゅ /名誉教授/
めいよこづな /名横綱/
めいよごせい /名誉碁聖/
めいよしょく /名誉職/
めいよしん /名誉心/
めいよそうさい /名誉総裁/
めいよばんかい /名誉挽回/
めいり /名利/
めいりゅう /名流/
めいりょう /明瞭/
めいりょうせい /明瞭性/
めいりょうてい /名料亭/
めいりょうど /明瞭度/
めいりん /明林/
めいりんかん /明倫館/
めいりんどう /明林堂/明倫堂/
めいれい /命令/
めいれいがた /命令型/
めいれいくちょう /命令口調/
めいれいぐん /命令群/
めいれいけい /命令形/
めいれいけいとう /命令系統/
めいれいご /命令語/
めいれいしょ /命令書/
めいれいじっこう /命令実行/
めいれいすう /命令数/
めいれいちょう /命令調;authoritative/命令長;[電算]command length/
めいれいついか /命令追加/
めいれいてき /命令的/
めいれいでんたつ /命令伝達/
めいれいはっこう /命令発行/
めいれいひょう /命令表/
めいれいぶん /命令文/
めいれいほう /命令法/
めいれいもと /命令元/
めいれいれつ /命令列/
めいれき /明暦;年号(1655-1658)/
めいれきのたいか /明暦の大火;[日本史]明暦3(1657)/
めいろ /迷路/目色/
めいろう /明朗/
めいろうかいけい /明朗会計/
めいろない /迷路内/
めいろん /名論/
めいわ /明和;年号(1764-1772)/
めいわきやく /名脇役/
めいわく /迷惑/
めいわくいがい /迷惑以外/
めいわくこうい /迷惑行為/
めいわくせんばん /迷惑千万/
めいわくちゅうしゃ /迷惑駐車/
めいわくでんわ /迷惑電話/
めいわくど /迷惑度/
めいわくめーる /迷惑メール/
めいわくもの /迷惑者/
めいわくやろう /迷惑野郎/
めいわくりょう /迷惑料/
めうえ /目上/
めうし /雌牛/牝牛/
めうち /目打ち/目打/
めうつり /目移り/
めお /女男/
めおし /目押し/
めおと /夫婦/娚/
めおとあい /夫婦愛/
めおとぢゃわん /夫婦茶碗/
めおとなか /夫婦仲/
めおとぼし /夫婦星;Altair and Vega/
めおとまんざい /夫婦漫才/
めかき /芽掻き;[園芸]/
めかくし /目隠し/目隠/
めかけ /妾/
めかけばら /妾腹/
めかじき /眼旗魚/
めかた /目方/
めかど /目角/
めかぶ /雌株;⇔雄株/和布蕪;ワカメの根/
めかぶら /和布蕪/
めかま /目蒲/
めかません /目蒲線/
めかり /和布刈り/和布刈/
めかりぶね /和布刈り舟/和布刈舟/
めが /女鹿/mega;[SI接頭語]M,10^6/
めがお /目顔/
めがしら /目頭/
めがね /眼鏡/
めがねちがい /眼鏡違い/
めがねっこ /眼鏡っ娘/メガネっ娘/
めがねてん /眼鏡店/
めがねばし /眼鏡橋/
めがねや /眼鏡屋/メガネ屋/
めがみ /女神/
めがみさま /女神様/
めがみぞう /女神像/
めがみてんせい /女神転生/
めがわ /女川/
めきき /目利き/
めきしこ /墨西哥;Mexico/
めきしこじん /メキシコ人/
めきゃべつ /芽キャベツ/
めぎか /メギ科/Berberidaceae/
めぎつね /女狐/牝狐/
めぎみ /女君/妻君/
めぎれ /目切れ/
めくぎ /目釘/
めくされ /目腐れ/
めくされがね /目腐れ金/
めくじら /目くじら/目鯨/
めくそ /目糞/目くそ/目クソ/目屎/
めくち /目口/
めくばせ /目配せ/眼配せ/
めくばり /目配り/
めくら /盲/瞽;≒盲/
めくらうち /盲打ち/
めくらかべ /盲壁;[建築]窓のない壁/
めくらじま /盲縞/
めくらばん /盲判/
めくらまし /目眩し/
めくらまど /盲窓;[建築]光の通らない窓/
めくらめっぽう /盲滅法/
めくり /捲り/
めくるめく /目眩く/
めぐすり /目薬/
めぐみ /恵/恵み/め組;町火消/恵美;人名/愛美/慈/惠;「恵」の旧字(人名用漢字)/めぐ美/
めぐみのあめ /恵みの雨/
めぐむ /恵/萠;「萌」の異体字(人名用漢字)/
めぐりあい /巡り合い/
めぐりあわせ /巡り合わせ/
めぐろ /目黒/
めぐろえき /目黒駅/
めぐろがくえん /目黒学園/
めぐろがわ /目黒川/
めぐろきねん /目黒記念/
めぐろく /目黒区/
めぐろくみん /目黒区民/
めぐろせいびがくえん /目黒星美学園/
めぐろとうきゅう /目黒東急/
めぐろのさんま /目黒の秋刀魚/
めぐろほうめん /目黒方面/
めこぼし /目溢し/
めごち /雌鯒/
めさき /目先/目崎/
めざし /目刺し;鰯の干物/目刺/
めざと /目敏/
めざまし /目覚まし;-時計/目覚し/
めざましどけい /目覚まし時計/目覚し時計/
めざめ /目覚め/
めざわり /目障り/
めし /飯/
めしあい /飯合/
めしい /盲/
めしがま /飯釜/
めした /目下/
めしたき /飯炊き/飯焚き/
めしたきおんな /飯炊き女/
めしだい /飯代/
めしぢゃわん /飯茶碗;ごはんちゃわん/
めしつかい /召使/召使い/召し使い/
めしつぶ /飯粒/
めしどき /飯時/
めしのたね /飯の種/
めしびつ /飯櫃/
めしべ /雌蕊/雌蘂;「蕊」異体字/
めしもの /召し物/
めしもり /飯盛り/
めしもりおんな /飯盛り女/
めしや /飯屋/
めしりょう /召料/
めしろ /目代/眼代/
めしわん /飯碗/飯椀/
めじ /目地/目時/目路/
めじか /女鹿/牝鹿/
めじざい /目地材/
めじり /目尻/
めじるし /目印/
めじろ /目白/繍眼児;=目白/
めじろおし /目白押し/目白押/
めじろかん /目白間/
めじろがくえん /目白学園/
めす /雌/牝/♀/
めす> /牝/雌;-猫,-豚/
めすいぬ /雌犬/メス犬/牝犬/
めすうま /牝馬/雌馬/
めすかぶ /雌株/
めすねこ /雌猫/牝猫/メス猫/
めず /馬頭/
めずらか /珍か/
めせん /目線/
めそぽたみあぶんめい /メソポタミア文明/
めぞぴあの /mezzo piano;やや弱く/
めぞふぉるて /mezzo forte;やや強く/
めたげんご /メタ言語;metalanguage/
めたりろん /メタ理論;metatheory/
めたんはっこう /メタン発酵/
めだか /目高;-の学校は川の中/
めだけ /女竹/
めだしぼう /目出し帽;ski mask/
めだち /目立/
めだちたがりや /目立ちたがり屋/
めだつ /目立つ/
めだま /目玉/眼球/
めだまきかく /目玉企画/
めだましょうひん /目玉商品/
めだまじいん /目玉寺院;ネパールの世界遺産/
めだませいひん /目玉製品/
めだまふうせん /目玉風船/
めだまやき /目玉焼き;[料理]fried egg/目玉焼/
めちがい /目違い/
めちゃ /目茶/
めちゃくちゃ /滅茶苦茶/目茶苦茶/
めちゃめちゃ /滅茶滅茶/
めっき /鍍金/滅金;=鍍金/
めっきゃく /滅却/
めっきん /滅菌/
めっきんご /滅菌後/
めっきんずみ /滅菌済み/
めっきんまえ /滅菌前/
めっさう /滅相/
めっさつ /滅殺/
めっし /滅私;-奉公/滅紫;faded purple/
めっしつ /滅失/
めっしほうこう /滅私奉公/
めっしゅがた /メッシュ型/
めっしゅきじ /メッシュ生地/
めっしゅじ /メッシュ地/
めっせーじせい /メッセージ性/
めっそう /滅相/
めった /滅多;(当て字)/
めったい /滅諦/
めったうち /滅多打ち;(当て字)/
めったぎり /滅多斬り;(当て字)/メッタ斬り/滅多切り;(当て字)/
めったづき /滅多突き;(当て字)包丁で-/
めったに /滅多に;(当て字)/
めったやたら /滅多矢鱈;「滅多」「矢鱈」共に当て字/
めっぽう /滅法/
めつ /滅/
めつき /目付き/目つき/眼つき/眼付/
めつけ /目付/目付け/
めつけやく /目付役/
めつご /滅後/滅期/
めつざい /滅罪/
めつじん /滅尽/
めつち /目土/
めつぶし /目潰し/
めつぼう /滅亡/
めつれつ /滅裂/
めづかい /目遣い/
めづまり /目詰まり/目詰り/
めて /馬手;右手/右手/
めで /愛で/
めでぃあおう /メディア王/
めでぃちけ /メディチ家;[世界史] I Medici/
めでとう /目出当/
めでゅさんどらもく /メデュサンドラ目/Medusandrales/
めとき /目時/
めど /目処/目途;=目処/針孔/蓍/
めどおし /目通し/
めどおり /目通り/
めどき /女時;bad time ⇔男時/
めどぎ /蓍/
めなだ /赤目魚/眼奈太/
めなみ /女波/
めにえーるびょう /メニエール病;[医](耳の病気)Meniere's disease/
めぬき /目貫/目抜き/
めぬきどおり /目抜き通り/
めぬま /妻沼/
めねじ /雌螺子/
めのう /瑪瑙;agate/碼碯;=瑪瑙/
めのかたき /目の敵/
めのこ /女の子/目の子;暗算、概算。「-勘定」/布の子;刻み昆布/海布の子;=布の子/
めのこかんじょう /目の子勘定/
めのこざん /目の子算/
めのこざんよう /目の子算用/
めのたま /目の玉/眼の玉/
めのと /乳母/
めのどく /目の毒/
めのほよう /目の保養/
めのまえ /目の前/
めはし /目端/
めはちぶ /目八分/
めはな /目鼻/
めはなだち /目鼻立ち/
めばえ /芽生え/
めばな /雌花/
めばり /目張り;タイルの-/目貼り/
めばる /眼張/
めひょう /女豹/
めびき /目引/
めぶし /女節;腹肉で作った鰹節/雌節;=女節/
めぶんりょう /目分量/
めへん /目偏/
めべり /目減り/
めぼし /目星/
めまい /眩暈/暈/目まい/目眩い/
めまとい /目纏い/
めまひ /目眩ひ/眩暈/目眩い/
めまんべつ /女満別/
めまんべつくうこう /女満別空港/
めみえ /目見え/
めむろ /芽室/
めめざこ /目目雑魚/目々雑魚/
めめじゃこ /目目雑魚/目々雑魚/
めもじ /目文字/
めもちょう /メモ帳/
めもと /目元/目許/
めもとくちもと /目元口元/
めもま /メモ魔;[口]何でもメモする人/
めもり /目盛/目盛り/
めやす /目安/
めやすていど /目安程度/
めやすばこ /目安箱/
めやすひょう /目安表/
めやに /目脂/目やに/目ヤニ/
めら /目良/
めらにんしきそ /メラニン色素/
めりか /芽里香/
めりけんこ /メリケン粉/
めりはり /減り張り/減張/乙張/
めりょう /馬寮/
めるかとるずほう /メルカトル図法/
めるとも /メル友/
めろう /女郎/
めん /面/麺;noodle/綿/免/緬;縮緬(ちりめん)/棉;≒綿/緜;「綿」の異体字/麪;「麺」の異体字/眄/
めんあつ /面圧/
めんいつ /面一/
めんえき /免疫/免役;†労役・兵役の免除/
めんえきかんけい /免疫関係/
めんえきがく /免疫学;immunology/
めんえききこう /免疫機構/
めんえきけい /免疫系/
めんえきせい /免疫性/
めんえきたい /免疫体/
めんえきていかじょうたい /免疫低下状態/
めんえきふぜん /免疫不全/
めんえきよくせいざい /免疫抑制剤/
めんえきりょうほう /免疫療法/
めんえきりょく /免疫力/
めんおり /綿織/
めんおりもの /綿織物/
めんか /綿花/棉花/綿価/
めんかい /面会/
めんかいしつ /面会室/
めんかいしゃぜつ /面会謝絶/
めんかいじかん /面会時間/
めんかく /面角/
めんかやく /綿火薬/
めんかん /免官/
めんが /面画/
めんきつ /面詰/
めんきょ /免許/
めんきょかいせい /免許改正/
めんきょかいでん /免許皆伝/
めんきょぎょうせい /免許行政/
めんきょこうしん /免許更新/
めんきょこうしんじ /免許更新時/
めんきょこうふ /免許交付/
めんきょしかく /免許資格/
めんきょしっこう /免許失効/
めんきょしゅとく /免許取得/
めんきょしゅとくしゃ /免許取得者/
めんきょしょ /免許書/
めんきょしょう /免許証/
めんきょしんせい /免許申請/
めんきょじょう /免許状/
めんきょせい /免許制/
めんきょせいど /免許制度/
めんきょぜい /免許税;license fee/
めんきょていし /免許停止;免停/
めんきょとりけし /免許取消/
めんきょにん /免許人/
めんきょばんごう /免許番号/
めんきょふよう /免許不要/
めんきょほじしゃ /免許保持者/
めんぎょ /面魚/
めんくい /面食い/面食/
めんけつごう /面結合/
めんけん /瞑眩/
めんこ /面子/
めんこうげん /面光源/
めんこうふはい /面向不背/
めんご /面語/
めんざい /免罪/
めんざいふ /免罪符/
めんし /綿糸/
めんしき /面識/
めんしゃ /面紗/綿紗/
めんしゅう /免囚/
めんしゅうごう /面集合/
めんしょく /免職/面色;[光学]film colour/
めんしん /免震;[建築]地震の影響を受けにくいこと。/
めんしんこうぞう /免震構造;[建築](強度を高める以外の手段で)地震の被害を受けにくくした構造/
めんしんりっぽうこうし /面心立方格子;face-centred cubic lattice/
めんじゅう /面従/
めんじゅうこうげん /面従後言/
めんじゅうふくはい /面従腹背/
めんじょ /免除/
めんじょう /面上/免状/面状/
めんじょうりょう /免状料/
めんじょしんせい /免除申請/
めんじょせいど /免除制度/
めんすう /面数/
めんせい /面性/
めんせいひん /綿製品/
めんせき /免責/面積/
めんせきあたり /面積当たり/
めんせきがく /免責額/
めんせきけい /面積計/
めんせきじこう /免責事項/
めんせきず /面積図/
めんせきそくど /面積速度;[物理]areal velocity/
めんせきひょう /面積表/
めんせきぶん /面積分/
めんせつ /面接/
めんせつかいじょう /面接会場/
めんせつかん /面接官/
めんせつしけん /面接試験/
めんせつしつ /面接室/
めんせつび /面接日/
めんぜい /免税/
めんぜいさく /免税策/
めんぜいてん /免税店;duty-free shop.「空港の-」/免税点;tax exemption limit.「固定資産税の-」/
めんぜいひん /免税品/
めんぜいひんてん /免税品店/
めんぜん /面前/
めんぜんちん /門前清/
めんそ /免訴;[法]刑事訴訟の打ち切り/免租;租税の免除/面素;[数学]surface element/
めんそう /面相/
めんたい /明太;スケトウダラ/面体/面対/
めんたいこ /明太子/
めんたいしょう /面対称/
めんたま /目ん玉/
めんだ /免田/
めんだん /面談/
めんちょう /面疔/
めんちん /面陳/
めんつ /面子/
めんつゆ /麺つゆ/
めんてい /免停/面体;顔つき/
めんてなんすせい /メンテナンス性/
めんでれびうむ /Md/Mendelevium/
めんでん /免田/緬甸;Burma (現Myanmar)/
めんとう /面頭/
めんとおし /面通し/
めんとり /面取り/面取/
めんどう /面倒/面堂/
めんどうみ /面倒見/
めんどり /雌鳥/雌鶏/
めんない /面内/
めんば /面罵/
めんばーかん /メンバー間/
めんばーしょうかい /メンバー紹介/
めんばかんすう /メンバ関数/
めんばへんすう /メンバ変数/
めんぴ /面皮/
めんぶ /面部/
めんぷ /綿布/
めんぺき /面壁/
めんぺきくねん /面壁九年;達磨大師の解脱/
めんぼう /綿棒/麺棒/面貌/綿紡/
めんぼく /面目/
めんぼくやくじょ /面目躍如/
めんぽう /面皰/
めんぽお /面頬/
めんま /麺麻/
めんみつ /綿密/
めんみつど /面密度/
めんめん /面々/綿々/面面/綿綿/
めんもう /綿毛/
めんもく /面目/
めんもくいっしん /面目一新/
めんもくやくじょ /面目躍如/
めんよう /面妖/緬羊/綿羊/面容/
めんようそ /面要素/
めんるい /麺類/
めんれんけつ /面連結/
めんわり /面割り;面通し/
も /喪/藻/裳/模;模倣/摸;≒模/糢;「模」の異体字/茂/面/姆/母/楙;しげ・る/望;?/邑;?/貰;?/
もーせごしょ /モーセ五書/
もーせのじっかい /モーセの十戒/
もーどぎょう /モード行/
もーどめい /モード名/
もーるすしんごう /モールス信号/
もーるすふごう /モールス符号;Morse code.　... _._ _._/
もいち /茂一;名/
もう /網/毛/盲/猛/孟;孟子/蒙;蒙昧/曚/矇/朦;朦朧/檬;(慣用音) 檸檬/濛;湯気濛々/艨/亡;亡者/妄;妄想/芒;すすき/罔;あみ/魍;魑魅魍魎/望;所望/耗;消耗/耄;耄碌/网;あみ/莽/申/
もう> /猛;猛反発,猛攻撃,猛ダッシュ/
もうあ /盲唖/
もうあい /盲愛/妄愛/
もうあく /猛悪/
もうい /猛威/
もういちど /もう一度/
もうう /猛雨/
もううん /妄雲/
もうか /猛火/真岡/
もうかてつどう /真岡鉄道/
もうかん /毛管;capillary tube/毛幹;hair shaft/
もうかんしょうこうぐん /盲管症候群/
もうかんじゅうそう /盲管銃創/
もうがっこう /盲学校/
もうき /盲亀/濛気/
もうきのふぼく /盲亀の浮木/
もうきん /猛禽/
もうきんるい /猛禽類/
もうぎゅう /猛牛/
もうけ /儲け/儲/
もうけぐち /儲け口/
もうけばなし /儲け話/
もうけもの /儲け物/
もうけやく /儲け役/儲役/
もうけん /猛犬/
もうげん /妄言/
もうげんたしゃ /妄言多謝/
もうこ /蒙古;Mongol/猛虎/
もうこう /猛攻/
もうこうぎ /猛抗議/
もうこうげき /猛攻撃/
もうこうねん /孟浩然/
もうこご /蒙古語;Mongolian/
もうこしょう /蒙古症/
もうこじんしゅ /蒙古人種/
もうことう /猛虎党/
もうこは /猛虎派/
もうこはん /蒙古斑/
もうこもじ /蒙古文字/
もうこれき /猛虎暦/
もうこん /毛根/
もうご /妄語/
もうごかい /妄語戒;[仏教]五戒の一つ/
もうさい /毛細/
もうさいかん /毛細管/
もうさいかんげんしょう /毛細管現象/
もうさいけっかん /毛細血管/
もうし /孟子/
もうしあわせ /申し合わせ/申合せ/申し合せ/
もうしいれ /申し入れ/申入れ/
もうしおくり /申し送り/申送り/
もうしこし /申し越し/
もうしこみ /申し込み/申込/申込み/
もうしこみうけつけじゅん /申込受付順/
もうしこみきかん /申込期間/
もうしこみきげん /申込期限/
もうしこみご /申込後/
もうしこみさき /申込先/申し込み先/
もうしこみしめきり /申込締切/
もうしこみしゃ /申込者/
もうしこみしゃしめい /申込者氏名/
もうしこみしゃたすう /申込者多数/
もうしこみしょ /申込書/
もうしこみじ /申込時/
もうしこみじょう /申込状/
もうしこみせい /申し込み制/
もうしこみたすう /申込多数/
もうしこみたんとうしゃ /申込担当者/
もうしこみちゅう /申込中/
もうしこみにん /申込人/
もうしこみひょう /申込票/
もうしこみび /申込日/
もうしこみほうほう /申込方法/
もうしこみようし /申込用紙/
もうしご /申し子/
もうしじょう /申状/申し状/申条/申し条/
もうしたて /申立/申立て/申し立て/
もうしたてしょ /申立書/
もうしたてにん /申立人/
もうしで /申し出/申出/
もうしひらき /申し開き/
もうしぶみ /申文/
もうしぶん /申し分/
もうしもく /網翅目/
もうしゃ /盲者/猛射/
もうしゅう /妄執/猛襲/
もうしゅん /孟春/
もうしょ /猛暑/
もうしょう /猛将/
もうしょび /猛暑日;最高気温が35℃以上の日/
もうしわけ /申し訳/申訳/申し分け/
もうしわけない /申し訳ない/
もうしん /猛進;†rush.「猪突-」/盲信;†blind belief.「カルトを-する」/妄信;†≒盲信/盲進;†advance blindly「方針もなく-する」/
もうじゃ /亡者;金の-/盲者;blind/
もうじゅう /猛獣/盲従/
もうじゅうつかい /猛獣使い/
もうじょう /網状/毛状/
もうじょうたい /網状態/毛状体/
もうじょうみゃく /網状脈/
もうじん /盲人/蒙塵/
もうじんしょかん /盲人書簡/
もうすこし /もう少し/
もうすぴーど /猛スピード/
もうせい /猛省/
もうせつ /妄説/
もうせん /毛氈/
もうせんごけ /毛氈苔/
もうぜん /猛然/惘然/
もうそう /妄想/盲僧/網総/
もうそうか /妄想家/
もうそうがた /妄想型/
もうそうきょう /妄想狂/
もうそうしょう /妄想症/
もうそうせい /妄想性/
もうそうだけ /孟宗竹/
もうそうちく /孟宗竹/
もうそうてき /妄想的/
もうそうびわ /盲僧琵琶/
もうそうへき /妄想癖/
もうたい /毛帯/
もうたいかく /毛帯核/
もうたくとう /毛沢東/
もうだ /猛打/
もうだしょう /猛打賞/
もうだっしゅ /猛ダッシュ/
もうだん /妄談/妄断/
もうちょう /盲腸/猛鳥/
もうちょうえん /盲腸炎/
もうちょうせん /盲腸線/
もうつい /猛追/
もうてん /盲点/
もうで /詣/詣で/
もうとう /毛頭/
もうとく /孟徳;曹操の字(あざな)/
もうとっくん /猛特訓/
もうどう /盲導/妄動/盲動;≒妄動/艨艟/
もうどうけん /盲導犬/
もうどく /猛毒/
もうない /網内/
もうねん /妄念/
もうのう /毛嚢/
もうはつ /毛髪/
もうはつよう /毛髪用/
もうはん /盲斑/
もうはんげき /猛反撃/
もうはんたい /猛反対/
もうはんぱつ /猛反発/
もうばく /猛爆/盲爆/
もうぱい /盲牌;[麻雀]/
もうひつ /毛筆/
もうひつしょたい /毛筆書体/
もうひつたい /毛筆体/
もうひとつ /もう一つ/
もうひょう /妄評/猛豹/
もうふ /毛布/
もうふう /猛風/
もうふぶき /猛吹雪/
もうほう /毛包/
もうぼ /孟母/
もうぼさんせん /孟母三遷/
もうまい /蒙昧;(この表記が一般的)/曚昧/矇昧/濛昧/
もうまく /網膜/
もうまくえん /網膜炎/
もうまくしょう /網膜症/
もうまくじょう /網膜上/
もうまくとうえい /網膜投影/
もうまくはくり /網膜剥離/
もうまくふしゅ /網膜浮腫/
もうもう /濛々;湯気が-/朦々;≒濛々/濛濛/朦朦/
もうもく /盲目/
もうもくてき /盲目的/
もうもん /網紋/
もうゆう /猛勇/
もうよう /網様/
もうようたい /毛様体;ciliary body/網様体;reticular formation/
もうら /網羅/
もうらせい /網羅性/
もうらてき /網羅的/
もうらりつ /網羅率/
もうり /毛利/
もうりてるもと /毛利輝元/
もうりもとなり /毛利元就/
もうりょう /魍魎/
もうれつ /猛烈/
もうれんしゅう /猛練習/
もうれんちゃん /猛連荘/
もうろう /朦朧/
もうろうたい /朦朧体/
もうろく /耄碌/
もえ /燃え/萌え/萌絵;名/燃/萌/萠;「萌」の異体字(人名用漢字)/
もえかす /燃え滓/
もえがら /燃え殻/
もえぎ /萌黄/萌木/萌葱/萌え木/
もえぎいろ /萌黄色/萌葱色/萌木色/
もえこ /萌子/
もえつきしょうこうぐん /燃え尽き症候群;[時事]burnout syndrome/
もおか /真岡/
もおかし /真岡市/
もおかてつどう /真岡鉄道/
もがさ /痘瘡/
もがみ /最上/
もがみがわ /最上川/
もがみよしみつ /最上義光/
もがり /殯;貴人の仮葬/虎落;竹製の柵/強請;=ゆすり/
もがりたけ /虎落竹/
もがりぶえ /虎落笛/
もぎ /模擬/茂木/摸擬;=模擬/
もぎけい /模擬系/
もぎさいばん /模擬裁判/
もぎしけん /模擬試験/
もぎじっけん /模擬実験;simulation/
もぎせん /模擬戦/
もぎてすと /模擬テスト/
もぎてん /模擬店/
もぎどう /没義道/
もく /目/木/黙/杢;(国字) 大工/沐;沐浴/默;「黙」の旧字(人名用漢字)/
もくあみ /黙阿弥;河竹-/木阿弥;元の-/
もくか /木化;[植物]lignify/
もくかい /黙会/
もくかせき /木化石/
もくがす /木ガス/
もくきん /木金/
もくきんど /木金土/
もくぎょ /木魚/
もくぐう /木偶/
もくぐん /目群/
もくげき /目撃/黙劇/
もくげきしゃ /目撃者/
もくげきじょうほう /目撃情報/
もくげきだん /目撃談/
もくげきほうこく /目撃報告/
もくこうぞう /木構造/
もくさく /木酢;木材から作る酢酸/木柵/
もくさつ /黙殺/木札/
もくさん /目算/
もくざい /木材/
もくざいこう /木材港/
もくざいしげん /木材資源/
もくし /目視/黙示;無言で示す/黙視;黙って見ている/黙止;黙り込む/黙思;黙って考える/目指;?/
もくしけんさ /目視検査/
もくしつ /木質/
もくしつか /木質化/
もくしょう /木匠/目睫/
もくしょうぜん /黙照禅/
もくしろく /黙示録;[聖書]The Apocalypse(Apoc)/
もくじ /目次/黙示/
もくじあん /目次案/
もくじき /木食/
もくじゅう /黙従/
もくじろく /黙示録;=もくしろく/
もくず /藻屑/
もくせい /木製;wooden/木星;Jupitor/木犀/木精;methanol/
もくせいか /モクセイ科/
もくせいかんそく /木星観測/
もくせいめん /木星面/
もくせいもく /モクセイ目/Oleales/
もくぜん /目前/黙然/
もくそう /黙想/目送/
もくそく /目測/
もくぞう /木造/木像/
もくぞうかおく /木造家屋/
もくぞうけんちくし /木造建築士/
もくぞうけんちくぶつ /木造建築物/
もくぞうじゅうたく /木造住宅/
もくたーる /木タール/
もくたん /木炭/
もくだい /目代/
もくだく /黙諾/
もくちょう /木彫/
もくづ /藻屑/
もくてき /目的/
もくてきいがい /目的以外/
もくてきいしき /目的意識/
もくてきいん /目的因;アリストテレス/
もくてきえき /目的駅/
もくてきおん /目的音/
もくてきかく /目的格/
もくてきかんすう /目的関数/
もくてきがい /目的外/
もくてきがいしよう /目的外使用/
もくてきがわ /目的側/
もくてきげんご /目的言語/
もくてきご /目的語/
もくてきごと /目的毎/
もくてきしょく /目的食/
もくてきしんごう /目的信号/
もくてきじたい /目的自体/
もくてきじょうせいとう /目的上正当/
もくてきじょうひつよう /目的上必要/
もくてきすいこう /目的遂行/
もくてきせってい /目的設定/
もくてきせんよう /目的専用/
もくてきぜい /目的税/
もくてきたっせい /目的達成/
もくてきち /目的地/
もくてきちほうこう /目的地方向/
もくてきてき /目的的/
もくてきふめい /目的不明/
もくてきぶつ /目的物/
もくてきべつ /目的別/
もくてきろん /目的論/
もくてきろんてき /目的論的/
もくと /目途/目睹;witness/
もくとう /黙祷/
もくどく /黙読/
もくにん /黙認/
もくねん /黙然;silent/黙念;ponder/
もくの /杢野/
もくはい /木杯/木盃/
もくはん /木版/
もくはんいんさつ /木版印刷/
もくはんが /木版画/
もくば /木馬/
もくひ /黙秘/木皮/木樋/
もくひけん /黙秘権/
もくひょう /目標/
もくひょうかん /目標艦/
もくひょうき /目標機/
もくひょうたっせい /目標達成/
もくひょうち /目標値/
もくひょうぶつ /目標物/
もくひょうほうこう /目標方向/
もくひょうまいすう /目標枚数/
もくぶ /木部/
もくへん /木片/
もくほん /木本/
もくぼ /木母/
もくまおうもく /モクマオウ目/Casuarinales/
もくまおうもくあぐん /モクマオウ目亜群/
もくめ /木目/
もくめもよう /木目模様/
もくもう /木毛;wood-wool. 「-セメント板」/
もくもく /黙々/黙黙/
もくやく /黙約/
もくよう /木曜/
もくようび /木曜日/
もくよく /沐浴/
もくらん /木蘭/
もくらんじき /木蘭色/
もくれい /目礼/黙礼/
もくれん /木蓮/
もくれんか /モクレン科/Magnoliaceae/
もくれんが /木煉瓦/
もくれんもく /モクレン目/Magnoliales/
もくろう /木蝋;ハゼノキから取る日本のロウ/
もくろく /目録/黙録/
もくろみ /目論見/
もくろみしょ /目論見書/
もくろん /目論/
もぐさ /艾;moxa/藻草;waterweed/
もぐさえん /百草園/
もぐら /土竜/土龍/
もぐらたたき /モグラ叩き/土竜叩き/
もぐり /潜り;-の医者/
もけい /模型/
もけいか /模型化/
もけいかい /模型界/
もけいぎょうかい /模型業界/
もけいぐん /模型群/
もけいこうさく /模型工作/
もけいざっし /模型雑誌/
もけいず /模型図/
もけいせいさく /模型製作/
もけいせんもんし /模型専門誌/
もけいてき /模型的/
もけいてん /模型店/
もけいひこうき /模型飛行機/
もけいや /模型屋/
もけいよう /模型用/
もこ /模糊/糢糊;=模糊/
もこく /模刻/摸刻;=模刻/
もこくぼん /模刻本/
もこし /裳階/
もこと /藻琴/
もさ /猛者/
もさく /模索/摸索;=模索/模作;†imitation/
もさくじょうたい /模索状態/
もさくちゅう /模索中/
もさくてき /模索的/
もざいくじょう /モザイク状/
もざいくびょう /モザイク病;(mosaic disease)農作物の病害/
もし /模試/若し/
もしか /若しか/
もしき /模式/摸式/
もしきか /模式化/
もしきず /模式図/
もしきてき /模式的/
もしくは /若しくは/
もしも /若しも/
もしゃ /模写/摸写;=模写/摸冩;「写」旧字/
もしゅ /喪主/
もしょう /喪章/
もじ /文字/門司;地名,福岡/綟/
もじいか /文字以下/
もじいがい /文字以外/
もじいじょう /文字以上/
もじいち /文字位置/
もじえ /文字絵/
もじえき /門司駅/
もじおち /文字落ち/文字落/
もじか /文字化/
もじかくてい /文字確定/
もじかん /文字間/
もじかんかく /文字間隔/
もじがた /文字型/
もじきごう /文字記号/
もじきなか /文字寸半/
もじきょう /文字鏡;今昔文字鏡/
もじきょうかい /文字境界/
もじぐん /文字群/
もじげんご /文字言語;written language.⇔音声言語/
もじこーど /文字コード/
もじこう /門司港/
もじこうほ /文字候補/
もじことば /文字詞/
もじごと /文字毎/
もじさいず /文字サイズ/
もじさくじょ /文字削除/
もじしき /文字式/
もじした /文字下/
もじしてん /門司支店/
もじしゅ /文字種/
もじしゅうごう /文字集合/
もじしゅうしょく /文字修飾/
もじしゅつりょく /文字出力/
もじしゅるい /文字種類/
もじしょうきょ /文字消去/
もじしょり /文字処理/
もじじしょ /文字辞書/
もじじたい /文字自体/
もじじょうほう /文字情報/
もじすう /文字数/
もじすうせいげん /文字数制限/
もじずり /捩摺/
もじぜんぶ /文字全部/
もじたいおう /文字対応/
もじたいけい /文字体系/
もじたじゅうほうそう /文字多重放送/
もじたんい /文字単位/
もじたんまつ /文字端末/
もじちょう /文字長/
もじつうしん /文字通信/
もじづら /文字面/
もじていすう /文字定数/
もじどおり /文字通り/
もじにゅうりょく /文字入力/
もじにゅうりょくじ /文字入力時/
もじにゅうりょくちゅう /文字入力中/
もじにんしき /文字認識/
もじにんしきぎじゅつ /文字認識技術/
もじはいれつ /文字配列/
もじはば /文字幅/
もじばけ /文字化け/
もじばん /文字盤/文字版/
もじひょうき /文字表記/
もじひょうじ /文字表示/
もじぶん /文字分/
もじへんこう /文字変更/
もじへんすう /文字変数/
もじほうそう /文字放送/
もじめ /文字目/
もじゃこ /藻雑魚/
もじやき /文字焼き/文字焼/
もじゅーるか /モジュール化/
もじゅーるしき /モジュール式/
もじよう /文字用/
もじり /捩/
もじれつ /文字列/
もじれつか /文字列化/
もじれつがた /文字列型/
もじれつがたへんすう /文字列型変数/
もじれつけんさく /文字列検索/
もじれつこうもく /文字列項目/
もじれつしょうごう /文字列照合/
もじれつしょり /文字列処理/
もじれつそうさ /文字列操作/
もじれつたんさく /文字列探索/
もじれつちゅう /文字列中/
もじれつちょう /文字列長/
もじれつていすう /文字列定数/
もじれつにゅうりょく /文字列入力/
もじれつへんしゅう /文字列編集/
もじわく /文字枠/
もすきーときゅう /モスキート級;[ボクシング](ジュニアのみ)45kg以下(mosquito=蚊)/
もすくわ /莫斯科/
もすそ /裳裾/
もず /百舌鳥/百舌/鵙/鴃/
もずく /海雲/水雲/海蘊;海藻/
もずくす /もずく酢/
もずみ /茂住/
もずめ /物集女/物集/
もせい /茂生/
もせうし /妹背牛/
もそう /模奏/
もぞう /模造/摸造;=模造/模像/
もぞうし /模造紙/
もぞうひん /模造品/
もたれ /凭れ/靠れ/
もだえ /悶え/
もだえじに /悶え死に/
もち /餅/糯;穀物の、餅の原料となる品種/黐;鳥黐/望/持ち/持/餠;「餅」の旧字/勿;勿論/
もちあい /持ち合い/持合/持合い/
もちあいかぶ /持ち合い株/
もちあじ /持ち味/
もちあみ /餅網/
もちあわせ /持ち合わせ;-がない/持ち合せ/持合せ/
もちい /用い/
もちいえ /持ち家/
もちいね /糯稲/
もちうた /持ち歌/
もちお /持尾/
もちおくり /持ち送り;[建築]corbel/持送り;[建築]/
もちおもり /持ち重り/
もちかえり /持ち帰り/
もちかた /持ち方/
もちかぶ /持株/持ち株/
もちかぶかい /持株会/
もちかぶがいしゃ /持株会社/持ち株会社/
もちかぶせいげん /持ち株制限/持株制限/
もちかぶひりつ /持株比率/
もちがし /餅菓子/
もちがせ /用瀬/
もちがね /持ち金/
もちきり /持ち切り;噂で-/
もちぐされ /持ち腐れ/持腐れ/
もちげい /持ち芸/
もちこし /持ち越し;carry-over/持越/持越し/
もちこみ /持ち込み/持込/持込み;-禁止/
もちこみうま /持込馬/
もちこみしゅうり /持込修理/
もちごま /持駒/
もちごめ /餅米/もち米/糯/糯米/
もちじかん /持ち時間/
もちずき /望月/
もちだ /持田/
もちだい /餅代/
もちだし /持ち出し/持出/持出し/
もちだせいやく /持田製薬;[企業名]/
もちつき /餅搗き/餅つき/
もちつもたれつ /持ちつ持たれつ/
もちづき /望月;full moon/餅月;人名?/
もちて /持ち手;handle, bearer/持手/
もちてん /持ち点/
もちにげ /持ち逃げ/持逃げ/
もちぬし /持ち主/持主/
もちねた /持ちネタ/
もちのひ /望の日;陰暦15日/
もちはこび /持ち運び/
もちはだ /餅肌/餅膚/
もちば /持ち場/持場/
もちばん /持ち番/持番/
もちひろ /望洋/
もちふだ /持ち札/
もちぶん /持分/持ち分/
もちぶんほう /持分法/
もちまえ /持ち前/貭;「質」の異体字/
もちまる /持丸;金持ち/
もちまわり /持ち回り/持回り/
もちむね /用宗/
もちもの /持ち物/持物/
もちや /餅屋/
もちゅう /喪中/
もちより /持ち寄り/持寄り/
もちろん /勿論/
もちろんれいがい /勿論例外/
もっか /目下/黙過/木化;[植物]lignify/
もっかい /木灰/黙会/
もっかく /木槨/
もっかつじばん /木活字版/
もっかどこんすい /木火土金水/
もっかん /木管/木簡/
もっかんがっき /木管楽器/
もっかんぐん /木管群/
もっかんごじゅうそう /木管五重奏/
もっき /木器/
もっきつ /勿吉;古代中国の少数民族。「ぶつきつ」/
もっきゃく /没却/
もっきょ /黙許/
もっきん /木琴/
もっけ /物怪/勿怪;=物怪/
もっけい /木鶏/黙契/牧谿;画僧/
もっこ /畚/
もっこう /木工/木瓜/黙考/
もっこうじゅつ /木工術/
もっこうよう /木工用/
もっこつ /木骨/
もっこん /目今/
もっしょくし /没食子;gallnut/
もったい /勿体/
もったいない /勿体無い/
もって /以て/
もってこい /持って来い/
もってのほか /以ての外/
もっとも /最も;most/尤も;(reasonable)「それも-だ」 (接続詞)「-、異論もある」/
もっともやく /尤役/
もっぱら /専ら/
もつ /物/勿;勿体/
もつご /没後/
もつなべ /もつ鍋/モツ鍋/
もつにゅう /没入/
もつやき /もつ焼き/
もつやく /没薬/
もつれ /縺れ/
もてぎ /茂木/
もでるか /モデル化/
もでるじぎょう /モデル事業/
もと /元/基;base.「実体験を-にする」/許;手の届く範囲。「親の-」/下;≒許 「白日の-」/素;「スープの-」/本/望都;人名/幹/礎/故/旧/
もと> /元/
もとあいぼう /元相棒/
もとあき /元昭/元明/
もとあざぶ /元麻布/
もとあり /本有/
もとい /基/元結;=もとゆい/元い;(間投詞)「老害、-大ベテラン」/
もといあんふ /元慰安婦/
もといけ /本池/
もといし /元石/本石/
もといせ /元伊勢/
もといれ /元入れ/
もとうけ /元請け/
もとうた /元歌/
もとうり /元売り/
もとえ /元絵/
もとえい /基栄/
もとお /元男/基夫/元夫/元朗/誠生/
もとおか /元岡/
もとおり /本居/
もとおりのりなが /本居宣長/
もとかしゅ /元歌手/
もとかず /元一/
もとかど /本門/
もとかの /元カノ/
もとかぶ /元株/
もとかれ /元彼;[口]昔の彼氏/元カレ/
もとかわ /本川/
もとかんじ /元幹事/
もとかんじちょう /元幹事長/
もとかんじゃ /元患者/
もとかんぶ /元幹部/
もとがしわ /本柏/
もとき /元木/本木/基樹/元紀/元基/基紀/
もときじ /元記事/
もときゅう /本久/
もときん /元金/
もとぎいん /元議員/
もとぎぼ /元義母/
もとぐんじん /元軍人/
もとけいきゅう /元京急/
もとこ /素子/元子/基子/茂登子/
もとこうこうきょうし /元高校教師/
もとこくさい /元国際/
もとこくたいせんしゅ /元国体選手/
もとこくてつ /元国鉄/
もとこくむちょうかん /元国務長官/
もとこむすび /元小結/
もとごうかく /元合格/
もとごえ /元肥;[園芸]/基肥/
もとさぎし /元詐欺師/
もとさと /理元/
もとざわ /本澤/
もとし /元司/基史/元志/基志/
もとしげ /元重/
もとしゃいん /元社員/
もとしゅしょう /元首相/
もとしゅふ /元主婦/
もとしりょう /元資料/
もとしんじゃ /元信者/
もとしんぱん /元審判/
もとじ /元司/
もとじま /本島;姓/
もとじめ /元締め/元締/
もとじゅうぐんいあんふ /元従軍慰安婦/
もとじゅく /本宿/
もとじょうし /元上司/
もとじろう /基次郎/
もとす /本巣/本栖/
もとすえ /本末/
もとすこ /本栖湖/
もとすみよし /元住吉/
もとせきわけ /元関脇/
もとせん /元栓/
もとせんしゅ /元選手/
もとたいいん /元隊員/
もとたか /基隆/元孝/
もとただ /元正/
もとたなか /元田中/
もとだ /元田/
もとだいじん /元大臣/
もとだいとうりょう /元大統領/
もとだか /元高/
もとだね /元種/
もとちじ /元知事/
もとちゅうにち /元中日/
もとちょう /元帳/
もとで /元手/
もとでら /元寺/
もとでんきや /元電気屋/
もととうきゅう /元東急/
もととうしゅ /元投手/
もととうだい /元東大/
もとどうりょう /元同僚/
もとどおり /元通り/
もとどくしゃ /元読者/
もとどり /髻/
もとなが /源久/
もとなり /元就/元成/本成り/本生り/
もとに /元に/基に/
もとにほんぐんじん /元日本軍人/
もとにほんこうくう /元日本航空/
もとにほんへい /元日本兵/
もとね /元値/
もとねた /元ネタ/
もとの /本埜/元野/基乃/
もとのぶ /元信/
もとのり /元紀/素典/一徳/
もとはこね /元箱根/
もとはし /本橋/
もとはず /本弭/本筈/
もとはま /元浜/
もとはら /本原/
もとはる /元春/
もとはんきゅう /元阪急/
もとはんしん /元阪神/
もとばこ /元箱/
もとばこづき /元箱付/
もとばやし /本林/
もとばらい /元払い;⇔着払い/元払/
もとひこ /元彦/
もとひさ /元久/基久/幹久/
もとひしょ /元秘書/
もとひで /元秀/元英/
もとひろ /基博/元洋/基史/礎弘/
もとひろしま /元広島/
もとび /元火/
もとふみ /元文/
もとぶ /本部/
もとへんしゅうちょう /元編集長/
もとほうしょう /元法相/
もとまくうち /元幕内/
もとまくうちりきし /元幕内力士/
もとまち /元町/
もとまちえき /元町駅/
もとみち /素道;名/
もとみや /本宮/
もとむら /本村/
もとめ /求め/
もとめかた /求め方/
もともと /元々/基々/元元/
もとや /元也/
もとやま /本山/元山/
もとやまかん /本山間/
もとやまきたまち /本山北町/
もとやわた /本八幡/
もとやん /元ヤン/
もとゆい /元結/
もとゆき /基之/幹之/
もとよこづな /元横綱/
もとよし /本吉/元吉/基吉/元慶/基良/
もとよししんのう /元良親王;わびぬれば いまはたおなじ 難波なる みをつくしても あはむとぞ思ふ/
もとより /元より/固より/素より/
もとりじちょう /元理事長/
もとりようしゃ /元利用者/
もとる /乖/
もどき /擬き/
もどしこうはい /戻し交配/
もどしじる /戻し汁/
もどしぜい /戻し税;drawback/
もどり /戻り/
もどりがつお /戻り鰹/
もどりさき /戻り先/
もどりち /戻り値/戻値/
もどりてがた /戻手形/戻り手形/
もどりみち /戻り道/
もなか /最中/
もにたーちょうさ /モニター調査/
もにみあか /モニミア科/Monimiaceae/
もにわ /茂庭/
もぬけ /蛻/
もぬけのから /蛻けの殻/蛻の殻/
もぬし /喪主/
もの /物/者/
もの> /物/
ものあらそい /物争い/
ものあんじ /物案じ/
ものいい /物言い/
ものいっぱん /物一般/
ものいみ /物忌み/
ものいり /物入り/
ものいれ /物入/
ものう /物憂/
ものうい /物憂い/懶い/
ものうげ /物憂げ/
ものうち /物打ち/物打/
ものうらやみ /物羨み/
ものうり /物売り/
ものお /桃生/
ものおき /物置/
ものおしみ /物惜しみ/
ものおじ /物怖じ/物怖/
ものおぢ /物怖/
ものおと /物音/
ものおぼえ /物覚え/
ものおもい /物思い/
ものかき /物書き/
ものかげ /物陰;shade/物影;shape/
ものかず /物数/
ものがたり /物語/
ものがたりじょう /物語上/
ものがたりせい /物語性/
ものがたりせかい /物語世界/
ものがたりちゅう /物語中/
ものがたりてき /物語的/
ものがたりぶんがく /物語文学/
ものがたりぶんしょう /物語文章/
ものぎわ /物際/
ものぐさ /懶/物種/物臭/
ものぐるい /物狂い/
ものごい /物乞い/物乞/
ものごころ /物心/
ものごし /物腰/物越し/
ものごと /物事/
ものさし /物差し/物指/物指し;=物差し/
ものしずか /物静か/
ものしらず /物知らず/
ものしり /物知り/物識り/
ものしりがお /物知り顔/
ものじたい /物自体/
ものずき /物好き/
ものたち /者達/
ものたりない /物足りない/
ものだね /物種/
ものづくし /物尽し/
ものづくり /物作り/
ものとり /物取り/
ものども /者共/
ものねたみ /物妬み/
もののあわれ /物の哀れ/
もののかず /物の数/
もののけ /物の怪/物怪/
もののじょうず /物の上手;達人。「好きこそ-なれ」/
もののな /物名/物の名/
もののはずみ /物の弾み/
もののふ /武士/
もののべ /物部/
もののべし /物部氏/
もののべのもりや /物部守屋/
もののほん /物の本/
もののみごと /物の見事;-にしてやられた/
ものはじめ /物始め/
ものび /物日/
ものぶそく /物不足/
ものべ /物部/
ものほけん /物保険;=ぶつほけん/
ものほし /物干し/物干/
ものほしざお /物干し竿/
ものほしだい /物干し台/物干台/
ものまえ /物前/
ものまね /物真似/物まね/
ものみ /物見/
ものみやぐら /物見櫓/
ものみゆさん /物見遊山/
ものもち /物持ち/物持/
ものもらい /物貰い/
ものわかり /物分り/物分かり/
ものわかれ /物別れ/
ものわすれ /物忘れ/
ものわらい /物笑い/
もはや /最早/
もはら /茂原/
もはん /模範/
もはんえんぎ /模範演技/
もはんえんそう /模範演奏/
もはんかいとう /模範解答/模範回答/
もはんしゅう /模範囚/
もはんじあい /模範試合/
もはんてき /模範的/
もばら /茂原/
もばらえき /茂原駅/
もひかんあたま /モヒカン頭/
もひかんがり /モヒカン刈り;Mohawk/
もふく /喪服/
もほう /模倣/
もほうがくしゅう /模倣学習/
もほうげいじゅつ /模倣芸術/
もほうせい /模倣性/
もほうせつ /模倣説/
もほん /模本/
もみ /籾;種籾/樅;もみのき/紅絹/
もみあい /揉み合い/
もみあげ /揉み上げ/
もみあらい /揉み洗い/
もみい /籾井/
もみかわ /揉み革/
もみがら /籾殻/
もみくちゃ /揉みくちゃ/
もみけし /揉み消し/もみ消し/
もみごめ /籾米/
もみじ /紅葉/楓;(かえで)/椛;国字/
もみじおろし /紅葉卸し;大根と人参/
もみじがり /紅葉狩り/紅葉狩/
もみじのが /紅葉賀/
もみじみ /紅葉見/
もみすり /籾摺り/
もみぞく /モミ属/Abies/
もみぞめ /紅染/
もみだね /籾種/
もみて /揉み手/
もみで /揉み手/
もみぬか /籾糠/
もみよね /籾米/
もめ /揉め/
もめごと /揉め事/揉事/
もめん /木綿/
もめんいと /木綿糸/
もめんおり /木綿織/
もめんどうふ /木綿豆腐/
もめんばり /木綿針/
もも /桃/股/腿;=股/百/
ももい /桃井/
ももいし /百石/
ももいろ /桃色/
ももうち /桃内/
ももえ /百恵/百枝/
ももか /百日/百夏;名/
ももかがり /百篝/
ももかわ /楊梅皮/桃皮/百川/桃川/
ももかん /桃缶/
ももき /百木/
ももくりさんねん /桃栗三年/
ももこ /桃子/
ももさき /桃崎/
ももざき /百崎/
ももじり /桃尻;-娘,-語訳 原義:乗馬がヘタ/
ももじりむすめ /桃尻娘/
ももせ /百瀬/
ももぞの /桃園/
ももぞのてんのう /桃園天皇/
ももた /百田/
ももたび /百度/
ももたろう /桃太郎/
ももたろうざむらい /桃太郎侍/
ももたろうでんせつ /桃太郎伝説/
ももたろうでんてつ /桃太郎電鉄/
ももだち /股立/
ももだに /桃谷/
ももち /百千/
ももちどり /百千鳥/
ももとせ /百歳/
ももとり /百鳥/
ももにく /もも肉/モモ肉/腿肉/
もものき /桃の木/
もものせっく /桃の節句/
ももひき /股引/
ももひめ /桃姫/
ももみみ /桃耳/
ももむら /百村/
ももや /桃屋/
ももやま /桃山/
ももやまじだい /桃山時代/
ももよ /百代/百夜/
ももわれ /桃割れ/
もや /母屋/靄/
もやいづな /舫い綱/
もやし /萌やし/
もやもやびょう /もやもや病/
もよい /催い;雪-/
もよう /模様/
もようあみ /模様編み/
もようがえ /模様替え/模様替/
もようながめ /模様眺め/
もよおし /催し/
もよおしじょう /催場/
もよおしもの /催し物/催物/
もより /最寄り/最寄/
もよりえき /最寄り駅/最寄駅/
もよりひん /最寄り品;convenience goods. 小売の分類の一/
もらいご /貰い子/
もらいじこ /貰い事故/
もらいて /貰い手;子猫の-/もらい手/
もらいなき /貰い泣き/
もらいなみだ /貰い涙/
もらいび /貰い火/
もらいもの /貰い物/
もらいゆ /貰い湯/
もり /森/杜;神社の木立ち。「神宮の-」/銛;harpoon/守/萌梨;名/盛/護/守り/漏り/盛り/
もりあい /盛合/
もりあがり /盛り上がり/
もりあき /守章/
もりあげ /盛り上げ/
もりあわせ /盛り合わせ/盛合せ/盛り合せ/
もりい /森井/
もりいで /森出/
もりうち /森内/
もりえだ /森枝/
もりお /森尾/守男/盛夫/杜夫/盛雄/守夫/森生/森男/
もりおうがい /森鴎外/
もりおか /盛岡;地名,岩手/森岡/守岡/森丘/
もりおかけいばじょう /盛岡競馬場/
もりおかし /盛岡市/
もりおかちさい /盛岡地裁/
もりかげ /森陰/森景/
もりかず /盛和/
もりかわ /森川/森河/守川/
もりがき /森垣/
もりがし /盛菓子;お供えの-/
もりき /守木/
もりきた /森北/
もりきたしゅっぱん /森北出版;[出版社名]/
もりきよ /森清;姓/
もりきり /盛切り/
もりくち /森口/
もりくら /森蔵/
もりぐち /森口/守口/
もりぐちし /守口市/
もりけい /森景/
もりさがり /盛り下がり/
もりさき /森崎/
もりさだ /森定/
もりさと /森里/
もりさわ /森沢/
もりざら /盛皿/盛り皿/
もりしげ /森重/護重/
もりした /森下/
もりしたがみ /森下紙/
もりしま /森島/森嶋/
もりしんいち /森進一/
もりじお /盛り塩/盛塩/
もりじり /森尻/
もりすえ /森末/
もりすみ /森住/
もりずな /盛砂/
もりせ /森瀬/
もりそば /盛蕎麦/
もりぞう /森蔵/
もりぞの /森園/
もりた /森田/盛田/守田/
もりたか /森高/
もりたかちさと /森高千里/
もりたざ /森田座;[歌舞伎]江戸三座の一/守田座;[歌舞伎]1856年に森田座から改称/
もりたに /森谷/守谷/
もりたりゅう /森田流;笛方/
もりたりょうほう /森田療法;[精医]Morita therapy. 心理療法の一。行動療法の側面が強い/
もりだくさん /盛り沢山/盛沢山/
もりちょう /森町/
もりつ /森津/
もりつか /杜塚;姓/
もりつぐ /森嗣/
もりつけ /盛り付け/
もりつち /盛土/盛り土/
もりつちしき /盛土式/
もりてん /森店/
もりと /森戸/
もりとう /森藤/
もりとお /盛遠/
もりとかいがん /森戸海岸/
もりとし /守利/
もりとも /守友/
もりなが /森永/
もりながじけん /森永事件/
もりながせいか /森永製菓/
もりの /森野/
もりのさと /森の里/
もりのせいかつ /森の生活;Walden, or Life in the Woods, 1854, Thoreau/
もりのぶ /森信/
もりのみや /森の宮/
もりばち /盛鉢/盛り鉢/
もりばな /盛花/盛り花/
もりばん /森番/
もりひこ /守彦/
もりひろ /守弘/護煕/
もりびと /守人/
もりぶでん /Mo/Molybdenum/
もりぶでんこう /モリブデン鋼;molybdenum steel/
もりべ /守部/森部/
もりまつ /森松/
もりまり /森茉莉;作家(1903-87) 鴎外の娘/
もりみち /守通/守倫/
もりみつ /森光/
もりむら /森村/
もりむらせいいち /森村誠一/
もりもと /森本/守本/盛本/
もりもの /盛物/盛り物/
もりや /守屋/守谷/森谷/森屋/
もりやく /守役/
もりやす /守安/森安/森保/
もりやま /森山/守山/
もりやまく /守山区/
もりゆき /森雪/
もりよし /森吉/守克/
もりらんまる /森蘭丸/
もりわか /森若/
もりわき /森脇/
もりわけ /守分/
もりん /茂林/
もるもんきょう /モルモン教/
もれ /漏れ/洩れ/
もれなく /漏れ無く;-プレゼント/漏れなく/
もろ /諸/師/
もろい /諸井;姓/
もろえ /諸江/
もろえや /諸江屋/
もろお /師尾/
もろおか /諸岡/師岡/師丘/
もろおや /諸親/両親/双親/
もろくち /諸口/
もろこ /諸子/
もろこし /蜀黍/
もろこしぶみ /唐土書/
もろこしもじ /唐土文字/
もろごい /諸恋;両思い。⇔片恋/
もろごえ /諸声/
もろさと /諸里/
もろざし /両差し;[相撲]両手を腋の下に入れる/双差し/
もろずみ /両角/諸角/双墨/
もろた /諸田/茂呂田;姓/
もろつか /諸塚/
もろて /諸手/双手/
もろとも /諸共/
もろどみ /諸富/
もろは /諸刃;諸刃の剣/両刃/
もろはし /諸橋/師橋/
もろはだ /諸肌/
もろはのつるぎ /諸刃の剣/
もろば /両刃/
もろひざ /諸膝/
もろびと /諸人/
もろびん /諸鬢/
もろほし /諸星/
もろぼし /諸星/
もろみ /醪/諸味/
もろむき /諸向き/双向き/
もろもろ /諸々/諸/諸諸/
もろや /諸矢/
もろやま /毛呂山/
もん /門;gate/問;question/紋/文/悶;悶絶/聞;(呉音)相聞歌/捫;なで・る/物;バッタ-/者;いなか-/
もんえい /門衛/
もんおり /紋織/
もんか /門下/
もんかききょろう /門下起居郎/
もんかく /門客/
もんかしょう /文科省;[略語]文部科学省/文科相;†文部科学大臣/
もんかじちゅう /門下侍中/
もんかじろう /門下侍郎/
もんかせい /門下生/
もんかろくじ /門下録事/
もんかん /文観/門鑑/
もんかんばん /紋看板/
もんがい /門外/
もんがいかん /門外漢/
もんがいふしゅつ /門外不出/
もんがく /文覚/
もんがた /門型/
もんがまえ /門構え/
もんきり /紋切り/紋切/
もんきりがた /紋切り型/紋切型/
もんく /文句/
もんくなし /文句無し/文句無/
もんげん /門限/
もんこ /門戸/
もんこかいほう /門戸開放/
もんこかいほうせいさく /門戸開放政策/
もんこく /旺角/
もんごるご /モンゴル語;モンゴルの公用語及び方言/
もんごるじん /モンゴル人/
もんごるすもう /モンゴル相撲/
もんごるずもう /モンゴル相撲/
もんごん /文言/
もんさつ /門札/
もんざい /問罪/
もんし /悶死/門歯/
もんしゅ /門主/
もんしょう /紋章/
もんしょうがく /紋章学/
もんしろちょう /紋白蝶/
もんしん /問診/
もんしんひょう /問診票/
もんじ /文字/
もんじゃやき /もんじゃ焼き/もんじゃ焼/
もんじゅ /文殊;-の知恵/文珠/
もんじゅどう /文殊堂/
もんじゅぼさつ /文殊菩薩/
もんじょ /文書/
もんじょう /文章/
もんじょかん /文書館;「ぶんしょかん」とも/
もんじょぶくろ /文書袋/
もんじん /門人/問訊/
もんせい /門生/
もんせき /問責/
もんせきけつぎ /問責決議/
もんせきけつぎあん /問責決議案/
もんせん /門扇/
もんぜき /門跡/
もんぜつ /悶絶/
もんぜん /門前/文選/問禅/
もんぜんじゃくら /門前雀羅/
もんぜんちょう /門前町/
もんぜんなかちょう /門前仲町/
もんぜんなかまち /門前仲町/
もんぜんばらい /門前払い/
もんぜんまち /門前町/
もんだい /問題/
もんだいあり /問題有/
もんだいいがい /問題以外/
もんだいいしき /問題意識/
もんだいいぜん /問題以前/
もんだいいっぱん /問題一般/
もんだいか /問題化/
もんだいかいけつ /問題解決/
もんだいかいけつほう /問題解決法/
もんだいかいけつりょく /問題解決力/
もんだいがい /問題外/
もんだいきじ /問題記事/
もんだいきじゅつ /問題記述/
もんだいくうかん /問題空間/
もんだいけい /問題系/
もんだいけいしき /問題形式/
もんだいさく /問題作/
もんだいし /問題視/問題史;一つの問題に的を絞った歴史の編纂法/
もんだいしゅう /問題集/
もんだいじ /問題児/
もんだいじこう /問題事項/
もんだいじたい /問題自体/
もんだいすう /問題数/
もんだいず /問題図/
もんだいせい /問題性/
もんだいせってい /問題設定/
もんだいたいしょう /問題対象/
もんだいていき /問題提起/
もんだいていきしゃ /問題提起者/
もんだいてん /問題点/
もんだいとうこう /問題投稿/
もんだいなし /問題無/
もんだいはっけん /問題発見/
もんだいはっせい /問題発生/
もんだいはつげん /問題発言/
もんだいひょうげん /問題表現/
もんだいぶん /問題文/
もんだいぶんせき /問題分析/
もんだいようし /問題用紙/
もんだいようやく /問題要約/
もんだいりょういき /問題領域/
もんだいれい /問題例/
もんち /門地/
もんちゃく /悶着/
もんちゅう /門柱/問中/問注/
もんちゅうじょ /問注所/
もんちょう /紋帳/
もんつき /紋付/
もんつきはかま /紋付袴/
もんてい /門弟/
もんていし /門弟子/
もんてかるろほう /モンテカルロ法/
もんでん /門田/
もんと /門徒/
もんとう /門灯/
もんとくじつろく /文徳実録;日本文徳天皇実録/
もんとくてんのう /文徳天皇/
もんど /主水/門戸/
もんどう /問答/
もんどうけいしき /問答形式/
もんどうしゅう /問答集/
もんどうへん /問答篇/
もんどうほう /問答法;ソクラテス/
もんどうむよう /問答無用/
もんどころ /紋所/
もんどり /翻筋斗/
もんな /門奈/
もんない /門内/
もんなし /文無し/
もんの /門野/
もんはぶたえ /紋羽二重/
もんばつ /門閥/
もんばやし /門林/
もんばん /門番/
もんぱ /門派/
もんび /紋日/
もんぴ /門扉/
もんぴょう /門標/
もんぶ /文部/
もんぶかがく /文部科学/
もんぶかがくしょう /文部科学省;文部省と科学技術庁が2001年1月の中央省庁再編で再編されたもの/
もんぶかがくだいじん /文部科学大臣/
もんぶかんりょう /文部官僚/
もんぶきょうかん /文部教官/
もんぶしょう /文部省;NB:2001年1月の中央省庁再編で文部科学省に再編された/
もんぶしょうかんかつ /文部省管轄/
もんぶしょうけんてい /文部省検定/
もんぶしょうしょうか /文部省唱歌/
もんぶだいじん /文部大臣/
もんぷく /紋服/
もんべつ /門別/紋別;地名/
もんべつえき /紋別駅/
もんぼうしょ /紋奉書/
もんま /門真/門馬/
もんみゃく /門脈/
もんむてんのう /文武天皇/
もんめ /匁/問目/
もんもう /文盲/
もんもうしゃ /文盲者/
もんもん /悶々/悶悶/
もんよう /文様/紋様/
もんりゅう /門柳/
もんろーしゅぎ /モンロー主義/
や /矢/屋/家/夜/野/也/哉/輻;spoke/弥;弥生/彌;「弥」の旧字(人名用漢字)/冶;冶金/八/谷/笶;竹の矢/埜;「野」の旧字(人名用漢字)/耶;耶蘇/揶;揶揄/椰;椰子/爺;老爺/↑;→やじるし/↓/→/←/⇒/⇔/
やー /Я/
やーど /碼;91.44cm/
やーどぽんどほう /ヤードポンド法;Imperial system/
やいごめ /焼米/
やいた /矢板/
やいだ /矢井田;姓/
やいづ /焼津/
やいづえきまえ /焼津駅前/
やいづちゅうおう /焼津中央/
やいと /灸/
やいば /刃/
やいん /夜陰/
やうち /家内/矢内/
やえ /八重/
やえい /野営;†/夜営;†/
やえいじょう /野営場/
やえいずみ /八重泉/
やえがき /八重垣/
やえがし /八重樫/
やえがすみ /八重霞/
やえこ /八重子/彌生子/
やえざき /八重咲き;[植物]double. ⇔一重咲き/
やえざくら /八重桜/
やえす /八重洲/
やえすがわ /八重洲側/
やえすぐち /八重洲口/
やえすしゅっぱん /八重洲出版;[出版社名]/
やえすちかがい /八重洲地下街/
やえすみなみぐち /八重洲南口/
やえすむせん /八重洲無線/
やえば /八重歯/
やえむぐら /八重葎/
やえやま /八重山/
やえん /野猿/夜宴/
やお /八尾/八百/矢尾/
やおい /矢追/
やおいた /矢尾板/
やおき /八起/
やおぎ /八尾木;地名/
やおくうこう /八尾空港/
やおくめ /八百粂/
やおし /八尾市/
やおちょう /八百長/
やおつ /八百津/
やおとめ /八乙女/
やおはら /八百原/
やおはん /八百半/
やおもて /矢面/
やおや /八百屋/
やおやおしち /八百屋お七/
やおよろず /八百万/
やおよろずのかみ /八百万の神/
やおら /徐ら;slowly/
やおん /野音/
やか /宅;[文語]屋敷/野火;のび/野花;のばな/夜火/八日;[古語]/
やかい /夜会/
やかいふく /夜会服/
やかいまき /夜会巻き/
やかく /野鶴/夜鶴/
やかけちょう /矢掛町/
やかげ /矢掛/
やかず /家数/矢数/
やかずはいかい /矢数俳諧/
やかぜ /矢風/
やかた /館/屋形/舘;「館」の異体字/
やかたぶね /屋形船/屋形舟/
やかたまち /屋形町/
やかべ /宅部/家部/
やかもち /家持;大伴家持/
やから /輩/族/
やかん /夜間/薬缶/野干/薬罐/薬鑵/
やかん> /夜間;-作業,-工事/
やかんがっこう /夜間学校/
やかんきゅうきゅう /夜間救急/
やかんそうこう /夜間走行/
やかんたい /夜間帯/
やかんだいがくいん /夜間大学院/
やかんちゅうがく /夜間中学/
やかんでんりょく /夜間電力/
やかんとうせき /夜間透析/
やかんひこう /夜間飛行/
やかんぶ /夜間部/
やかんほいくしょ /夜間保育所/
やが /屋我/
やがい /野外/屋外;※「おくがい」の誤り/
やがいかつどう /野外活動/
やがいげき /野外劇/
やがいさつえい /野外撮影/
やがいよう /野外用/
やがいりょうり /野外料理/
やがく /夜学/
やがけ /矢掛/
やがすり /矢絣/
やがっこう /夜学校/
やがて /軈て/軈/軅;「軈」の異体字/
やがみ /八神/矢上/
やがも /矢鴨/
やがわ /矢川/
やがわら /谷川原/
やき /夜気/焼き/焼/八寸;馬の大きさ/燒;「焼」の旧字(人名用漢字)/
やきあみ /焼き網/焼網/
やきいも /焼き芋/焼芋/
やきいれ /焼入れ/焼き入れ/
やきいろ /焼き色;おいしそうな-/
やきいん /焼印/焼き印/
やきうち /焼き討ち/焼討ち/
やきうどん /焼き饂飩/焼うどん/
やきえ /焼き絵/焼絵/
やきかた /焼き方/
やきがし /焼き菓子/焼菓子/
やきぎょうざ /焼き餃子/焼餃子/
やきぐし /焼き串/焼串/
やきぐり /焼き栗/燒栗;旧字/
やきこ /焼粉;grog/
やきごて /焼き鏝/焼鏝/
やきざかな /焼き魚/焼魚/
やきしお /焼き塩/焼塩/
やきしめ /焼き締め/焼締め/
やきじゃけ /焼き鮭/
やきすぎ /焼杉;木目を強調/焼き杉/
やきず /矢傷/
やきそば /焼きそば/焼き蕎麦/焼そば/
やきたて /焼き立て;-のほっかほか/
やきつけ /焼付/焼き付け/焼付け/
やきつち /焼き土/焼土;[園芸]土を焼いて殺菌すること/
やきとり /焼き鳥/焼鳥/
やきとりや /焼き鳥屋/焼鳥屋/
やきどうふ /焼き豆腐/焼豆腐/
やきなおし /焼き直し/焼直し/
やきなす /焼き茄子/
やきなまし /焼き鈍し/焼鈍し/
やきにく /焼き肉/焼肉/
やきにくていしょく /焼肉定食/
やきにくてん /焼肉店/
やきにくや /焼肉屋/
やきにくよう /焼肉用/
やきのり /焼き海苔/
やきはた /焼畑/焼き畑;-農業/
やきはたのうぎょう /焼畑農業/
やきはまぐり /焼き蛤/焼蛤/
やきば /焼き刃;やいば/焼き場;火葬場/焼場/焼刃/
やきびーふん /焼ビーフン/
やきびたい /焼額/
やきびたいやま /焼額山/
やきふ /焼麩/
やきぶた /焼豚/焼き豚/
やきまし /焼き増し/焼増し/焼増/
やきみそ /焼き味噌/焼味噌/
やきみょうばん /焼明礬/
やきめ /焼き目;-をつける/焼目/
やきめし /焼き飯/焼飯/
やきもち /焼き餅/焼餅/
やきもちやき /焼き餅焼き/
やきもどし /焼戻し/焼き戻し/
やきもの /焼き物/焼物/
やきものし /焼物師/焼き物師/
やきやぶり /焼き破り;[新語]火で開錠する泥棒さん/
やきゅう /野球/
やきゅうおうこく /野球王国/
やきゅうかい /野球界/
やきゅうかん /野球観/
やきゅうかんけいしゃ /野球関係者/
やきゅうかんせん /野球観戦/
やきゅうかんれん /野球関連/
やきゅうきこう /野球機構/
やきゅうきゅうだん /野球球団/
やきゅうきょう /野球狂/
やきゅうきょうやく /野球協約/
やきゅうけん /野球拳;ジャンケンで負けた者が服を一枚ずつ脱ぐ遊び/
やきゅうこぞう /野球小僧/
やきゅうしあい /野球試合/
やきゅうしょうねん /野球少年/
やきゅうじっきょう /野球実況/
やきゅうじょう /野球場/
やきゅうじん /野球人/
やきゅうずき /野球好き/
やきゅうせんしゅ /野球選手/
やきゅうたいかい /野球大会/
やきゅうだん /野球団/
やきゅうちゅうけい /野球中継/
やきゅうちゅうけいえんちょう /野球中継延長/
やきゅうつう /野球通/
やきゅうでんどう /野球殿堂;the Hall of Fame/
やきゅうぶ /野球部/
やきゅうぶいん /野球部員/
やきゅうほんらい /野球本来/
やきゅうまんが /野球漫画/
やきゅうようご /野球用語/
やきゅうようひん /野球用品/
やきょうしょう /夜驚症;[医]/
やきょく /夜曲/
やきりんご /焼きリンゴ/焼き林檎/焼林檎/
やきん /夜勤/冶金/野禽/
やきんがく /冶金学/
やきんこうぎょう /冶金工業/
やきんじゅつ /冶金術/
やぎ /山羊/八木/柳/
やぎがわ /山羊革/
やぎさわ /八木沢;姓/
やぎざ /山羊座;Capricornus(Cap),(12.22-1.19)/
やぎた /八木田/
やぎぬま /八木沼/
やぎはし /八木橋/
やぎぶし /八木節;[民謡]群馬/
やぎやま /八木山/
やぎゅう /柳生/野牛/
やぎゅういちぞく /柳生一族/
やぎゅうさんだい /柳生三代/
やぎゅうじゅうべえ /柳生十兵衛/
やぎゅうばし /柳生橋/
やぎょう /夜行;夜の行動/夜業;夜の仕事/ヤ行/や行/
やぎり /矢切/
やく /約/役/訳/薬/厄/葯;[植物]anther/屋久;-島/夜久;人名/龠;(ふえ)/籥;(ふえ)/鑰;かぎ/疫;疫病神/躍;躍動/益;利益/扼;扼殺/蜴;(呉音) 蜥蜴/繹;(呉音) 演繹(えんえき)/譯;「訳」の旧字/藥;「薬」の旧字(人名用漢字)/焼/檪;くぬぎ,いちい,?/≒;=:/
やく#ねんまえ /約#3年前/
やく> /約/
やくあり /訳有/
やくい /薬医/
やくいちにち /約一日/
やくいちめい /約一名/
やくいん /役員/薬院/役印/約因/
やくいんかい /役員会/
やくいんしつ /役員室/
やくいんしょうよ /役員賞与/
やくいんだん /役員団/
やくいんほうしゅう /役員報酬/
やくえき /薬液/
やくえん /薬園/
やくおとし /厄落とし/厄落し/
やくおん /約音/
やくかい /訳解/
やくがい /薬害/
やくがいきょういく /薬害教育/
やくがえ /役替え/
やくがく /薬学/
やくがくぶ /薬学部/
やくがら /役柄/
やくぎ /役儀/訳義/
やくぎょう /訳業/
やくぎょうじほうしゃ /薬業時報社;[出版社名]/
やくげん /約言/
やくこう /訳稿/
やくご /訳語/
やくごめん /役御免/
やくさい /厄災/訳載/薬菜/
やくさつ /薬殺;毒殺/扼殺;絞殺/
やくざい /薬剤/
やくざいし /薬剤師/
やくざいしめんきょ /薬剤師免許/
やくざもの /やくざ者/ヤクザ者/
やくし /薬師;-如来/訳詞;verse/訳詩;poem/薬司;くすりのつかさ/
やくしじ /薬師寺/
やくしだけ /薬師岳/
やくしつ /薬室/
やくしどう /薬師堂/
やくしにょらい /薬師如来/
やくしま /屋久島/
やくしまる /薬師丸/
やくしまるひろこ /薬師丸ひろ子/
やくしゃ /役者;actor/訳者;translator/
やくしゃえ /役者絵/
やくしゃたち /役者達/
やくしゃちゅう /訳者注/
やくしゃばか /役者馬鹿/
やくしゃろんご /役者論語/
やくしゅ /薬酒/薬種/
やくしゅしょう /薬種商/
やくしゅつ /訳出/
やくしゅや /薬種屋/
やくしょ /役所/訳書/
やくしょかん /役所間/
やくしょく /役職/
やくしょくめい /役職名/
やくしょしごと /役所仕事/
やくしん /躍進/薬疹/
やくじ /薬事/薬餌/
やくじほう /薬事法/
やくじほういはん /薬事法違反/
やくじゅつ /訳述/
やくじょ /躍如/
やくじょう /約定/
やくじょうしょ /約定書/
やくじょうりそく /約定利息/
やくじょうりりつ /約定利率/
やくじん /厄神/疫神/
やくすう /約数/
やくすぎ /屋久杉/
やくずもう /役相撲/
やくせき /薬石/
やくぜん /薬膳/
やくぜんりょうり /薬膳料理/
やくそう /薬草/躍層/役僧/
やくそうがく /薬草学/
やくそく /約束/
やくそくごと /約束事/
やくそくてがた /約束手形/
やくたい /薬袋;medicine bag/益体/
やくたく /役宅/
やくたたず /役立たず/
やくだい /薬代/
やくだく /約諾/
やくちゅう /訳注/訳註/薬中/
やくづき /役付/役付き/
やくづくり /役作り/
やくて /約手/
やくてい /約定/
やくてん /薬店/約転;contraction/
やくとう /薬湯/
やくとく /役得/
やくどう /躍動/
やくどうかん /躍動感/
やくどく /訳読/薬毒/役得;やくとく/
やくどころ /役所/
やくどし /厄年/
やくなし /訳無/
やくなん /厄難/
やくなんこ /約何個/
やくにん /役人/
やくにんこんじょう /役人根性/
やくにんさま /役人様/
やくにんたち /役人達/
やくの /夜久野/
やくはらい /厄払い/
やくはんがく /約半額/
やくはんすう /約半数/
やくはんとし /約半年/
やくはんとしまえ /約半年前/
やくはんね /約半値/
やくはんぶん /約半分/
やくば /役場/
やくばらい /厄払い/
やくひつ /訳筆/
やくひん /薬品/
やくひんしゅう /薬品臭/
やくひんじょうほう /薬品情報/
やくび /厄日/
やくびょう /疫病/
やくびょうがみ /疫病神/厄病神/
やくぶそく /役不足;⇔力不足, 軽すぎて能力を発揮できない役目/
やくぶつ /薬物/
やくぶついぞんしょう /薬物依存症/
やくぶつしょじ /薬物所持/
やくぶつちゅうどく /薬物中毒/
やくぶつはんのう /薬物反応/
やくぶつらんよう /薬物濫用/薬物乱用/
やくぶつりょうほう /薬物療法;[精医]⇔精神療法/
やくぶん /訳文/約分/
やくへん /訳編/
やくほう /薬方;薬の調合/薬包;薬の包み/
やくほうし /薬包紙/
やくほん /訳本/
やくぼ /矢久保/
やくまる /薬丸/
やくまわり /役回り/
やくまん /役満;[麻雀]/
やくまんがん /役満貫;[麻雀]/
やくまんれき /役満歴;[麻雀]/
やくみ /薬味/
やくみけい /薬味系/
やくみざら /薬味皿/
やくむき /役向き/
やくめ /役目/
やくめい /役名/
やくも /八雲/
やくもがくえん /八雲学園/
やくもの /役物/約物;†句読点や括弧などの記号類/
やくゆ /薬湯/
やくよう /薬用/
やくようせっけん /薬用石鹸/
やくよけ /厄除け/厄除/
やくり /薬理/
やくりがく /薬理学/
やくりきし /役力士/
やくりさよう /薬理作用/
やくりょう /薬料/
やくれい /訳例/
やくれき /薬歴/
やくろう /薬籠/
やくろうちゅう /薬籠中/
やくろん /約論/
やくわり /役割/
やくわりいっぱん /役割一般/
やくわりえんぎ /役割演技/
やくわりぶんたん /役割分担/
やくわん /扼腕/
やぐ /夜具/
やぐち /矢口/谷口/
やぐちのわたし /矢口渡/
やぐら /櫓/矢倉/
やぐらだいこ /櫓太鼓;[相撲]/
やぐらなげ /櫓投げ/
やぐらもん /櫓門/
やぐるま /矢車/
やぐるまぎく /矢車菊/
やぐるまそう /矢車草/
やけ /自棄/焼け/
やけあと /焼け跡/焼跡/
やけい /夜景/夜警/野鶏/
やけいこっか /夜警国家/
やけいし /焼け石/
やけくそ /自棄糞/
やけこげ /焼け焦げ/
やけざけ /自棄酒/やけ酒/ヤケ酒/焼け酒/
やけだけ /焼岳/
やけだされ /焼け出され/
やけっぱち /自棄っぱち/
やけど /火傷/
やけどじょうたい /火傷状態/
やけの /焼野/
やけのはら /焼け野原/焼野原/
やけひばし /焼け火箸/
やけびたい /焼額/
やけびたいさん /焼額山/
やけぶとり /焼け太り/
やけぼっくい /焼け棒杭/焼けぼっくい/
やけやま /焼山/焼け山/
やけん /野犬/
やげん /薬研/
やげんぼり /薬研堀/
やこ /野狐/
やこう /夜行;†nocturnal.「-列車」/夜光;†noctilucent.「-の杯」/矢向/夜香/八高/
やこうかいそく /夜行快速/
やこうきゅうこう /夜行急行/
やこうこうそく /夜行高速/
やこうしんだい /夜行寝台/
やこうしんだいれっしゃ /夜行寝台列車/
やこうせい /夜行性;nocturnal/夜光性;?/
やこうちゅう /夜光虫;noctiluca/夜行虫;?/
やこうちょうきょり /夜行長距離/
やこうとっきゅう /夜行特急/
やこうとりょう /夜光塗料/
やこうどけい /夜光時計/
やこうのはい /夜光の杯/
やこうばす /夜行バス/
やこうびん /夜行便/
やこうぼく /夜香木/
やこうれっしゃ /夜行列車/
やこぜん /野狐禅/
やこびぎょうれつ /ヤコビ行列/
やこぶびょう /ヤコブ病/
やご /野語/
やごう /屋号/野合/
やごえ /矢声/
やごし /矢越/
やごと /八事/
やさい /野菜/
やさいいため /野菜炒め/
やさいいちば /野菜市場/
やさいうりば /野菜売場/
やさいくず /野菜屑/
やさいさらだ /野菜サラダ/
やさいしつ /野菜室/
やさいじゅーす /野菜ジュース/
やさいすーぷ /野菜スープ/
やさいぞえ /野菜添え/
やさいづくり /野菜作り/
やさいばたけ /野菜畑/
やさいもの /野菜物/
やさいりょうり /野菜料理/
やさいるい /野菜類/
やさおとこ /優男/
やさか /八坂/弥栄/八尺/
やさかじんじゃ /八坂神社/
やさかに /八尺瓊/
やさかにのまがたま /八尺瓊勾玉;三種の神器/
やさかりゅう /八坂流/屋坂流/
やさがし /家捜し/
やさがた /優形/
やさき /矢先/
やさく /矢作/
やさすがた /優姿/
やさと /八郷/
やざ /矢座;Sagitta(Sge)/
やざき /矢崎/
やざわ /矢沢/矢澤/谷沢/
やし /椰子/香具師/椰/野史/弥四/野師/
やしお /八潮/八入/
やしか /椰子科;[植物]palmaceae/ヤシ科/
やしがに /椰子蟹/
やしき /屋敷/邸/廛/屋輔/壥/矢輔/
やしきあと /屋敷跡/
やしきうち /屋敷内/
やしきまち /屋敷町/
やしち /弥七/
やしないおや /養い親/
やしのみ /椰子の実/
やしま /八島/屋島/八洲/矢島/
やしまくに /八洲国;地名/
やしまでら /屋島寺/
やしもく /ヤシ目/Aracales/Palmales/Principes/
やしもくぐん /ヤシ目群/
やしゃ /夜叉/
やしゃご /玄孫/
やしゅ /野手/野趣/
やしゅう /夜襲/野州;下野(しもつけ,栃木)/
やしゅじん /野手陣/
やしゅせんたく /野手選択;(野球)フィルダースチョイス/
やしょく /夜食/夜色/
やしょくしょうこうぐん /夜食症候群/
やしろ /社/八代/屋代/矢代/安城/
やしわご /玄孫/
やしん /野心/
やしんか /野心家/
やしんさく /野心作/
やしんてき /野心的/
やじ /野次/弥次;-喜多/
やじうま /野次馬/弥次馬/
やじうまてききょうみ /野次馬的興味/
やじきた /弥次喜多/
やじきたどうちゅう /弥次喜多道中/
やじま /矢島/矢嶋/八島/谷島/
やじまや /谷島屋/
やじゅう /野獣/
やじゅうは /野獸派/野獣派;[美術] fauvisme(Fr)/
やじり /鏃/矢尻/
やじるし /矢印/↑;うえや/↓;したや/→;みぎや/←;ひだりや/⇒;=>/⇔;<=>,equiv/
やじるしきー /矢印キー/
やじるししんごう /矢印信号/
やじるしほうこう /矢印方向/
やじろべい /弥次郎兵衛/
やじろべえ /弥次郎兵衛/
やじん /野人/
やす /安/野洲;地名/夜須;地名/保/康/泰/裕/靖/恭/
やす> /安;安月給,安普請,安アパート/
やすあがり /安上り/
やすあき /康明/保昭/泰昭/恭章/
やすい /安井/保井/靖/
やすいけ /安池/
やすいちろう /靖一郎/
やすうけあい /安請け合い/安請合い/
やすうら /安浦/
やすうり /安売り/安売/
やすえ /安江;姓/康恵;名/保江;名/安恵;名/
やすお /康夫/康雄/康男/靖夫/保夫/泰雄/保雄/泰夫/安雄/康生/靖雄/泰男/保男/泰生/安男/寿男/八洲男/裕雄/保生/恭朗/弥寿夫/
やすおか /安岡/泰阜/
やすかが /安加賀/
やすかず /康一/保一/保和/
やすかた /安方/
やすかわ /安川/安可愛/
やすかわでんき /安川電機;[企業名]/
やすき /泰樹/安樹/靖己/康己/易き;――に流れる/
やすきよ /安挙/
やすぎ /安来/八杉/
やすぎぶし /安来節;[民謡]島根。泥鰌掬い/
やすくに /靖国/安国/
やすくにじんじゃ /靖国神社/
やすくにじんじゃさんぱい /靖国神社参拝/
やすくにどおり /靖国通り/
やすけ /弥助/
やすげ /安げ/
やすげっきゅう /安月給/
やすこ /靖子/康子/恭子/泰子/安子/妥子/
やすさ /安さ/
やすさだ /保貞/
やすさと /安里/
やすざか /安坂/
やすざけ /安酒/
やすし /安/靖/康/保/泰/寧/康史/泰司/也寸志/尉/靖史/泰士/靖志/保司/廉史/
やすしば /安柴/
やすじ /康二/康司/康次/康嗣/
やすじろう /安二郎/
やすたか /康隆/泰隆/泰孝/泰宇/泰臣/
やすたけ /安武/康剛/
やすたに /保谷/
やすたみ /康民/
やすだ /安田/保田/
やすだかさい /安田火災/
やすだきねん /安田記念/
やすだきねんば /安田記念馬/
やすだこうどう /安田講堂/
やすだなるみ /安田成美/
やすづか /安塚/
やすて /野ステ/
やすてつ /康哲/
やすで /安手/
やすと /靖人/保人/
やすとし /康俊/泰稔/康敏/
やすとみ /安富/
やすとめ /安留/
やすとも /康友/
やすな /保名/
やすなお /康尚/
やすなが /安永/康永/保永/
やすなり /康成/康也/
やすね /安値/
やすねびけ /安値引け;[相場]/
やすの /安野/
やすのう /安納/
やすのぶ /泰信/保信/恭伸/
やすのり /安則/泰典/保典/泰則/康則/康徳/保則/保憲/保徳/泰憲/靖則/安紀/保法/靖教/
やすは /泰葉/
やすはら /安原/保原/
やすはる /康晴/康治/泰治/泰晴/
やすひこ /康彦/泰彦/靖彦/安彦/
やすひさ /恭久/靖久/
やすひで /保秀/
やすひと /康仁/保人/
やすひろ /康弘/泰弘/康博/康裕/康宏/泰宏/安弘/恭弘/康浩/康広/靖弘/泰広/靖浩/保博/靖宏/泰寛/恭裕/安浩/保浩/保広/靖太/
やすぴか /安ぴか/
やすふみ /康文/泰史/康史/
やすぶしん /安普請/
やすぶみ /康文/
やすまさ /泰正/康正/康雅/
やすまつ /安松/
やすみ /休み/休/保美/
やすみあけ /休み明け/
やすみじかん /休み時間/
やすみち /易道/
やすみちゅう /休み中/
やすみぢゃや /休み茶屋/
やすみつ /康光/康満/
やすみやすみ /休み休み;-言え/
やすむら /安村/
やすめ /安目;-で上がる/安め/
やすもと /安本/
やすもの /安物/
やすものかい /安物買い/
やすものがい /安物買い/
やすや /恭也/
やすやす /易々/
やすやど /安宿/
やすゆき /康之/泰之/靖之/康幸/康行/泰幸/靖幸/保之/恭之/育志/
やすよ /康代/安代/靖代/康世/
やすよし /康義/安吉/康良/康善/靖佳/
やすら /安良/安ら/
やすらい /安らい/休らい;=安らい/
やすらか /安らか/
やすらぎ /安らぎ/
やすり /鑢/
やすろう /康朗/恭郎/
やず /谷津/
やずぎ /八杉/
やせ /八瀬/
やせい /野生;†自然に生育すること。「-[動植]物」/野性;†自然のままの(荒々しい)性質。「-的」「-化」/
やせいか /野性化/
やせいしゅ /野生種/
やせいじ /野生児/野性児/
やせいじだい /野性時代/野生時代/
やせいてき /野性的/
やせいどうぶつ /野生動物/
やせいみ /野性味/野生味;?/
やせうで /痩せ腕/
やせうま /痩せ馬/
やせおとこ /痩せ男/
やせおんな /痩せ女/
やせがた /やせ型/痩せ形/
やせがまん /痩せ我慢/
やせぎす /痩せぎす/
やせぐすり /痩せ薬/
やせち /痩せ地/
やせっぽち /痩せっぽち/
やせつ /夜雪/
やせん /野戦;open battle/夜戦;night battle/野選;[野球]fielder's choice/
やせんぐん /野戦軍/
やせんこうじょう /野戦攻城/
やせんびょういん /野戦病院;field hospital/
やぜん /夜前/
やそ /耶蘇/八十/
やそう /野草/夜走/
やそうえん /野草園/
やそうきょく /夜想曲/
やそかい /耶蘇会/
やそかわ /八十川/
やそきょう /耶蘇教/
やそしま /八十島/
やそじ /八十路/八十/
やそすけ /八十助/
やそよろず /八十万/
やぞう /弥蔵/
やた /八咫/矢田/箭田;地名 人名 姓/
やたい /屋台/
やたいぼね /屋台骨/
やたいむら /屋台村/
やたがい /矢田貝/
やたがらす /八咫烏/八咫鴉/
やたけび /矢叫び;「あたーりー」/
やたて /矢立/
やたでら /矢田寺/
やたのかがみ /八咫鏡/
やたべ /谷田部/矢田部/
やたま /矢玉/
やたやま /矢田山/
やたら /矢鱈;当て字/
やたろう /弥太郎/
やだ /矢田/
やだいく /家大工/
やだけ /矢竹/
やだね /矢種/
やだま /矢玉/矢弾/
やち /谷地/屋地/萢/
やちた /谷地田/
やちだ /谷内田/谷地田/
やちほ /八千穂/
やちまた /八街;地名/八衢/
やちまたし /八街市/
やちゅう /夜中/
やちょ /野猪/
やちょう /野鳥/野帳/夜鳥/
やちよ /八千代/
やちよし /八千代市/
やちよだい /八千代台/
やちよばし /八千代橋/
やちん /家賃/屋賃;<rare> =家賃 ‖「知らん顔して-ばかり取り立てにくる」『吾輩は猫である』/
やちんしゅうにゅう /家賃収入/
やちんほじょ /家賃補助/
やっか /薬科/薬価/薬禍/
やっかい /厄介/訳解/
やっかいごと /厄介事/
やっかいばらい /厄介払い/
やっかいもの /厄介者/
やっかきじゅん /薬価基準/
やっかさえき /薬価差益/
やっかだい /薬科大/
やっかだいがく /薬科大学/
やっかん /約款/
やっき /躍起/
やっきょう /薬莢/
やっきょく /薬局/
やっきょくほう /薬局方/
やっこ /奴/
やっこう /薬効/
やっこうはつげん /薬効発現/
やっこそうか /ヤッコソウ科/Rafflesiaceae/
やっこそうもく /ヤッコソウ目/Rafflesiales/
やっこどうふ /奴豆腐/
やっつ /八つ/
やっつけしごと /遣っ付け仕事/
やっと /漸と/
やっとこ /鋏/
やっぱり /矢つ張り/
やつ /奴/谷/八つ/八/谷津/
やつあたり /八つ当たり/八つ当り/
やつお /八尾/
やつおり /八つ折り/
やつか /八束/
やつかほ /八束穂/
やつがしら /八頭;里芋の一種/
やつがたけ /八ヶ岳/
やつがだけ /八ヶ岳/八岳/
やつがれ /僕/
やつぎ /矢継/
やつぎばや /矢継ぎ早/
やつくち /八口/
やつざき /八つ裂き/
やつしろ /八代/
やつだ /谷津田/
やつだま /八玉/
やつで /八手/
やつはし /八橋/八つ橋/八ツ橋/
やつはしけんぎょう /八橋検校;(1614-1685) 箏曲家。『六段の調べ』/
やつばら /奴原/
やつめ /八つ目/
やつめうなぎ /八目鰻/鱧/
やつもり /八ッ森/
やつゆうえん /谷津遊園/
やつら /奴等/奴ら/
やつわり /八つ割り/
やづくり /家作り/
やづつ /矢筒/
やてん /夜天/
やと /野兎/
やとい /雇/
やといにん /雇人/雇い人;employee/
やといぬし /雇い主/雇主/
やとう /野党/野盗;bandit/夜盗;burglar/
やとうがわ /野党側/
やとうむし /夜盗虫/
やとびょう /野兎病/
やとみ /弥富/
やとわれ /雇われ/
やど /宿/
やどいり /宿入り/
やどかり /宿借り/寄居虫/寄居蟲/
やどがえ /宿替え/
やどさがり /宿下がり/
やどじょうほう /宿情報/
やどせん /宿銭/
やどだい /宿代/
やどちょう /宿帳/
やどちん /宿賃/
やどなし /宿無し/
やどぬし /宿主/
やどひき /宿引き/
やどや /宿屋/
やどりき /宿木/
やどりぎ /宿り木/宿木/寄生木/
やどろく /宿六/
やどわり /宿割り/
やな /簗/梁;=簗 NB:「はり」とも/
やない /柳井/屋内/矢内/箭内/
やないづ /柳津/
やないはら /矢内原/
やないば /柳葉;鏃の一種/
やなお /柳尾/
やなか /谷中/
やながわ /柳川/梁川/
やながわしない /柳川市内/
やながわなべ /柳川鍋/
やなぎ /柳/
やなぎいろ /柳色/
やなぎごし /柳腰/
やなぎさわ /柳沢/柳澤/
やなぎさわえき /柳沢駅/
やなぎしま /柳島/
やなぎた /柳田/
やなぎたくにお /柳田国男;(1875-1962)民俗学者。『遠野物語』/
やなぎたに /柳谷/
やなぎだ /柳田/
やなぎだる /柳多留;(1765-1838) 川柳集/柳樽/
やなぎちょう /柳町/
やなぎはら /柳原/
やなぎば /柳葉/柳刃/
やなぎばし /柳橋/
やなぎばとしろう /柳葉敏郎/
やなぎぼり /柳堀/
やなぎまち /柳町/
やなぎもく /ヤナギ目/Salicales/
やなぎもくあぐん /ヤナギ目亜群/
やなぎもと /柳本/
やなぎや /柳家/柳谷/
やなざき /柳崎/
やなせ /柳瀬/梁瀬/
やなだ /梁田/
やなだに /柳谷/
やなつ /柳津/
やなとり /梁取/
やなはら /柵原/
やなば /簗塲/
やなみ /家並み/家並/八並;姓/
やなり /家鳴り/
やなる /矢鳴/
やに /脂/
やにょうしょう /夜尿症/
やにわ /矢場/矢庭/
やにわに /矢庭に;suddenly/
やぬし /家主/
やね /屋根/
やねいた /屋根板/
やねうま /屋根馬/
やねうら /屋根裏/
やねうらべや /屋根裏部屋/
やねがた /屋根型/
やねこうばい /屋根勾配/
やねごし /屋根越し/
やねざい /屋根材/
やねした /屋根下/
やねじょう /屋根上/
やねづけ /屋根付/
やねゆき /屋根雪/
やの /矢野/
やのあきこ /矢野顕子/
やのくら /矢野倉/
やのぐち /矢野口/
やのはら /矢箆原/
やはぎ /矢作/矢矧/八萩/
やはく /夜泊/
やはず /矢筈/
やはた /八幡/
やはたし /八幡市/
やはたしえき /八幡市駅/
やはたしょてん /八幡書店/
やはたせいてつじょ /八幡製鉄所;地名,福岡県にある大規模な製鉄所/
やはたにし /八幡西/
やはたの /八幡野/
やはたひがし /八幡東/
やはたやま /八幡山/
やはば /矢巾/
やはり /矢張り/
やはん /夜半/
やはんまえ /夜半前/
やはんらく /夜半楽/
やば /矢場/野馬/
やばい /野梅/
やばけい /耶馬渓/
やばせ /矢橋/
やばとん /矢場とん/
やばね /矢羽/矢羽根/
やばん /野蛮/
やばんじん /野蛮人/
やひ /野卑/野鄙/
やひこ /弥彦/
やひこざわ /矢彦沢;姓/
やひこせん /弥彦線/
やひろ /八尋/
やぶ /藪/薮;異体字/
やぶいり /藪入り/
やぶうち /薮内/
やぶか /薮蚊/
やぶからぼう /薮から棒;「藪」異体字/
やぶがみ /薮上/
やぶき /矢吹/
やぶきた /藪北/
やぶさか /吝か/
やぶさめ /流鏑馬;騎射(きしゃ)の一種/薮雨;[鳥]シオサザイ、カワリウグイス/薮鮫;[鳥]=薮雨/
やぶさわ /薮沢/
やぶすま /矢衾/
やぶそば /薮蕎麦/
やぶた /藪田/
やぶだたみ /藪畳/
やぶにらみ /藪睨み/
やぶのなか /藪の中;真相は-/
やぶはら /薮原/
やぶへび /薮蛇/
やぶみ /矢文/
やぶもと /薮本/藪本/
やぶれかぶれ /破れかぶれ/
やぶれしょうじ /破れ障子/
やぶれめ /破れ目/
やぶん /夜分/
やべ /矢部/
やべせん /矢部線/
やほ /谷保/屋舗/
やほう /野砲/
やほうず /野放図/
やほこ /八穂子/
やほち /夜発/
やほり /矢堀/
やぼ /野暮/
やぼう /野望/
やぼてん /野暮天/
やぼよう /野暮用/ヤボ用/
やま /山/耶麻/夜魔/夜摩/岾/
やまあい /山間/山合/
やまあし /山足/
やまあそび /山遊び/
やまあらし /山嵐/
やまあるき /山歩き/
やまい /病/山井/
やまいこうこう /病膏肓/
やまいし /山石/
やまいち /山一證券/
やまいちしょうけん /山一證券/
やまいぬ /山犬/豺/犲;「豺」の異体字/病犬/
やまいも /山芋/薯蕷/
やまいもあめ /山芋飴/
やまうち /山内/
やまうば /山姥/
やまうら /山浦/
やまえ /山江/
やまお /山尾/
やまおか /山岡/
やまおかてっしゅう /山岡鉄舟;(1836-88) 政治家/
やまおき /山沖/
やまおく /山奥/
やまおとこ /山男/
やまおり /山折り/
やまおんな /山女/
やまかい /山峡/
やまかけ /山掛け/
やまかげ /山陰/山影/
やまかさ /山笠/
やまかじ /山火事/
やまかぜ /山風/
やまかっこ /山括弧/〈/〉/《/》;二重山括弧/
やまかみ /山上/
やまかわ /山川/
やまかわしゅっぱんしゃ /山川出版社;[出版社名]/
やまかん /山勘/
やまかんむり /山冠/
やまが /山鹿/山家/山香/山賀/
やまがさ /山笠/
やまがた /山形/山県/山方/山縣/山型/
やまがたありとも /山県有朋/
やまがたえき /山形駅/
やまがたかん /山形間/
やまがたがわ /山形側/
やまがたきた /山形北/
やまがたぎんこう /山形銀行/
やまがたけん /山形県/
やまがたけんない /山形県内/
やまがたざおう /山形蔵王/
やまがたし /山形市/
やまがたしんかんせん /山形新幹線/
やまがたじどうしゃどう /山形自動車道/
やまがただい /山形大/
やまがただいがく /山形大学/
やまがただいこう /山形大工/
やまがたな /山刀/
やまがたばん /山形版/
やまがたひがし /山形東/
やまがたふう /山形風/
やまがたべん /山形弁/
やまがたほうそう /山形放送/
やまがたほうめん /山形方面/
やまがち /山勝ち;日本の-な地形/
やまがっこ /山括弧/〈/〉/《;二重山括弧/》/
やまがつ /山賤/
やまがみ /山上/山神/
やまがら /山雀/
やまがり /山狩り/山狩/
やまがわ /山川/山側/
やまき /山木/八巻/山気/八槇/八槙/
やまきた /山北/
やまぎし /山岸/
やまぎり /山霧/
やまぎわ /山際/山極/
やまぎん /山吟/
やまくさ /山草/
やまくずれ /山崩れ/
やまくに /山国/
やまくら /山倉/
やまぐち /山口/
やまぐちけん /山口県/
やまぐちけんない /山口県内/
やまぐちさよこ /山口小夜子/
やまぐちし /山口市/
やまぐちせん /山口線/
やまぐちだい /山口大/
やまぐちだいがく /山口大学/
やまぐちべん /山口弁/
やまぐちほうそう /山口放送/
やまぐちももえ /山口百恵/
やまぐに /山国/
やまぐま /山隈/
やまぐも /山雲/
やまぐるまか /ヤマグルマ科/Trochodendraceae/
やまけ /山気/
やまけい /山渓/
やまこう /山交/
やまこし /山越/山古志/山腰/
やまことば /山言葉/
やまごえ /山越え/
やまごし /山越し/
やまごぼう /山牛蒡/
やまごもり /山籠り/
やまごや /山小屋/
やまさ /山佐/
やまさか /山坂/
やまさき /山崎/
やまさち /山幸/
やまさわ /山沢/
やまざき /山崎/山咲/
やまざきせいぱん /山崎製パン;[企業名]www.yamazakipan.co.jp/
やまざきひろこ /山崎浩子/
やまざくら /山桜/
やまざと /山里/
やまざる /山猿/
やまし /山師/
やましぎ /山鷸/
やましごと /山仕事/
やました /山下/
やましたこうえん /山下公園;横浜/
やましたしょてん /山下書店/
やましたたつろう /山下達郎/
やましたふとう /山下埠頭/
やましな /山科/
やましなえき /山科駅/
やましなく /山科区/
やましなのみや /山階宮/
やましなほうめん /山科方面/
やましろ /山城/
やましろおんせん /山代温泉/
やましろこうこう /山城高校/
やましろや /山代屋/
やまじ /山地/山路/
やまじろ /山城/
やますげ /山菅/
やますそ /山裾/
やまずい /山瑞/
やまずみ /山積;※仮名遣い「やまづみ」/
やませ /山背/山瀬;人名/
やまぜん /山善/
やまそだち /山育ち/
やまそと /山外/
やまそわ /山岨/
やまぞい /山沿い/
やまぞえ /山添/
やまたい /耶馬台/
やまたいこく /邪馬台国/邪馬臺国;旧字混淆 (NB:「臺」と「壹」で論争がある)/邪馬臺國;旧字/
やまたか /山高/
やまたかぼう /山高帽/
やまたかぼうし /山高帽子;derby hat/
やまたけ /山武/
やまたけはねうぇる /山武ハネウェル/
やまたに /山谷/
やまたねさんぎょう /山種産業;[企業名]/
やまたねしょうけん /山種証券;[企業名]NB:現・SMBCフレンド証券/
やまたのおろち /八岐大蛇/八岐の大蛇/八俣の大蛇/
やまだ /山田/
やまだい /山大/山台/
やまだいこう /山大工/
やまだいすず /山田五十鈴/
やまだおんせん /山田温泉/
やまだがわ /山田川/
やまだこうさく /山田耕筰/
やまだし /山出し/
やまだしょいん /山田書院;[出版社名]/
やまだせん /山田線/
やまだにしき /山田錦/
やまだようじ /山田洋次/
やまだりゅう /山田流;箏曲/
やまちく /山蓄/
やまっけ /山っ気/
やまつか /山塚/
やまつり /矢祭/
やまづみ /山積み/
やまづら /山面/
やまて /山手/
やまてかもつせん /山手貨物線/
やまてせん /山手線/
やまてせんない /山手線内/
やまてら /山寺/
やまてん /夜摩天/
やまでら /山寺/
やまでらかん /山寺間/
やまでん /山電/
やまと /大和/山門/
やまといも /大和芋/
やまとうんゆ /ヤマト運輸;[企業名]/
やまとえ /大和絵/倭絵/
やまとえき /大和駅/
やまとおうちょう /大和王朝/
やまとおおじ /大和大路/
やまとがく /大和楽/
やまとがわ /大和川/
やまとぐさもく /ヤマトグサ目/Theligonales/
やまとぐら /大和鞍/
やまとこうぎょう /大和工業;[企業名]/
やまとこおりやま /大和郡山/
やまとことば /大和言葉/
やまとご /大和語/
やまとさんざん /大和三山;天香久山・耳成山・畝傍山/
やまとし /大和市/
やまとしみん /大和市民/
やまとじ /大和路/
やまとじだい /大和時代/
やまとそうけん /大和総研/
やまとたかだ /大和高田/
やまとたける /日本武尊/
やまとだましい /大和魂/
やまとちょうてい /大和朝廷/
やまととじ /大和綴じ/
やまとなでしこ /大和撫子/
やまとに /大和煮/
やまとみ /山富/
やまとみんぞく /大和民族/
やまともじ /大和文字/
やまとものがたり /大和物語/
やまどめ /山止め/
やまどり /山鳥/
やまな /山名/
やまなか /山中/
やまなかこ /山中湖/
やまなかごえ /山中越/
やまなかぶし /山中節;[民謡]石川/
やまなし /山梨/
やまなしがわ /山梨側/
やまなしけん /山梨県/
やまなしけんがわ /山梨県側/
やまなしけんじん /山梨県人/
やまなしけんない /山梨県内/
やまなしこうじょう /山梨工場/
やまなしし /山梨市/
やまなしだい /山梨大/
やまなしだいがく /山梨大学/
やまなしほうそう /山梨放送/
やまなみ /山並み/山並/
やまなり /山形/山鳴り/
やまにし /山西/
やまね /山根/
やまねこ /山猫/
やまねこざ /山猫座;Lynx(Lyn)/
やまの /山野/
やまのいも /山の芋/薯蕷/山芋/
やまのうえ /山上/
やまのうえのおくら /山上憶良;660-733?/
やまのうち /山内/山ノ内/山之内/
やまのうちせいやく /山之内製薬;[企業名]/
やまのかみ /山の神/山之上/
やまのがっき /山野楽器/
やまのくち /山之口/
やまのさち /山の幸/
やまのて /山手/山の手/
やまのてせん /山手線/
やまのてせんない /山手線内/
やまのは /山の端/
やまのぼり /山登り/
やまのぼりほう /山登り法/
やまは /山葉/
やまはい /山廃/
やまはいぎんじょう /山廃吟醸/
やまはいじこみ /山廃仕込み/
やまはた /山畑/
やまはだ /山肌/
やまははつどうき /ヤマハ発動機;[企業名]/
やまはら /山原/
やまば /山場/ヤマ場/
やまばと /山鳩/
やまばといろ /山鳩色/
やまひだ /山襞/
やまび /山日/山火/
やまびこ /山彦/谺/
やまびと /山人/
やまびらき /山開き/
やまふじ /山藤/
やまふだ /山札/
やまふところ /山懐/
やまぶき /山吹/山蕗/
やまぶきいろ /山吹色/
やまぶきちょう /山吹町/
やまぶし /山伏/
やまぶしたけ /山伏茸/
やまぶち /山淵/
やまぶどう /山葡萄/
やまへん /山偏/
やまべ /山部/山辺/
やまべのあかひと /山部赤人/
やまほうし /山法師/
やまほこじゅんこう /山鉾巡行/
やまほど /山程/
やまぼこ /山鉾/
やままつ /山松/
やままつり /山祭/山祭り/
やままゆ /天蚕/山繭/
やままん /山万/
やまみ /山見/
やまみち /山道/
やまむら /山村/
やまむらがらす /山村硝子/
やまむらざ /山村座;[歌舞伎]/
やまむろ /山室/
やまめ /山女/山女魚/
やまもがしもく /ヤマモガシ目/Proteales/
やまもがしもくぐん /ヤマモガシ目群/
やまもと /山本/山元/
やまもといそろく /山本五十六/
やまもとかんさい /山本寛斎/
やまもとこうじ /山本浩二/
やまもとしゅうごろう /山本周五郎/
やまもとちょう /山本丁/
やまもとひろし /山本弘/
やまもとや /山本屋/
やまもとやま /山本山/
やまもとゆうぞう /山本有三/
やまもも /山桃/楊梅/
やまもももく /ヤマモモ目/Myricales/
やまもり /山盛り/山守/山森/
やまや /山家/山屋/山矢/
やまやき /山焼き/
やまやしき /山屋敷/
やまやま /山々/
やまゆき /山行/山雪/
やまゆり /山百合/
やまよう /山用/
やまようひん /山用品/
やまわき /山脇/
やまわきがくえん /山脇学園/
やまわけ /山分け/
やまんば /山姥/
やみ /闇/
やみ> /闇;闇市,闇金融,闇相場/
やみあがり /病み上がり/
やみいち /闇市/
やみいちば /闇市場;闇市/
やみうち /闇討ち/闇討/
やみきょういく /闇教育/
やみきん /闇金/
やみきんゆう /闇金融/
やみくも /闇雲/
やみごめ /闇米/
やみしじょう /闇市場/
やみしょうばい /闇商売/
やみじ /闇路/
やみじる /闇汁/
やみそうば /闇相場/
やみつき /病み付き/
やみとりひき /闇取引/
やみなべ /闇鍋/
やみね /闇値/
やみもり /闇森/
やみや /闇屋/
やみよ /闇夜/
やみりょうがえ /闇両替/
やみるーと /闇ルート;illegal channels/
やむいも /ヤム芋;長芋など/
やむちゃ /飲茶/
やむをえず /止むを得ず/
やめ /止め/八女;地名/矢目/已め/
やもうしょう /夜盲症/
やもお /鰥/寡男/
やもと /矢本/
やもめ /寡;(夫を亡くした)widow/孀;=寡/鰥;(妻を亡くした)widower/鰥夫;=鰥/
やもり /守宮/夜森/
やや /稍;somewhat/漸;somewhat/稚;ややこ/
やや> /稍/漸/
ややおも /稍重/
ややこ /稚児/
やゆ /揶揄/
やゆてき /揶揄的/
やよい /弥生;陰暦3月/
やよいき /弥生期/
やよいご /弥生語/
やよいしきどき /弥生式土器/
やよいしょう /弥生賞/
やよいじだい /弥生時代/
やよいじん /弥生人/
やよいちょう /弥生町/
やよいどき /弥生土器/
やよいぶんか /弥生文化/
やよいもん /弥生門/
やら /屋良/
やらい /矢来/夜来/
やらいちょう /矢来町/
やらずのあめ /遣らずの雨/
やり /槍/鎗;=槍/鑓;(国字) =槍/遣り/矢理/
やりいか /槍烏賊/
やりかた /やり方/遣り方/
やりがい /やり甲斐/遣り甲斐/
やりがたけ /槍ヶ岳/鑓ヶ岳/
やりがだけ /槍岳/
やりきへい /槍騎兵/
やりくち /やり口/遣り口/遣口/
やりくり /遣り繰り/
やりごたえ /やり応え/
やりさき /槍先/
やりしき /やり式/
やりた /鎗田/
やりだま /槍玉/やり玉/
やりて /やり手/遣り手/
やりてばば /遣り手婆/
やりてむすび /遣り手結び/
やりとり /やり取り/遣り取り/
やりなおし /遣り直し/
やりなげ /槍投げ/
やりば /やり場/遣り場/
やりぶすま /槍衾/
やりみず /鑓水/遣り水/
やりもち /槍持/
やりよう /やり様/遣り様/
やるかた /遣る方;憤懣-無し/
やるき /やる気/ヤル気/遣る気/
やること /やる事/
やるせ /遣る瀬;-ない/
やるせない /遣る瀬ない/
やるたかいだん /ヤルタ会談/
やれ /破れ/
やれあな /破れ穴;靴下の-/
やろう /野郎/
やろうじだい /夜郎自大/
やろうどうし /野郎同士/
やわ /夜話/柔/
やわた /八幡/
やわたはま /八幡浜/
やわはだ /柔肌/
やわら /柔/谷和原/
やん /楊/梁/
やんぐりつ /ヤング率/
やんぬるかな /已んぬる哉/
やんばる /山原/
やんばるくいな /山原水鶏/
やんばん /両班;(yangban) =やんぱん/
やんぱん /両班;(yangban)朝鮮の高級官僚/
やんべ /山家/
やんろんちゃ /燕龍茶/
ゆ /湯/油/由/愉;愉快/愈;いよいよ/癒;治癒/瘉;「癒」の異体字/諭;教諭/輸;輸送/兪/喩;譬喩/揄;揶揄/楡;ニレ/渝/瑜/蝓;蛞蝓/覦;覬覦/踰;踰越/逾/腴/臾;須臾/諛;阿諛/遊;(呉音)/斎;斎庭/柚;柚子/弓;弓月/揺;?/揃;?/
ゆーくりっどきかがく /ユークリッド幾何学/
ゆーくりっどくうかん /ユークリッド空間/
ゆーざーかい /ユーザー会/
ゆーざーしゃけん /ユーザー車検/
ゆーざーとうろく /ユーザー登録/
ゆーざかい /ユーザ会/
ゆーざじしょ /ユーザ辞書/
ゆーざとうろく /ユーザ登録/
ゆーざにんしょう /ユーザ認証/
ゆーざめい /ユーザ名/
ゆーじ /Ｕ字/U字/
ゆーたーん /Ｕターン/Uターン/
ゆーらしあたいりく /ユーラシア大陸/
ゆーろけん /ユーロ圏/
ゆーろさい /ユーロ債;[金融]Eurobond/
ゆーろだか /ユーロ高/
ゆーろやす /ユーロ安/
ゆあか /湯垢/
ゆあがり /湯上り/湯上がり/
ゆあさ /湯浅/湯淺;「浅」旧字/
ゆあさでんち /湯浅電池/
ゆあたり /湯中り/
ゆあつ /油圧/
ゆあつけい /油圧計/油圧系/
ゆあつしき /油圧式/
ゆあつしょべる /油圧ショベル/
ゆあつぽんぷ /油圧ポンプ/
ゆあみ /湯浴み/
ゆい /唯/由/遺/結/結い/由衣/由比/由井/油井/悠衣/湯井/由以/
ゆいいち /唯一/
ゆいいつ /唯一/惟一;<rare> =唯一/
ゆいいつしん /唯一神/
ゆいいつしんきょう /唯一神教;[宗教]monotheism/
ゆいいつしんめいづくり /唯一神明造;[建築]伊勢神宮の様式/唯一神明造り;[建築]/
ゆいいつせい /唯一性/
ゆいいつぜったい /唯一絶対/
ゆいいつち /唯一知/
ゆいいつむに /唯一無二/
ゆいえき /由比駅/
ゆいか /結花/
ゆいが /唯我/
ゆいがどくそん /唯我独尊/唯我獨尊/
ゆいがはま /由比ヶ浜/
ゆいがろん /唯我論/
ゆいごん /遺言/
ゆいごんしょ /遺言書/
ゆいごんじょう /遺言状/
ゆいごんにん /遺言人/
ゆいしき /唯識/
ゆいしきは /唯識派;[印哲]/
ゆいしきろん /唯識論/
ゆいしょ /由緒/
ゆいしょがき /由緒書/由緒書き/
ゆいしん /唯心/
ゆいしんてき /唯心的/
ゆいしんろん /唯心論;mentalism/唯神論/
ゆいつ /唯一/
ゆいな /維那/
ゆいのう /結納/
ゆいのうきん /結納金/
ゆいのうしき /結納式/
ゆいのうひん /結納品/
ゆいのうや /結納屋/
ゆいのうろん /唯脳論;養老孟司の著書/
ゆいび /唯美/
ゆいびしゅぎ /唯美主義/
ゆいびは /唯美派/
ゆいぶつ /唯物/
ゆいぶつしかん /唯物史観/
ゆいぶつてき /唯物的/
ゆいぶつろん /唯物論/
ゆいぶつろんてき /唯物論的/
ゆいま /維摩/
ゆいまぎょう /維摩経/
ゆいめいていぎ /唯名定義/
ゆいめいろん /唯名論/
ゆう /優/夕/勇;匹夫の-/憂;うれい/雄/有/友/由宇;地名,山口県/木綿/由;理由/柚;ゆず/釉;釉薬/蚰;蚰蜒(ゆうえん,げじげじ)/悠;悠然/攸;ところ/佑;(help) 天佑/祐;≒佑/侑;≒佑/囿/宥;宥和/邑;むら/悒;うれう/酉;とり/猶;猶予/猷;はかる/蕕;くさい/尤;最尤/尢;まがる/犹;「猶」の異体字/疣;いぼ/肬;≒疣/遊;あそぶ/蝣;蜉蝣/游;およぐ/湧/涌;≒湧/俑;兵馬俑/熊;くま/揖/莠;はぐさ/黝;あおぐろ/幽;幽霊/裕;余裕/誘;誘惑/郵;郵便/融;融点/右;左右/
ゆう> /優/有;有人,有酸素,有肺類/
ゆうあい /友愛/
ゆうあかり /夕明り/
ゆうあく /優渥/
ゆうあん /幽暗/
ゆうい /優位/有意/有為/有位/雄偉/
ゆういぎ /有意義/
ゆういさ /有意差/
ゆういさけんてい /有意差検定/
ゆういしゃ /優位者/
ゆういすいじゅん /有意水準/
ゆういせい /優位性/有意性/
ゆういせいけんてい /有意性検定/
ゆういち /夕市/裕一/雄一/祐一/勇一/有一/優一/友一/
ゆういちろう /雄一郎/祐一郎/裕一郎/勇一郎/有一郎/
ゆういてん /優位点/
ゆういみ /有意味/
ゆういろ /夕色/
ゆういん /誘引;attraction.「観光客の-」/誘因;trigger.「炎症の-」/有印/
ゆううつ /憂鬱/幽鬱/
ゆううつしつ /憂鬱質/
ゆうえい /遊泳/游泳/
ゆうえき /有益/
ゆうえきせい /有益性/
ゆうえつ /優越/勇悦/
ゆうえつかん /優越感/
ゆうえつこう /優越項/
ゆうえん /遊園/有鉛/遊宴/悠遠/優艶/幽遠/有煙/幽艶/優婉/結縁;姓/
ゆうえんち /遊園地/
ゆうえんちけん /遊園地券/
ゆうおう /雄黄/勇徃/
ゆうおうまいしん /勇往邁進/勇徃邁進;異体字/
ゆうか /有価/
ゆうかい /誘拐/融解/有界/幽界/
ゆうかいさつじん /誘拐殺人/
ゆうかいざい /誘拐罪/
ゆうかいじけん /誘拐事件/
ゆうかいだん /優階段/
ゆうかいてん /融解点/
ゆうかいねつ /融解熱/
ゆうかいはん /誘拐犯/
ゆうかいはんにん /誘拐犯人/
ゆうかいへんどう /有界変動/
ゆうかいほうどう /誘拐報道/
ゆうかいもの /誘拐物/
ゆうかいようぎ /誘拐容疑/
ゆうかく /遊廓/遊客/
ゆうかげ /夕影/夕陰/
ゆうかしょうけん /有価証券/
ゆうかぜ /夕風/
ゆうかだん /憂歌団/
ゆうかぶつ /有価物/
ゆうかん /夕刊/勇敢/有閑/有感/憂患/遊観/幽閑/勇悍/幽間/
ゆうかんし /夕刊紙/
ゆうかんじしん /有感地震/
ゆうかんふじん /有閑夫人/
ゆうかんまだむ /有閑マダム/
ゆうが /優雅/勇牙/
ゆうがい /有害/有蓋/
ゆうがいかしゃ /有蓋貨車/
ゆうがいしがいせん /有害紫外線/
ゆうがいしてい /有害指定/
ゆうがいとしょ /有害図書/
ゆうがいぶっしつ /有害物質/
ゆうがいむえき /有害無益/
ゆうがお /夕顔/
ゆうがく /遊学/遊楽/
ゆうがすみ /夕霞/
ゆうがた /夕方/
ゆうがたいこう /夕方以降/
ゆうがたごろ /夕方頃/
ゆうがたしゅっぱつ /夕方出発/
ゆうがたはつ /夕方発/
ゆうがたびん /夕方便/
ゆうがとう /誘蛾灯/
ゆうき /有機/勇気/誘起/有期/結城/有紀/有希/夕樹/憂木/裕樹/祐希/優希/夕貴/裕木/友樹/悠紀/優樹/幽鬼/雄基/勇喜/祐己/雄規/夕希/又木/雄希/有気/有基/有規/優起/憂喜/
ゆうき> /有機;[化学]-化合物,-炭素,-肥料/
ゆうきおん /有気音/
ゆうきかがく /有機化学/
ゆうきかごうぶつ /有機化合物/
ゆうききんこ /有期禁錮/
ゆうきけい /有期刑;⇔無期刑/
ゆうきこよう /有期雇用/
ゆうきごうせい /有機合成/
ゆうきさいばい /有機栽培/
ゆうきさん /有機酸/
ゆうきざい /有機材/
ゆうきしつ /有機質/
ゆうきせい /有機性/
ゆうきたい /有機体/
ゆうきたんそ /有機炭素/
ゆうきち /祐吉/勇吉/有吉/
ゆうきちょうえき /有期懲役/
ゆうきつむぎ /結城紬/
ゆうきてき /有機的/
ゆうきてきかんれん /有機的関連/
ゆうきのうほう /有機農法/
ゆうきひりょう /有機肥料/
ゆうきぶつ /有機物/
ゆうきゃく /誘客/遊脚/
ゆうきや /有機屋/
ゆうきゅう /有給;†paid.「-休暇」/悠久/有休;[略語]有給休暇/遊休;†idle.「-地」/
ゆうきゅうきゅうか /有給休暇/
ゆうきゅうしさん /遊休資産/
ゆうきゅうすう /優級数/
ゆうきゅうち /遊休地/
ゆうきょ /幽居/
ゆうきょう /遊興/遊侠/
ゆうきょうでん /遊侠伝/
ゆうきょうひ /遊興費/
ゆうきょく /有棘/
ゆうきようざい /有機溶剤/
ゆうきようばい /有機溶媒/
ゆうきん /遊金/游禽/
ゆうぎ /遊戯/遊技;†(特に、金品を賭けたあそび)/友誼/
ゆうぎき /遊技機/遊戯機/
ゆうぎしゃ /遊戯者/
ゆうぎじょう /遊技場/遊戯場/
ゆうぎだい /遊技台/
ゆうぎちゅう /遊技中/
ゆうぎてき /遊戯的/
ゆうぎほう /遊技法/
ゆうぎょ /勇魚/游魚/遊魚/
ゆうぎょせん /遊漁船/
ゆうぎり /夕霧/
ゆうぎりょうほう /遊戯療法;[精医]/
ゆうく /憂苦/
ゆうぐ /遊具/
ゆうぐう /優遇/
ゆうぐうきんり /優遇金利/
ゆうぐうぜいせい /優遇税制/
ゆうぐうそち /優遇措置/
ゆうぐも /夕雲/
ゆうぐれ /夕暮れ/夕暮/
ゆうぐれどき /夕暮れ時/
ゆうぐん /友軍/遊軍/
ゆうぐんき /友軍機/
ゆうけい /有形/夕景/雄勁/
ゆうけいこていしさん /有形固定資産/
ゆうけいぶんかざい /有形文化財/
ゆうけいむけい /有形無形/
ゆうけいりょく /有形力/
ゆうけむり /夕煙/
ゆうけん /有権/郵券/勇健/
ゆうけんかいしゃく /有権解釈/
ゆうけんしゃ /有権者/
ゆうけんしゃすう /有権者数/
ゆうげ /夕餉/
ゆうげい /遊芸/
ゆうげき /遊撃/
ゆうげきしゅ /遊撃手/
ゆうげきせん /遊撃戦/
ゆうげきたい /遊撃隊/
ゆうげしき /夕景色/
ゆうげしょう /夕化粧/
ゆうげん /有限/幽玄/有言/幽幻/祐源/
ゆうげん> /有限/
ゆうげんおんど /有限温度/
ゆうげんかい /有限回/
ゆうげんがいしゃ /有限会社/
ゆうげんぐん /有限群/
ゆうげんぐんろん /有限群論/
ゆうげんこ /有限個/
ゆうげんしげん /有限資源/
ゆうげんしつりょう /有限質量/
ゆうげんしゅうごう /有限集合/
ゆうげんじっこう /有言実行/
ゆうげんじっこうがた /有言実行型/
ゆうげんじょうたい /有限状態/
ゆうげんすうれつ /有限数列/
ゆうげんせい /有限性/
ゆうげんせきにん /有限責任/
ゆうげんせきにんがいしゃ /有限責任会社/
ゆうげんせきにんしゃいん /有限責任社員/
ゆうげんち /有限値/
ゆうげんちょう /有限長/
ゆうげんてき /有限的/
ゆうげんようそほう /有限要素法/
ゆうげんれつ /有限列/
ゆうこ /優子/裕子/夕子/祐子/ゆう子/友子/由子/悠子/有子/由布子/侑子/木綿子/裕有子/
ゆうこう /有効/友好/遊興/遊行/有功;meritorious/有孔;porous.「-合板」/有向;directed.「-辺」/裕弘/幽光/
ゆうこう> /有効;(valid,effective) -期限,-電力,-落差/
ゆうこうえだ /有向枝/
ゆうこうか /有効化/
ゆうこうかいとうすう /有効回答数/
ゆうこうかつよう /有効活用/
ゆうこうかんけい /友好関係/
ゆうこうがそ /有効画素/
ゆうこうがそすう /有効画素数/
ゆうこうがっき /有簧楽器/
ゆうこうきかん /有効期間/
ゆうこうきかんちゅう /有効期間中/
ゆうこうきかんない /有効期間内/
ゆうこうきげん /有効期限/
ゆうこうきげんない /有効期限内/
ゆうこうきゅうじんばいりつ /有効求人倍率/
ゆうこうきょり /有効距離/
ゆうこうぎ /有向木/
ゆうこうけた /有効桁/
ゆうこうけたすう /有効桁数/
ゆうこうこうけい /有効口径/
ゆうこうこく /友好国/
ゆうこうしつりょう /有効質量/
ゆうこうしゅうごう /有向集合/
ゆうこうじかんたい /有効時間帯/
ゆうこうじゅよう /有効需要/
ゆうこうじょうやく /友好条約/
ゆうこうすう /有効数/
ゆうこうすうじ /有効数字/
ゆうこうせい /有効性/
ゆうこうせいぶん /有効成分/
ゆうこうせんぶん /有向線分/
ゆうこうだ /有効打/
ゆうこうちゅう /有孔虫/
ゆうこうちょう /有効長/
ゆうこうてき /友好的/有効的/
ゆうこうでんりょく /有効電力/
ゆうこうとうひょうしゃ /有効投票者/
ゆうこうとうひょうすう /有効投票数/
ゆうこうとうひょうちゅう /有効投票中/
ゆうこうとうひょうりつ /有効投票率/
ゆうこうとくてん /有効得点/
ゆうこうど /友好度/
ゆうこうはんい /有効範囲/
ゆうこうひょう /有効票/
ゆうこうび /有効日/
ゆうこうびっと /有効ビット/
ゆうこうぶ /有効部/
ゆうこうへん /有向辺/
ゆうこうりょう /有効量/
ゆうこうりよう /有効利用/
ゆうこうりようほう /有効利用法/
ゆうこく /夕刻/憂国/幽谷/
ゆうこん /雄渾/幽魂/
ゆうごう /融合/
ゆうごうがた /融合型/
ゆうごうがったい /融合合体/
ゆうごうけい /融合型/
ゆうごうけん /融合研/
ゆうごうてき /融合的/
ゆうごうぶんや /融合分野/
ゆうごうろ /融合炉/
ゆうごはん /夕御飯/夕ご飯/
ゆうさい /幽斎/雄才/有妻;married/
ゆうさいしょく /有彩色/
ゆうさく /優作/勇作/雄策/雄作/裕作/祐策/
ゆうさん /有産/
ゆうさんかいきゅう /有産階級/
ゆうさんそ /有酸素/
ゆうさんそうんどう /有酸素運動;エアロビ/
ゆうざい /有罪/
ゆうざいはんけつ /有罪判決/
ゆうざん /雄山/
ゆうざんかく /雄山閣/
ゆうし /融資/有志;†volunteer.「-を募る」/勇姿;†勇ましい姿。「兵団の-」/雄姿;†雄々しい姿。「指導者の-」/勇士;†勇ましい人物。「歴戦の-」/有史/雄志;†雄々しい意気込み/有刺;-鉄線,-障壁,-植物(サボテンなど)/有司/遊子/雄視/猶子/勇史/憂思/遊糸/遊資/右史;⇔左史/
ゆうしいらい /有史以来/
ゆうしお /夕潮/
ゆうしかい /有視界/
ゆうしかく /有資格/
ゆうしかくしゃ /有資格者/
ゆうしき /有識/
ゆうしきしゃ /有識者/
ゆうしぐれ /夕時雨/
ゆうしさき /融資先/
ゆうししゃ /有志者/
ゆうしじょうけん /融資条件/
ゆうしつ /幽室/
ゆうしつどうぶつ /有櫛動物/
ゆうしてっせん /有刺鉄線/
ゆうしぶんれつ /有糸分裂;[生物]mitosis/
ゆうしゃ /勇者/優者/
ゆうしゃく /有爵/
ゆうしゃたち /勇者達/
ゆうしゅ /郵趣;切手収集などの趣味/遊手/
ゆうしゅう /優秀/憂愁/有終/幽囚/幽愁/
ゆうしゅうきょくしょう /優秀曲賞/
ゆうしゅうさくひん /優秀作品/
ゆうしゅうしゃ /優秀者/
ゆうしゅうしょう /優秀賞/
ゆうしゅうせい /優秀性/
ゆうしゅうせんしゅしょう /優秀選手賞/
ゆうしゅうだい /優秀台/
ゆうしゅうのび /有終の美/
ゆうしゅうはっぴょう /優秀発表/
ゆうしゅうろくおん /優秀録音/
ゆうしゅつ /湧出/涌出;=湧出/誘出/
ゆうしゅん /優駿/
ゆうしゅんひんば /優駿牝馬/
ゆうしょ /郵書/
ゆうしょう /優勝/有償/優賞/勇将/湧昇/
ゆうしょういがい /優勝以外/
ゆうしょうかいすう /優勝回数/
ゆうしょうかくりつ /優勝確率/
ゆうしょうき /優勝旗/
ゆうしょうきねん /優勝記念/優勝祈念/
ゆうしょうきねんごう /優勝記念号/
ゆうしょうきねんひん /優勝記念品/
ゆうしょうきょく /優勝曲/
ゆうしょうけいけん /優勝経験/
ゆうしょうけいやく /有償契約/
ゆうしょうけってい /優勝決定/
ゆうしょうけっていせん /優勝決定戦/
ゆうしょうこう /優勝校/
ゆうしょうこうい /有償行為/
ゆうしょうこうほ /優勝候補/
ゆうしょうご /優勝後/
ゆうしょうしゃ /優勝者/優勝車/
ゆうしょうしゃよそう /優勝者予想/
ゆうしょうしゅうり /有償修理/
ゆうしょうしゅくがかい /優勝祝賀会/
ゆうしょうしょうきん /優勝賞金/
ゆうしょうしょうひん /優勝賞品/優勝商品/
ゆうしょうせーる /優勝セール/
ゆうしょうせん /優勝戦/
ゆうしょうせんせん /優勝戦線/
ゆうしょうちーむ /優勝チーム/
ゆうしょうとうしゅ /優勝投手/
ゆうしょうはい /優勝杯/
ゆうしょうば /優勝馬/
ゆうしょうよそう /優勝予想/
ゆうしょうれっぱい /優勝劣敗/
ゆうしょく /夕食/有職/有色/憂色/
ゆうしょくかい /夕食会/
ゆうしょくしゃ /有職者/
ゆうしょくじんしゅ /有色人種/
ゆうしょくだい /夕食代/
ゆうしょくどき /夕食時/
ゆうしょくよう /夕食用/
ゆうしん /有信/有心/雄心/憂心/
ゆうしんぼつぼつ /雄心勃々/
ゆうしんろん /有神論/
ゆうじ /有事/雄二/裕二/裕司/祐司/祐二/祐治/勇二/雄司/裕治/勇治/雄次/勇次/祐次/裕史/裕志/雄志/佑二/友二/雄士/祐史/祐之/右二/雄爾/裕慈/祐地/
ゆうじほうせい /有事法制/
ゆうじゃ /雄者/
ゆうじゃく /幽寂/
ゆうじゅう /優柔/
ゆうじゅうふだん /優柔不断/
ゆうじょ /遊女/宥恕/優女/佑助/
ゆうじょう /友情/
ゆうじょうかんけい /友情関係/
ゆうじょうしゅつえん /友情出演/
ゆうじりっぽう /有事立法/
ゆうじろう /雄二郎/裕次郎/悠二郎/
ゆうじん /友人/有人/遊人/
ゆうじん> /有人;-飛行,-探査機,-改札/
ゆうじんいちどう /友人一同/
ゆうじんえき /有人駅/
ゆうじんかいさつ /有人改札/
ゆうじんかいさつぐち /有人改札口/
ゆうじんかん /友人間/
ゆうじんかんけい /友人関係/
ゆうじんしょゆう /友人所有/
ゆうじんたく /友人宅/
ゆうじんたち /友人達/
ゆうじんちじん /友人知人/
ゆうじんちゅう /友人中/
ゆうじんとう /有人島/
ゆうじんどうし /友人同士/
ゆうじんぶん /友人分/
ゆうじんまどぐち /有人窓口/
ゆうじんれんちゅう /友人連中/
ゆうすい /湧水/有水/幽邃/
ゆうすいち /遊水池/
ゆうすう /有数/
ゆうすけ /祐介/雄介/裕介/祐輔/勇介/雄輔/勇輔/佳祐/有祐/幽助/
ゆうすずみ /夕涼み/
ゆうずい /雄蕊/
ゆうずう /融通/
ゆうずうせい /融通性/
ゆうずうむげ /融通無碍/融通無礙;=融通無碍/
ゆうずつ /夕星/長庚;=ゆうつづ/
ゆうせい /郵政/優勢;†⇔劣勢。「-を保つ」/遊星/優性;†[生物]dominance.「-遺伝」/優生;†eugenics.「-学」/雄性/有性;sexual.「-生殖」/有声;voiced.「-破裂音」/幽静/有生;人名/
ゆうせいいでん /優性遺伝/
ゆうせいおん /有声音/
ゆうせいか /有声化;[音声学]vocalisation/
ゆうせいかんさつきょく /郵政監察局/
ゆうせいがく /優生学/
ゆうせいがち /優勢勝ち/
ゆうせいこうしゃ /郵政公社/
ゆうせいしいん /有声子音/
ゆうせいしゃ /遊星社/
ゆうせいしょう /郵政省;NB:2001年1月の中央省庁再編で総務省に再編された/
ゆうせいしょうれい /郵政省令/
ゆうせいじぎょうちょう /郵政事業庁/
ゆうせいせいしょく /有性生殖/
ゆうせいせだい /有性世代/
ゆうせいぞく /郵政族/
ゆうせいだいじん /郵政大臣/
ゆうせいほごほう /優生保護法/
ゆうせいらん /有精卵/
ゆうせき /有責/
ゆうせきせい /有責性/
ゆうせつ /融雪/
ゆうせつざい /融雪剤/
ゆうせん /優先/有線/郵船/湧泉/勇戦/涌泉/
ゆうせんかいせん /有線回線/
ゆうせんかだい /優先課題/
ゆうせんかぶ /優先株/
ゆうせんがわ /優先側/
ゆうせんきじゅん /優先基準/
ゆうせんけん /優先権/
ゆうせんこうにゅう /優先購入/
ゆうせんしき /有線式/
ゆうせんしゅっそうけん /優先出走権/
ゆうせんしんごう /優先信号/
ゆうせんじこう /優先事項/
ゆうせんじゅん /優先順/
ゆうせんじゅんい /優先順位/
ゆうせんじゅんいつき /優先順位付/
ゆうせんじゅんじょ /優先順序/
ゆうせんじょうけん /優先条件/
ゆうせんせき /優先席/
ゆうせんそうしん /有線送信/
ゆうせんたんさく /優先探索/
ゆうせんつうしん /有線通信/
ゆうせんてき /優先的/
ゆうせんてきけんり /優先的権利/
ゆうせんでんわ /有線電話;⇔無線電話・携帯電話/
ゆうせんでんわき /有線電話機/
ゆうせんでんわよやく /優先電話予約/
ゆうせんど /優先度/
ゆうせんどう /優先道/
ゆうせんどうろ /優先道路/
ゆうせんはんばい /優先販売/
ゆうせんほうそう /有線放送/
ゆうせんほうそうでんわ /有線放送電話/
ゆうせんよやく /優先予約/
ゆうせんろしゅつ /優先露出/
ゆうせんわく /優先枠/
ゆうぜい /遊説/有税/郵税/游説/
ゆうぜん /友禅/悠然/
ゆうぜんぞめ /友禅染/
ゆうそう /郵送/勇壮/遊走/雄壮/遊僧/
ゆうそうか /郵送可/
ゆうそうきぼう /郵送希望/
ゆうそうさいぼう /遊走細胞/
ゆうそうさき /郵送先/
ゆうそうだい /郵送代/
ゆうそうてすうりょう /郵送手数料/
ゆうそうひ /郵送費/
ゆうそうぶつ /郵送物/
ゆうそうりょう /郵送料/
ゆうそく /有職/
ゆうそくこじつ /有職故実/
ゆうぞう /雄三/祐三/裕三/勇三/勇蔵/
ゆうぞら /夕空/
ゆうた /祐太/由宇太/
ゆうたい /優待/勇退/幽体/融体/郵袋/
ゆうたいかかく /優待価格/
ゆうたいけん /優待券/
ゆうたいどうさん /有体動産/
ゆうたいばんるい /有胎盤類/
ゆうたいぶつ /有体物/
ゆうたいりだつ /幽体離脱/
ゆうたいりょうきん /優待料金/
ゆうたいるい /有袋類/
ゆうたいわりびきけん /優待割引券/
ゆうたろう /裕太郎/
ゆうたんぽ /有担保/
ゆうだ /遊惰/
ゆうだい /雄大/
ゆうだち /夕立/夕立ち/
ゆうだちぐも /夕立雲/
ゆうだん /勇断/
ゆうだんしゃ /有段者/
ゆうち /誘致/
ゆうちうんどう /誘致運動/
ゆうちゃく /融着/
ゆうちょ /郵貯/
ゆうちょう /悠長/有徴;marked/
ゆうつうせい /有痛性/
ゆうつづ /夕星;金星/長庚;金星/
ゆうづう /融通/
ゆうづうせい /融通性/
ゆうづき /夕月/有月/
ゆうづきよ /夕月夜/
ゆうづくよ /夕月夜/
ゆうづる /夕鶴/
ゆうてい /夕定/
ゆうているい /有蹄類;[生物]Ungulata/
ゆうてん /融点/
ゆうてんじ /祐天寺/
ゆうでん /誘電/
ゆうでんかねつ /誘電加熱/
ゆうでんそんしつ /誘電損失/
ゆうでんたい /誘電体/
ゆうでんぶんきょく /誘電分極/
ゆうでんりつ /誘電率/
ゆうと /勇人/雄図/雄途/
ゆうとう /優等/遊蕩/友党/雄踏;地名/
ゆうとうぐん /雄踏郡/
ゆうとうしゃ /優等車/
ゆうとうせい /優等生/
ゆうとうせいてき /優等生的/
ゆうとうれっしゃ /優等列車/
ゆうとく /祐徳/有徳/
ゆうど /尤度/裕度/
ゆうどう /誘導/遊動/有働/
ゆうどういん /誘導員/
ゆうどうえんぼく /遊動円木/
ゆうどうがかり /誘導係/
ゆうどうがた /誘導型/
ゆうどうき /誘導機/
ゆうどうざつおん /誘導雑音/
ゆうどうじんもん /誘導尋問/
ゆうどうたい /誘導体/
ゆうどうたんい /誘導単位;derived unit. eg. N→kg・m／s^2/
ゆうどうだん /誘導弾/
ゆうどうでんどうき /誘導電動機/
ゆうどうでんりゅう /誘導電流;[物理]/
ゆうどうとう /誘導灯/
ゆうどうほうしゃのう /誘導放射能/
ゆうどうほうしゅつ /誘導放出/
ゆうどうろ /誘導路;taxiway. 「空港の-」/
ゆうどかんすう /尤度関数/
ゆうどく /有毒/
ゆうどくがす /有毒ガス/
ゆうどくせい /有毒性/
ゆうどくせいぶん /有毒成分/
ゆうどくぶっしつ /有毒物質/
ゆうどくぶつ /有毒物/
ゆうな /夕菜/
ゆうなぎ /夕凪/
ゆうなみ /夕波/
ゆうに /優に/
ゆうねつき /有熱期/
ゆうのう /有能/
ゆうはい /有配/
ゆうはつ /誘発/
ゆうはつざい /誘発剤/
ゆうはつせい /誘発性/
ゆうはつでんい /誘発電位/
ゆうはもん /幽波紋/
ゆうはん /夕飯/雄藩/有半/
ゆうばえ /夕映え/夕暎え;異体字/
ゆうばく /誘爆/
ゆうばり /夕張/
ゆうばれ /夕晴れ/
ゆうぱっく /ゆうパック/
ゆうひ /夕日/夕陽/雄飛/
ゆうひかく /有斐閣/
ゆうひつ /右筆/祐筆/
ゆうひょう /有標/融氷/遊標/
ゆうひょうか /優評価/
ゆうひょうき /融氷期/
ゆうひん /優品/
ゆうび /優美/
ゆうびょうりつ /有病率/
ゆうびん /郵便/〒/
ゆうびんうけ /郵便受け/
ゆうびんかわせ /郵便為替/
ゆうびんかわせしょうしょ /郵便為替証書/
ゆうびんきって /郵便切手/
ゆうびんきょく /郵便局/
ゆうびんきょくいん /郵便局員/
ゆうびんきょくどめ /郵便局止め/
ゆうびんきょくまえ /郵便局前/
ゆうびんく /郵便区/
ゆうびんこうざ /郵便口座/
ゆうびんこがわせ /郵便小為替/
ゆうびんこづつみ /郵便小包/
ゆうびんしゃ /郵便車/
ゆうびんしょかん /郵便書簡/
ゆうびんじこ /郵便事故/
ゆうびんせいど /郵便制度/
ゆうびんそくたつ /郵便速達/
ゆうびんだい /郵便代/
ゆうびんちょきん /郵便貯金/
ゆうびんでんしゃ /郵便電車/
ゆうびんはいたつ /郵便配達/
ゆうびんはがき /郵便葉書/
ゆうびんばこ /郵便箱/
ゆうびんばんごう /郵便番号/〒/
ゆうびんばんごうじしょ /郵便番号辞書/
ゆうびんばんごうぼ /郵便番号簿/
ゆうびんふりかえ /郵便振替/
ゆうびんふりかえこうざ /郵便振替口座/
ゆうびんふりかえようし /郵便振替用紙/
ゆうびんふりこみ /郵便振込/
ゆうびんふりこみようし /郵便振込用紙/
ゆうびんぶつ /郵便物/
ゆうびんほう /郵便法/
ゆうびんや /郵便屋/
ゆうびんりょう /郵便料/
ゆうびんりょうきん /郵便料金/
ゆうふ /有夫/
ゆうふく /裕福/
ゆうふつ /勇払/
ゆうふつぐん /勇払郡/
ゆうふん /憂憤/
ゆうぶ /勇武/
ゆうへい /幽閉/雄平/裕平/
ゆうへん /雄編/雄篇/
ゆうべ /夕べ/昨夜/夕/
ゆうべつ /湧別/
ゆうべつえき /湧別駅/
ゆうべん /雄弁/
ゆうべんか /雄弁家/
ゆうべんかい /雄弁会/
ゆうべんじゅつ /雄弁術;elocution/
ゆうほ /遊歩/
ゆうほう /雄峰/友朋/友邦/
ゆうほうどうしょてん /友朋堂書店/
ゆうほどう /遊歩道/
ゆうぼう /有望/
ゆうぼうかぶ /有望株/
ゆうぼうし /有望視/
ゆうぼく /遊牧/
ゆうぼくみん /遊牧民/
ゆうぼくみんぞく /遊牧民族/
ゆうま /遊馬/
ゆうまぐれ /夕間暮れ/
ゆうみ /裕美/
ゆうみや /夕宮/
ゆうみん /遊民/
ゆうみんしゃ /遊眠社/遊民社/
ゆうむ /有無/
ゆうめい /有名/勇名;「-を馳せる」/幽明;†明暗。あの世とこの世。「-境を異にする」/幽冥;†暗い。あの世。「-界」/
ゆうめい> /有名/
ゆうめいかい /幽冥界/
ゆうめいかしゅ /有名歌手/
ゆうめいかんこうち /有名観光地/
ゆうめいこう /有名校/
ゆうめいこく /有名国/
ゆうめいしょ /有名所/
ゆうめいしんがっこう /有名進学校/
ゆうめいじいん /有名寺院/
ゆうめいじん /有名人/
ゆうめいせんしゅ /有名選手/
ゆうめいぜい /有名税/
ゆうめいてん /有名店/
ゆうめいどころ /有名所/
ゆうめいはいゆう /有名俳優/
ゆうめいば /有名馬/
ゆうめいむじつ /有名無実/
ゆうめいむじつか /有名無実化/
ゆうめいりきし /有名力士/
ゆうめし /夕飯/
ゆうめん /宥免/
ゆうもう /勇猛/有毛/
ゆうもうかかん /勇猛果敢/
ゆうもうせん /湧網線/
ゆうもや /夕靄/
ゆうもん /幽門/憂悶/
ゆうや /裕也/雄也/裕哉/裕弥/
ゆうやく /釉薬/勇躍/
ゆうやけ /夕焼け/夕焼/
ゆうやけぐも /夕焼け雲/
ゆうやけこやけ /夕焼小焼;童謡/
ゆうやみ /夕闇/
ゆうゆう /悠々;「-自適」/融々/悠悠/融融/
ゆうゆうかんかん /悠々閑々/
ゆうゆうじてき /悠々自適/悠悠自適/
ゆうよ /猶予/有余/
ゆうよう /有用/悠揚/融溶/
ゆうようせい /有用性/
ゆうようてき /有用的/
ゆうよきかん /猶予期間/
ゆうよく /有翼/遊弋/游弋/
ゆうらく /遊楽/有楽/
ゆうらくがい /有楽街/
ゆうらくちょう /有楽町/
ゆうらくちょうえきまえ /有楽町駅前/
ゆうらくちょうせいぶ /有楽町西武/
ゆうらくちょうせん /有楽町線/
ゆうらくてん /有楽店/
ゆうらん /遊覧/
ゆうらんせん /遊覧船/
ゆうらんひこう /遊覧飛行/
ゆうり /有利/遊離/有理/遊里/友里;人名/悠里/悠理/
ゆうりかく /遊離核/
ゆうりかんすう /有理関数/
ゆうりき /遊離基/
ゆうりこう /釉裏紅/
ゆうりご /遊里語/
ゆうりし /有利子/
ゆうりしふさい /有利子負債/
ゆうりすう /有理数/
ゆうりすうたい /有理数体/
ゆうりてき /有理的/
ゆうりふり /有利不利/
ゆうりゃく /雄略/
ゆうりゃくてんのう /雄略天皇/
ゆうりょ /憂慮/
ゆうりょう /有料/優良/遊猟/
ゆうりょううんてんしゃ /優良運転者/
ゆうりょううんてんしゅ /優良運転手/
ゆうりょうか /有料化/優良可/
ゆうりょうかぶ /優良株/
ゆうりょうきぎょう /優良企業/
ゆうりょうさーびす /有料サービス/
ゆうりょうせい /優良性/
ゆうりょうぜい /遊漁税;法定外目的税/
ゆうりょうちゅうしゃじょう /有料駐車場/
ゆうりょうてん /優良店/
ゆうりょうとっきゅう /有料特急/
ゆうりょうどうろ /有料道路/
ゆうりょうどうろいりぐち /有料道路入口/
ゆうりょうにゅうじょうしゃすう /有料入場者数/
ゆうりょうひん /優良品/
ゆうりょうほうそう /有料放送/
ゆうりょく /有力/
ゆうりょくかぶ /有力株/
ゆうりょくこう /有力校/
ゆうりょくこうほ /有力候補/
ゆうりょくし /有力視/
ゆうりょくしゃ /有力者/
ゆうりょくせいじか /有力政治家/
ゆうりょくせんしゅ /有力選手/
ゆうりょくだいぎし /有力代議士/
ゆうりょくば /有力馬/
ゆうりょくばじょうほう /有力馬情報/
ゆうりん /有鱗/友隣/
ゆうりんしゃ /友隣社/
ゆうりんどう /有隣堂/
ゆうりんるい /有鱗類/
ゆうれい /幽霊/優麗/雄麗/
ゆうれいかぶ /幽霊株/
ゆうれいがいしゃ /幽霊会社/
ゆうれいじんこう /幽霊人口/
ゆうれいせん /幽霊船/
ゆうれいたいじ /幽霊退治/
ゆうれいたけ /幽霊茸/
ゆうれいぶいん /幽霊部員/
ゆうれいやく /幽霊役/
ゆうれいやしき /幽霊屋敷/
ゆうれいれっしゃ /幽霊列車/
ゆうれき /遊歴/
ゆうれつ /優劣/
ゆうろぴうむ /Eu/Europium/
ゆうわ /融和;うちとける/宥和;ゆるしあう/雄和;地名,秋田など/優和;人名/友輪/
ゆうわく /誘惑/
ゆうわくしゃ /誘惑者/
ゆうわくせい /誘惑性/
ゆうわさく /融和策/
ゆうわせいさく /宥和政策/融和政策/
ゆえ /故/湯江/優恵/
ゆえい /輸贏/
ゆえき /輸液/
ゆえつ /愉悦/踰越/諛悦/
ゆえに /故に/∴/
ゆえよし /故由/
ゆえん /所以/由縁/油煙/
ゆおう /硫黄/
ゆおも /湯母;[古語]/
ゆおん /湯温;†(おゆ)/油温;†(あぶら)/
ゆおんけい /油温計/
ゆか /床/牀;≒床 (本来の字)/油化/夕香;人名/友香/由佳/結花/由香/裕香/有香/由加/由架/夕夏/夕佳/友華/友賀/弓佳/
ゆかい /愉快/
ゆかいた /床板/
ゆかいちめん /床一面/
ゆかいはん /愉快犯/
ゆかうえ /床上/
ゆかうえしんすい /床上浸水/
ゆかうんどう /床運動/
ゆかおき /床置/床置き/
ゆかおきしき /床置式/
ゆかぐみ /床組/
ゆかげん /湯加減/
ゆかこ /由香子/裕香子/優香子/有香子/友華子/
ゆかざい /床材/
ゆかした /床下/
ゆかしたきき /床下機器/
ゆかしたしんすい /床下浸水/
ゆかしただんぼう /床下暖房/
ゆかしたよう /床下用/
ゆかた /浴衣/
ゆかたすがた /浴衣姿/
ゆかたびら /湯帷子/
ゆかだか /床高/
ゆかだんぼう /床暖房/
ゆかの /由佳乃/
ゆかばり /床張り/
ゆかほん /床本/
ゆかみがき /床磨き/
ゆかめん /床面/
ゆかめんせき /床面積/
ゆかよう /床用/
ゆかり /縁/紫/由加里/由香里/由香利/所縁/由佳里/由佳利/由加利/友佳梨/由架梨/
ゆかわ /湯川/湯河/
ゆかわおんせん /湯川温泉/
ゆかわひでき /湯川秀樹/
ゆかん /湯灌/
ゆが /瑜伽;yoga/憂花/
ゆがしま /湯ケ島/湯ヶ島/湯が島/
ゆがしゅう /瑜伽宗/
ゆがま /湯釜/
ゆがみ /歪み/
ゆがわ /湯川/
ゆがわら /湯河原/
ゆき /雪/行/行き/裄/由紀/有紀/由貴/有希/由樹/友紀/夕貴/由希/由季/夕紀/由起/由記/由姫/裕紀/由岐/斎木/由綺;名/湯来/由妃/油木/由喜/油機/幸/之/志/征/恭/倖/
ゆきあい /行合/
ゆきあか /雪垢/
ゆきあかり /雪明り/雪明かり/
ゆきあそび /雪遊び/
ゆきあたり /行き当たり/行き当り/
ゆきあらし /雪嵐/
ゆきいり /雪入/
ゆきうさぎ /雪兎/
ゆきえ /幸恵/幸江/幸枝/雪絵/由紀江/好恵/幸栄/由喜枝/由起絵/
ゆきお /幸雄/幸男/幸夫/由紀夫/行雄/幸生/行夫/悠紀雄/幸應/雪夫/悠紀夫/由起夫/行生/由記雄/由希夫/
ゆきおこし /雪起こし/雪起し/
ゆきおと /雪音/
ゆきおとこ /雪男/
ゆきおれ /雪折れ/
ゆきおろし /雪下ろし/
ゆきおんな /雪女/
ゆきか /幸香/
ゆきかえり /行き帰り/往き還り/
ゆきかき /雪掻き/
ゆきかぜ /雪風/
ゆきかた /行き方/
ゆきかべ /雪壁/
ゆきがかり /行き掛かり/行き掛り/
ゆきがけ /行き掛け;-の駄賃/
ゆきがこい /雪囲い/
ゆきがた /行き方/
ゆきがっせん /雪合戦/
ゆきき /行き来/
ゆきくら /雪倉/
ゆきぐに /雪国/
ゆきぐみ /雪組;[芸能]宝塚/
ゆきぐも /雪雲/
ゆきけむり /雪煙/
ゆきげしき /雪景色/
ゆきげしょう /雪化粧/
ゆきこ /幸子/由紀子/有希子/由希子/有紀子/由起子/雪子/由貴子/友紀子/由季子/夕紀子/有己子/
ゆきころがし /雪転がし/
ゆきさき /行き先/行先/
ゆきざさ /雪笹/
ゆきしつ /雪質/
ゆきしろ /雪代;雪融け水/
ゆきじ /雪路/
ゆきじるし /雪印/
ゆきじろ /雪白;snow white/
ゆきすぎ /行き過ぎ/行過ぎ/
ゆきすずめ /雪雀/
ゆきずり /行き摩り/行き摺り/
ゆきぞう /行三/
ゆきぞら /雪空/
ゆきた /幸田/
ゆきたか /幸貴/
ゆきたけ /裄丈/雪竹/
ゆきたに /雪谷/
ゆきだおれ /行き倒れ/
ゆきだま /雪玉/
ゆきだまり /雪溜まり/
ゆきだるま /雪達磨/雪だるま/雪ダルマ/
ゆきだるましき /雪達磨式;-に借金がかさむ/
ゆきち /諭吉/
ゆきちがい /行き違い/
ゆきつけ /行き付け/
ゆきづきよ /雪月夜/
ゆきづまり /行き詰まり/
ゆきとし /幸俊/幸敏/礼暁/
ゆきとみ /幸富/
ゆきとり /雪取/
ゆきどけ /雪解け/雪融け/
ゆきどけみず /雪解け水/
ゆきどころ /行き所/
ゆきどまり /行き止まり/
ゆきなげ /雪投げ/
ゆきなり /行成/幸成/志勢/
ゆきぬけ /行き抜け/
ゆきの /雪野/雪乃/
ゆきのじょう /雪之丞/
ゆきのすけ /雪ノ助/
ゆきのぶ /行信/之宣/
ゆきのり /幸則/幸徳/幸典/幸紀/幸範/行則/行徳/幸記/
ゆきはだ /雪肌/
ゆきはる /幸春/
ゆきば /行き場/行場/
ゆきばな /雪花/
ゆきばれ /雪晴れ/
ゆきひこ /幸彦/行彦/由紀彦/恭彦/由記彦/
ゆきひで /幸秀/
ゆきひと /幸仁/
ゆきひら /行平;雪平鍋/雪平;-鍋/
ゆきひらなべ /雪平鍋/
ゆきひろ /幸弘/幸宏/幸広/幸博/行弘/行宏/幸展/幸拾/
ゆきびさし /雪庇/
ゆきふみ /幸史/
ゆきぶそく /雪不足/
ゆきほ /行穂/
ゆきぼうし /雪帽子/
ゆきまさ /幸正/幸政/幸真/
ゆきまじり /雪混じり/雪交じり;-の雨/雪雑じり/
ゆきまちづき /雪待月/雪待ち月/
ゆきまつ /行松/
ゆきまつり /雪祭り/雪祭/
ゆきみ /雪見/
ゆきみぐさ /雪見草/
ゆきみざけ /雪見酒/
ゆきみち /雪道/雪路/幸道/
ゆきみちよう /雪道用/
ゆきみつ /幸光/
ゆきむし /雪虫/
ゆきむら /幸村/
ゆきめ /雪眼/
ゆきもと /雪本/
ゆきもどり /行き戻り/
ゆきもよう /雪模様/
ゆきや /幸也/
ゆきやなぎ /雪柳;[植物]バラ科/
ゆきやま /雪山/
ゆきよ /雪夜/幸代/雪代/
ゆきよし /幸義/幸喜/
ゆきれっしゃ /雪列車/
ゆきわかれ /行き別れ/行別れ/
ゆきわりそう /雪割草/
ゆきんこ /雪ん子/
ゆぎ /柚木/由木/
ゆぎえ /靫負;=ゆげい/
ゆぎおい /靫負;=ゆげい/
ゆぎしょう /湯起請/
ゆぎょう /遊行/
ゆぎん /輸銀/
ゆくあき /行く秋/
ゆくえ /行方/行く方/
ゆくえふめい /行方不明/
ゆくえふめいしゃ /行方不明者/
ゆくかた /行く方/
ゆくさき /行く先/行先/
ゆくさきざき /行く先々/
ゆくすえ /行く末/
ゆくて /行く手/
ゆくとし /行く年/
ゆくは /的;=いくは(=まと)/
ゆくはし /行橋/
ゆくはる /行く春/
ゆくへ /行方/
ゆくゆく /行く行く;-は/
ゆぐち /湯口/
ゆけつ /輸血/
ゆけむり /湯煙/
ゆけん /油研/
ゆけんこうぎょう /油研工業;[企業名]/
ゆげ /湯気/弓削/遊戯/
ゆげい /靫負/
ゆげた /弓削田/
ゆこく /諭告/
ゆごう /癒合/
ゆさ /遊佐/
ゆさい /油彩/
ゆさいが /油彩画/
ゆさてき /遊佐的/
ゆさぶり /揺さぶり;-をかける/揺さ振り/
ゆさぼう /遊佐坊/
ゆさわり /鞦韆/
ゆさん /遊山/
ゆざい /油剤/
ゆざまし /湯冷まし/
ゆざめ /湯冷め/湯ざめ/
ゆざわ /湯沢/湯澤/
ゆし /油脂/油紙/諭旨/
ゆしま /湯島/油島/
ゆしまてんじん /湯島天神/
ゆしめんしょく /諭旨免職/
ゆしゅつ /輸出/
ゆしゅつきせい /輸出規制/
ゆしゅつきょうそうりょく /輸出競争力/
ゆしゅつさき /輸出先/
ゆしゅつしゃ /輸出車/
ゆしゅつしょう /輸出商/
ゆしゅつしよう /輸出仕様/
ゆしゅつしんこく /輸出申告/
ゆしゅつしんこくしょ /輸出申告書/
ゆしゅつぜい /輸出税/
ゆしゅつぜんたい /輸出全体/
ゆしゅつちょうか /輸出超過/
ゆしゅつにゅう /輸出入/
ゆしゅつひん /輸出品/
ゆしゅつほけん /輸出保険;export insurance. 政策保険の一/
ゆしゅつよう /輸出用/
ゆしょう /油症;カネミ-/
ゆしょく /愉色/
ゆしるい /油脂類/
ゆじょう /油状/
ゆすはら /梼原/
ゆすら /桜桃;=ゆすらうめ/梅桃/山桜桃/
ゆすらうめ /桜桃;NB:「おうとう」「さくらんぼ」と同字/梅桃;=桜桃/山桜桃;=桜桃/英桃;=桜桃/
ゆすり /強請/
ゆず /柚子/柚/梼;?/
ゆずがま /柚釜/
ゆずき /柚木/柚月/
ゆずこ /柚子/
ゆずぼう /柚子坊/
ゆずみそ /柚味噌;風呂吹き大根に/
ゆずゆ /柚湯/
ゆずりうけ /譲り受け/
ゆずりうけにん /譲受人/
ゆずりは /譲葉;[植物] (新しい葉が出ると古い葉が落ちる)/
ゆずりわたしにん /譲渡人/
ゆずる /譲/讓;「譲」の旧字(人名用漢字)/
ゆせ /湯瀬/
ゆせい /油性/油井;oil well/
ゆせいかん /輸精管/
ゆせいとりょう /油性塗料;oil paint/
ゆせいぺん /油性ペン/
ゆせいまじっく /油性マジック/
ゆせん /湯煎/湯銭/湯せん/
ゆそう /輸送/油槽/湯槽/油送/油層/
ゆそうかん /輸送艦/輸送管/
ゆそうき /輸送機/
ゆそうきかん /輸送機関/
ゆそうきょり /輸送距離/
ゆそうぎょう /輸送業/
ゆそうぎょうしゃ /輸送業者/
ゆそうけいかく /輸送計画/
ゆそうけいさん /輸送計算/
ゆそうしゃ /輸送車/
ゆそうしゅだん /輸送手段/
ゆそうじ /輸送時/
ゆそうじっせき /輸送実績/
ゆそうじゅよう /輸送需要/
ゆそうじょう /輸送上/
ゆそうじんいん /輸送人員/
ゆそうせん /輸送船/油槽船/
ゆそうたい /輸送隊/
ゆそうちゅう /輸送中/
ゆそうのうりょく /輸送能力/
ゆそうひ /輸送費/
ゆそうひよう /輸送費用/
ゆそうぶんたんりつ /輸送分担率/
ゆそうへり /輸送ヘリ/
ゆそうほうていしき /輸送方程式/
ゆそうほうほう /輸送方法/
ゆそうよう /輸送用/
ゆそうりょう /輸送量/輸送料/
ゆそうりょく /輸送力/
ゆそうりょくぞうきょう /輸送力増強/
ゆそうりょくぶそく /輸送力不足/
ゆそうろ /輸送路/
ゆそつ /輸卒/
ゆたか /豊/裕/優/泰/穰;「穣」の旧字(人名用漢字)/豐;「豊」の旧字/豊か/
ゆたかさ /豊かさ/豊さ/
ゆたかしょうゆ /豊醤油/
ゆたに /湯谷/由谷/
ゆたゆた /揺た揺た/
ゆたん /油単/
ゆたんぽ /湯湯婆/湯たんぽ/
ゆだ /湯田/
ゆだく /油濁/
ゆだち /弓立/
ゆだて /湯立/
ゆだなか /湯田中/
ゆだなかえき /湯田中駅/
ゆだま /湯玉/
ゆだめ /檠/
ゆだや /猶太/
ゆだやきょう /ユダヤ教/
ゆだやきょうと /ユダヤ教徒/
ゆだやけい /ユダヤ系/
ゆだやじん /ユダヤ人/
ゆだん /油断/
ゆだんたいてき /油断大敵/
ゆちゃ /湯茶/
ゆちゃく /癒着/
ゆつか /弓束/
ゆつぼ /湯壺/
ゆづかみ /湯津上/
ゆづかれ /湯疲れ/
ゆづき /弓月/由月/
ゆづけ /湯漬け/湯漬/
ゆづる /弓弦/
ゆてき /油滴/
ゆてん /油点/
ゆで /茹で/
ゆであずき /茹で小豆/
ゆでえび /茹で海老/
ゆでぐり /茹で栗/
ゆでじかん /茹で時間/
ゆでじる /茹で汁;パスタの-/
ゆでたまご /茹で卵/ゆで卵/茹で玉子/
ゆでだこ /茹で蛸/
ゆでめん /茹で麺/
ゆでん /油田/
ゆとう /湯桶/
ゆとうよみ /湯桶読み/
ゆど /油土/
ゆどうふ /湯豆腐/
ゆどおし /湯通し/
ゆどの /湯殿/
ゆどのさん /湯殿山;地名,山形/
ゆな /湯女/
ゆに /由仁/
ゆにばーさるきばん /ユニバーサル基板/
ゆにゅう /輸入/
ゆにゅうきんし /輸入禁止/
ゆにゅうぎゅう /輸入牛/
ゆにゅうぎょうしゃ /輸入業者/
ゆにゅうけん /輸入権/
ゆにゅうざい /輸入材/
ゆにゅうざっか /輸入雑貨/
ゆにゅうしゃ /輸入車/輸入者/
ゆにゅうしゅぼば /輸入種牡馬/
ゆにゅうしょ /輸入書/
ゆにゅうしょう /輸入商/
ゆにゅうしょくざい /輸入食材/
ゆにゅうしんこく /輸入申告/
ゆにゅうしんこくしょ /輸入申告書/
ゆにゅうじ /輸入時/
ゆにゅうじゆうか /輸入自由化/
ゆにゅうせんもん /輸入専門/
ゆにゅうぜい /輸入税/
ゆにゅうだいこう /輸入代行/
ゆにゅうだいりてん /輸入代理店/
ゆにゅうちょうか /輸入超過/
ゆにゅうにく /輸入肉/
ゆにゅうはんばい /輸入販売/
ゆにゅうば /輸入馬/
ゆにゅうばん /輸入盤/輸入版/
ゆにゅうばんせんもんてん /輸入盤専門店/
ゆにゅうばんてん /輸入盤店/
ゆにゅうばんや /輸入盤屋/
ゆにゅうひよう /輸入費用/
ゆにゅうひん /輸入品/
ゆにゅうぶつ /輸入物/
ゆにゅうまい /輸入米/
ゆにゅうもと /輸入元/
ゆにゅうもの /輸入物/
ゆにゅうりょう /輸入量/
ゆにょうかん /輸尿管/
ゆにわ /斎場;清めて/斎庭;=斎場/弓庭;射術場/
ゆのかわ /湯ノ川/湯野川/
ゆのき /柚木/
ゆのたに /湯之谷/
ゆのつ /温泉津/
ゆのはな /湯の花/
ゆのはま /湯野浜/
ゆのはまおんせん /湯野浜温泉/
ゆのまえ /湯前/
ゆのみ /湯呑み/湯飲み/
ゆのみぢゃわん /湯飲み茶碗/湯呑み茶碗/
ゆはず /弓弭;弓弦をかける所/
ゆはた /纈/
ゆはら /湯原/
ゆば /湯葉/弓場/湯波/湯場/
ゆばら /湯原/
ゆばり /尿/
ゆび /指/趾;足のゆび/
ゆびあな /指孔/
ゆびいっぽん /指一本/
ゆびいっぽんぶん /指一本分/
ゆびいん /指印/
ゆびおり /指折り/
ゆびき /湯引き/
ゆびきり /指切り/
ゆびさき /指先/
ゆびさし /指差し;-確認/
ゆびさしかくにん /指差確認/
ゆびさっく /指サック;事務用品/
ゆびずもう /指相撲/
ゆびづかい /指使い/指遣い/
ゆびにんぎょう /指人形/
ゆびぬき /指貫/指貫き/
ゆびばん /指板/
ゆびひき /指弾き/
ゆびぶえ /指笛;口に指を入れてピーと鳴らします/
ゆびもじ /指文字/
ゆびわ /指輪/指環/
ゆびわものがたり /指輪物語/
ゆふ /由府/
ゆふいん /湯布院;町名/由布院;温泉名/
ゆふね /湯舟/
ゆふばえ /夕暎え/
ゆぶね /湯船/湯舟/湯ぶね/
ゆぶん /油分/
ゆぷしろん /υ;upsilon/Υ;Upsilon/
ゆべし /柚餅子/
ゆま /由真/
ゆまく /油膜/
ゆまり /尿/
ゆみ /弓/由美/裕美/優美/有美/友美/由実/祐未/祐美/有望/宙美/
ゆみえ /由美恵/弓技/
ゆみおか /弓岡/
ゆみか /由美香/
ゆみがた /弓形/
ゆみがはま /弓ヶ浜/
ゆみこ /由美子/弓子/裕美子/優美子/祐美子/有美子/祐三子/友美子;名/佑三子/
ゆみし /弓師/
ゆみず /湯水/
ゆみそ /柚味噌/
ゆみた /弓田/
ゆみつくり /弓造り/
ゆみづかい /弓使い/
ゆみづる /弓弦/
ゆみとり /弓取り;[相撲]/弓取/
ゆみなか /弓仲/
ゆみなが /弓長/
ゆみなり /弓形;NB:「ゆみがた」「きゅうけい」と同形/
ゆみの /弓野/
ゆみはじめ /弓始/
ゆみはず /弓筈/
ゆみはり /弓張/
ゆみはりづき /弓張り月/
ゆみば /弓場/
ゆみへい /弓兵/
ゆみへん /弓偏/
ゆみや /弓矢/
ゆむき /湯剥き;トマトを-する/
ゆむら /湯村/
ゆむらおんせん /湯村温泉/
ゆめ /夢/梦;「夢」の異体字/結女/努/
ゆめあわせ /夢合せ/
ゆめいっぱい /夢一杯/
ゆめいろ /夢色/
ゆめうつつ /夢現/
ゆめうらない /夢占い/
ゆめおち /夢オチ/
ゆめかかく /夢価格/
ゆめがたり /夢語り/
ゆめきこう /夢紀行/
ゆめきぶん /夢気分/
ゆめこ /夢子/
ゆめこうぼう /夢工房/
ゆめごこち /夢心地/
ゆめさき /夢前/
ゆめさら /夢更/
ゆめじ /夢路/夢二;名/
ゆめぞの /夢園/
ゆめでんせつ /夢伝説/
ゆめと /夢人/
ゆめどの /夢殿/
ゆめの /夢野/
ゆめのうきはし /夢浮橋/
ゆめのきゅうさく /夢野久作/
ゆめのしま /夢の島/
ゆめはんだん /夢判断/
ゆめぼうけん /夢冒険/
ゆめまくら /夢枕/
ゆめまぼろし /夢幻/
ゆめみ /夢見/
ゆめみごこち /夢見心地/
ゆめものがたり /夢物語/
ゆめゆめ /努々;-忘れるな/夢々/努努/夢夢/
ゆめよ /夢代/
ゆもじ /湯文字/
ゆもと /湯本/湯元/
ゆや /湯屋/油谷/
ゆやま /湯山/
ゆゆ /結由/
ゆゆしき /由々しき/
ゆようせい /油溶性;[化学]oil soluble/
ゆよく /湯浴/
ゆら /由良/
ゆらい /由来/
ゆらいがき /由来書/
ゆらおんせん /由良温泉/
ゆらぎ /揺らぎ/
ゆらく /愉楽/
ゆらのすけ /由良之助/
ゆらめき /揺らめき/
ゆらんかん /輸卵管/
ゆり /百合/祐里/有里/由梨/由利/祐理/友理/由里/友梨/由理/憂里/友利/岼/閖/
ゆりあげ /閖上/
ゆりあげこう /閖上港/
ゆりあにあもく /ユリアニア目/Julianiales/
ゆりいす /揺り椅子;rocking chair/
ゆりうすれき /ユリウス暦;ローマの暦法/
ゆりえ /友里恵/由梨絵/百合枝/
ゆりか /ユリ科/百合科/優里香/Liliaceae/
ゆりかえし /揺り返し/
ゆりかご /揺り籠/
ゆりかもめ /百合鴎/
ゆりこ /百合子/ゆり子/由里子/由利子/祐里子/祐理子/
ゆりこう /ユリ綱/Liliopsida/
ゆりね /百合根/
ゆりのちょう /百合野町/
ゆりみ /有里巳/
ゆりもく /ユリ目/Liliales/
ゆりもくあぐん /ユリ目亜群/
ゆりもくぐん /ユリ目群/
ゆりもどし /揺り戻し/
ゆりょう /湯量/油糧;†油脂など/油量;†アブラの多さ/油料;†油の原料となる/
ゆりょうさくもつ /油料作物/
ゆりょうほうふ /湯量豊富/
ゆる /緩/百合;[古語]ユリ/閖;ゆり?/
ゆるがせ /忽せ/忽/
ゆるぎ /揺るぎ/
ゆるしいろ /聴し色;⇔禁色(きんじき)/
ゆるすまじ /許すまじ/
ゆるみ /緩み/弛み/
ゆるやか /緩やか/
ゆるゆる /緩々/緩緩/揺る揺る/
ゆるり /緩り/
ゆれ /揺れ/
ゆれも /揺藻/
ゆわかし /湯沸し/
ゆわかしき /湯沸器/湯沸かし器/湯沸かし機/
ゆわり /湯割り/
ゆゑ /故/
ゆゑん /所以/
ゆん /潤/
ゆんぜい /弓勢/
ゆんで /弓手;左手/左手/
ゆんべ /昨夜/
ゆんも /潤模/
よ /代/世/余/夜/与;貸与/予;予定/預;預金/輿;(こし)輿論/歟;(か)/誉;名誉/四/畭/舁;か・く/蕷;薯蕷/飫/丗;「世」の異体字/豫;「予」の旧字/餘;「余」の旧字/與;「与」の旧字(人名用漢字)/譽;「誉」の旧字/弥;?/
よ> /四/夜;夜桜,夜更し,夜軍(よいくさ)/
よーどらん /ヨード卵/
よーろっぱ /欧羅巴/歐羅巴/
よーろっぱじん /ヨーロッパ人/
よあかし /夜明し/
よあけ /夜明け/
よあけがた /夜明け方/
よあけまえ /夜明け前/
よあそび /夜遊び/
よあつ /与圧;pressurise/予圧;preload/
よあらし /夜嵐/
よあるき /夜歩き/
よい /宵/酔/酔い/余威/良い/
よいき /余域/
よいこ /良い子/よい子/
よいごこち /酔い心地/酔心地/
よいごし /宵越し/
よいざまし /酔い覚まし/
よいた /与板/
よいち /余市/夜市/世一/四一/
よいっぱり /宵っ張り/
よいづき /宵月/
よいづきよ /宵月夜/
よいづみ /宵積み/
よいど /余緯度/
よいどめ /酔い止め/
よいどれ /酔いどれ/
よいね /宵寝/
よいのくち /宵の口/
よいのみょうじょう /宵の明星;the morning star (金星)/
よいまち /宵待/宵待ち/
よいまちぐさ /宵待草/
よいまつり /宵祭/
よいみや /宵宮/
よいやま /宵山/
よいやみ /宵闇/
よいん /余韻/余音/餘韻;「余」旧字/餘音;「余」旧字/
よいんし /余因子/
よいんしぎょうれつ /余因子行列/
よいんじょうじょう /余韻嫋々/余韻嫋嫋/
よう /用/様/要/洋/幼/杳;-として/陽/養/葉;葉脈/窯;かま/窰;「窯」の異体字/羊;羊肉/佯;佯狂/恙;つつが/痒;痛痒/癰;[医]carbuncle/廱;やわらぐ/曜;曜日/耀;栄耀/燿;かがやく/妖;妖怪/夭;夭折/殀;殀折(=夭折)/揚;揚水/楊;(やなぎ)楊枝/昜;あがる/暘;(日の出)/煬;煬帝/瘍;腫瘍/幺;ちいさい/雍;冉雍/壅;(ふさぐ)壅塞/擁;擁護/拗;執拗/窈;窈窕/容;容態/溶;溶液/熔;熔融/鎔;「熔」の異体字/榕/穃/蓉;芙蓉/傭;傭兵/庸;凡庸/慵;ものうい/甬/踊;舞踊/踴;「踊」の異体字/俑;兵馬俑/蛹;(さなぎ)蛹化/慂;慫慂/揺;動揺/搖;「揺」の旧字(人名用漢字)/謡;民謡/謠;「謡」の旧字(人名用漢字)/遥;(はる・か)逍遥/遙;「遥」の旧字(人名用漢字)/徭;雑徭/瑶/瑤;「瑶」の旧字/癢;かゆい/瀁;(水のたゆたう様子)/漾;ただよう/樣;「様」の旧字(人名用漢字)/瓔;瓔珞/珱;「瓔」の異体字/鷹;たか/膺;膺懲/厭;いや/腰;こし/陶;陶器(とうき)/姚/孕;はら・む/曄/邀;邀撃/泱;(漢音)/怏;(漢音)/八;八日/
よう> /要;(require) -2G/洋;(western) 洋室,洋楽器,洋学校/陽;(positive) 陽画,陽旋法,陽電子 ⇔陰/養;(adoptive) 養父母, (飼育) 養蚕/幼;(infant) 幼獣,幼猫,幼保/
ようあん /溶暗/
ようい /用意/容易/妖異/洋医/
よういおん /陽イオン/
よういく /養育/
よういくひ /養育費/
よういしゅうとう /用意周到/
よういせい /容易性/
よういち /洋一/陽一/要一/暢一/
よういちろう /洋一郎/陽一郎/曜一郎/
よういん /要因;factor/要員;personnel/
よういんりろん /要因理論/
ようえい /揺曳/
ようえき /溶液/葉腋/用役;service/用益;use and benefit/徭役/
ようえきさいばい /養液栽培/
ようえきち /要役地/
ようえきちゅう /溶液中/
ようえきるい /溶液類/
ようえん /妖艶/陽炎/葉縁/揺炎/
ようおん /拗音/
ようおんかい /陽音階/
ようか /八日/八鹿;地名/蛹化/ヨウ化/妖花/養家/沃化;[化学]*I 「-カリウム,-銀」/８日/8日/
ようかい /妖怪/溶解/容喙;口を挟む/熔解;≒溶解/鎔解;≒溶解/
ようかいえき /溶解液/
ようかいご /要介護/
ようかいごにんてい /要介護認定/
ようかいせい /溶解性/
ようかいち /八日市/
ようかいちば /八日市場/
ようかいど /溶解度;[化学]solubility/
ようかいどきょくせん /溶解度曲線/
ようかいどせき /溶解度積;[化学]solubility product/
ようかいねつ /溶解熱/
ようかいへんげ /妖怪変化/
ようかいりょく /溶解力/
ようかいろ /溶解炉/
ようかかん /八日間/8日間/
ようかぎん /沃化銀;[化学]AgI/ヨウ化銀/
ようかくにん /要確認/
ようかすいそ /沃化水素;[化学]HI/ヨウ化水素/
ようかた /養方/
ようかぶつ /沃化物;[化学]/ヨウ化物/
ようかん /洋館/羊羹/陽関/腰間/羊羮;異体字/
ようかんすう /陽関数/
ようが /洋画/用賀;地名/幼芽;[植物]budlet/葉芽;[植物]leaf bud. ⇔花芽/陽画;⇔陰画/
ようがい /要害/
ようがいけんご /要害堅固/
ようがく /洋楽;⇔邦楽/洋学;⇔和学,漢学/幼学;10歳/
ようがけい /洋画系/
ようがげきじょう /洋画劇場/
ようがさ /洋傘/
ようがし /洋菓子/
ようがしてん /洋菓子店/
ようがっき /洋楽器/
ようがっこう /洋学校/
ようがらし /洋辛子/洋芥子/
ようがわら /洋瓦/
ようがん /溶岩/熔岩;=溶岩/容顔;顔つき/
ようがんりゅう /溶岩流/
ようき /容器/陽気/用器/妖気/妖鬼/
ようきちゅう /容器中/
ようきひ /楊貴妃;唐の玄宗に愛された美女/
ようきほあんきそく /容器保安規則/
ようきゅう /要求/洋弓/楊弓/
ようきゅうがく /要求額/
ようきゅうがわ /要求側/
ようきゅうきのう /要求機能/
ようきゅうこうもく /要求項目/
ようきゅうしつ /要求室/
ようきゅうしゃ /要求者/
ようきゅうしょ /要求書/
ようきゅうしょり /要求処理/
ようきゅうしよう /要求仕様/
ようきゅうしようしょ /要求仕様書/
ようきゅうじこう /要求事項/
ようきゅうじょうけん /要求条件/
ようきゅうすいじゅん /要求水準/
ようきゅうせいのう /要求性能/
ようきゅうちゅう /要求中/
ようきゅうていぎ /要求定義/
ようきゅうてん /楊弓店/
ようきゅうどおり /要求通り/
ようきゅうないよう /要求内容/
ようきゅうなど /要求等/
ようきゅうば /楊弓場/
ようきゅうばらいよきん /要求払預金/
ようきゅうひん /要求品/
ようきゅうぶつ /要求物/
ようきゅうぶん /要求文/
ようきゅうぶんせき /要求分析/
ようきゅうまち /要求待ち/
ようきゅうめいれい /要求命令/
ようきょう /容共;⇔反共/佯狂/
ようきょうか /要強化/
ようきょく /謡曲/陽極/
ようきょくがわ /陽極側/
ようきょくせん /陽極線/
ようきん /用金/溶菌/洋琴/要緊/洋斤;£/洋禽/
ようぎ /容疑/要義/容儀/
ようぎしゃ /容疑者/
ようぎょ /幼魚/養魚/
ようぎょう /窯業/
ようぎょじょう /養魚場/
ようぎん /洋銀/
ようくぎ /洋釘/
ようくん /幼君/
ようぐ /用具/要具/庸愚/
ようぐんがん /羊群岩/
ようけい /養鶏/葉茎/葉形/幼形/
ようけいぎょう /養鶏業/
ようけいさいるい /葉茎菜類;[園芸]ネギ・アスパラなど/
ようけいじょう /養鶏場/
ようけいせいじゅく /幼形成熟/
ようけつ /溶血/要訣/
ようけん /要件;†requirement.「-を満たす」/用件;†business.「ご-は何でしょう」/洋犬/楊堅;隋の皇帝/
ようけんじじつ /要件事実/
ようけんとう /要検討/
ようけんどう /養賢堂/
ようげき /要撃/邀撃;=要撃/要劇;very busy/
ようげん /用言/揚言/妖言/
ようげんか /溶原化/
ようこ /陽子/洋子/葉子/容子/耀子/よう子/瑤子/暢子/庸子/妖子/妖狐/羊子/楊子/揚子/
ようこう /要項;†points.「募集-」/要綱;†outline.「指導-」/陽光/用高/洋行/要港/妖光/
ようこうかん /要交換/
ようこうしゅう /要項集/
ようこうだい /洋光台/
ようこうろ /溶鉱炉/鎔鉱炉/鎔鉱爐/
ようこく /陽刻;⇔陰刻/
ようこん /幼根/
ようご /用語/養護;†care.「老人の-」/擁護;†protect.「権利の-」/用後/洋語/
ようごう /影向/
ようごがっこう /養護学校/
ようごきょうゆ /養護教諭/
ようごしせつ /養護施設/
ようごしゅう /用語集/
ようごじしょ /用語辞書/
ようごじてん /用語辞典/
ようごせつめい /用語説明/
ようごは /擁護派/用語派/
ようごへん /用語編/
ようごほう /用語法/
ようごろん /擁護論/
ようさい /要塞/洋裁/洋才/
ようさいあと /要塞跡/
ようさいか /要塞化/
ようさいこうげき /要塞攻撃/
ようさいとし /要塞都市/
ようさいない /要塞内/
ようさいるい /葉菜類/
ようさん /葉酸/養蚕/洋算/
ようさんぎょう /養蚕業/
ようざい /溶剤/用材/
ようざっし /洋雑誌/
ようざら /洋皿/
ようざん /腰斬/要斬/
ようし /用紙/要旨/容姿/養子/陽子/洋紙;⇔和紙/羊歯/夭死/羊脂/
ようしえん /要支援/
ようしえんぐみ /養子縁組/
ようしえんぐみとどけ /養子縁組届/
ようしき /様式;†pattern.「ロココ-」/洋式;†western.「-便器」/要式;†formal.「-行為」/
ようしきじょう /様式上/
ようしきび /様式美/
ようしきふう /洋式風/
ようしきべんき /洋式便器/
ようしし /養嗣子/
ようししてい /用紙指定/
ようししゅう /要旨集/
ようしせってい /用紙設定/
ようしたんれい /容姿端麗/
ようしつ /洋室/溶質/
ようしつき /用紙付き/
ようしはば /用紙幅/
ようしば /洋芝/
ようしゃ /容赦/用捨/幼者/
ようしゅ /洋酒/洋種/楊朱/
ようしゅう /揚州/
ようしゅうり /要修理/
ようしゅつ /溶出/
ようしゅん /陽春/
ようしゅんはくせつ /陽春白雪/
ようしょ /洋書/要所/
ようしょう /幼少/要衝/葉鞘/
ようしょうき /幼少期/
ようしょうじ /幼少時/
ようしょうりば /洋書売場/
ようしょく /洋食/養殖/要職/容色/
ようしょくいけ /養殖池/
ようしょくうお /養殖魚/
ようしょくぎょ /養殖魚/
ようしょくじょう /養殖場/
ようしょくもの /養殖物/
ようしょくや /洋食屋/
ようしょくよう /養殖用/
ようしょせんもんてん /洋書専門店/
ようしょてん /洋書店/
ようしょや /洋書屋/
ようしょようしょ /要所要所/
ようしろう /陽志郎/
ようしん /葉身/養親/
ようしんし /養親子/
ようじ /用事/幼児/用字;字の用い方/楊枝/楊子;=楊枝/要事/幼時;infancy/洋二;人名/洋治/洋司/洋次/陽二/陽治/陽司/耀司/庸治/陽次/庸次/曜示/
ようじあいて /幼児相手/
ようじうお /楊子魚/
ようじか /幼児化/
ようじき /幼児期/
ようじきょういく /幼児教育/
ようじご /幼児語/
ようじせい /幼児性/
ようじたいけい /幼児体型/
ようじたいけん /幼児体験/
ようじてき /幼児的/
ようじばんぐみ /幼児番組/
ようじほう /用字法/
ようじゃく /幼若/幼弱/
ようじゃくほるもん /幼若ホルモン;[生物]juvenile hormone/
ようじゅう /妖獣/
ようじゅつ /妖術/
ようじゅつし /妖術師;sorceror/
ようじょ /幼女/養女/妖女/葉序/
ようじょう /養生/洋上/葉状/横笛/
ようじょうくん /養生訓;貝原益軒(1713)/
ようじょうたい /葉状体/
ようじよう /幼児用/
ようじようご /用字用語/
ようじろう /洋次郎/陽治郎/
ようじん /用心/要人;VIP/洋人;westerner/要心;=用心/
ようじんぼう /用心棒/
ようす /様子/容子;≒様子/
ようすい /用水;irrigation/揚水;pump up/羊水/陽水;人名/
ようすいちえきけん /用水地役権/
ようすいろ /用水路/
ようすけ /洋介/陽介/洋輔/庸介/洋祐/葉介/洋助/
ようすこう /揚子江/
ようすみ /様子見/
ようするに /要するに/
ようず /要図/
ようずみ /用済み/
ようせい /養成/要請/妖精/陽性/幼生/妖星/夭逝/葉性/
ようせいかい /妖精界/
ようせいがっこう /養成学校/
ようせいきかん /養成機関/
ようせいこうざ /養成講座/
ようせいしせつ /養成施設/
ようせいしょ /要請書/
ようせいじょ /養成所/
ようせいせいしょく /幼生生殖/
ようせいぞく /妖精族/
ようせいたち /妖精達/
ようせいちゅう /養成中/
ようせいはんのう /陽性反応/
ようせいぶん /要請文/
ようせき /容積/陽石;cf.陽物/
ようせきりつ /容積率/
ようせつ /溶接/夭折/要説/熔接;=溶接/殀折;=夭折/
ようせつぶ /溶接部/
ようせん /用船/傭船/用箋/
ようせんけいやく /傭船契約/
ようせんぽう /陽旋法/
ようぜいてんのう /陽成天皇/
ようそ /要素/沃素;I/ヨウ素/I/Iodine/
ようそう /様相/洋装/
ようそうぼん /洋装本/
ようそうろんり /様相論理/
ようそかん /要素間/
ようそぎじゅつ /要素技術/
ようそぎじゅつかいはつ /要素技術開発/
ようそく /壅塞/
ようそぐん /要素群/
ようそしゅぎ /要素主義/
ようそすう /要素数/
ようそちょう /要素長/
ようそばんごう /要素番号/
ようそぶんかつ /要素分割/
ようそわ /要素和/
ようそん /養鱒/
ようぞう /洋三/陽三/容三/
ようぞん /溶存/
ようた /洋太/
ようたい /様態;mode/容態;condition/容体;=容態/溶体;[化学]solution/
ようたし /用達/用足し/
ようたつ /用達/
ようたろう /洋太郎/
ようだ /様だ/
ようだい /容態/容体;=容態/煬帝;隋王朝の第二代皇帝/
ようだこ /洋凧/
ようだん /用談;business talk/要談;important talk/
ようだんす /用箪笥/洋箪笥/洋ダンス/
ようち /用地/幼稚/要地;key area/夜討/夜討ち/
ようちあさがけ /夜討ち朝駆け/
ようちえん /幼稚園/
ようちえんきょうゆ /幼稚園教諭/
ようちえんじ /幼稚園児/
ようちえんじだい /幼稚園時代/
ようちえんせい /幼稚園生/
ようちさんぎょう /幼稚産業;[経済]infant industry/
ようちしゃ /幼稚舎/
ようちばいしゅう /用地買収/
ようちぶ /幼稚部/
ようちゅう /幼虫/幼沖;おさない/鎔鑄/
ようちゅうい /要注意/
ようちゅういかしょ /要注意箇所/
ようちゅうじだい /幼虫時代/
ようちょう /羊腸;gut/膺懲;討ち懲らす/窈窕;たおやか/
ようちん /葉枕;[植物]pulvinus/永沈;浄土双六の地獄/
ようつい /腰椎/
ようついますい /腰椎麻酔;[医]/
ようつう /腰痛/
ようてい /要諦;point/揚程;pump head/羊蹄;-山(北海道)/幼帝/
ようていざん /羊蹄山/
ようてん /要点/陽転/
ようでんき /陽電気/
ようでんし /陽電子/
ようでんしずのう /陽電子頭脳/
ようと /用途/
ようとう /羊頭/洋燈;異体字/洋灯;lamp/洋島/妖刀/
ようとうくにく /羊頭狗肉/
ようとして /杳として/
ようとじ /洋綴じ/
ようとちいき /用途地域;(都市計画法)/
ようとへんこう /用途変更/
ようとべつ /用途別/
ようとん /養豚/
ようど /用土;soil/用度;supply/沃度;I/
ようどう /揺動;swing/陽動;feint.「-作戦」/幼童/
ようどうさくせん /陽動作戦/
ようどがかり /用度掛/
ようなし /洋梨/用無し/洋ナシ/洋なし/
ように /様に/用に/陽に/
ようにく /羊肉/葉肉/
ようにん /容認/用人/傭人/遥任/
ようねん /幼年/
ようねんき /幼年期/
ようねんし /幼年誌/
ようねんじだい /幼年時代/
ようねんへい /幼年兵/
ようのすけ /陽之助/洋之介/
ようは /要は;in short/
ようはい /遥拝/腰佩/
ようはいがん /羊背岩/
ようはく /洋白/
ようはつ /洋髪/
ようはん /洋販/鎔笵/羊斑/
ようば /妖婆/
ようばい /溶媒/楊梅/
ようばいひ /楊梅皮/
ようばん /洋盤/用番/
ようひ /要否/
ようひし /羊皮紙/
ようひつ /用筆/
ようひん /用品;goods/洋品;洋風の服飾品/
ようひんてん /洋品店;men's shop/用品店;(複合して)ゴルフ-/
ようひんや /用品屋/
ようび /曜日/妖美/
ようびごと /曜日毎/
ようびべつ /曜日別/
ようびめい /曜日名/
ようびよやく /曜日予約/
ようふ /養父/用布/妖婦/
ようふう /洋風/
ようふうけんちく /洋風建築/
ようふく /洋服/
ようふくだい /洋服代/
ようふくだんす /洋服箪笥/
ようふくや /洋服屋/
ようふくよう /洋服用/
ようふぼ /養父母/
ようふよう /要不要/
ようぶ /腰部/洋舞/
ようぶつ /陽物/
ようぶつけいやく /要物契約/
ようぶん /養分/洋文/陽文/幼文/
ようへい /傭兵;mercenary/葉柄/用兵;tactics/洋平;人名/傭聘;招き雇う/
ようへいたい /傭兵隊/
ようへき /擁壁/
ようへん /窯変/葉片/曜変/耀変;=曜変/
ようへんこう /要変更/
ようべん /用便/
ようほ /幼保;[略語]幼稚園と保育園/
ようほう /用法/養蜂/陽報/妖法/
ようほうじばん /要法寺版/
ようほうじょう /養蜂場/
ようほん /洋本/
ようぼ /養母/
ようぼう /要望/容貌/杳茫/
ようぼうあん /要望案/
ようぼうかいい /容貌魁偉/
ようぼうしょ /要望書/
ようぼうしょていしゅつ /要望書提出/
ようぼうじこう /要望事項/
ようぼうないよう /要望内容/
ようぼく /用木/幼木/
ようま /妖魔/洋間/
ようまく /羊膜/
ようまつ /洋松/
ようまん /養鰻/
ようみゃく /葉脈/
ようみゃくけい /葉脈系/
ようみょう /幼名/
ようむ /用務;用事。「-員」/要務;重要な任務/妖霧/遥夢/洋鵡/
ようむいん /用務員/
ようむいんしつ /用務員室/
ようむき /用向き/
ようむさき /用務先/
ようめい /用命/幼名/養命/溶明/
ようめいがく /陽明学/
ようめいしゅ /養命酒/
ようめいしゅせいぞう /養命酒製造/
ようめいてんのう /用明天皇/
ようめいもん /陽明門/
ようめん /葉面/容面;かおかたち/
ようもう /羊毛/養毛/
ようもうざい /養毛剤/
ようもうぶとん /羊毛布団/
ようもく /要目/
ようもの /洋物/洋モノ/
ようもん /要文/
ようやく /要約/漸く/
ようやくきのう /要約機能/
ようやくひっき /要約筆記/
ようゆう /溶融/熔融/
ようゆうろ /溶融炉/
ようよう /洋々;前途-/揚々;意気-/様々/様様/鷹揚;=おうよう/洋洋/要用/幼葉/揚揚/漸う;(だんだん) -白くなりゆく山際/溶溶/揺揺/妖々/
ようらく /瓔珞;インドの装身具/揺落;揺れ落ちる/
ようらん /要覧/洋蘭/揺籃/洋ラン/
ようらんき /揺籃期/
ようり /養鯉;-業/要理/葉理/
ようりく /揚陸/
ようりくかん /揚陸艦/
ようりつ /擁立/
ようりゃく /要略/
ようりゅう /楊柳/
ようりょう /容量;capacity/要領;point/用量;dose/養料/
ようりょういっぱい /容量一杯/
ようりょうかくほ /容量確保/
ようりょうかんり /容量管理/
ようりょうけいかく /容量計画/
ようりょうげんかい /容量限界/
ようりょうせいげん /容量制限/
ようりょうせってい /容量設定/
ようりょうぞうか /容量増加/
ようりょうてき /容量的/
ようりょうひょうじ /容量表示/
ようりょうぶそく /容量不足/
ようりょうよく /要領良く/
ようりょく /揚力/妖力/
ようりょくけいすう /揚力係数/
ようりょくそ /葉緑素/
ようりょくたい /葉緑体/
ようれい /用例/妖霊/妖麗/
ようれいしゅう /用例集/
ようれき /陽暦/
ようれつ /庸劣/
ようれんきん /溶連菌;溶血性連鎖球菌の略らしい/
ようろ /要路/
ようろう /養老;(年号(717-724))/
ようろういん /養老院/
ようろうのたき /養老の滝/
ようろうほけん /養老保険/
ようろく /要録/
ようろん /要論/
ようわ /養和;年号(1181-1182)/溶和/
ようん /余蘊/
よえい /余映/余栄/
よえつ /与悦/
よえん /余炎/余煙/
よおぎ /八尾木;地名/
よか /余暇/予価/予科/四日;[古語]/餘暇;「余」旧字/
よかかつどう /余暇活動/
よかく /与格;[文法]dative/予覚/余角/余核/
よかじかん /余暇時間/
よかぜ /夜風/
よかつ /余割;[数学]cosec/
よかれ /善かれ/
よかれあしかれ /善かれ悪しかれ/良かれ悪しかれ/
よかれん /予科練/
よかわ /吉川/
よかわほうご /横川法語/
よかん /予感/余寒/豫感;「予」旧字/
よかんてきちゅう /予感的中/
よがたり /夜語り/
よがりごえ /善がり声/
よき /予期/良き/豫期;「予」旧字/
よきょう /余興;divertissement/余響;resonance/餘興;「余」旧字(=余興)/
よきょくいり /余曲入/
よきん /預金/
よきんがく /預金額/
よきんきんり /預金金利/
よきんぎょうむ /預金業務/
よきんこうざ /預金口座/
よきんざんだか /預金残高/
よきんしゃ /預金者/
よきんしゅもく /預金種目/
よきんしょうしょ /預金証書/
よきんつうか /預金通貨/
よきんつうちょう /預金通帳/
よきんとうけつ /預金凍結/
よきんほけんきこう /預金保険機構/
よきんほけんせいど /預金保険制度/
よぎ /夜着/余技/余儀/
よぎしゃ /夜汽車/
よぎた /与北/
よぎょう /余業/
よぎり /夜霧/
よく /欲;desire/翼;wing/翌;next/浴;bath/抑;抑圧/沃;肥沃/弋;遊弋/杙;くい/翊/峪;たに/慾;「欲」の旧字/良く/緘;?/
よく> /翌/
よくあさ /翌朝/
よくあつ /抑圧/
よくあつしゃ /抑圧者/
よくあつてき /抑圧的/
よくあつほう /抑圧法/
よくい /浴衣/
よくうかん /余空間/
よくうつ /抑鬱/
よくうつしょう /抑鬱症;[精医]鬱病/
よくか /翼果/
よくかい /欲界/
よくがた /翼型/
よくき /翌期/
よくけ /欲気/
よくけい /翼形/
よくげつ /翌月/
よくげつごう /翌月号/
よくげつばらい /翌月払い/
よくげつぶん /翌月分/
よくこうるい /翼甲類/
よくご /浴後/
よくさん /翼賛/
よくし /抑止/
よくしこうか /抑止効果/
よくしつ /浴室/
よくしつかんそうき /浴室乾燥機/
よくしつよう /浴室用/
よくしゅう /翌週/翌秋/
よくしゅりゅう /翼手竜/
よくしゅるい /翼手類/
よくしゅん /翌春/
よくしりょく /抑止力/
よくしん /欲心/慾心;=欲心/
よくじつ /翌日/
よくじつぶん /翌日分/
よくじつゆうがた /翌日夕方/
よくじょう /浴場;bath/欲情;desire/翼状/慾情;=欲情/抑情/
よくせい /抑制/
よくせいがた /抑制型/
よくせいこうか /抑制効果/
よくせいさいばい /抑制栽培/
よくせいさいぼう /抑制細胞/
よくせいさく /抑制策/
よくせいざい /抑制剤/
よくせいしゅほう /抑制手法/
よくせいせい /抑制性/
よくせいてき /抑制的/
よくせいぶっしつ /抑制物質/
よくせき /翌夕/
よくそう /浴槽/
よくそくじ /抑速時/
よくたん /翼端/
よくち /沃地/
よくちょう /翌朝/翼長/
よくと /yocto;[SI接頭語]y,10^-24/
よくとく /欲得/
よくとくずく /欲得尽く/
よくとし /翌年/
よくど /沃土/
よくどう /欲動/
よくねん /翌年/欲念/
よくねんど /翌年度/
よくのかわ /欲の皮;-が突っ張る/
よくばり /欲張り/欲張/
よくばん /翌晩/
よくふか /欲深/
よくぼう /欲望/慾望;「欲」旧字/
よくぼけ /欲ボケ/
よくめ /欲目/
よくめん /翼面/
よくめんかじゅう /翼面荷重;wing load/
よくめんせき /翼面積/
よくや /沃野/翌夜/
よくよう /抑揚/浴用/
よくようとんざ /抑揚頓挫/
よくよく /翌々/翼々/善く善く/能く能く;-懲りたのだろう/
よくよくげつ /翌々月/翌翌月/
よくよくじつ /翌々日/翌翌日/
よくよくねん /翌々年/翌翌年/
よくりゅう /抑留/翼竜;pterosaur/翼龍/
よくりゅうしゃ /抑留者/
よくれつ /翼列/
よくん /余薫/
よぐち /与口/
よけい /余計/余慶;おかげ/餘計;「余」旧字/
よけいもの /余計者;除け者/余計物;無用の長物/
よけつ /預血/
よけん /予見/与件/豫見;「予」旧字/
よげつ /余月/
よげん /予言;†predict.「未来を予言する」/預言;†prophecy.「神の預言」/余弦;cosine/豫言;「予」旧字/
よげんかんすう /余弦関数;[数学]cosine function/
よげんきょくせん /余弦曲線/
よげんしゃ /預言者;†神の言葉を伝える人/予言者;†未来を言い当てる人/
よげんしょ /予言書;†未来予知の本/預言書;†神の言葉が書かれた本/
よげんていり /余弦定理;[数学]cosine theorem/
よげんは /余弦波/
よこ /横/─;罫線/━;太い罫線/
よこ> /横;横座り,横恋慕,横吹雪/
よこあい /横合い/横合/
よこあな /横穴/
よこあめ /横雨/
よこあるき /横歩き/
よこい /横井/
よこいた /横板/
よこいち /横位置/
よこいちれつ /横一列/
よこいっせん /横一線/
よこいっちょくせん /横一直線/
よこいと /横糸/緯糸/
よこいどう /横移動/
よこう /予行/予稿/余香/余光/
よこうえんしゅう /予行演習/
よこうげんこう /予稿原稿/
よこうしゅう /予稿集/
よこうしゅうだい /予稿集代/
よこうち /横内/
よこうれんしゅう /予行練習/
よこえ /横絵/
よこお /横尾/
よこおき /横置き/横置/
よこかいてん /横回転/
よこかぜ /横風/
よこかぜちゃくりく /横風着陸/
よこかべ /横壁/
よこかわ /横川/横河/
よこかわえき /横川駅/
よこかわでんき /横河電気/
よこがお /横顔/
よこがき /横書き/横書/
よこがく /横額/
よこがた /横型/
よこがみ /横髪/横紙/
よこがみやぶり /横紙破り/
よこがめん /横画面/
よこがわ /横川/横河/
よこがわでんき /横河電機;[企業名]/
よこぎ /横木/
よこく /予告/与国;同盟国/豫告;「予」旧字/
よこくかんばん /予告看板/
よこくとう /予告灯/
よこくとうき /予告登記/
よこくひょうしき /予告標識/
よこくへん /予告編/予告篇/
よこくよう /予告用/
よこくら /横倉/
よこぐみ /横組/
よこぐも /横雲/
よこぐるま /横車/
よこけい /横罫/
よこげり /横蹴り/
よここうず /横構図/
よここくだい /横国大/
よこごし /横越/
よこさと /横里/
よこざ /横座/
よこざひょう /横座標/
よこざま /横方/横様/横樣;旧字/
よこざわ /横沢/
よこざん /横桟/
よこしば /横芝/
よこしほうがため /横四方固め/
よこしま /邪/横島/辟/奸/邪ま/横しま;-な考え/
よこじく /横軸/
よこじくじょう /横軸上/
よこじま /横縞/
よこすか /横須賀/
よこすかえき /横須賀駅/
よこすかきち /横須賀基地/
よこすかし /横須賀市/
よこすかせん /横須賀線/
よこすかどうろ /横須賀道路/
よこすくろーる /横スクロール/
よこすじ /横筋/
よこすべり /横滑り/
よこずき /横好き;新辞林より：うまくもないのに，むやみに好きなこと。「下手（へた）の―」/
よこずれ /横ずれ/
よこずわり /横座り/
よこせ /横瀬/
よこせん /横線/─;罫線/━;太い罫線/
よこた /横田/
よこたきち /横田基地/
よこたに /横谷/
よこだおし /横倒し/
よこだき /横抱き/
よこちょう /横丁/横町;=横丁/
よこっつら /横っ面/
よこっとび /横っ飛び/横っ跳び/
よこっぱら /横っ腹/
よこつか /横塚/
よこつら /横面/
よこづけ /横付け/
よこづな /横綱/
よこづなきゅう /横綱級/
よこづなしょうしん /横綱昇進/
よこづなしんぎいいんかい /横綱審議委員会/
よこづなずもう /横綱相撲/
よこづみ /横積/
よこて /横手/
よこてさん /横手山/
よこてなげ /横手投げ;sidearm throw/
よこてやま /横手山/
よこで /横手/
よことじ /横綴じ/
よことば /夜言葉/
よことび /横飛び/横跳び/
よこどい /横樋/
よこどり /横取り/
よこなが /横長/
よこなががめん /横長画面/
よこながし /横流し/
よこながばん /横長版/
よこながれ /横流れ/
よこなぐり /横殴り/
よこなげ /横投げ/
よこなみ /横波/横並/
よこならび /横並び;横に並ぶこと。また差のない事。/
よこね /横根/横寝/
よこの /横野/
よこのり /横乗り;バイクに-する/
よこはいり /横入り/
よこはね /横羽/
よこはば /横幅/横巾/
よこはま /横浜/横濱;「浜」旧字/
よこはまありーな /横浜アリーナ/
よこはまいちりつだい /横浜市立大/
よこはまえき /横浜駅/
よこはまえきにしぐち /横浜駅西口/
よこはまかん /横浜間/
よこはまがた /横浜方/
よこはまがわ /横浜側/
よこはまきゅうじょう /横浜球場/
よこはまきんこう /横浜近郊/
よこはまぎんこう /横浜銀行/
よこはまけいむしょ /横浜刑務所/
よこはまけんきゅうじょ /横浜研究所/
よこはまこう /横浜港/横浜高/
よこはまこうえん /横浜公演/
よこはまこうじょう /横浜工場/
よこはまこうほく /横浜港北/
よこはまこくだい /横浜国大/
よこはまこくりつだいがく /横浜国立大学/
よこはまごむ /横浜ゴム/
よこはまし /横浜市/
よこはましえい /横浜市営/
よこはましこうほくく /横浜市港北区/
よこはましてん /横浜支店/
よこはましない /横浜市内/
よこはましぶ /横浜支部/
よこはましみん /横浜市民/
よこはましりつだい /横浜市立大/
よこはましりつだいがく /横浜市立大学/
よこはましんどう /横浜新道/
よこはまじけん /横浜事件;[日本史](1942)中央公論と改造を廃刊させた言論弾圧事件/
よこはまじん /横浜人/
よこはませいさくしょ /横浜製作所;[企業名]/
よこはません /横浜線/横浜戦/
よこはませんおおぐちえき /横浜線大口駅/
よこはませんかいそく /横浜線快速/
よこはませんはしもとえき /横浜線橋本駅/
よこはまたいかい /横浜大会/
よこはまたいよう /横浜大洋/
よこはまたかしまや /横浜高島屋/
よこはまちく /横浜地区/
よこはまてん /横浜店/
よこはまとうきゅう /横浜東急/
よこはまにしぐち /横浜西口/
よこはまにしぐちこう /横浜西口校/
よこはまはく /横浜博/
よこはまばん /横浜版/
よこはまほうめん /横浜方面/
よこはままつざかや /横浜松坂屋/
よこはまみつこし /横浜三越/
よこはまもとまち /横浜元町/
よこはまや /横浜屋/横濱屋/
よこはら /横腹/
よこばい /横這い/横ばい/
よこばいかく /横倍角/
よこばしり /横走り/
よこばら /横腹/
よこひょうじ /横表示/
よこひら /横平/
よこふとり /横歩取り/
よこふどり /横歩取り/
よこぶえ /横笛/
よこぶとり /横太り/
よこぶり /横降り/
よこぶんれつ /横分裂/
よこほうこう /横方向/
よこほり /横堀/
よこほん /横本/
よこぼう /横棒/
よこぼり /横堀/
よこまち /横町/
よこまつ /横松/
よこまる /横丸/
よこみ /横見/
よこみぞ /横溝/
よこみぞせいし /横溝正史/
よこみち /横道/
よこみつ /横光/
よこみつりいち /横光利一;新感覚派の作家。『機械』『春は馬車に乗って』/
よこみねでら /横峰寺/
よこむき /横向き/横向/
よこめ /横目/
よこもじ /横文字/
よこもち /横持ち;移送/
よこもの /横物/
よこもり /横森/
よこや /横谷/横矢/横屋/
よこやま /横山/
よこやまたいかん /横山大観;日本画家。『生生流転』/
よこやり /横槍/横やり/
よこゆれ /横揺れ/
よこよこ /横横/
よこよこどう /横横道/
よこれんぼ /横恋慕/
よこわけ /横分/
よこわり /横割り/
よご /予後/余呉;地名/豫後;「予」旧字/
よごころ /世心/
よごと /夜毎/寿詞/
よごふりょう /予後不良/
よごれ /汚れ/
よごれもの /汚れ物;ぱんちゅ/
よごれやく /汚れ役/汚役/
よさ /与謝/良さ/善さ/
よさく /与作/
よさこいぶし /よさこい節;[民謡]土佐./
よさつ /予察/
よさの /与謝野/
よさのあきこ /与謝野晶子;(1878-1942)歌人/
よさのてっかん /与謝野鉄幹;(1873-1935)歌人/
よさぶそん /与謝蕪村;1716-83/
よさぶろう /与三郎/
よさむ /夜寒/
よさめ /夜雨/
よさん /予算/予讃;-線(JR四国)/豫算;「予」旧字/
よさんあん /予算案/
よさんい /予算委;予算委員会/
よさんいいんかい /予算委員会/
よさんかくだい /予算拡大/
よさんかんけい /予算関係/
よさんがい /予算外/
よさんがく /予算額/
よさんきょうしょ /予算教書/
よさんさくげん /予算削減/
よさんじょう /予算上/
よさんせん /予讃線/
よさんそうがく /予算総額/
よさんそしき /予算組織/
よさんちょうか /予算超過/
よさんてき /予算的/
よさんとうにゅう /予算投入/
よさんはいぶん /予算配分/
よさんはん /予算班/
よさんぶそく /予算不足/
よさんへんせい /予算編成/
よさんわく /予算枠/
よざい /余罪/余財/餘罪;「余」旧字/
よざかり /世盛り/
よざくら /夜桜/
よし /由/葦/葭/因/余資/余矢;[数学]versed cosine/好/良/美/吉/純/義/喜/善/佳/圭/慶/祥/芳/嘉/克/宜/淑/禎/禧/譱/縦/
よしあき /義明/義昭/良明/嘉明/良昭/嘉昭/吉昭/義章/嘉章/義朗/喜明/吉明/善昭/美明/克明/義晃/由明/善章/嘉晃/吉晃/良秋/義亮/宜明/芳明/純明/良晃/
よしあし /善し悪し/良し悪し/善悪/
よしい /吉井/芳井/
よしいけ /吉池/
よしいち /義一/
よしうみ /吉海/
よしうら /吉浦/
よしえ /芳恵/良枝/吉江/好恵/佳恵/好江/
よしお /義雄/義夫/義男/良夫/良雄/芳雄/芳夫/吉雄/嘉男/善雄/新生/善夫/好夫/好男/良男/吉男/善男/佳男/吉夫/昌男/由夫/好雄/嘉夫/嘉雄/美夫/淑生/吉生/佳郎/好生/宗生/佳雄/芳男/好央/禧雄/誉志雄/温雄/
よしおか /吉岡/
よしおかしょてん /吉岡書店/
よしおみ /善臣/佳臣/
よしか /佳香/
よしかず /義和/義一/良和/喜一/芳一/美一/善和/善一/好一/慶一/佳一/由和/能収/佳和/英一/
よしかつ /義勝/良勝/好克/隆克/
よしかわ /吉川/好川/
よしがき /芳垣;姓/
よしがみ /吉上/
よしき /与式/芳樹;人名/美樹/良樹/吉敷/佳樹/吉城/義樹/善樹/嘉樹/由樹/善紀/慶樹/吉起/吉喜/好輝/吉輝/芳季/芳希/喜紀/
よしきゅう /与死球/
よしきよ /義清/
よしきり /葦切;[鳥]/葦雀;=葦切/
よしきりざめ /葦切鮫/
よしくに /吉国/喜国/美邦/
よしこ /佳子/良子/美子/淑子/芳子/よし子/好子/由子/嘉子/賀子/ヨシ子/
よしこし /吉越/
よしごと /夜仕事/
よしさだ /義貞/悦貞/
よしさと /義聡/
よしざき /吉崎/
よしざわ /吉澤/吉沢/芳沢/義澤/
よししきゅう /与四死球/
よしじ /良治/良至/良司/
よしじま /吉島/
よしすけ /義介/
よしず /葦簀/葭簀/
よしずみ /吉住/
よしぞう /芳三/
よしたか /義孝/義隆/良隆/義高/佳孝/孝高/嘉隆/善隆/吉高/芳孝/善孝/禎孝/
よしたけ /吉武/吉竹/尚武/美武/義丈/義竹/
よしたに /吉谷/
よしたろう /芳太郎/由太郎/
よしだ /吉田/慶田/
よしだけんいち /吉田健一;評論家(1912-77) 『ヨオロツパの世紀末』/
よしだけんこう /吉田兼好/
よしだこうぎょう /吉田工業;[企業名]/
よしだしげる /吉田茂/
よしだしょういん /吉田松陰/
よしだせんしゃ /吉田戦車/
よしだちょう /吉田町/
よしだみわ /吉田美和/
よしだや /吉田屋/
よしつ /好津/
よしつぐ /善次/善嗣/佳次/
よしつね /義経/
よしつねごう /義経号/
よしつねせんぼんざくら /義経千本桜/
よしつねぞう /義経像/
よしづか /吉塚/
よしづかえき /吉塚駅/
よしてる /芳輝/喜照/
よしと /義人/芳人/圭人/
よしとお /義遠/
よしとし /義敏/吉年/
よしとせん /吉都線/
よしとみ /吉富/善富/
よしとも /良知/佳友/義智/義朋/義恭/
よしどめ /吉留/
よしなお /義直/喜直/
よしなか /義仲/吉仲/
よしなが /吉永/良永/
よしながさゆり /吉永小百合/
よしなしごと /由無し事/
よしなり /吉成/良成/義成/善成/義也/芳成/祐生/悌也/能成/
よしの /吉野/芳野/美乃/吉乃/淑乃/
よしのがりいせき /吉野ヶ里遺跡;佐賀/
よしのがわ /吉野川/
よしのさくぞう /吉野作造/
よしのじんぐう /吉野神宮/
よしのせん /吉野線/
よしのだに /吉野谷/
よしのぶ /慶喜/義信/芳信/嘉伸/良伸/栄伸/
よしのや /吉野家;[企業名]牛丼屋/吉野屋/
よしのやま /吉野山/
よしのり /義則/義範/義典/良典/義徳/善則/良則/佳典/吉則/芳徳/佳紀/善徳/嘉則/吉徳/由典/吉典/芳則/美則/好則/善範/佳則/嘉典/良憲/芳規/善典/良教/芳範/良規/良法/由規/義昇/美徳/良紀/彬伯/賀悟;名/嘉哲/
よしは /吉葉/
よしはま /吉浜/
よしはら /吉原/
よしはらせいゆ /吉原製油/
よしはらちゅうおうえき /吉原中央駅/
よしはる /義治/義晴/善治/義春/吉春/芳晴/喜治/喜晴/佳春/
よしば /吉羽/吉場/
よしひこ /義彦/善彦/良彦/吉彦/芳彦/嘉彦/喜彦/慶彦/義比古/
よしひさ /義久/善久/芳久/慶久/良久/嘉久/由久/純央/
よしひで /良英/慶英/善英/
よしひと /芳仁/芳人/由人/善一/圭仁/
よしひろ /義博/義弘/吉弘/善博/義浩/善弘/吉宏/義広/良博/嘉宏/義裕/義宏/嘉弘/喜博/良宏/嘉浩/良浩/吉廣/慶大;名/良広/美博/佳浩/好広/佳寛/良祐/吉広/佳泰/喜弘/由泰/至寛/嘉伯/
よしふみ /義文/良文/好文/祥史/佳文/仁史/善文/
よしぶえ /葦笛/
よしほ /美穂/
よしま /吉間/
よしまさ /義正/好正/良昌/義雅/喜昌/
よしまつ /吉松/由松/
よしみ /由美/昌美/良美/吉見/芳美/好美/誼/義美/善美/嘉美/由光/義巳/
よしみず /吉水/
よしみち /由道/
よしみつ /義光/吉光/善光/喜光/嘉光/芳充/
よしむね /吉宗/義統/
よしむら /吉村/芳村/義村/
よしもと /吉本/芳本/
よしもとこうぎょう /吉本興業;[企業名]/
よしもとしんきげき /吉本新喜劇/
よしもり /吉森/
よしや /吉屋/嘉也/善哉/義哉/
よしやす /嘉康/好康/
よしやま /吉山/
よしゅ /余種/
よしゅう /予習/予州;伊予(愛媛)/余臭/豫習;「予」旧字/
よしゅうよう /予習用/
よしゅく /予祝/
よしゆき /義之/善之/義行/義幸/良之/吉行/佳之/善幸/芳行/好幸/誉志幸/由行/嘉志/嘉雪/良幸/嘉之/佳行/
よしゆきじゅんのすけ /吉行淳之介/
よしょく /余色/
よしろう /芳郎/義郎/喜朗/善郎/嘉朗/与四郎/
よしわ /吉和/
よしわら /吉原/葦原/
よしわらことば /吉原言葉/
よしん /与信/余震/予診/予審/餘震;「余」旧字/
よしんぎょうむ /与信業務;credit affaires/
よしんば /縦んば/
よじ /余事/予示;=よし/四時/四次/
よじげん /四次元/
よじげんくうかん /四次元空間/
よじしょう /余事象;[数学]complementary event/
よじじゅくご /四字熟語/
よじつ /余日/
よじみゃく /四次脈/
よじょう /余剰;surplus/余情/餘情;「余」旧字/餘剩;「余剰」の旧字表記/
よじょうぎみ /余剰気味/
よじょうしゃ /余剰車/
よじょうせい /余剰性/
よじょうでんりょく /余剰電力/
よじょうはん /四畳半/
よじょうぶぶん /余剰部分/
よじろう /与次郎/
よじん /余人/余燼/餘人;「余」旧字/余塵/
よすい /余水/
よすが /縁/便/因/
よすがら /終夜/
よすぎ /世過ぎ/
よすて /世捨/
よすてびと /世捨て人/
よすみ /四隅/
よずめ /余詰;※仮名遣い「よづめ」/
よせ /寄席/寄せ/
よせあつめ /寄せ集め/
よせい /余生;afterlife.「-を送る」/余勢;-を駆って/余情;=よじょう/餘生;「余」旧字/餘勢;「余」旧字/
よせうえ /寄せ植え/寄植え/
よせえ /寄せ餌/
よせえんげい /寄席演芸/
よせがき /寄せ書き/寄書き/
よせき /余積/
よせぎ /寄木;-細工/
よせぎざいく /寄木細工/寄せ木細工/
よせぎづくり /寄木造り;[彫刻]複数の木を接ぐ/
よせざん /寄せ算/
よせだいこ /寄せ太鼓;客寄せ/
よせつ /余接;cot/
よせなべ /寄せ鍋/
よせば /寄せ場/寄場/
よせばし /寄せ箸/
よせむね /寄棟/寄せ棟/
よせむねづくり /寄せ棟造り;[建築]/寄棟造り;[建築] 上から見て >―< の形の屋根/寄棟造/
よせもじ /寄席文字/
よせもと /寄元/
よせもの /寄せ物/
よせん /予選/予戦;?/予餞/豫選;「予」旧字/
よせんいっかいせん /予選一回戦/
よせんおち /予選落ち/予選落/
よせんかい /予餞会/
よせんかいじょう /予選会場/
よせんけっか /予選結果/
よせんけん /予選券/
よせんごと /予選毎/
よせんさいかい /予選最下位/
よせんじゅんい /予選順位/
よせんぜんじつ /予選前日/
よせんだいいっせん /予選第一戦/
よせんちゅう /予選中/
よせんつうか /予選通過/
よせんつうかしゃ /予選通過者/
よせんとっぱ /予選突破/
よせんはいたい /予選敗退/
よせんめんじょ /予選免除/
よせんりーぐ /予選リーグ/
よぜみ /代ゼミ/
よぜん /余喘/
よそ /他所/余所/餘所;「余」旧字/
よそいき /余所行き/
よそう /予想/豫想;「予」旧字/
よそういじょう /予想以上/
よそうかい /予想会/
よそうかくりつ /予想確率/
よそうかのう /予想可能/
よそうがい /予想外/
よそうきじ /予想記事/
よそうしゃ /予想者/
よそうじゅんい /予想順位/
よそうず /予想図/
よそうち /予想値/
よそうどおり /予想通り/
よそうにんずう /予想人数/
よそうひょう /予想表/
よそうほう /予想法/
よそうほうほう /予想方法/
よそうもんだい /予想問題/
よそうもんだいしゅう /予想問題集/
よそうや /予想屋/
よそおい /装い/装/
よそく /予測/豫測;「予」旧字/
よそくがい /予測外/
よそくがた /予測型/
よそくき /予測器/
よそくごさ /予測誤差/
よそくせい /予測性/
よそくち /予測値/
よそくてき /予測的/
よそくどおり /予測通り/
よそくのうりょく /予測能力/
よそくふかのう /予測不可能/
よそくふのう /予測不能/
よそくへんかん /予測変換/
よそくほう /予測法/
よそくりつ /予測率/
よそごと /余所事/
よそじ /四十路/四十/
よそみ /余所見/よそ見/
よそめ /余所目/
よそもの /余所者/よそ者/他所者/
よそゆき /余所行き/
よぞら /夜空/
よた /与太/世太/yotta;[SI接頭語]Y,10^24/
よたい /預貸/
よたいりつ /預貸率/
よたか /夜鷹/
よたく /預託/余沢;先人の恩恵/
よたくきん /預託金/
よたくしょうほう /預託商法/
よたばなし /与太話/
よたもの /与太者/
よたり /四人/
よたろう /与太郎/四太郎/
よだ /依田/与田/余田/誉田/
よだいすう /余代数/
よだち /夜立ち/
よだつ /与奪;生殺-/予奪;=与奪/
よだれ /涎/
よだれかけ /涎掛け/
よだん /余談/予断;-を許さない/四段/餘談;「余」旧字/豫斷;「予断」旧字/
よだんかつよう /四段活用/
よち /余地/予知/輿地/予地/豫知/余値/
よちかん /予知観/
よちず /輿地図/
よちのうりょく /予知能力/
よちむ /予知夢/
よちょう /予兆/余丁/
よちょうまち /余丁町/
よちょきん /預貯金/
よちれん /予知連/
よっか /四日/翼下/４日/4日/
よっかい /欲界;[仏教]/
よっかいち /四日市/
よっかいちえき /四日市駅/
よっかいちぜんそく /四日市喘息/
よっかいちほうめん /四日市方面/
よっかく /浴客/
よっかめ /四日目/
よっきゃく /浴客/
よっきゅう /欲求/
よっきゅうふまん /欲求不満/
よったり /四人/
よっつ /四つ/4つ/
よって /依って/∴/
よっぱらい /酔っ払い/酔っぱらい/
よっぽど /余っ程/
よつ /四つ/四/
よつあし /四足/四つ足/四つ脚/
よついけ /四ツ池/
よつおり /四つ折り/
よつかいどう /四街道/
よつかど /四つ角/
よつがな /四つ仮名;[国語学]じぢずづ/
よつき /四月/
よつぎ /世継/世嗣/世嗣ぎ/世継ぎ/
よつぎものがたり /世継物語/
よつぎり /四つ切/四切/
よつくら /四倉/
よつずもう /四つ相撲/
よつだけ /四つ竹/
よつつじ /四辻/
よつどき /四つ時/
よつば /四葉/四つ葉/
よつばし /四つ橋/
よつぼし /四つ星/
よつまた /四叉/四つ叉/
よつみ /四つ身/
よつめ /四つ目/
よつめがき /四つ目垣/
よつめとじ /四つ目綴じ/
よつや /四谷/四ツ谷/
よつやえき /四谷駅/
よつやかいだん /四谷怪談/
よつやさんちょうめ /四谷三丁目/
よつやなぎ /四柳/
よつやほうこう /四谷方向/
よつやほうめん /四谷方面/
よつやま /四つ山/
よつゆ /夜露/
よつわり /四つ割り/
よつんばい /四つん這い/
よづめ /余詰/
よづり /夜釣り/夜釣/
よてい /予定/豫定;「予」旧字/
よていあん /予定案/
よていかかく /予定価格/
よていがい /予定外/
よていがく /予定額/
よていこう /予定稿/
よていしゃ /予定者/
よていしゃめい /予定者名/
よていじかん /予定時間/
よていじこく /予定時刻/
よていすう /予定数/
よていせん /予定線/
よていち /予定地/
よていちょうわ /予定調和/
よていちょうわてき /予定調和的/
よていどおり /予定通り/
よていないよう /予定内容/
よていにんずう /予定人数/
よていのうぜい /予定納税/
よていひょう /予定表/
よていひん /予定品/
よていび /予定日/
よていへんこう /予定変更/
よていりりつ /予定利率;引き下げ/
よてき /余滴/
よとう /与党/夜盗;コソ泥さん/
よとうがわ /与党側/
よとうむし /夜盗虫;害虫/
よとぎ /夜伽/
よとく /余得;余分の儲け/余徳;先人の恩徳/
よど /淀/
よどえ /淀江/
よどおし /夜通し/
よどがわ /淀川/
よどがわかこう /淀川河口/
よどがわかせんこうえん /淀川河川公園/
よどがわかせんじき /淀川河川敷/
よどぎみ /淀君/
よどしゃこ /淀車庫/
よどせん /予土線/
よどばし /淀橋;地名,新宿区/
よどみ /淀み/澱み/澱/
よどみばし /澱橋/
よどや /淀屋/
よどやばし /淀屋橋/
よない /米内/
よないみつまさ /米内光政/
よないやま /米内山/
よなおし /世直し/
よなか /夜中/
よなかじゅう /夜中中/
よなが /夜長/
よなき /夜泣き/夜鳴き/
よなくに /与那国/
よなぐすく /与那城/
よなぐに /与那国/
よなぐにじま /与那国島/
よなご /米子/
よなごくうこう /米子空港/
よなごじどうしゃどう /米子自動車道/
よなぬき /ヨナ抜き/
よなぬきおんかい /ヨナ抜き音階/
よなばる /与那原/
よなべ /夜なべ/
よなよな /夜な夜な/
よにげ /夜逃げ/
よにげや /夜逃げ屋;[新語]/
よにも /世にも/
よにゅう /預入/
よにん /余人/四人/
よにんうち /四人打ち/
よにんしゅう /四人衆/
よにんめ /四人目/
よね /米/
よねい /米井/
よねいちまる /米一丸/
よねお /米雄/
よねかわ /米川;姓/
よねきち /米吉/
よねくら /米倉/
よねぐち /米口/
よねこ /米子/
よねさかせん /米坂線/
よねざき /米崎/
よねざわ /米沢/米澤/
よねざわおり /米沢織/
よねざわぎゅう /米沢牛/
よねざわし /米沢市/
よねしま /米嶋/
よねしろがわ /米代川/
よねじま /米嶋/
よねず /米酢/
よねだ /米田/
よねつ /余熱;†afterheat.「-で火が通る」/予熱;†preheat.「フライパンを-する」/
よねづ /米津/
よねなが /米長/
よねはら /米原/
よねはる /米春/
よねばやし /米林/
よねみつ /米光/
よねむら /米村/
よねもと /米本/
よねもり /米森/
よねやま /米山/
よねやまじんく /米山甚句;[民謡]新潟.「行こか参らんしょか米山薬師」/
よねん /余年;≒余生/余念/四年/４年/餘念;「余」旧字/
よねんせい /四年生/
よねんめ /四年目/
よの /与野/
よのう /予納/
よのうづ /米水津/
よのじ /よノ字/
よのすけ /世之介;西鶴『好色一代男』の主人公/
よのつね /世の常/
よのてん /与野店/
よのなか /世の中/
よのならい /世の習い/
よは /余波/餘波;「余」旧字/
よはい /余輩/予輩/
よはく /余白/餘白;「余」旧字/
よはねもくしろく /ヨハネ黙示録;[聖書]Revelation(Rev)/
よはらい /預払い/
よばい /夜這い;(当て字)/婚/
よばたらき /夜働き/
よばなし /夜咄;[茶道]午後六時のお茶会/夜話/
よばわり /呼ばわり/
よばん /四番/夜番/
よばんちょう /四番丁/
よひとよ /夜一夜/
よび /予備/呼び/豫備;「予」旧字/
よびえき /予備役/
よびかいぎ /予備会議/
よびかいせき /予備解析/
よびかけ /呼び掛け/呼掛け/呼掛/
よびかた /呼び方/
よびがくせい /予備学生/
よびがわ /呼び側/
よびき /予備機/
よびきょういく /予備教育/
よびぐん /予備軍/予備群/
よびけい /呼び径/
よびけん /予備検/
よびこ /呼子/
よびこう /予備校/
よびこうか /予備校化/
よびこうさつ /予備考察/
よびこうしゅうかい /予備講習会/
よびこうしょう /予備交渉/
よびこうせい /予備校生/
よびこせん /呼子線/
よびこみ /呼び込み/
よびごえ /呼び声/
よびしはらいにん /予備支払人/
よびしゃ /予備車/
よびしゃけんじょう /予備車検場/
よびしん /予備審/
よびしんさ /予備審査/
よびしんさかい /予備審査会/
よびしんぱん /予備審判/
よびじっけん /予備実験/
よびじょうほう /予備情報/
よびすて /呼び捨て/呼捨て/呼びすて/
よびせっけい /予備設計/
よびせん /予備選/
よびせんきょ /予備選挙/
よびせんりょく /予備戦力/
よびたい /予備隊/
よびだし /呼出/呼び出し/呼出し/
よびだしおん /呼出音/呼び出し音/
よびだしがわ /呼出側/
よびだしふごう /呼出符号/
よびちしき /予備知識/
よびちょうさ /予備調査/
よびつけ /呼付け/呼び付け/
よびてき /予備的/
よびでんち /予備電池/
よびとうひょう /予備投票/
よびな /呼び名/呼名/
よびね /呼値/呼び値/
よびひ /予備費/
よびび /予備日/
よびへんせい /予備編成/
よびみず /呼び水/
よびめんきょ /予備免許/
よびもどし /呼び戻し/
よびもの /呼び物/
よびや /呼び屋/
よびょう /余病/
よびよせん /予備予選/
よびりん /呼び鈴/
よふう /余風/
よふかし /夜更かし/夜更し/
よふけ /夜更け/夜更/
よふん /余憤/
よぶき /ヨブ記;[聖書]Job/
よぶこ /呼子/
よぶん /余分/余聞/餘分;「余」旧字/
よへい /与平/余弊/
よべ /昨夜/
よほう /予報/余方/豫報;「予」旧字/
よほうく /予報区/
よほうし /予報士/
よほうじかん /予報時間/
よほど /余程/
よぼう /予防/輿望;期待。「国民の-」/豫防;「予」旧字/
よぼういがく /予防医学/
よぼういりょう /予防医療/
よぼうきん /予防菌/
よぼうこうか /予防効果/
よぼうさく /予防策/
よぼうせっしゅ /予防接種/
よぼうせん /予防線/
よぼうせんそう /予防戦争/
よぼうそち /予防措置/
よぼうちゅうしゃ /予防注射/
よぼうてき /予防的/
よぼうほう /予防法/
よぼうほうほう /予防方法/
よまいごと /世迷い言/
よまつ /余沫/
よまつり /夜祭/夜祭り/
よまわり /夜回り/
よみ /黄泉/読み/
よみあげ /読み上げ/読上げ/
よみあわせ /読み合わせ/読合せ/
よみうり /読売/讀賣;旧字/
よみうりがわ /読売側/
よみうりきょじん /読売巨人/
よみうりきょじんぐん /読売巨人軍/
よみうりけい /読売系/
よみうりけいれつ /読売系列/
よみうりしんぶん /読売新聞/
よみうりしんぶんしゃ /読売新聞社;[企業名]www.yomiuri.co.jp/
よみうりしんぶんゆうかん /読売新聞夕刊/
よみうりせん /読売戦/
よみうりちょうかん /読売朝刊/
よみうりにほん /読売日本/
よみうりらんど /読売ランド/
よみかき /読み書き/
よみかた /読み方/
よみがな /読み仮名/読みがな/
よみきり /読切/読み切り/読切り/
よみくだし /読み下し/訓み下し/
よみくだしぶん /読み下し文/訓み下し文/
よみくち /読み口/
よみこみ /読み込み/読込/読込み/
よみこみじ /読み込み時/
よみこみちゅう /読込中/
よみごえ /読み声/
よみごたえ /読み応え/
よみじ /黄泉路/
よみせ /夜店/夜見世/
よみたに /読谷/
よみだし /読み出し/
よみち /夜道/
よみて /読み手/詠み手;和歌の-/
よみで /読みで/
よみとり /読取/読み取り/読取り/
よみとりき /読み取り機/
よみのくに /黄泉の国/黄泉国/
よみびとしらず /詠人不知/
よみふだ /読み札/
よみほん /読本/
よみまちがい /読み間違い/
よみもの /読み物/読物/
よみや /宵宮/夜宮/
よみょう /余命/
よめ /嫁/夜目/娵;息子の妻/
よめい /余命/餘命;旧字/
よめいびり /嫁いびり/
よめいり /嫁入り/嫁入/
よめいりじたく /嫁入り支度/
よめえらび /嫁選び/
よめご /嫁御/
よめごりょう /嫁御寮/
よめさん /嫁さん/
よめしゅうとめ /嫁姑/
よめじょ /嫁女/
よめとおめ /夜目遠目;-笠の内/
よめとり /嫁取り/
よめな /嫁菜/
よも /四方/
よもぎ /蓬/艾/蒿/
よもぎう /蓬生/
よもぎた /蓬田/
よもぎだ /蓬田/
よもぎもち /蓬餅/
よもすえ /世も末/
よもすがら /終夜/
よもつ /黄泉つ;「つ」は「の」の意の格助詞/
よもつくに /黄泉国/
よもつひらさか /黄泉平坂/
よもやま /四方山/
よもやまばなし /四方山話/
よやく /予約/豫約;「予」旧字/
よやくうけつけ /予約受付/
よやくうけつけちゅう /予約受付中/
よやくか /予約課/予約可/
よやくかいし /予約開始/
よやくかいしび /予約開始日/
よやくかのう /予約可能/
よやくかんけい /予約関係/
よやくがかり /予約係/
よやくきげん /予約期限/
よやくきのう /予約機能/
よやくきゃく /予約客/
よやくきろく /予約記録/
よやくきん /予約金/
よやくけん /予約券/
よやくこうどく /予約購読/
よやくこうにゅう /予約購入/
よやくご /予約語/
よやくしゃ /予約者/
よやくしゅっぱん /予約出版/
よやくしょうめいしょ /予約証明書/
よやくじ /予約時/
よやくじゅん /予約順/
よやくじょうきょう /予約状況/
よやくせい /予約制/
よやくせき /予約席/
よやくせってい /予約設定/
よやくちゅう /予約中/
よやくてはい /予約手配/
よやくでんわばんごう /予約電話番号/
よやくとくてん /予約特典/
よやくないよう /予約内容/
よやくはんばい /予約販売/
よやくばんごう /予約番号/
よやくひ /予約費/
よやくひょう /予約表/
よやくぶん /予約分/
よやくへんこう /予約変更/
よやくほうしき /予約方式/
よやくまどぐち /予約窓口/
よやくめい /予約名/
よやくよう /予約要/
よやくようし /予約用紙/
よやくらん /予約欄/
よやくりょういき /予約領域/
よやくろくが /予約録画/
よやくろくがきのう /予約録画機能/
よやす /世安/
よやとう /与野党/
よやみ /夜闇/
よゆう /余裕/餘裕;「余」旧字/
よゆうしゃくしゃく /余裕綽々/余裕綽綽/
よゆうじかん /余裕時間/
よゆうは /余裕派;[文学]漱石・鴎外/
よよ /夜々/世々/世世/夜夜/
よよぎ /代々木/
よよぎうえはら /代々木上原/
よよぎきょうぎじょう /代々木競技場/
よよぎこうえん /代々木公園/
より /寄/縒/頼/依/和/依里/
よりあい /寄合/寄り合い/
よりあいがき /寄合書/
よりあいじょたい /寄り合い所帯/
よりあき /頼明/頼芸/頼晶/
よりい /寄居/
よりいかん /寄居間/
よりいっそう /より一層/
よりいと /縒り糸/
よりうど /寄人/
よりお /頼男/
よりき /与力/寄木;流れ寄せた木/
よりきり /寄り切り/
よりこ /依子/頼子/夜梨子/
よりしま /寄島/
よりしろ /依代/憑代/
よりすぐり /選りすぐり/
よりせん /より線/縒り線/
よりたおし /寄り倒し/
よりちか /頼近/
よりついせん /より対線/
よりつき /寄付き/
よりとも /頼朝/
よりどころ /拠り所/拠/より所/拠所/據/
よりどり /選り取り/
よりどりみどり /選り取り見取り/
よりによって /選りに選って/
よりぬき /選り抜き/
よりのぶ /頼信/
よりびと /寄人/
よりまし /憑坐/尸童/
よりみ /寄り身/
よりみち /寄り道/
よりめ /寄り目/
よりゅうど /寄人/
よりょく /余力/餘力;「余」旧字/
よる /夜/依/倚/
よるい /余類/
よるおそく /夜遅く/
よるがた /夜型/
よるごはん /夜御飯/
よるちゃく /夜着/
よるひる /夜昼/
よるべ /寄る辺/
よるよう /夜用/
よるよなか /夜夜中/
よるよる /夜々/夜夜/
よれい /予冷/予鈴/余齢/
よろい /鎧/
よろいいたちうお /鎧鼬魚/
よろいざわ /鎧沢/
よろいせんし /鎧戦士/
よろいど /鎧戸/
よろいどおし /鎧通し/
よろいまど /鎧窓/
よろいむしゃ /鎧武者/
よろく /余録;余話/余禄;儲け物/
よろけ /蹌踉/蹣跚/
よろこび /喜び/慶び;(祝福)「お-申し上げます」 (字義:お祝いを持って行く)/歓び;(字義:声を上げてよろこぶ)/悦び;(字義:心のしこりが取れる)/憙/
よろこびごと /喜び事/慶び事/
よろしく /宜しく/
よろず /万/萬/
よろずちょうほう /万朝報/
よろずや /万屋/
よろずやきんのすけ /萬屋錦之介/
よろぼし /弱法師/
よろん /世論;せろん。「輿論」の代替表記/輿論;本来の字/余論;他の議論/与論;地名 NB:「輿論」の意では誤り(「輿」と「與」の混同)/與論;「与」の旧字/餘論;「余」の旧字/
よろんちょうさ /世論調査/
よろんゆうどう /世論誘導/
よわ /余話/夜半;(当て字)/
よわい /齢/齡;「齢」の旧字/弱い/
よわき /弱気/
よわきすじ /弱気筋/
よわごし /弱腰/
よわたり /世渡り/
よわたりじょうず /世渡り上手/
よわね /弱音/
よわび /弱火/
よわふくみ /弱含み/
よわみ /弱味/弱み;-に付け込む/
よわみそ /弱味噌/
よわむし /弱虫/
よわめ /弱目/
よわよわ /弱々/
よわりめ /弱り目/
よん /四/４/
よん> /四/
よんい /四位/
よんかい /四階/
よんかいせい /四回生/
よんかいめ /四回目/
よんかんおう /四冠王/
よんがっか /四学科/
よんき /四紀/
よんきゅう /四球/四級/
よんきょうか /四教科/
よんぎょう /四行/
よんく /四駆/四区/
よんけたほう /四桁法/
よんけん /四研/４研/
よんげんすう /四元数/
よんげんそせつ /四元素説/
よんこう /4項/
よんこま /４コマ/
よんこままんが /４コマ漫画/四コマ漫画/
よんごう /四合/
よんごうびん /四合瓶/
よんさいば /四歳馬/
よんし /四子/
よんしまい /四姉妹/
よんしゃ /四者/4者/
よんしゃたくいつ /四者択一/
よんしゅうかん /四週間/
よんしゅるい /四種類/4種類/
よんしょう /四章/四商/
よんしょうめ /四勝目/
よんしょく /四色/
よんしょくもんだい /四色問題;[数学]four-colour problem/
よんじゅう /四重/四十/
よんじゅうじんかく /四重人格/
よんじょ /四女/
よんせい /四声/
よんせんねん /四千年/
よんたく /四択/
よんだい /四大/四台/
よんだいしゅうきょう /四大宗教/
よんちゃく /四着/
よんとう /四島/
よんとうこく /四等国/
よんとうごらく /四当五落/
よんど /四度/
よんどかく /四度核/
よんなん /四男/
よんねん /四年/
よんのじがため /４の字固め;プロレス技/
よんばいたい /四倍体;[生物]tetraploid/
よんばんめ /四番目/4番目/
よんぱく /四白/
よんひき /四匹/
よんびょうし /四拍子;[音楽]/
よんぶ /四部/
よんぶん /四分/
よんぶんかつ /四分割/
よんべ /昨夜/
よんほん /四本/
よんほんゆび /四本指/
よんまい /四枚/
よんめい /四名/４名/
よんめん /四面/
よんもく /四目/
よんもじことば /四文字言葉/
よんりん /四輪/
よんりんくどう /四輪駆動/
よんりんくどうしゃ /四輪駆動車/
よんりんしゃ /四輪車/
よんりんどう /四輪道/
よんわり /四割/
ら /等/裸/羅;銅鑼/鑼;銅鑼/蘿;かずら/邏;巡邏/螺;螺鈿/騾;騾馬/拉;拉致/們/良;奈良/
らーぱーつぁい /辣白菜/
らーめん /拉麺/老麺/
らーめんこうぞう /ラーメン構造/
らーめんてん /ラーメン店/
らーめんや /ラーメン屋/
らーゆ /辣油/ラー油/
らい /癩;らい病/来/頼;信頼/籟;笛/雷;落雷/蕾;花蕾/罍;(酒樽)/儡;傀儡/櫑;≒罍/擂;する/耒;(鋤)/莱/磊;磊落/賚;(賜物)/醴;白酒/礼;(呉音)礼記/來;「来」の旧字(人名用漢字)/徠;「来」の異体字/
らい> /来/
らいい /来意/
らいいん /来院/
らいう /雷雨/
らいうん /雷雲/
らいえん /来援/来演/
らいおう /来往/
らいか /来夏/雷火/
らいかい /来会/
らいかん /来館/雷管/来観/
らいが /来駕/雷牙/
らいがく /来学/
らいがくねん /来学年/
らいがっき /来学期/
らいき /来季;next season/来期;next period/礼記/
らいきゃく /来客/
らいきゃくちゅう /来客中/
らいきゃくよう /来客用/
らいぎょ /雷魚/
らいけん /来県/
らいげき /雷撃/
らいげきき /雷撃機/
らいげつ /来月/
らいげつごう /来月号/
らいげつすえ /来月末/
らいげつちゅう /来月中/
らいげつど /来月度/
らいげつぶん /来月分/
らいげつまつ /来月末/
らいげん /来源/
らいこう /来校/来航/来光/雷光;lightning/雷公;雷さま/来寇/来貢/雷汞;Hg(ONC)2/
らいごう /来迎/来降/
らいごうず /来迎図/
らいさん /礼賛/礼讃/
らいさんよう /頼山陽/
らいしーずん /来シーズン/
らいしつ /来室/
らいしゃ /来社/来車/
らいしゅう /来週/来襲/来秋/来集/
らいしゅうあたま /来週頭/
らいしゅうかよう /来週火曜/
らいしゅうげつよう /来週月曜/
らいしゅうちゅう /来週中/
らいしゅうぶん /来週分/
らいしゅうほうえい /来週放映/
らいしゅうまつ /来週末/
らいしゅうよこく /来週予告/
らいしゅん /来春/
らいしゅんかいまく /来春開幕/
らいしゅんしゅうしょく /来春就職/
らいしょ /来所/来書;来た手紙/
らいしょう /来生/
らいしん /来診/来信;来た手紙/
らいしんし /頼信紙/
らいじ /来示/
らいじゅ /頼樹/
らいじゅう /雷獣/
らいじょう /来場/来状;来た手紙/
らいじょうしゃ /来場者/
らいじん /雷神/
らいじんおう /雷神王/
らいせ /来世/
らいせい /雷声/
らいせいき /来世紀/
らいせん /来仙/
らいせんすけいやく /ライセンス契約/
らいせんすりょう /ライセンス料/
らいそん /来孫/
らいぞう /頼三/
らいた /雷太/
らいたく /来宅/
らいだん /来談/
らいちゃく /来着/
らいちょう /雷鳥/来聴/来朝/
らいちょうさわ /雷鳥沢/
らいてい /雷帝;イワン-/雷霆;thunderbolt/
らいてん /来店/
らいでん /雷電/来電;来た電報/
らいとう /来冬/
らいときゅう /ライト級;[ボクシング]61kg以下/
らいどう /雷同/来道/
らいなつ /来夏/
らいにち /来日/
らいにちけってい /来日決定/
らいにちこうえん /来日公演/
らいにちじ /来日時/
らいにちちゅう /来日中/
らいにちちゅうし /来日中止/
らいにちまえ /来日前/
らいにん /来任/
らいねん /来年/
らいねんあき /来年秋/
らいねんいこう /来年以降/
らいねんいっぱい /来年一杯/
らいねんかいさい /来年開催/
らいねんごろ /来年頃/
らいねんそつぎょう /来年卒業/
らいねんど /来年度/
らいねんどちゅう /来年度中/
らいねんどまつ /来年度末/
らいねんなつ /来年夏/
らいねんはる /来年春/
らいねんまつ /来年末/
らいはい /礼拝/
らいはいじょ /礼拝所/
らいはいどう /礼拝堂/
らいはる /来春/
らいはん /来阪;大阪へ来る/
らいばしょ /来場所/來場所;「来」旧字/
らいばるいしき /ライバル意識/
らいひん /来賓/
らいひんせき /来賓席/
らいびょう /癩病/
らいふく /来復/
らいふるじゅう /ライフル銃;rifle/
らいぶかん /ライブ感/
らいぶちゅう /ライブ中/
らいぶちゅうけい /ライブ中継/
らいぶばん /ライブ盤/
らいぶらりかんすう /ライブラリ関数/
らいぶろくおん /ライブ録音/
らいほう /来訪/来報/
らいほうしゃ /来訪者/
らいむ /来夢/
らいむぎ /ライ麦/
らいむぎばたけ /ライ麦畑/
らいめい /雷鳴/雷名;fame/
らいもん /雷文/
らいゆう /来遊/来由;≒由来/
らいらい /来々/磊々;「-落々」/
らいらいねん /来々年/
らいらいらくらく /磊々落々/磊磊落落/
らいらく /磊落/
らいりゅう /雷竜/
らいりん /来臨/
らいれき /来歴/
らいん /莱因/
らいんすう /ライン数/
らう /羅宇/
らうす /羅臼/
らお /羅宇/
らおご /ラオ語;ラオ族の言語/
らおちゅー /老酒/
らおちゅう /老酒/
らおん /ラ音/
らかん /羅漢/
らかんか /羅漢果/
らかんちゅう /羅貫中;三国志演義/
らがん /裸眼/
らがんしりょく /裸眼視力;⇔矯正視力/
らがんりったいし /裸眼立体視/
らぎょう /裸形/ラ行/ら行/
らぎょうへんかくかつよう /ラ行変格活用;[文法]ラ変。 (有り)ら-り-り-る-れ-れ/
らく /楽/落/酪;酪農/絡;連絡/洛;上洛/烙;烙印/珞;瓔珞/駱;駱駝/犖;(まだらうし)/樂;「楽」の旧字(人名用漢字)/
らくいちらくざ /楽市楽座/
らくいん /烙印/落胤/
らくいんきょ /楽隠居/
らくえん /楽園/
らくかん /楽観/
らくかんてき /楽観的/
らくがい /洛外/
らくがき /落書き/落書/楽書;=落書/楽書き/
らくがきちょう /落書き帳/落書帳/らく書き帳/
らくがん /落雁/
らくご /落語/落伍/落後;「落伍」の常用漢字での書き換え/
らくごか /落語家/
らくごしゃ /落伍者/落後者;「落伍者」の常用漢字での書き換え/
らくごばんぐみ /落語番組/
らくさ /落差/
らくさつ /落札/
らくさつかかく /落札価格/
らくさつしゃ /落札者/
らくさん /酪酸;butyric acid/
らくざ /楽座/
らくしゃ /落車/
らくしゅ /落首/落手/
らくしょ /落書/洛書/
らくしょう /楽勝/落掌;入手/落照;夕陽/酪漿;乳汁/
らくしょく /落飾/
らくじつ /落日/
らくじょう /落城/
らくすいそう /落水荘;[建築]Falling Water. F.L.Wrightの代表作/
らくせい /落成/
らくせいけんさ /落成検査/
らくせいしき /落成式/
らくせき /落石/落籍/
らくせつ /落雪/落屑;[医]desquamation/
らくせん /落選/
らくせんうんどう /落選運動/
らくせんしゃ /落選者/
らくたい /落体/
らくたろう /楽太郎;芸名/
らくたん /落胆/
らくだ /駱駝/
らくだい /落第/
らくだいせい /落第生/
らくだいてん /落第点/
らくだいろ /駱駝色/
らくち /楽地/
らくちゃく /落着/
らくちゃわん /楽茶碗/
らくちゅう /洛中/
らくちょう /落丁/落潮/
らくちん /楽チン/楽ちん/楽珍/
らくぢゃわん /楽茶碗/
らくてつ /落鉄/
らくてん /楽天/
らくてんか /楽天家/
らくてんし /楽天使/
らくてんしゅぎ /楽天主義;optimism/
らくてんてき /楽天的/
らくとう /洛東/
らくど /楽土/
らくのう /酪農/
らくのうか /酪農家/
らくのうぎょう /酪農業/
らくはく /落魄;おちぶれる/落剥;はがれおちる/
らくはつ /落髪/
らくば /落馬/
らくばい /落梅/
らくばく /落莫/
らくばん /落盤/落磐;=落盤/
らくひつ /落筆/
らくび /楽日/
らくほく /洛北/
らくほくこうこう /洛北高校/
らくほくこうこうまえ /洛北高校前/
らくめい /落命/
らくやき /楽焼/楽焼き/
らくよう /落葉/洛陽;地名,(Luoyang)/落陽;sunset/
らくようこうぼく /落葉高木/
らくようこうようじゅ /落葉広葉樹/
らくようじゅ /落葉樹/
らくようじゅりん /落葉樹林/
らくようていぼく /落葉低木/
らくらい /落雷/
らくらく /楽々/楽楽/落落;「磊磊-」/
らくるい /落涙/
らくろうぐん /楽浪郡;地名,現在の平壌周辺/
らぐびーぶ /ラグビー部/
らこく /羅国/
らざほーじうむ /Rf/Rutherfordium/
らし /螺子;ねじ/裸子;「-植物」/
らししょくぶつ /裸子植物/
らししょくぶつあもん /Gymnospermae/
らしゃ /羅紗/
らしゅつ /裸出/
らしょうもん /羅生門/
らしん /裸身/羅針/
らしんぎ /羅針儀/
らしんばん /羅針盤/
らしんばんざ /羅針盤座;Pyxis(Pyx)/
らじ /裸耳/
らじうむ /Ra/Radium/
らじおきょく /ラジオ局/
らじおこうざ /ラジオ講座/
らじおしーえむ /ラジオＣＭ/
らじおしゅつえん /ラジオ出演/
らじおたいそう /ラジオ体操/
らじおちゅうけい /ラジオ中継/
らじおばんぐみ /ラジオ番組/
らじおほうそう /ラジオ放送/
らじかるはんのう /ラジカル反応/
らじょうもん /羅城門;羅生門/
らせつ /羅刹;[仏教](raksasa)人喰い鬼/羅切;[仏教]castration/
らせん /螺旋/螺線/ら旋/
らせんかいだん /螺旋階段/
らせんじょう /螺旋状/
らそく /裸足/
らぞう /裸像/
らたい /裸体/
らたいが /裸体画;nude/
らち /埒/拉致/埓;異体字/
らちかんきん /拉致監禁/
らちがい /埒外/
らっか /落下/落花/落果/
らっかうんどう /落下運動/
らっかさん /落下傘/
らっかさんぶたい /落下傘部隊;paratroop/
らっかせい /落花生/
らっかちてん /落下地点/
らっかちゅう /落下中/
らっかてん /落下点/
らっかぶったい /落下物体/
らっかぶつ /落下物/
らっかりゅうすい /落花流水/
らっかろうぜき /落花狼藉/
らっかん /楽観/落款/
らっかんし /楽観視/
らっかんしゅぎ /楽観主義/
らっかんしゅぎしゃ /楽観主義者/
らっかんてき /楽観的/
らっかんろん /楽観論/
らっき /落暉/
らっきゅう /落球/
らっきょう /薤/辣韮;=薤/辣韭;=薤/楽境;安楽な境遇/
らっこ /海獺;(アイヌ語)rakko/猟虎;=海獺/
らっしゅじ /ラッシュ時/
らっせるしゃ /ラッセル車;(russel) 除雪車/
らっぱ /喇叭/
らっぱしゅ /喇叭手/
らっぱずいせん /喇叭水仙/
らっぱのみ /ラッパ飲み/喇叭飲み/
らつ /辣;辛辣/剌;溌剌/喇;喇叭/拉/溂;溌溂(=溌剌)/
らつわん /辣腕/
らてんけい /ラテン系/
らてんご /ラテン語;natale solum dulce/
らてんもじ /ラテン文字;Latin characters/
らでん /螺鈿/
らどん /Rn/Radon/
らぬきことば /ら抜き言葉;[国語学]「タマネギ食べれる？」/
らば /騾馬/
らふ /裸婦/
らふぞう /裸婦像/
らぶは /ラブ波;[地学]Love wave/
らぶらどるかいりゅう /ラブラドル海流;Labrador current/
らへん /ラ変/
らまーずほう /ラマーズ法;出産法。Lamaze technique/
らまきょう /ラマ教;Lamaism/
らむしゅ /ラム酒;(rum) サトウキビ蒸留酒/
らむだ /λ;lambda/Λ;Lambda/
らむにく /ラム肉/
らめいと /ラメ糸/
らめいり /ラメ入り/
らもん /羅門/
らりこっぱい /乱離骨灰/
らりょう /羅綾/
られつ /羅列/
らん /欄;†column/蘭;†[植物]orchid/卵/乱/濫;濫用/藍;藍色/覧;一覧/覽;「覧」の旧字(人名用漢字)/儖/嬾;嬾惰(=懶惰)/懶;懶惰/攬;総攬/檻;おり/欖;橄欖/籃;揺籃/襤;襤褸(ぼろ)/繿;「襤」の異体字/纜;ともづな/瀾;波瀾万丈/爛;爛熟/襴;金襴/闌;たけなわ/巒/欒;団欒/臠;ししむら/鸞;親鸞/嵐/婪;貪婪/亂;「乱」の旧字/
らん> /乱;乱落,乱山,乱積み/
らんい /蘭医/
らんうん /乱雲/
らんえ /爛壊/
らんえき /卵液/
らんおう /卵黄/
らんおうのう /卵黄嚢/
らんおうまく /卵黄膜/
らんか /蘭科/爛柯;囲碁の楽しさ/
らんかい /卵塊/
らんかいはつ /乱開発/
らんかく /乱獲/卵殻;shell/濫獲/卵核;[生物]ovum nucleus/
らんかくまく /卵殻膜/
らんかつ /卵割/
らんかつこう /卵割腔/
らんかん /欄干/卵管/藍関/
らんかんさい /卵管采/
らんがい /欄外/
らんがく /蘭学/乱学/
らんがくことはじめ /蘭学事始;杉田玄白(1815)/
らんき /嵐気/
らんきゅう /卵丘/
らんきりゅう /乱気流/
らんぎく /乱菊/
らんぎょう /乱行/
らんぎょく /藍玉/
らんぎり /乱切り/
らんくがい /ランク外/
らんくづけ /ランク付け/
らんぐい /乱杭/乱杙;=乱杭/
らんぐいば /乱杭歯/乱杙歯;歯並びの悪い歯/
らんぐん /乱軍/
らんけーぶる /LANケーブル/
らんけい /卵形/鸞鏡/
らんげき /乱撃/
らんげるはんすとう /ランゲルハンス島/
らんこ /蘭子/
らんこう /乱交;orgy/乱行;=らんぎょう/
らんこうげ /乱高下/
らんこし /蘭越/
らんこん /乱婚/
らんご /蘭語/
らんごく /乱国/
らんさいぼう /卵細胞/
らんざつ /乱雑/
らんざん /嵐山/乱山/
らんし /乱視/卵子/
らんしま /蘭島/
らんしゃ /乱射/
らんしゅ /乱酒/
らんしゅう /蘭州/
らんしょ /蘭書/
らんしょう /卵生;[仏教]/濫觴;origin/
らんしょく /藍色/卵色/
らんしん /乱心/乱臣/
らんしんぞくし /乱臣賊子/
らんじゃたい /蘭奢待/
らんじゅ /藍綬/
らんじゅく /爛熟/
らんじゅくき /爛熟期/
らんじょ /乱序/
らんじょう /乱声/
らんすい /嵐翠;green haze/乱酔/
らんすう /乱数/
らんすうか /乱数化/
らんすうけいれつ /乱数系列/
らんすうせいせい /乱数生成/
らんすうち /乱数値/
らんすうはっせい /乱数発生/
らんすうはっせいき /乱数発生器/
らんすうひょう /乱数表/
らんすうれつ /乱数列/
らんせい /乱世/卵生/
らんせいしょく /藍青色/
らんせん /乱戦/
らんぜん /爛然/
らんそ /濫訴/
らんそう /卵巣/藍藻/乱奏/
らんそううん /乱層雲/
らんそうがん /卵巣癌/卵巣がん/卵巣ガン/
らんそうるい /藍藻類;[植物]blue algae/
らんぞう /濫造/乱造/乱声;=らんじょう/
らんたいせい /卵胎生/
らんたろう /乱太郎/
らんたん /La/Lanthanum/
らんだ /乱打/懶惰/
らんだせん /乱打戦/
らんちき /乱痴気/
らんちきさわぎ /乱痴気騒ぎ/
らんちく /蘭竹;[美術]蘭と竹の画題/
らんちょう /乱調/乱丁/蘭蝶;新内節/鸞鳥/
らんちょうし /乱調子/
らんづみ /乱積み/
らんていじょ /蘭亭序;[固有名詞]王羲之の代表作/
らんてっこう /藍鉄鉱/
らんでぃ /蘭泥/
らんでい /蘭泥/
らんでん /藍田/
らんとう /乱闘/卵塔/
らんとうじけん /乱闘事件/
らんとうちゅう /乱闘中/
らんとうば /卵塔場/
らんどうこう /藍銅鉱/
らんどく /乱読/濫読/濫讀;旧字/
らんどり /乱取り/
らんない /欄内/
らんにゅう /乱入/闌入;無許可で入る/
らんにゅうしゃ /乱入者/
らんにゅうたいせん /乱入対戦/
らんはんしゃ /乱反射/
らんばい /乱売/
らんばつ /乱伐/濫伐/
らんぱく /卵白/
らんぱつ /乱発/濫発/乱髪/
らんびょうし /乱拍子/
らんぴ /乱費/濫費/
らんぴつ /乱筆/
らんぴつらんぶん /乱筆乱文/
らんぶ /乱舞/
らんぶん /乱文/
らんぶんかつ /卵分割/
らんぺき /藍碧/蘭癖/
らんほう /卵胞/
らんぼう /乱暴/乱妨;掠奪・狼藉/濫妨/
らんぼうもの /乱暴者/
らんぼうろうぜき /乱暴狼藉/
らんぽ /乱歩/
らんぽう /卵胞/蘭方/鸞鳳/乱邦/乱峰/
らんぽうい /蘭方医/
らんぽうほるもん /卵胞ホルモン/
らんぽしょう /乱歩賞/
らんぽん /藍本/
らんま /欄間/乱麻;「快刀-」/乱馬/
らんまく /卵膜/
らんまる /蘭丸/
らんまん /爛漫/
らんみゃく /乱脈/
らんもく /ラン目/Gynandrae/Microspermae/Orchidales/
らんもん /乱文/
らんよう /乱用/濫用/卵用/
らんようしゅ /卵用種/
らんらん /爛々/爛爛/
らんり /乱離/
らんりつ /乱立/
らんりつじょうたい /乱立状態/
らんりゅう /乱流/
らんりゅうろん /乱流論/
らんりょう /蘭領;Dutch.「-インドシナ」/
らんりん /乱倫/
らんる /襤褸/藍縷;=襤褸/
らんるい /卵類/
り /理/利/裏;back/裡;inside/里/離;([八卦]陽陰陽)/吏/李/哩;mile/浬;sea mile/釐;1／100/俚;いなか/履/罹;罹災/璃;瑠璃/梨;なし/痢;下痢/莉;茉莉/俐;伶俐/悧;怜悧/漓/籬;まがき/莅;のぞ・む/詈;罵詈/驪;くろうま/
り> /離;離韓,離仏,離国/
りー /李/
りーぐせん /リーグ戦;league game/
りーぐゆうしょう /リーグ優勝/
りーすがいしゃ /リース会社/
りーすけいやく /リース契約/
りーすりょう /リース料/
りーだーかく /リーダー格/
りーち /立直;[麻雀]/
りーどがっき /リード楽器;reed instrument/
りーどせん /リード線/
りあ /里亜/
りあい /理合;reason/理合い/
りあおう /リア王;King Lear,1605?,Shakespeare/
りあげ /利上げ/
りあすしきかいがん /リアス式海岸;rias coast/
りあるたいむしょり /リアルタイム処理/
りいち /利一;名/理一;名/理１/
りいちろう /理一郎;名/
りいん /吏員/
りうまちか /リウマチ科/
りえ /理恵;名/理絵;名/利恵;名/里絵;名/理央;名/里恵;名/里枝;名/利枝;名/利栄;名/莉英;名/リエ;名/
りえき /利益/
りえきかくてい /利益確定/
りえきかんかく /利益感覚;計数感覚/
りえきかんげん /利益還元/
りえきしゃかい /利益社会;[社会学]Gesellschaft/
りえきしゅうだん /利益集団;interest group/
りえきしょぶんけいさんしょ /利益処分計算書/
りえきじゅんびきん /利益準備金;法定準備金の一種。資本金の4分の1に達するまで配当の10分の1以上を積み立てる商法上の制度/
りえきじょうよきん /利益剰余金/
りえきぞう /利益増/
りえきだいひょう /利益代表/
りえきついきゅう /利益追求/
りえきはいとう /利益配当/
りえきはいぶん /利益配分/
りえきふりえき /利益不利益/
りえきぶんぱい /利益分配/
りえきゆうせん /利益優先/
りえきゆうどう /利益誘導/
りえきりつ /利益率/
りえこ /理恵子/利江子/
りえん /離縁/梨園/
りえんじょう /離縁状/
りお /理音/
りおち /利落ち/
りおな /里緒菜/
りか /理科/梨花/李下;-に冠を正さず/里歌/里香/梨香/理香/里佳/理化/利佳/利香/理加/梨加/里花/梨果/
りかい /理解/理会/
りかいかてい /理解過程/
りかいしゃ /理解者/
りかいじょうたい /理解状態/
りかいど /理解度/
りかいのうりょく /理解能力/
りかいふかのう /理解不可能/
りかいふのう /理解不能/
りかいぶそく /理解不足/
りかいりょく /理解力/
りかいりょくぶそく /理解力不足/
りかがく /理化学/
りかがくけんきゅうしょ /理化学研究所/
りかがくけんきゅうじょ /理化学研究所/
りかく /離隔;へだたり/離角;2点の角距離/
りかけい /理科系/
りかけいしゅっしんしゃ /理科系出身者/
りかけいにんげん /理科系人間/
りかこ /里佳子/理香子/りか子/里加子/
りかしつ /理科室/
りかじょしだい /梨花女子大/
りかじょしだいがっこう /梨花女子大学校;韓国/
りかだい /理科大/
りかだいがく /理科大学/
りかてき /理科的/
りかにるい /理科二類/
りかねんぴょう /理科年表/
りかん /罹患/離間/
りかんさく /離間策/
りかんりつ /罹患率/
りがい /利害/理外/
りがいかんけい /利害関係/
りがいかんけいしゃ /利害関係者/
りがいとくしつ /利害得失/
りがく /理学/
りがくけい /理学系/
りがくけいけんきゅうか /理学系研究科/
りがくけんきゅうか /理学研究科/
りがくしゅうし /理学修士/
りがくてき /理学的/
りがくはかせ /理学博士/
りがくはくし /理学博士/
りがくぶ /理学部/
りがくぶ#ごうかん /理学部#0号館/
りがくぶかがっか /理学部化学科/
りがくぶすうがっか /理学部数学科/
りがくぶちょう /理学部長/
りがくぶぶつり /理学部物理/
りがくぶぶつりがっか /理学部物理学科/
りがくりょうほう /理学療法;[医]/
りがくりょうほうし /理学療法士;physical therapist(PT). 国家資格/
りがっか /理学科/
りがん /離岸/
りがんりゅう /離岸流/
りき /力/利器/理気/篥;篳篥/理器;?/
りきいし /力石/
りきえい /力泳/
りきえき /力役/
りきえん /力演/
りきお /力男/力雄/理紀夫/
りきかく /力覚/
りきかん /力感/
りきがく /力学/
りきがくかんけい /力学関係/
りきがくけい /力学系/
りきがくけいりろん /力学系理論/
りきがくけんきゅうしつ /力学研究室/
りきがくてき /力学的/
りきこう /力行/
りきさく /力作/
りきし /力士/
りきしゃ /力者/力車/
りきせき /力積/
りきせつ /力説/
りきせん /力戦;-奮闘/力線;flux line/
りきせんふんとう /力戦奮闘/
りきそう /力走/力漕/
りきぞう /力蔵/
りきたけ /力武/
りきち /利吉/
りきてん /力点/
りきてんし /力天使;virtues/
りきとう /力投/力闘/
りきどう /力動/
りきどうかん /力動感/
りきどうざん /力道山/
りきどうざんじだい /力道山時代/
りきば /力場/力馬;?/
りきや /力也/力哉/
りきゅう /利休/離宮/
りきゅういろ /利休色/
りきゅうねずみ /利休鼠/
りきゅうばし /利休箸/
りきょう /離郷/離京/
りきりつ /力率;[電気] 皮相電力に対する有効電力の割合/
りきりょう /力量/
りきりょうてき /力量的/
りきん /利金/
りぎょ /鯉魚/李漁/
りく /陸/戮;殺戮/勠;(あわせる)/淕;(雪)/
りくあげ /陸揚げ/陸揚/
りくい /陸尉/
りくいぐあな /陸イグアナ/
りくう /陸羽/
りくうさいせん /陸羽西線/
りくうとうせん /陸羽東線/
りくうん /陸運/
りくうんきょく /陸運局/
りくうんぎょう /陸運業/
りくうんしきょく /陸運支局/
りくうんじむきょく /陸運事務局/
りくうんじむしょ /陸運事務所/
りくえい /陸影/
りくえふ /六衛府/
りくお /陸男/
りくか /六花/
りくかい /陸海/
りくかいくう /陸海空/
りくかいくうぐん /陸海空軍/
りくかいぐん /陸海軍/
りくかぜ /陸風/
りくかわ /陸川/
りくかん /六官;NB:[天地春夏秋冬]官/
りくがわ /陸側/
りくがん /陸岸/
りくきょう /陸橋/
りくぎ /六義/
りくぎえん /六義園/
りくぐん /陸軍/
りくぐんしかんがっこう /陸軍士官学校/
りくぐんしき /陸軍式/
りくぐんしょう /陸軍省/
りくぐんだいがっこう /陸軍大学校/
りくぐんだいじん /陸軍大臣/
りくぐんびょういん /陸軍病院/
りくけいとう /陸繋島/
りくけん /陸圏/
りくこう /陸攻/
りくこく /六国;=りっこく/
りくさ /陸佐/
りくし /陸士/
りくしき /陸式/
りくしゅつ /六出/
りくしゅつか /六出花/
りくしょ /六書/
りくしょう /陸相;陸軍大臣/陸将/戮笑;物笑い/
りくじ /陸自/
りくじょう /陸上/
りくじょうかんけい /陸上関係/
りくじょうき /陸上機/
りくじょうきょうぎ /陸上競技/
りくじょうきょうぎじょう /陸上競技場/
りくじょうこうつう /陸上交通/
りくじょうこうつうもう /陸上交通網/
りくじょうじえいたい /陸上自衛隊/
りくじょうたんぱつ /陸上単発/
りくじょうぶ /陸上部/
りくじょうぶたい /陸上部隊/
りくじょく /戮辱/
りくすいがく /陸水学/
りくせい /陸生/陸棲/
りくせいそう /陸成層/
りくせん /陸戦/
りくせんきそく /陸戦規則/
りくせんたい /陸戦隊/
りくぜん /陸前/
りくぜんさんのう /陸前山王/
りくぜんたかた /陸前高田/
りくそう /陸送/陸曹/
りくぞく /陸続/
りくたい /六体/
りくたん /陸単/
りくだな /陸棚/
りくち /陸地/
りくちゅう /陸中/
りくちゅうおおはし /陸中大橋/
りくちょう /六朝/
りくつ /理屈/
りくつぜめ /理屈責め/
りくつづき /陸続き/
りくつぬき /理屈抜き/
りくつや /理屈屋/
りくでん /陸田;畑/
りくとう /陸稲/
りくとうさんりゃく /六韜三略/
りくとく /六徳;人が守るべき六つの徳。「ろくとく」とも/
りくどう /六道/
りくな /陸名;姓/
りくの /陸野/
りくのことう /陸の孤島/
りくはんきゅう /陸半球/
りくふう /陸風/
りくふうがた /陸封型/
りくへい /陸兵/
りくべつ /陸別/
りくぼつ /戮没/
りくやね /陸屋根/
りくよう /陸用/
りくりょく /戮力/
りくれん /陸連/
りくろ /陸路/
りぐい /利食い/
りけい /理系/理経/
りけいがくせい /理系学生/
りけいしんがく /理系進学/
りけいてき /理系的/
りけいにんげん /理系人間/
りけん /理研/利権/利剣/
りけんがらみ /利権絡み/
りけんこうぞう /利権構造/
りげん /俚諺/俚言/理元/
りげんしゅうらん /俚言集覧/
りこ /利己/
りこう /理工/履行/利口/利巧;=利口/悧巧;=利口/悧口;=利口/利光/
りこうか /理工科/
りこうがく /理工学/
りこうがくけん /理工学研/
りこうがくけんきゅうか /理工学研究科/
りこうがくせんこう /理工学専攻/
りこうがくぶ /理工学部/
りこうけい /理工系/
りこうちたい /履行遅滞/
りこうふのう /履行不能/
りこしゅぎ /利己主義/
りこしゅぎしゃ /利己主義者/
りこしん /利己心/
りこせい /利己性/
りこてき /利己的/
りこてきいでんし /利己的遺伝子/
りこん /離婚/利根/
りこんけいけん /離婚経験/
りこんご /離婚後/
りこんじ /離婚時/
りこんとどけ /離婚届/
りこんびょう /離魂病/
りこんりつ /離婚率/
りこんれき /離婚歴/
りご /俚語/
りごう /離合/
りごうしゅうさん /離合集散/
りさ /梨沙/理沙/里沙/里紗/理佐/
りさい /罹災/り災/
りさいしょうめい /り災証明/罹災証明/
りさげ /利下げ/
りさこ /りさ子/
りさつ /利札/
りさぶろう /利三郎/
りさん /離散/理III/
りさんいそう /離散位相/
りさんか /離散化/
りさんかごさ /離散化誤差/
りさんきんじ /離散近似/
りさんけい /離散系/
りさんじかん /離散時間/
りさんじしょう /離散事象/
りさんすうがく /離散数学/
りさんせい /離散性/
りさんち /離散値/
りさんてき /離散的/
りざい /理財/
りざいか /理財家/
りざや /利鞘/
りし /利子/李斯/李四;「李氏の四男」の意/
りししょとく /利子所得;interest income/
りしぜい /利子税;interest tax. min(7.3%,公定歩合+4%)/
りしそうとうがく /利子相当額/
りしほきゅう /利子補給/
りしゅ /理趣;理趣経/
りしゅう /履修/離愁/
りしゅうかもく /履修科目/
りしゅうしゃ /履修者/
りしゅうせい /履修生/
りしゅうちゅう /履修中/
りしゅきょう /理趣経/
りしゅたい /利主体/
りしょう /離床/利生;[仏教]/離礁;⇔座礁/離昇;liftoff/
りしょうばん /李承晩/
りしょく /離職/利殖/
りしょくしゃ /離職者/
りしょくしょうほう /利殖商法/
りしょくひょう /離職票/
りしょくりつ /離職率/
りしり /利尻/
りしりとう /利尻島/
りしん /離心/
りしんりつ /離心率/
りしんろん /理神論/
りじ /理事/
りじかい /理事会/
りじかいしつ /理事会室/
りじこく /理事国/
りじちょう /理事長/
りじつ /離日/
りじゅん /利潤/
りじゅんついきゅう /利潤追求/
りじゅんもくてき /利潤目的/
りじょ /犂鋤/
りじょう /鯉城/
りじょく /詈辱/
りじん /離人/利刃/
りじんかん /離人感/
りじんしょう /離人症/
りす /栗鼠/
りすい /利水/理水/離水/
りすう /理数/
りすうか /理数科/
りすうけい /理数系/
りすくかんり /リスク管理/
りすけ /理介/
りすざる /栗鼠猿/
りすとか /リスト化/
りずむかん /リズム感/
りずむたい /リズム隊/
りせい /理性/離生/
りせいしんぴ /離生心皮/
りせいてき /理性的/
りせいてきそんざいしゃ /理性的存在者/
りせいろん /理性論/
りせき /離席/離籍/
りせつ /利雪;雪の利用/理説/離接;disjunction/
りせん /離船/利銭/離仙/
りそう /理想/離層;[植物]abscission layer/
りそうか /理想化/理想家/
りそうきたい /理想気体/
りそうきょう /理想郷/理想境/
りそうけい /理想形/理想型/理想系/
りそうしゃかい /理想社会/
りそうしゅぎ /理想主義/
りそうしゅぎしゃ /理想主義者/
りそうしゅぎてき /理想主義的/
りそうじょう /理想上/
りそうじょうたい /理想状態/
りそうせかい /理想世界/
りそうぞう /理想像/
りそうち /理想値/
りそうてき /理想的/
りそうてきかんきょう /理想的環境/
りそうてきじょうたい /理想的状態/
りそうは /理想派/
りそうろん /理想論/
りそく /利息/利足/
りそくせいげんほう /利息制限法/
りそくそうとう /利息相当/
りそくぶん /利息分/
りそなぎんこう /りそな銀行/
りそん /離村/
りぞーとち /リゾート地/
りぞく /離俗/
りた /利他/
りたい /履帯/
りたこうどう /利他行動/
りたしゅぎ /利他主義/
りたつ /利達/
りたてき /利他的;⇔利己的/
りだつ /離脱/
りだん /離断/
りち /理知/理智/理致;道理の立つ趣旨/律/篥;呉音(cf.篳篥)/
りちうむ /Li/Lithium/
りちうむでんち /リチウム電池;lithium battery/
りちぎ /律儀/律義;=律儀/
りちてき /理知的/理智的/
りちゃくりく /離着陸/
りちゃくりくじ /離着陸時/
りちゃっかん /離着艦/
りちゅうてんのう /履中天皇/
りちょう /李朝/
りっか /立夏;[二十四節気]5.6頃/
りっかん /律管/六官;=りくかん/
りっきゃく /立脚/立客/
りっきゃくしき /立脚式/
りっきゃくてん /立脚点/
りっきょう /陸橋/立教/
りっきょうせん /立教戦/
りっきょうだい /立教大/
りっきょうだいがく /立教大学/
りっけん /立件/立憲/陸圏/
りっけんくんしゅ /立憲君主/
りっけんくんしゅこく /立憲君主国/
りっけんくんしゅせい /立憲君主制/
りっけんしゅぎ /立憲主義;constitutionalism/
りっけんせいじ /立憲政治/
りっけんせいゆうかい /立憲政友会;[日本史]/
りっけんみんせいとう /立憲民政党;[日本史]/
りっこう /力行/立項/立后/六行;孝・友・睦・姻・任・恤/
りっこうほ /立候補/
りっこうほしゃ /立候補者/
りっこうほしゃすう /立候補者数/
りっこく /立国/六国;[中国史]燕・韓・魏・斉・楚・趙/
りっこくし /六国史/
りっし /立志/律師/律詩;8句の漢詩/
りっしでん /立志伝/
りっしゃくじ /立石寺/
りっしゅう /立秋;[二十四節気]8.8頃/律宗/
りっしゅん /立春;[二十四節気]2.4頃/
りっしょう /立証/立正;-佼成会/立哨/
りっしょうあんこくろん /立正安国論/
りっしょうこうせいかい /立正佼成会/
りっしょうせきにん /立証責任/
りっしょうちゅう /立証中/
りっしょく /立食/
りっしん /立身/
りっしんしゅっせ /立身出世/
りっすい /立錐;-の余地もない/立推;?/
りっすいせん /立水栓/
りっすいのち /立錐の地/立錐之地/
りっせき /立席/
りっせんぽう /律旋法/
りっそう /律僧/
りっそく /律速;(concat "複要素が絡み合う事柄を律しているのはどの要素か。http:\057\057www.h3.dion.ne.jp\057~nahonoro")/
りっそくだんかい /律速段階/
りったい /立体/
りったいえいぞう /立体映像/
りったいか /立体化/
りったいかく /立体角/
りったいかん /立体感/
りったいがぞう /立体画像/
りったいきょう /立体鏡/
りったいけいじょう /立体形状/
りったいこうさ /立体交差/
りったいこうぞう /立体構造/
りったいし /立体視/立太子/
りったいしがぞう /立体視画像/
りったいしゃしん /立体写真/
りったいずけい /立体図形/
りったいぞう /立体像/
りったいちゅうしゃじょう /立体駐車場/
りったいてき /立体的/
りったいは /立体派;[美術]cubism/
りったいばん /立体版/
りったいぶつ /立体物/
りっち /立地/
りっちじょうけん /立地条件/
りっちほう /立地法;[法][略語]大規模小売店舗立地法/
りっとう /立冬;[二十四節気]11.8頃/立党/立刀;[部首]「利」の旁/栗東;地名/立東;人名?/
りっとうしゃ /立東社/
りっとうちょう /栗東町/
りっとく /六徳;単位。10^-19/
りっぱ /立派/
りっぷく /立腹/
りっぽう /立法;†legislation.「議員-」/立方;†cube.「-メートル」/律法;law.「モーセの-」/
りっぽう> /立方;(cubic) -(ミリ|センチ|キロ)メートル,-フィート,-格子/
りっぽういん /立法院/
りっぽうきかん /立法機関/
りっぽうけん /立法権/
りっぽうこうし /立方格子/
りっぽうこん /立方根/
りっぽうしょうけい /立方晶系;[化学]cubic system/
りっぽうすう /立方数/
りっぽうたい /立方体/
りっぽうふ /立法府/
りっぽうろん /立法論/
りつ /率/立/律/葎;むぐら/慄;慄然/栗;くり/
りつあん /立案/
りつい /立位/
りつおんかい /律音階;ドレファソラド/
りつがん /立願/
りつき /利付き/
りつきょう /立教/
りつぎ /律儀/
りつけいさん /率計算/
りつげん /立言/
りつこ /律子/りつ子/利津子/理津子/里葎子/
りつご /律語/
りつじゅん /率順/
りつぜん /慄然/
りつぞう /立像/
りつだい /立大/
りつどう /律動/
りつどうてき /律動的;rhythmical/
りつぶん /律文/
りつめい /立命/
りつめいかん /立命館/
りつめいかんだい /立命館大/
りつめいかんだいがく /立命館大学/
りつめいかんだいがくいん /立命館大学院/
りつめいがわ /立命側/
りつめいせん /立命戦/
りつめいだい /立命大/
りつめんず /立面図/
りつもうきん /立毛筋/
りつりつ /栗栗/慄慄;=栗栗/
りつりょう /律令/
りつりょうきゃくしき /律令格式/
りつりょうこっか /律令国家/
りつりょうじだい /律令時代/
りつりょうせい /律令制/
りつりん /栗林/
りつりんこうえん /栗林公園;香川/
りつれい /立礼/律令;=りつりょう/
りつれつ /慄冽/
りつろん /立論/
りづめ /理詰め/理詰/
りてい /里程/
りていひょう /里程標/
りてき /利敵/理的/
りてん /利点/
りとう /離島/離党/利刀/吏党;⇔民党/
りとく /利得/
りとますし /リトマス紙/
りとますしけんし /リトマス試験紙;litmus paper/
りどう /里道/
りどん /利鈍/
りな /里奈/梨奈/利奈/里菜/理奈/梨菜/莉菜/梨名/ＲＩＮＡ/
りに /理２/
りにち /離日/
りにゅう /離乳/
りにゅうしょく /離乳食/
りにょう /利尿/
りにょうやく /利尿薬/
りにん /離任/
りにんしき /離任式/
りにんち /離任地/
りねん /理念/
りねんけい /理念型;Idealtypus(独)/
りねんしつ /リネン室;linen room/
りの /梨乃/
りのーるさん /リノール酸;C17H31COOH/
りのう /離農/
りはい /離背/
りはく /李白/理博;[略語]理学博士/
りはっちゃく /離発着/
りはっちゃくかいすう /離発着回数/
りはつ /理髪/利発/
りはつし /理髪師/
りはつてん /理髪店/
りはつりく /離発陸/
りはば /利幅/
りはびりか /リハビリ科/
りはびりてーしょんか /リハビリテーション科/
りはん /離反/離叛;≒離反/
りばけ /理化/
りばらい /利払い/
りひ /理非/
りひきょくちょく /理非曲直/
りびょう /罹病;infection/痢病;赤痢など/
りふ /利府/
りふく /利福/
りふじん /理不尽/
りふだ /利札/
りふとけん /リフト券/
りぶつ /理物/
りぶん /利分/
りへい /利平/
りべい /離米/
りべつ /離別/
りべん /利便/離弁/
りべんか /離弁花/
りべんかるい /離弁花類/Apopetalae/Choripetalae/
りべんせい /利便性/
りほ /里穂/理穂/理保/
りほう /理法/李鵬;(Li Peng, 1928-) 中国の政治家/
りほこ /理保子/
りぼかくさん /リボ核酸/
りぼばらい /リボ払い/
りまわり /利回り/
りまんかいりゅう /リマン海流;Liman current/
りみ /梨美/
りむ /吏務/
りめん /裏面/裡面/
りめんし /裏面史/
りゃく /略/掠;掠奪/擽;くすぐ・る/畧;「略」の異体字/
りゃく> /略;略年表,略地図,略礼服/
りゃくおう /暦応;年号(1338-1342)/
りゃくかい /略解/
りゃくが /略画/
りゃくき /略記/
りゃくきほう /略記法/
りゃくぎ /略儀/
りゃくげ /略解/
りゃくげん /略言/
りゃくこう /略光/
りゃくご /略語/
りゃくごう /略号/
りゃくごしゅう /略語集/
りゃくさん /略算/
りゃくしき /略式/
りゃくしききそ /略式起訴/
りゃくしきさいばん /略式裁判/
りゃくしきてつづき /略式手続/
りゃくしきめいれい /略式命令/
りゃくしゅ /略取/
りゃくしゅゆうかいざい /略取誘拐罪/
りゃくしょ /略書/
りゃくしょう /略称/略章/
りゃくしょうひょう /略称表/
りゃくじ /略字/
りゃくじゅ /略綬/
りゃくじゅつ /略述/
りゃくじょ /略叙/
りゃくず /略図/
りゃくせつ /略説/
りゃくそう /略装/
りゃくたい /略体/
りゃくだつ /略奪/掠奪/
りゃくだつあい /略奪愛/
りゃくだつこん /略奪婚/
りゃくだつしゃ /略奪者/
りゃくちず /略地図/
りゃくでん /略伝/
りゃくにん /暦仁;年号(1238-1239)/
りゃくねんぴょう /略年表/
りゃくひつ /略筆/
りゃくひょう /略表/
りゃくふ /略譜/
りゃくふく /略服/
りゃくほん /略本/
りゃくぼう /略帽/
りゃくめい /略名/
りゃくれいふく /略礼服/
りゃくれき /略歴/
りゃくれきしょ /略歴書/
りゃっかい /略解/
りゃっき /略記/
りゃっきほう /略記法/
りゃんそう /二索/
りゃんはんしばり /二翻縛/
りゃんめん /両面;[麻雀]/
りやく /利益/理薬/
りゅーいーそー /緑一色/
りゅーふぁー /緑発/
りゅう /竜/龍;「竜」の旧字(人名用漢字)/流/溜;溜飲/澑;「溜」の異体字/留;留学/畄;「留」の異体字/瑠;瑠璃/榴;手榴弾/瘤;(こぶ)肉瘤/霤;したたり/餾;むす/隆;隆起/嶐/窿;穹窿/笠;かさ/立;建立/粒;粒子/苙;おり/琉;琉球/硫;硫酸/旒/柳;花柳/鉚/劉;劉備/嚠/瀏/鏐;(純金)/
りゅうあん /硫安;硫酸アンモニウム/劉安;人名,淮南子の編者/
りゅうあんかめい /柳暗花明/
りゅうあんじ /竜安寺/
りゅうい /留意/
りゅういいそう /緑一色/
りゅういき /流域/
りゅういじこう /留意事項/
りゅういち /隆一/龍一/竜一/
りゅういちろう /隆一郎/竜一郎/
りゅういてん /留意点/
りゅういん /溜飲/
りゅううん /隆運/
りゅうおう /竜王/龍王/
りゅうおうせん /竜王戦/
りゅうおん /流音/
りゅうか /硫化/流下/琉歌/
りゅうか> /硫化;[化学]sulfide/
りゅうかあえん /硫化亜鉛;[化学]ZnS/
りゅうかい /流会/
りゅうかぎん /硫化銀;[化学]Ag2S/
りゅうかくさん /龍角散/
りゅうかすいぎん /硫化水銀/
りゅうかすいそ /硫化水素/
りゅうかせんりょう /硫化染料/
りゅうかてつ /硫化鉄;[化学]FeS,Fe2S3,FeS2/
りゅうかどう /硫化銅;[化学]CuS,Cu2S/
りゅうかぶつ /硫化物;[化学]sulfid/
りゅうかん /流感/流汗;sweating/
りゅうがく /留学/
りゅうがくせい /留学生/
りゅうがくせいか /留学生課/
りゅうがくせいかつ /留学生活/
りゅうがくせいぜんいん /留学生全員/
りゅうがくせいたち /留学生達/
りゅうがくせいもんだい /留学生問題/
りゅうがくちゅう /留学中/
りゅうがくびざ /留学ビザ/
りゅうがさき /竜ヶ崎/竜崎/竜ケ崎/龍崎/
りゅうがだけ /竜ヶ岳/
りゅうがん /龍眼/竜眼/竜顔;天子の顔/
りゅうき /隆起/竜旗;天子の旗/劉貴/
りゅうきこう /硫気孔/
りゅうきし /竜騎士/
りゅうきへい /竜騎兵/
りゅうきゅう /琉球/
りゅうきゅういも /琉球芋/
りゅうきゅうおうちょう /琉球王朝/
りゅうきゅうおもて /琉球表;畳の./
りゅうきゅうおんかい /琉球音階/
りゅうきゅうぎんこう /琉球銀行/
りゅうきゅうこ /琉球弧/
りゅうきゅうご /琉球語/
りゅうきゅうじん /琉球人/
りゅうきゅうだい /琉球大/
りゅうきゅうだいがく /琉球大学/
りゅうきゅうほうげん /琉球方言/
りゅうきゅうほうそう /琉球放送/
りゅうきょう /劉向;BC77-BC6/
りゅうきょく /流局/
りゅうきん /琉金/
りゅうぎ /流儀/
りゅうぐう /龍宮/竜宮/流寓/
りゅうぐうじょう /竜宮城/龍宮城/
りゅうけい /粒径;particle size/流刑/
りゅうけつ /流血/
りゅうけん /竜権/
りゅうげ /竜華/
りゅうげん /流言/
りゅうげんひご /流言飛語/流言蜚語/
りゅうこ /龍虎/竜虎/隆子/竜子/
りゅうこう /流行/隆興/龍宏/劉向;BC77-BC6/流光/
りゅうこうおんがく /流行音楽/
りゅうこうか /流行歌/
りゅうこうご /流行語/
りゅうこうしょく /流行色;服や口紅など/
りゅうこうじょうほう /流行情報/
りゅうこうせい /流行性/
りゅうこうせいかんぼう /流行性感冒/
りゅうこうせいじかせんえん /流行性耳下腺炎;[医]/
りゅうこうびょう /流行病/
りゅうこく /竜谷/龍谷/
りゅうこくだい /龍谷大/
りゅうこくだいがく /龍谷大学/
りゅうこくだいがくせた /龍谷大学瀬田/
りゅうこくだいりこう /龍谷大理工/
りゅうこつ /竜骨/
りゅうこつざ /竜骨座;Carina(Car)/
りゅうご /隆吾/龍五/立鼓/輪鼓;=立鼓/
りゅうさ /流砂/流沙/
りゅうさん /硫酸/
りゅうさんし /硫酸紙/
りゅうさんだん /榴散弾/
りゅうさんどう /硫酸銅/
りゅうざ /竜座;Draco(Dra)/
りゅうざい /粒剤;granule/
りゅうざき /竜崎/
りゅうざん /流産/竜山/流竄/
りゅうし /粒子/
りゅうしけいそく /粒子計測/
りゅうしすう /粒子数/
りゅうしせい /粒子性/
りゅうしせん /粒子線/
りゅうしそく /粒子束/
りゅうしそくど /粒子速度/
りゅうしち /流質/
りゅうしつ /流失/
りゅうしゃ /流沙/竜車/
りゅうしゅつ /流出/
りゅうしゅつすい /流出水/
りゅうしょう /隆昌/
りゅうしょく /粒食;⇔粉食/柳色/
りゅうじ /龍二/隆二/竜二/隆治/隆司/隆史/
りゅうじゅ /龍樹;(Nagarjuna) 人名,仏教学者/竜樹/
りゅうじょ /柳絮/
りゅうじょう /粒状/
りゅうじょうかっせいたん /粒状活性炭/
りゅうじょうこ /柳条湖;地名,中国・遼寧省/
りゅうじょうこし /竜驤虎視/
りゅうじょうこはく /竜攘虎搏/
りゅうじょうせい /粒状性/
りゅうじん /龍神/竜神/
りゅうすい /流水/
りゅうすう /留数/
りゅうすけ /隆介/竜介/龍介/竜助/龍輔/
りゅうず /竜頭/
りゅうせい /流星/隆盛/
りゅうせいう /流星雨/
りゅうせいかんそく /流星観測/
りゅうせいぐん /流星群/
りゅうせいじん /流星塵/
りゅうせつ /流説/
りゅうせん /流線/流涎/隆線/
りゅうせんかく /竜泉閣/
りゅうせんかんすう /流線関数/
りゅうせんけい /流線型/流線形/
りゅうぜつらん /竜舌蘭/龍舌蘭/
りゅうぜん /流涎/
りゅうぜんこう /竜涎香/
りゅうそうげん /柳宗元;773-819/
りゅうそうざん /流早産/
りゅうそく /流速/流束/
りゅうそくけい /流速計;current metre/
りゅうぞう /立像/隆三/竜三/龍蔵/
りゅうぞうじ /龍造寺/
りゅうぞく /流俗/
りゅうた /隆太/竜太/
りゅうたい /流体/隆替/
りゅうたいかいせき /流体解析/
りゅうたいかがくけんきゅうじょ /流体科学研究所/
りゅうたいけん /流体研/流体科学研究所;※abbrev/
りゅうたいこうがく /流体工学/
りゅうたいじくうけ /流体軸受/流体軸受け/
りゅうたいぶつり /流体物理/
りゅうたいりきがく /流体力学/
りゅうたく /流謫/
りゅうたつぶし /隆達節;小唄/
りゅうたろう /龍太郎/竜太郎/
りゅうたん /竜胆/
りゅうだい /琉大;[略語]琉球大学/龍大;[略語]龍谷大学/
りゅうだん /榴弾/流弾/榴彈;旧字/
りゅうだんほう /榴弾砲;howitzer/
りゅうち /留置/
りゅうちけん /留置権/
りゅうちしゅう /笠智衆/
りゅうちじょ /留置所/
りゅうちじょう /留置場/
りゅうちせん /留置線/
りゅうちばり /留置針/
りゅうちぶつ /留置物/
りゅうちょう /流暢/留鳥;⇔渡り鳥/
りゅうちよう /留置用/
りゅうつう /流通/
りゅうつうかかく /流通価格/
りゅうつうかがくだいがく /流通科学大学/
りゅうつうかくめい /流通革命/
りゅうつうかてい /流通過程/
りゅうつうきこう /流通機構/
りゅうつうぎょう /流通業/
りゅうつうぎょうしゃ /流通業者/
りゅうつうけい /流通系/
りゅうつうけいざい /流通経済;distribution economics/
りゅうつうけいひ /流通経費/
りゅうつうけいろ /流通経路/
りゅうつうしじょう /流通市場/
りゅうつうしゅだん /流通手段/
りゅうつうしんぶん /流通新聞/
りゅうつうじじょう /流通事情/
りゅうつうじょう /流通上/
りゅうつうじょうきょう /流通状況/
りゅうつうじょうほう /流通情報/
りゅうつうせい /流通性/
りゅうつうだんかい /流通段階/
りゅうつうまい /流通米/
りゅうつうりょう /流通量/
りゅうつぼ /立坪/
りゅうてい /流涕/
りゅうてき /龍笛/竜笛/
りゅうでん /流電/流伝/
りゅうとう /竜頭/竜党/
りゅうとうげきしゅ /竜頭鷁首/
りゅうとうだび /竜頭蛇尾/龍頭蛇尾/
りゅうど /粒度/
りゅうどう /流動/竜童/竜堂/
りゅうどうか /流動化/
りゅうどうけんきゅういん /流動研究員/
りゅうどうしさん /流動資産;当座資産、棚卸資産、その他の流動資産(前払費用、未収入金、短期貸付金など)の3つ/
りゅうどうしょく /流動食/
りゅうどうせい /流動性/
りゅうどうせいはいれつほう /流動性配列法;貸借対照表などで換金性の高い項目から順に配列するルール/
りゅうどうせいよきん /流動性預金/
りゅうどうたい /流動体/
りゅうどうてき /流動的/
りゅうどうひりつ /流動比率/
りゅうどうふさい /流動負債/
りゅうどうぶつ /流動物/
りゅうにち /留日/
りゅうにゅう /流入/
りゅうにん /留任/
りゅうねん /留年/
りゅうねんせい /留年生/
りゅうのすけ /龍之介/竜之介/
りゅうのひげ /竜の鬚/
りゅうは /流派/
りゅうばんこきょ /竜蟠虎踞/
りゅうひょう /流氷/
りゅうび /劉備;三国時代・蜀漢の初代皇帝/柳眉/
りゅうびじゅつ /隆鼻術/
りゅうふう /流風/
りゅうへい /流弊;横行している弊害/龍平;名/
りゅうべい /立米/
りゅうべつ /留別/
りゅうべん /流眄/
りゅうほ /留保/
りゅうほう /劉邦;前漢の初代皇帝/龍鳳/隆法;人名/
りゅうほく /竜北/
りゅうぼう /流亡/流氓;流浪の民/
りゅうぼく /流木/立木;[法]/
りゅうま /竜馬/
りゅうみん /流民/
りゅうめ /竜馬;(将棋)成った角/
りゅうもん /竜門/竜文/竜紋/
りゅうよう /流用/竜洋/柳腰/
りゅうようか /流用化/
りゅうようひん /流用品/
りゅうようほう /流用法/
りゅうり /流離/
りゅうりゅう /隆々;「筋骨-」/粒々;「-辛苦」/隆隆/粒粒/嚠々;冴えた音色/嚠嚠/
りゅうりゅうしんく /粒々辛苦/粒粒辛苦/
りゅうりょう /流量/
りゅうりょうけい /流量計;flowmeter/
りゅうりょうちょうせつ /流量調節/
りゅうりょくかこう /柳緑花紅/
りゅうるい /流涙/
りゅうるいしょう /流涙症;[医]/
りゅうれい /流麗/立礼/
りゅうれいしき /立礼式/
りゅうれん /流連/
りゅうれんこうぼう /流連荒亡/
りゅうろ /流路;channel.「河川の-」/流露;effusion.「感情の-」/
りゆう /理由/
りゆうしょ /理由書/
りゆうせつめい /理由説明/
りゆうづけ /理由付け/理由付/
りょ /旅/慮;遠慮/虜;捕虜/侶;伴侶/呂;(漢音)/梠/絽;(漢音) ろ/閭;むら/膂;膂力/踉;?/
りょう /量/両/寮/料/了/良/領/漁;fish/猟;hunt/涼/陵;天皇陵/梁;はり/粱;高粱/糧;食糧/粮;「糧」の異体字/僚;同僚/療;医療/瞭;明瞭/暸;「瞭」の異体字/遼;遼遠/撩;撩乱/繚;百花繚乱/燎;かがりび/鐐;ひらかね/鷯;鷦鷯/椋;むく/諒;諒承/凉;「涼」の旧字(人名用漢字)/寥;寂寥/廖/繆/蓼;たで/綾;あや/菱;ひし/凌;凌辱/稜;稜角/崚/倆;技倆/兩;「両」の旧字/裲;裲襠/輛;車輌/輌;「輛」の異体字/魎;魑魅魍魎/獵;「漁」の旧字/鬣;たてがみ/令;律令制/怜;(呉音) 怜悧(れいり)/嶺;(呉音) 山嶺(さんれい)/亮;諸葛亮/喨/霊;怨霊/靈;「霊」の旧字/聊;無聊/楞/
りょう> /両/良;良作,良馬場,良ゲーム/
りょうあし /両足/両脚/
りょうあて /寮宛/
りょうあん /両案/良案/
りょうあんじ /竜安寺/
りょうい /霊異/良医/稜威/良為/
りょういき /領域/
りょういきか /領域化/
りょういきかいほう /領域解放/
りょういきかくほ /領域確保/
りょういきがい /領域外/
りょういきしてい /領域指定/
りょういきない /領域内/
りょういきぶんかつ /領域分割/
りょういきぶんかつほう /領域分割法/
りょういきりろん /領域理論/
りょういきろん /領域論/
りょういち /良一/亮一/遼一/龍一/竜一/領一/凌一/
りょういちろう /良一郎/良一朗/
りょういん /両院/
りょういんきょうぎかい /両院協議会/
りょうう /涼雨/
りょううで /両腕/
りょううわて /両上手/
りょううん /凌雲/
りょううんしゃ /両運車/
りょううんてんだい /両運転台/
りょうえき /両駅/
りょうえきかん /両駅間/
りょうえん /良縁/遼遠/
りょうえんこ /両円弧/
りょうおち /両落ち/
りょうおもい /両思い/両想い/
りょうおやゆび /両親指/
りょうおんせい /両音声/
りょうか /量化;quantify/良化;ameliorate/寮歌/良貨/涼香;名/良家;=りょうけ/良過;?/
りょうかい /了解/領海/諒解;≒了解/両界;[仏教]金剛界と胎蔵界/領解;≒了解/領会/
りょうかいしんぱん /領海侵犯/
りょうかいじこう /了解事項/
りょうかいずみ /了解済み/
りょうかいせい /了解性/
りょうかいせん /領海線/
りょうかいど /了解度/
りょうかいない /領海内/
りょうかいほう /領海法/
りょうかいまんだら /両界曼荼羅;金剛界曼荼羅と胎蔵界曼荼羅/
りょうかがた /良化型/
りょうかく /稜角/
りょうかし /量化子/
りょうかた /両方/両肩/
りょうかみ /両神/
りょうかん /涼感/量感/良寛;歌人/寮監/僚艦/両艦/猟官;[政治]spoil (system). -制,-運動/寮管/
りょうかんせい /猟官制/
りょうが /凌駕/
りょうがいじん /両外人/
りょうがえ /両替/
りょうがえき /両替機/
りょうがえしょう /両替商/
りょうがえじょ /両替所/
りょうがえてすうりょう /両替手数料/
りょうがえや /両替屋/
りょうがわ /両側/
りょうがん /両岸/両眼/
りょうがんし /両眼視/
りょうがんしさ /両眼視差/
りょうがんりったいし /両眼立体視/
りょうき /猟奇/漁期/両機/僚機/猟期/涼気/量器/
りょうきおう /猟奇王/
りょうきき /両利き/
りょうきごう /量記号/
りょうきさつじん /猟奇殺人/
りょうきち /良吉/亮吉/
りょうきてき /猟奇的/
りょうきゃく /両脚/
りょうきょく /両極/
りょうきょくしゅう /両曲集/
りょうきょくたん /両極端/
りょうきん /料金/
りょうきんあんない /料金案内/
りょうきんか /料金課/
りょうきんかいてい /料金改定/
りょうきんかくさ /料金格差/
りょうきんけいさん /料金計算/
りょうきんけん /料金券/
りょうきんさ /料金差/
りょうきんしょ /料金所/
りょうきんしょじゅうたい /料金所渋滞/
りょうきんじょ /料金所/
りょうきんじょじゅうたい /料金所渋滞/
りょうきんせいきゅう /料金請求/
りょうきんせってい /料金設定/
りょうきんたいけい /料金体系/
りょうきんちゃくばらい /料金着払/
りょうきんちょうしゅう /料金徴収/
りょうきんてき /料金的/
りょうきんねさげ /料金値下げ/料金値下/
りょうきんばこ /料金箱/
りょうきんひょう /料金表/
りょうきんふたん /料金負担/
りょうきんふよう /料金不要/
りょうきんぷらん /料金プラン/
りょうきんべつのう /料金別納/
りょうぎ /両義/
りょうぎいん /両議院/
りょうぎし /両岸/
りょうぎせい /両義性/
りょうぎてき /両義的/
りょうぎり /両切り/
りょうくう /領空/
りょうくうかん /両空間/
りょうくうけん /領空権/
りょうくうしんぱん /領空侵犯/
りょうくちびる /両唇/
りょうくん /両君/
りょうぐ /猟具/
りょうぐん /両軍/両群/
りょうぐんせんしゅ /両軍選手/
りょうけ /両家/領家/良家/
りょうけい /量刑/両系/良形/良計/菱形/
りょうけいとう /両系統/
りょうけつ /良血/
りょうけつば /良血馬/
りょうけん /猟犬/了見/両県/料簡/了簡/良兼/
りょうけんざ /猟犬座;Canes Venatici(CVn)/
りょうけんちがい /料簡違い;-も甚だしい/
りょうげ /領解/令外/
りょうげん /両舷/燎原/
りょうげんご /両言語/
りょうこ /涼子/良子/亮子/量子/遼子/僚子/了子/凌子/領子/寮子/
りょうこう /良好/両校/良港/良工/
りょうこうほ /両候補/
りょうこうり /両公理/
りょうこく /両国/
りょうこくかん /両国間/
りょうご /良吾;名/
りょうごく /両国/領国/
りょうごくけっせん /両国決戦/
りょうごくこくぎかん /両国国技館/
りょうごくたいかい /両国大会/
りょうごくはなにしきとうし /両国花錦闘士/
りょうごくばし /両国橋/
りょうごくほうめん /両国方面/
りょうごくよびこう /両国予備校/
りょうさい /良妻/寮祭/
りょうさいけんぼ /良妻賢母/
りょうさいしい /聊斎志異;中国文学/
りょうさいど /両サイド/
りょうさく /良作;名/良策/
りょうさくひん /両作品/
りょうさつ /了察/
りょうさん /量産/
りょうさんか /量産化/
りょうさんがた /量産型/
りょうさんき /量産機/
りょうさんけい /量産形/
りょうさんこうか /量産効果/
りょうさんしゃ /量産車/
りょうさんちゅう /量産中/
りょうざい /良材/梁材/良剤/
りょうざぶろう /量三朗/
りょうざんぱく /梁山泊/
りょうし /量子/漁師/猟師/両氏/両市/料紙/両誌/良師/遼史;二十一史/良之/
りょうしあい /両試合/
りょうしあんごう /量子暗号;[情報]quantum encryption/
りょうしいろりきがく /量子色力学;quantum chromodynamics/
りょうしうちゅう /量子宇宙/
りょうしか /量子化/
りょうしかがく /量子化学/
りょうしかがくけいさん /量子化学計算/
りょうしかがくてき /量子化学的/
りょうしかせつ /量子仮説;プランクの-/
りょうしき /良識/両式/
りょうしきか /良識家/
りょうしきじん /良識人/
りょうしきてき /良識的/
りょうしきのふ /良識の府;参議院/
りょうしこうか /量子効果/
りょうしこうがく /量子工学;†quantum engineering/量子光学;†quantum optics/
りょうしこうぞう /量子構造/
りょうしこうりつ /量子効率/
りょうしざつおん /量子雑音/
りょうしすう /量子数;[物理]quantum number/
りょうしつ /良質/
りょうしてき /量子的/
りょうしでんし /量子電子/
りょうしでんじきがく /量子電磁気学/
りょうしとうけい /量子統計/
りょうしば /量子場/
りょうしぶつり /量子物理/
りょうしぶつりがく /量子物理学/
りょうしゃ /両者/両社/寮舎/
りょうしゃかん /両者間/
りょうしゃきょうつう /両者共通/
りょうしゃはんそく /両者反則/
りょうしゅ /領主/良種/領取/料酒/
りょうしゅう /領収/領袖/涼州;地名,中国甘粛省/涼秋/
りょうしゅういん /領収印/
りょうしゅうがく /領収額/
りょうしゅうしょ /領収書/
りょうしゅうしょう /領収証/
りょうしゅうずみ /領収済/
りょうしゅけん /領主権/
りょうしゅだい /両主題/
りょうしゅほう /両手法/
りょうしょ /両所/両書/良書/梁書;二十一史/料所/領所/猟書/
りょうしょう /了承/諒承/
りょうしょく /糧食;ration/寮食;寮の食堂/猟色/
りょうしょくどう /寮食堂/
りょうしりきがく /量子力学/
りょうしりきがくてき /量子力学的/
りょうしろん /量子論/
りょうしん /両親/良心/両唇/両身/
りょうしんおん /両唇音;[音声学]bilabial/
りょうしんせい /両新製/
りょうしんてき /良心的/
りょうしんとも /両親共/
りょうしんのじゆう /良心の自由;憲法19条/
りょうじ /領事/両耳/令旨/療治/両次/良治;人名/良二/亮二/亮治/良知/良司/良至/
りょうじかん /領事館/両耳間/両時間/
りょうじかんさ /両耳間差/
りょうじく /両軸/
りょうじこうか /両耳効果/
りょうじさ /両耳差/
りょうじそうよう /両耳装用/
りょうじちかい /寮自治会/
りょうじちょう /両耳聴/
りょうじつ /両日/
りょうじつさんか /両日参加/
りょうじゅう /猟銃/
りょうじゆうごう /両耳融合/
りょうじょ /梁書;二十一史/諒恕/
りょうじょう /梁上;-の君子(泥棒or鼠)/繚繞/
りょうじょく /陵辱/凌辱;=陵辱/
りょうじん /良人/梁塵/猟人/
りょうじんえい /両陣営/
りょうじんひしょう /梁塵秘抄;後白河法皇/
りょうすい /量水/領水/
りょうすいき /量水器/
りょうすう /両数/輛数/
りょうすけ /亮介/良介/良祐/良助/了介/領介/遼右/
りょうず /両図/
りょうせい /良性/両性;†both sexes/寮生/両生;†-類/令制/両棲;=両生/
りょうせいか /両性花/
りょうせいかつ /寮生活/
りょうせいぐゆう /両性具有/
りょうせいしゅよう /良性腫瘍;[医]benign tumour/
りょうせいしょく /寮生食/
りょうせいせいしょく /両性生殖;[生物]⇔単性生殖/
りょうせいたいかい /寮生大会/
りょうせいばい /両成敗/
りょうせいびょうどう /両性平等/
りょうせいふ /両政府/
りょうせいるい /両生類/両棲類/
りょうせつ /両説/
りょうせん /稜線/両船/僚船/両線/両川/
りょうせんしゅ /両選手/
りょうせんじょう /稜線上/
りょうせんせい /両先生/
りょうせんぱつとうしゅ /両先発投手/
りょうせんれつ /稜線列/
りょうぜいほう /両税法/
りょうぜつ /両舌/
りょうぜん /瞭然/両全;忠孝-/霊山/
りょうそく /寮則/両側;(医学などで)/
りょうそくめん /両側面/
りょうそしき /両組織/
りょうそで /両袖/
りょうぞう /良三/
りょうぞく /良俗/
りょうぞくせい /両属性/
りょうた /亮太/良太/
りょうたいおう /両対応/
りょうたいすう /両対数/
りょうたいせん /両大戦/
りょうたいせんかん /両大戦間/
りょうたろう /遼太郎/良太郎;名/亮太郎/
りょうたん /両端/
りょうたんてん /両端点/
りょうだいがく /両大学/
りょうだて /両建て/
りょうだめ /両為/
りょうだん /両断/
りょうだんたい /両団体/
りょうち /領地/了知/良知/領置/料地/
りょうちーむ /両チーム/
りょうちく /両地区/
りょうちょ /良著/
りょうちょう /寮長/猟鳥/
りょうちりょうのう /良知良能/
りょうつ /両津/
りょうつじんく /両津甚句;[民謡]新潟./
りょうて /両手/
りょうてい /料亭/量定/涼亭;涼むあずまや/
りょうてき /量的/
りょうてきかんわ /量的緩和;マネーサプライの-/
りょうてきへんか /量的変化/
りょうてきもんだい /量的問題/
りょうてなべ /両手鍋/
りょうてもち /両手持ち/
りょうてりょうあし /両手両足/
りょうてんさい /両天才/
りょうてんびん /両天秤/
りょうでん /菱電/
りょうでんか /両殿下/
りょうと /良図/
りょうとう /両党/両刀/遼東;Liaodong/両頭/竜頭/両統/
りょうとうつかい /両刀使い/
りょうとうづかい /両刀遣い/両刀使い/
りょうとうてつりつ /両統迭立/
りょうとうろんぽう /両刀論法/
りょうとく /両得/領得/
りょうとし /両都市/
りょうど /領土/両度/
りょうどう /両道/領導/糧道/
りょうどうたい /良導体/
りょうどかくだい /領土拡大/
りょうどない /領土内/
りょうどなり /両隣/
りょうどほぜん /領土保全/
りょうどもんだい /領土問題/
りょうない /領内/寮内/
りょうなん /綾南/
りょうにらみ /両睨み/
りょうにん /両人/良人/
りょうねい /遼寧/
りょうねん /両年/
りょうの /稜野/
りょうのう /両脳/菱脳;hindbrain/
りょうは /両派/
りょうはい /両肺/
りょうはし /両端/
りょうはじ /両端/
りょうはん /量販/両班/
りょうはんきゅう /両半球/
りょうはんてん /量販店/
りょうば /漁場/両刃/両馬/良馬/猟場/
りょうばつきてい /両罰規定;[法]従業者の罪は事業主の罪/
りょうばば /良馬場/
りょうばんこきょ /竜蟠虎踞/
りょうひ /良否/寮費/
りょうひざ /両膝/
りょうひつ /良筆/
りょうひん /良品/
りょうび /両備/綾美/
りょうびょう /療病/
りょうびらき /両開き/
りょうびん /両鬢/
りょうふ /寮父/両夫/猟夫/
りょうふう /涼風/良風/
りょうぶ /両部/
りょうぶしんとう /両部神道/
りょうぶもん /両部門/
りょうぶん /領分/両分/領文;?/
りょうぶんや /両分野/
りょうへい /良平/
りょうへいか /両陛下/
りょうへき /両壁/
りょうへん /両辺/
りょうほ /稜堡/
りょうほう /両方/療法/良法/
りょうほういっしょ /両方一緒/
りょうほうかくにん /両方確認/
りょうほうこう /両方向/
りょうほうさいよう /両方採用/
りょうほうし /療法士/
りょうほうしき /両方式/
りょうほうそうび /両方装備/
りょうほうたいおう /両方対応/
りょうほうとも /両方共/
りょうほうどうじ /両方同時/
りょうほうほう /両方法/
りょうほぞん /量保存/
りょうほんごく /両本国/
りょうぼ /寮母/陵墓/
りょうま /竜馬/龍馬/遼麻/
りょうまい /糧米/
りょうまえ /両前/
りょうまつ /糧秣/
りょうみ /涼味/
りょうみみ /両耳/
りょうみみかん /両耳間/
りょうみん /領民/良民/
りょうむ /寮務/
りょうめ /両目/量目/竜馬;=りゅうめ/
りょうめい /両名/
りょうめじり /両目尻/
りょうめん /両面/
りょうめんいんさつ /両面印刷/
りょうめんきばん /両面基板/
りょうめんさいせい /両面再生/
りょうめんたい /菱面体/
りょうめんてーぷ /両面テープ/
りょうめんやき /両面焼き/両面焼/
りょうもう /両毛/
りょうもうせん /両毛線/
りょうもん /良問/
りょうや /領野/良夜/涼夜/⇔/
りょうやく /良薬/
りょうゆう /領有/両雄/僚友/良友/領邑/
りょうゆうけん /領有権/
りょうゆうともにはたたず /両雄不倶立/両雄倶には立たず/
りょうゆうならびたたず /両雄並び立たず/
りょうよう /療養/両用;†どちらにも使える。「水陸-」「遠近-」/両様;†二つのありかた。「和戦-」「硬軟-」/
りょうよういん /療養院/
りょうようき /両用機/
りょうようしょく /療養食/
りょうようじょ /療養所/
りょうようせいかつ /療養生活/
りょうようちゅう /療養中/
りょうようてき /療養的/
りょうようひ /療養費/
りょうよく /両翼/
りょうよこ /両横/
りょうらきんしゅう /綾羅錦繍/
りょうらん /繚乱/撩乱;=繚乱/
りょうり /料理/良吏/
りょうりーぐ /両リーグ/
りょうりいぜん /料理以前/
りょうりいんしょくとうしょうひぜい /料理飲食等消費税/
りょうりかい /料理界/料理会/
りょうりがく /料理学/
りょうりがっこう /料理学校/
りょうりきょうしつ /料理教室/
りょうりけんきゅうか /料理研究家/
りょうりざっし /料理雑誌/
りょうりしゅ /料理酒/
りょうりじょうず /料理上手/
りょうりちゅう /料理中/
りょうりちょう /料理長/
りょうりぢゃや /料理茶屋;restaurant/
りょうりつ /料率/両立/
りょうりてじゅん /料理手順/
りょうりてん /料理店/
りょうりどうぐ /料理道具/
りょうりにん /料理人/
りょうりばん /料理番/
りょうりばんぐみ /料理番組/
りょうりほう /料理法/
りょうりほうほう /料理方法/
りょうりぼん /料理本/
りょうりめい /料理名/
りょうりめいじん /料理名人/
りょうりものがたり /料理物語;料理書(1643)/
りょうりゃく /領略/
りょうりや /料理屋/
りょうりょう /寥々;ものさびしい/両々;each/稜々;とがった/了々;明白/喨々;明るい響き/寥寥/了了/両両/喨喨/稜稜/
りょうりょういき /両領域/
りょうりよう /料理用/
りょうりん /両輪/
りょうれん /寮連/
りょうろん /両論/
りょうろんへいき /両論併記/
りょうわき /両脇/
りょうわん /両腕/
りょかく /旅客/
りょかくき /旅客機/
りょかっき /旅客機/
りょかん /旅館/
りょかんがい /旅館街/
りょかんなみ /旅館並み/
りょがい /慮外/
りょがいもの /慮外者/
りょきゃく /旅客/
りょきゃくあつかい /旅客扱い/
りょきゃくあんない /旅客案内/
りょきゃくうんちん /旅客運賃/
りょきゃくえいぎょう /旅客営業/
りょきゃくえいぎょうきそく /旅客営業規則/
りょきゃくえき /旅客駅/
りょきゃくか /旅客化/
りょきゃくき /旅客機/
りょきゃくしゃ /旅客車/
りょきゃくせん /旅客線/
りょきゃくにん /旅客人/
りょきゃくゆそう /旅客輸送/
りょきゃくよう /旅客用/
りょきゃくりゅうどう /旅客流動/
りょきゃくれっしゃ /旅客列車/
りょきゃっき /旅客機/
りょぎん /旅銀/
りょく /力/緑/仂/
りょくい /緑衣/
りょくいん /緑陰/
りょくう /緑雨/
りょくえき /力役/
りょくえんとし /緑園都市/
りょくおうしょく /緑黄色/
りょくおうしょくやさい /緑黄色野菜/
りょくおうやさい /緑黄野菜/
りょくか /緑化/
りょくかききん /緑化基金/
りょくがん /緑眼/
りょくぎょく /緑玉/
りょくしきもう /緑色盲/
りょくしょく /緑色/
りょくじゅ /緑樹/
りょくじゅほうしょう /緑綬褒章/
りょくすい /緑水/
りょくすいてい /緑水亭/
りょくそう /緑藻;[生物]green alga/緑草/
りょくそうしょくぶつ /緑藻植物;[生物]green algae/
りょくそうるい /緑藻類/
りょくち /緑地/
りょくちく /緑竹/
りょくちたい /緑地帯/
りょくちゃ /緑茶/
りょくちゅうせき /緑柱石;emerald, aquamarine/
りょくでんか /緑電化/
りょくとう /緑豆/
りょくど /緑土/
りょくないしょう /緑内障/
りょくのうきん /緑膿菌/
りょくはつ /緑髪/
りょくばん /緑礬/
りょくひ /緑肥/
りょくふう /緑風/
りょくべん /緑便/
りょくもん /緑門/
りょくや /緑野/
りょくゆう /緑釉/
りょくよう /緑葉/
りょくようかんらん /緑葉甘藍/
りょくりん /緑林/
りょけん /旅券/
りょけんか /旅券課/
りょけんじむしょ /旅券事務所/
りょけんばんごう /旅券番号/
りょこう /旅行/閭巷;村里/
りょこうあんないしょ /旅行案内書/旅行案内所/
りょこうあんないじょ /旅行案内所/
りょこううかがい /旅行伺/
りょこうかい /旅行会/
りょこうかかく /旅行価格/
りょこうかばん /旅行鞄/
りょこうかんきょう /旅行環境/
りょこうかんけい /旅行関係/
りょこうがいしゃ /旅行会社/
りょこうき /旅行記/旅行紀/
りょこうきぶん /旅行気分/
りょこうきゃく /旅行客/
りょこうぎょう /旅行業/
りょこうぎょうしゃ /旅行業者/
りょこうぎょうほう /旅行業法/
りょこうぎょうむとりあつかいしゅにんしゃ /旅行業務取扱主任者;国家資格(<旅行業法)/
りょこうけいかく /旅行計画/
りょこうけん /旅行券/
りょこうけんきゅうかい /旅行研究会/
りょこうさき /旅行先/
りょこうざっし /旅行雑誌/
りょこうしゃ /旅行者;†traveller/旅行社;†travel agency/
りょこうじ /旅行時/
りょこうじゅつ /旅行術/
りょこうじょうほう /旅行情報/
りょこうずき /旅行好き/
りょこうせんもんがっこう /旅行専門学校/
りょこうだい /旅行代/
りょこうだいりてん /旅行代理店/
りょこうだん /旅行団/
りょこうちゅう /旅行中/
りょこうちゅうし /旅行中止/
りょこうちょきん /旅行貯金/
りょこうにってい /旅行日程/
りょこうひよう /旅行費用/
りょこうほけん /旅行保険/
りょこうぼう /旅行帽/
りょこうまえ /旅行前/
りょこうもくてき /旅行目的/
りょこうよう /旅行用/
りょしゅう /旅愁/虜囚/
りょしゅく /旅宿/
りょじ /旅次/
りょじゅん /旅順/
りょじょう /旅情/
りょじんぼく /旅人木;[植物]traveler's tree(Ravenala)/
りょせんぽう /呂旋法/
りょそう /旅荘/旅装/旅僧/
りょだん /旅団/
りょちゅう /旅中/
りょちょう /旅鳥/
りょっか /緑化/
りょっこう /緑光/
りょてい /旅程/旅亭/
りょていひょう /旅程表/
りょてつ /旅鉄/
りょてん /旅店/
りょのう /旅嚢/
りょひ /旅費/
りょひこうつうひ /旅費交通費/
りょひしゅくはくひ /旅費宿泊費/
りょふ /呂布;人名,後漢末期の群雄/
りょふい /呂不韋/
りょりつ /呂律/
りょりょく /膂力/
りよう /利用/理容/俚謡/里謡/
りようあんない /利用案内/
りよういがい /利用以外/
りようえき /利用駅/
りようか /利用可/
りようかいし /利用開始/
りようかいすう /利用回数/
りようかく /利用角/
りようかくだい /利用拡大/
りようかち /利用価値/
りようかのう /利用可能/
りようかのうせい /利用可能性/
りようかんきょう /利用環境/
りようがかり /利用掛/
りようがく /利用額/利用学/
りようきかい /利用機会/
りようきかん /利用期間/
りようきげん /利用期限/
りようきてい /利用規程/
りようきぼう /利用希望/
りようきゃく /利用客/
りようきやく /利用規約/
りようきょり /利用距離/
りようきんがく /利用金額/
りようぎじゅつ /利用技術/
りようくかん /利用区間/
りようけいかく /利用計画/
りようけいけん /利用経験/
りようけいたい /利用形態/
りようけいやくしゃ /利用契約者/
りようけん /利用権;right to use/利用券;ticket/利用研/
りようけんきゅうかい /利用研究会/
りようけんげん /利用権限/
りようげんど /利用限度/
りようげんどがく /利用限度額/
りようこうせい /利用厚生/
りようこうりつ /利用効率/
りようし /理容師/
りようしかく /利用資格/
りようしつ /理容室/
りようしゃ /利用者/
りようしゃいがい /利用者以外/
りようしゃかくい /利用者各位/
りようしゃかんり /利用者管理/
りようしゃがわ /利用者側/
りようしゃげんてい /利用者限定/
りようしゃこうしゅうかい /利用者講習会/
りようしゃごと /利用者毎/
りようしゃすう /利用者数/
りようしゃぜんたい /利用者全体/
りようしゃそう /利用者層/
りようしゃとうろく /利用者登録/
りようしゃとくてん /利用者特典/
りようしゃばんごう /利用者番号/
りようしゃめい /利用者名/
りようしゅうはすう /利用周波数/
りようしゅだん /利用手段/
りようしょう /利用証/
りようしんせい /利用申請/
りようしんせいしょ /利用申請書/
りようじ /利用時/
りようじかん /利用時間/
りようじっせき /利用実績/
りようじょう /利用上/
りようじょうきょう /利用状況/
りようじょうけん /利用条件/
りようじょうほう /利用情報/
りようせいげん /利用制限/
りようぜんぱん /利用全般/
りようちゅう /利用中/
りようていし /利用停止/
りようてん /理容店/
りようとうけい /利用統計/
りようとうろく /利用登録/
りようど /利用度/
りようはんい /利用範囲/
りようひんど /利用頻度/
りようび /利用日/
りようふか /利用不可/
りようふかのう /利用不可能/
りようふたんきん /利用負担金/
りようぶんや /利用分野/
りようほう /利用法/
りようほうほう /利用方法/
りようめいさい /利用明細/
りようもくてき /利用目的/
りようよそく /利用予測/
りようよてい /利用予定/
りようりつ /利用率/
りようりょう /利用料/
りようりょうきん /利用料金/
りようれい /利用例/
りようれき /利用歴/
りよく /利欲/
りよこ /理代子/
りよん /里昴/
りらびえ /リラ冷え/
りりーふじん /リリーフ陣/
りりく /離陸/
りりくご /離陸後/
りりくじ /離陸時/
りりくじかん /離陸時間/
りりくそくど /離陸速度/
りりくちゅうし /離陸中止/
りりくまえ /離陸前/
りりこ /梨々子/
りりつ /利率/
りりょう /李陵/吏僚/
りりょく /理力/
りるい /離塁/
りれーしき /リレー式/
りれき /履歴/
りれきげんしょう /履歴現象/
りれきしょ /履歴書/
りろ /理路/
りろせいぜん /理路整然/
りろん /理論/
りろんか /理論家/
りろんかい /理論解/
りろんかいせき /理論解析/
りろんかがく /理論化学/
りろんきょくせん /理論曲線/
りろんけいさん /理論計算/
りろんけいさんきかがく /理論計算機科学/
りろんけいざいがく /理論経済学/
りろんけん /理論研/
りろんげんかい /理論限界/
りろんこうせい /理論構成/
りろんこうちく /理論構築/
りろんし /理論誌/
りろんしき /理論式/
りろんしゅぎ /理論主義/
りろんしょ /理論書/
りろんじく /理論軸/
りろんじょう /理論上/
りろんじょうかのう /理論上可能/
りろんすうがく /理論数学/
りろんせいぶつがく /理論生物学/
りろんせんせん /理論戦線/
りろんたいけい /理論体系/
りろんち /理論値/
りろんてき /理論的/
りろんてきかいしゃく /理論的解釈/
りろんてきかのうせい /理論的可能性/
りろんてきげんかい /理論的限界/
りろんてきこんきょ /理論的根拠/
りろんてきせいごうせい /理論的整合性/
りろんてきそくめん /理論的側面/
りろんてきてんぼう /理論的展望/
りろんてんかい /理論展開/
りろんとうそう /理論闘争/
りろんは /理論派/
りろんぶ /理論部/
りろんぶそう /理論武装/
りろんぶつり /理論物理/
りろんぶつりがく /理論物理学/
りろんめん /理論面/
りろんや /理論屋/
りん /燐;P/厘/凛;勇気凛々/林/輪/臨/鈴;風鈴/隣;隣家/鱗;片鱗/麟;麒麟/倫;倫理/棆/淪/綸;綸旨/稟;稟議/禀;異体字/懍;≒凛/凜;「凛」の異体字/廩;米蔵/吝;吝嗇/悋;≒吝/淋;淋病/琳;光琳/痳;≒淋/醂;味醂/霖;霖雨(ながあめ)/菻/藺;藺草/躙;蹂躙/躪;異体字/鄰;「隣」の異体字/P/Phosphorus/
りんあん /燐安/
りんいち /倫一/
りんいちろう /倫一郎/
りんう /霖雨/
りんうん /鱗雲;うろこぐも/
りんえん /林苑/
りんか /隣家/輪禍/燐火/
りんかい /臨海;†seaside.「-公園」/臨界;†critical.「-前核実験」/
りんかいあつりょく /臨界圧力/
りんかいあんぜん /臨界安全/
りんかいおんど /臨界温度/
りんかいかく /臨界角/
りんかいがっこう /臨海学校/
りんかいき /臨界期/
りんかいきょうぎじょう /臨海競技場/
りんかいげんしょう /臨界現象/
りんかいこうぎょうちたい /臨海工業地帯/
りんかいじっけんしょ /臨海実験所/
りんかいじょうたい /臨界状態/
りんかいせき /燐灰石;apatite/
りんかいぜん /臨界前/
りんかいぜんかくじっけん /臨界前核実験/
りんかいたいいき /臨界帯域/
りんかいち /臨界値/
りんかいてん /臨界点/
りんかいふくとしん /臨海副都心/
りんかいぶ /臨海部/
りんかいりょう /臨界量/
りんかく /輪郭/輪廓/
りんかくせん /輪郭線/
りんかん /林間/輪姦/輪奐/
りんかんがっこう /林間学校/
りんが /臨画/鱗芽/
りんがく /林学/
りんがっか /林学科/
りんがっかい /林学会/
りんき /臨機/悋気/
りんきおうへん /臨機応変/
りんきょうしん /臨教審/
りんきん /淋菌/
りんぎ /稟議/禀議;異体字/
りんぎしょ /稟議書/禀議書;異体字/
りんぎょ /臨御/
りんぎょう /林業/
りんぎょうか /林業家/
りんぎょうよう /林業用/
りんくう /臨空/
りんくさき /リンク先/
りんくしゅう /リンク集/
りんくもと /リンク元/
りんぐがた /リング型/
りんぐじょう /リング上/リング状/
りんけい /鱗茎;[植物]bulb/輪形;circular/鱗形;scaly/
りんけいきょう /林経協/
りんけん /隣県/臨検/
りんげつ /臨月/
りんげん /綸言/
りんこ /凛乎/
りんこう /臨港/輪講/輪行/林光/燐光/燐鉱/輪光/臨幸/隣好/
りんこうかい /輪講会/
りんこうぐん /燐光群/
りんこうしつ /輪講室/
りんこうしゃ /輪行車/
りんこうじゅん /輪講順/
りんこうせき /燐鉱石/
りんこうせん /臨港線/
りんご /林檎/
りんごあじ /リンゴ味/
りんごがり /りんご狩り/
りんごく /隣国/
りんごしゅ /林檎酒;cider/リンゴ酒/りんご酒/
りんごす /林檎酢/
りんごばたけ /林檎畑/
りんさいぼう /林災防/
りんさく /輪作/
りんさん /リン酸/林産/燐酸/
りんさんかごうぶつ /リン酸化合物/
りんさんぶつ /林産物/
りんざい /臨済;禅の流派/臨在;[キリスト教]「神の-」/林材/
りんざいしゅう /臨済宗/
りんし /臨死/
りんししつ /燐脂質/
りんしたいけん /臨死体験/
りんしつ /隣室/淋疾/
りんしもく /鱗翅目/
りんしゃ /倫社;[略語]倫理社会/臨写/
りんしゃん /嶺上;[麻雀]/
りんしゃんかいほー /嶺上開花;[麻雀]/
りんしゃんかいほう /嶺上開花;[麻雀]/
りんしゅう /凛秋/
りんしゅつ /臨出/
りんしょ /臨書/
りんしょう /臨床/林床;[植物]forest floor/輪唱;troll/林鐘;[音楽]/臨牀;「床」の本字/
りんしょうい /臨床医/
りんしょういがく /臨床医学/
りんしょういがくけい /臨床医学系/
りんしょうか /臨床家/
りんしょうけん /臨床研/
りんしょうけんさ /臨床検査/
りんしょうけんさぎし /臨床検査技師;国家資格/
りんしょうしけん /臨床試験/
りんしょうしょうじょう /臨床症状/
りんしょうしんり /臨床心理/
りんしょうしんりがく /臨床心理学/
りんしょうしんりし /臨床心理士/
りんしょうじっけん /臨床実験/
りんしょうせいりがく /臨床生理学/
りんしょうちけん /臨床治験/
りんしょうてき /臨床的/
りんしょうれい /臨床例/
りんしょく /吝嗇/
りんしん /稟申/凛森/禀申/
りんじ /臨時/綸旨/
りんじいん /臨時員/
りんじえき /臨時駅/
りんじかい /臨時会/
りんじかいいん /臨時会員/
りんじかいさつぐち /臨時改札口/
りんじかいそく /臨時快速/
りんじかいそくれっしゃ /臨時快速列車/
りんじきごう /臨時記号;[音楽]♭♯ ナチュラル等/
りんじきゅうぎょう /臨時休業/
りんじきゅうこう /臨時急行/臨時休講/
りんじく /輪軸/
りんじけんさ /臨時検査/
りんじこう /臨時工/
りんじこっかい /臨時国会/
りんじしゅうにゅう /臨時収入/
りんじしょとく /臨時所得;extra income/
りんじそうかい /臨時総会/
りんじそちほう /臨時措置法/
りんじぞうかん /臨時増刊/
りんじぞうかんごう /臨時増刊号/
りんじていしゃ /臨時停車/
りんじてき /臨時的/
りんじでんしゃ /臨時電車/
りんじとっきゅう /臨時特急/
りんじにゅーす /臨時ニュース/
りんじはつばい /臨時発売/
りんじばんぐみ /臨時番組/
りんじひ /臨時費;⇔経常費/
りんじびん /臨時便/
りんじへんせい /臨時編成/
りんじほう /臨時法/
りんじやとい /臨時雇い/
りんじゅう /臨終/
りんじょう /輪状;わっか状/臨場/鱗状;うろこ状/
りんじょうかん /臨場感/
りんじょうかんつうしん /臨場感通信/
りんじょうなんこつ /輪状軟骨/
りんじれっしゃ /臨時列車/
りんじん /隣人/
りんじんあい /隣人愛/
りんじんたち /隣人達/
りんず /綸子/綾子/
りんせい /林政/輪生/稟請/
りんせいじょう /輪生状/
りんせいもく /輪生目/Verticillatae/
りんせき /臨席/隣席/
りんせつ /隣接/鱗屑/
りんせつえき /隣接駅/
りんせつかんけい /隣接関係/
りんせつぎょうれつ /隣接行列/
りんせつせき /隣接席/
りんせつち /隣接地/
りんせん /臨戦/臨川;地名,中国地名/林泉/
りんせんじ /林泉寺/
りんせんじばん /臨川寺版/
りんせんたいせい /臨戦態勢/
りんぜん /凛然/
りんそん /隣村/
りんたい /輪帯/
りんたいさく /倫対策/
りんたく /輪タク/
りんち /林地/隣地/
りんちょう /臨調/
りんてん /輪転/
りんてんき /輪転機/
りんと /凛と/
りんどう /林道/竜胆/
りんどうか /リンドウ科/
りんどうぐん /林道群/
りんどうしゅうてん /林道終点/
りんどうめい /林道名/
りんどうもく /リンドウ目/Gentianales/
りんどく /輪読/
りんない /林内/
りんね /輪廻/
りんねてんしょう /輪廻転生/
りんねてんせい /輪廻転生/
りんばつ /輪伐/
りんばん /輪番/
りんばんせい /輪番制/
りんぱ /琳派;光琳派/淋巴;[医]lymph/
りんぱえき /リンパ液/
りんぱかん /リンパ管;[医]lymphatic/
りんぱかんけい /リンパ管系/
りんぱきゅう /リンパ球;[医]lymphocyte/
りんぱけい /リンパ系/
りんぱしゅ /リンパ腫/
りんぱせつ /リンパ節/
りんぱせん /リンパ腺/
りんびょう /淋病/
りんぴ /燐肥/
りんぴょうとうしゃかいちんれつざいぜん /臨兵鬪者皆陳列在前/
りんぶ /輪舞/
りんぶきょく /輪舞曲;rondo/
りんぶん /林分/
りんぷん /鱗粉/
りんぺん /鱗片/
りんぺんよう /鱗片葉;[植物]scale leaf/
りんぼ /臨模;=りんも/
りんぼく /鱗木/
りんぽ /隣保/
りんぽう /隣邦/
りんぽん /臨本/
りんむ /林務/
りんも /臨模/
りんもう /鱗毛;[植物]scaly hair/厘毛;very few/
りんや /林野/
りんやちょう /林野庁/
りんゆうがく /林邑楽/
りんらく /淪落/
りんり /倫理/淋漓/
りんりかん /倫理観/倫理感/
りんりがく /倫理学/
りんりきせい /倫理規制/
りんりきてい /倫理規定/
りんりしゃかい /倫理社会/
りんりじょう /倫理上/
りんりじょうもんだい /倫理上問題/
りんりつ /林立/
りんりてき /倫理的/
りんりてきしゅうきょう /倫理的宗教/
りんりてきもんだい /倫理的問題/
りんりどうとく /倫理道徳/
りんりどうとくかん /倫理道徳観/
りんりめん /倫理面/
りんりん /凛々;「凜」異体字/凜々;「勇気-」/凛凛/凜凜;NB:「凜」は人名漢字、「凛」はその異体字であるが「凛」の方が通用している/
りんれつ /凛冽/凛烈/凜冽/
りんわしつ /輪話室/
る /縷;(糸) 一縷/鏤;(金糸) 鏤刻/婁;二十八宿の一つ/褸;ぼろ/瑠;瑠璃/璢;「瑠」の異体字/屡;often/留;(呉音)留守/流;(呉音)流浪/琉;(呉音) 琉球/陋;(呉音) 固陋(ころう)/畄;「留」の異体字/
るーと /√;root/
るーぶるびじゅつかん /ルーブル美術館;www.louvre.fr/
るーまにあ /羅馬尼/
るーるいはん /ルール違反/
るーんもじ /ルーン文字/
るい /類/塁/累;-が及ぶ/涙;涙腺/誄;誄歌/瘰;瘰癧/縲;縲絏/羸;病羸/瑠偉;人名/留衣/瑠維/壘;「塁」の旧字(人名用漢字)/泪;「涙」の異体字/
るいえき /涙液/
るいえふしょうまぞく /Actaea/ルイエフショウマ属/
るいえん /類縁/類苑/
るいおんご /類音語/
るいか /累加/類歌/誄歌/類火/ルイ華;人名?/
るいがいねん /類概念/
るいぎ /類義/
るいぎご /類義語/
るいぎごじてん /類義語辞典/
るいく /類句/
るいけい /累計/類型/類形;<rare>/
るいけいか /類型化/
るいけいがく /累計額/類型学;typology/
るいけいてき /類型的/
るいけいろん /類型論/
るいけいろんてき /類型論的/
るいげつ /累月/
るいげん /累減/
るいげんぜい /累減税/
るいこ /ルイ子/
るいご /類語/
るいごじてん /類語辞典/
るいごめい /類語名/
るいさん /類纂/累算/
るいざん /累算/
るいざんき /累算器/
るいしゅう /類集/
るいしょ /類書/
るいしょう /類焼/類症/
るいしん /累進;progression.「-課税」/塁審;[野球]base umpire/
るいしんかぜい /累進課税/
るいしんせい /累進性/
るいしんぜい /累進税/
るいしんぜいりつ /累進税率/
るいしんりつ /累進率/
るいじ /類似/累次/類字/
るいじきかん /類似機関/
るいじご /類似語/
るいじせい /類似性/
るいじつ /累日/
るいじてん /類似点/
るいじど /類似度/
るいじひん /類似品/
るいじぶつ /類似物/
るいじぶぶん /類似部分/
るいじほう /類似法/
るいじめい /類似名/
るいじゃく /羸弱/
るいじゅ /類聚;種類別に集める/類従;≒類聚/
るいじゅう /類聚;=るいじゅ/類従;≒類聚/
るいじゅこくし /類聚国史;六国史(日本三代実録除く)を菅原道真が編纂し直したもの/
るいじゅみょうぎしょう /類聚名義抄;漢和辞典/
るいじょう /塁上/累乗/
るいじょうこん /累乗根/
るいじれい /類似例/
るいじんえん /類人猿/
るいすい /類推/
るいすいかいしゃく /類推解釈/
るいすいかのう /類推可能/
るいせい /累世/
るいせき /累積/
るいせきがく /累積額/
るいせききよりつ /累積寄与率/
るいせきさいむ /累積債務/
るいせきとうひょう /累積投票/
るいせきぶんぷ /累積分布/
るいせん /涙腺/
るいそん /累損/
るいぞう /累増/
るいぞく /類族/
るいたいろん /類体論/
るいだ /塁打/
るいだい /累代/類題/
るいだすう /塁打数/
るいてき /類的/
るいとも /類友;[略語]類は友を呼ぶ/
るいどう /類同/
るいねん /累年/
るいのう /涙嚢/
るいはん /累犯/類板/
るいひ /類比/
るいひすいり /類比推理/
るいへき /塁壁/
るいべつ /類別/
るいらん /累卵/
るいるい /累々/累累/累類;一族/
るいれい /類例/
るいれき /瘰癧/
るいわ /累和/
るか /流花/
るかでん /ルカ伝;[聖書]Luke/
るけい /流刑/
るけいせつ /流刑説/
るけいち /流刑地/
るこく /鏤刻/
るこつ /鏤骨/
るざい /流罪/
るざん /流竄/
るしゃなぶつ /盧舎那仏/盧遮那仏/
るす /留守/
るすい /留守居/
るすたく /留守宅/
るすちゅう /留守中/
るすつ /留寿都/
るすでん /留守電/
るすばん /留守番/
るすばんでんわ /留守番電話/
るすばんでんわき /留守番電話機/
るすばんろくが /留守番録画/
るすろく /留守録/
るすろくが /留守録画/
るすろくきのう /留守録機能/
るせつ /流説;rumour/縷説;こまごまと説く/
るそん /呂宋;Luzon/
るそんすけざえもん /呂宋助左衛門;安土桃山時代の商人/
るたく /流謫/
るつこ /路津子/
るつぼ /坩堝/
るてちうむ /Lu/Lutetium/
るてにうむ /Ru/Ruthenium/
るてん /流転/
るてんりんね /流転輪廻/
るでん /流伝/
るにん /流人/
るねさんすようしき /ルネサンス様式/
るびーいろ /ルビー色/
るびじうむ /Rb/Rubidium/
るびつき /ルビ付き/ルビ付/
るふ /流布/
るふぼん /流布本/
るべーぐせきぶん /ルベーグ積分;[数学]Lebesgue integral/
るべしべ /留辺蕊/
るべつ /留別/
るみ /留美/瑠美/流美/留実/
るみこ /留美子/るみ子/
るみん /流民/
るもい /留萌/
るり /瑠璃/
るりいろ /瑠璃色/
るりがわら /瑠璃瓦;施釉した美しい瓦/
るりこ /瑠璃子/るり子/ルリ子/留理子/
るりびたき /瑠璃鶲/
るる /縷々/縷縷/
るるめんめん /縷々綿々/
るろう /流浪/
るろうのたみ /流浪の民/
るん /♪/
るんびにえん /ルンビニ園;(Lumbini) 釈迦の生誕地/
れーざーこう /レーザー光/
れーざーこうせん /レーザー光線/
れーざこう /レーザ光/
れーすあみ /レース編み/
れーすちゅう /レース中/
れーべるめん /レーベル面/
れい /例/礼/霊;†soul/零;†0/〇;漢数字のゼロ/令/冷;冷却/伶;伶人/嶺;山嶺/怜;怜悧/玲;玲瓏/苓/鈴;予鈴/齢;年齢/齡;「齢」の旧字/囹;(牢獄)/澪;みお/羚;羚羊/聆;(きく)/蛉;蜻蛉/鴒;鶺鴒/麗;華麗/儷;(ならぶ)/驪;(くろうま)/戻;(もど・る)返戻金/唳;鶴唳/綟;(もじる)/犂/犁;異体字/黎;黎明/蛎;「蠣」の異体字/砺;「礪」の異体字/励;励行/勵;「励」の旧字/癘;疫癘/糲;(くろごめ)/醴;(甘酒)/禮;「礼」の旧字(人名用漢字)/隷;奴隷/隸;「隷」の旧字/櫺;れんじ/茘;茘枝(れいし,ライチ)/蠡;范蠡/靈;「霊」の旧字/祈;?/
れい> /冷;冷麺,冷湿布,冷しゃぶ/
れいあんしつ /霊安室/
れいあんしょ /冷暗所/
れいあんじょ /冷暗所/
れいい /霊威/
れいいき /霊域/
れいいち /鈴一/
れいいんきょく /冷陰極/
れいう /冷雨/
れいうん /嶺雲/
れいえき /霊液/
れいえん /霊園/
れいおんたい /冷温帯/
れいか /冷夏/零下/冷菓/麗華;人名/麗香/隷下/霊化/玲花/
れいかい /例会;regular meeting/霊界/例解;illustrate.「用法の-」/冷灰/
れいかいご /例会後/
れいかく /冷覚/
れいかん /霊感/冷汗/冷感/冷寒/伶官/
れいかんあつえん /冷間圧延/
れいかんさんと /冷汗三斗/
れいかんしょう /冷感症/
れいかんしょうほう /霊感商法/
れいかんたんぞう /冷間鍛造/
れいがい /例外/冷害/
れいがいきこう /例外機構/
れいがいきそく /例外規則/
れいがいきてい /例外規定/
れいがいしょり /例外処理/
れいがいしょりきのう /例外処理機能/
れいがいじこう /例外事項/
れいがいちゅう /例外中/
れいがいてき /例外的/
れいがいてん /例外点/
れいがく /礼楽/
れいがん /冷眼/
れいき /例規/冷気/励起/霊気/冷機/霊亀;年号(715-717)/霊鬼/癘気/
れいきじょうたい /励起状態/
れいきはちょう /励起波長/
れいきゃく /冷却/
れいきゃくいき /冷却域/
れいきゃくえき /冷却液/
れいきゃくおんど /冷却温度/
れいきゃくき /冷却器/
れいきゃくきかん /冷却期間/
れいきゃくぎじゅつ /冷却技術/
れいきゃくこうか /冷却効果/
れいきゃくざい /冷却材/
れいきゃくしゅだん /冷却手段/
れいきゃくすい /冷却水/
れいきゃくすいぶそく /冷却水不足/
れいきゃくせいのう /冷却性能/
れいきゃくそうち /冷却装置/
れいきゃくたいさく /冷却対策/
れいきゃくのうりょく /冷却能力/
れいきゃくふう /冷却風/
れいきゃくぶ /冷却部/
れいきゃくぶぶん /冷却部分/
れいきゃくほう /冷却法/
れいきゃくほうほう /冷却方法/
れいきゃくよう /冷却用/
れいきゅう /霊柩/
れいきゅうしゃ /霊柩車/
れいきょりしゃげき /零距離射撃/
れいきん /礼金/
れいぎ /礼儀/
れいぎさほう /礼儀作法/
れいく /麗句/
れいぐう /冷遇/礼遇;†honor/
れいけい /令閨;おくさん/令兄/
れいけつ /冷血/
れいけつかん /冷血漢/
れいけつどうぶつ /冷血動物/
れいけん /霊験;「-あらたか」/霊剣;「-天叢雲」/
れいげつ /例月/
れいげん /霊験/冷厳/霊言/例言/冷源/
れいげんしゅう /霊言集/
れいげんてんのう /霊元天皇/
れいげんどうし /霊幻道士/
れいこ /例挙;[律令制]法定分の出挙/玲子/礼子/麗子/令子/怜子/玲香/祈子/
れいこう /励行/霊光/冷光;luminescence/
れいこく /冷酷/例刻/
れいこん /霊魂/
れいこんふめつ /霊魂不滅/
れいさい /零細/例祭/零歳/
れいさいきぎょう /零細企業/
れいさいけいえい /零細経営/
れいざん /霊山/
れいし /霊芝/霊視/茘枝/令旨/麗姿/令嗣/令史/令姉/
れいしき /礼式/零式/
れいしきせんとうき /零式戦闘機/
れいしきゆそうき /零式輸送機/
れいしっぷ /冷湿布;⇔温湿布/
れいしつ /令室/麗質/
れいしゃ /礼者/
れいしゅ /冷酒/
れいしょ /隷書/冷所/令書/冷処/
れいしょう /冷笑/例証/霊障/冷床/醴漿/
れいしょく /冷食;火を通さずに食べること。 [略語]冷凍食品/令色/冷色/
れいしょたい /隷書体/
れいしん /励振/
れいしんりょく /励振力/
れいじ /零時/例示/零士;人名/玲司/玲二/礼仁/禮二/零次/怜二/
れいじか /例示化/
れいじつ /例日/
れいじゅう /隷従/霊獣/
れいじょう /霊場/令嬢/礼状;thank-you letter/令状;召集-/礼譲/
れいじろう /礼二郎/令二朗/霊次郎/
れいじん /麗人;美人/霊神/伶人;演奏者/
れいじんそう /伶人草/
れいすい /冷水/霊水/
れいすいき /冷水機/冷水器/
れいすいよう /冷水用/
れいすいよく /冷水浴/
れいず /例図/
れいせい /冷静/冷製;-スープ/霊性/励声/令婿/
れいせいちんちゃく /冷静沈着/
れいせき /霊跡/
れいせつ /礼節/例説/
れいせん /冷戦/零戦/冷泉/霊泉/零戰;「戦」旧字/
れいせんか /冷戦下/
れいせんご /冷戦後/
れいせんしゅうけつ /冷戦終結/
れいせんじだい /冷戦時代/
れいぜい /冷泉/
れいぜいいん /冷泉院/
れいぜいてんのう /冷泉天皇/
れいぜん /霊前/冷然/
れいそう /礼装/霊草/
れいそく /令息/
れいそん /令孫/
れいぞう /冷蔵/
れいぞうこ /冷蔵庫/冷藏庫;「蔵」旧字/
れいぞうこよう /冷蔵庫用/
れいぞうしつ /冷蔵室/
れいぞうそうこ /冷蔵倉庫/
れいぞうのうりょく /冷蔵能力/
れいぞうほぞん /冷蔵保存/
れいぞく /隷属/隸屬;旧字/
れいぞくてき /隷属的/
れいたい /霊体/冷帯/
れいたいさい /例大祭/
れいたつ /令達/
れいたん /冷淡/冷鍛/
れいだい /例題/霊代/
れいだいよう /例題用/
れいだん /冷暖/
れいだんじち /冷暖自知/
れいだんぼう /冷暖房/
れいだんぼうひ /冷暖房費/
れいち /霊地/霊智/
れいちゃ /冷茶/
れいちょう /霊長/
れいちょうけん /霊長研/
れいちょうるい /霊長類/
れいてい /令弟/
れいてき /霊的/
れいてつ /冷徹/
れいてとう /レイテ島;Leyte island/
れいてん /零点/礼典/冷点/
れいとう /冷凍/
れいとうかいじゅう /冷凍怪獣/
れいとうき /冷凍機/
れいとうぎょうざ /冷凍餃子/
れいとうこ /冷凍庫/
れいとうご /冷凍後/
れいとうしつ /冷凍室/
れいとうしゃ /冷凍車/
れいとうしょくひん /冷凍食品/
れいとうそうこ /冷凍倉庫/
れいとうひん /冷凍品/
れいとうほぞん /冷凍保存/
れいとうもの /冷凍物/
れいとうれいぞうこ /冷凍冷蔵庫/
れいとねりあもく /レイトネリア目/Leitneriales/
れいど /零度/
れいな /麗奈/玲奈/伶奈/
れいにく /霊肉/冷肉/
れいにゅう /戻入/
れいねつ /冷熱/
れいねん /例年/
れいねんいじょう /例年以上/
れいの /例の/
れいのう /霊能/
れいのうしゃ /霊能者/
れいのうりょく /霊能力/
れいのうりょくしゃ /霊能力者/
れいのるずすう /レイノルズ数;Reynolds number, Re=U・L／(μ／ρ)/
れいはい /礼拝/零敗/霊牌/
れいはいしき /礼拝式/
れいはいじ /礼拝時/
れいはいじょ /礼拝所/
れいはいちゅう /礼拝中/
れいはいどう /礼拝堂/
れいはいび /礼拝日/
れいはん /冷飯/
れいば /冷罵/
れいばい /冷媒/霊媒/
れいばいじゅつ /霊媒術/
れいひつ /麗筆/
れいひょう /冷評/
れいびょう /霊廟/霊猫/
れいふう /冷風/零封;[スポーツ]相手に全く点数を与えないこと。shutout,完封/
れいふうき /冷風機/
れいふうせん /冷風扇/
れいふく /礼服/
れいふじん /令夫人/
れいぶん /例文/礼文/麗文;あでやかな模様/令聞;よい評判/
れいぶんしゅう /例文集/
れいぷま /レイプ魔/
れいへい /例幣/
れいほう /霊峰/礼法/霊宝/礼砲/
れいほん /零本/
れいぼう /冷房/礼帽/麗貌/
れいぼうか /冷房化/
れいぼうかいぞう /冷房改造/
れいぼうかりつ /冷房化率/
れいぼうきかん /冷房期間/
れいぼうこう /礼奉公/
れいぼうしゃ /冷房車/
れいぼうじゅよう /冷房需要/
れいぼうせつび /冷房設備/
れいぼうちゅう /冷房中/
れいぼうのうりょく /冷房能力/
れいぼうよう /冷房用/
れいぼうりつ /冷房率/
れいぼく /霊木/零墨;断簡-/
れいまい /令妹/
れいまいり /礼参り/
れいみ /麗美/
れいむ /霊夢/
れいめい /黎明/令名/
れいめいき /黎明期/
れいめん /冷麺/
れいもつ /礼物/
れいや /麗也/
れいやく /霊薬/
れいゆうかい /霊友会/
れいよう /羚羊/麗容/
れいようしゅ /冷用酒/
れいよし /零余子/
れいらく /零落/
れいり /怜悧/伶俐;=怜悧/
れいりょう /冷涼/
れいりょく /霊力/
れいろう /玲瓏/
れいわ /例話/
れおな /玲於奈/玲央名/
れき /歴;†history/暦;†calendar/礫;小石/轢;-死/檪;クヌギ/瀝;pitch/櫪;クヌギ/癧;瘰癧/轣/靂;(青天の)霹靂/鬲;鼎/
れきがん /礫岩/
れきげつ /暦月/
れきさつ /轢殺/
れきさん /暦算/
れきし /歴史/轢死/
れきしか /歴史家/
れきしかいどう /歴史街道/
れきしかがく /歴史科学/
れきしかん /歴史館/歴史観/
れきしが /歴史画/
れきしがく /歴史学/
れきしがくは /歴史学派/
れきしがっか /歴史学科/
れきしきょうかしょ /歴史教科書/
れきしげんごがく /歴史言語学/
れきししゅぎ /歴史主義;historicism/
れきししょ /歴史書/
れきししょうせつ /歴史小説/
れきしじだい /歴史時代/
れきしじょう /歴史上/
れきしじんぶつ /歴史人物/
れきしすいり /歴史推理/
れきしせい /歴史性/
れきしたい /轢死体/
れきしちりがく /歴史地理学;historical geography/
れきしてき /歴史的/
れきしてきいち /歴史的位置/
れきしてきいみ /歴史的意味/
れきしてきかち /歴史的価値/
れきしてきかてい /歴史的過程/
れきしてきかなづかい /歴史的仮名遣い/
れきしてきけいい /歴史的経緯/
れきしてきけんぞうぶつ /歴史的建造物/
れきしてきけんち /歴史的見地/
れきしてきげんかい /歴史的限界/
れきしてきげんざい /歴史的現在;[文法]present historique/
れきしてきこうさつ /歴史的考察/
れきしてきこんきょ /歴史的根拠/
れきしてきしゅんかん /歴史的瞬間/
れきしてきじけん /歴史的事件/
れきしてきじじつ /歴史的事実/
れきしてきじじょう /歴史的事情/
れきしてきじょうけん /歴史的条件/
れきしてきせいやく /歴史的制約/
れきしてきちしき /歴史的知識/
れきしてきできごと /歴史的出来事/
れきしてきはいけい /歴史的背景/
れきしてきはってん /歴史的発展/
れきしてきぶんけん /歴史的文献/
れきしてきへんせん /歴史的変遷/
れきしてきめいば /歴史的名馬/
れきしてきりゆう /歴史的理由/
れきしてつがく /歴史哲学/
れきしどくほん /歴史読本/
れきしにんしき /歴史認識/
れきしはいけい /歴史背景/
れきしはっけん /歴史発見/
れきしぶんか /歴史文化/
れきしほうそく /歴史法則/
れきしもの /歴史物/
れきしものがたり /歴史物語/
れきしもんだい /歴史問題/
れきしょ /暦書/
れきしりかい /歴史理解/
れきじ /歴事/
れきじつ /暦日/
れきすう /暦数/
れきせい /瀝青/歴世/
れきせん /歴戦/
れきぜん /歴然/
れきだい /歴代/
れきだいせいふ /歴代政府/
れきだいほうあん /歴代宝案/
れきだいよこづな /歴代横綱/
れきだん /轢断/
れきちゅう /暦注/
れきちょう /歴朝/
れきてい /歴程/
れきど /礫土/
れきにん /歴任/
れきねん /暦年;calendar/歴年;-の功/
れきねんれい /暦年齢/
れきはく /歴博;[略語]歴史博物館/
れきひょう /暦表/
れきひょうじ /暦表時/
れきぶ /暦部/
れきほう /歴訪;tour/暦法;calendar/
れきほん /暦本/
れきもと /暦本;姓/
れきゆう /歴遊/
れきれき /歴々/歴歴/
れぎゅらーばんぐみ /レギュラー番組/
れこーどがいしゃ /レコード会社/
れこーどてん /レコード店/
れこーどや /レコード屋/
れしぴぼん /レシピ本/
れじおねらきん /レジオネラ菌/
れじよこ /レジ横/
れすきゅーたい /レスキュー隊;rescue team/
れすちおもく /レスチオ目/Restionales/
れすりんぐぶ /レスリング部/
れち /裂/
れちくるざ /レチクル座;Reticulum(Ret)/
れっか /劣化;deterioration/烈火;†-の如く/裂果;[植物]dehiscent fruit/列火;†[部首]「然」の足/
れっかーしゃ /レッカー車;wrecker/
れっかい /裂開/
れっかいか /裂開果/
れっかうらん /劣化ウラン;depleted uranium/
れっかうらんだん /劣化ウラン弾/
れっき /列記/礫器/劣機/
れっきと /歴と/
れっきょ /列挙/
れっきょう /列強/
れっきょがた /列挙型/
れっこう /裂肛/列侯/
れっこく /列国/
れっし /烈士;無駄死に十五烈士/列子/
れっしゃ /列車/
れっしゃあいしょう /列車愛称/
れっしゃいがい /列車以外/
れっしゃいどう /列車移動/
れっしゃうんこう /列車運行/
れっしゃかんかく /列車間隔/
れっしゃぐん /列車群/
れっしゃしゃしん /列車写真/
れっしゃしゅべつ /列車種別/
れっしゃしょくどう /列車食堂/
れっしゃせっきん /列車接近/
れっしゃない /列車内/
れっしゃばんごう /列車番号/
れっしゃへんせい /列車編成/
れっしゃへんせいひょう /列車編成表/
れっしゃほう /列車砲/
れっしゃほんすう /列車本数/
れっしゃみつど /列車密度/
れっしゃむせん /列車無線/
れっしゃめい /列車名/
れっしゃりょうきん /列車料金/
れっしょう /裂傷/
れっしん /烈震/
れっすんしつ /レッスン室/
れっせい /劣勢;†inferior.「味方は-だ」/劣性;†[生物]recessive.「-遺伝」/列聖;canonise/列星/冽清/
れっせいいでん /劣性遺伝/
れっせいいでんし /劣性遺伝子/
れっせき /列席/
れっせきしゃ /列席者/
れっそう /裂創/
れっちゅう /列柱/
れっとう /列島/劣等/
れっとうかん /劣等感/
れっとうざい /劣等財/
れっとうじゅうだん /列島縦断/
れっとうせい /劣等生/
れっぱ /裂破/
れっぱい /劣敗/
れっぱく /裂帛/
れっぱん /列藩/
れっぴん /列品/
れっぴんかん /列品館/
れっぷ /烈婦/烈夫/
れっぷう /烈風/
れっぷく /列福/
れっぺん /裂片/
れつ /列;row/劣;卑劣/烈;強烈/裂;分裂/冽;清冽/洌;(きよい)/
れつ> /劣/
れつあく /劣悪/
れつあくしゃ /劣悪者/
れつい /劣位;inferior/列位;order/
れつくうかん /列空間/
れつご /劣後/
れつごさい /劣後債/
れつざ /列座/
れつじつ /烈日/
れつじゃく /劣弱/
れつじょ /烈女/
れつじょう /劣情/
れつじょでん /列女伝/
れつたんい /列単位/
れつだい /列代/
れつでん /列伝/
れつなみ /列並/
れつばんごう /列番号/
れつべくとる /列ベクトル/
れつめ /列目/
れつりつ /列立/
れつりろん /列理論/
れつれつ /烈々;激しいさま/冽々;寒さの厳しいさま/烈烈/冽冽/
れてん /レ点/
れとるとしょくひん /レトルト食品;retort food. インスタントカレーなど/
れな /玲奈/
れにうむ /Re/Rhenium/
ればさし /レバ刺し/
ればにらいため /レバニラ炒め/
れぶん /礼文/
れぶんとう /礼文島/
れべる# /レベル#1/
れべるさ /レベル差/
れみ /礼美/
れむすいみん /レム睡眠/REM睡眠/
れもん /檸檬/
れもんあじ /レモン味/
れもんいろ /レモン色/
れもんじる /レモン汁/
れもんすい /レモン水/
れもんに /レモン煮/
れん /連/恋/聯;≒連/聨;「聯」の異体字/鎌;かま/廉;廉売/簾;すだれ/濂/煉;煉獄/練;練習/錬;精錬/漣;さざなみ/蓮;はす/嗹/縺;もつ・れる/鏈;くさり/戀;「恋」の旧字/攣;痙攣/臠;ししむら/匳/奩;「匳」の異体字/斂;収斂/瀲;みぎわ/憐;憐憫/輦;てぐるま/
れん> /連;連荘,連銀,連音符/
れんあい /恋愛/憐愛/
れんあいうん /恋愛運/
れんあいえいが /恋愛映画/
れんあいかん /恋愛観/
れんあいかんけい /恋愛関係/
れんあいかんじょう /恋愛感情/
れんあいけっこん /恋愛結婚/
れんあいし /恋愛詩/
れんあいしじょうしゅぎ /恋愛至上主義/
れんあいしょうせつ /恋愛小説/
れんあいじょうじゅ /恋愛成就/
れんあいじょうたい /恋愛状態/
れんあいそうだん /恋愛相談/
れんあいたいしょう /恋愛対象/
れんあいばなし /恋愛話/
れんあいべた /恋愛下手/
れんあいまんが /恋愛漫画/
れんあいろん /恋愛論/
れんおん /連音;liaison/
れんか /廉価/恋歌/連歌;れんが/連枷/
れんかばん /廉価版/廉価盤/
れんかん /連関/連環/聯関;=連関/
れんかんせい /連関性/
れんが /煉瓦/連歌/連火/
れんがいろ /煉瓦色;brickred/
れんがし /連歌師/
れんがづくり /煉瓦造り/レンガ造り/
れんがべい /煉瓦塀/
れんき /連記/練気/
れんきゅう /連休/
れんきゅうあけ /連休明け/連休明/
れんきゅうきかん /連休期間/
れんきゅうこうはん /連休後半/
れんきゅうちゅう /連休中/
れんきゅうまえ /連休前/
れんきょ /蓮炬/
れんきん /錬金/
れんきんじゅつ /錬金術/
れんきんじゅつし /錬金術師/
れんぎ /連木/
れんぎょう /連翹/
れんぎん /連銀/連吟/
れんく /連句/
れんぐん /連軍/
れんけい /連携;coordination/連係;linkage/連系;connected system/連繋;=連係/聯係;=連係/
れんけいかんけい /連携関係/
れんけいきょうか /連携強化/
れんけいこうげき /連係攻撃/
れんけいじ /連係時/
れんけいぷれー /連携プレー/
れんけいわざ /連携技/
れんけつ /連結/廉潔/
れんけついち /連結位置/
れんけつかのう /連結可能/
れんけつき /連結器/連結機/
れんけつけっさん /連結決算/
れんけつさぎょう /連結作業/
れんけつざいむしょひょう /連結財務諸表/
れんけつし /連結子/
れんけつせい /連結性/
れんけつせいぶん /連結成分/
れんけつのうぜいせいど /連結納税制度/
れんけつぶぶん /連結部分/
れんけつめん /連結面/
れんげ /蓮華/蓮花/
れんげおうじょう /蓮華往生/
れんげおんせん /蓮華温泉/
れんげざ /蓮華座/蓮華坐/
れんげそう /蓮華草;手に取るなやはり野におけ- (瓢水)/
れんげん /連言/∧/
れんげんけい /連言形/
れんげんし /連言肢/
れんこ /連呼/
れんこう /連行/連衡/攣拘/簾鉤/
れんこうあし /練行足/
れんこん /蓮根/
れんご /連語/連碁;[囲碁]タッグマッチ/
れんごう /連合/聯合;=連合/
れんごうおうこく /連合王国/
れんごうかい /連合会/
れんごうかんたい /連合艦隊/聯合艦隊/
れんごうきこう /連合機構/
れんごうきょうぎかい /連合協議会/
れんごうぐん /連合軍/
れんごうこく /連合国/
れんごうこくがわ /連合国側/
れんごうこっか /連合国家/
れんごうしんりがく /連合心理学;association psychology/
れんごうたい /連合体/
れんごうてき /連合的/
れんごうや /連合野/
れんごく /煉獄/
れんごくへん /煉獄篇/
れんさ /連鎖/
れんさい /連載/
れんさいかいし /連載開始/
れんさいかいしじ /連載開始時/
れんさいかいしまえ /連載開始前/
れんさいかいすう /連載回数/
れんさいきじ /連載記事/
れんさいきゅうし /連載休止/
れんさいけいしき /連載形式/
れんさいさいかい /連載再開/
れんさいさくひん /連載作品/
れんさいさっか /連載作家/
れんさいし /連載誌/
れんさいしゅうりょう /連載終了/
れんさいしゅうりょうご /連載終了後/
れんさいしょうせつ /連載小説/
れんさいじ /連載時/
れんさいちゅう /連載中/
れんさいちゅうし /連載中止/
れんさいちゅうだん /連載中断/
れんさいとうしょ /連載当初/
れんさいとちゅう /連載途中/
れんさいまんが /連載漫画/
れんさきゅうきん /連鎖球菌;Streptococcus/
れんさく /連作/
れんさくかきょく /連作歌曲/
れんさくしゅう /連作集/
れんさくしょうがい /連作障害/
れんさくたんぺん /連作短編/連作短篇/
れんさくたんぺんしゅう /連作短編集/
れんさすう /連鎖数/
れんさつ /憐察/
れんさてき /連鎖的/
れんさてん /連鎖店;(chain) =チェーン店/
れんさとうさん /連鎖倒産/
れんさはんのう /連鎖反応/
れんさはんばい /連鎖販売/
れんさはんばいとりひき /連鎖販売取引/
れんざ /連座/連坐/蓮座/
れんざせい /連座制/
れんざぶろう /錬三郎/
れんざん /連山/連産/
れんし /連詩/連枝/
れんしゃ /連射/連写/
れんしゃおん /連射音/
れんしゃしき /連射式/
れんしゃたいおう /連写対応/
れんしゃりょく /連射力/
れんしゅ /連取/
れんしゅう /練習/
れんしゅうあいて /練習相手/
れんしゅうかい /練習会/
れんしゅうかいすう /練習回数/
れんしゅうかだい /練習課題/
れんしゅうかん /練習艦/
れんしゅうき /練習機/
れんしゅうきかん /練習期間/
れんしゅうきょく /練習曲/
れんしゅうきょくさくひん /練習曲作品/
れんしゅうこうかい /練習航海/
れんしゅうしだい /練習次第/
れんしゅうしゃ /練習車/
れんしゅうじ /練習時/
れんしゅうじあい /練習試合/
れんしゅうじかん /練習時間/
れんしゅうじょ /練習所/
れんしゅうじょう /練習場/
れんしゅうせい /練習生/
れんしゅうせん /練習船/
れんしゅうそうこう /練習走行/
れんしゅうだい /練習台/
れんしゅうちゅう /練習中/
れんしゅうちょう /練習帳/
れんしゅうなかま /練習仲間/
れんしゅうばしょ /練習場所/
れんしゅうばんごう /練習番号/
れんしゅうび /練習日/
れんしゅうふうけい /練習風景/
れんしゅうぶそく /練習不足/
れんしゅうほう /練習法/
れんしゅうほうほう /練習方法/
れんしゅうまえ /練習前/
れんしゅうもんだい /練習問題/
れんしゅうよう /練習用/
れんしゅうようぐ /練習用具/
れんしゅうりょう /練習量/
れんしゅく /攣縮/
れんしょ /連署/
れんしょう /連勝/
れんしょうきろく /連勝記録/
れんしょうご /連勝後/
れんしょうしき /連勝式/
れんしょうたんしき /連勝単式/
れんしょうちゅう /連勝中/
れんしょうふくしき /連勝複式/
れんじ /連辞;[言語]syntagme ⇔範列(paradigme)/櫺子;窓などの格子/連子;=櫺子/櫺;=櫺子/蓮司;人名/
れんじく /連軸/
れんじだい /レンジ台/
れんじつ /連日/
れんじつほうそう /連日放送/
れんじつれんや /連日連夜/
れんじまど /連子窓;和の格子窓/
れんじゃく /連雀/連尺/
れんじゅ /連珠/
れんじゅう /連中/
れんじゅく /練熟/
れんじょ /連署/
れんじょう /連城/恋情/連声;[言語]sandhi/
れんすうじ /連数字/
れんずぐも /レンズ雲;lenticular cloud/
れんずじょう /レンズ状/
れんずまめ /レンズ豆/
れんせい /錬成/連成/連星/連製/
れんせいけい /連星系/連成系/
れんせいちゅうせいしせい /連星中性子星/
れんせき /煉石;brick/
れんせつ /連接/廉節/
れんせつし /連接子/
れんせつしゃ /連接車/
れんせつぶ /連接部/
れんせつぼう /連接棒/
れんせん /連戦/
れんせんちゅう /連戦中/
れんせんれんしょう /連戦連勝/
れんせんれんぱい /連戦連敗/
れんぜんあしげ /連銭葦毛/
れんそう /連想/聯想;≒連想/連装;-機銃/連奏/
れんそうきおく /連想記憶/
れんそうきおくじゅつ /連想記憶術/
れんそうけんさく /連想検索/
れんそうげーむ /連想ゲーム/
れんそうしき /連想式/
れんそうじしょ /連想辞書/
れんそうてき /連想的/
れんそうはいれつ /連想配列/
れんそうほう /連装砲/
れんそうらむ /連想ＲＡＭ/
れんそうりょく /連想力/
れんぞく /連続/連續;「続」旧字/
れんぞくうんてん /連続運転/
れんぞくおうて /連続王手/
れんぞくおんせい /連続音声/
れんぞくかいさい /連続開催/
れんぞくかいてん /連続回転/
れんぞくかんすう /連続関数/連続函数/
れんぞくかんぷう /連続完封/
れんぞくがぞう /連続画像/
れんぞくくうかん /連続空間/
れんぞくけい /連続系/
れんぞくけいさい /連続掲載/
れんぞくこ /連続弧/
れんぞくこうげき /連続攻撃/
れんぞくさいせい /連続再生/
れんぞくさいせいじかん /連続再生時間/
れんぞくさつえい /連続撮影/
れんぞくさつえいじかん /連続撮影時間/
れんぞくさつじん /連続殺人/
れんぞくさつじんじけん /連続殺人事件/
れんぞくさつじんはん /連続殺人犯/
れんぞくさんしん /連続三振/
れんぞくし /連続紙/
れんぞくしあいしゅつじょう /連続試合出場/
れんぞくしき /連続式/
れんぞくしゃげき /連続射撃/
れんぞくしゃしん /連続写真/
れんぞくしゃぞう /連続写像/
れんぞくじゅうでん /連続充電/
れんぞくじょうしゃけん /連続乗車券/
れんぞくせい /連続性/
れんぞくそうしん /連続送信/
れんぞくそく /連続束/
れんぞくたい /連続体/
れんぞくたいかせつ /連続体仮説/
れんぞくたいりょくがく /連続体力学/
れんぞくだ /連続打/
れんぞくだん /連続弾/
れんぞくち /連続値/
れんぞくてき /連続的/
れんぞくとくてん /連続得点/
れんぞくどうさ /連続動作/
れんぞくはっこう /連続発行/
れんぞくばんぐみ /連続番組/
れんぞくふか /連続負荷/
れんぞくもの /連続もの/
れんぞくゆうしょう /連続優勝/
れんぞくようし /連続用紙/
れんぞくりったいこうさ /連続立体交差/
れんぞくりょう /連続量/
れんぞくりょういき /連続領域/
れんぞくろくがじかん /連続録画時間/
れんぞくわざ /連続技/
れんたい /連帯;joint/連隊;regiment/連対;[競馬]二着までに入ること/連体;[文法]adnominal/聯隊;=連隊/聨隊;「聯」異体字/
れんたい> /連帯;-保証(人|債務),-無限責任,-意識/
れんたいいしき /連帯意識/
れんたいかん /連帯感/
れんたいき /連隊旗/
れんたいきぼ /連隊規模/
れんたいけい /連体形/
れんたいさいむ /連帯債務/
れんたいし /連体詞/
れんたいしゅうしょくご /連体修飾語/
れんたいじっせき /連対実績/
れんたいせきにん /連帯責任/
れんたいせつ /連体節/
れんたいちょう /連隊長/
れんたいほう /連体法/
れんたいほしょう /連帯保証/
れんたいほしょうにん /連帯保証人/
れんたいりつ /連対率/連体率/
れんたつ /練達/
れんたるりょう /レンタル料/
れんたん /連単/練炭/連担/煉炭;=練炭/
れんたんせい /連担性/
れんだ /連打/
れんだい /蓮台/輦台/
れんだいの /蓮台野/
れんだく /連濁/
れんだこ /連凧/
れんだん /連弾/
れんち /廉恥/
れんちゃく /恋着/
れんちゃん /連荘/連チャン/
れんちゅう /連中/
れんちゅうたち /連中達/
れんちょう /連長/
れんちょく /廉直/
れんてつ /錬鉄/
れんとう /連投/連騰;[相場]/連闘;[競馬]連続出走/連祷;litany/
れんとげんしゃしん /レントゲン写真/
れんど /練度/
れんどう /連動/
れんどうかのう /連動可能/
れんどうがた /連動型/
れんどうしき /連動式/
れんどら /連ドラ/
れんにゅう /練乳/煉乳/
れんにょ /蓮如/
れんねん /連年/
れんばい /廉売/
れんばく /恋縛/
れんばん /連番/連判;=れんぱん/
れんばんじょう /連判状/
れんぱ /連覇;連続優勝/連破;連勝/
れんぱい /連敗/連俳;連歌と俳諧／俳諧の連句/
れんぱいきろく /連敗記録/
れんぱいちゅう /連敗中/
れんぱく /連泊/練帛/
れんぱたっせい /連覇達成/
れんぱちゅう /連覇中/
れんぱつ /連発/
れんぱん /連判/
れんぱんじょう /連判状/
れんびん /憐憫/憐愍;=憐憫/
れんぴ /連比/
れんふく /連複/
れんふくしき /連複式/
れんぶ /練武/
れんぶんすう /連分数/
れんぶんせつ /連文節/
れんぶんせつへんかん /連文節変換/
れんぷ /連符/
れんべん /蓮弁/
れんぺい /練兵/錬兵/
れんぺいじょう /練兵場/
れんほう /蓮舫/連舫/
れんぼ /恋慕/
れんぼいん /連母音;[言語]hiatus/
れんぼう /連坊/
れんぼうこうじ /連坊小路/
れんぽ /蓮歩/
れんぽう /連邦;federation/連峰;mountain range/聯邦;=連邦/
れんぽうかいぎ /連邦会議/
れんぽうがわ /連邦側/
れんぽうきょうわこく /連邦共和国/
れんぽうぐん /連邦軍/
れんぽうけいさつ /連邦警察/
れんぽうこっか /連邦国家/
れんぽうさいばんしょ /連邦裁判所/
れんぽうじゅんびぎんこう /連邦準備銀行;Federal Reserve Bank(FRB)/
れんぽうせい /連邦制/
れんぽうせいふ /連邦政府/
れんぽうそうさきょく /連邦捜査局/
れんま /錬磨/練磨;=錬磨/
れんめい /連盟;union/連名;joint names/聯盟;=連盟/
れんめいしゃ /連名者/
れんめん /連綿/
れんや /連夜/
れんよう /連用/
れんようけい /連用形/
れんようしゅうしょくご /連用修飾語/
れんらく /連絡/聯絡;=連絡/
れんらくいいん /連絡委員/
れんらくいん /連絡員/
れんらくえき /連絡駅/
れんらくかい /連絡会/
れんらくかいぎ /連絡会議/
れんらくかのう /連絡可能/
れんらくがかり /連絡係/
れんらくきっぷ /連絡切符/
れんらくきゅうこう /連絡急行/
れんらくきょう /連絡橋/
れんらくぐち /連絡口/
れんらくさ /連絡差/
れんらくさき /連絡先/
れんらくさきしょざいち /連絡先所在地/
れんらくさきじゅうしょ /連絡先住所/
れんらくさきめいき /連絡先明記/
れんらくしゃ /連絡者/
れんらくしゃめい /連絡者名/
れんらくしゅだん /連絡手段/
れんらくしょ /連絡所/連絡書/
れんらくじ /連絡時/
れんらくじこう /連絡事項/
れんらくじょ /連絡所/
れんらくずみ /連絡済み/
れんらくせん /連絡船/連絡線/
れんらくたんとうしゃ /連絡担当者/
れんらくちょう /連絡帳/
れんらくつうろ /連絡通路/
れんらくてつどう /連絡鉄道/
れんらくどう /連絡道/
れんらくひょう /連絡票/
れんらくぶんしょ /連絡文書/
れんらくほうほう /連絡方法/
れんらくもう /連絡網/
れんらくよう /連絡用/
れんらくようむせん /連絡用無線/
れんらくらん /連絡欄/
れんり /連理/
れんりそう /連理草/
れんりつ /連立/聯立;=連立/
れんりついちじほうていしき /連立一次方程式/
れんりつせいけん /連立政権/
れんりつないかく /連立内閣/
れんりつほうていしき /連立方程式/
れんりのえだ /連理の枝;地に在らば-/
れんるい /連累/
れんれん /恋々/恋恋/攣攣/
ろ /炉/路/櫓;oar/艪;=櫓/魯;魯鈍/艫;とも,へさき/櫨;はぜのき/枦;「櫨」の異体字/廬;いおり/瀘;濾過/爐;「炉」の旧字/盧;盧溝橋/臚/蘆;あし/轤;轆轤(ろくろ)/顱;かしら/驢;驢馬/呂;風呂/絽;絽袴/櫚;棕櫚/鷺;さぎ/蕗;ふき/賂;賄賂/露;結露/輅;(大きな車)/鹵;しお/滷/髏;(慣用音)髑髏/
ろ> /露;[略語]ロシア.-大統領,-議会/
ろー /ρ;rho/Ρ;Rho/
ろーかるきょく /ローカル局/
ろーかるしょく /ローカル色/
ろーかるせん /ローカル線;地方鉄道など/
ろーかるばん /ローカル版/
ろーとせいやく /ロート製薬;[企業名]/
ろーとる /老頭児;[中国語]/
ろーま /羅馬;Roma/
ろーまきょうこう /ローマ教皇;pope/
ろーまきょうこうちょう /ローマ教皇庁;Curia Romana/
ろーまし /ローマ史/
ろーましんわ /ローマ神話/
ろーまじ /ローマ字/
ろーまじひょうき /ローマ字表記/
ろーまじん /ローマ人/
ろーますうじ /ローマ数字;I II III IV V VI.../
ろーまていこく /ローマ帝国/
ろーまほう /ローマ法/
ろーまほうおう /ローマ法王;pope/
ろーまほうおうちょう /ローマ法王庁/
ろーむそう /ローム層/
ろーるし /ロール紙/
ろーれんしうむ /Lr/Lawrencium/
ろーれんつへんかん /ローレンツ変換;[物理]Lorentz conversion/
ろーんがいしゃ /ローン会社/
ろあく /露悪/
ろいろ /蝋色/
ろいろうるし /蝋色漆/
ろう /老/牢/労/浪;浪人/朗;ほがらか/郎/蝋;蝋燭/楼;たかどの/聾;聾唖/壟;壟断/朧;朦朧/瓏;玲瓏/籠;かご/篭;「籠」の異体字/蘢;(植物名)/隴;得隴望蜀/滝;たき/槞/臘;陰暦12月/鑞;はんだ/廊;廊下/榔;檳榔樹/瑯;琺瑯/螂;蟷螂(とうろう,かまきり)/狼;おおかみ/琅;琳琅/朖;「朗」の異体字/粮;「糧」の異体字/婁;二十八宿の一つ/僂;傴僂/樓;「楼」の旧字/瘻;痔瘻/簍;(たけかご)/縷;(漢音) 一縷(いちる)/螻;けら/褸;襤褸(ぼろ)/勞;「労」の旧字/撈;漁撈/癆/弄;愚弄/哢;さえずる/漏;漏電/咾/柆/潦;(にわたずみ)/臈;下臈/薐/陋;陋屋/糧;(呉音)兵糧/露;(慣用音)披露/實;「実」の旧字(人名用漢字)/焜;?/
ろう> /老;老猫,老女優,老ゲーテ/
ろうあ /聾唖/
ろうあがっこう /聾唖学校/
ろういろ /蝋色/
ろうえい /漏洩/朗詠/漏泄;=漏洩 (NB:「ろうせつ」の慣用読み)/
ろうえいでんぱ /漏洩電波/
ろうえき /労役/
ろうえきじょう /労役場/
ろうえきじょうりゅうち /労役場留置/
ろうえん /狼煙/
ろうおう /老翁/老王/
ろうおく /陋屋/
ろうおん /漏音/
ろうか /老化/廊下/蝋花/
ろうかい /老獪/
ろうかがわ /廊下側/
ろうかく /楼閣/
ろうかげんしょう /老化現象/
ろうかん /蝋管;†蓄音機の一種/瘻管;[医]fistulous track/老漢/楼観/
ろうがい /老害/労咳/
ろうがっこう /聾学校/
ろうがん /老眼/老顔/蝋丸/
ろうがんきょう /老眼鏡/
ろうき /牢記/癆気/
ろうきほう /労基法/
ろうきゅう /老朽/籠球;basketball/篭球/
ろうきゅうか /老朽化/
ろうきょ /籠居/蝋炬/
ろうきょう /老境/労協;[略語]労働組合協議会/
ろうきょうじゅ /老教授/
ろうきょく /浪曲/
ろうきん /労金;[略語]労働金庫/
ろうぎょ /撈魚/
ろうぎん /朗吟/労銀/
ろうく /労苦/老躯/
ろうくみ /労組/
ろうくん /郎君/老君/
ろうけい /老兄/
ろうけつ /蝋纈/
ろうけん /老健/老犬/陋見/
ろうげつ /朗月/
ろうこ /牢固/狼虎/牢乎/
ろうこう /老公/老巧/瘻孔/陋巷/漏光/
ろうこく /漏刻;水時計/鏤刻;=るこく/
ろうこつ /老骨/
ろうご /老後/
ろうごく /牢獄/
ろうさい /労災/老妻/
ろうさいほけん /労災保険;労働者災害補償保険/
ろうさく /労作/
ろうさん /老杉/
ろうざいく /蝋細工/
ろうざん /老残/
ろうし /労使;労働者と使用者/浪士/老師/老子;道教の祖/労資;労働者と資本家/老死/牢死/浪死;無駄死に/
ろうしかん /労使間/
ろうしかんけい /労使関係/
ろうしつ /狼疾/
ろうしふんそう /労使紛争/
ろうしゃ /聾者/
ろうしゅ /老酒/蝋珠/
ろうしゅう /老醜/陋習/
ろうしゅつ /漏出/
ろうしゅん /老春/
ろうしょう /老松/労相/朗唱/老将/朗笑/労症/癆症/
ろうしょうふじょう /老少不定/
ろうしん /老親/老臣/老身/
ろうしんし /老紳士/
ろうじ /聾児/
ろうじつ /老実/
ろうじゃく /老若/老弱/
ろうじゃくだんじょ /老若男女;ろうにゃくなんにょ?/
ろうじゅ /老樹/
ろうじゅう /老中/
ろうじゅく /老熟/
ろうじょ /老女/
ろうじょう /籠城/篭城;「籠」異体字/楼上/老嬢/
ろうじょもの /老女物/
ろうじん /老人/
ろうじんいりょう /老人医療/
ろうじんいりょうひ /老人医療費/
ろうじんかい /老人会/
ろうじんくらぶ /老人クラブ/
ろうじんご /老人語/
ろうじんしせつ /老人施設/
ろうじんせい /老人性;[医]senile/老人星;[天文]Canopus/
ろうじんせんよう /老人専用/
ろうじんはん /老人斑/
ろうじんびょう /老人病/
ろうじんびょういん /老人病院/
ろうじんふくし /老人福祉/
ろうじんふくししせつ /老人福祉施設/
ろうじんふくしほう /老人福祉法/
ろうじんほーむ /老人ホーム/
ろうじんほけん /老人保健/
ろうじんほけんしせつ /老人保健施設/
ろうじんほけんほう /老人保健法/
ろうすい /漏水/老衰/
ろうすいし /老衰死/
ろうせい /労政/老成;年を積む/老生;老いた人/
ろうせいぶ /労政部/
ろうせき /蝋石/
ろうせつ /漏洩/漏泄;≒漏洩/臘雪/陋拙/
ろうぜき /狼藉/
ろうぜきもの /狼藉者/
ろうそ /労組/
ろうそう /老荘/老僧/老壮/
ろうそうしそう /老荘思想/
ろうそうせい /老壮青/
ろうそく /蝋燭/
ろうぞめ /蝋染/
ろうたい /老体/
ろうたいか /老大家/
ろうたいこく /老大国/
ろうだい /楼台/
ろうだん /壟断;利益独占/
ろうちょうほう /労調法/
ろうちん /労賃/
ろうていとく /老提督/
ろうでん /漏電/楼殿/
ろうと /漏斗/
ろうとう /郎党/郎等/蝋灯/
ろうとじょう /漏斗状/
ろうどう /労働/労動;?/
ろうどうあんぜんえいせいほう /労働安全衛生法/
ろうどういいんかい /労働委員会/
ろうどういよく /労働意欲/
ろうどううんどう /労働運動/
ろうどうか /労働歌/
ろうどうかい /労働界/
ろうどうかいきゅう /労働階級/
ろうどうかちせつ /労働価値説;[経済]/
ろうどうかんきょう /労働環境/
ろうどうかんけいちょうせいほう /労働関係調整法/
ろうどうきじゅん /労働基準/
ろうどうきじゅんかんとくかん /労働基準監督官/
ろうどうきじゅんかんとくしょ /労働基準監督署/
ろうどうきじゅんきょく /労働基準局/
ろうどうきじゅんほう /労働基準法/
ろうどうきぞく /労働貴族/
ろうどうきほんけん /労働基本権/
ろうどうきょうか /労働強化/
ろうどうきょうやく /労働協約/
ろうどうきんこ /労働金庫/
ろうどうぎょうせい /労働行政/
ろうどうくみあい /労働組合/
ろうどうくみあいほう /労働組合法/
ろうどうけいやく /労働契約/
ろうどうけん /労働権/
ろうどうけんしょう /労働憲章/
ろうどうさいがい /労働災害/
ろうどうさんけん /労働三権/
ろうどうさんぽう /労働三法;労働組合法・労働基準法・労働関係調整法/
ろうどうしじょう /労働市場/
ろうどうしゃ /労働者/
ろうどうしゃかいきゅう /労働者階級;working class/
ろうどうしゃとう /労働者党/
ろうどうしゃはけんほう /労働者派遣法/
ろうどうしゅうにゅう /労働収入/
ろうどうしゅうやく /労働集約/
ろうどうしょう /労働省;NB:2001年1月の中央省庁再編で厚生労働省に再編された/労働相;大臣/
ろうどうじかん /労働時間/
ろうどうじょう /労働上/
ろうどうじょうけん /労働条件/
ろうどうせいさく /労働政策/
ろうどうそうぎ /労働争議/
ろうどうだいじん /労働大臣/
ろうどうだんたい /労働団体/
ろうどうとう /労働党/
ろうどうひ /労働費/
ろうどうひよう /労働費用/
ろうどうび /労働日/
ろうどうぶんぱいりつ /労働分配率/
ろうどうほう /労働法/
ろうどうりょう /労働量/
ろうどうりょく /労働力/
ろうどうりょくりつ /労働力率/
ろうどうりんり /労働倫理/
ろうどく /朗読/
ろうどくかい /朗読会/
ろうどくげき /朗読劇/
ろうなぬし /牢名主/
ろうに /老尼/
ろうにゃく /老若/
ろうにゃくなんにょ /老若男女/
ろうにん /浪人/
ろうにんぎょう /蝋人形/
ろうにんじだい /浪人時代/
ろうにんせい /浪人生/
ろうにんせいかつ /浪人生活/
ろうにんちゅう /浪人中/
ろうねん /老年/
ろうねんき /老年期/
ろうねんしゃ /老年者/
ろうのう /労農/老農/
ろうのうは /労農派/
ろうはい /老廃/老輩/
ろうはいぶつ /老廃物/
ろうば /老婆/老馬/
ろうばい /狼狽/老梅/臘梅/
ろうばいか /ロウバイ科/Calycanthaceae/
ろうばしん /老婆心/
ろうばん /牢番/
ろうひ /浪費/
ろうひか /浪費家/
ろうひへき /浪費癖/
ろうびょう /老病/老猫/
ろうふ /老婦/老父/老夫/
ろうふうふ /老夫婦/
ろうふじん /老婦人/
ろうへい /老兵/
ろうほう /朗報/
ろうぼ /老母/
ろうぼく /老木/老僕/
ろうまん /浪漫/
ろうむ /労務/
ろうむし /労務士/
ろうむしゃ /労務者/
ろうむひ /労務費/
ろうめ /浪目/
ろうめいじん /老名人/
ろうもう /老耄/
ろうもん /楼門/
ろうや /牢屋/老爺/朧夜/
ろうやしき /牢屋敷/
ろうやぶり /牢破り/
ろうゆう /老友/老優/老雄/
ろうよう /老幼/
ろうらい /老来/
ろうらく /篭絡/籠絡/
ろうらんどう /楼蘭堂/
ろうりょく /労力/
ろうりょくてき /労力的/
ろうるい /蝋涙/
ろうれい /老齢/
ろうれいか /老齢化/
ろうれいきそねんきん /老齢基礎年金/
ろうれいこうせいねんきん /老齢厚生年金/
ろうれいしゃ /老齢者/
ろうれいねんきん /老齢年金/
ろうれいふくしねんきん /老齢福祉年金/
ろうれつ /陋劣/
ろうれん /労連/老練/
ろうろう /朗々/朗朗/
ろうろうかいご /老老介護;高齢者を高齢者が介護すること/
ろうわ /漏話/朗話/
ろうわん /六萬/
ろえい /露営/
ろおわん /六萬/
ろか /濾過;filter/芦花/蘆花;徳富-/
ろかい /蘆薈;[植物]aloe/櫓櫂;-船/艪櫂;=櫓櫂/
ろかき /濾過器/
ろかく /鹵獲/
ろかこうえん /芦花公園/
ろかそう /濾過槽/
ろかそうち /濾過装置/
ろかた /路肩/
ろかたそうこう /路肩走行/
ろかたちゅうしゃ /路肩駐車/
ろかたはば /路肩幅/
ろぎょ /魯魚;(特に行書などで)間違いやすい字。「-章草の誤り」/鱸魚/
ろぎょがいし /魯魚亥豕/
ろぎん /路銀/
ろく /録;記録/碌;(まとも)碌でなし,碌すっぽ/禄;(salary)禄高/祿;「禄」の旧字(人名用漢字)/六/肋;肋骨/勒;弥勒/漉;こ・す/鹿;(しか)鹿鳴館/麓;山麓/轆;轆轤/戮;(呉音) 殺戮/淕;(呉音)/緑;(呉音)緑青/６/陸;=碌/
ろく> /六/
ろくい /禄位/
ろくいちぎんこう /六一銀行;=一六銀行/
ろくいのくろうど /六位の蔵人/
ろくいん /勒韻/
ろくえふ /六衛府/
ろくおん /録音/鹿苑/
ろくおんかのう /録音可能/
ろくおんかのうじかん /録音可能時間/
ろくおんがわ /録音側/
ろくおんき /録音機/
ろくおんきざい /録音機材/
ろくおんきのう /録音機能/
ろくおんぎじゅつ /録音技術/
ろくおんぎじゅつしゃ /録音技術者/
ろくおんさいせい /録音再生/
ろくおんじ /鹿苑寺;金閣寺の正式な名前/録音時/
ろくおんじょうたい /録音状態/
ろくおんずみ /録音済/
ろくおんちゅう /録音中/
ろくおんてーぷ /録音テープ/
ろくおんないよう /録音内容/
ろくおんねん /録音年/
ろくおんばん /録音盤/
ろくおんひょう /録音評/
ろくおんもと /録音元/
ろくおんもの /録音物/
ろくおんよう /録音用/
ろくが /録画/
ろくがかいしじこく /録画開始時刻/
ろくがきのう /録画機能/
ろくがぎじゅつ /録画技術/
ろくがさいせい /録画再生/
ろくがしっぱい /録画失敗/
ろくがしゅうりょうじこく /録画終了時刻/
ろくがじかん /録画時間/
ろくがじょうほう /録画情報/
ろくがずみ /録画済み/
ろくがたいしょう /録画対象/
ろくがちゅう /録画中/
ろくがちゅうけい /録画中継/
ろくがつ /六月/６月/6月/水無月;※連想,旧暦/
ろくがどり /録画撮り/
ろくがぶ /録画部/
ろくがほうしき /録画方式/
ろくがもの /録画物/
ろくがよやく /録画予約/
ろくがよやくほうしき /録画予約方式/
ろくがりつ /録画率/
ろくぎ /六義/
ろくごう /六郷/六合/麓郷;地名,北海道/
ろくごうざきとうだい /禄剛崎灯台/
ろくごうせん /六号線/
ろくさい /録再/
ろくさいせい /録再生/
ろくさぶろう /六三郎/
ろくさわ /六沢/
ろくさんせい /六三制/
ろくざい /肋材/
ろくしげどう /六師外道/
ろくしゃく /六尺/陸尺/
ろくしゅ /六種/
ろくしょ /六書/
ろくしょう /緑青/六章/
ろくしょういろ /緑青色;Montpellier green/
ろくしょうじっきく /六菖十菊/
ろくしんがったい /六神合体/
ろくしんがん /六神丸;漢方薬/
ろくしんたい /六神体/
ろくじ /六時/録事/6時/
ろくじぞう /六地蔵/
ろくじっさい /六十歳/
ろくじゅう /六十/
ろくじゅうそう /六重奏/
ろくじゅっさい /六十歳/
ろくじょう /六条/六畳/鹿茸;鹿の袋角/
ろくじょうてんのう /六条天皇/
ろくじょうのみやすどころ /六条御息所;[源氏物語]/
ろくじん /六塵/
ろくじんずう /六神通/
ろくすけ /六輔/
ろくすっぽ /碌すっぽ/陸すっぽ/
ろくせい /鹿西/
ろくぞう /六蔵/
ろくたま /六玉/
ろくたろう /六太郎/
ろくたんだ /六反田/
ろくたんとう /六炭糖;[化学]hexose. C6H12O6/
ろくだいがく /六大学/
ろくだいしゅう /六大州/
ろくだか /禄高/
ろくだん /六段/
ろくだんぐみ /六段組/
ろくちょうし /六調子;[邦楽]壱越,平,双,黄鐘,盤渉,太食/
ろくてん /六天/
ろくでなし /碌でなし/陸でなし/
ろくとく /六徳;人が守るべき六つの徳。「りくとく」とも/
ろくど /六度/
ろくどう /六道/
ろくどうえ /六道絵/
ろくどうりんね /六道輪廻/
ろくに /陸に/碌に/
ろくにん /六人/
ろくねん /六年/
ろくねんせい /六年生/
ろくのへ /六戸/
ろくはら /六波羅/
ろくはらたんだい /六波羅探題/
ろくはらみつ /六波羅蜜/
ろくはらみつじ /六波羅蜜寺/
ろくば /六馬/
ろくばん /六番/
ろくばんちょう /六番町/
ろくばんめ /六番目/
ろくびょうし /六拍子;[音楽]/
ろくぶ /六部/
ろくぶんぎ /六分儀/
ろくぶんぎざ /六分儀座;Sextans(Sex)/
ろくべえ /六兵衛/
ろくぼうせい /六芒星/
ろくぼく /肋木/
ろくまい /禄米;扶持米/
ろくまく /肋膜/
ろくまくえん /肋膜炎/
ろくめい /六名/
ろくめいかん /鹿鳴館/
ろくめんたい /六面体/６面体/
ろくもんせん /六文銭/
ろくや /六哉/
ろくやね /陸屋根;[建築]RC造などで、(ほぼ)平らな屋根。 ┌───┐/
ろくよう /六曜/六葉/
ろくよく /六欲/
ろくよくてん /六欲天/
ろくりょうへんせい /六両編成/
ろくれん /６連/
ろくろ /轆轤/
ろくろう /六郎/
ろくろく /碌々/
ろくろくび /轆轤首/
ろくろし /轆轤師/
ろくわり /六割/
ろぐいんめい /ログイン名/
ろけい /炉型/
ろけち /ロケ地/
ろけっとだん /ロケット弾/
ろけっとほう /ロケット砲/
ろけん /路肩/露見/露顕;=露見/
ろこ /路子/
ろこう /露光/炉工/
ろこうき /露光機/
ろこうきょう /盧溝橋/
ろこうきょうじけん /盧溝橋事件/
ろこうじかん /露光時間/
ろこうまど /露光窓/
ろこうりょう /露光量/
ろここちょう /ロココ調/
ろここようしき /ロココ様式/
ろこつ /露骨/
ろご /露語/
ろさんじん /魯山人/
ろざ /露座;-の大仏/炉座;Fornax(For)/露坐;=露座/
ろざん /廬山/
ろし /濾紙/ろ紙/
ろしあ /露西亜/
ろしあかくめい /ロシア革命;[世界史](1917) ソ連誕生/
ろしあぐん /ロシア軍/
ろしあご /ロシア語/
ろしあさん /ロシア産/
ろしあじん /ロシア人/
ろしあせい /ロシア製/
ろしあせいきょうかい /ロシア正教会/
ろしあぶんがく /ロシア文学/
ろしあもじ /ロシア文字;абвгд…→cyrillic,Cyrillic/
ろしありょうり /ロシア料理/
ろしあれんぽう /ロシア連邦;РоссийскаяФедерация/
ろしゅつ /露出/
ろしゅつかた /露出過多/
ろしゅつきょう /露出狂/
ろしゅつけい /露出計/露出系/
ろしゅつけいないぞう /露出計内蔵/
ろしゅつしょう /露出症;[精医]/
ろしゅつじかん /露出時間/
ろしゅつせってい /露出設定/
ろしゅつち /露出値/
ろしゅつど /露出度/
ろしゅつばいすう /露出倍数/
ろしゅつぶ /露出部/
ろしゅつぶそく /露出不足/
ろしゅつほせい /露出補正/
ろしょう /路床/
ろしん /炉心/
ろじ /路地;†alley.「-裏」/露地;†garden.「-栽培」/路次;†道筋/
ろじうむ /Rh/Rhodium/
ろじうら /路地裏/
ろじさいばい /露地栽培/
ろじょう /路上/
ろじょうかんさつ /路上観察/
ろじょうかんさつがく /路上観察学/
ろじょうかんさつがっかい /路上観察学会/
ろじょうきつえん /路上喫煙;-に罰金刑/
ろじょうきょうしゅう /路上教習/
ろじょうせいかつ /路上生活/
ろじょうせいかつしゃ /路上生活者/
ろじょうちゅうしゃ /路上駐車/
ろじょうはんばい /路上販売/
ろじょうれんしゅう /路上練習/
ろじん /魯迅;(1881-1936) 作家。『阿Ｑ正伝』/路人;道行く人/露人;русский/
ろすい /呂翠/
ろせん /路線/
ろせんいがい /路線以外/
ろせんか /路線価/
ろせんけんさく /路線検索/
ろせんげんてい /路線限定/
ろせんしゃ /路線車/
ろせんず /路線図/
ろせんせいび /路線整備/
ろせんばす /路線バス/
ろせんばんごう /路線番号/
ろせんへんこう /路線変更/
ろせんべつ /路線別/
ろせんめい /路線名/
ろせんめいしょう /路線名称/
ろせんもう /路線網/
ろぜったいし /ロゼッタ石;Rosetta Stone/
ろそくたい /路側帯/
ろたんちょう /ロ短調/
ろだい /露台/
ろだたみ /炉畳;[茶道]/
ろちゅう /路駐/
ろちょう /路長/顱頂/
ろちょうちょう /ロ長調/
ろっか /六花/
ろっかーしつ /ロッカー室/
ろっかく /六角/
ろっかくけい /六角形/
ろっかくさい /鹿角菜/
ろっかくばし /六角橋/
ろっかくや /六角家/
ろっかくろむ /六価クロム/
ろっかしょむら /六ヶ所村/
ろっかせん /六歌仙/
ろっかっけい /六角形/
ろっかん /肋間/六官;=りくかん/六巻/
ろっかんきん /肋間筋/
ろっかんしんけい /肋間神経/
ろっかんしんけいつう /肋間神経痛/
ろっき /六輝;NB:先勝・友引・先負・仏滅・大安・赤口。六曜/
ろっきーどじけん /ロッキード事件;[政治](1976)Lockheed scandal/
ろっきとう /六気筒/
ろっきゃく /六脚/
ろっく /六区/
ろっけつ /六穴/
ろっこう /六甲/六興/
ろっこうおろし /六甲颪/
ろっこうさん /六甲山/
ろっこうさんけい /六甲山系/
ろっこうさんじょう /六甲山上/
ろっこうだい /六甲台/
ろっこうみち /六甲道/
ろっこく /六国;=りっこく/
ろっこつ /肋骨/
ろっこん /六根/
ろっこんしょうじょう /六根清浄/
ろっとばんごう /ロット番号/
ろっぱく /六白/
ろっぴき /六匹/
ろっぷ /六腑/
ろっぺい /六平/
ろっぽう /六法/六方/
ろっぽうしょうけい /六方晶系;[化学]hexagonal system/
ろっぽうぜんしょ /六法全書/
ろっぽん /六本/
ろっぽんぎ /六本木/
ろっぽんぎしんじゅう /六本木心中/
ろっぽんぎほうめん /六本木方面/
ろっぽんまつ /六本松/
ろてい /露呈;expose/路程;path/
ろてき /蘆荻/
ろてん /露天;†open-air.「-風呂」/露店;†stall.「縁日の-」/露点;†dew point/
ろてんしょう /露天商/
ろてんぶろ /露天風呂/
ろてんぼり /露天掘り/
ろとう /露頭;†outcrop/路頭;†-に迷う/
ろどん /魯鈍/
ろない /炉内/
ろねつ /炉熱/
ろはば /路幅/
ろはん /露伴/
ろば /驢馬/
ろばた /炉端/爐端;「炉」旧字/
ろばたやき /炉端焼き/炉端焼/
ろばん /路盤;road bed/露盤;[建築]仏塔の九輪の台/
ろばんこうじ /路盤工事/
ろひ /路費/
ろひょう /路標/
ろびーかつどう /ロビー活動;[新語]/
ろびらき /炉開き/
ろふさぎ /炉塞ぎ/
ろぶつ /炉物/
ろぶつり /炉物理/
ろぶん /露文/
ろぶんか /露文科/
ろへん /炉辺;ろばた/路辺;みちばた/
ろへんだんわ /炉辺談話/
ろほう /濾胞/
ろぼう /路傍/
ろぼうのいし /路傍の石/
ろまねすくようしき /ロマネスク様式/
ろまん /浪漫/
ろまんしゅぎ /ロマン主義;romanticism/浪漫主義/
ろまんちっくかいどう /ロマンチック街道;(Romantische Straβe) Wurzburg-Fussen/
ろまんは /ロマン派/
ろまんひこう /浪漫飛行/
ろみ /路美/
ろめい /露命/
ろめいけんばい /驢鳴犬吠/
ろめん /路面/
ろめんおんど /路面温度/
ろめんじょうきょう /路面状況/
ろめんじょうたい /路面状態/
ろめんでんしゃ /路面電車/
ろめんでんしゃよう /路面電車用/
ろめんよう /路面用/
ろもう /路網/
ろやく /露訳/
ろゆう /芦有/
ろよう /路用/
ろれつ /呂律/臚列/
ろん /論/侖;(まるい)/崙;崑崙/崘;「崙」の異体字/栄;[麻雀]/堽;?/
ろんかく /論客/
ろんがい /論外/
ろんきつ /論詰/
ろんきゃく /論客/
ろんきゅう /論究;†discuss/論及;†mention/
ろんきょ /論拠/
ろんぎ /論議/
ろんけつ /論結/論決/
ろんけん /論憲/
ろんげ /ロン毛;[口](男性の)長髪/
ろんこう /論考/論稿/論功;-行賞/論攷;=論考/
ろんこうこうしょう /論功行賞/
ろんこく /論告/
ろんご /論語/
ろんさく /論策/
ろんさん /論纂/
ろんし /論旨/
ろんしゃ /論者/
ろんしゅう /論集/
ろんしょう /論証/
ろんしょうかのう /論証可能/
ろんしょうてき /論証的/
ろんじ /論師/
ろんじゃ /論者/
ろんじゅつ /論述/
ろんじゅつしき /論述式/
ろんじん /論陣/
ろんせつ /論説/
ろんせついいん /論説委員/
ろんせつぶん /論説文/
ろんせん /論戦/
ろんそう /論争/論爭;「争」旧字/
ろんそうあいて /論争相手/
ろんそうし /論争史/
ろんそうちゅう /論争中/
ろんぞう /論蔵/
ろんだい /論題/
ろんだん /論壇;言論界/論断;†discuss and judge/論談;†talk/
ろんちょう /論調/
ろんてい /論定/
ろんてき /論敵/論的;(複合用途) イデア-/
ろんてん /論点/
ろんどん /倫敦;London/
ろんどんしじょう /ロンドン市場/
ろんなん /論難/
ろんばく /論駁/
ろんぱ /論破/
ろんぱん /論判/
ろんひょう /論評/
ろんぴょう /論評/
ろんぶん /論文/
ろんぶんか /論文化/
ろんぶんけいしき /論文形式/
ろんぶんげんこう /論文原稿/
ろんぶんこうえん /論文講演/
ろんぶんさくせい /論文作成/
ろんぶんし /論文誌/
ろんぶんしっぴつ /論文執筆/
ろんぶんしどう /論文指導/
ろんぶんしゅう /論文集/
ろんぶんしょう /論文賞/
ろんぶんしょうかい /論文紹介/
ろんぶんしょうじゅしょう /論文賞受賞/
ろんぶんしんさ /論文審査/
ろんぶんすう /論文数/
ろんぶんせんしゅう /論文選集/
ろんぶんだいめい /論文題名/
ろんぶんちゅう /論文中/
ろんぶんちょう /論文調/
ろんぶんていしゅつ /論文提出/
ろんぶんとうこう /論文投稿/
ろんぶんなど /論文等/
ろんぶんはかせ /論文博士/
ろんぶんはくし /論文博士/
ろんぶんはっぴょう /論文発表/
ろんぶんはっぴょうしゃ /論文発表者/
ろんぶんぼしゅう /論文募集/
ろんぶんめい /論文名/
ろんぶんようし /論文要旨/
ろんべん /論弁/
ろんほー /栄和;[麻雀]/
ろんほうら /栄和了/
ろんぽう /論法/論鋒;議論の勢い。「-鋭く」/
ろんり /論理/
ろんりえんざん /論理演算/
ろんりえんざんし /論理演算子/
ろんりか /論理化/
ろんりかいしゃく /論理解釈/
ろんりかいそう /論理階層/
ろんりかいろ /論理回路/
ろんりかいろず /論理回路図/
ろんりかん /論理感/
ろんりかんすう /論理関数/
ろんりがく /論理学/
ろんりがくしゃ /論理学者/
ろんりがくてき /論理学的/
ろんりがた /論理型/
ろんりがたげんご /論理型言語/
ろんりきごう /論理記号/
ろんりきのう /論理機能/
ろんりきばん /論理機番/
ろんりけい /論理系/
ろんりけいさん /論理計算/
ろんりけつごうし /論理結合子/
ろんりこうぞう /論理構造/
ろんりご /論理語/
ろんりごうせい /論理合成/
ろんりざひょう /論理座標/
ろんりしき /論理式/
ろんりしゅぎ /論理主義/
ろんりじかん /論理時間/
ろんりじょう /論理上/
ろんりせい /論理性/
ろんりせき /論理積/
ろんりせっけい /論理設計/
ろんりそうさ /論理操作/
ろんりそうち /論理装置/
ろんりそし /論理素子/
ろんりたいけい /論理体系/
ろんりち /論理値/
ろんりていすう /論理定数/
ろんりてき /論理的/
ろんりてききけつ /論理的帰結/
ろんりてきこんきょ /論理的根拠/
ろんりてきしこう /論理的思考/
ろんりてきしこうりょく /論理的思考力/
ろんりてきしょうめい /論理的証明/
ろんりてきせいごうせい /論理的整合性/
ろんりてきはんだん /論理的判断/
ろんりてきむじゅん /論理的矛盾/
ろんりてきりかい /論理的理解/
ろんりてんかい /論理展開/
ろんりへんすう /論理変数/
ろんりむじゅん /論理矛盾/
ろんりめい /論理名/
ろんりめいだい /論理命題/
ろんりゆうせん /論理優先/
ろんりわ /論理和/
わ /和/輪/環;≒輪/話/羽;鶏1羽/把;葱1把/倭;日本/我/吾;≒我/啝;(したがう)/萵;ちしゃ/杷;?/琶;?/
わ> /和;和室,和楽器,和仏辞典/
わーるどかっぷ /Ｗ杯/
わい /賄;賄賂/猥;猥褻/隈;界隈/矮;矮小/歪;歪曲/淮;淮水(中国の川)/薈;あつ・まる/
わいおく /矮屋/
わいか /矮化/猥歌/
わいかじ /脇舵/脇楫/
わいが /淮河;地名/
わいきょく /歪曲/
わいきょくしゅうさ /歪曲収差/
わいく /矮躯/
わいげん /猥言/
わいご /猥語/
わいざつ /猥雑/
わいしかんぎ /矮子看戯/
わいしゃつ /Ｙシャツ/Yシャツ/
わいしょ /猥書/
わいしょう /矮小/
わいしょうか /矮小化/
わいじく /Ｙ軸/Y軸/
わいじん /矮人/
わいすい /淮水/
わいせい /矮性;[生物]dwarf.「-種」/矮星;[天文]dwarf star.「白色-」/
わいせつ /猥褻/
わいせつざい /猥褻罪/
わいせつぶつ /猥褻物/
わいせつぶんしょ /猥褻文書/
わいせんしょくたい /Y染色体;[生物]Y-chromosome/Ｙ染色体;[生物]Y-chromosome/
わいだて /脇楯/
わいだん /猥談/
わいど /歪度/
わいない /和井内/
わいほん /猥本/
わいろ /賄賂/
わいろう /矮陋/
わいん /和韻/
わいんいろ /ワイン色/
わいんぐら /ワイン蔵/
わいんに /ワイン煮/
わいんむし /ワイン蒸し/
わう /往/横/王/黄/皇/
わえい /和英/
わえいじしょ /和英辞書/
わえいじてん /和英辞典/
わおう /和欧/
わおん /和音/
わおんかい /和音階/
わか /和歌/若/
わか> /若;若大将,若社長,若ハゲ/
わかあゆ /若鮎/
わかい /和解/和諧/若井/和賀井/
わかいこ /若い子/
わかいしゅ /若い衆/
わかいずみ /和解済/
わかいつばめ /若い燕;愛人/
わかいもの /若い者/
わかいろ /若色/
わかいんきょ /若隠居/
わかえだ /若枝/
わかお /稚郎/
わかおくさま /若奥様/
わかおんな /若女/
わかがえり /若返り/
わかがき /若書き/
わかがしら /若頭/
わかき /若木/
わかぎ /若木/若気;=わかげ/
わかぎみ /若君/
わかくさ /若草/
わかくさいろ /若草色/
わかくさものがたり /若草物語/
わかくわ /若桑/
わかげ /若気/
わかげのいたり /若気の至り/
わかこ /和歌子/和佳子/
わかごま /若駒/
わかさ /若狭/若佐/若さ/
わかさき /若桜木/
わかさぎ /公魚/若鷺/
わかさだに /若狭谷/
わかさと /若里/
わかさま /若様/
わかさわん /若狭湾/
わかざむらい /若侍/
わかざり /輪飾り/
わかしおこくたい /若潮国体/
わかしま /若島/
わかしまづ /若嶋津/
わかしゃちょう /若社長/
わかしゅ /若衆/
わかしゅう /若衆/和歌集/
わかしゅどう /若衆道/
わかしゆ /沸かし湯/
わかしらが /若白髪/
わかじし /若獅子/
わかじに /若死に/
わかす /若洲/
わかすぎ /若杉/
わかせ /若瀬/
わかせがわ /若瀬川/
わかぞう /若造/若僧;=若造/
わかた /若田/
わかたか /若貴;若乃花と貴乃花/
わかたけ /若竹/
わかたけに /若竹煮/
わかたに /若谷/
わかたべ /若田部/
わかだいしょう /若大将/
わかだんな /若旦那/
わかちがき /分かち書き;‖文章を 空白で 区切る 書き方/わかち書き/
わかつき /若槻/若月/
わかづくり /若作り/
わかづま /若妻/
わかて /若手/
わかてかい /若手会/
わかてきし /若手棋士/
わかてけんきゅうしゃ /若手研究者/
わかてげいにん /若手芸人/
わかてさっか /若手作家/
わかてせんしゅ /若手選手/
わかてたいけつ /若手対決/
わかてちゅうしん /若手中心/
わかと /若戸/
わかとおおはし /若戸大橋/
わかとの /若殿/
わかどしより /若年寄/
わかどり /若鶏/若鳥/
わかな /若菜/和佳奈;名/
わかなえいろ /若苗色/
わかなしゅう /若菜集;島崎藤村/
わかのはな /若乃花/若ノ花/
わかはげ /若禿/若ハゲ/
わかはなだ /若花田/
わかはら /若原/
わかば /若葉/
わかばだい /若葉台/
わかばちょう /若葉町/
わかばまーく /若葉マーク/
わかばやし /若林/
わかばやしく /若林区/
わかふうふ /若夫婦/
わかまつ /若松/
わかまつく /若松区/
わかまつじょう /若松城/
わかまつちょう /若松町/
わかまつつうしょう /若松通商;[企業名]/
わかみ /若美/
わかみず /若水/
わかみどり /若緑/
わかみや /若宮/
わかむき /若向き/
わかむし /若虫/
わかむしゃ /若武者/
わかむら /若村/
わかむらさき /若紫/
わかめ /若芽;†young bud/若布;†海藻のワカメ/和布;=若布/稚海藻;=若布/裙蔕菜;=若布/
わかもとせいやく /わかもと製薬;[企業名]/
わかもの /若者/
わかものことば /若者言葉/
わかものたち /若者達/
わかものむき /若者向/
わかものやく /若者役/
わかもり /若森/
わかやく /若役/
わかやなぎ /若柳/
わかやなぎちょう /若柳町/
わかやま /和歌山/若山/
わかやまかん /和歌山間/
わかやまけん /和歌山県/
わかやまけんちょう /和歌山県庁/
わかやまし /和歌山市/
わかやません /和歌山線/
わかやませんごじょう /和歌山線五条/
わかやまだい /和歌山大/
わかやまだいがく /和歌山大学/
わかやまほうめん /和歌山方面/
わかやまぼくすい /若山牧水;(1885-1928)歌人。『別離』『海の声』/
わからずや /分からず屋/
わかれ /別れ/訣れ/
わかれぎわ /別れ際/
わかればなし /別れ話/
わかれみち /分かれ道/別れ道/
わかれめ /分かれ目/
わかれわかれ /別れ別れ/
わかん /和漢/和姦/
わかんこんこうぶん /和漢混淆文;和文ト漢文ノ混淆シタル文体ヲ謂フ/
わかんさんさいずえ /和漢三才図会/
わかんしょ /和漢書/
わかんむり /ワ冠;[部首]/
わかんやく /和漢薬/
わかんよう /和漢洋/
わかんろうえいしゅう /和漢朗詠集/
わが /我が/和賀/吾が/我/
わがい /我が意;-を得たり/
わがきみ /我が君/
わがく /和楽/
わがくに /我が国/わが国/我が國;旧字/
わがこ /我が子/吾子/
わがこと /我が事/我がこと/
わがさ /和傘/
わがし /和菓子/
わがしてん /和菓子店/
わがしゃ /我が社/我社/
わがしや /和菓子屋/
わがしよう /和菓子用/
わがっき /和楽器/
わがつま /我妻/
わがとう /我が党/
わがな /我が名/我名/
わがはい /我輩/吾輩/我が輩/吾が輩/
わがまま /我侭/我儘/我が儘/我がまま/我が侭/
わがみ /我が身/我身/
わがもの /我が物;-と思えば軽し/
わがものがお /我が物顔/
わがや /我が家/我家/
わがわら /和瓦/
わき /脇;side, armpit/腋;armpit/掖;=腋/和気;-あいあい/和紀;人名/沸き/和氣;「気」旧字/
わき> /脇;脇刀,脇固め,脇三味線/
わきあいあい /和気藹々/和気藹藹/和気靄々/和気靄靄/和気あいあい/
わきかいどう /脇街道/
わきかじ /脇舵/
わきかた /脇方/ワキ方/
わきが /腋臭/
わきがため /脇固め/
わきぐち /湧き口/
わきげ /腋毛/脇毛/
わきこ /和貴子/
わきさか /脇坂/
わきざし /脇差/
わきし /脇師/
わきしょうじ /脇障子/
わきじ /脇侍/脇士/
わきすじ /脇筋/
わきた /脇田/
わきだち /脇立/
わきだて /脇楯/
わきつづみ /脇鼓/
わきづくえ /脇机/
わきづけ /脇付/
わきて /脇手/
わきでら /脇寺/
わきのう /脇能/
わきのさわ /脇野沢/
わきのした /脇の下/腋の下/
わきはま /脇浜/
わきはまちょう /脇浜町/
わきばしら /脇柱/
わきばら /脇腹/わき腹/
わきまえ /弁え/
わきみ /脇見/わき見/
わきみうんてん /脇見運転/
わきみず /湧き水/
わきみち /脇道/
わきむら /脇村/
わきめ /脇目;-も振らず/脇芽;[植物]axillary bud/腋芽;=脇芽/
わきもと /脇本/
わきもん /脇門/
わきや /脇谷/
わきやく /脇役/
わきやま /脇山/
わきょう /和協/
わきろ /脇艪/
わきん /和金/和巾/
わぎ /和議/和木/
わぎほう /和議法/
わぎも /吾妹/
わぎもこ /吾妹子/
わぎゅう /和牛/
わぎゅうしょうほう /和牛商法/
わぎょう /ワ行/わ行/
わぎり /輪切り/
わく /枠/惑;惑星/或;ある/和煦;春の日の暖かさ/
わくい /和久井/涌井/
わくいり /枠入り/
わくおち /枠落/
わくがい /枠外/
わくきん /枠金/
わくぎ /和釘/
わくぐみ /枠組み/枠組/
わくぐみかべこうほう /枠組壁工法/枠組壁構法;[建築]いわゆる２×４/
わくじゅん /枠順/
わくじゅんかくてい /枠順確定/
わくじゅんはっぴょう /枠順発表/
わくせい /惑星/枠制/
わくせいかん /惑星間/
わくせいかんじん /惑星間塵/
わくせいけい /惑星系/
わくせいじょうせいうん /惑星状星雲/
わくせいたんさき /惑星探査機/
わくせいめい /惑星名/
わくせん /枠線/
わくた /和久田/
わくだ /和久田/
わくづけ /枠付け/
わくでき /惑溺/
わくない /枠内/
わくなし /枠無し/
わくばん /枠番/
わくべつ /湧別/
わくもん /或問/
わくや /涌谷/
わくら /和倉/
わくらおんせん /和倉温泉/
わくらば /病葉/
わくらん /惑乱/
わくり /和久利/和栗/
わくれん /枠連/
わくん /和訓/
わくんのしおり /和訓栞/
わけ /訳/和気;地名/理由;当て字/分け/分/譯;「訳」の旧字/戯奴/
わけあい /訳合/訳合い/
わけあり /訳有り/
わけい /和敬/
わけいせいじゃく /和敬清寂/
わけかた /分け方/
わけがら /訳柄/
わけぎ /分葱/
わけしり /訳知り/
わけどり /分け取り/
わけへだて /分け隔て/別け隔て/
わけべ /分部/
わけまえ /分け前/
わけめ /分け目/
わけん /和犬/
わげい /話芸/
わげん /和弦/
わこ /和子/
わこう /和光/倭寇/和幸/和孝/若生/和寇/
わこうし /和光市/
わこうしょうけん /和光証券;[企業名]NB:現・新光証券/
わこうだいがく /和光大学;www.wako.ac.jp/
わこうど /若人/
わこうどう /和光堂/
わこうどうじん /和光同塵/
わこうまえ /和光前/
わこく /倭国/
わこくぼん /和刻本/
わこん /和魂/
わこんかんさい /和魂漢才/
わこんようさい /和魂洋才/
わご /和語/倭語/
わごう /和合/
わごむ /輪ゴム/
わごん /和琴/
わごんしゃ /ワゴン車/
わさ /輪差/
わさい /和裁/
わさび /山葵/
わさびあえ /わさび和え/
わさびじょうゆ /山葵醤油/
わさびづけ /山葵漬/
わさん /和算;日本古来の数学/和讃;和語による讃歌/
わさんぼん /和三盆/
わざ /技;technique.「柔道の-」/業;conduct.「なせる-」/術;<rare> trick/伎;≒技/
わざあり /技有り;2つで一本/
わざおぎ /俳優/
わざし /業師/
わざせん /技戦/
わざと /態と/
わざもの /業物/
わざら /和皿/
わざわ /和沢/
わざわい /災い/禍;(字義:落とし穴)/災;(字義:生活を阻むもの)/
わざわざ /態々/態態/
わし /鷲/和紙/儂;I/
わしお /鷲尾/
わしか /鷲家;姓/
わしき /和式/
わしさか /鷲坂/
わしざ /鷲座;Aquila(Aql)/
わしず /鷲巣;姓/
わしつ /和室/
わしつちゅうしん /和室中心/
わしづ /鷲津/
わしづかみ /鷲掴み/
わしのぎ /鷲之樹/
わしばな /鷲鼻/
わしま /和島/
わしみ /鷲見/
わしみや /鷲宮/
わしゃ /話者/
わしゃかん /話者間/
わしゃすう /話者数/
わしゃてきおう /話者適応/
わしゃない /話者内/
わしゃにんしき /話者認識/
わしゅ /和種/
わしゅう /和州;大和/和臭;(漢詩の)日本臭さ/和習/倭州;大和/
わしゅうごう /和集合/∪/
わしゅうざん /鷲羽山/
わしょ /和書/
わしょく /和食/
わしょくどう /和食堂/
わしょっき /和食器/
わしら /儂等/
わしん /和親/
わしんとん /華盛頓;Wshington/
わしんとんじょうやく /ワシントン条約;Washington Convention. 「絶滅のおそれのある野生動植物の国際取引に関する条約」/
わじ /和字/
わじき /鷲敷/
わじここんつうれいぜんしょ /和字古今通例全書/
わじしょうらんしょう /和字正濫鈔;契沖,1695. 歴史的仮名遣いを確立/
わじま /輪島;地名,石川県/和島/和嶋/
わじまぬり /輪島塗/
わじゅう /輪中/
わじゅつ /話術/
わじゅん /和順/
わじるし /わ印/
わじん /倭人/和人;=倭人/
わじんでん /倭人伝/
わすう /話数/
わすうじ /和数字/
わすれ /忘れ/
わすれがたみ /忘れ形見/
わすれなぐさ /勿忘草/
わすれね /忘れ音/
わすれもの /忘れ物/
わずか /僅か/
わずらい /煩い/患い/
わせ /早稲/早生/
わせい /和製/和声/話声/和西/和生;人名/
わせいえいご /和製英語/
わせいか /和声化/
わせいがく /和声学/
わせいしんこう /和声進行/
わせいてき /和声的/
わせいほう /和声法;作曲技法の一,⇔対位法/
わせいや /和声屋/
わせいりろん /和声理論/
わせき /和積/
わせだ /早稲田/
わせだぐち /早稲田口/
わせださい /早稲田祭/
わせだだい /早稲田大/
わせだだいがく /早稲田大学/
わせだぶんがく /早稲田文学;雑誌/
わせだりこう /早稲田理工/
わせん /和船/和戦/
わそう /和装/
わそうぼん /和装本/
わぞく /倭族/
わた /綿/腸/棉;≒綿/緜;「綿」の異体字/渡/
わたあめ /綿飴/
わたいれ /綿入れ/
わたうち /綿打ち/
わたかべ /渡壁/
わたがし /綿菓子/棉菓子/
わたくし /私/
わたくしあて /私宛/
わたくしぎ /私儀/
わたくしごと /私事/
わたくししごと /私仕事/
わたくししょうせつ /私小説/
わたくしじしん /私自身/
わたくしせい /私性/
わたくしたち /私達/
わたくしども /私共/私ども/
わたくしばん /私版/
わたくしりつ /私立/
わたくり /綿繰り/
わたぐも /綿雲/
わたげ /綿毛/
わたごみ /綿ゴミ/
わたし /私/渡し/
わたしあて /私宛/
わたしいがい /私以外/
わたしかた /渡し方/
わたしこじん /私個人/
わたしこみ /渡し込み/
わたしじしん /私自身/
わたしたち /私達/私たち/
わたしたちあて /私達宛/
わたしども /私共/私ども/
わたしの /私の/
わたしば /渡し場/
わたしばし /渡し箸/
わたしひとり /私一人/
わたしぶね /渡船/渡し船/渡し舟/
わたしもり /渡し守/
わたしゃ /私ゃ/
わたしら /私等/
わたしりゅう /私流/
わたせ /渡瀬/綿瀬/
わたたに /綿谷/
わただ /和多田/
わたつみ /綿津見;海(の神様)/綿摘み/
わたどの /渡殿/
わたなべ /渡辺/渡部/渡邊/渡邉/
わたなべかざん /渡辺崋山;1793-1841/
わたなべかずお /渡辺一夫;(1901-75) 仏文学者・ユマニスト/
わたなべじゅんいち /渡辺淳一/
わたぬき /綿貫/
わたのは /渡波/
わたばね /綿羽/
わたびき /綿引/
わたぶとん /綿布団/
わたべ /渡部/
わたぼうし /綿帽子/
わたぼこり /綿埃/
わたむら /綿村/
わたもり /渡森/
わたや /綿屋/渡谷/
わたゆき /綿雪/
わたらい /度会/
わたらせがわ /渡良瀬川/
わたり /渡り/亘/亘理/渡/
わたりおん /渡り音;[音声学]transient/
わたりがに /渡蟹/
わたりぐん /亘理郡/
わたりぜりふ /渡り台詞/
わたりぞめ /渡り初め/
わたりちょう /亘理町/
わたりどの /渡殿/渡り殿/
わたりどり /渡り鳥/
わたりもの /渡り者/
わたりやぐら /渡り櫓/
わたりろう /渡り廊/
わたりろうか /渡り廊下/
わたる /渡/道/航/渉/亘/弥/亙;(人名用漢字)/
わだ /和田/
わだい /話題/
わだいげんてい /話題限定/
わだいこ /和太鼓/
わだいこうかん /話題交換/
わだいさく /話題作/
わだいせい /話題性/
わだいそうぜん /話題騒然/
わだいていきょう /話題提供/
わだいていきょうしゃ /話題提供者/
わだいぬし /話題主/
わだいふっとう /話題沸騰/
わだいふっとうちゅう /話題沸騰中/
わだいまんさい /話題満載/
わだち /轍/和達/
わだつみ /海神/海童/
わだやま /和田山/
わだんす /和箪笥/
わち /和知/和智/
わちゅう /話中/和衷;-協同/
わちゅうきょうどう /和衷協同/
わちょう /和朝/倭朝;=和朝/
わっか /輪っか/
わっかない /稚内/
わっかないえき /稚内駅/
わっかないかん /稚内間/
わっかないこうえん /稚内公園/
わっかないしない /稚内市内/
わっさむ /和寒/
わっとじ /ワット時;Wh/
わっぱ /輪っぱ;-飯/
わっぷ /割賦/割符/
わつじ /和辻/
わづか /和束/
わて /和手/
わていしょく /和定食/
わとう /話頭/
わとじ /和綴じ/
わどう /和銅;年号(708-715)/
わどうかいちん /和同開珎/
わどうかいほう /和同開珎/和同開宝;?/
わどく /和独;-辞典/
わどくじてん /和独辞典/
わどけい /和時計/
わどまり /和泊/
わどめ /輪止め/輪留め/
わな /罠/羂;≒罠/
わなげ /輪投げ/
わなみ /罠網/
わに /鰐/王仁;人名,百済の学者/和邇/
わにがわ /鰐皮/ワニ革/ワニ皮/
わにぐち /鰐口/
わにりょうり /鰐料理/
わぬけ /輪抜け/
わのうち /輪之内/
わはん /和版/
わひと /和人;=我人/我人;you/
わび /詫び;apologise/詫/侘び;-寂び/侘/佗/
わびごと /詫び言/
わびじょう /詫び状/詫状/
わびずまい /侘び住まい/侘住い/
わびちゃ /侘び茶/侘茶/
わびね /侘寝/
わふう /和風/
わふうあじ /和風味/
わふうきっさ /和風喫茶/
わふうけんちく /和風建築/
わふく /和服/
わふくすがた /和服姿/
わふつ /和仏/
わぶん /和文/
わぶんだいもく /和文題目/
わぶんつうわひょう /和文通話表/
わぶんでんしん /和文電信/
わぶんもじ /和文文字/
わぶんろんぶん /和文論文/
わへい /和平/話柄/
わへいあん /和平案/
わへいかいぎ /和平会議/
わへいこうしょう /和平交渉/
わへいすいしんは /和平推進派/
わほう /話法;narration/和方;⇔漢方/
わほん /和本/話本/
わぼうちょう /和包丁/
わぼく /和睦/
わみょうしょう /和名抄;漢和辞典/
わみょうるいじゅしょう /倭名類聚鈔/
わむし /輪虫/
わめい /和名/
わめきごえ /喚き声/
わもじ /我文字/
わもの /和物/和モノ/倭物/
わや /和谷;姓/
わやく /和訳/
わやくぶん /和訳文/
わよう /和洋/和様/
わようくだん /和洋九段/
わようじょし /和洋女子/
わようじょしだい /和洋女子大/
わようせっちゅう /和洋折衷/
わようちゅう /和洋中/
わら /藁/稿;≒藁/原/和良/
わらい /笑い/（笑）/笑/(笑)/
わらいえ /笑い絵/
わらいかた /笑い方/
わらいがお /笑い顔/
わらいぐさ /笑い種/
わらいごえ /笑い声/
わらいごと /笑い事/
わらいじょうご /笑い上戸/
わらいじわ /笑い皺/
わらいなき /笑い泣き/
わらいばなし /笑い話/
わらいぼん /笑い本/
わらいもの /笑い者/笑い物/
わらがい /藁谷/
わらがみ /藁紙/
わらく /和楽/
わらくず /藁屑/
わらぐつ /藁沓/
わらし /童/
わらしごと /藁仕事/
わらしべ /藁しべ/
わらしや /藁谷/
わらじ /草鞋/鞋/
わらじだいおう /草鞋大王/
わらじばき /草鞋履/
わらじむし /草鞋虫/
わらぞうり /藁草履/
わらなわ /藁縄/
わらにんぎょう /藁人形/
わらばい /藁灰/
わらばんし /藁半紙/
わらび /蕨/藁火/
わらびこ /蕨粉/
わらびて /蕨手/
わらびもち /蕨餅/わらび餅/
わらぶき /藁葺き/
わらぶとん /藁布団/藁蒲団/
わらべ /童/
わらべうた /童歌/童唄/わらべ歌/わらべ唄/
わらべがみ /童神/
わらべことば /童言葉/
わらや /藁屋/
わらわ /妾/童/
わらわべ /童部/
わり /割/割り/
わりあい /割合/
わりあて /割り当て/割当/割当て/
わりあてかのう /割当て可能/
わりあてせい /割当制/
わりいし /割石/
わりいん /割印/割り印/
わりかし /割かし/割りかし/
わりかた /割方/割り方/
わりかん /割り勘/割勘/
わりがき /割書/
わりぐりいし /割栗石/
わりこうだい /割高台/
わりこみ /割り込み/割込み/割込/
わりこみじ /割り込み時/
わりざん /割り算/割算/
わりした /割下/
わりじょうゆ /割り醤油;[料理]ダシ等で割った醤油/
わりだか /割高/
わりだかかん /割高感/
わりだかりょうきん /割高料金/
わりだけ /割竹/割り竹/
わりだし /割り出し/割出し/
わりちゅう /割注/
わりつけ /割付/割り付け/割付け/
わりつけがく /割付額/
わりと /割と;-元気良く/
わりに /割に;-合う,-良く出来てる/
わりばし /割り箸/割箸/
わりびき /割引/割引き/割り引き/
わりびきうんちん /割引運賃/
わりびきかかく /割引価格/
わりびききっぷ /割引切符/
わりびきけん /割引券/
わりびきこうくうけん /割引航空券/
わりびきさい /割引債/
わりびきしょう /割引証/
わりびきせいど /割引制度/
わりびきてがた /割引手形/
わりびきはっこう /割引発行;discount issue. 「公社債の-」 NB:株式の割引発行は禁止されていたが、商法改正で撤廃/
わりびきはんばい /割引販売/
わりびきりつ /割引率/
わりびきりょう /割引料/
わりびきりょうきん /割引料金/
わりふ /割符/
わりふり /割り振り/割振り/
わりまえ /割前/
わりまし /割増/割増し/割り増し/
わりましうんちん /割増運賃/
わりましきん /割増金/
わりまししょうきゃく /割増償却/
わりましちんぎん /割増賃金/
わりめ /割目/
わりもどし /割戻し/割り戻し/
わりやす /割安/
わりやすかん /割安感/
わる /悪/÷/惡;「悪」の旧字(人名用漢字)/割る/
わる> /悪;悪ガキ,悪ノリ,悪知恵/
わるあがき /悪足掻き/悪あがき/
わるあそび /悪遊び/
わるいき /悪い気/
わるいこ /悪い子/
わるいこと /悪い事/
わるお /悪男/
わるがき /悪ガキ/悪餓鬼/
わるぎ /悪気/
わるくち /悪口/
わるぐち /悪口/
わるさ /悪さ/
わるじえ /悪知恵/
わるずれ /悪擦れ/
わるだくみ /悪巧み/
わるだっしゃ /悪達者/
わるだま /悪玉/
わるぢえ /悪知恵/
わるどめ /悪止め/
わるのり /悪乗り/悪ノリ/
わるふざけ /悪ふざけ/悪巫山戯/
わるもの /悪者/悪物/
わるやく /悪役/
わるよい /悪酔い/
われ /我/吾/
われから /割殻/
われがち /我勝ち/
われき /和暦/
われごえ /破れ声/
われさき /我先/
われしらず /我知らず/
われながら /我乍ら/我ながら/
われなべ /割れ鍋;-に綴じ蓋/破れ鍋;=割れ鍋/
われひと /我人/
われめ /割れ目/割目/
われもこう /吾亦紅;[植物]burnet/吾木香/我毛香/
われもの /割れ物/
われもわれも /我も我も/
われら /我等/我ら/我們/
われわれ /我々/我我/
わん /椀;木質のおわん/碗;焼き物のおわん/湾;湾岸/彎;彎曲/弯;「彎」の異体字/灣;「湾」の旧字/腕;鉄腕/豌;豌豆(えんどう)/綰/万;(wan)中国音/萬;「万」の旧字(人名用漢字)/王;(wang)中国音/
わんがい /湾外/
わんがた /碗型/
わんがん /湾岸/
わんがんかいはつ /湾岸開発/
わんがんしょこく /湾岸諸国/
わんがんせん /湾岸線/
わんがんせんそう /湾岸戦争/
わんがんせんそうじ /湾岸戦争時/
わんがんちいき /湾岸地域/
わんきゅう /椀久;椀屋久右衛門/
わんきょく /湾曲/彎曲;=湾曲/弯曲;異体字/
わんぎり /ワン切り/
わんこう /湾口/
わんこそば /椀子蕎麦/
わんこつ /腕骨/
わんしょう /腕章/
わんじょう /椀状/
わんず /万子/
わんそくるい /腕足類/
わんたん /雲呑/
わんたんめん /雲呑麺/ワンタン麺/
わんだね /椀種;[料理]お吸い物の具/
わんちゃい /湾仔/
わんとう /湾頭/
わんない /湾内/
わんにゅう /湾入/彎入;=湾入/
わんぱい /王牌/
わんぱく /腕白/
わんもの /椀物/碗物/
わんりゅう /湾流/
わんりょく /腕力/
わんりょくは /腕力派/
を /小/緒/雄/男/牡/尾/悪/汚/惡;「悪」の旧字(人名用漢字)/
をう /翁/
をことてん /乎古止点/
をんな /女/
